# -*- coding: utf-8 -*-

################################################################################
#                                                                              #
# tonescale                                                                    #
#                                                                              #
################################################################################
#                                                                              #
# LICENCE INFORMATION                                                          #
#                                                                              #
# This program provides sound utilities and sounds.                            #
#                                                                              #
# copyright (C) 2017 William Breaden Madden                                    #
#                                                                              #
# This software is released under the terms of the GNU General Public License  #
# version 3 (GPLv3).                                                           #
#                                                                              #
# This program is free software: you can redistribute it and/or modify it      #
# under the terms of the GNU General Public License as published by the Free   #
# Software Foundation, either version 3 of the License, or (at your option)    #
# any later version.                                                           #
#                                                                              #
# This program is distributed in the hope that it will be useful, but WITHOUT  #
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or        #
# FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for     #
# more details.                                                                #
#                                                                              #
# For a copy of the GNU General Public License, see                            #
# <http://www.gnu.org/licenses/>.                                              #
#                                                                              #
################################################################################

from __future__ import division
import os

import numpy
import scipy.io.wavfile
import shijian

name    = "tonescale"
version = "2017-05-16T1733Z"

class Sound(object):

    def __init__(
        self,
        name = None,
        rate = 41000,
        data = numpy.array([[0, 0]], dtype = numpy.int16)
        ):

        self._name = name
        self._rate = rate
        self._data = data

    def name(
        self
        ):

        return self._name

    def set_name(
        self,
        name = None
        ):

        self._name = name

    def rate(
        self
        ):

        return self._rate

    def set_rate(
        self,
        rate = None
        ):

        self._rate = rate

    def data(
        self
        ):

        return self._data

    def set_data(
        self,
        data = None
        ):
        self._data = data

    def read_WAVE(
        self,
        filename = None
        ):

        self._rate, self._data = scipy.io.wavfile.read(filename)
        if self._name is None:
            self._name = filename.rstrip(".wav").rstrip(".WAV")

    def save_WAVE(
        self,
        filename = None
        ):

        if filename is None:
            filename = shijian.slugify(text = self._name)
        scipy.io.wavfile.write(
            filename,
            self._rate,
            self._data
        )

    def save_plaintext(
        self,
        filename = None
        ):

        if filename is None:
            filename = shijian.slugify(text = self._name)
        file_save = open(filename, "w")
        numpy_print_option_threshold_tmp = numpy.get_printoptions()["threshold"]
        numpy.set_printoptions(threshold = numpy.nan)
        file_save.write(numpy.array_repr(self._data))
        numpy.set_printoptions(threshold = numpy_print_option_threshold_tmp)
        file_save.close()

    def repeat(
        self,
        number = None
        ):

        data_tmp = numpy.concatenate((self._data,) * number)
        self._data = data_tmp

    def play(
        self,
        background = False
        ):

        filename_tmp = shijian.propose_filename(
            filename = shijian.time_UTC() + ".wav"
        )
        self.save_WAVE(
            filename = filename_tmp
        )
        command = """
        aplay --quiet "{filename}"
        """.format(
            filename = filename_tmp
        )
        if background:
            command = command.rstrip().rstrip("\n") + " &"
        shijian.engage_command(
            command = command
        )
        os.remove(filename_tmp)

    def concatenate(
        self,
        sounds = None
        ):

        for sound in sounds:
            self._data = numpy.concatenate((self._data, sound._data))

    def __add__(
        self,
        other
        ):

        return Sound(data = numpy.concatenate((self._data, other._data)))

    def __radd__(
        self,
        other
        ):

        if other == 0:
            return self
        else:
            return self.__add__(other)

sounds = []

def access_sound(
    name = None
    ):

    for sound in sounds:
        if sound.name() == name:
            return sound
    return None

def convert_WAVE_file_to_tonescale_sound_file(
    filename_WAVE            = None,
    filename_tonescale_sound = None
    ):

    if not filename_tonescale_sound:
        filename_tonescale_sound = filename_WAVE.rstrip(".wav").rstrip(".WAV")
        filename_tonescale_sound = shijian.propose_filename(
            filename = filename_tonescale_sound + ".py"
        )
    sound = Sound()
    sound.read_WAVE(filename = filename_WAVE)
    sound.save_plaintext(filename = filename_tonescale_sound)

sounds.append(Sound(
    name = "199935__drzhnn__04-blip",
    rate = 41000,
    data = numpy.array([[     1,      1],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [     3,      4],
                        [     4,      4],
                        [     2,      2],
                        [     2,      2],
                        [    -1,      1],
                        [    -1,      1],
                        [     6,      7],
                        [     8,      9],
                        [     6,      6],
                        [     2,      1],
                        [     4,      2],
                        [     6,      5],
                        [     0,      2],
                        [     2,      2],
                        [     2,      1],
                        [     0,     -2],
                        [     5,      6],
                        [     3,      7],
                        [     1,      2],
                        [     2,      0],
                        [     4,      4],
                        [     7,      9],
                        [     3,      2],
                        [     2,      2],
                        [     4,      7],
                        [    -1,     -2],
                        [    -2,      0],
                        [     2,      4],
                        [    10,      7],
                        [     2,      2],
                        [    -4,     -2],
                        [    11,     11],
                        [    -4,     -4],
                        [     2,      3],
                        [    12,     12],
                        [    -8,     -8],
                        [     6,      5],
                        [     4,      7],
                        [    -1,      0],
                        [     8,      8],
                        [     2,      7],
                        [     1,      0],
                        [     7,      6],
                        [     2,      5],
                        [    -1,      0],
                        [     7,      6],
                        [    -2,      1],
                        [     2,      2],
                        [     4,      2],
                        [     2,      5],
                        [     4,      2],
                        [     2,     -1],
                        [     5,      6],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [     2,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     7,      8],
                        [     5,      5],
                        [     2,      2],
                        [     7,     10],
                        [     2,      3],
                        [     2,      1],
                        [     6,      6],
                        [     1,      0],
                        [    -2,     -1],
                        [     7,      6],
                        [    -2,     -2],
                        [     4,      3],
                        [    10,      9],
                        [    -4,     -2],
                        [     4,      5],
                        [    -1,     -2],
                        [    -3,     -2],
                        [     9,      9],
                        [     2,      2],
                        [     2,      3],
                        [    -6,     -5],
                        [    -4,     -3],
                        [    11,      9],
                        [    -4,     -4],
                        [     2,      2],
                        [    11,      9],
                        [     5,      4],
                        [     7,      7],
                        [    -5,     -5],
                        [     7,      4],
                        [     5,      5],
                        [    -5,     -3],
                        [    10,      9],
                        [    -2,     -3],
                        [     2,      1],
                        [    11,     11],
                        [    -1,     -5],
                        [     0,      2],
                        [     2,      6],
                        [    -1,     -3],
                        [     7,      8],
                        [    10,      9],
                        [     4,      3],
                        [     6,      7],
                        [    -5,     -4],
                        [    -2,      0],
                        [     8,      7],
                        [    -1,      1],
                        [    -5,     -4],
                        [     4,      3],
                        [     2,      5],
                        [    -1,     -3],
                        [    12,     11],
                        [    -1,      1],
                        [    -6,     -6],
                        [    10,      9],
                        [     2,      2],
                        [     2,      1],
                        [     1,      0],
                        [     6,      5],
                        [     5,      2],
                        [    -4,     -2],
                        [     6,      7],
                        [     0,     -1],
                        [    -2,      0],
                        [     6,      5],
                        [     1,      2],
                        [    -2,     -4],
                        [    -4,     -2],
                        [    -1,      2],
                        [     1,     -2],
                        [     4,      8],
                        [     8,      8],
                        [     1,     -3],
                        [    -4,     -2],
                        [     1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      0],
                        [    -4,     -2],
                        [     2,      2],
                        [     2,      3],
                        [    -4,     -2],
                        [     2,     -1],
                        [    -4,     -2],
                        [     4,      4],
                        [     3,      1],
                        [    -7,     -4],
                        [     7,      6],
                        [     2,     -1],
                        [    -2,     -2],
                        [     4,      7],
                        [    -1,      1],
                        [    -3,     -6],
                        [    -9,    -11],
                        [    -7,     -6],
                        [     7,      7],
                        [     1,      0],
                        [     5,      7],
                        [     6,      8],
                        [    -7,     -5],
                        [     0,     -2],
                        [    -3,     -3],
                        [    -5,     -5],
                        [    -2,     -3],
                        [    -2,     -3],
                        [     0,      0],
                        [    -4,     -2],
                        [    -3,     -2],
                        [     3,      2],
                        [     3,      2],
                        [    -2,     -2],
                        [    -6,     -4],
                        [     1,      1],
                        [     1,     -1],
                        [     0,     -1],
                        [    -2,     -3],
                        [    -4,     -4],
                        [    -1,      0],
                        [    -3,     -3],
                        [     5,      6],
                        [    -2,      1],
                        [    -7,     -5],
                        [     9,      8],
                        [     3,      3],
                        [    -3,     -1],
                        [     1,      3],
                        [    -1,     -3],
                        [     2,      1],
                        [     3,      2],
                        [    -2,     -3],
                        [     0,      3],
                        [     4,      4],
                        [    -2,     -5],
                        [    -5,     -7],
                        [    -5,     -4],
                        [     1,      3],
                        [     6,      4],
                        [    -7,     -7],
                        [     3,      4],
                        [     5,      4],
                        [    -5,     -4],
                        [     5,      3],
                        [    -7,     -7],
                        [    -7,     -4],
                        [    -3,     -4],
                        [    -7,     -8],
                        [     7,      7],
                        [     0,      2],
                        [    -4,     -3],
                        [     1,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -8,     -7],
                        [    -4,     -2],
                        [     3,      2],
                        [     1,      0],
                        [    -7,     -8],
                        [    -1,      0],
                        [     2,      0],
                        [    -9,     -9],
                        [     6,      7],
                        [     8,      8],
                        [    -4,     -5],
                        [   -10,    -11],
                        [    -4,     -2],
                        [     4,      3],
                        [     2,      2],
                        [     2,      3],
                        [    -3,     -6],
                        [    -4,     -4],
                        [     1,      0],
                        [    -5,     -7],
                        [    -5,     -3],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -7],
                        [    -5,     -3],
                        [     2,      4],
                        [    -2,     -3],
                        [    -9,     -7],
                        [    -3,     -3],
                        [     1,      2],
                        [     0,      1],
                        [    -7,     -9],
                        [    -2,     -2],
                        [    -6,     -2],
                        [     2,      1],
                        [     5,      2],
                        [    -8,     -5],
                        [    -1,     -2],
                        [     0,     -3],
                        [     4,      5],
                        [    -2,     -1],
                        [    -6,     -5],
                        [     3,      6],
                        [    -5,     -7],
                        [    -5,     -8],
                        [     6,      6],
                        [    -3,     -5],
                        [    -3,      0],
                        [     7,      8],
                        [    -2,     -4],
                        [    -3,     -4],
                        [    -3,     -2],
                        [     0,     -1],
                        [     3,      4],
                        [    -2,     -2],
                        [     3,      2],
                        [     1,     -1],
                        [    -7,     -8],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -1,     -2],
                        [    -3,     -4],
                        [    -4,     -5],
                        [     2,      1],
                        [     6,      3],
                        [    -2,     -2],
                        [    -3,     -1],
                        [     2,      3],
                        [    -1,     -2],
                        [    -1,     -3],
                        [    -6,     -6],
                        [    -7,     -6],
                        [    -5,     -4],
                        [     2,      0],
                        [     8,      7],
                        [    -1,     -1],
                        [    -6,     -4],
                        [    -5,     -4],
                        [    -4,     -6],
                        [     3,      2],
                        [     2,      1],
                        [    -6,     -6],
                        [     4,      3],
                        [    -1,     -1],
                        [    -5,     -6],
                        [     1,      2],
                        [    -2,     -2],
                        [    -7,     -9],
                        [     0,      2],
                        [     4,      3],
                        [     1,     -3],
                        [    -3,     -3],
                        [    -1,     -2],
                        [     1,     -1],
                        [    -8,     -7],
                        [     1,      1],
                        [    -7,     -7],
                        [    -6,     -6],
                        [     3,      3],
                        [   -11,    -11],
                        [     0,     -2],
                        [     2,      1],
                        [    -9,    -10],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -8,     -7],
                        [    -6,     -8],
                        [    -6,     -7],
                        [    -5,     -4],
                        [    -3,     -5],
                        [    -2,     -3],
                        [     2,      0],
                        [    -4,     -2],
                        [    -7,     -6],
                        [    -2,     -5],
                        [    -2,     -2],
                        [    -4,     -4],
                        [     2,      2],
                        [     1,     -2],
                        [    -9,    -10],
                        [    -7,     -7],
                        [    -1,      0],
                        [     4,      2],
                        [    -6,    -10],
                        [    -7,     -4],
                        [    -2,      0],
                        [    -5,     -6],
                        [     1,      3],
                        [    -5,     -7],
                        [   -10,    -11],
                        [     0,      2],
                        [    -5,     -6],
                        [    -5,     -4],
                        [    -2,     -2],
                        [    -6,     -6],
                        [    -2,     -2],
                        [    -4,     -6],
                        [     3,      3],
                        [    -4,     -3],
                        [    -6,     -7],
                        [     4,      3],
                        [   -11,    -11],
                        [    -5,     -2],
                        [     0,      0],
                        [    -8,    -10],
                        [    -7,     -7],
                        [   -10,    -10],
                        [     0,     -1],
                        [     2,      1],
                        [    -7,     -6],
                        [     0,     -1],
                        [    -6,     -7],
                        [    -4,     -4],
                        [     3,      1],
                        [   -12,    -13],
                        [    -6,     -6],
                        [     1,      1],
                        [    -6,     -5],
                        [    -2,     -2],
                        [    -4,     -7],
                        [    -4,     -5],
                        [    -3,     -1],
                        [    -1,     -2],
                        [     1,      0],
                        [    -7,     -9],
                        [    -9,    -11],
                        [    -3,     -2],
                        [    -2,     -3],
                        [    -6,     -5],
                        [    -2,     -4],
                        [    -4,     -6],
                        [    -4,     -1],
                        [     1,      0],
                        [    -7,     -7],
                        [    -2,     -2],
                        [    -4,     -2],
                        [    -5,     -3],
                        [     1,     -1],
                        [    -6,     -5],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -7,     -6],
                        [     1,      1],
                        [    -3,     -5],
                        [    -2,     -2],
                        [     3,      1],
                        [    -7,     -7],
                        [     1,      3],
                        [    -3,     -4],
                        [    -9,     -9],
                        [    -2,     -2],
                        [    -6,     -5],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -4],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -5,     -5],
                        [    -3,     -3],
                        [    -6,     -7],
                        [    -7,     -7],
                        [    -1,     -2],
                        [    -5,     -4],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -8,     -6],
                        [     2,      2],
                        [    -2,     -3],
                        [     1,      2],
                        [     5,      5],
                        [    -5,     -7],
                        [    -1,     -2],
                        [    -7,     -7],
                        [    -2,     -2],
                        [     7,      5],
                        [    -7,     -6],
                        [    -2,     -3],
                        [    -2,     -2],
                        [    -3,     -4],
                        [    -3,     -5],
                        [    -8,     -8],
                        [     4,      3],
                        [    -3,     -1],
                        [    -8,     -7],
                        [     9,      9],
                        [     1,     -1],
                        [    -9,     -8],
                        [    -1,      0],
                        [    -2,     -3],
                        [    -6,     -7],
                        [     5,      6],
                        [    -3,     -2],
                        [   -10,    -11],
                        [    -1,      0],
                        [     1,      0],
                        [     3,      0],
                        [    -2,     -1],
                        [    -5,     -2],
                        [    -2,     -2],
                        [    -3,     -3],
                        [    -4,     -4],
                        [     2,      2],
                        [    -4,     -4],
                        [    -6,     -3],
                        [     2,      3],
                        [    -7,     -7],
                        [    -3,     -3],
                        [    -3,     -5],
                        [    -1,      0],
                        [    -2,     -1],
                        [    -7,     -6],
                        [     6,      6],
                        [     0,     -3],
                        [    -2,     -3],
                        [    -2,     -1],
                        [    -3,     -4],
                        [    -2,     -1],
                        [     1,      0],
                        [    -1,      0],
                        [    -8,     -6],
                        [    -2,     -3],
                        [    -3,     -4],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -3],
                        [    -2,     -2],
                        [    -5,     -2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -3,     -3],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -6,     -3],
                        [    -5,     -2],
                        [    -3,     -4],
                        [    -8,     -9],
                        [     3,      3],
                        [     7,      8],
                        [    -6,     -6],
                        [   -11,     -9],
                        [    -2,      0],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -5,     -2],
                        [    -1,     -1],
                        [    -2,     -4],
                        [    -6,     -5],
                        [     2,      3],
                        [    -1,     -2],
                        [    -4,     -3],
                        [     0,      0],
                        [     1,      2],
                        [    -3,      0],
                        [    -1,     -4],
                        [    -3,     -5],
                        [    -7,     -2],
                        [     5,      3],
                        [    -3,     -3],
                        [    -6,     -6],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     3,      2],
                        [     2,      1],
                        [     1,      2],
                        [    -3,     -2],
                        [    -2,     -4],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -7,     -7],
                        [    -2,     -3],
                        [     6,      6],
                        [    -1,      1],
                        [    -3,     -4],
                        [    -4,     -4],
                        [    -2,     -1],
                        [     2,      2],
                        [    -2,     -3],
                        [    -1,      2],
                        [     0,      0],
                        [    -3,     -4],
                        [    -1,      1],
                        [     1,      0],
                        [    -2,     -1],
                        [     1,     -1],
                        [    -5,     -5],
                        [    -1,     -1],
                        [     5,      6],
                        [    -4,     -2],
                        [     3,      1],
                        [     5,      6],
                        [     2,      0],
                        [    -2,     -3],
                        [    -2,      2],
                        [     0,      0],
                        [    -3,     -3],
                        [     0,     -1],
                        [     1,      2],
                        [    -2,      2],
                        [    -7,     -8],
                        [     4,      4],
                        [     2,      2],
                        [    -3,     -4],
                        [     2,      3],
                        [    -7,     -7],
                        [    -2,     -4],
                        [    -2,     -2],
                        [    -3,     -4],
                        [     6,      5],
                        [    -1,     -2],
                        [    -3,     -3],
                        [     5,      6],
                        [    -3,     -6],
                        [    -2,     -3],
                        [    -3,     -1],
                        [    -4,     -2],
                        [     2,      2],
                        [     0,     -2],
                        [    -2,     -2],
                        [     0,      2],
                        [     2,      2],
                        [     0,      0],
                        [     1,     -2],
                        [     1,     -3],
                        [     0,      2],
                        [    -4,     -7],
                        [    -2,     -2],
                        [     2,      3],
                        [     1,      0],
                        [    -4,     -3],
                        [    -5,     -7],
                        [     4,      3],
                        [     2,      4],
                        [    -2,     -3],
                        [     0,      0],
                        [     3,      5],
                        [     1,      0],
                        [     0,      0],
                        [     4,      4],
                        [     3,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,      1],
                        [    -2,     -2],
                        [     2,      4],
                        [     6,      7],
                        [    -5,     -7],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,     -1],
                        [     1,      2],
                        [     4,      5],
                        [     5,      4],
                        [    -1,     -1],
                        [     0,      2],
                        [    -2,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,      0],
                        [    -2,     -1],
                        [     0,      2],
                        [     6,      5],
                        [     2,      2],
                        [     2,      3],
                        [     4,      3],
                        [    -5,     -4],
                        [    -2,     -1],
                        [     2,      2],
                        [     4,      3],
                        [     0,     -2],
                        [    -2,     -2],
                        [     4,      7],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     3,      2],
                        [     3,      5],
                        [     3,      4],
                        [     2,      2],
                        [     2,      2],
                        [     3,      2],
                        [     5,      7],
                        [    -2,     -1],
                        [     1,     -2],
                        [     2,      4],
                        [    -3,     -2],
                        [     4,      2],
                        [     4,      3],
                        [     0,      1],
                        [    -7,     -7],
                        [    -1,      0],
                        [     7,      7],
                        [    -2,     -4],
                        [     2,      2],
                        [     3,      4],
                        [     2,      1],
                        [    -2,      0],
                        [     1,      0],
                        [     4,      4],
                        [     0,      2],
                        [    -1,      1],
                        [    -2,     -3],
                        [     1,      0],
                        [    -2,     -1],
                        [    -4,     -3],
                        [     4,      2],
                        [    -1,     -2],
                        [     3,      2],
                        [     2,      2],
                        [     0,      0],
                        [     4,      7],
                        [    -7,     -7],
                        [    -2,     -2],
                        [    10,      9],
                        [    -5,     -6],
                        [    -2,      0],
                        [     4,      2],
                        [    -4,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [    -5,     -6],
                        [    -1,     -4],
                        [     1,      2],
                        [     2,      0],
                        [     7,      3],
                        [     0,      2],
                        [    -9,    -10],
                        [     0,     -1],
                        [     0,      1],
                        [     0,     -1],
                        [     3,      4],
                        [    -3,     -3],
                        [     7,      5],
                        [     6,      6],
                        [   -10,     -8],
                        [     3,      7],
                        [     3,      2],
                        [    -5,     -7],
                        [     3,      6],
                        [    -1,     -1],
                        [     0,     -1],
                        [     7,      5],
                        [     2,      3],
                        [     0,      1],
                        [     7,      7],
                        [     4,      3],
                        [     0,      0],
                        [     3,      2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [     6,      6],
                        [     4,      6],
                        [    -4,     -5],
                        [     3,      2],
                        [     3,      3],
                        [    -4,     -4],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      1],
                        [     4,      3],
                        [    -2,     -3],
                        [    -1,      0],
                        [     7,      8],
                        [    -1,      0],
                        [     1,      0],
                        [     5,      5],
                        [    -4,     -3],
                        [     3,      2],
                        [     5,      5],
                        [    -2,     -3],
                        [     2,      2],
                        [     3,      4],
                        [     2,      2],
                        [     6,      5],
                        [    -2,     -1],
                        [     2,      1],
                        [     4,      6],
                        [    -2,      0],
                        [     2,      0],
                        [    -1,     -2],
                        [     5,      4],
                        [     9,      9],
                        [    -2,     -1],
                        [     5,      5],
                        [     2,      2],
                        [    -3,     -2],
                        [     3,      2],
                        [    -1,     -1],
                        [     2,      4],
                        [    -1,     -3],
                        [    -1,     -2],
                        [     4,      4],
                        [     0,     -2],
                        [     3,      3],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,      2],
                        [     4,      2],
                        [    -2,      0],
                        [    -4,     -3],
                        [     1,     -2],
                        [     4,      5],
                        [     0,      2],
                        [    -4,     -4],
                        [     2,      2],
                        [     1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [    -4,     -5],
                        [     3,      4],
                        [     9,     11],
                        [     0,      0],
                        [    -1,     -2],
                        [     4,      3],
                        [     1,      1],
                        [     4,      3],
                        [     7,      4],
                        [    -1,     -1],
                        [     2,      2],
                        [     4,      2],
                        [     1,      1],
                        [    -3,     -3],
                        [     2,      3],
                        [     7,      6],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      3],
                        [     3,      5],
                        [     7,      7],
                        [     2,      2],
                        [     2,      1],
                        [     1,     -1],
                        [    -1,      0],
                        [     4,      5],
                        [     3,      1],
                        [     1,      0],
                        [     3,      4],
                        [     5,      2],
                        [    -2,     -2],
                        [    -5,     -2],
                        [     8,      7],
                        [     2,      1],
                        [    -7,     -5],
                        [     8,      8],
                        [     3,      3],
                        [    -4,     -3],
                        [     4,      3],
                        [     1,      2],
                        [     2,      2],
                        [     5,      3],
                        [     1,      2],
                        [     3,      3],
                        [     2,      2],
                        [    -2,     -2],
                        [     5,      6],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -1],
                        [     9,      9],
                        [     1,     -2],
                        [     0,      3],
                        [     5,      6],
                        [    -3,     -5],
                        [     1,      2],
                        [     1,      2],
                        [     5,      5],
                        [     2,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     4,      4],
                        [     5,      2],
                        [     4,      3],
                        [     2,      1],
                        [    -5,     -5],
                        [     8,      8],
                        [     5,      4],
                        [    -2,     -2],
                        [     8,      7],
                        [     1,     -1],
                        [     3,      4],
                        [     3,      3],
                        [    -2,     -3],
                        [     3,      5],
                        [     3,      2],
                        [     1,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      1],
                        [     6,      5],
                        [     1,      0],
                        [    -3,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [     2,      3],
                        [     3,      3],
                        [     2,      2],
                        [     2,      2],
                        [    -3,     -2],
                        [     4,      2],
                        [     7,      9],
                        [    -6,     -4],
                        [     5,      4],
                        [     4,      7],
                        [    -2,     -1],
                        [     2,      1],
                        [    -1,      1],
                        [     7,      8],
                        [     5,      5],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      2],
                        [     5,      6],
                        [     3,      2],
                        [     3,      2],
                        [     2,      4],
                        [     4,      5],
                        [     2,      3],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [     6,      7],
                        [     2,      2],
                        [     2,      2],
                        [     2,      4],
                        [     1,      2],
                        [     3,      5],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [     1,      2],
                        [     7,      8],
                        [    -2,     -2],
                        [     2,      4],
                        [     4,      7],
                        [    -2,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     6,      7],
                        [     3,      4],
                        [     0,     -2],
                        [     2,      2],
                        [    -3,     -1],
                        [     2,      3],
                        [     5,      5],
                        [     0,      0],
                        [     4,      6],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      3],
                        [     1,      0],
                        [     2,      1],
                        [    -1,      0],
                        [     6,      7],
                        [     0,     -1],
                        [    -1,     -1],
                        [     7,      7],
                        [     0,      1],
                        [     2,      4],
                        [     1,     -2],
                        [     0,     -1],
                        [     1,      3],
                        [     2,      0],
                        [     1,      0],
                        [    -2,     -2],
                        [     2,      3],
                        [     4,      4],
                        [     6,      5],
                        [    -1,      0],
                        [     2,      0],
                        [     6,      5],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,      0],
                        [     6,      7],
                        [     0,      2],
                        [     4,      3],
                        [     2,      2],
                        [     1,      1],
                        [     1,     -1],
                        [    -2,     -2],
                        [    10,      8],
                        [     3,      2],
                        [    -6,     -4],
                        [     2,      2],
                        [     4,      2],
                        [    -2,     -2],
                        [     0,      2],
                        [     7,      6],
                        [     2,      0],
                        [     1,      1],
                        [     2,      1],
                        [     0,     -1],
                        [     1,     -1],
                        [     7,      7],
                        [     4,      5],
                        [     3,      2],
                        [     3,      4],
                        [    -2,     -4],
                        [     3,      2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      5],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,      2],
                        [     5,      3],
                        [    -1,      0],
                        [    -2,     -1],
                        [     2,      2],
                        [     5,      6],
                        [     4,      3],
                        [     2,      2],
                        [    -2,     -1],
                        [     1,      1],
                        [     7,      7],
                        [     0,      0],
                        [     1,      2],
                        [     5,      7],
                        [    -2,     -3],
                        [     2,      2],
                        [     2,      4],
                        [    -1,      0],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     0,     -2],
                        [     1,      1],
                        [     7,      7],
                        [     1,      1],
                        [    -2,      0],
                        [     4,      4],
                        [     1,      1],
                        [     2,      3],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     5,      5],
                        [    -2,     -2],
                        [     0,      1],
                        [     3,      3],
                        [     3,      2],
                        [     2,      1],
                        [    -2,     -2],
                        [     4,      5],
                        [     6,      4],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,      0],
                        [     8,     11],
                        [     6,      5],
                        [    -2,     -2],
                        [     2,      2],
                        [    -3,     -2],
                        [     2,      2],
                        [     7,      6],
                        [    -1,      2],
                        [     0,      1],
                        [    -1,     -2],
                        [    -1,      1],
                        [     7,      7],
                        [     6,      5],
                        [    -1,      0],
                        [    -4,     -3],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     7,      6],
                        [     1,      3],
                        [     5,      5],
                        [     2,      0],
                        [    -5,     -5],
                        [     4,      3],
                        [     0,      2],
                        [     2,      4],
                        [     4,      4],
                        [    -2,     -1],
                        [     2,      2],
                        [    -1,     -2],
                        [     0,      1],
                        [     3,      5],
                        [    -1,     -2],
                        [     2,      2],
                        [     1,      2],
                        [     1,      0],
                        [     7,      6],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -3,     -3],
                        [     4,      5],
                        [     2,      0],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     2,      4],
                        [     3,      2],
                        [     0,      0],
                        [    -3,     -5],
                        [     5,      5],
                        [     2,      3],
                        [    -4,     -3],
                        [     6,      7],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,      2],
                        [     4,      5],
                        [     7,      6],
                        [    -2,     -2],
                        [     3,      4],
                        [     3,      2],
                        [    -2,     -1],
                        [     2,      5],
                        [     3,      2],
                        [     1,      1],
                        [     2,      4],
                        [    -4,     -3],
                        [    -1,      0],
                        [     7,      7],
                        [    -2,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -3,     -2],
                        [     7,      5],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [     5,      4],
                        [    -1,      0],
                        [    -2,      0],
                        [     7,      5],
                        [     4,      3],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     4,      2],
                        [     2,      3],
                        [     3,      4],
                        [    -2,     -2],
                        [    -2,     -3],
                        [     2,     -1],
                        [    -7,     -5],
                        [     5,      5],
                        [     3,      4],
                        [    -2,     -1],
                        [     6,      4],
                        [    -2,     -2],
                        [     3,      3],
                        [     3,      2],
                        [    -2,     -2],
                        [     5,      5],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     2,      1],
                        [     0,      0],
                        [     2,      0],
                        [    -3,     -2],
                        [     0,      1],
                        [     6,      2],
                        [    -1,     -1],
                        [    -4,     -3],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [     5,      4],
                        [    -1,      0],
                        [     0,      0],
                        [    -3,     -5],
                        [    -1,      1],
                        [     2,      0],
                        [    -3,     -2],
                        [     4,      7],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     6,      4],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     0,      2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     3,      2],
                        [     4,      3],
                        [     2,      3],
                        [     1,      1],
                        [    -5,     -6],
                        [     1,      2],
                        [     2,      2],
                        [    -1,     -2],
                        [     1,      0],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     6,      4],
                        [     1,      1],
                        [    -2,     -1],
                        [     4,      3],
                        [     4,      2],
                        [     3,      2],
                        [    -3,     -2],
                        [     2,      2],
                        [     2,      1],
                        [    -3,     -2],
                        [     2,      2],
                        [     1,     -1],
                        [    -2,     -1],
                        [     1,      0],
                        [     7,      5],
                        [    -5,     -2],
                        [     0,      1],
                        [    10,      7],
                        [     0,      0],
                        [     0,      1],
                        [     2,      1],
                        [     2,      2],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      0],
                        [     5,      4],
                        [     0,      1],
                        [     1,      2],
                        [     4,      4],
                        [     0,      0],
                        [     1,      2],
                        [     0,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     7,      7],
                        [    -3,     -2],
                        [     0,      1],
                        [     2,      3],
                        [    -2,     -3],
                        [     3,      2],
                        [     2,      3],
                        [     4,      4],
                        [     1,     -2],
                        [    -7,     -5],
                        [     5,      3],
                        [     5,      2],
                        [     2,      5],
                        [     5,      5],
                        [     1,      1],
                        [    -1,      0],
                        [     0,     -1],
                        [    -2,     -1],
                        [     3,      3],
                        [     1,      1],
                        [    -5,     -4],
                        [     4,      3],
                        [    -2,     -2],
                        [    -4,     -3],
                        [     6,      6],
                        [    -2,     -2],
                        [     1,      1],
                        [     5,      5],
                        [    -4,     -3],
                        [     0,     -1],
                        [     4,      5],
                        [     2,      2],
                        [    -2,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     3,      3],
                        [     3,      4],
                        [    -2,     -1],
                        [    -2,     -3],
                        [     0,      0],
                        [     0,      2],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     4,      4],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [    -3,     -2],
                        [     4,      2],
                        [     4,      4],
                        [    -2,      0],
                        [     5,      3],
                        [     2,      2],
                        [     1,      2],
                        [     2,      2],
                        [    -3,     -3],
                        [     0,      1],
                        [     1,      1],
                        [    -4,     -5],
                        [     2,      2],
                        [     3,      3],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      0],
                        [    -5,     -7],
                        [     2,      3],
                        [    -1,      0],
                        [    -2,     -2],
                        [     4,      5],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -6,     -5],
                        [     6,      6],
                        [     2,      2],
                        [    -4,     -5],
                        [     7,      6],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [    -2,     -4],
                        [    -1,     -1],
                        [     3,      4],
                        [     0,      0],
                        [     1,     -1],
                        [    -2,     -2],
                        [    -2,      0],
                        [     1,      1],
                        [    -4,     -4],
                        [     2,      2],
                        [    -4,     -3],
                        [     1,      2],
                        [     2,      3],
                        [    -4,     -4],
                        [     7,      5],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -3],
                        [     0,     -1],
                        [     2,      3],
                        [    -2,     -2],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -4,     -2],
                        [    -4,     -5],
                        [     4,      2],
                        [    -3,     -1],
                        [    -5,     -5],
                        [     0,      0],
                        [     1,      2],
                        [     3,      4],
                        [    -2,     -2],
                        [    -3,     -4],
                        [     2,      3],
                        [     0,     -1],
                        [     0,     -2],
                        [     0,      1],
                        [     2,      1],
                        [    -4,     -4],
                        [    -3,     -2],
                        [     3,      1],
                        [     2,      1],
                        [    -2,     -2],
                        [    -3,     -3],
                        [     2,      4],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      0],
                        [    -4,     -6],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [     3,      2],
                        [    -2,      0],
                        [    -4,     -5],
                        [    -3,     -3],
                        [     0,      2],
                        [     6,      4],
                        [    -1,     -2],
                        [    -3,     -5],
                        [     2,      2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      1],
                        [    -5,     -5],
                        [     0,     -1],
                        [     0,      2],
                        [     1,      3],
                        [     2,      1],
                        [    -1,     -3],
                        [     2,      1],
                        [     0,     -2],
                        [    -4,     -2],
                        [     0,      1],
                        [     0,      0],
                        [     2,      3],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,     -2],
                        [     3,      2],
                        [     0,      2],
                        [    -3,     -3],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -4],
                        [     0,     -1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [    -1,      0],
                        [    -3,     -3],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -3,     -3],
                        [    -3,     -1],
                        [     0,     -2],
                        [    -1,     -2],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      1],
                        [     2,      2],
                        [     1,      1],
                        [    -4,     -5],
                        [    -3,     -4],
                        [     2,      2],
                        [    -1,     -1],
                        [    -4,     -4],
                        [     1,     -1],
                        [     2,      2],
                        [     2,      4],
                        [    -1,      0],
                        [    -2,     -4],
                        [     1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,      0],
                        [     2,      2],
                        [     0,     -2],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     6,      3],
                        [     0,      0],
                        [    -2,      1],
                        [     4,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -2],
                        [     2,      2],
                        [     2,      5],
                        [    -2,     -3],
                        [     2,      2],
                        [     0,      1],
                        [    -4,     -5],
                        [     0,      0],
                        [     0,      1],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      2],
                        [    -3,     -2],
                        [     1,      0],
                        [     2,      0],
                        [    -1,     -1],
                        [     4,      3],
                        [     0,     -1],
                        [     1,      0],
                        [     7,      7],
                        [    -4,     -2],
                        [    -3,     -3],
                        [     1,     -1],
                        [     1,      0],
                        [     3,      5],
                        [     0,      2],
                        [     2,      1],
                        [    -1,      1],
                        [    -2,     -3],
                        [     2,      2],
                        [     2,      2],
                        [     1,      0],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     7,      6],
                        [    -1,      0],
                        [    -7,     -6],
                        [     5,      3],
                        [     2,      2],
                        [    -2,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     2,      4],
                        [    -3,     -2],
                        [     3,      3],
                        [     7,      7],
                        [    -3,     -4],
                        [     0,      0],
                        [     3,      5],
                        [     0,      1],
                        [     2,      1],
                        [     2,      2],
                        [    -3,     -2],
                        [     4,      4],
                        [     2,      3],
                        [    -4,     -5],
                        [     4,      5],
                        [     0,      1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [     2,      2],
                        [     2,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -3,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [    -2,      2],
                        [     0,      0],
                        [    -2,     -3],
                        [     3,      3],
                        [     2,      2],
                        [    -1,     -2],
                        [     4,      3],
                        [    -2,     -1],
                        [    -4,     -2],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      2],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      3],
                        [    -4,     -3],
                        [    -1,     -2],
                        [     3,      2],
                        [     0,      1],
                        [     1,     -1],
                        [     2,      2],
                        [    -3,     -3],
                        [    -1,     -3],
                        [     3,      3],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      2],
                        [    -3,     -4],
                        [     0,     -1],
                        [     4,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      3],
                        [     0,     -1],
                        [     0,     -2],
                        [     2,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [    -3,     -3],
                        [     1,      1],
                        [     1,      0],
                        [     1,     -1],
                        [    -2,      0],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      0],
                        [    -2,     -1],
                        [    -3,     -5],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     2,      3],
                        [    -5,     -5],
                        [     1,      2],
                        [     4,      4],
                        [    -4,     -5],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      2],
                        [     0,      0],
                        [     1,      1],
                        [    -5,     -5],
                        [    -1,      2],
                        [     3,      4],
                        [    -3,     -4],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     2,      2],
                        [    -4,     -4],
                        [    -4,     -4],
                        [     5,      5],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -4,     -4],
                        [     1,      2],
                        [     2,      3],
                        [    -3,     -4],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     5,      3],
                        [    -4,     -3],
                        [    -5,     -4],
                        [     3,      2],
                        [     1,      2],
                        [    -2,     -2],
                        [     0,     -2],
                        [    -3,     -2],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     4,      5],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      3],
                        [     5,      6],
                        [    -1,     -2],
                        [     0,     -1],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -5,     -3],
                        [    -2,     -3],
                        [     4,      4],
                        [    -1,      0],
                        [    -2,     -4],
                        [     2,      3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -1],
                        [    -4,     -3],
                        [    -2,     -1],
                        [    -1,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,      1],
                        [    -3,     -3],
                        [    -4,     -4],
                        [    -2,     -4],
                        [     0,      1],
                        [    -1,      2],
                        [     0,     -2],
                        [    -2,     -4],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -2,      0],
                        [    -2,     -2],
                        [    -1,      1],
                        [    -2,     -2],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -8,     -7],
                        [    -2,     -4],
                        [     2,      1],
                        [    -3,     -2],
                        [     0,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -6,     -5],
                        [     3,      4],
                        [     2,      1],
                        [    -4,     -3],
                        [    -4,     -2],
                        [     0,      1],
                        [     2,      2],
                        [    -4,     -2],
                        [     0,      2],
                        [     0,     -3],
                        [    -1,      0],
                        [     0,      1],
                        [    -3,     -4],
                        [    -1,      2],
                        [     0,     -1],
                        [     1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,     -1],
                        [     0,     -2],
                        [     2,      3],
                        [    -1,      0],
                        [    -3,     -3],
                        [     2,      2],
                        [    -2,     -3],
                        [    -4,     -3],
                        [     2,      2],
                        [     2,      2],
                        [    -2,      1],
                        [    -1,     -2],
                        [     2,      1],
                        [    -2,     -2],
                        [    -4,     -4],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -4,     -3],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -3,     -3],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [    -1,     -2],
                        [     1,      0],
                        [    -3,     -2],
                        [    -2,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -4,     -3],
                        [    -1,     -1],
                        [    -4,     -4],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     2,      1],
                        [     1,     -1],
                        [    -4,     -4],
                        [     0,      1],
                        [    -1,      0],
                        [    -5,     -5],
                        [    -1,      1],
                        [     2,      2],
                        [    -3,     -5],
                        [     2,      2],
                        [     2,      2],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [    -4,     -4],
                        [    -6,     -6],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -4,     -3],
                        [    -4,     -2],
                        [     0,     -1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [    -3,     -4],
                        [     1,      2],
                        [     3,      4],
                        [    -7,     -7],
                        [    -2,     -3],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     0,     -2],
                        [    -7,     -7],
                        [    -2,     -2],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -3],
                        [     0,      0],
                        [     3,      3],
                        [    -2,     -2],
                        [    -4,     -2],
                        [     2,      2],
                        [    -1,     -2],
                        [    -4,     -4],
                        [     2,      2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     3,      4],
                        [    -2,     -2],
                        [     2,      1],
                        [    -5,     -3],
                        [    -2,     -2],
                        [     4,      2],
                        [    -3,     -3],
                        [    -5,     -3],
                        [     0,      1],
                        [     2,      1],
                        [     0,     -1],
                        [     3,      2],
                        [    -1,     -1],
                        [    -3,     -4],
                        [     0,     -1],
                        [     1,      1],
                        [    -2,     -1],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -3],
                        [    -3,     -4],
                        [    -1,      1],
                        [     2,      1],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -1,     -2],
                        [     1,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -3,     -3],
                        [     1,      2],
                        [    -2,     -2],
                        [    -5,     -6],
                        [     2,      4],
                        [    -1,     -1],
                        [    -2,     -4],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -2],
                        [    -3,     -3],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -3,     -2],
                        [     1,      1],
                        [    -2,     -3],
                        [     1,      2],
                        [    -2,     -2],
                        [    -5,     -7],
                        [     0,      2],
                        [     2,      2],
                        [    -4,     -3],
                        [    -4,     -5],
                        [     2,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -3,     -2],
                        [    -4,     -3],
                        [    -2,     -2],
                        [    -2,     -3],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -3,     -4],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -4,     -3],
                        [     2,      2],
                        [     1,      0],
                        [    -5,     -5],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      2],
                        [     0,     -2],
                        [    -4,     -3],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,     -2],
                        [    -3,     -4],
                        [     1,     -1],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [    -2,      0],
                        [    -4,     -4],
                        [     3,      3],
                        [     0,      1],
                        [    -4,     -5],
                        [     0,      1],
                        [     0,      0],
                        [    -3,     -4],
                        [     1,      0],
                        [     5,      6],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -2,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -1],
                        [    -2,     -3],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      2],
                        [    -3,     -2],
                        [     1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -3,     -3],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     1,     -1],
                        [    -2,     -3],
                        [    -5,     -2],
                        [     1,      2],
                        [     1,     -1],
                        [    -4,     -3],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -3,     -3],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -2,     -3],
                        [    -1,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      1],
                        [     5,      4],
                        [    -4,     -5],
                        [    -2,     -2],
                        [     2,      3],
                        [     1,     -1],
                        [     0,     -1],
                        [     1,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      2],
                        [     0,      1],
                        [    -4,     -3],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,     -2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      0],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      2],
                        [    -4,     -3],
                        [    -2,     -3],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,      0],
                        [    -2,     -1],
                        [     0,     -2],
                        [     0,      1],
                        [    -2,     -2],
                        [    -3,     -4],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,     -1],
                        [    -3,     -2],
                        [     0,      0],
                        [     0,      0],
                        [    -7,     -6],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [    -3,     -2],
                        [     0,      0],
                        [    -1,      0],
                        [    -3,     -3],
                        [     2,      3],
                        [    -2,     -1],
                        [    -2,     -3],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,      0],
                        [     0,     -2],
                        [    -5,     -5],
                        [     0,      2],
                        [     2,      2],
                        [    -3,     -5],
                        [     0,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     4,      3],
                        [    -2,     -2],
                        [    -3,     -3],
                        [     2,      4],
                        [     0,     -2],
                        [    -5,     -6],
                        [     0,      2],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [    -1,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -4,     -4],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      3],
                        [     2,      0],
                        [    -1,     -1],
                        [     4,      4],
                        [    -2,     -2],
                        [    -6,     -5],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      3],
                        [    -6,     -5],
                        [    -3,     -4],
                        [     3,      3],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     2,      3],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [    -2,     -3],
                        [    -3,     -3],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -3],
                        [    -2,     -2],
                        [     3,      3],
                        [    -1,      0],
                        [    -3,     -2],
                        [     0,     -1],
                        [    -4,     -4],
                        [     0,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      2],
                        [    -2,     -2],
                        [    -2,     -4],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [    -2,      0],
                        [    -1,      0],
                        [    -2,     -1],
                        [     2,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      1],
                        [    -3,     -2],
                        [    -1,     -2],
                        [     2,      2],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      0],
                        [    -5,     -5],
                        [     0,      1],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -3,     -2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [    -5,     -4],
                        [     1,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      2],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     4,      4],
                        [    -3,     -3],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,     -2],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -3,     -3],
                        [    -1,      0],
                        [     2,      1],
                        [    -1,     -2],
                        [     2,      2],
                        [     2,      3],
                        [    -3,     -3],
                        [    -2,     -2],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     3,      2],
                        [     2,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     3,      4],
                        [     2,      2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     2,      1],
                        [    -3,     -2],
                        [     1,      2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     2,      0],
                        [    -5,     -3],
                        [     2,      2],
                        [     5,      4],
                        [    -2,     -2],
                        [     2,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     1,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     2,      3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [     4,      3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      0],
                        [     2,      2],
                        [     3,      2],
                        [     0,     -1],
                        [     2,      2],
                        [     0,     -2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -2],
                        [     4,      4],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     3,      2],
                        [     0,      1],
                        [    -2,     -1],
                        [     3,      1],
                        [     2,      2],
                        [     3,      3],
                        [     2,      2],
                        [    -3,     -2],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      2],
                        [     2,      1],
                        [     2,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      1],
                        [     0,     -1],
                        [    -1,      0],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,     -1],
                        [     3,      3],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     3,      4],
                        [    -3,     -3],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      0],
                        [     2,      2],
                        [     2,      1],
                        [    -1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      0],
                        [     1,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [     4,      3],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [     0,     -1],
                        [     5,      5],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     3,      4],
                        [    -2,     -2],
                        [     0,      0],
                        [     4,      5],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [    -1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     3,      2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      3],
                        [     2,      2],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      2],
                        [    -1,      0],
                        [     1,      0],
                        [     0,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [     3,      3],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     2,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     4,      4],
                        [    -1,      1],
                        [     2,      0],
                        [     2,      2],
                        [    -1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,     -2],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -4],
                        [    -1,     -1],
                        [     1,      2],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     3,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -1],
                        [     2,      1],
                        [     0,     -1],
                        [    -5,     -4],
                        [     2,      2],
                        [     3,      3],
                        [    -2,     -2],
                        [     2,      1],
                        [     0,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      2],
                        [     2,      2],
                        [     3,      2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     2,      2],
                        [     2,      1],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      2],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -3],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     0,      2],
                        [     4,      3],
                        [    -2,     -2],
                        [    -3,     -2],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -3,     -2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [     3,      2],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [    -1,     -3],
                        [     4,      4],
                        [     2,      2],
                        [    -2,     -3],
                        [     2,      3],
                        [     1,      0],
                        [    -1,      0],
                        [     2,      3],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -4],
                        [     1,      2],
                        [     0,      2],
                        [     1,     -1],
                        [     1,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     4,      5],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      3],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [     2,      2],
                        [     1,      1],
                        [    -3,     -3],
                        [     2,      2],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [     0,      0],
                        [     2,      2],
                        [     0,      1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,      0],
                        [    -2,     -1],
                        [     3,      3],
                        [     2,      1],
                        [     0,      0],
                        [     4,      3],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [     1,      0],
                        [     3,      3],
                        [     2,      3],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     3,      2],
                        [    -3,     -3],
                        [    -2,     -1],
                        [     4,      4],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [     0,      2],
                        [     0,      1],
                        [    -1,     -1],
                        [     3,      2],
                        [     2,      3],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,      2],
                        [     1,      0],
                        [     0,      1],
                        [     1,      2],
                        [     2,      0],
                        [    -2,     -1],
                        [     1,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     4,      4],
                        [    -2,     -2],
                        [    -3,     -2],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      2],
                        [     0,      1],
                        [     1,      1],
                        [     2,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      2],
                        [     2,      2],
                        [     2,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     3,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [     2,      3],
                        [    -2,     -2],
                        [     2,      2],
                        [     3,      3],
                        [    -4,     -3],
                        [     2,      2],
                        [     4,      3],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     0,      1],
                        [     1,      1],
                        [     1,     -1],
                        [     3,      4],
                        [     4,      3],
                        [    -3,     -3],
                        [     2,      2],
                        [     1,      2],
                        [    -1,      0],
                        [     3,      2],
                        [     0,      2],
                        [     2,      2],
                        [     1,      0],
                        [     2,      2],
                        [     0,      1],
                        [     1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     3,      3],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      2],
                        [     2,      3],
                        [     2,      2],
                        [     0,      0],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      1],
                        [     1,      2],
                        [     1,      0],
                        [     1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     2,      1],
                        [     2,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -2,      0],
                        [     1,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     3,      3],
                        [     3,      4],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     2,      0],
                        [     2,      2],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      2],
                        [     0,      1],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [    -4,     -4],
                        [     1,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [    -2,     -1],
                        [     2,      1],
                        [     0,      1],
                        [     2,      2],
                        [     2,      0],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [     3,      3],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     3,      2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     1,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,      1],
                        [     1,      2],
                        [     0,     -1],
                        [    -2,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -3,     -3],
                        [     3,      4],
                        [     2,      2],
                        [    -2,     -3],
                        [    -2,     -1],
                        [     0,     -1],
                        [     0,      1],
                        [     1,      2],
                        [     2,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     3,      3],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     2,      2],
                        [     3,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [     2,      0],
                        [     2,      0],
                        [    -2,     -1],
                        [    -1,      0],
                        [     2,      1],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     3,      3],
                        [     0,     -1],
                        [    -3,     -4],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      3],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      1],
                        [     1,      2],
                        [     1,      0],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     1,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [    -1,      0],
                        [     2,      1],
                        [     2,      3],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      0],
                        [     2,      2],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      2],
                        [     2,      3],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      1],
                        [     3,      3],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -3,     -2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [     2,      1],
                        [     2,      2],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -1,      0],
                        [     2,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -3],
                        [     2,      2],
                        [    -1,      1],
                        [    -2,     -1],
                        [     1,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [    -1,      0],
                        [    -3,     -2],
                        [     0,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      2],
                        [    -1,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     3,      4],
                        [     2,      1],
                        [     2,      1],
                        [     1,      2],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      0],
                        [     0,     -1],
                        [     2,      3],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      1],
                        [    -2,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     2,      3],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -3],
                        [     1,      1],
                        [     2,      2],
                        [     1,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -3,     -2],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     5,      6],
                        [     1,      1],
                        [    -2,     -4],
                        [     2,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [     0,     -1],
                        [    -3,     -3],
                        [    -3,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [     2,      2],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -2,      0],
                        [     2,      2],
                        [     1,      2],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     3,      3],
                        [     0,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,      0],
                        [     4,      4],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     0,      1],
                        [    -1,     -2],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [    -2,      0],
                        [     2,      2],
                        [     1,      2],
                        [    -1,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [    -1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -2],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [     0,      0],
                        [     2,     -1],
                        [     0,      0],
                        [    -3,     -3],
                        [     1,      0],
                        [     2,      2],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     4,      3],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      0],
                        [    -2,     -3],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      0],
                        [     1,      0],
                        [     2,      2],
                        [     2,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -2],
                        [     2,      2],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     2,      1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     2,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [    -3,     -3],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -4,     -3],
                        [     0,      0],
                        [     2,      2],
                        [    -3,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      2],
                        [    -2,     -3],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     1,      0],
                        [     2,      1],
                        [    -2,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      2],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     3,      3],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      3],
                        [     0,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     1,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      2],
                        [    -3,     -2],
                        [     0,      0],
                        [     4,      3],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     0,      0],
                        [     3,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     3,      3],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -3,     -3],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -3,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      1],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      0],
                        [    -1,      0],
                        [    -2,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      2],
                        [    -1,     -2],
                        [     2,      1],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -3],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -3],
                        [     0,      0],
                        [     1,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      0],
                        [     1,      0],
                        [    -1,      0],
                        [     1,      0],
                        [    -3,     -2],
                        [    -1,      0],
                        [     1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,      0],
                        [     2,      3],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -1,      0],
                        [     1,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [    -3,     -3],
                        [    -2,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -2,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [     2,      0],
                        [     1,      1],
                        [    -2,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      2],
                        [    -1,      0],
                        [     1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [    -1,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      2],
                        [     0,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      1],
                        [    -2,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [    -2,     -1],
                        [     2,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     3,      3],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     2,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     2,      2],
                        [     0,     -1],
                        [    -1,     -2],
                        [     2,      2],
                        [     0,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -2,     -1],
                        [    -2,     -3],
                        [     2,      2],
                        [     0,      0],
                        [    -1,      1],
                        [     1,      2],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      2],
                        [     1,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     3,      2],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     0,     -1],
                        [     1,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,     -1],
                        [     1,      2],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,     -2],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,      1],
                        [    -1,     -2],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      2],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     1,      2],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     2,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      2],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      1],
                        [    -1,      0],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     2,      2],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [     2,      2],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [     2,      2],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -2,     -2],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      2],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     1,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     1,      0],
                        [     0,      0],
                        [     1,      2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      2],
                        [    -2,     -2],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     2,      2],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -2],
                        [     2,      2],
                        [     2,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      2],
                        [    -1,     -2],
                        [     1,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     2,      2],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     2,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      2],
                        [    -2,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -2,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [     1,      2],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      2],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      2],
                        [     0,      1],
                        [     1,      1],
                        [     1,      0],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     2,      1],
                        [     2,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     2,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     0,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      2],
                        [    -2,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -2],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [    -2,     -1],
                        [     1,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      1],
                        [     1,      2],
                        [     0,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     2,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [     1,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     2,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      2],
                        [     0,      0],
                        [     1,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      1],
                        [     2,      2],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      1],
                        [    -1,     -2],
                        [     0,     -1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      2],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [    -2,     -1],
                        [    -1,      0],
                        [     2,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [     1,      2],
                        [    -1,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -1],
                        [     0,      1],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -2],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -2,     -2],
                        [    -1,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     2,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -2,     -1],
                        [    -1,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -2,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     2,      2],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -2],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -2],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      1],
                        [     0,      1],
                        [     1,      2],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      2],
                        [     0,      1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -2,     -2],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [    -1,      0],
                        [     1,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      2],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,      0],
                        [     1,      2],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     2,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     2,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      2],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      2],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     2,      2],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -2,     -2],
                        [     1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     1,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     2,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     2,      1],
                        [     0,     -1],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [    -2,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     2,      2],
                        [     1,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     2,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     2,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -2,     -2],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     0,      1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      1],
                        [     1,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     1,      1],
                        [     1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     1,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      1],
                        [    -1,     -1],
                        [     1,      1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     5,      6],
                        [    11,     11],
                        [    18,     18],
                        [    28,     27],
                        [    34,     34],
                        [    42,     42],
                        [    51,     51],
                        [    59,     59],
                        [    66,     66],
                        [    73,     73],
                        [    79,     79],
                        [    83,     83],
                        [     7,      7],
                        [    12,     12],
                        [    16,     16],
                        [    21,     21],
                        [    26,     26],
                        [    30,     30],
                        [    33,     33],
                        [    38,     38],
                        [    41,     41],
                        [    45,     45],
                        [    50,     50],
                        [    53,     52],
                        [    56,     56],
                        [    60,     60],
                        [    63,     63],
                        [    68,     68],
                        [   -15,    -15],
                        [    -4,     -4],
                        [     7,      7],
                        [    19,     19],
                        [    31,     30],
                        [    44,     43],
                        [    57,     57],
                        [    71,     71],
                        [    85,     85],
                        [    99,     99],
                        [   115,    115],
                        [   131,    131],
                        [   145,    145],
                        [   162,    162],
                        [   177,    177],
                        [   194,    194],
                        [   179,    178],
                        [   194,    193],
                        [   210,    210],
                        [   226,    226],
                        [   241,    241],
                        [   255,    255],
                        [   270,    270],
                        [   283,    283],
                        [   294,    294],
                        [   306,    306],
                        [   318,    318],
                        [   327,    326],
                        [   335,    335],
                        [   343,    343],
                        [   349,    349],
                        [   353,    353],
                        [   358,    358],
                        [   361,    361],
                        [   362,    363],
                        [   363,    363],
                        [   362,    362],
                        [   360,    360],
                        [   358,    358],
                        [   354,    354],
                        [   349,    349],
                        [   344,    343],
                        [   337,    336],
                        [   328,    328],
                        [   319,    319],
                        [   310,    310],
                        [   301,    300],
                        [   289,    288],
                        [   276,    275],
                        [   262,    262],
                        [   249,    249],
                        [   234,    234],
                        [   217,    217],
                        [   200,    201],
                        [   182,    181],
                        [   161,    161],
                        [   141,    141],
                        [   119,    119],
                        [    93,     93],
                        [    68,     68],
                        [    39,     40],
                        [     9,      9],
                        [   -23,    -23],
                        [   -59,    -59],
                        [   -96,    -96],
                        [  -136,   -136],
                        [  -179,   -179],
                        [  -224,   -225],
                        [  -273,   -273],
                        [  -324,   -324],
                        [  -381,   -381],
                        [  -437,   -437],
                        [  -476,   -476],
                        [  -487,   -487],
                        [  -466,   -467],
                        [  -414,   -414],
                        [  -321,   -321],
                        [  -188,   -188],
                        [   -40,    -40],
                        [   102,    102],
                        [   234,    234],
                        [   354,    354],
                        [   462,    461],
                        [   551,    551],
                        [   624,    624],
                        [   679,    680],
                        [   717,    717],
                        [   735,    735],
                        [   733,    733],
                        [   713,    713],
                        [   674,    674],
                        [   618,    618],
                        [   546,    546],
                        [   460,    460],
                        [   360,    360],
                        [   249,    249],
                        [   126,    125],
                        [    -6,     -6],
                        [  -143,   -144],
                        [  -287,   -287],
                        [  -434,   -434],
                        [  -583,   -583],
                        [  -732,   -732],
                        [  -882,   -882],
                        [ -1029,  -1029],
                        [ -1172,  -1172],
                        [ -1311,  -1311],
                        [ -1443,  -1444],
                        [ -1570,  -1570],
                        [ -1689,  -1689],
                        [ -1801,  -1801],
                        [ -1903,  -1903],
                        [ -1997,  -1997],
                        [ -2082,  -2082],
                        [ -2156,  -2156],
                        [ -2222,  -2222],
                        [ -2277,  -2277],
                        [ -2321,  -2321],
                        [ -2358,  -2358],
                        [ -2387,  -2387],
                        [ -2405,  -2405],
                        [ -2415,  -2416],
                        [ -2417,  -2417],
                        [ -2412,  -2412],
                        [ -2400,  -2400],
                        [ -2382,  -2382],
                        [ -2359,  -2358],
                        [ -2329,  -2329],
                        [ -2297,  -2297],
                        [ -2260,  -2261],
                        [ -2221,  -2221],
                        [ -2181,  -2181],
                        [ -2139,  -2139],
                        [ -2095,  -2095],
                        [ -2050,  -2051],
                        [ -2008,  -2009],
                        [ -1965,  -1966],
                        [ -1925,  -1926],
                        [ -1887,  -1887],
                        [ -1851,  -1850],
                        [ -1819,  -1819],
                        [ -1790,  -1790],
                        [ -1763,  -1763],
                        [ -1742,  -1742],
                        [ -1724,  -1724],
                        [ -1710,  -1710],
                        [ -1701,  -1701],
                        [ -1695,  -1696],
                        [ -1695,  -1694],
                        [ -1697,  -1697],
                        [ -1703,  -1703],
                        [ -1713,  -1713],
                        [ -1725,  -1725],
                        [ -1741,  -1741],
                        [ -1759,  -1759],
                        [ -1779,  -1779],
                        [ -1801,  -1801],
                        [ -1823,  -1823],
                        [ -1846,  -1846],
                        [ -1868,  -1868],
                        [ -1891,  -1891],
                        [ -1912,  -1911],
                        [ -1931,  -1931],
                        [ -1948,  -1948],
                        [ -1960,  -1960],
                        [ -1970,  -1970],
                        [ -1975,  -1975],
                        [ -1976,  -1976],
                        [ -1972,  -1972],
                        [ -1961,  -1961],
                        [ -1944,  -1944],
                        [ -1922,  -1922],
                        [ -1892,  -1892],
                        [ -1855,  -1855],
                        [ -1811,  -1811],
                        [ -1759,  -1758],
                        [ -1698,  -1698],
                        [ -1631,  -1630],
                        [ -1554,  -1554],
                        [ -1471,  -1471],
                        [ -1380,  -1380],
                        [ -1281,  -1281],
                        [ -1175,  -1175],
                        [ -1062,  -1063],
                        [  -942,   -942],
                        [  -816,   -816],
                        [  -684,   -684],
                        [  -548,   -548],
                        [  -405,   -405],
                        [  -260,   -260],
                        [  -113,   -112],
                        [    39,     39],
                        [   192,    192],
                        [   346,    346],
                        [   492,    493],
                        [   594,    594],
                        [   629,    629],
                        [   591,    591],
                        [   477,    477],
                        [   276,    276],
                        [    -3,     -2],
                        [  -309,   -308],
                        [  -604,   -603],
                        [  -882,   -882],
                        [ -1143,  -1142],
                        [ -1383,  -1384],
                        [ -1601,  -1601],
                        [ -1793,  -1793],
                        [ -1958,  -1958],
                        [ -2098,  -2098],
                        [ -2209,  -2209],
                        [ -2295,  -2295],
                        [ -2354,  -2354],
                        [ -2388,  -2388],
                        [ -2399,  -2399],
                        [ -2386,  -2386],
                        [ -2353,  -2353],
                        [ -2299,  -2299],
                        [ -2230,  -2230],
                        [ -2144,  -2144],
                        [ -2042,  -2042],
                        [ -1928,  -1928],
                        [ -1805,  -1805],
                        [ -1669,  -1670],
                        [ -1527,  -1527],
                        [ -1377,  -1376],
                        [ -1222,  -1221],
                        [ -1061,  -1060],
                        [  -896,   -896],
                        [  -729,   -729],
                        [  -557,   -558],
                        [  -387,   -387],
                        [  -215,   -215],
                        [   -42,    -41],
                        [   132,    132],
                        [   305,    305],
                        [   476,    476],
                        [   649,    648],
                        [   819,    819],
                        [   987,    987],
                        [  1153,   1154],
                        [  1319,   1319],
                        [  1481,   1482],
                        [  1640,   1640],
                        [  1797,   1798],
                        [  1951,   1951],
                        [  2101,   2101],
                        [  2248,   2248],
                        [  2390,   2390],
                        [  2528,   2529],
                        [  2661,   2661],
                        [  2789,   2789],
                        [  2913,   2913],
                        [  3031,   3031],
                        [  3142,   3142],
                        [  3248,   3248],
                        [  3347,   3347],
                        [  3439,   3439],
                        [  3526,   3526],
                        [  3606,   3606],
                        [  3679,   3679],
                        [  3745,   3745],
                        [  3804,   3804],
                        [  3856,   3857],
                        [  3902,   3902],
                        [  3942,   3942],
                        [  3976,   3976],
                        [  4003,   4003],
                        [  4024,   4024],
                        [  4041,   4041],
                        [  4051,   4052],
                        [  4058,   4058],
                        [  4060,   4060],
                        [  4058,   4058],
                        [  4053,   4053],
                        [  4045,   4045],
                        [  4033,   4033],
                        [  4020,   4020],
                        [  4005,   4006],
                        [  3989,   3989],
                        [  3973,   3973],
                        [  3955,   3955],
                        [  3937,   3937],
                        [  3921,   3921],
                        [  3903,   3903],
                        [  3886,   3886],
                        [  3871,   3872],
                        [  3855,   3855],
                        [  3840,   3840],
                        [  3826,   3826],
                        [  3812,   3812],
                        [  3798,   3798],
                        [  3784,   3784],
                        [  3770,   3770],
                        [  3755,   3755],
                        [  3738,   3737],
                        [  3718,   3718],
                        [  3696,   3696],
                        [  3669,   3669],
                        [  3640,   3640],
                        [  3606,   3606],
                        [  3565,   3565],
                        [  3519,   3518],
                        [  3465,   3464],
                        [  3402,   3402],
                        [  3331,   3331],
                        [  3251,   3251],
                        [  3161,   3161],
                        [  3062,   3062],
                        [  2949,   2949],
                        [  2826,   2826],
                        [  2693,   2692],
                        [  2546,   2546],
                        [  2386,   2386],
                        [  2217,   2217],
                        [  2036,   2037],
                        [  1840,   1840],
                        [  1649,   1649],
                        [  1513,   1514],
                        [  1458,   1458],
                        [  1485,   1485],
                        [  1605,   1606],
                        [  1833,   1833],
                        [  2152,   2152],
                        [  2492,   2492],
                        [  2805,   2805],
                        [  3086,   3086],
                        [  3335,   3335],
                        [  3543,   3544],
                        [  3712,   3712],
                        [  3839,   3839],
                        [  3922,   3921],
                        [  3964,   3964],
                        [  3963,   3963],
                        [  3921,   3921],
                        [  3842,   3842],
                        [  3727,   3727],
                        [  3580,   3580],
                        [  3404,   3404],
                        [  3202,   3202],
                        [  2978,   2978],
                        [  2737,   2737],
                        [  2481,   2481],
                        [  2215,   2215],
                        [  1944,   1943],
                        [  1667,   1667],
                        [  1391,   1391],
                        [  1119,   1119],
                        [   853,    853],
                        [   596,    596],
                        [   349,    349],
                        [   115,    115],
                        [  -104,   -104],
                        [  -308,   -308],
                        [  -494,   -494],
                        [  -662,   -662],
                        [  -813,   -812],
                        [  -944,   -944],
                        [ -1058,  -1058],
                        [ -1152,  -1152],
                        [ -1229,  -1229],
                        [ -1289,  -1289],
                        [ -1330,  -1331],
                        [ -1359,  -1359],
                        [ -1371,  -1371],
                        [ -1370,  -1370],
                        [ -1357,  -1357],
                        [ -1332,  -1333],
                        [ -1298,  -1298],
                        [ -1255,  -1256],
                        [ -1207,  -1207],
                        [ -1153,  -1154],
                        [ -1094,  -1094],
                        [ -1034,  -1034],
                        [  -971,   -971],
                        [  -908,   -908],
                        [  -847,   -847],
                        [  -787,   -787],
                        [  -729,   -730],
                        [  -677,   -677],
                        [  -628,   -628],
                        [  -583,   -583],
                        [  -547,   -547],
                        [  -515,   -515],
                        [  -488,   -488],
                        [  -470,   -470],
                        [  -458,   -458],
                        [  -453,   -452],
                        [  -453,   -453],
                        [  -459,   -459],
                        [  -472,   -472],
                        [  -489,   -490],
                        [  -511,   -511],
                        [  -538,   -538],
                        [  -566,   -566],
                        [  -599,   -599],
                        [  -634,   -634],
                        [  -667,   -667],
                        [  -701,   -701],
                        [  -735,   -735],
                        [  -766,   -767],
                        [  -795,   -795],
                        [  -819,   -819],
                        [  -839,   -839],
                        [  -854,   -854],
                        [  -861,   -861],
                        [  -861,   -862],
                        [  -854,   -854],
                        [  -838,   -838],
                        [  -811,   -812],
                        [  -776,   -776],
                        [  -730,   -730],
                        [  -673,   -674],
                        [  -605,   -605],
                        [  -527,   -527],
                        [  -436,   -436],
                        [  -334,   -334],
                        [  -220,   -220],
                        [   -94,    -94],
                        [    41,     41],
                        [   187,    188],
                        [   345,    345],
                        [   512,    511],
                        [   688,    687],
                        [   873,    873],
                        [  1065,   1064],
                        [  1264,   1264],
                        [  1471,   1471],
                        [  1683,   1683],
                        [  1898,   1898],
                        [  2117,   2117],
                        [  2338,   2337],
                        [  2560,   2561],
                        [  2783,   2783],
                        [  3003,   3002],
                        [  3222,   3222],
                        [  3438,   3438],
                        [  3646,   3646],
                        [  3847,   3847],
                        [  4047,   4047],
                        [  4214,   4214],
                        [  4293,   4293],
                        [  4261,   4260],
                        [  4111,   4111],
                        [  3835,   3835],
                        [  3413,   3413],
                        [  2862,   2862],
                        [  2263,   2263],
                        [  1675,   1675],
                        [  1101,   1101],
                        [   546,    545],
                        [    18,     18],
                        [  -477,   -477],
                        [  -931,   -931],
                        [ -1345,  -1345],
                        [ -1713,  -1714],
                        [ -2034,  -2035],
                        [ -2308,  -2308],
                        [ -2529,  -2529],
                        [ -2703,  -2702],
                        [ -2829,  -2829],
                        [ -2907,  -2907],
                        [ -2940,  -2940],
                        [ -2930,  -2930],
                        [ -2877,  -2877],
                        [ -2786,  -2786],
                        [ -2660,  -2659],
                        [ -2499,  -2499],
                        [ -2308,  -2309],
                        [ -2091,  -2091],
                        [ -1848,  -1848],
                        [ -1584,  -1584],
                        [ -1301,  -1301],
                        [ -1001,  -1001],
                        [  -687,   -687],
                        [  -363,   -363],
                        [   -28,    -28],
                        [   313,    313],
                        [   658,    657],
                        [  1005,   1005],
                        [  1353,   1354],
                        [  1701,   1701],
                        [  2045,   2045],
                        [  2386,   2386],
                        [  2720,   2719],
                        [  3047,   3047],
                        [  3365,   3365],
                        [  3676,   3676],
                        [  3976,   3975],
                        [  4262,   4262],
                        [  4537,   4538],
                        [  4800,   4800],
                        [  5048,   5048],
                        [  5282,   5282],
                        [  5501,   5502],
                        [  5707,   5707],
                        [  5896,   5896],
                        [  6069,   6069],
                        [  6227,   6227],
                        [  6369,   6369],
                        [  6496,   6496],
                        [  6607,   6607],
                        [  6703,   6703],
                        [  6784,   6784],
                        [  6852,   6852],
                        [  6905,   6905],
                        [  6945,   6945],
                        [  6973,   6973],
                        [  6988,   6988],
                        [  6993,   6993],
                        [  6986,   6987],
                        [  6970,   6970],
                        [  6945,   6946],
                        [  6913,   6914],
                        [  6874,   6874],
                        [  6830,   6830],
                        [  6781,   6780],
                        [  6727,   6727],
                        [  6671,   6671],
                        [  6611,   6611],
                        [  6550,   6551],
                        [  6490,   6490],
                        [  6428,   6428],
                        [  6366,   6366],
                        [  6305,   6305],
                        [  6245,   6245],
                        [  6186,   6186],
                        [  6129,   6129],
                        [  6072,   6072],
                        [  6017,   6017],
                        [  5962,   5963],
                        [  5909,   5909],
                        [  5857,   5857],
                        [  5804,   5804],
                        [  5749,   5749],
                        [  5695,   5695],
                        [  5637,   5637],
                        [  5577,   5577],
                        [  5512,   5512],
                        [  5439,   5439],
                        [  5362,   5362],
                        [  5278,   5277],
                        [  5184,   5185],
                        [  5083,   5083],
                        [  4971,   4971],
                        [  4849,   4849],
                        [  4716,   4716],
                        [  4568,   4568],
                        [  4414,   4414],
                        [  4249,   4249],
                        [  4069,   4069],
                        [  3873,   3874],
                        [  3659,   3659],
                        [  3424,   3424],
                        [  3174,   3174],
                        [  2910,   2910],
                        [  2632,   2632],
                        [  2339,   2340],
                        [  2034,   2034],
                        [  1716,   1716],
                        [  1391,   1391],
                        [  1055,   1055],
                        [   708,    709],
                        [   386,    386],
                        [   145,    145],
                        [     4,      4],
                        [   -37,    -37],
                        [    36,     37],
                        [   248,    248],
                        [   586,    586],
                        [   973,    973],
                        [  1351,   1352],
                        [  1723,   1723],
                        [  2082,   2082],
                        [  2419,   2419],
                        [  2727,   2727],
                        [  3003,   3003],
                        [  3245,   3245],
                        [  3449,   3450],
                        [  3613,   3613],
                        [  3738,   3738],
                        [  3826,   3826],
                        [  3876,   3876],
                        [  3886,   3886],
                        [  3860,   3860],
                        [  3801,   3801],
                        [  3714,   3714],
                        [  3599,   3599],
                        [  3461,   3461],
                        [  3306,   3306],
                        [  3135,   3135],
                        [  2951,   2951],
                        [  2758,   2758],
                        [  2561,   2561],
                        [  2360,   2360],
                        [  2160,   2160],
                        [  1961,   1961],
                        [  1767,   1767],
                        [  1580,   1580],
                        [  1401,   1401],
                        [  1230,   1230],
                        [  1069,   1069],
                        [   920,    920],
                        [   781,    781],
                        [   652,    652],
                        [   535,    535],
                        [   429,    430],
                        [   335,    335],
                        [   248,    247],
                        [   171,    170],
                        [   101,    101],
                        [    38,     39],
                        [   -17,    -17],
                        [   -70,    -70],
                        [  -115,   -116],
                        [  -160,   -160],
                        [  -203,   -204],
                        [  -245,   -245],
                        [  -286,   -286],
                        [  -329,   -329],
                        [  -373,   -372],
                        [  -417,   -417],
                        [  -465,   -465],
                        [  -514,   -514],
                        [  -568,   -568],
                        [  -624,   -624],
                        [  -683,   -683],
                        [  -745,   -744],
                        [  -808,   -808],
                        [  -874,   -874],
                        [  -943,   -943],
                        [ -1011,  -1011],
                        [ -1080,  -1080],
                        [ -1147,  -1147],
                        [ -1211,  -1211],
                        [ -1276,  -1276],
                        [ -1337,  -1337],
                        [ -1398,  -1398],
                        [ -1463,  -1463],
                        [ -1533,  -1533],
                        [ -1611,  -1611],
                        [ -1694,  -1694],
                        [ -1783,  -1783],
                        [ -1878,  -1878],
                        [ -1962,  -1962],
                        [ -2039,  -2038],
                        [ -2097,  -2097],
                        [ -2137,  -2137],
                        [ -2159,  -2159],
                        [ -2161,  -2161],
                        [ -2142,  -2142],
                        [ -2101,  -2101],
                        [ -2039,  -2039],
                        [ -1957,  -1956],
                        [ -1851,  -1852],
                        [ -1726,  -1726],
                        [ -1581,  -1581],
                        [ -1418,  -1418],
                        [ -1237,  -1237],
                        [ -1038,  -1038],
                        [  -826,   -826],
                        [  -599,   -599],
                        [  -360,   -360],
                        [  -111,   -111],
                        [   147,    147],
                        [   411,    411],
                        [   680,    680],
                        [   954,    954],
                        [  1228,   1228],
                        [  1500,   1501],
                        [  1773,   1773],
                        [  2042,   2042],
                        [  2303,   2303],
                        [  2559,   2559],
                        [  2806,   2806],
                        [  3042,   3042],
                        [  3266,   3266],
                        [  3478,   3478],
                        [  3675,   3675],
                        [  3855,   3855],
                        [  4019,   4019],
                        [  4167,   4167],
                        [  4294,   4294],
                        [  4400,   4400],
                        [  4486,   4486],
                        [  4554,   4554],
                        [  4570,   4570],
                        [  4490,   4490],
                        [  4310,   4310],
                        [  4026,   4026],
                        [  3621,   3621],
                        [  3065,   3065],
                        [  2366,   2366],
                        [  1599,   1600],
                        [   820,    820],
                        [    28,     28],
                        [  -766,   -765],
                        [ -1547,  -1547],
                        [ -2304,  -2304],
                        [ -3029,  -3029],
                        [ -3715,  -3715],
                        [ -4351,  -4351],
                        [ -4935,  -4935],
                        [ -5460,  -5460],
                        [ -5921,  -5921],
                        [ -6319,  -6319],
                        [ -6650,  -6650],
                        [ -6911,  -6911],
                        [ -7107,  -7107],
                        [ -7236,  -7236],
                        [ -7300,  -7300],
                        [ -7302,  -7302],
                        [ -7244,  -7244],
                        [ -7131,  -7131],
                        [ -6964,  -6964],
                        [ -6748,  -6748],
                        [ -6489,  -6489],
                        [ -6190,  -6190],
                        [ -5854,  -5854],
                        [ -5488,  -5488],
                        [ -5096,  -5096],
                        [ -4682,  -4682],
                        [ -4250,  -4250],
                        [ -3805,  -3805],
                        [ -3352,  -3352],
                        [ -2893,  -2893],
                        [ -2433,  -2433],
                        [ -1975,  -1975],
                        [ -1523,  -1523],
                        [ -1081,  -1081],
                        [  -650,   -650],
                        [  -233,   -233],
                        [   165,    165],
                        [   547,    546],
                        [   906,    905],
                        [  1242,   1243],
                        [  1557,   1557],
                        [  1844,   1844],
                        [  2108,   2108],
                        [  2345,   2345],
                        [  2555,   2555],
                        [  2739,   2739],
                        [  2897,   2897],
                        [  3027,   3028],
                        [  3133,   3133],
                        [  3214,   3214],
                        [  3272,   3272],
                        [  3307,   3306],
                        [  3318,   3318],
                        [  3311,   3311],
                        [  3283,   3284],
                        [  3239,   3239],
                        [  3179,   3179],
                        [  3105,   3105],
                        [  3018,   3018],
                        [  2919,   2919],
                        [  2810,   2810],
                        [  2692,   2692],
                        [  2569,   2569],
                        [  2442,   2442],
                        [  2325,   2325],
                        [  2218,   2218],
                        [  2139,   2139],
                        [  2084,   2085],
                        [  2064,   2063],
                        [  2073,   2073],
                        [  2096,   2096],
                        [  2140,   2140],
                        [  2175,   2174],
                        [  2203,   2203],
                        [  2222,   2222],
                        [  2232,   2232],
                        [  2230,   2230],
                        [  2217,   2217],
                        [  2191,   2191],
                        [  2151,   2150],
                        [  2096,   2096],
                        [  2028,   2028],
                        [  1946,   1946],
                        [  1848,   1848],
                        [  1736,   1736],
                        [  1607,   1608],
                        [  1463,   1463],
                        [  1302,   1302],
                        [  1126,   1126],
                        [   933,    934],
                        [   722,    722],
                        [   496,    496],
                        [   254,    254],
                        [    -8,     -8],
                        [  -284,   -284],
                        [  -577,   -577],
                        [  -887,   -887],
                        [ -1213,  -1213],
                        [ -1554,  -1554],
                        [ -1909,  -1909],
                        [ -2278,  -2278],
                        [ -2661,  -2661],
                        [ -3056,  -3056],
                        [ -3459,  -3460],
                        [ -3872,  -3872],
                        [ -4292,  -4292],
                        [ -4716,  -4716],
                        [ -5142,  -5142],
                        [ -5568,  -5569],
                        [ -5994,  -5994],
                        [ -6412,  -6412],
                        [ -6823,  -6823],
                        [ -7226,  -7225],
                        [ -7588,  -7588],
                        [ -7884,  -7885],
                        [ -8114,  -8114],
                        [ -8272,  -8273],
                        [ -8338,  -8338],
                        [ -8270,  -8270],
                        [ -8062,  -8062],
                        [ -7771,  -7771],
                        [ -7435,  -7435],
                        [ -7054,  -7054],
                        [ -6636,  -6636],
                        [ -6195,  -6195],
                        [ -5737,  -5738],
                        [ -5272,  -5272],
                        [ -4808,  -4808],
                        [ -4348,  -4348],
                        [ -3901,  -3901],
                        [ -3470,  -3471],
                        [ -3062,  -3062],
                        [ -2676,  -2675],
                        [ -2316,  -2315],
                        [ -1984,  -1983],
                        [ -1680,  -1680],
                        [ -1406,  -1406],
                        [ -1162,  -1162],
                        [  -946,   -945],
                        [  -756,   -756],
                        [  -596,   -596],
                        [  -459,   -459],
                        [  -347,   -346],
                        [  -257,   -257],
                        [  -188,   -188],
                        [  -137,   -137],
                        [  -105,   -105],
                        [   -89,    -89],
                        [   -89,    -89],
                        [  -101,   -100],
                        [  -124,   -124],
                        [  -161,   -161],
                        [  -206,   -207],
                        [  -263,   -262],
                        [  -327,   -327],
                        [  -400,   -401],
                        [  -481,   -481],
                        [  -568,   -568],
                        [  -662,   -662],
                        [  -763,   -763],
                        [  -869,   -869],
                        [  -981,   -981],
                        [ -1096,  -1096],
                        [ -1216,  -1216],
                        [ -1341,  -1341],
                        [ -1469,  -1469],
                        [ -1600,  -1599],
                        [ -1731,  -1731],
                        [ -1866,  -1866],
                        [ -2001,  -2002],
                        [ -2134,  -2135],
                        [ -2269,  -2269],
                        [ -2400,  -2400],
                        [ -2528,  -2528],
                        [ -2652,  -2651],
                        [ -2771,  -2771],
                        [ -2882,  -2882],
                        [ -2988,  -2988],
                        [ -3084,  -3085],
                        [ -3170,  -3171],
                        [ -3248,  -3248],
                        [ -3312,  -3312],
                        [ -3361,  -3361],
                        [ -3396,  -3395],
                        [ -3416,  -3416],
                        [ -3421,  -3421],
                        [ -3418,  -3418],
                        [ -3404,  -3404],
                        [ -3404,  -3404],
                        [ -3417,  -3417],
                        [ -3452,  -3452],
                        [ -3508,  -3508],
                        [ -3581,  -3581],
                        [ -3672,  -3673],
                        [ -3742,  -3742],
                        [ -3794,  -3794],
                        [ -3811,  -3811],
                        [ -3798,  -3798],
                        [ -3752,  -3752],
                        [ -3671,  -3672],
                        [ -3560,  -3560],
                        [ -3417,  -3417],
                        [ -3244,  -3244],
                        [ -3044,  -3044],
                        [ -2816,  -2816],
                        [ -2564,  -2565],
                        [ -2295,  -2295],
                        [ -2004,  -2004],
                        [ -1700,  -1701],
                        [ -1383,  -1384],
                        [ -1058,  -1058],
                        [  -726,   -727],
                        [  -394,   -394],
                        [   -60,    -60],
                        [   269,    268],
                        [   593,    592],
                        [   908,    908],
                        [  1211,   1212],
                        [  1502,   1502],
                        [  1776,   1776],
                        [  2033,   2033],
                        [  2270,   2270],
                        [  2485,   2485],
                        [  2679,   2679],
                        [  2849,   2849],
                        [  2994,   2994],
                        [  3114,   3114],
                        [  3207,   3208],
                        [  3274,   3274],
                        [  3313,   3313],
                        [  3325,   3325],
                        [  3311,   3311],
                        [  3269,   3269],
                        [  3198,   3198],
                        [  3103,   3103],
                        [  2980,   2980],
                        [  2819,   2819],
                        [  2615,   2616],
                        [  2381,   2381],
                        [  2117,   2117],
                        [  1801,   1801],
                        [  1396,   1397],
                        [   883,    883],
                        [   292,    292],
                        [  -345,   -345],
                        [ -1022,  -1022],
                        [ -1728,  -1728],
                        [ -2449,  -2448],
                        [ -3171,  -3170],
                        [ -3885,  -3885],
                        [ -4583,  -4582],
                        [ -5250,  -5250],
                        [ -5882,  -5882],
                        [ -6472,  -6471],
                        [ -7011,  -7010],
                        [ -7496,  -7495],
                        [ -7923,  -7923],
                        [ -8290,  -8290],
                        [ -8595,  -8595],
                        [ -8837,  -8837],
                        [ -9017,  -9017],
                        [ -9136,  -9136],
                        [ -9197,  -9197],
                        [ -9200,  -9200],
                        [ -9150,  -9150],
                        [ -9050,  -9051],
                        [ -8906,  -8907],
                        [ -8719,  -8720],
                        [ -8497,  -8498],
                        [ -8241,  -8242],
                        [ -7959,  -7960],
                        [ -7654,  -7655],
                        [ -7330,  -7331],
                        [ -6995,  -6996],
                        [ -6649,  -6650],
                        [ -6298,  -6299],
                        [ -5947,  -5947],
                        [ -5597,  -5598],
                        [ -5254,  -5255],
                        [ -4921,  -4921],
                        [ -4600,  -4600],
                        [ -4292,  -4292],
                        [ -4002,  -4002],
                        [ -3728,  -3728],
                        [ -3474,  -3475],
                        [ -3244,  -3244],
                        [ -3032,  -3033],
                        [ -2845,  -2845],
                        [ -2677,  -2678],
                        [ -2533,  -2533],
                        [ -2410,  -2410],
                        [ -2310,  -2310],
                        [ -2230,  -2231],
                        [ -2169,  -2169],
                        [ -2126,  -2126],
                        [ -2101,  -2101],
                        [ -2091,  -2091],
                        [ -2096,  -2096],
                        [ -2114,  -2113],
                        [ -2143,  -2142],
                        [ -2179,  -2179],
                        [ -2225,  -2225],
                        [ -2277,  -2277],
                        [ -2331,  -2332],
                        [ -2390,  -2390],
                        [ -2454,  -2454],
                        [ -2519,  -2518],
                        [ -2581,  -2581],
                        [ -2641,  -2641],
                        [ -2698,  -2698],
                        [ -2728,  -2728],
                        [ -2731,  -2731],
                        [ -2688,  -2688],
                        [ -2598,  -2598],
                        [ -2459,  -2459],
                        [ -2270,  -2270],
                        [ -2055,  -2055],
                        [ -1814,  -1814],
                        [ -1588,  -1588],
                        [ -1374,  -1374],
                        [ -1179,  -1179],
                        [ -1003,  -1003],
                        [  -854,   -854],
                        [  -730,   -730],
                        [  -637,   -637],
                        [  -574,   -573],
                        [  -542,   -542],
                        [  -544,   -544],
                        [  -579,   -579],
                        [  -648,   -648],
                        [  -752,   -752],
                        [  -889,   -888],
                        [ -1059,  -1059],
                        [ -1263,  -1263],
                        [ -1497,  -1497],
                        [ -1762,  -1762],
                        [ -2056,  -2056],
                        [ -2377,  -2377],
                        [ -2724,  -2725],
                        [ -3096,  -3097],
                        [ -3488,  -3488],
                        [ -3902,  -3902],
                        [ -4331,  -4331],
                        [ -4774,  -4774],
                        [ -5231,  -5230],
                        [ -5696,  -5696],
                        [ -6166,  -6166],
                        [ -6639,  -6639],
                        [ -7112,  -7112],
                        [ -7581,  -7581],
                        [ -8042,  -8042],
                        [ -8494,  -8493],
                        [ -8930,  -8930],
                        [ -9349,  -9349],
                        [ -9747,  -9746],
                        [-10120, -10119],
                        [-10463, -10462],
                        [-10775, -10775],
                        [-11052, -11052],
                        [-11295, -11295],
                        [-11522, -11521],
                        [-11745, -11744],
                        [-11958, -11958],
                        [-12143, -12142],
                        [-12254, -12253],
                        [-12245, -12244],
                        [-12120, -12119],
                        [-11895, -11895],
                        [-11572, -11572],
                        [-11161, -11161],
                        [-10677, -10677],
                        [-10129, -10129],
                        [ -9524,  -9524],
                        [ -8874,  -8875],
                        [ -8192,  -8192],
                        [ -7485,  -7485],
                        [ -6761,  -6761],
                        [ -6031,  -6031],
                        [ -5301,  -5301],
                        [ -4578,  -4578],
                        [ -3869,  -3870],
                        [ -3179,  -3179],
                        [ -2512,  -2513],
                        [ -1874,  -1874],
                        [ -1268,  -1268],
                        [  -694,   -695],
                        [  -158,   -158],
                        [   340,    340],
                        [   801,    801],
                        [  1221,   1221],
                        [  1602,   1602],
                        [  1944,   1944],
                        [  2246,   2246],
                        [  2508,   2508],
                        [  2734,   2734],
                        [  2923,   2923],
                        [  3076,   3076],
                        [  3196,   3196],
                        [  3285,   3285],
                        [  3343,   3342],
                        [  3372,   3371],
                        [  3373,   3373],
                        [  3351,   3351],
                        [  3306,   3306],
                        [  3239,   3240],
                        [  3157,   3157],
                        [  3057,   3057],
                        [  2942,   2942],
                        [  2818,   2818],
                        [  2682,   2682],
                        [  2541,   2541],
                        [  2393,   2394],
                        [  2243,   2243],
                        [  2093,   2093],
                        [  1944,   1944],
                        [  1799,   1800],
                        [  1658,   1659],
                        [  1527,   1527],
                        [  1404,   1405],
                        [  1292,   1293],
                        [  1193,   1194],
                        [  1109,   1109],
                        [  1039,   1040],
                        [   986,    986],
                        [   951,    951],
                        [   933,    933],
                        [   934,    934],
                        [   956,    956],
                        [   997,    997],
                        [  1061,   1060],
                        [  1146,   1145],
                        [  1246,   1246],
                        [  1356,   1356],
                        [  1476,   1476],
                        [  1575,   1575],
                        [  1657,   1656],
                        [  1709,   1707],
                        [  1732,   1731],
                        [  1723,   1721],
                        [  1681,   1680],
                        [  1649,   1649],
                        [  1624,   1624],
                        [  1622,   1621],
                        [  1635,   1634],
                        [  1675,   1675],
                        [  1737,   1736],
                        [  1821,   1820],
                        [  1928,   1927],
                        [  2056,   2055],
                        [  2204,   2204],
                        [  2370,   2369],
                        [  2552,   2551],
                        [  2750,   2749],
                        [  2956,   2955],
                        [  3170,   3170],
                        [  3392,   3392],
                        [  3615,   3615],
                        [  3839,   3839],
                        [  4059,   4059],
                        [  4274,   4274],
                        [  4479,   4479],
                        [  4675,   4676],
                        [  4857,   4857],
                        [  5023,   5024],
                        [  5173,   5173],
                        [  5304,   5304],
                        [  5414,   5415],
                        [  5502,   5503],
                        [  5568,   5570],
                        [  5612,   5613],
                        [  5631,   5631],
                        [  5626,   5627],
                        [  5596,   5597],
                        [  5540,   5542],
                        [  5463,   5464],
                        [  5361,   5362],
                        [  5234,   5235],
                        [  5086,   5086],
                        [  4915,   4916],
                        [  4723,   4723],
                        [  4509,   4509],
                        [  4277,   4277],
                        [  4055,   4055],
                        [  3884,   3884],
                        [  3780,   3780],
                        [  3746,   3746],
                        [  3768,   3768],
                        [  3799,   3799],
                        [  3776,   3776],
                        [  3671,   3672],
                        [  3493,   3493],
                        [  3248,   3249],
                        [  2945,   2945],
                        [  2594,   2596],
                        [  2207,   2208],
                        [  1788,   1788],
                        [  1350,   1350],
                        [   901,    902],
                        [   450,    450],
                        [     4,      5],
                        [  -430,   -429],
                        [  -845,   -844],
                        [ -1237,  -1237],
                        [ -1601,  -1601],
                        [ -1935,  -1935],
                        [ -2235,  -2234],
                        [ -2498,  -2498],
                        [ -2726,  -2726],
                        [ -2916,  -2916],
                        [ -3070,  -3070],
                        [ -3188,  -3189],
                        [ -3273,  -3274],
                        [ -3327,  -3327],
                        [ -3351,  -3352],
                        [ -3348,  -3348],
                        [ -3322,  -3323],
                        [ -3274,  -3275],
                        [ -3208,  -3209],
                        [ -3129,  -3131],
                        [ -3036,  -3037],
                        [ -2935,  -2936],
                        [ -2828,  -2829],
                        [ -2717,  -2718],
                        [ -2605,  -2606],
                        [ -2494,  -2495],
                        [ -2385,  -2386],
                        [ -2280,  -2281],
                        [ -2182,  -2182],
                        [ -2089,  -2089],
                        [ -2004,  -2005],
                        [ -1928,  -1929],
                        [ -1860,  -1860],
                        [ -1800,  -1801],
                        [ -1749,  -1749],
                        [ -1705,  -1705],
                        [ -1669,  -1669],
                        [ -1640,  -1640],
                        [ -1616,  -1617],
                        [ -1597,  -1598],
                        [ -1583,  -1584],
                        [ -1572,  -1572],
                        [ -1563,  -1563],
                        [ -1554,  -1554],
                        [ -1545,  -1546],
                        [ -1536,  -1536],
                        [ -1523,  -1522],
                        [ -1506,  -1506],
                        [ -1486,  -1486],
                        [ -1460,  -1460],
                        [ -1429,  -1428],
                        [ -1393,  -1392],
                        [ -1353,  -1351],
                        [ -1306,  -1305],
                        [ -1254,  -1253],
                        [ -1192,  -1191],
                        [ -1123,  -1122],
                        [ -1026,  -1025],
                        [  -904,   -903],
                        [  -745,   -743],
                        [  -548,   -547],
                        [  -308,   -306],
                        [   -24,    -22],
                        [   287,    288],
                        [   622,    623],
                        [   943,    944],
                        [  1253,   1255],
                        [  1541,   1543],
                        [  1808,   1809],
                        [  2042,   2043],
                        [  2245,   2246],
                        [  2407,   2408],
                        [  2531,   2532],
                        [  2611,   2613],
                        [  2646,   2647],
                        [  2636,   2637],
                        [  2580,   2581],
                        [  2477,   2477],
                        [  2329,   2329],
                        [  2138,   2139],
                        [  1904,   1905],
                        [  1629,   1630],
                        [  1317,   1318],
                        [   972,    973],
                        [   593,    595],
                        [   189,    190],
                        [  -240,   -239],
                        [  -687,   -687],
                        [ -1151,  -1151],
                        [ -1624,  -1624],
                        [ -2105,  -2104],
                        [ -2586,  -2585],
                        [ -3063,  -3063],
                        [ -3534,  -3534],
                        [ -3992,  -3992],
                        [ -4431,  -4431],
                        [ -4851,  -4851],
                        [ -5243,  -5242],
                        [ -5605,  -5604],
                        [ -5933,  -5931],
                        [ -6222,  -6221],
                        [ -6469,  -6468],
                        [ -6671,  -6670],
                        [ -6827,  -6826],
                        [ -6930,  -6929],
                        [ -6985,  -6983],
                        [ -7041,  -7040],
                        [ -7152,  -7150],
                        [ -7333,  -7331],
                        [ -7585,  -7583],
                        [ -7897,  -7895],
                        [ -8220,  -8219],
                        [ -8466,  -8466],
                        [ -8579,  -8579],
                        [ -8563,  -8563],
                        [ -8424,  -8424],
                        [ -8166,  -8167],
                        [ -7802,  -7803],
                        [ -7339,  -7340],
                        [ -6788,  -6789],
                        [ -6158,  -6159],
                        [ -5462,  -5464],
                        [ -4712,  -4714],
                        [ -3917,  -3920],
                        [ -3088,  -3090],
                        [ -2237,  -2239],
                        [ -1373,  -1376],
                        [  -505,   -507],
                        [   358,    356],
                        [  1208,   1206],
                        [  2038,   2035],
                        [  2841,   2839],
                        [  3613,   3611],
                        [  4347,   4345],
                        [  5039,   5038],
                        [  5690,   5688],
                        [  6294,   6292],
                        [  6848,   6847],
                        [  7354,   7353],
                        [  7811,   7810],
                        [  8218,   8217],
                        [  8575,   8574],
                        [  8885,   8885],
                        [  9147,   9147],
                        [  9366,   9365],
                        [  9541,   9541],
                        [  9677,   9677],
                        [  9775,   9776],
                        [  9838,   9839],
                        [  9869,   9870],
                        [  9874,   9874],
                        [  9852,   9852],
                        [  9809,   9809],
                        [  9747,   9747],
                        [  9669,   9669],
                        [  9579,   9579],
                        [  9481,   9481],
                        [  9377,   9377],
                        [  9269,   9269],
                        [  9163,   9164],
                        [  9059,   9060],
                        [  8960,   8960],
                        [  8868,   8869],
                        [  8786,   8787],
                        [  8716,   8717],
                        [  8658,   8659],
                        [  8615,   8615],
                        [  8587,   8587],
                        [  8574,   8574],
                        [  8578,   8578],
                        [  8599,   8599],
                        [  8636,   8636],
                        [  8690,   8690],
                        [  8759,   8758],
                        [  8845,   8843],
                        [  8946,   8945],
                        [  9062,   9060],
                        [  9189,   9186],
                        [  9324,   9322],
                        [  9461,   9458],
                        [  9597,   9595],
                        [  9718,   9715],
                        [  9822,   9819],
                        [  9899,   9895],
                        [  9951,   9947],
                        [  9960,   9957],
                        [  9927,   9924],
                        [  9878,   9874],
                        [  9806,   9803],
                        [  9727,   9724],
                        [  9638,   9635],
                        [  9545,   9542],
                        [  9449,   9445],
                        [  9350,   9348],
                        [  9253,   9250],
                        [  9157,   9154],
                        [  9061,   9059],
                        [  8970,   8968],
                        [  8881,   8878],
                        [  8793,   8791],
                        [  8708,   8707],
                        [  8625,   8623],
                        [  8542,   8541],
                        [  8459,   8457],
                        [  8375,   8374],
                        [  8288,   8288],
                        [  8199,   8198],
                        [  8106,   8105],
                        [  8006,   8006],
                        [  7901,   7901],
                        [  7789,   7789],
                        [  7668,   7668],
                        [  7539,   7540],
                        [  7401,   7401],
                        [  7254,   7255],
                        [  7096,   7097],
                        [  6928,   6929],
                        [  6751,   6751],
                        [  6562,   6563],
                        [  6363,   6364],
                        [  6154,   6154],
                        [  5935,   5935],
                        [  5706,   5707],
                        [  5469,   5470],
                        [  5224,   5223],
                        [  4969,   4969],
                        [  4709,   4708],
                        [  4436,   4435],
                        [  4170,   4169],
                        [  3981,   3980],
                        [  3934,   3933],
                        [  4045,   4045],
                        [  4315,   4314],
                        [  4743,   4743],
                        [  5280,   5280],
                        [  5812,   5812],
                        [  6263,   6263],
                        [  6627,   6628],
                        [  6911,   6912],
                        [  7114,   7115],
                        [  7240,   7242],
                        [  7294,   7295],
                        [  7278,   7280],
                        [  7202,   7204],
                        [  7069,   7070],
                        [  6887,   6888],
                        [  6662,   6663],
                        [  6399,   6400],
                        [  6107,   6108],
                        [  5790,   5791],
                        [  5453,   5454],
                        [  5102,   5103],
                        [  4743,   4744],
                        [  4378,   4379],
                        [  4011,   4012],
                        [  3647,   3648],
                        [  3288,   3289],
                        [  2936,   2936],
                        [  2591,   2592],
                        [  2257,   2257],
                        [  1934,   1934],
                        [  1621,   1621],
                        [  1321,   1320],
                        [  1033,   1032],
                        [   756,    755],
                        [   492,    492],
                        [   239,    238],
                        [    -2,     -3],
                        [  -231,   -232],
                        [  -449,   -451],
                        [  -657,   -658],
                        [  -852,   -854],
                        [ -1039,  -1041],
                        [ -1214,  -1216],
                        [ -1379,  -1380],
                        [ -1533,  -1535],
                        [ -1677,  -1679],
                        [ -1809,  -1811],
                        [ -1931,  -1932],
                        [ -2041,  -2042],
                        [ -2139,  -2140],
                        [ -2225,  -2226],
                        [ -2299,  -2301],
                        [ -2360,  -2361],
                        [ -2407,  -2408],
                        [ -2442,  -2444],
                        [ -2464,  -2465],
                        [ -2472,  -2472],
                        [ -2466,  -2467],
                        [ -2446,  -2447],
                        [ -2414,  -2415],
                        [ -2368,  -2368],
                        [ -2309,  -2309],
                        [ -2238,  -2238],
                        [ -2156,  -2156],
                        [ -2062,  -2062],
                        [ -1959,  -1958],
                        [ -1845,  -1845],
                        [ -1728,  -1727],
                        [ -1605,  -1603],
                        [ -1473,  -1471],
                        [ -1338,  -1336],
                        [ -1199,  -1197],
                        [ -1052,  -1050],
                        [  -901,   -898],
                        [  -746,   -743],
                        [  -591,   -587],
                        [  -419,   -416],
                        [  -233,   -231],
                        [   -31,    -27],
                        [   189,    193],
                        [   405,    409],
                        [   618,    622],
                        [   817,    821],
                        [  1002,   1005],
                        [  1162,   1165],
                        [  1297,   1301],
                        [  1399,   1402],
                        [  1471,   1474],
                        [  1506,   1509],
                        [  1502,   1506],
                        [  1459,   1462],
                        [  1378,   1381],
                        [  1259,   1260],
                        [  1101,   1103],
                        [   907,    908],
                        [   678,    680],
                        [   419,    421],
                        [   132,    134],
                        [  -177,   -176],
                        [  -509,   -507],
                        [  -856,   -854],
                        [ -1215,  -1213],
                        [ -1580,  -1578],
                        [ -1946,  -1944],
                        [ -2308,  -2307],
                        [ -2664,  -2663],
                        [ -3006,  -3005],
                        [ -3332,  -3330],
                        [ -3634,  -3633],
                        [ -3911,  -3909],
                        [ -4156,  -4154],
                        [ -4367,  -4366],
                        [ -4539,  -4537],
                        [ -4671,  -4669],
                        [ -4759,  -4757],
                        [ -4801,  -4799],
                        [ -4794,  -4792],
                        [ -4738,  -4736],
                        [ -4634,  -4631],
                        [ -4472,  -4470],
                        [ -4280,  -4278],
                        [ -4147,  -4145],
                        [ -4137,  -4136],
                        [ -4267,  -4266],
                        [ -4540,  -4539],
                        [ -4964,  -4964],
                        [ -5493,  -5493],
                        [ -5996,  -5995],
                        [ -6385,  -6385],
                        [ -6654,  -6654],
                        [ -6813,  -6814],
                        [ -6859,  -6861],
                        [ -6796,  -6798],
                        [ -6632,  -6633],
                        [ -6369,  -6372],
                        [ -6019,  -6022],
                        [ -5591,  -5594],
                        [ -5092,  -5095],
                        [ -4533,  -4536],
                        [ -3923,  -3927],
                        [ -3271,  -3275],
                        [ -2589,  -2593],
                        [ -1885,  -1889],
                        [ -1168,  -1172],
                        [  -447,   -451],
                        [   270,    267],
                        [   976,    972],
                        [  1664,   1661],
                        [  2329,   2326],
                        [  2966,   2962],
                        [  3572,   3569],
                        [  4141,   4138],
                        [  4673,   4670],
                        [  5166,   5163],
                        [  5616,   5615],
                        [  6027,   6026],
                        [  6397,   6395],
                        [  6726,   6725],
                        [  7016,   7015],
                        [  7268,   7267],
                        [  7485,   7485],
                        [  7668,   7668],
                        [  7820,   7820],
                        [  7944,   7945],
                        [  8045,   8045],
                        [  8121,   8122],
                        [  8178,   8179],
                        [  8221,   8222],
                        [  8249,   8249],
                        [  8266,   8267],
                        [  8276,   8278],
                        [  8282,   8283],
                        [  8286,   8287],
                        [  8288,   8290],
                        [  8293,   8294],
                        [  8301,   8303],
                        [  8315,   8317],
                        [  8335,   8336],
                        [  8361,   8363],
                        [  8397,   8398],
                        [  8441,   8442],
                        [  8492,   8493],
                        [  8551,   8552],
                        [  8620,   8621],
                        [  8693,   8695],
                        [  8773,   8774],
                        [  8860,   8860],
                        [  8948,   8948],
                        [  9037,   9037],
                        [  9128,   9128],
                        [  9219,   9218],
                        [  9306,   9304],
                        [  9385,   9384],
                        [  9458,   9456],
                        [  9522,   9519],
                        [  9575,   9571],
                        [  9627,   9622],
                        [  9672,   9668],
                        [  9706,   9702],
                        [  9729,   9725],
                        [  9709,   9705],
                        [  9648,   9644],
                        [  9540,   9535],
                        [  9383,   9378],
                        [  9185,   9181],
                        [  8947,   8942],
                        [  8676,   8672],
                        [  8372,   8368],
                        [  8044,   8040],
                        [  7690,   7685],
                        [  7318,   7315],
                        [  6929,   6926],
                        [  6528,   6525],
                        [  6118,   6116],
                        [  5702,   5701],
                        [  5280,   5279],
                        [  4857,   4856],
                        [  4435,   4434],
                        [  4015,   4015],
                        [  3599,   3598],
                        [  3187,   3187],
                        [  2781,   2781],
                        [  2383,   2383],
                        [  1992,   1992],
                        [  1609,   1609],
                        [  1237,   1237],
                        [   872,    872],
                        [   516,    516],
                        [   171,    171],
                        [  -166,   -165],
                        [  -492,   -492],
                        [  -809,   -809],
                        [ -1118,  -1118],
                        [ -1415,  -1415],
                        [ -1706,  -1705],
                        [ -1987,  -1987],
                        [ -2260,  -2260],
                        [ -2524,  -2524],
                        [ -2781,  -2782],
                        [ -3031,  -3031],
                        [ -3271,  -3272],
                        [ -3504,  -3504],
                        [ -3737,  -3737],
                        [ -3932,  -3933],
                        [ -3994,  -3995],
                        [ -3859,  -3861],
                        [ -3522,  -3524],
                        [ -2974,  -2975],
                        [ -2202,  -2203],
                        [ -1254,  -1255],
                        [  -276,   -277],
                        [   631,    631],
                        [  1458,   1458],
                        [  2211,   2212],
                        [  2875,   2876],
                        [  3447,   3449],
                        [  3929,   3930],
                        [  4318,   4319],
                        [  4614,   4616],
                        [  4821,   4823],
                        [  4941,   4942],
                        [  4977,   4980],
                        [  4938,   4940],
                        [  4825,   4828],
                        [  4643,   4647],
                        [  4401,   4404],
                        [  4105,   4106],
                        [  3759,   3762],
                        [  3372,   3374],
                        [  2946,   2948],
                        [  2491,   2493],
                        [  2012,   2013],
                        [  1511,   1512],
                        [   995,    996],
                        [   470,    470],
                        [   -62,    -62],
                        [  -596,   -596],
                        [ -1127,  -1128],
                        [ -1654,  -1654],
                        [ -2171,  -2171],
                        [ -2677,  -2678],
                        [ -3170,  -3170],
                        [ -3646,  -3647],
                        [ -4103,  -4105],
                        [ -4539,  -4541],
                        [ -4952,  -4955],
                        [ -5342,  -5345],
                        [ -5706,  -5709],
                        [ -6043,  -6045],
                        [ -6351,  -6354],
                        [ -6632,  -6634],
                        [ -6882,  -6884],
                        [ -7101,  -7103],
                        [ -7291,  -7293],
                        [ -7449,  -7451],
                        [ -7577,  -7579],
                        [ -7674,  -7677],
                        [ -7743,  -7746],
                        [ -7782,  -7785],
                        [ -7794,  -7796],
                        [ -7779,  -7781],
                        [ -7737,  -7739],
                        [ -7670,  -7673],
                        [ -7582,  -7586],
                        [ -7473,  -7476],
                        [ -7345,  -7347],
                        [ -7198,  -7201],
                        [ -7038,  -7040],
                        [ -6864,  -6866],
                        [ -6678,  -6680],
                        [ -6485,  -6487],
                        [ -6285,  -6286],
                        [ -6081,  -6082],
                        [ -5876,  -5877],
                        [ -5671,  -5671],
                        [ -5470,  -5469],
                        [ -5274,  -5272],
                        [ -5085,  -5084],
                        [ -4926,  -4925],
                        [ -4796,  -4795],
                        [ -4710,  -4709],
                        [ -4668,  -4668],
                        [ -4652,  -4652],
                        [ -4663,  -4664],
                        [ -4664,  -4665],
                        [ -4659,  -4660],
                        [ -4646,  -4647],
                        [ -4625,  -4625],
                        [ -4603,  -4603],
                        [ -4582,  -4579],
                        [ -4566,  -4562],
                        [ -4556,  -4551],
                        [ -4557,  -4552],
                        [ -4567,  -4562],
                        [ -4594,  -4590],
                        [ -4635,  -4631],
                        [ -4693,  -4691],
                        [ -4767,  -4765],
                        [ -4858,  -4856],
                        [ -4963,  -4962],
                        [ -5083,  -5083],
                        [ -5214,  -5214],
                        [ -5354,  -5354],
                        [ -5503,  -5502],
                        [ -5656,  -5653],
                        [ -5809,  -5805],
                        [ -5959,  -5954],
                        [ -6100,  -6095],
                        [ -6231,  -6227],
                        [ -6350,  -6346],
                        [ -6448,  -6446],
                        [ -6527,  -6527],
                        [ -6581,  -6582],
                        [ -6609,  -6611],
                        [ -6606,  -6611],
                        [ -6572,  -6577],
                        [ -6502,  -6509],
                        [ -6398,  -6407],
                        [ -6255,  -6264],
                        [ -6076,  -6086],
                        [ -5858,  -5870],
                        [ -5601,  -5614],
                        [ -5306,  -5319],
                        [ -4978,  -4991],
                        [ -4613,  -4628],
                        [ -4208,  -4223],
                        [ -3809,  -3825],
                        [ -3521,  -3538],
                        [ -3400,  -3417],
                        [ -3450,  -3469],
                        [ -3688,  -3707],
                        [ -4141,  -4161],
                        [ -4767,  -4787],
                        [ -5419,  -5440],
                        [ -6000,  -6023],
                        [ -6513,  -6536],
                        [ -6957,  -6979],
                        [ -7323,  -7346],
                        [ -7608,  -7631],
                        [ -7811,  -7835],
                        [ -7937,  -7959],
                        [ -7984,  -8006],
                        [ -7958,  -7979],
                        [ -7861,  -7882],
                        [ -7700,  -7720],
                        [ -7481,  -7499],
                        [ -7209,  -7226],
                        [ -6890,  -6907],
                        [ -6533,  -6547],
                        [ -6143,  -6156],
                        [ -5728,  -5740],
                        [ -5293,  -5303],
                        [ -4846,  -4853],
                        [ -4391,  -4396],
                        [ -3933,  -3936],
                        [ -3476,  -3477],
                        [ -3025,  -3024],
                        [ -2584,  -2581],
                        [ -2154,  -2149],
                        [ -1739,  -1731],
                        [ -1338,  -1328],
                        [  -956,   -943],
                        [  -592,   -577],
                        [  -245,   -227],
                        [    85,    106],
                        [   394,    419],
                        [   688,    717],
                        [   966,    999],
                        [  1229,   1265],
                        [  1477,   1519],
                        [  1714,   1760],
                        [  1939,   1990],
                        [  2156,   2211],
                        [  2364,   2424],
                        [  2563,   2628],
                        [  2759,   2828],
                        [  2950,   3023],
                        [  3140,   3213],
                        [  3329,   3399],
                        [  3517,   3583],
                        [  3707,   3766],
                        [  3898,   3947],
                        [  4089,   4126],
                        [  4280,   4302],
                        [  4466,   4474],
                        [  4650,   4643],
                        [  4824,   4806],
                        [  4992,   4963],
                        [  5150,   5111],
                        [  5295,   5251],
                        [  5428,   5380],
                        [  5548,   5497],
                        [  5651,   5599],
                        [  5736,   5683],
                        [  5801,   5750],
                        [  5846,   5800],
                        [  5866,   5827],
                        [  5864,   5835],
                        [  5835,   5817],
                        [  5780,   5773],
                        [  5713,   5719],
                        [  5632,   5652],
                        [  5569,   5604],
                        [  5520,   5570],
                        [  5483,   5548],
                        [  5458,   5539],
                        [  5402,   5498],
                        [  5318,   5428],
                        [  5168,   5292],
                        [  4955,   5092],
                        [  4682,   4833],
                        [  4353,   4514],
                        [  3975,   4147],
                        [  3545,   3729],
                        [  3079,   3270],
                        [  2572,   2772],
                        [  2038,   2245],
                        [  1477,   1689],
                        [   898,   1115],
                        [   303,    523],
                        [  -298,    -76],
                        [  -906,   -684],
                        [ -1512,  -1291],
                        [ -2115,  -1896],
                        [ -2708,  -2493],
                        [ -3291,  -3081],
                        [ -3859,  -3653],
                        [ -4410,  -4211],
                        [ -4941,  -4749],
                        [ -5451,  -5267],
                        [ -5939,  -5763],
                        [ -6400,  -6234],
                        [ -6839,  -6682],
                        [ -7251,  -7105],
                        [ -7636,  -7500],
                        [ -7997,  -7872],
                        [ -8331,  -8217],
                        [ -8640,  -8536],
                        [ -8925,  -8833],
                        [ -9185,  -9102],
                        [ -9422,  -9350],
                        [ -9636,  -9575],
                        [ -9829,  -9777],
                        [ -9999,  -9957],
                        [-10153, -10120],
                        [-10287, -10263],
                        [-10402, -10386],
                        [-10500, -10493],
                        [-10590, -10589],
                        [-10618, -10624],
                        [-10496, -10509],
                        [-10183, -10203],
                        [ -9680,  -9705],
                        [ -8970,  -9000],
                        [ -8024,  -8059],
                        [ -6883,  -6923],
                        [ -5693,  -5736],
                        [ -4547,  -4594],
                        [ -3448,  -3499],
                        [ -2405,  -2459],
                        [ -1433,  -1491],
                        [  -542,   -605],
                        [   262,    197],
                        [   974,    905],
                        [  1590,   1518],
                        [  2106,   2031],
                        [  2524,   2448],
                        [  2845,   2770],
                        [  3070,   3000],
                        [  3204,   3140],
                        [  3248,   3193],
                        [  3211,   3167],
                        [  3096,   3062],
                        [  2911,   2888],
                        [  2663,   2646],
                        [  2356,   2347],
                        [  2001,   1996],
                        [  1601,   1597],
                        [  1167,   1162],
                        [   703,    693],
                        [   217,    201],
                        [  -284,   -310],
                        [  -797,   -833],
                        [ -1314,  -1363],
                        [ -1828,  -1894],
                        [ -2338,  -2421],
                        [ -2835,  -2937],
                        [ -3319,  -3443],
                        [ -3782,  -3930],
                        [ -4225,  -4396],
                        [ -4643,  -4840],
                        [ -5034,  -5257],
                        [ -5397,  -5644],
                        [ -5727,  -6001],
                        [ -6026,  -6327],
                        [ -6293,  -6619],
                        [ -6526,  -6878],
                        [ -6726,  -7103],
                        [ -6893,  -7292],
                        [ -7030,  -7450],
                        [ -7139,  -7573],
                        [ -7222,  -7664],
                        [ -7282,  -7725],
                        [ -7322,  -7756],
                        [ -7342,  -7759],
                        [ -7343,  -7737],
                        [ -7325,  -7690],
                        [ -7287,  -7621],
                        [ -7227,  -7533],
                        [ -7149,  -7426],
                        [ -7055,  -7305],
                        [ -6945,  -7171],
                        [ -6823,  -7027],
                        [ -6692,  -6875],
                        [ -6552,  -6719],
                        [ -6407,  -6559],
                        [ -6258,  -6398],
                        [ -6109,  -6238],
                        [ -5961,  -6082],
                        [ -5813,  -5930],
                        [ -5672,  -5785],
                        [ -5539,  -5650],
                        [ -5420,  -5532],
                        [ -5316,  -5428],
                        [ -5270,  -5385],
                        [ -5282,  -5402],
                        [ -5368,  -5493],
                        [ -5528,  -5661],
                        [ -5744,  -5883],
                        [ -6013,  -6161],
                        [ -6271,  -6428],
                        [ -6520,  -6686],
                        [ -6740,  -6916],
                        [ -6930,  -7118],
                        [ -7095,  -7292],
                        [ -7231,  -7440],
                        [ -7343,  -7564],
                        [ -7430,  -7660],
                        [ -7494,  -7737],
                        [ -7533,  -7788],
                        [ -7553,  -7820],
                        [ -7551,  -7830],
                        [ -7533,  -7822],
                        [ -7493,  -7794],
                        [ -7436,  -7748],
                        [ -7360,  -7684],
                        [ -7268,  -7602],
                        [ -7156,  -7499],
                        [ -7027,  -7380],
                        [ -6877,  -7239],
                        [ -6708,  -7079],
                        [ -6520,  -6898],
                        [ -6310,  -6695],
                        [ -6078,  -6470],
                        [ -5824,  -6221],
                        [ -5548,  -5949],
                        [ -5248,  -5653],
                        [ -4924,  -5331],
                        [ -4577,  -4985],
                        [ -4206,  -4614],
                        [ -3811,  -4219],
                        [ -3395,  -3799],
                        [ -2958,  -3358],
                        [ -2498,  -2894],
                        [ -2022,  -2411],
                        [ -1528,  -1910],
                        [ -1019,  -1391],
                        [  -498,   -860],
                        [    33,   -317],
                        [   566,    230],
                        [  1104,    782],
                        [  1648,   1341],
                        [  2138,   1848],
                        [  2496,   2224],
                        [  2693,   2440],
                        [  2724,   2491],
                        [  2566,   2353],
                        [  2177,   1985],
                        [  1587,   1417],
                        [   921,    774],
                        [   259,    134],
                        [  -402,   -504],
                        [ -1055,  -1133],
                        [ -1682,  -1738],
                        [ -2275,  -2308],
                        [ -2830,  -2841],
                        [ -3339,  -3328],
                        [ -3798,  -3766],
                        [ -4201,  -4152],
                        [ -4550,  -4486],
                        [ -4843,  -4772],
                        [ -5077,  -5006],
                        [ -5254,  -5190],
                        [ -5379,  -5329],
                        [ -5449,  -5417],
                        [ -5470,  -5460],
                        [ -5445,  -5454],
                        [ -5375,  -5402],
                        [ -5267,  -5308],
                        [ -5120,  -5175],
                        [ -4942,  -5006],
                        [ -4734,  -4804],
                        [ -4498,  -4573],
                        [ -4240,  -4315],
                        [ -3962,  -4034],
                        [ -3665,  -3732],
                        [ -3354,  -3412],
                        [ -3030,  -3076],
                        [ -2696,  -2728],
                        [ -2352,  -2367],
                        [ -2002,  -1996],
                        [ -1646,  -1619],
                        [ -1286,  -1234],
                        [  -925,   -845],
                        [  -561,   -453],
                        [  -197,    -59],
                        [   166,    335],
                        [   528,    730],
                        [   886,   1123],
                        [  1241,   1512],
                        [  1591,   1898],
                        [  1935,   2278],
                        [  2275,   2650],
                        [  2610,   3015],
                        [  2942,   3369],
                        [  3273,   3712],
                        [  3599,   4042],
                        [  3923,   4359],
                        [  4234,   4658],
                        [  4535,   4939],
                        [  4815,   5201],
                        [  5072,   5441],
                        [  5301,   5658],
                        [  5503,   5852],
                        [  5672,   6017],
                        [  5810,   6156],
                        [  5915,   6264],
                        [  5984,   6342],
                        [  6017,   6387],
                        [  6014,   6400],
                        [  5974,   6379],
                        [  5896,   6322],
                        [  5778,   6229],
                        [  5623,   6099],
                        [  5432,   5938],
                        [  5206,   5740],
                        [  4975,   5539],
                        [  4739,   5333],
                        [  4544,   5168],
                        [  4384,   5038],
                        [  4266,   4946],
                        [  4188,   4895],
                        [  4102,   4832],
                        [  4010,   4764],
                        [  3857,   4631],
                        [  3642,   4435],
                        [  3374,   4182],
                        [  3053,   3872],
                        [  2680,   3510],
                        [  2261,   3097],
                        [  1801,   2641],
                        [  1304,   2146],
                        [   779,   1619],
                        [   227,   1063],
                        [  -342,    488],
                        [  -925,   -106],
                        [ -1514,   -706],
                        [ -2108,  -1315],
                        [ -2698,  -1919],
                        [ -3282,  -2521],
                        [ -3853,  -3111],
                        [ -4409,  -3688],
                        [ -4947,  -4245],
                        [ -5462,  -4783],
                        [ -5952,  -5297],
                        [ -6418,  -5786],
                        [ -6853,  -6245],
                        [ -7261,  -6676],
                        [ -7637,  -7076],
                        [ -7983,  -7444],
                        [ -8296,  -7781],
                        [ -8579,  -8086],
                        [ -8833,  -8361],
                        [ -9055,  -8603],
                        [ -9247,  -8816],
                        [ -9411,  -8999],
                        [ -9549,  -9155],
                        [ -9659,  -9283],
                        [ -9745,  -9385],
                        [ -9805,  -9462],
                        [ -9845,  -9516],
                        [ -9862,  -9548],
                        [ -9856,  -9555],
                        [ -9833,  -9546],
                        [ -9795,  -9520],
                        [ -9692,  -9430],
                        [ -9474,  -9224],
                        [ -9128,  -8891],
                        [ -8657,  -8433],
                        [ -8036,  -7824],
                        [ -7225,  -7026],
                        [ -6240,  -6055],
                        [ -5192,  -5020],
                        [ -4143,  -3986],
                        [ -3096,  -2954],
                        [ -2063,  -1939],
                        [ -1063,   -956],
                        [  -108,    -19],
                        [   794,    863],
                        [  1633,   1681],
                        [  2402,   2429],
                        [  3096,   3102],
                        [  3709,   3702],
                        [  4242,   4226],
                        [  4692,   4675],
                        [  5060,   5051],
                        [  5350,   5353],
                        [  5560,   5584],
                        [  5696,   5739],
                        [  5764,   5822],
                        [  5769,   5839],
                        [  5713,   5789],
                        [  5605,   5683],
                        [  5452,   5526],
                        [  5257,   5321],
                        [  5029,   5080],
                        [  4774,   4806],
                        [  4496,   4504],
                        [  4205,   4184],
                        [  3902,   3850],
                        [  3593,   3507],
                        [  3285,   3161],
                        [  2982,   2817],
                        [  2687,   2480],
                        [  2404,   2153],
                        [  2135,   1840],
                        [  1886,   1545],
                        [  1655,   1270],
                        [  1445,   1016],
                        [  1258,    787],
                        [  1093,    580],
                        [   954,    401],
                        [   838,    249],
                        [   743,    120],
                        [   671,     19],
                        [   618,    -59],
                        [   579,   -113],
                        [   552,   -145],
                        [   530,   -155],
                        [   513,   -148],
                        [   498,   -123],
                        [   485,    -82],
                        [   477,    -31],
                        [   473,     33],
                        [   481,    105],
                        [   495,    181],
                        [   514,    262],
                        [   540,    346],
                        [   570,    429],
                        [   602,    509],
                        [   634,    586],
                        [   666,    658],
                        [   696,    722],
                        [   722,    777],
                        [   747,    825],
                        [   769,    865],
                        [   786,    894],
                        [   795,    911],
                        [   787,    905],
                        [   761,    878],
                        [   665,    775],
                        [   501,    601],
                        [   252,    339],
                        [   -79,    -10],
                        [  -475,   -426],
                        [  -935,   -910],
                        [ -1376,  -1377],
                        [ -1801,  -1830],
                        [ -2182,  -2240],
                        [ -2517,  -2607],
                        [ -2806,  -2927],
                        [ -3044,  -3197],
                        [ -3230,  -3417],
                        [ -3364,  -3585],
                        [ -3447,  -3702],
                        [ -3476,  -3764],
                        [ -3455,  -3775],
                        [ -3382,  -3734],
                        [ -3262,  -3646],
                        [ -3093,  -3506],
                        [ -2879,  -3321],
                        [ -2620,  -3088],
                        [ -2321,  -2814],
                        [ -1981,  -2495],
                        [ -1603,  -2139],
                        [ -1190,  -1743],
                        [  -746,  -1315],
                        [  -269,   -851],
                        [   233,   -358],
                        [   763,    163],
                        [  1315,    711],
                        [  1887,   1281],
                        [  2475,   1870],
                        [  3079,   2477],
                        [  3692,   3096],
                        [  4315,   3729],
                        [  4942,   4366],
                        [  5571,   5010],
                        [  6197,   5653],
                        [  6819,   6294],
                        [  7431,   6928],
                        [  8030,   7551],
                        [  8612,   8159],
                        [  9176,   8750],
                        [  9714,   9319],
                        [ 10222,   9858],
                        [ 10704,  10372],
                        [ 11149,  10850],
                        [ 11521,  11257],
                        [ 11789,  11559],
                        [ 11949,  11756],
                        [ 11999,  11842],
                        [ 11912,  11791],
                        [ 11637,  11554],
                        [ 11178,  11130],
                        [ 10607,  10595],
                        [  9973,   9995],
                        [  9276,   9333],
                        [  8532,   8621],
                        [  7759,   7880],
                        [  6968,   7119],
                        [  6171,   6351],
                        [  5380,   5588],
                        [  4604,   4838],
                        [  3855,   4107],
                        [  3140,   3404],
                        [  2465,   2731],
                        [  1836,   2091],
                        [  1260,   1493],
                        [   737,    935],
                        [   271,    428],
                        [  -135,    -26],
                        [  -482,   -418],
                        [  -769,   -747],
                        [  -997,  -1015],
                        [ -1168,  -1220],
                        [ -1280,  -1363],
                        [ -1339,  -1445],
                        [ -1346,  -1471],
                        [ -1304,  -1441],
                        [ -1215,  -1358],
                        [ -1083,  -1225],
                        [  -912,  -1047],
                        [  -703,   -825],
                        [  -462,   -564],
                        [  -188,   -267],
                        [   112,     61],
                        [   433,    418],
                        [   775,    798],
                        [  1133,   1198],
                        [  1501,   1614],
                        [  1880,   2045],
                        [  2264,   2483],
                        [  2650,   2926],
                        [  3036,   3370],
                        [  3416,   3811],
                        [  3790,   4247],
                        [  4154,   4674],
                        [  4508,   5087],
                        [  4851,   5485],
                        [  5185,   5863],
                        [  5509,   6220],
                        [  5820,   6551],
                        [  6119,   6856],
                        [  6398,   7131],
                        [  6657,   7375],
                        [  6884,   7585],
                        [  7077,   7758],
                        [  7233,   7895],
                        [  7349,   7994],
                        [  7423,   8054],
                        [  7456,   8075],
                        [  7446,   8055],
                        [  7391,   7995],
                        [  7294,   7894],
                        [  7154,   7754],
                        [  6974,   7576],
                        [  6749,   7356],
                        [  6485,   7099],
                        [  6184,   6807],
                        [  5850,   6484],
                        [  5484,   6131],
                        [  5131,   5790],
                        [  4787,   5461],
                        [  4498,   5186],
                        [  4262,   4964],
                        [  4089,   4804],
                        [  3980,   4707],
                        [  3886,   4626],
                        [  3813,   4563],
                        [  3699,   4458],
                        [  3548,   4314],
                        [  3358,   4130],
                        [  3134,   3910],
                        [  2874,   3651],
                        [  2579,   3356],
                        [  2255,   3029],
                        [  1902,   2672],
                        [  1527,   2290],
                        [  1131,   1887],
                        [   722,   1468],
                        [   297,   1033],
                        [  -131,    593],
                        [  -566,    145],
                        [  -998,   -300],
                        [ -1426,   -743],
                        [ -1846,  -1180],
                        [ -2257,  -1606],
                        [ -2654,  -2019],
                        [ -3034,  -2416],
                        [ -3395,  -2793],
                        [ -3738,  -3152],
                        [ -4058,  -3488],
                        [ -4357,  -3801],
                        [ -4630,  -4091],
                        [ -4881,  -4356],
                        [ -5107,  -4596],
                        [ -5308,  -4811],
                        [ -5485,  -5001],
                        [ -5640,  -5168],
                        [ -5769,  -5308],
                        [ -5875,  -5426],
                        [ -5960,  -5522],
                        [ -6021,  -5595],
                        [ -6062,  -5646],
                        [ -6080,  -5676],
                        [ -6080,  -5688],
                        [ -6059,  -5678],
                        [ -6016,  -5648],
                        [ -5956,  -5601],
                        [ -5874,  -5536],
                        [ -5753,  -5434],
                        [ -5589,  -5293],
                        [ -5393,  -5122],
                        [ -5164,  -4922],
                        [ -4876,  -4667],
                        [ -4482,  -4307],
                        [ -3959,  -3821],
                        [ -3354,  -3253],
                        [ -2698,  -2635],
                        [ -1994,  -1969],
                        [ -1254,  -1268],
                        [  -495,   -548],
                        [   271,    178],
                        [  1034,    902],
                        [  1785,   1614],
                        [  2514,   2305],
                        [  3213,   2969],
                        [  3875,   3604],
                        [  4496,   4207],
                        [  5072,   4775],
                        [  5599,   5303],
                        [  6075,   5793],
                        [  6502,   6244],
                        [  6878,   6645],
                        [  7202,   6996],
                        [  7479,   7300],
                        [  7711,   7554],
                        [  7898,   7761],
                        [  8047,   7926],
                        [  8160,   8049],
                        [  8240,   8136],
                        [  8291,   8189],
                        [  8317,   8214],
                        [  8320,   8211],
                        [  8307,   8188],
                        [  8279,   8146],
                        [  8240,   8088],
                        [  8192,   8019],
                        [  8138,   7942],
                        [  8080,   7859],
                        [  8020,   7772],
                        [  7962,   7685],
                        [  7902,   7596],
                        [  7846,   7510],
                        [  7793,   7427],
                        [  7742,   7347],
                        [  7692,   7270],
                        [  7645,   7198],
                        [  7601,   7131],
                        [  7557,   7067],
                        [  7512,   7005],
                        [  7461,   6947],
                        [  7404,   6890],
                        [  7333,   6832],
                        [  7251,   6775],
                        [  7152,   6716],
                        [  7038,   6654],
                        [  6913,   6589],
                        [  6773,   6518],
                        [  6628,   6440],
                        [  6476,   6355],
                        [  6319,   6264],
                        [  6154,   6163],
                        [  5985,   6054],
                        [  5812,   5937],
                        [  5635,   5809],
                        [  5454,   5674],
                        [  5272,   5528],
                        [  5086,   5372],
                        [  4903,   5212],
                        [  4722,   5047],
                        [  4542,   4876],
                        [  4362,   4696],
                        [  4171,   4499],
                        [  3968,   4284],
                        [  3707,   4003],
                        [  3394,   3664],
                        [  3013,   3252],
                        [  2567,   2770],
                        [  2067,   2230],
                        [  1511,   1631],
                        [   984,   1055],
                        [   479,    500],
                        [    24,     -7],
                        [  -378,   -463],
                        [  -721,   -862],
                        [ -1003,  -1200],
                        [ -1219,  -1472],
                        [ -1370,  -1679],
                        [ -1454,  -1818],
                        [ -1467,  -1885],
                        [ -1416,  -1887],
                        [ -1298,  -1819],
                        [ -1116,  -1687],
                        [  -873,  -1489],
                        [  -573,  -1230],
                        [  -215,   -912],
                        [   191,   -540],
                        [   647,   -117],
                        [  1143,    351],
                        [  1680,    864],
                        [  2247,   1410],
                        [  2846,   1991],
                        [  3466,   2599],
                        [  4105,   3229],
                        [  4758,   3876],
                        [  5419,   4535],
                        [  6082,   5201],
                        [  6745,   5869],
                        [  7398,   6530],
                        [  8042,   7187],
                        [  8668,   7826],
                        [  9273,   8449],
                        [  9853,   9049],
                        [ 10402,   9620],
                        [ 10919,  10160],
                        [ 11398,  10665],
                        [ 11835,  11129],
                        [ 12227,  11551],
                        [ 12572,  11925],
                        [ 12865,  12249],
                        [ 13104,  12521],
                        [ 13287,  12740],
                        [ 13414,  12907],
                        [ 13504,  13041],
                        [ 13574,  13160],
                        [ 13621,  13258],
                        [ 13623,  13314],
                        [ 13531,  13275],
                        [ 13302,  13098],
                        [ 12948,  12793],
                        [ 12488,  12377],
                        [ 11928,  11858],
                        [ 11286,  11253],
                        [ 10574,  10573],
                        [  9808,   9835],
                        [  8999,   9050],
                        [  8162,   8232],
                        [  7311,   7396],
                        [  6457,   6550],
                        [  5610,   5701],
                        [  4782,   4861],
                        [  3980,   4037],
                        [  3215,   3236],
                        [  2491,   2464],
                        [  1814,   1731],
                        [  1190,   1042],
                        [   623,    411],
                        [   113,   -164],
                        [  -335,   -674],
                        [  -723,  -1118],
                        [ -1050,  -1496],
                        [ -1316,  -1806],
                        [ -1525,  -2050],
                        [ -1677,  -2229],
                        [ -1775,  -2347],
                        [ -1822,  -2405],
                        [ -1822,  -2408],
                        [ -1778,  -2362],
                        [ -1695,  -2269],
                        [ -1575,  -2133],
                        [ -1425,  -1961],
                        [ -1249,  -1754],
                        [ -1051,  -1520],
                        [  -835,  -1264],
                        [  -605,   -989],
                        [  -367,   -702],
                        [  -126,   -407],
                        [   117,   -108],
                        [   355,    188],
                        [   586,    479],
                        [   806,    759],
                        [  1012,   1025],
                        [  1203,   1273],
                        [  1376,   1501],
                        [  1529,   1701],
                        [  1664,   1878],
                        [  1779,   2023],
                        [  1871,   2136],
                        [  1943,   2216],
                        [  1991,   2260],
                        [  2012,   2270],
                        [  2001,   2243],
                        [  1957,   2178],
                        [  1879,   2076],
                        [  1767,   1939],
                        [  1623,   1766],
                        [  1441,   1558],
                        [  1229,   1317],
                        [   984,   1047],
                        [   709,    746],
                        [   405,    419],
                        [    71,     63],
                        [  -286,   -314],
                        [  -665,   -710],
                        [ -1059,  -1119],
                        [ -1465,  -1538],
                        [ -1844,  -1928],
                        [ -2197,  -2290],
                        [ -2492,  -2591],
                        [ -2731,  -2834],
                        [ -2896,  -3002],
                        [ -2988,  -3096],
                        [ -3040,  -3148],
                        [ -3046,  -3153],
                        [ -3066,  -3170],
                        [ -3088,  -3189],
                        [ -3121,  -3218],
                        [ -3163,  -3256],
                        [ -3219,  -3306],
                        [ -3289,  -3371],
                        [ -3375,  -3451],
                        [ -3474,  -3543],
                        [ -3589,  -3651],
                        [ -3716,  -3772],
                        [ -3856,  -3905],
                        [ -4007,  -4049],
                        [ -4168,  -4201],
                        [ -4338,  -4362],
                        [ -4513,  -4529],
                        [ -4692,  -4700],
                        [ -4876,  -4874],
                        [ -5061,  -5050],
                        [ -5243,  -5222],
                        [ -5425,  -5394],
                        [ -5604,  -5563],
                        [ -5779,  -5727],
                        [ -5946,  -5884],
                        [ -6108,  -6035],
                        [ -6260,  -6177],
                        [ -6404,  -6311],
                        [ -6539,  -6434],
                        [ -6663,  -6549],
                        [ -6776,  -6652],
                        [ -6878,  -6745],
                        [ -6966,  -6823],
                        [ -7042,  -6892],
                        [ -7105,  -6947],
                        [ -7153,  -6988],
                        [ -7185,  -7015],
                        [ -7202,  -7028],
                        [ -7203,  -7027],
                        [ -7186,  -7009],
                        [ -7149,  -6975],
                        [ -7092,  -6923],
                        [ -7012,  -6855],
                        [ -6938,  -6799],
                        [ -6912,  -6799],
                        [ -6949,  -6871],
                        [ -7047,  -7009],
                        [ -7186,  -7197],
                        [ -7320,  -7380],
                        [ -7375,  -7485],
                        [ -7328,  -7486],
                        [ -7187,  -7393],
                        [ -6958,  -7209],
                        [ -6649,  -6942],
                        [ -6270,  -6603],
                        [ -5830,  -6201],
                        [ -5337,  -5744],
                        [ -4804,  -5241],
                        [ -4236,  -4700],
                        [ -3644,  -4132],
                        [ -3036,  -3538],
                        [ -2419,  -2929],
                        [ -1800,  -2309],
                        [ -1184,  -1684],
                        [  -577,  -1055],
                        [    15,   -429],
                        [   590,    185],
                        [  1146,    786],
                        [  1676,   1364],
                        [  2182,   1918],
                        [  2660,   2442],
                        [  3111,   2935],
                        [  3534,   3395],
                        [  3928,   3821],
                        [  4295,   4214],
                        [  4632,   4576],
                        [  4942,   4908],
                        [  5227,   5212],
                        [  5484,   5487],
                        [  5715,   5734],
                        [  5922,   5955],
                        [  6104,   6151],
                        [  6262,   6320],
                        [  6397,   6464],
                        [  6509,   6585],
                        [  6599,   6684],
                        [  6667,   6759],
                        [  6714,   6812],
                        [  6738,   6844],
                        [  6741,   6853],
                        [  6723,   6842],
                        [  6684,   6810],
                        [  6622,   6758],
                        [  6541,   6686],
                        [  6437,   6594],
                        [  6311,   6482],
                        [  6164,   6351],
                        [  5995,   6202],
                        [  5802,   6034],
                        [  5584,   5849],
                        [  5343,   5647],
                        [  5078,   5430],
                        [  4795,   5196],
                        [  4495,   4949],
                        [  4180,   4688],
                        [  3855,   4417],
                        [  3522,   4135],
                        [  3180,   3843],
                        [  2836,   3543],
                        [  2491,   3239],
                        [  2146,   2931],
                        [  1805,   2620],
                        [  1475,   2315],
                        [  1155,   2012],
                        [   845,   1713],
                        [   548,   1419],
                        [   254,   1123],
                        [   -36,    825],
                        [  -348,    497],
                        [  -678,    145],
                        [ -1037,   -240],
                        [ -1419,   -654],
                        [ -1831,  -1104],
                        [ -2271,  -1587],
                        [ -2684,  -2045],
                        [ -3071,  -2481],
                        [ -3413,  -2874],
                        [ -3708,  -3223],
                        [ -3948,  -3517],
                        [ -4130,  -3756],
                        [ -4250,  -3932],
                        [ -4310,  -4047],
                        [ -4304,  -4097],
                        [ -4235,  -4082],
                        [ -4102,  -4002],
                        [ -3907,  -3859],
                        [ -3655,  -3655],
                        [ -3346,  -3393],
                        [ -2984,  -3076],
                        [ -2574,  -2707],
                        [ -2121,  -2294],
                        [ -1631,  -1838],
                        [ -1107,  -1347],
                        [  -556,   -826],
                        [    15,   -280],
                        [   603,    285],
                        [  1198,    860],
                        [  1797,   1443],
                        [  2392,   2025],
                        [  2979,   2602],
                        [  3551,   3167],
                        [  4104,   3714],
                        [  4631,   4238],
                        [  5130,   4737],
                        [  5592,   5201],
                        [  6018,   5630],
                        [  6400,   6016],
                        [  6736,   6359],
                        [  7024,   6653],
                        [  7260,   6897],
                        [  7443,   7089],
                        [  7569,   7226],
                        [  7639,   7305],
                        [  7652,   7330],
                        [  7602,   7295],
                        [  7495,   7207],
                        [  7389,   7125],
                        [  7339,   7106],
                        [  7363,   7168],
                        [  7461,   7310],
                        [  7629,   7524],
                        [  7814,   7755],
                        [  7927,   7910],
                        [  7916,   7937],
                        [  7789,   7844],
                        [  7554,   7638],
                        [  7218,   7326],
                        [  6796,   6922],
                        [  6296,   6436],
                        [  5731,   5877],
                        [  5111,   5260],
                        [  4450,   4596],
                        [  3759,   3895],
                        [  3049,   3170],
                        [  2331,   2432],
                        [  1614,   1688],
                        [   906,    947],
                        [   215,    216],
                        [  -450,   -499],
                        [ -1083,  -1190],
                        [ -1680,  -1848],
                        [ -2237,  -2471],
                        [ -2750,  -3046],
                        [ -3219,  -3574],
                        [ -3639,  -4049],
                        [ -4014,  -4470],
                        [ -4341,  -4837],
                        [ -4623,  -5150],
                        [ -4860,  -5413],
                        [ -5055,  -5629],
                        [ -5213,  -5803],
                        [ -5334,  -5937],
                        [ -5423,  -6034],
                        [ -5484,  -6098],
                        [ -5519,  -6134],
                        [ -5534,  -6143],
                        [ -5532,  -6133],
                        [ -5517,  -6106],
                        [ -5493,  -6067],
                        [ -5464,  -6021],
                        [ -5435,  -5971],
                        [ -5408,  -5922],
                        [ -5385,  -5876],
                        [ -5372,  -5839],
                        [ -5371,  -5813],
                        [ -5381,  -5798],
                        [ -5409,  -5802],
                        [ -5454,  -5823],
                        [ -5521,  -5865],
                        [ -5612,  -5929],
                        [ -5725,  -6015],
                        [ -5861,  -6125],
                        [ -6013,  -6260],
                        [ -6180,  -6417],
                        [ -6359,  -6598],
                        [ -6554,  -6801],
                        [ -6762,  -7027],
                        [ -6982,  -7272],
                        [ -7215,  -7534],
                        [ -7460,  -7815],
                        [ -7715,  -8108],
                        [ -7979,  -8413],
                        [ -8250,  -8727],
                        [ -8526,  -9046],
                        [ -8806,  -9369],
                        [ -9091,  -9696],
                        [ -9375, -10021],
                        [ -9655, -10340],
                        [ -9926, -10648],
                        [-10187, -10942],
                        [-10415, -11201],
                        [-10612, -11424],
                        [-10766, -11600],
                        [-10875, -11728],
                        [-10920, -11789],
                        [-10901, -11781],
                        [-10827, -11715],
                        [-10698, -11590],
                        [-10545, -11437],
                        [-10369, -11256],
                        [-10176, -11055],
                        [ -9967, -10835],
                        [ -9752, -10607],
                        [ -9531, -10369],
                        [ -9313, -10131],
                        [ -9096,  -9892],
                        [ -8886,  -9657],
                        [ -8684,  -9428],
                        [ -8495,  -9209],
                        [ -8317,  -9000],
                        [ -8153,  -8804],
                        [ -8004,  -8620],
                        [ -7871,  -8451],
                        [ -7754,  -8297],
                        [ -7652,  -8158],
                        [ -7568,  -8033],
                        [ -7497,  -7923],
                        [ -7441,  -7828],
                        [ -7398,  -7746],
                        [ -7369,  -7676],
                        [ -7349,  -7617],
                        [ -7340,  -7570],
                        [ -7340,  -7532],
                        [ -7347,  -7502],
                        [ -7357,  -7477],
                        [ -7373,  -7458],
                        [ -7390,  -7441],
                        [ -7406,  -7426],
                        [ -7420,  -7410],
                        [ -7431,  -7395],
                        [ -7434,  -7372],
                        [ -7430,  -7345],
                        [ -7416,  -7309],
                        [ -7390,  -7265],
                        [ -7347,  -7207],
                        [ -7291,  -7138],
                        [ -7215,  -7053],
                        [ -7113,  -6948],
                        [ -6997,  -6838],
                        [ -6946,  -6801],
                        [ -7019,  -6897],
                        [ -7231,  -7141],
                        [ -7581,  -7530],
                        [ -8062,  -8060],
                        [ -8627,  -8674],
                        [ -9152,  -9249],
                        [ -9566,  -9710],
                        [ -9864, -10054],
                        [-10052, -10285],
                        [-10132, -10405],
                        [-10108, -10415],
                        [ -9983, -10323],
                        [ -9765, -10131],
                        [ -9462,  -9849],
                        [ -9082,  -9486],
                        [ -8632,  -9046],
                        [ -8121,  -8541],
                        [ -7557,  -7981],
                        [ -6949,  -7373],
                        [ -6304,  -6724],
                        [ -5633,  -6039],
                        [ -4939,  -5325],
                        [ -4235,  -4588],
                        [ -3525,  -3836],
                        [ -2815,  -3077],
                        [ -2111,  -2319],
                        [ -1419,  -1571],
                        [  -743,   -840],
                        [   -89,   -132],
                        [   544,    551],
                        [  1146,   1203],
                        [  1719,   1824],
                        [  2258,   2412],
                        [  2762,   2966],
                        [  3229,   3485],
                        [  3659,   3967],
                        [  4047,   4408],
                        [  4396,   4809],
                        [  4704,   5169],
                        [  4970,   5488],
                        [  5196,   5766],
                        [  5380,   6000],
                        [  5523,   6193],
                        [  5626,   6346],
                        [  5689,   6457],
                        [  5714,   6529],
                        [  5701,   6562],
                        [  5653,   6558],
                        [  5569,   6517],
                        [  5453,   6442],
                        [  5311,   6335],
                        [  5144,   6196],
                        [  4957,   6029],
                        [  4753,   5834],
                        [  4531,   5615],
                        [  4288,   5373],
                        [  4021,   5111],
                        [  3733,   4833],
                        [  3424,   4539],
                        [  3096,   4232],
                        [  2756,   3916],
                        [  2404,   3593],
                        [  2047,   3264],
                        [  1686,   2934],
                        [  1327,   2604],
                        [   972,   2277],
                        [   624,   1957],
                        [   287,   1645],
                        [   -34,   1344],
                        [  -340,   1055],
                        [  -626,    781],
                        [  -894,    522],
                        [ -1145,    275],
                        [ -1375,     43],
                        [ -1587,   -175],
                        [ -1782,   -380],
                        [ -1961,   -574],
                        [ -2127,   -761],
                        [ -2303,   -960],
                        [ -2484,  -1170],
                        [ -2656,  -1374],
                        [ -2819,  -1572],
                        [ -2961,  -1753],
                        [ -3083,  -1915],
                        [ -3174,  -2049],
                        [ -3239,  -2157],
                        [ -3267,  -2230],
                        [ -3265,  -2273],
                        [ -3223,  -2277],
                        [ -3146,  -2245],
                        [ -3032,  -2178],
                        [ -2883,  -2073],
                        [ -2699,  -1933],
                        [ -2484,  -1761],
                        [ -2240,  -1558],
                        [ -1970,  -1328],
                        [ -1677,  -1073],
                        [ -1366,   -799],
                        [ -1040,   -509],
                        [  -704,   -206],
                        [  -364,    102],
                        [   -22,    414],
                        [   314,    724],
                        [   644,   1027],
                        [   960,   1319],
                        [  1259,   1594],
                        [  1536,   1850],
                        [  1790,   2084],
                        [  2014,   2289],
                        [  2207,   2464],
                        [  2365,   2605],
                        [  2488,   2711],
                        [  2571,   2778],
                        [  2613,   2806],
                        [  2615,   2793],
                        [  2576,   2739],
                        [  2493,   2641],
                        [  2368,   2503],
                        [  2203,   2324],
                        [  1996,   2105],
                        [  1740,   1841],
                        [  1469,   1565],
                        [  1275,   1371],
                        [  1224,   1325],
                        [  1329,   1443],
                        [  1597,   1729],
                        [  2039,   2191],
                        [  2602,   2777],
                        [  3152,   3348],
                        [  3603,   3816],
                        [  3959,   4187],
                        [  4223,   4463],
                        [  4396,   4643],
                        [  4479,   4731],
                        [  4482,   4732],
                        [  4407,   4652],
                        [  4262,   4497],
                        [  4055,   4276],
                        [  3794,   4000],
                        [  3485,   3674],
                        [  3137,   3313],
                        [  2760,   2923],
                        [  2357,   2510],
                        [  1937,   2080],
                        [  1507,   1633],
                        [  1072,   1177],
                        [   638,    713],
                        [   210,    249],
                        [  -210,   -209],
                        [  -618,   -656],
                        [ -1008,  -1086],
                        [ -1384,  -1499],
                        [ -1742,  -1890],
                        [ -2080,  -2259],
                        [ -2401,  -2608],
                        [ -2704,  -2937],
                        [ -2990,  -3251],
                        [ -3261,  -3549],
                        [ -3519,  -3833],
                        [ -3766,  -4104],
                        [ -4002,  -4363],
                        [ -4232,  -4614],
                        [ -4454,  -4857],
                        [ -4674,  -5096],
                        [ -4890,  -5331],
                        [ -5107,  -5565],
                        [ -5324,  -5800],
                        [ -5544,  -6036],
                        [ -5768,  -6276],
                        [ -5997,  -6522],
                        [ -6231,  -6772],
                        [ -6472,  -7030],
                        [ -6721,  -7293],
                        [ -6982,  -7565],
                        [ -7259,  -7843],
                        [ -7553,  -8127],
                        [ -7863,  -8418],
                        [ -8187,  -8713],
                        [ -8513,  -9011],
                        [ -8842,  -9314],
                        [ -9160,  -9614],
                        [ -9466,  -9914],
                        [ -9758, -10212],
                        [-10036, -10503],
                        [-10296, -10786],
                        [-10538, -11061],
                        [-10761, -11321],
                        [-10964, -11568],
                        [-11145, -11797],
                        [-11303, -12007],
                        [-11438, -12195],
                        [-11550, -12362],
                        [-11637, -12504],
                        [-11694, -12617],
                        [-11726, -12702],
                        [-11728, -12756],
                        [-11710, -12786],
                        [-11668, -12790],
                        [-11610, -12774],
                        [-11538, -12739],
                        [-11428, -12662],
                        [-11282, -12544],
                        [-11078, -12363],
                        [-10818, -12120],
                        [-10515, -11828],
                        [-10166, -11486],
                        [ -9786, -11106],
                        [ -9373, -10688],
                        [ -8940, -10247],
                        [ -8488,  -9781],
                        [ -8029,  -9303],
                        [ -7564,  -8816],
                        [ -7101,  -8325],
                        [ -6642,  -7834],
                        [ -6195,  -7352],
                        [ -5761,  -6879],
                        [ -5345,  -6422],
                        [ -4947,  -5980],
                        [ -4573,  -5560],
                        [ -4223,  -5160],
                        [ -3898,  -4785],
                        [ -3599,  -4435],
                        [ -3324,  -4108],
                        [ -3077,  -3807],
                        [ -2854,  -3531],
                        [ -2654,  -3279],
                        [ -2477,  -3049],
                        [ -2321,  -2842],
                        [ -2182,  -2654],
                        [ -2061,  -2484],
                        [ -1955,  -2329],
                        [ -1861,  -2190],
                        [ -1773,  -2059],
                        [ -1692,  -1937],
                        [ -1616,  -1822],
                        [ -1540,  -1710],
                        [ -1458,  -1596],
                        [ -1375,  -1482],
                        [ -1282,  -1363],
                        [ -1180,  -1237],
                        [ -1063,  -1099],
                        [  -934,   -951],
                        [  -787,   -791],
                        [  -611,   -606],
                        [  -448,   -440],
                        [  -397,   -392],
                        [  -514,   -518],
                        [  -807,   -828],
                        [ -1281,  -1326],
                        [ -1950,  -2025],
                        [ -2763,  -2869],
                        [ -3565,  -3706],
                        [ -4267,  -4440],
                        [ -4865,  -5070],
                        [ -5361,  -5596],
                        [ -5747,  -6009],
                        [ -6023,  -6309],
                        [ -6189,  -6494],
                        [ -6249,  -6567],
                        [ -6205,  -6533],
                        [ -6065,  -6396],
                        [ -5833,  -6165],
                        [ -5517,  -5852],
                        [ -5124,  -5464],
                        [ -4665,  -5012],
                        [ -4144,  -4503],
                        [ -3572,  -3941],
                        [ -2957,  -3335],
                        [ -2310,  -2685],
                        [ -1636,  -2001],
                        [  -947,  -1290],
                        [  -250,   -561],
                        [   446,    175],
                        [  1135,    911],
                        [  1809,   1636],
                        [  2461,   2347],
                        [  3087,   3033],
                        [  3681,   3692],
                        [  4242,   4321],
                        [  4764,   4916],
                        [  5246,   5475],
                        [  5685,   5994],
                        [  6080,   6471],
                        [  6429,   6901],
                        [  6731,   7287],
                        [  6987,   7628],
                        [  7195,   7919],
                        [  7357,   8165],
                        [  7473,   8363],
                        [  7546,   8517],
                        [  7574,   8625],
                        [  7562,   8689],
                        [  7511,   8712],
                        [  7422,   8697],
                        [  7302,   8644],
                        [  7151,   8557],
                        [  6983,   8439],
                        [  6800,   8292],
                        [  6610,   8118],
                        [  6417,   7921],
                        [  6221,   7706],
                        [  6021,   7473],
                        [  5809,   7228],
                        [  5586,   6972],
                        [  5349,   6710],
                        [  5103,   6443],
                        [  4849,   6175],
                        [  4591,   5909],
                        [  4332,   5647],
                        [  4076,   5390],
                        [  3824,   5144],
                        [  3582,   4909],
                        [  3349,   4686],
                        [  3131,   4478],
                        [  2927,   4287],
                        [  2742,   4114],
                        [  2576,   3958],
                        [  2429,   3820],
                        [  2312,   3712],
                        [  2225,   3634],
                        [  2191,   3606],
                        [  2212,   3629],
                        [  2278,   3696],
                        [  2392,   3808],
                        [  2512,   3924],
                        [  2640,   4045],
                        [  2751,   4146],
                        [  2846,   4229],
                        [  2931,   4301],
                        [  3002,   4357],
                        [  3067,   4405],
                        [  3124,   4444],
                        [  3178,   4479],
                        [  3226,   4508],
                        [  3275,   4535],
                        [  3322,   4559],
                        [  3370,   4583],
                        [  3419,   4607],
                        [  3469,   4630],
                        [  3518,   4652],
                        [  3569,   4674],
                        [  3616,   4692],
                        [  3662,   4708],
                        [  3704,   4720],
                        [  3741,   4725],
                        [  3769,   4722],
                        [  3789,   4710],
                        [  3798,   4687],
                        [  3793,   4649],
                        [  3775,   4598],
                        [  3741,   4530],
                        [  3687,   4443],
                        [  3616,   4337],
                        [  3525,   4212],
                        [  3411,   4063],
                        [  3277,   3894],
                        [  3120,   3702],
                        [  2942,   3488],
                        [  2741,   3250],
                        [  2519,   2992],
                        [  2277,   2714],
                        [  2016,   2416],
                        [  1736,   2099],
                        [  1439,   1765],
                        [  1129,   1419],
                        [   808,   1062],
                        [   468,    687],
                        [   165,    349],
                        [     2,    154],
                        [    29,    150],
                        [   252,    346],
                        [   686,    759],
                        [  1354,   1410],
                        [  2208,   2249],
                        [  3095,   3124],
                        [  3924,   3942],
                        [  4697,   4704],
                        [  5412,   5410],
                        [  6059,   6046],
                        [  6632,   6607],
                        [  7131,   7094],
                        [  7555,   7504],
                        [  7903,   7837],
                        [  8178,   8095],
                        [  8379,   8286],
                        [  8513,   8413],
                        [  8579,   8484],
                        [  8585,   8506],
                        [  8531,   8478],
                        [  8422,   8408],
                        [  8263,   8288],
                        [  8058,   8123],
                        [  7811,   7910],
                        [  7528,   7655],
                        [  7213,   7359],
                        [  6871,   7030],
                        [  6507,   6671],
                        [  6124,   6286],
                        [  5725,   5881],
                        [  5314,   5457],
                        [  4893,   5020],
                        [  4462,   4569],
                        [  4024,   4104],
                        [  3577,   3627],
                        [  3124,   3142],
                        [  2666,   2649],
                        [  2205,   2149],
                        [  1741,   1645],
                        [  1275,   1135],
                        [   808,    622],
                        [   341,    109],
                        [  -124,   -406],
                        [  -587,   -921],
                        [ -1047,  -1432],
                        [ -1502,  -1940],
                        [ -1949,  -2444],
                        [ -2389,  -2941],
                        [ -2820,  -3430],
                        [ -3245,  -3908],
                        [ -3665,  -4376],
                        [ -4088,  -4829],
                        [ -4510,  -5267],
                        [ -4933,  -5688],
                        [ -5354,  -6088],
                        [ -5757,  -6467],
                        [ -6147,  -6823],
                        [ -6500,  -7153],
                        [ -6819,  -7456],
                        [ -7096,  -7729],
                        [ -7334,  -7973],
                        [ -7529,  -8183],
                        [ -7681,  -8358],
                        [ -7789,  -8498],
                        [ -7851,  -8601],
                        [ -7872,  -8667],
                        [ -7848,  -8695],
                        [ -7781,  -8683],
                        [ -7671,  -8632],
                        [ -7521,  -8543],
                        [ -7332,  -8416],
                        [ -7109,  -8254],
                        [ -6853,  -8060],
                        [ -6600,  -7867],
                        [ -6350,  -7675],
                        [ -6121,  -7501],
                        [ -5916,  -7345],
                        [ -5711,  -7187],
                        [ -5511,  -7027],
                        [ -5262,  -6812],
                        [ -4968,  -6549],
                        [ -4625,  -6232],
                        [ -4234,  -5860],
                        [ -3804,  -5445],
                        [ -3339,  -4991],
                        [ -2847,  -4505],
                        [ -2331,  -3990],
                        [ -1803,  -3459],
                        [ -1263,  -2909],
                        [  -723,  -2354],
                        [  -182,  -1792],
                        [   350,  -1235],
                        [   873,   -683],
                        [  1378,   -145],
                        [  1865,    381],
                        [  2330,    887],
                        [  2774,   1376],
                        [  3192,   1840],
                        [  3584,   2280],
                        [  3950,   2696],
                        [  4288,   3086],
                        [  4604,   3452],
                        [  4894,   3794],
                        [  5161,   4111],
                        [  5406,   4407],
                        [  5632,   4682],
                        [  5842,   4940],
                        [  6037,   5182],
                        [  6221,   5410],
                        [  6396,   5627],
                        [  6563,   5835],
                        [  6728,   6037],
                        [  6890,   6235],
                        [  7054,   6433],
                        [  7222,   6629],
                        [  7395,   6831],
                        [  7577,   7037],
                        [  7768,   7251],
                        [  7966,   7469],
                        [  8175,   7698],
                        [  8403,   7942],
                        [  8589,   8146],
                        [  8642,   8217],
                        [  8527,   8119],
                        [  8242,   7850],
                        [  7773,   7391],
                        [  7089,   6712],
                        [  6236,   5862],
                        [  5363,   4988],
                        [  4550,   4175],
                        [  3798,   3420],
                        [  3111,   2732],
                        [  2503,   2122],
                        [  1977,   1598],
                        [  1537,   1164],
                        [  1185,    820],
                        [   922,    569],
                        [   746,    404],
                        [   653,    326],
                        [   641,    319],
                        [   704,    380],
                        [   836,    500],
                        [  1033,    671],
                        [  1286,    894],
                        [  1591,   1159],
                        [  1937,   1473],
                        [  2319,   1827],
                        [  2727,   2218],
                        [  3153,   2639],
                        [  3585,   3083],
                        [  4018,   3542],
                        [  4445,   4007],
                        [  4859,   4474],
                        [  5253,   4929],
                        [  5625,   5372],
                        [  5970,   5794],
                        [  6285,   6192],
                        [  6568,   6563],
                        [  6819,   6905],
                        [  7034,   7213],
                        [  7212,   7488],
                        [  7356,   7727],
                        [  7461,   7929],
                        [  7531,   8096],
                        [  7567,   8226],
                        [  7567,   8318],
                        [  7537,   8379],
                        [  7477,   8407],
                        [  7387,   8401],
                        [  7274,   8369],
                        [  7137,   8309],
                        [  6983,   8225],
                        [  6814,   8120],
                        [  6645,   7997],
                        [  6478,   7857],
                        [  6323,   7704],
                        [  6183,   7542],
                        [  6058,   7373],
                        [  5950,   7199],
                        [  5845,   7023],
                        [  5744,   6848],
                        [  5640,   6676],
                        [  5536,   6509],
                        [  5434,   6351],
                        [  5332,   6199],
                        [  5233,   6059],
                        [  5139,   5930],
                        [  5050,   5814],
                        [  4968,   5712],
                        [  4892,   5623],
                        [  4825,   5549],
                        [  4766,   5487],
                        [  4716,   5439],
                        [  4675,   5406],
                        [  4643,   5385],
                        [  4648,   5403],
                        [  4684,   5456],
                        [  4793,   5584],
                        [  4970,   5781],
                        [  5211,   6043],
                        [  5516,   6370],
                        [  5829,   6705],
                        [  6152,   7051],
                        [  6431,   7352],
                        [  6667,   7612],
                        [  6862,   7829],
                        [  7011,   8002],
                        [  7118,   8132],
                        [  7181,   8218],
                        [  7205,   8264],
                        [  7187,   8267],
                        [  7134,   8232],
                        [  7043,   8157],
                        [  6921,   8048],
                        [  6766,   7902],
                        [  6585,   7726],
                        [  6373,   7517],
                        [  6139,   7282],
                        [  5881,   7018],
                        [  5602,   6732],
                        [  5303,   6420],
                        [  4988,   6089],
                        [  4656,   5737],
                        [  4310,   5369],
                        [  3950,   4983],
                        [  3579,   4583],
                        [  3196,   4170],
                        [  2806,   3745],
                        [  2408,   3311],
                        [  2004,   2867],
                        [  1596,   2417],
                        [  1185,   1963],
                        [   771,   1504],
                        [   359,   1046],
                        [   -50,    589],
                        [  -458,    132],
                        [  -859,   -319],
                        [ -1251,   -761],
                        [ -1634,  -1194],
                        [ -2007,  -1617],
                        [ -2364,  -2026],
                        [ -2702,  -2414],
                        [ -3023,  -2786],
                        [ -3325,  -3143],
                        [ -3547,  -3422],
                        [ -3612,  -3547],
                        [ -3495,  -3492],
                        [ -3200,  -3257],
                        [ -2702,  -2817],
                        [ -1972,  -2135],
                        [ -1044,  -1250],
                        [   -52,   -295],
                        [   932,    658],
                        [  1907,   1608],
                        [  2863,   2544],
                        [  3782,   3447],
                        [  4654,   4306],
                        [  5471,   5115],
                        [  6226,   5865],
                        [  6912,   6548],
                        [  7525,   7161],
                        [  8058,   7707],
                        [  8514,   8183],
                        [  8889,   8595],
                        [  9182,   8944],
                        [  9393,   9229],
                        [  9523,   9453],
                        [  9575,   9604],
                        [  9549,   9689],
                        [  9453,   9695],
                        [  9288,   9627],
                        [  9061,   9485],
                        [  8776,   9271],
                        [  8442,   8991],
                        [  8062,   8647],
                        [  7642,   8249],
                        [  7187,   7800],
                        [  6700,   7309],
                        [  6186,   6782],
                        [  5649,   6224],
                        [  5091,   5637],
                        [  4518,   5028],
                        [  3930,   4399],
                        [  3335,   3756],
                        [  2735,   3102],
                        [  2131,   2442],
                        [  1529,   1777],
                        [   934,   1116],
                        [   345,    457],
                        [  -232,   -193],
                        [  -795,   -834],
                        [ -1340,  -1458],
                        [ -1866,  -2065],
                        [ -2370,  -2651],
                        [ -2850,  -3214],
                        [ -3310,  -3750],
                        [ -3749,  -4257],
                        [ -4173,  -4731],
                        [ -4582,  -5174],
                        [ -4976,  -5579],
                        [ -5354,  -5948],
                        [ -5705,  -6277],
                        [ -6030,  -6567],
                        [ -6307,  -6813],
                        [ -6541,  -7018],
                        [ -6723,  -7178],
                        [ -6855,  -7295],
                        [ -6935,  -7368],
                        [ -6962,  -7396],
                        [ -6940,  -7382],
                        [ -6867,  -7324],
                        [ -6748,  -7225],
                        [ -6581,  -7085],
                        [ -6369,  -6904],
                        [ -6112,  -6683],
                        [ -5819,  -6428],
                        [ -5488,  -6138],
                        [ -5136,  -5828],
                        [ -4762,  -5499],
                        [ -4424,  -5205],
                        [ -4120,  -4944],
                        [ -3872,  -4739],
                        [ -3682,  -4589],
                        [ -3534,  -4478],
                        [ -3429,  -4408],
                        [ -3292,  -4303],
                        [ -3129,  -4169],
                        [ -2924,  -3990],
                        [ -2678,  -3768],
                        [ -2396,  -3509],
                        [ -2081,  -3213],
                        [ -1737,  -2888],
                        [ -1367,  -2533],
                        [  -980,  -2156],
                        [  -574,  -1758],
                        [  -158,  -1347],
                        [   266,   -922],
                        [   693,   -492],
                        [  1121,    -57],
                        [  1545,    378],
                        [  1965,    811],
                        [  2374,   1237],
                        [  2775,   1656],
                        [  3161,   2065],
                        [  3537,   2463],
                        [  3898,   2849],
                        [  4245,   3223],
                        [  4578,   3585],
                        [  4899,   3934],
                        [  5208,   4270],
                        [  5506,   4596],
                        [  5796,   4911],
                        [  6076,   5216],
                        [  6349,   5514],
                        [  6616,   5804],
                        [  6881,   6090],
                        [  7141,   6370],
                        [  7399,   6647],
                        [  7658,   6923],
                        [  7916,   7197],
                        [  8174,   7469],
                        [  8433,   7742],
                        [  8694,   8015],
                        [  8955,   8289],
                        [  9210,   8557],
                        [  9463,   8829],
                        [  9712,   9100],
                        [  9898,   9318],
                        [  9969,   9427],
                        [  9917,   9419],
                        [  9739,   9288],
                        [  9415,   9008],
                        [  8901,   8537],
                        [  8223,   7897],
                        [  7487,   7196],
                        [  6750,   6490],
                        [  6010,   5780],
                        [  5276,   5074],
                        [  4565,   4390],
                        [  3885,   3737],
                        [  3241,   3119],
                        [  2640,   2545],
                        [  2087,   2019],
                        [  1584,   1541],
                        [  1135,   1115],
                        [   738,    728],
                        [   396,    385],
                        [   106,     76],
                        [  -135,   -199],
                        [  -326,   -439],
                        [  -472,   -649],
                        [  -578,   -820],
                        [  -645,   -954],
                        [  -683,  -1047],
                        [  -696,  -1103],
                        [  -690,  -1123],
                        [  -671,  -1112],
                        [  -644,  -1075],
                        [  -614,  -1016],
                        [  -585,   -945],
                        [  -560,   -865],
                        [  -540,   -786],
                        [  -531,   -710],
                        [  -531,   -640],
                        [  -542,   -579],
                        [  -564,   -526],
                        [  -599,   -484],
                        [  -646,   -454],
                        [  -705,   -436],
                        [  -776,   -430],
                        [  -856,   -436],
                        [  -946,   -452],
                        [ -1045,   -479],
                        [ -1148,   -514],
                        [ -1257,   -558],
                        [ -1368,   -608],
                        [ -1480,   -661],
                        [ -1589,   -719],
                        [ -1692,   -778],
                        [ -1778,   -835],
                        [ -1846,   -893],
                        [ -1886,   -946],
                        [ -1899,   -994],
                        [ -1884,  -1036],
                        [ -1840,  -1071],
                        [ -1779,  -1097],
                        [ -1702,  -1114],
                        [ -1620,  -1122],
                        [ -1531,  -1120],
                        [ -1438,  -1107],
                        [ -1342,  -1085],
                        [ -1246,  -1052],
                        [ -1146,  -1010],
                        [ -1049,   -959],
                        [  -952,   -900],
                        [  -858,   -835],
                        [  -768,   -765],
                        [  -684,   -692],
                        [  -606,   -617],
                        [  -532,   -538],
                        [  -466,   -457],
                        [  -368,   -340],
                        [  -242,   -188],
                        [   -50,     37],
                        [   210,    332],
                        [   531,    695],
                        [   917,   1125],
                        [  1307,   1562],
                        [  1703,   2007],
                        [  2038,   2393],
                        [  2314,   2724],
                        [  2529,   2992],
                        [  2680,   3200],
                        [  2768,   3345],
                        [  2791,   3425],
                        [  2751,   3443],
                        [  2649,   3396],
                        [  2490,   3291],
                        [  2273,   3124],
                        [  2006,   2902],
                        [  1688,   2626],
                        [  1326,   2302],
                        [   922,   1930],
                        [   484,   1519],
                        [    12,   1068],
                        [  -483,    586],
                        [ -1004,     74],
                        [ -1540,   -460],
                        [ -2090,  -1013],
                        [ -2648,  -1581],
                        [ -3211,  -2159],
                        [ -3774,  -2741],
                        [ -4336,  -3326],
                        [ -4891,  -3907],
                        [ -5437,  -4483],
                        [ -5970,  -5048],
                        [ -6485,  -5598],
                        [ -6983,  -6132],
                        [ -7458,  -6645],
                        [ -7906,  -7134],
                        [ -8329,  -7597],
                        [ -8723,  -8032],
                        [ -9085,  -8435],
                        [ -9414,  -8806],
                        [ -9706,  -9139],
                        [ -9964,  -9437],
                        [-10183,  -9696],
                        [-10358,  -9913],
                        [-10492, -10093],
                        [-10575, -10229],
                        [-10569, -10285],
                        [-10449, -10231],
                        [-10214, -10070],
                        [ -9873,  -9800],
                        [ -9395,  -9393],
                        [ -8747,  -8806],
                        [ -7937,  -8046],
                        [ -7044,  -7197],
                        [ -6114,  -6303],
                        [ -5153,  -5368],
                        [ -4175,  -4408],
                        [ -3199,  -3443],
                        [ -2240,  -2488],
                        [ -1308,  -1554],
                        [  -418,   -656],
                        [   423,    199],
                        [  1203,    999],
                        [  1915,   1742],
                        [  2555,   2425],
                        [  3114,   3045],
                        [  3591,   3603],
                        [  3983,   4093],
                        [  4286,   4517],
                        [  4504,   4864],
                        [  4634,   5137],
                        [  4682,   5322],
                        [  4647,   5420],
                        [  4537,   5428],
                        [  4357,   5351],
                        [  4114,   5186],
                        [  3811,   4939],
                        [  3456,   4619],
                        [  3053,   4231],
                        [  2610,   3790],
                        [  2132,   3299],
                        [  1627,   2771],
                        [  1098,   2212],
                        [   550,   1624],
                        [   -10,   1016],
                        [  -574,    396],
                        [ -1143,   -236],
                        [ -1708,   -869],
                        [ -2264,  -1500],
                        [ -2808,  -2123],
                        [ -3336,  -2735],
                        [ -3843,  -3328],
                        [ -4326,  -3901],
                        [ -4782,  -4449],
                        [ -5207,  -4968],
                        [ -5600,  -5454],
                        [ -5959,  -5907],
                        [ -6286,  -6320],
                        [ -6582,  -6694],
                        [ -6852,  -7027],
                        [ -7094,  -7316],
                        [ -7313,  -7561],
                        [ -7508,  -7762],
                        [ -7673,  -7916],
                        [ -7807,  -8024],
                        [ -7901,  -8088],
                        [ -7954,  -8108],
                        [ -7961,  -8084],
                        [ -7924,  -8017],
                        [ -7844,  -7910],
                        [ -7720,  -7763],
                        [ -7555,  -7580],
                        [ -7351,  -7362],
                        [ -7111,  -7113],
                        [ -6836,  -6834],
                        [ -6528,  -6526],
                        [ -6189,  -6192],
                        [ -5826,  -5838],
                        [ -5442,  -5467],
                        [ -5055,  -5097],
                        [ -4669,  -4730],
                        [ -4340,  -4424],
                        [ -4068,  -4178],
                        [ -3874,  -4011],
                        [ -3757,  -3922],
                        [ -3707,  -3902],
                        [ -3728,  -3954],
                        [ -3735,  -3992],
                        [ -3737,  -4026],
                        [ -3711,  -4032],
                        [ -3657,  -4012],
                        [ -3575,  -3965],
                        [ -3465,  -3890],
                        [ -3327,  -3789],
                        [ -3162,  -3661],
                        [ -2972,  -3508],
                        [ -2757,  -3330],
                        [ -2520,  -3129],
                        [ -2262,  -2906],
                        [ -1987,  -2663],
                        [ -1692,  -2401],
                        [ -1385,  -2125],
                        [ -1064,  -1833],
                        [  -733,  -1528],
                        [  -391,  -1211],
                        [   -45,   -886],
                        [   309,   -551],
                        [   666,   -208],
                        [  1029,    142],
                        [  1393,    498],
                        [  1763,    860],
                        [  2135,   1224],
                        [  2511,   1593],
                        [  2888,   1965],
                        [  3267,   2339],
                        [  3646,   2715],
                        [  4025,   3092],
                        [  4404,   3468],
                        [  4779,   3842],
                        [  5152,   4215],
                        [  5521,   4585],
                        [  5883,   4949],
                        [  6238,   5306],
                        [  6580,   5655],
                        [  6914,   5995],
                        [  7230,   6321],
                        [  7525,   6631],
                        [  7795,   6927],
                        [  8032,   7200],
                        [  8212,   7430],
                        [  8330,   7613],
                        [  8399,   7755],
                        [  8413,   7851],
                        [  8352,   7872],
                        [  8164,   7763],
                        [  7837,   7510],
                        [  7414,   7155],
                        [  6920,   6725],
                        [  6359,   6225],
                        [  5741,   5664],
                        [  5083,   5058],
                        [  4394,   4417],
                        [  3681,   3748],
                        [  2955,   3062],
                        [  2227,   2369],
                        [  1501,   1673],
                        [   785,    981],
                        [    85,    290],
                        [  -596,   -393],
                        [ -1250,  -1071],
                        [ -1879,  -1740],
                        [ -2476,  -2394],
                        [ -3040,  -3034],
                        [ -3572,  -3647],
                        [ -4070,  -4235],
                        [ -4535,  -4783],
                        [ -4966,  -5294],
                        [ -5367,  -5758],
                        [ -5741,  -6178],
                        [ -6087,  -6554],
                        [ -6407,  -6885],
                        [ -6703,  -7180],
                        [ -6977,  -7439],
                        [ -7230,  -7673],
                        [ -7464,  -7885],
                        [ -7677,  -8073],
                        [ -7874,  -8240],
                        [ -8051,  -8387],
                        [ -8213,  -8514],
                        [ -8356,  -8624],
                        [ -8482,  -8714],
                        [ -8590,  -8787],
                        [ -8680,  -8842],
                        [ -8752,  -8881],
                        [ -8808,  -8902],
                        [ -8843,  -8906],
                        [ -8863,  -8894],
                        [ -8862,  -8864],
                        [ -8842,  -8818],
                        [ -8803,  -8756],
                        [ -8742,  -8678],
                        [ -8655,  -8583],
                        [ -8543,  -8474],
                        [ -8400,  -8349],
                        [ -8229,  -8211],
                        [ -8028,  -8060],
                        [ -7799,  -7896],
                        [ -7550,  -7720],
                        [ -7282,  -7535],
                        [ -7007,  -7342],
                        [ -6725,  -7140],
                        [ -6442,  -6934],
                        [ -6158,  -6723],
                        [ -5879,  -6511],
                        [ -5605,  -6297],
                        [ -5342,  -6084],
                        [ -5090,  -5875],
                        [ -4851,  -5670],
                        [ -4631,  -5475],
                        [ -4432,  -5293],
                        [ -4250,  -5117],
                        [ -4088,  -4952],
                        [ -3944,  -4799],
                        [ -3780,  -4616],
                        [ -3600,  -4411],
                        [ -3373,  -4151],
                        [ -3100,  -3839],
                        [ -2774,  -3469],
                        [ -2397,  -3043],
                        [ -2018,  -2611],
                        [ -1637,  -2173],
                        [ -1313,  -1790],
                        [ -1043,  -1458],
                        [  -835,  -1186],
                        [  -685,   -972],
                        [  -600,   -821],
                        [  -579,   -735],
                        [  -619,   -709],
                        [  -722,   -747],
                        [  -883,   -844],
                        [ -1101,  -1001],
                        [ -1371,  -1212],
                        [ -1689,  -1475],
                        [ -2050,  -1783],
                        [ -2453,  -2138],
                        [ -2885,  -2526],
                        [ -3348,  -2950],
                        [ -3832,  -3400],
                        [ -4333,  -3875],
                        [ -4843,  -4366],
                        [ -5362,  -4871],
                        [ -5879,  -5383],
                        [ -6396,  -5899],
                        [ -6905,  -6411],
                        [ -7403,  -6917],
                        [ -7885,  -7409],
                        [ -8349,  -7888],
                        [ -8790,  -8345],
                        [ -9206,  -8779],
                        [ -9593,  -9186],
                        [ -9950,  -9563],
                        [-10272,  -9907],
                        [-10559, -10215],
                        [-10808, -10485],
                        [-11019, -10719],
                        [-11189, -10908],
                        [-11318, -11057],
                        [-11407, -11164],
                        [-11450, -11225],
                        [-11445, -11243],
                        [-11392, -11218],
                        [-11285, -11149],
                        [-11128, -11042],
                        [-10946, -10918],
                        [-10757, -10793],
                        [-10565, -10667],
                        [-10346, -10513],
                        [-10064, -10284],
                        [ -9674,  -9939],
                        [ -9193,  -9493],
                        [ -8639,  -8967],
                        [ -8022,  -8367],
                        [ -7355,  -7709],
                        [ -6656,  -7011],
                        [ -5935,  -6281],
                        [ -5204,  -5536],
                        [ -4479,  -4788],
                        [ -3768,  -4049],
                        [ -3083,  -3328],
                        [ -2433,  -2631],
                        [ -1825,  -1968],
                        [ -1267,  -1340],
                        [  -763,   -754],
                        [  -318,   -212],
                        [    65,    283],
                        [   384,    724],
                        [   638,   1110],
                        [   826,   1429],
                        [   951,   1684],
                        [  1013,   1863],
                        [  1018,   1972],
                        [   969,   2006],
                        [   869,   1970],
                        [   725,   1867],
                        [   540,   1704],
                        [   322,   1494],
                        [    74,   1241],
                        [  -194,    960],
                        [  -479,    653],
                        [  -775,    328],
                        [ -1076,    -11],
                        [ -1378,   -358],
                        [ -1676,   -708],
                        [ -1966,  -1055],
                        [ -2243,  -1395],
                        [ -2504,  -1722],
                        [ -2745,  -2033],
                        [ -2966,  -2325],
                        [ -3161,  -2594],
                        [ -3327,  -2835],
                        [ -3465,  -3048],
                        [ -3574,  -3230],
                        [ -3651,  -3379],
                        [ -3699,  -3494],
                        [ -3719,  -3574],
                        [ -3712,  -3619],
                        [ -3681,  -3628],
                        [ -3628,  -3602],
                        [ -3555,  -3542],
                        [ -3463,  -3448],
                        [ -3352,  -3322],
                        [ -3222,  -3165],
                        [ -3070,  -2979],
                        [ -2897,  -2767],
                        [ -2703,  -2530],
                        [ -2489,  -2272],
                        [ -2257,  -1996],
                        [ -2009,  -1702],
                        [ -1744,  -1394],
                        [ -1469,  -1077],
                        [ -1183,   -752],
                        [  -884,   -418],
                        [  -576,    -80],
                        [  -267,    254],
                        [    43,    586],
                        [   336,    894],
                        [   610,   1181],
                        [   822,   1398],
                        [   973,   1551],
                        [  1050,   1624],
                        [  1051,   1616],
                        [   979,   1531],
                        [   830,   1365],
                        [   678,   1191],
                        [   517,   1003],
                        [   366,    821],
                        [   229,    650],
                        [   111,    495],
                        [    15,    358],
                        [   -55,    243],
                        [   -99,    153],
                        [  -111,     90],
                        [   -92,     55],
                        [   -41,     51],
                        [    44,     77],
                        [   160,    134],
                        [   310,    223],
                        [   491,    340],
                        [   703,    489],
                        [   943,    666],
                        [  1211,    873],
                        [  1504,   1107],
                        [  1819,   1368],
                        [  2156,   1654],
                        [  2513,   1965],
                        [  2885,   2295],
                        [  3275,   2646],
                        [  3678,   3011],
                        [  4093,   3393],
                        [  4515,   3784],
                        [  4942,   4185],
                        [  5372,   4591],
                        [  5804,   5000],
                        [  6229,   5408],
                        [  6648,   5813],
                        [  7057,   6211],
                        [  7452,   6598],
                        [  7829,   6970],
                        [  8186,   7326],
                        [  8517,   7661],
                        [  8822,   7971],
                        [  9091,   8253],
                        [  9322,   8504],
                        [  9501,   8720],
                        [  9633,   8900],
                        [  9741,   9073],
                        [  9864,   9276],
                        [ 10021,   9523],
                        [ 10207,   9809],
                        [ 10409,  10110],
                        [ 10571,  10369],
                        [ 10628,  10515],
                        [ 10556,  10529],
                        [ 10364,  10417],
                        [ 10059,  10186],
                        [  9649,   9844],
                        [  9148,   9402],
                        [  8563,   8870],
                        [  7905,   8257],
                        [  7185,   7575],
                        [  6415,   6835],
                        [  5605,   6046],
                        [  4762,   5216],
                        [  3900,   4354],
                        [  3025,   3468],
                        [  2146,   2563],
                        [  1269,   1649],
                        [   401,    729],
                        [  -450,   -189],
                        [ -1276,  -1094],
                        [ -2077,  -1983],
                        [ -2843,  -2841],
                        [ -3572,  -3663],
                        [ -4262,  -4436],
                        [ -4909,  -5160],
                        [ -5512,  -5828],
                        [ -6069,  -6437],
                        [ -6580,  -6991],
                        [ -7044,  -7487],
                        [ -7463,  -7936],
                        [ -7837,  -8339],
                        [ -8166,  -8693],
                        [ -8452,  -9003],
                        [ -8695,  -9265],
                        [ -8897,  -9484],
                        [ -9057,  -9658],
                        [ -9176,  -9791],
                        [ -9258,  -9882],
                        [ -9300,  -9933],
                        [ -9306,  -9946],
                        [ -9276,  -9922],
                        [ -9212,  -9865],
                        [ -9116,  -9774],
                        [ -8990,  -9653],
                        [ -8835,  -9502],
                        [ -8654,  -9326],
                        [ -8447,  -9125],
                        [ -8217,  -8903],
                        [ -7967,  -8661],
                        [ -7696,  -8403],
                        [ -7408,  -8130],
                        [ -7102,  -7846],
                        [ -6780,  -7553],
                        [ -6445,  -7253],
                        [ -6098,  -6949],
                        [ -5747,  -6645],
                        [ -5393,  -6340],
                        [ -5042,  -6039],
                        [ -4699,  -5745],
                        [ -4364,  -5458],
                        [ -4042,  -5181],
                        [ -3738,  -4916],
                        [ -3450,  -4664],
                        [ -3184,  -4428],
                        [ -2945,  -4213],
                        [ -2730,  -4016],
                        [ -2542,  -3839],
                        [ -2375,  -3677],
                        [ -2233,  -3532],
                        [ -2087,  -3378],
                        [ -1938,  -3213],
                        [ -1767,  -3022],
                        [ -1580,  -2807],
                        [ -1357,  -2552],
                        [ -1100,  -2259],
                        [  -838,  -1955],
                        [  -566,  -1638],
                        [  -329,  -1354],
                        [  -124,  -1097],
                        [    46,   -877],
                        [   178,   -691],
                        [   267,   -550],
                        [   316,   -448],
                        [   322,   -388],
                        [   288,   -370],
                        [   212,   -392],
                        [    98,   -453],
                        [   -52,   -549],
                        [  -236,   -681],
                        [  -449,   -840],
                        [  -688,  -1028],
                        [  -949,  -1238],
                        [ -1227,  -1467],
                        [ -1517,  -1711],
                        [ -1815,  -1967],
                        [ -2115,  -2230],
                        [ -2416,  -2498],
                        [ -2711,  -2766],
                        [ -2998,  -3030],
                        [ -3274,  -3283],
                        [ -3534,  -3527],
                        [ -3777,  -3754],
                        [ -4000,  -3963],
                        [ -4200,  -4149],
                        [ -4375,  -4314],
                        [ -4522,  -4450],
                        [ -4640,  -4558],
                        [ -4727,  -4636],
                        [ -4785,  -4683],
                        [ -4810,  -4698],
                        [ -4802,  -4679],
                        [ -4762,  -4627],
                        [ -4689,  -4541],
                        [ -4583,  -4422],
                        [ -4444,  -4271],
                        [ -4266,  -4088],
                        [ -4048,  -3871],
                        [ -3799,  -3634],
                        [ -3575,  -3434],
                        [ -3435,  -3326],
                        [ -3397,  -3327],
                        [ -3465,  -3437],
                        [ -3629,  -3644],
                        [ -3843,  -3892],
                        [ -4009,  -4085],
                        [ -4083,  -4180],
                        [ -4069,  -4182],
                        [ -3976,  -4097],
                        [ -3813,  -3935],
                        [ -3587,  -3703],
                        [ -3308,  -3410],
                        [ -2983,  -3066],
                        [ -2624,  -2680],
                        [ -2239,  -2263],
                        [ -1839,  -1824],
                        [ -1428,  -1370],
                        [ -1016,   -909],
                        [  -609,   -448],
                        [  -210,      7],
                        [   173,    453],
                        [   538,    882],
                        [   882,   1298],
                        [  1199,   1694],
                        [  1488,   2065],
                        [  1745,   2408],
                        [  1973,   2715],
                        [  2170,   2988],
                        [  2336,   3218],
                        [  2475,   3407],
                        [  2588,   3557],
                        [  2677,   3671],
                        [  2747,   3755],
                        [  2800,   3814],
                        [  2844,   3858],
                        [  2880,   3890],
                        [  2914,   3915],
                        [  2948,   3932],
                        [  2984,   3948],
                        [  3025,   3965],
                        [  3075,   3986],
                        [  3135,   4015],
                        [  3205,   4053],
                        [  3291,   4103],
                        [  3388,   4167],
                        [  3502,   4245],
                        [  3629,   4340],
                        [  3772,   4452],
                        [  3929,   4581],
                        [  4102,   4729],
                        [  4289,   4892],
                        [  4491,   5072],
                        [  4708,   5269],
                        [  4937,   5480],
                        [  5176,   5703],
                        [  5423,   5938],
                        [  5670,   6181],
                        [  5917,   6433],
                        [  6156,   6690],
                        [  6388,   6951],
                        [  6614,   7212],
                        [  6830,   7472],
                        [  7037,   7728],
                        [  7233,   7979],
                        [  7420,   8221],
                        [  7594,   8454],
                        [  7757,   8675],
                        [  7906,   8882],
                        [  8048,   9078],
                        [  8175,   9258],
                        [  8288,   9418],
                        [  8387,   9560],
                        [  8461,   9671],
                        [  8510,   9752],
                        [  8518,   9786],
                        [  8486,   9772],
                        [  8407,   9705],
                        [  8281,   9583],
                        [  8096,   9395],
                        [  7854,   9143],
                        [  7595,   8868],
                        [  7317,   8566],
                        [  7039,   8259],
                        [  6761,   7946],
                        [  6496,   7642],
                        [  6245,   7347],
                        [  6017,   7074],
                        [  5813,   6819],
                        [  5642,   6592],
                        [  5504,   6394],
                        [  5402,   6227],
                        [  5339,   6095],
                        [  5315,   6000],
                        [  5332,   5939],
                        [  5390,   5919],
                        [  5488,   5935],
                        [  5621,   5987],
                        [  5793,   6076],
                        [  5998,   6200],
                        [  6234,   6359],
                        [  6497,   6549],
                        [  6786,   6769],
                        [  7095,   7014],
                        [  7423,   7282],
                        [  7763,   7567],
                        [  8115,   7868],
                        [  8472,   8179],
                        [  8831,   8498],
                        [  9185,   8816],
                        [  9533,   9134],
                        [  9867,   9443],
                        [ 10186,   9741],
                        [ 10481,  10021],
                        [ 10753,  10281],
                        [ 10992,  10517],
                        [ 11200,  10723],
                        [ 11369,  10896],
                        [ 11498,  11033],
                        [ 11577,  11130],
                        [ 11607,  11184],
                        [ 11572,  11187],
                        [ 11493,  11161],
                        [ 11447,  11178],
                        [ 11492,  11302],
                        [ 11643,  11539],
                        [ 11902,  11893],
                        [ 12270,  12352],
                        [ 12689,  12861],
                        [ 13037,  13296],
                        [ 13249,  13588],
                        [ 13329,  13743],
                        [ 13280,  13762],
                        [ 13109,  13649],
                        [ 12821,  13413],
                        [ 12423,  13057],
                        [ 11926,  12592],
                        [ 11340,  12029],
                        [ 10675,  11376],
                        [  9943,  10646],
                        [  9150,   9848],
                        [  8312,   8997],
                        [  7438,   8102],
                        [  6537,   7177],
                        [  5615,   6229],
                        [  4685,   5265],
                        [  3757,   4296],
                        [  2840,   3326],
                        [  1941,   2361],
                        [  1073,   1418],
                        [   241,    501],
                        [  -552,   -378],
                        [ -1298,  -1211],
                        [ -1991,  -1990],
                        [ -2632,  -2712],
                        [ -3216,  -3373],
                        [ -3742,  -3970],
                        [ -4211,  -4510],
                        [ -4624,  -4993],
                        [ -4981,  -5418],
                        [ -5284,  -5785],
                        [ -5534,  -6096],
                        [ -5732,  -6352],
                        [ -5879,  -6554],
                        [ -5978,  -6703],
                        [ -6030,  -6804],
                        [ -6039,  -6856],
                        [ -6005,  -6864],
                        [ -5933,  -6831],
                        [ -5824,  -6759],
                        [ -5683,  -6652],
                        [ -5511,  -6513],
                        [ -5313,  -6346],
                        [ -5094,  -6155],
                        [ -4855,  -5940],
                        [ -4607,  -5709],
                        [ -4351,  -5464],
                        [ -4093,  -5207],
                        [ -3837,  -4943],
                        [ -3582,  -4675],
                        [ -3328,  -4405],
                        [ -3071,  -4136],
                        [ -2815,  -3872],
                        [ -2558,  -3615],
                        [ -2303,  -3366],
                        [ -2053,  -3129],
                        [ -1812,  -2904],
                        [ -1582,  -2693],
                        [ -1365,  -2498],
                        [ -1163,  -2320],
                        [  -976,  -2158],
                        [  -810,  -2016],
                        [  -665,  -1895],
                        [  -539,  -1791],
                        [  -433,  -1705],
                        [  -345,  -1633],
                        [  -275,  -1578],
                        [  -215,  -1530],
                        [  -165,  -1488],
                        [  -124,  -1451],
                        [   -89,  -1418],
                        [   -41,  -1366],
                        [    24,  -1296],
                        [   109,  -1201],
                        [   216,  -1081],
                        [   324,   -958],
                        [   439,   -826],
                        [   549,   -696],
                        [   659,   -567],
                        [   761,   -444],
                        [   856,   -329],
                        [   940,   -224],
                        [  1015,   -128],
                        [  1074,    -43],
                        [  1124,     33],
                        [  1159,     99],
                        [  1184,    158],
                        [  1197,    207],
                        [  1200,    251],
                        [  1194,    288],
                        [  1182,    322],
                        [  1165,    353],
                        [  1144,    383],
                        [  1122,    411],
                        [  1103,    442],
                        [  1086,    475],
                        [  1075,    513],
                        [  1071,    557],
                        [  1073,    609],
                        [  1087,    671],
                        [  1111,    743],
                        [  1146,    827],
                        [  1194,    922],
                        [  1254,   1031],
                        [  1329,   1154],
                        [  1417,   1290],
                        [  1519,   1440],
                        [  1636,   1605],
                        [  1765,   1782],
                        [  1909,   1973],
                        [  2065,   2176],
                        [  2236,   2391],
                        [  2418,   2616],
                        [  2615,   2849],
                        [  2837,   3101],
                        [  3047,   3329],
                        [  3147,   3439],
                        [  3081,   3374],
                        [  2835,   3118],
                        [  2398,   2670],
                        [  1766,   2023],
                        [   997,   1241],
                        [   230,    462],
                        [  -453,   -230],
                        [ -1053,   -839],
                        [ -1575,  -1364],
                        [ -2015,  -1806],
                        [ -2373,  -2161],
                        [ -2652,  -2435],
                        [ -2857,  -2630],
                        [ -2992,  -2750],
                        [ -3062,  -2802],
                        [ -3072,  -2789],
                        [ -3027,  -2720],
                        [ -2932,  -2603],
                        [ -2791,  -2446],
                        [ -2607,  -2254],
                        [ -2386,  -2031],
                        [ -2132,  -1783],
                        [ -1852,  -1507],
                        [ -1549,  -1208],
                        [ -1233,   -884],
                        [  -904,   -540],
                        [  -570,   -186],
                        [  -232,    180],
                        [   107,    547],
                        [   446,    916],
                        [   782,   1280],
                        [  1114,   1638],
                        [  1445,   1993],
                        [  1772,   2342],
                        [  2099,   2691],
                        [  2425,   3041],
                        [  2752,   3389],
                        [  3082,   3738],
                        [  3410,   4084],
                        [  3741,   4431],
                        [  4071,   4780],
                        [  4401,   5128],
                        [  4731,   5475],
                        [  5059,   5822],
                        [  5384,   6168],
                        [  5706,   6513],
                        [  6023,   6855],
                        [  6335,   7196],
                        [  6641,   7531],
                        [  6939,   7862],
                        [  7234,   8187],
                        [  7523,   8504],
                        [  7811,   8811],
                        [  8100,   9109],
                        [  8384,   9393],
                        [  8665,   9666],
                        [  8929,   9922],
                        [  9177,  10163],
                        [  9398,  10385],
                        [  9591,  10588],
                        [  9752,  10770],
                        [  9885,  10931],
                        [  9987,  11070],
                        [ 10059,  11185],
                        [ 10103,  11276],
                        [ 10117,  11342],
                        [ 10106,  11383],
                        [ 10069,  11400],
                        [ 10011,  11395],
                        [  9928,  11364],
                        [  9825,  11310],
                        [  9701,  11232],
                        [  9562,  11134],
                        [  9407,  11017],
                        [  9251,  10891],
                        [  9095,  10758],
                        [  8934,  10615],
                        [  8770,  10462],
                        [  8574,  10269],
                        [  8348,  10041],
                        [  8097,   9779],
                        [  7821,   9486],
                        [  7531,   9175],
                        [  7230,   8847],
                        [  6931,   8517],
                        [  6633,   8186],
                        [  6347,   7864],
                        [  6073,   7552],
                        [  5822,   7258],
                        [  5591,   6982],
                        [  5389,   6729],
                        [  5215,   6502],
                        [  5072,   6302],
                        [  4961,   6129],
                        [  4883,   5987],
                        [  4836,   5874],
                        [  4820,   5789],
                        [  4834,   5733],
                        [  4875,   5705],
                        [  4941,   5701],
                        [  5025,   5719],
                        [  5129,   5758],
                        [  5242,   5813],
                        [  5367,   5881],
                        [  5493,   5957],
                        [  5622,   6039],
                        [  5745,   6121],
                        [  5861,   6199],
                        [  5962,   6270],
                        [  6048,   6329],
                        [  6112,   6372],
                        [  6152,   6396],
                        [  6162,   6394],
                        [  6141,   6368],
                        [  6084,   6307],
                        [  5991,   6216],
                        [  5857,   6087],
                        [  5679,   5919],
                        [  5456,   5711],
                        [  5187,   5464],
                        [  4860,   5166],
                        [  4525,   4866],
                        [  4279,   4665],
                        [  4180,   4616],
                        [  4239,   4730],
                        [  4462,   5015],
                        [  4871,   5482],
                        [  5404,   6072],
                        [  5911,   6633],
                        [  6308,   7080],
                        [  6602,   7418],
                        [  6791,   7646],
                        [  6874,   7759],
                        [  6852,   7760],
                        [  6729,   7651],
                        [  6511,   7438],
                        [  6203,   7126],
                        [  5813,   6722],
                        [  5350,   6237],
                        [  4821,   5677],
                        [  4235,   5064],
                        [  3601,   4403],
                        [  2924,   3708],
                        [  2214,   2988],
                        [  1482,   2251],
                        [   738,   1503],
                        [    -9,    743],
                        [  -749,    -22],
                        [ -1471,   -784],
                        [ -2169,  -1536],
                        [ -2835,  -2265],
                        [ -3465,  -2970],
                        [ -4051,  -3638],
                        [ -4592,  -4269],
                        [ -5085,  -4851],
                        [ -5525,  -5384],
                        [ -5917,  -5870],
                        [ -6256,  -6304],
                        [ -6548,  -6688],
                        [ -6793,  -7024],
                        [ -6992,  -7310],
                        [ -7147,  -7549],
                        [ -7260,  -7742],
                        [ -7332,  -7892],
                        [ -7367,  -8000],
                        [ -7368,  -8069],
                        [ -7335,  -8102],
                        [ -7273,  -8103],
                        [ -7186,  -8075],
                        [ -7075,  -8021],
                        [ -6945,  -7946],
                        [ -6799,  -7851],
                        [ -6642,  -7740],
                        [ -6479,  -7618],
                        [ -6320,  -7486],
                        [ -6169,  -7349],
                        [ -6033,  -7209],
                        [ -5916,  -7068],
                        [ -5813,  -6929],
                        [ -5727,  -6795],
                        [ -5647,  -6667],
                        [ -5574,  -6546],
                        [ -5500,  -6434],
                        [ -5428,  -6333],
                        [ -5357,  -6242],
                        [ -5289,  -6164],
                        [ -5224,  -6095],
                        [ -5164,  -6040],
                        [ -5108,  -5995],
                        [ -5056,  -5961],
                        [ -5011,  -5937],
                        [ -4969,  -5922],
                        [ -4933,  -5915],
                        [ -4899,  -5914],
                        [ -4871,  -5918],
                        [ -4846,  -5929],
                        [ -4843,  -5962],
                        [ -4863,  -6017],
                        [ -4912,  -6102],
                        [ -4990,  -6212],
                        [ -5072,  -6325],
                        [ -5155,  -6437],
                        [ -5201,  -6509],
                        [ -5208,  -6540],
                        [ -5179,  -6532],
                        [ -5108,  -6480],
                        [ -5006,  -6394],
                        [ -4869,  -6273],
                        [ -4707,  -6126],
                        [ -4518,  -5951],
                        [ -4310,  -5755],
                        [ -4080,  -5536],
                        [ -3839,  -5301],
                        [ -3584,  -5046],
                        [ -3321,  -4778],
                        [ -3050,  -4496],
                        [ -2777,  -4206],
                        [ -2499,  -3907],
                        [ -2223,  -3602],
                        [ -1948,  -3291],
                        [ -1677,  -2977],
                        [ -1411,  -2660],
                        [ -1148,  -2342],
                        [  -891,  -2025],
                        [  -637,  -1708],
                        [  -389,  -1393],
                        [  -146,  -1081],
                        [    91,   -773],
                        [   323,   -469],
                        [   549,   -169],
                        [   769,    126],
                        [   982,    414],
                        [  1189,    695],
                        [  1386,    968],
                        [  1577,   1232],
                        [  1761,   1489],
                        [  1937,   1737],
                        [  2104,   1974],
                        [  2264,   2201],
                        [  2414,   2417],
                        [  2557,   2623],
                        [  2689,   2814],
                        [  2814,   2992],
                        [  2936,   3165],
                        [  3001,   3274],
                        [  2907,   3218],
                        [  2613,   2953],
                        [  2113,   2473],
                        [  1393,   1767],
                        [   431,    813],
                        [  -712,   -325],
                        [ -1877,  -1489],
                        [ -2980,  -2594],
                        [ -4022,  -3639],
                        [ -4994,  -4615],
                        [ -5886,  -5513],
                        [ -6691,  -6324],
                        [ -7407,  -7044],
                        [ -8029,  -7668],
                        [ -8556,  -8198],
                        [ -8990,  -8631],
                        [ -9331,  -8969],
                        [ -9578,  -9219],
                        [ -9736,  -9384],
                        [ -9805,  -9475],
                        [ -9787,  -9497],
                        [ -9689,  -9455],
                        [ -9514,  -9354],
                        [ -9270,  -9185],
                        [ -8962,  -8956],
                        [ -8601,  -8661],
                        [ -8193,  -8305],
                        [ -7746,  -7896],
                        [ -7263,  -7437],
                        [ -6753,  -6936],
                        [ -6221,  -6397],
                        [ -5670,  -5831],
                        [ -5108,  -5240],
                        [ -4536,  -4635],
                        [ -3960,  -4019],
                        [ -3382,  -3396],
                        [ -2802,  -2767],
                        [ -2223,  -2137],
                        [ -1649,  -1509],
                        [ -1082,   -886],
                        [  -525,   -271],
                        [    19,    332],
                        [   548,    922],
                        [  1060,   1496],
                        [  1550,   2052],
                        [  2020,   2586],
                        [  2464,   3100],
                        [  2884,   3588],
                        [  3275,   4051],
                        [  3639,   4486],
                        [  3974,   4892],
                        [  4285,   5267],
                        [  4572,   5613],
                        [  4844,   5925],
                        [  5101,   6204],
                        [  5343,   6450],
                        [  5571,   6663],
                        [  5773,   6840],
                        [  5952,   6983],
                        [  6090,   7092],
                        [  6190,   7168],
                        [  6248,   7210],
                        [  6266,   7220],
                        [  6245,   7198],
                        [  6186,   7145],
                        [  6095,   7064],
                        [  5969,   6955],
                        [  5813,   6819],
                        [  5630,   6660],
                        [  5423,   6478],
                        [  5194,   6275],
                        [  4947,   6055],
                        [  4682,   5818],
                        [  4426,   5585],
                        [  4176,   5359],
                        [  3970,   5173],
                        [  3807,   5027],
                        [  3685,   4919],
                        [  3605,   4849],
                        [  3525,   4774],
                        [  3444,   4696],
                        [  3335,   4583],
                        [  3196,   4437],
                        [  3035,   4266],
                        [  2853,   4072],
                        [  2658,   3864],
                        [  2450,   3642],
                        [  2236,   3416],
                        [  2017,   3184],
                        [  1803,   2954],
                        [  1588,   2724],
                        [  1383,   2499],
                        [  1184,   2279],
                        [   996,   2069],
                        [   819,   1866],
                        [   653,   1673],
                        [   500,   1490],
                        [   359,   1317],
                        [   228,   1151],
                        [   109,    994],
                        [    -4,    840],
                        [  -113,    690],
                        [  -220,    541],
                        [  -332,    391],
                        [  -449,    236],
                        [  -574,     75],
                        [  -711,    -96],
                        [  -863,   -279],
                        [ -1030,   -475],
                        [ -1219,   -689],
                        [ -1429,   -922],
                        [ -1663,  -1175],
                        [ -1923,  -1450],
                        [ -2210,  -1752],
                        [ -2524,  -2077],
                        [ -2869,  -2429],
                        [ -3241,  -2807],
                        [ -3644,  -3214],
                        [ -4075,  -3647],
                        [ -4528,  -4103],
                        [ -5010,  -4587],
                        [ -5518,  -5098],
                        [ -5989,  -5573],
                        [ -6333,  -5919],
                        [ -6513,  -6099],
                        [ -6526,  -6110],
                        [ -6352,  -5929],
                        [ -5954,  -5524],
                        [ -5389,  -4951],
                        [ -4800,  -4356],
                        [ -4264,  -3813],
                        [ -3772,  -3318],
                        [ -3332,  -2878],
                        [ -2953,  -2501],
                        [ -2638,  -2195],
                        [ -2389,  -1958],
                        [ -2206,  -1793],
                        [ -2089,  -1701],
                        [ -2035,  -1676],
                        [ -2043,  -1717],
                        [ -2106,  -1818],
                        [ -2224,  -1961],
                        [ -2392,  -2144],
                        [ -2607,  -2355],
                        [ -2861,  -2589],
                        [ -3148,  -2841],
                        [ -3462,  -3106],
                        [ -3794,  -3395],
                        [ -4135,  -3702],
                        [ -4478,  -4025],
                        [ -4816,  -4359],
                        [ -5145,  -4700],
                        [ -5461,  -5046],
                        [ -5757,  -5388],
                        [ -6030,  -5723],
                        [ -6277,  -6043],
                        [ -6498,  -6345],
                        [ -6693,  -6624],
                        [ -6858,  -6877],
                        [ -6999,  -7107],
                        [ -7113,  -7311],
                        [ -7206,  -7491],
                        [ -7274,  -7646],
                        [ -7323,  -7779],
                        [ -7352,  -7890],
                        [ -7362,  -7980],
                        [ -7357,  -8052],
                        [ -7337,  -8106],
                        [ -7307,  -8148],
                        [ -7265,  -8175],
                        [ -7215,  -8193],
                        [ -7160,  -8203],
                        [ -7100,  -8205],
                        [ -7042,  -8205],
                        [ -6986,  -8200],
                        [ -6945,  -8196],
                        [ -6918,  -8191],
                        [ -6917,  -8188],
                        [ -6940,  -8187],
                        [ -6984,  -8188],
                        [ -7052,  -8195],
                        [ -7124,  -8204],
                        [ -7204,  -8217],
                        [ -7278,  -8234],
                        [ -7345,  -8253],
                        [ -7404,  -8275],
                        [ -7456,  -8298],
                        [ -7496,  -8321],
                        [ -7526,  -8343],
                        [ -7544,  -8361],
                        [ -7550,  -8378],
                        [ -7542,  -8387],
                        [ -7517,  -8388],
                        [ -7478,  -8382],
                        [ -7423,  -8365],
                        [ -7359,  -8343],
                        [ -7285,  -8316],
                        [ -7243,  -8324],
                        [ -7230,  -8363],
                        [ -7264,  -8451],
                        [ -7341,  -8582],
                        [ -7436,  -8732],
                        [ -7551,  -8899],
                        [ -7616,  -9016],
                        [ -7634,  -9083],
                        [ -7593,  -9087],
                        [ -7490,  -9027],
                        [ -7334,  -8912],
                        [ -7122,  -8738],
                        [ -6862,  -8516],
                        [ -6554,  -8244],
                        [ -6208,  -7931],
                        [ -5823,  -7576],
                        [ -5410,  -7187],
                        [ -4967,  -6762],
                        [ -4505,  -6313],
                        [ -4024,  -5838],
                        [ -3533,  -5345],
                        [ -3032,  -4838],
                        [ -2532,  -4323],
                        [ -2032,  -3798],
                        [ -1541,  -3274],
                        [ -1056,  -2747],
                        [  -585,  -2225],
                        [  -128,  -1708],
                        [   315,  -1200],
                        [   742,   -704],
                        [  1151,   -221],
                        [  1540,    245],
                        [  1909,    694],
                        [  2257,   1123],
                        [  2582,   1530],
                        [  2884,   1915],
                        [  3163,   2276],
                        [  3417,   2611],
                        [  3646,   2919],
                        [  3851,   3202],
                        [  4032,   3458],
                        [  4187,   3685],
                        [  4319,   3886],
                        [  4429,   4060],
                        [  4513,   4207],
                        [  4569,   4323],
                        [  4602,   4417],
                        [  4611,   4486],
                        [  4536,   4470],
                        [  4305,   4295],
                        [  3904,   3944],
                        [  3332,   3413],
                        [  2570,   2682],
                        [  1582,   1717],
                        [   416,    566],
                        [  -790,   -632],
                        [ -1968,  -1809],
                        [ -3119,  -2965],
                        [ -4230,  -4084],
                        [ -5282,  -5150],
                        [ -6266,  -6151],
                        [ -7174,  -7077],
                        [ -7997,  -7919],
                        [ -8730,  -8673],
                        [ -9367,  -9332],
                        [ -9907,  -9892],
                        [-10347, -10363],
                        [-10688, -10740],
                        [-10925, -11036],
                        [-11062, -11252],
                        [-11104, -11391],
                        [-11052, -11460],
                        [-10914, -11447],
                        [-10694, -11360],
                        [-10405, -11190],
                        [-10052, -10943],
                        [ -9644, -10620],
                        [ -9186, -10228],
                        [ -8687,  -9770],
                        [ -8153,  -9254],
                        [ -7594,  -8691],
                        [ -7012,  -8084],
                        [ -6417,  -7451],
                        [ -5813,  -6797],
                        [ -5207,  -6130],
                        [ -4600,  -5456],
                        [ -3998,  -4778],
                        [ -3402,  -4104],
                        [ -2819,  -3438],
                        [ -2251,  -2784],
                        [ -1704,  -2147],
                        [ -1180,  -1530],
                        [  -679,   -936],
                        [  -207,   -369],
                        [   235,    169],
                        [   646,    677],
                        [  1023,   1150],
                        [  1366,   1588],
                        [  1674,   1989],
                        [  1947,   2355],
                        [  2191,   2681],
                        [  2406,   2969],
                        [  2606,   3220],
                        [  2789,   3433],
                        [  2958,   3608],
                        [  3115,   3746],
                        [  3253,   3848],
                        [  3375,   3915],
                        [  3461,   3950],
                        [  3517,   3954],
                        [  3538,   3927],
                        [  3525,   3872],
                        [  3482,   3792],
                        [  3408,   3689],
                        [  3307,   3563],
                        [  3183,   3419],
                        [  3037,   3259],
                        [  2871,   3082],
                        [  2686,   2893],
                        [  2490,   2694],
                        [  2283,   2490],
                        [  2069,   2280],
                        [  1884,   2104],
                        [  1730,   1960],
                        [  1648,   1891],
                        [  1640,   1896],
                        [  1703,   1976],
                        [  1840,   2130],
                        [  1996,   2301],
                        [  2170,   2494],
                        [  2309,   2648],
                        [  2413,   2768],
                        [  2485,   2858],
                        [  2524,   2914],
                        [  2532,   2941],
                        [  2506,   2936],
                        [  2452,   2907],
                        [  2369,   2851],
                        [  2261,   2771],
                        [  2128,   2666],
                        [  1973,   2539],
                        [  1795,   2390],
                        [  1598,   2221],
                        [  1381,   2032],
                        [  1151,   1827],
                        [   901,   1603],
                        [   639,   1363],
                        [   363,   1105],
                        [    74,    828],
                        [  -229,    533],
                        [  -548,    219],
                        [  -883,   -115],
                        [ -1236,   -470],
                        [ -1608,   -844],
                        [ -1999,  -1237],
                        [ -2409,  -1653],
                        [ -2838,  -2087],
                        [ -3286,  -2542],
                        [ -3752,  -3014],
                        [ -4236,  -3506],
                        [ -4737,  -4015],
                        [ -5253,  -4539],
                        [ -5783,  -5077],
                        [ -6325,  -5629],
                        [ -6878,  -6192],
                        [ -7437,  -6762],
                        [ -8001,  -7338],
                        [ -8565,  -7916],
                        [ -9118,  -8492],
                        [ -9664,  -9067],
                        [-10194,  -9635],
                        [-10649, -10138],
                        [-10980, -10518],
                        [-11174, -10766],
                        [-11234, -10876],
                        [-11126, -10815],
                        [-10809, -10541],
                        [-10312, -10084],
                        [ -9743,  -9553],
                        [ -9151,  -8996],
                        [ -8535,  -8413],
                        [ -7906,  -7815],
                        [ -7277,  -7217],
                        [ -6658,  -6628],
                        [ -6053,  -6055],
                        [ -5471,  -5504],
                        [ -4918,  -4981],
                        [ -4398,  -4493],
                        [ -3915,  -4038],
                        [ -3468,  -3617],
                        [ -3063,  -3222],
                        [ -2702,  -2853],
                        [ -2383,  -2504],
                        [ -2107,  -2176],
                        [ -1870,  -1867],
                        [ -1672,  -1578],
                        [ -1508,  -1322],
                        [ -1373,  -1096],
                        [ -1263,   -908],
                        [ -1175,   -753],
                        [ -1106,   -636],
                        [ -1053,   -556],
                        [ -1012,   -509],
                        [  -982,   -494],
                        [  -960,   -502],
                        [  -943,   -531],
                        [  -931,   -571],
                        [  -923,   -622],
                        [  -918,   -679],
                        [  -917,   -743],
                        [  -921,   -815],
                        [  -930,   -892],
                        [  -941,   -973],
                        [  -958,  -1059],
                        [  -979,  -1149],
                        [ -1004,  -1242],
                        [ -1035,  -1341],
                        [ -1071,  -1442],
                        [ -1112,  -1547],
                        [ -1156,  -1656],
                        [ -1206,  -1768],
                        [ -1259,  -1883],
                        [ -1319,  -2000],
                        [ -1384,  -2120],
                        [ -1464,  -2242],
                        [ -1558,  -2363],
                        [ -1672,  -2484],
                        [ -1806,  -2604],
                        [ -1957,  -2722],
                        [ -2125,  -2836],
                        [ -2294,  -2945],
                        [ -2464,  -3049],
                        [ -2618,  -3144],
                        [ -2757,  -3229],
                        [ -2875,  -3304],
                        [ -2975,  -3366],
                        [ -3052,  -3414],
                        [ -3102,  -3446],
                        [ -3128,  -3461],
                        [ -3127,  -3458],
                        [ -3096,  -3433],
                        [ -3032,  -3384],
                        [ -2941,  -3313],
                        [ -2821,  -3222],
                        [ -2685,  -3119],
                        [ -2532,  -3005],
                        [ -2418,  -2936],
                        [ -2339,  -2906],
                        [ -2315,  -2933],
                        [ -2342,  -3014],
                        [ -2402,  -3130],
                        [ -2498,  -3282],
                        [ -2547,  -3385],
                        [ -2555,  -3445],
                        [ -2502,  -3443],
                        [ -2388,  -3378],
                        [ -2218,  -3255],
                        [ -1992,  -3074],
                        [ -1714,  -2840],
                        [ -1387,  -2553],
                        [ -1017,  -2221],
                        [  -606,  -1846],
                        [  -163,  -1434],
                        [   311,   -986],
                        [   807,   -512],
                        [  1323,    -12],
                        [  1848,    502],
                        [  2384,   1032],
                        [  2917,   1566],
                        [  3447,   2104],
                        [  3966,   2639],
                        [  4472,   3170],
                        [  4961,   3691],
                        [  5430,   4202],
                        [  5878,   4698],
                        [  6304,   5176],
                        [  6705,   5633],
                        [  7080,   6068],
                        [  7428,   6476],
                        [  7746,   6857],
                        [  8036,   7210],
                        [  8296,   7534],
                        [  8524,   7825],
                        [  8721,   8085],
                        [  8889,   8313],
                        [  9025,   8508],
                        [  9133,   8670],
                        [  9211,   8800],
                        [  9259,   8899],
                        [  9278,   8965],
                        [  9267,   9002],
                        [  9220,   9004],
                        [  9143,   8982],
                        [  9029,   8929],
                        [  8842,   8806],
                        [  8557,   8588],
                        [  8187,   8279],
                        [  7726,   7875],
                        [  7158,   7350],
                        [  6435,   6660],
                        [  5573,   5822],
                        [  4656,   4919],
                        [  3724,   3993],
                        [  2779,   3048],
                        [  1839,   2100],
                        [   921,   1168],
                        [    36,    264],
                        [  -804,   -600],
                        [ -1590,  -1413],
                        [ -2312,  -2165],
                        [ -2963,  -2849],
                        [ -3538,  -3458],
                        [ -4033,  -3998],
                        [ -4444,  -4462],
                        [ -4766,  -4858],
                        [ -5003,  -5185],
                        [ -5155,  -5446],
                        [ -5223,  -5644],
                        [ -5213,  -5772],
                        [ -5126,  -5833],
                        [ -4975,  -5820],
                        [ -4760,  -5734],
                        [ -4492,  -5575],
                        [ -4175,  -5347],
                        [ -3816,  -5052],
                        [ -3424,  -4695],
                        [ -3003,  -4287],
                        [ -2562,  -3830],
                        [ -2107,  -3344],
                        [ -1643,  -2832],
                        [ -1177,  -2310],
                        [  -714,  -1780],
                        [  -257,  -1250],
                        [   190,   -722],
                        [   624,   -203],
                        [  1039,    301],
                        [  1435,    789],
                        [  1809,   1256],
                        [  2158,   1700],
                        [  2481,   2117],
                        [  2776,   2503],
                        [  3041,   2861],
                        [  3278,   3187],
                        [  3485,   3480],
                        [  3661,   3740],
                        [  3808,   3968],
                        [  3933,   4162],
                        [  4033,   4325],
                        [  4123,   4457],
                        [  4203,   4557],
                        [  4277,   4630],
                        [  4345,   4676],
                        [  4409,   4695],
                        [  4469,   4693],
                        [  4511,   4669],
                        [  4538,   4626],
                        [  4548,   4565],
                        [  4541,   4491],
                        [  4519,   4404],
                        [  4483,   4306],
                        [  4434,   4201],
                        [  4375,   4090],
                        [  4306,   3976],
                        [  4227,   3856],
                        [  4141,   3736],
                        [  4049,   3616],
                        [  3956,   3504],
                        [  3863,   3397],
                        [  3814,   3341],
                        [  3806,   3332],
                        [  3876,   3408],
                        [  4024,   3569],
                        [  4252,   3816],
                        [  4561,   4151],
                        [  4893,   4511],
                        [  5248,   4901],
                        [  5564,   5255],
                        [  5843,   5575],
                        [  6079,   5857],
                        [  6271,   6099],
                        [  6415,   6297],
                        [  6509,   6449],
                        [  6553,   6554],
                        [  6545,   6612],
                        [  6488,   6623],
                        [  6378,   6585],
                        [  6221,   6499],
                        [  6013,   6364],
                        [  5761,   6186],
                        [  5461,   5961],
                        [  5123,   5696],
                        [  4743,   5389],
                        [  4328,   5043],
                        [  3880,   4659],
                        [  3400,   4238],
                        [  2891,   3781],
                        [  2355,   3292],
                        [  1794,   2771],
                        [  1208,   2221],
                        [   600,   1643],
                        [   -25,   1044],
                        [  -669,    423],
                        [ -1323,   -214],
                        [ -1987,   -865],
                        [ -2658,  -1527],
                        [ -3329,  -2194],
                        [ -3998,  -2862],
                        [ -4663,  -3531],
                        [ -5318,  -4193],
                        [ -5960,  -4846],
                        [ -6582,  -5483],
                        [ -7183,  -6102],
                        [ -7755,  -6698],
                        [ -8293,  -7267],
                        [ -8784,  -7802],
                        [ -9228,  -8305],
                        [ -9615,  -8764],
                        [ -9923,  -9157],
                        [-10153,  -9479],
                        [-10310,  -9735],
                        [-10398,  -9917],
                        [-10387,  -9994],
                        [-10225,  -9915],
                        [ -9901,  -9667],
                        [ -9463,  -9298],
                        [ -8938,  -8837],
                        [ -8327,  -8284],
                        [ -7643,  -7653],
                        [ -6905,  -6962],
                        [ -6122,  -6221],
                        [ -5306,  -5440],
                        [ -4469,  -4632],
                        [ -3622,  -3810],
                        [ -2773,  -2980],
                        [ -1932,  -2152],
                        [ -1108,  -1330],
                        [  -307,   -515],
                        [   464,    287],
                        [  1201,   1075],
                        [  1899,   1845],
                        [  2553,   2593],
                        [  3162,   3317],
                        [  3725,   3999],
                        [  4243,   4643],
                        [  4714,   5235],
                        [  5141,   5774],
                        [  5523,   6252],
                        [  5861,   6669],
                        [  6157,   7022],
                        [  6413,   7313],
                        [  6630,   7547],
                        [  6810,   7726],
                        [  6957,   7863],
                        [  7071,   7958],
                        [  7156,   8018],
                        [  7212,   8043],
                        [  7240,   8036],
                        [  7242,   7997],
                        [  7219,   7931],
                        [  7174,   7839],
                        [  7108,   7725],
                        [  7022,   7590],
                        [  6919,   7436],
                        [  6801,   7268],
                        [  6671,   7085],
                        [  6529,   6892],
                        [  6381,   6692],
                        [  6227,   6485],
                        [  6069,   6275],
                        [  5909,   6064],
                        [  5742,   5854],
                        [  5569,   5648],
                        [  5389,   5449],
                        [  5205,   5258],
                        [  5015,   5077],
                        [  4821,   4910],
                        [  4633,   4757],
                        [  4453,   4622],
                        [  4292,   4505],
                        [  4154,   4408],
                        [  4040,   4332],
                        [  3950,   4279],
                        [  3889,   4250],
                        [  3859,   4247],
                        [  3859,   4268],
                        [  3889,   4314],
                        [  3954,   4390],
                        [  4052,   4494],
                        [  4180,   4621],
                        [  4338,   4773],
                        [  4507,   4930],
                        [  4687,   5094],
                        [  4828,   5213],
                        [  4930,   5289],
                        [  4977,   5307],
                        [  4970,   5267],
                        [  4916,   5179],
                        [  4813,   5040],
                        [  4739,   4929],
                        [  4685,   4838],
                        [  4672,   4787],
                        [  4697,   4776],
                        [  4761,   4805],
                        [  4865,   4873],
                        [  5007,   4981],
                        [  5184,   5127],
                        [  5393,   5305],
                        [  5633,   5514],
                        [  5899,   5752],
                        [  6188,   6015],
                        [  6494,   6296],
                        [  6816,   6597],
                        [  7146,   6905],
                        [  7482,   7223],
                        [  7817,   7542],
                        [  8149,   7862],
                        [  8470,   8175],
                        [  8781,   8483],
                        [  9076,   8780],
                        [  9354,   9067],
                        [  9615,   9339],
                        [  9857,   9595],
                        [ 10077,   9832],
                        [ 10276,  10049],
                        [ 10453,  10244],
                        [ 10606,  10416],
                        [ 10732,  10563],
                        [ 10836,  10687],
                        [ 10915,  10784],
                        [ 10970,  10857],
                        [ 10999,  10904],
                        [ 11003,  10923],
                        [ 10985,  10918],
                        [ 10943,  10888],
                        [ 10876,  10831],
                        [ 10787,  10752],
                        [ 10666,  10648],
                        [ 10515,  10520],
                        [ 10333,  10372],
                        [ 10116,  10201],
                        [  9877,  10013],
                        [  9634,   9830],
                        [  9414,   9667],
                        [  9212,   9519],
                        [  9010,   9361],
                        [  8756,   9140],
                        [  8410,   8821],
                        [  7992,   8419],
                        [  7517,   7955],
                        [  6993,   7433],
                        [  6429,   6866],
                        [  5843,   6269],
                        [  5242,   5654],
                        [  4638,   5029],
                        [  4040,   4407],
                        [  3459,   3798],
                        [  2902,   3209],
                        [  2377,   2647],
                        [  1889,   2114],
                        [  1444,   1617],
                        [  1043,   1153],
                        [   691,    725],
                        [   388,    332],
                        [   137,    -24],
                        [   -64,   -339],
                        [  -216,   -615],
                        [  -323,   -843],
                        [  -385,  -1026],
                        [  -409,  -1156],
                        [  -397,  -1239],
                        [  -354,  -1268],
                        [  -284,  -1246],
                        [  -191,  -1181],
                        [   -79,  -1074],
                        [    47,   -939],
                        [   180,   -779],
                        [   319,   -609],
                        [   457,   -431],
                        [   595,   -249],
                        [   726,    -66],
                        [   851,    115],
                        [   967,    290],
                        [  1074,    456],
                        [  1171,    613],
                        [  1255,    756],
                        [  1327,    885],
                        [  1387,    999],
                        [  1433,   1097],
                        [  1467,   1180],
                        [  1487,   1246],
                        [  1494,   1296],
                        [  1489,   1330],
                        [  1476,   1350],
                        [  1457,   1357],
                        [  1437,   1351],
                        [  1417,   1333],
                        [  1401,   1307],
                        [  1391,   1272],
                        [  1391,   1230],
                        [  1402,   1184],
                        [  1416,   1133],
                        [  1434,   1081],
                        [  1455,   1029],
                        [  1479,    977],
                        [  1503,    929],
                        [  1530,    883],
                        [  1558,    843],
                        [  1588,    808],
                        [  1618,    778],
                        [  1645,    752],
                        [  1670,    730],
                        [  1697,    718],
                        [  1724,    716],
                        [  1753,    723],
                        [  1821,    778],
                        [  1923,    878],
                        [  2084,   1046],
                        [  2300,   1277],
                        [  2582,   1583],
                        [  2927,   1960],
                        [  3288,   2363],
                        [  3668,   2793],
                        [  4012,   3192],
                        [  4321,   3564],
                        [  4586,   3898],
                        [  4805,   4191],
                        [  4971,   4435],
                        [  5082,   4629],
                        [  5133,   4766],
                        [  5125,   4848],
                        [  5055,   4872],
                        [  4922,   4835],
                        [  4731,   4741],
                        [  4479,   4587],
                        [  4168,   4376],
                        [  3801,   4109],
                        [  3385,   3792],
                        [  2918,   3423],
                        [  2409,   3010],
                        [  1858,   2551],
                        [  1274,   2052],
                        [   658,   1516],
                        [    17,    947],
                        [  -648,    346],
                        [ -1332,   -279],
                        [ -2030,   -925],
                        [ -2736,  -1584],
                        [ -3446,  -2256],
                        [ -4154,  -2931],
                        [ -4857,  -3608],
                        [ -5546,  -4276],
                        [ -6220,  -4936],
                        [ -6869,  -5578],
                        [ -7493,  -6200],
                        [ -8084,  -6795],
                        [ -8639,  -7358],
                        [ -9150,  -7885],
                        [ -9616,  -8370],
                        [-10027,  -8811],
                        [-10380,  -9202],
                        [-10662,  -9540],
                        [-10871,  -9819],
                        [-11009, -10043],
                        [-11106, -10241],
                        [-11204, -10446],
                        [-11318, -10674],
                        [-11456, -10918],
                        [-11593, -11156],
                        [-11674, -11330],
                        [-11632, -11373],
                        [-11453, -11271],
                        [-11152, -11038],
                        [-10732, -10676],
                        [-10204, -10199],
                        [ -9586,  -9622],
                        [ -8885,  -8954],
                        [ -8116,  -8209],
                        [ -7292,  -7399],
                        [ -6427,  -6538],
                        [ -5532,  -5639],
                        [ -4617,  -4710],
                        [ -3694,  -3765],
                        [ -2776,  -2810],
                        [ -1866,  -1853],
                        [  -978,   -904],
                        [  -117,     33],
                        [   709,    948],
                        [  1491,   1839],
                        [  2227,   2693],
                        [  2914,   3506],
                        [  3548,   4268],
                        [  4127,   4974],
                        [  4650,   5613],
                        [  5118,   6184],
                        [  5530,   6682],
                        [  5885,   7106],
                        [  6187,   7460],
                        [  6437,   7745],
                        [  6638,   7972],
                        [  6793,   8143],
                        [  6905,   8265],
                        [  6979,   8341],
                        [  7016,   8372],
                        [  7018,   8361],
                        [  6988,   8313],
                        [  6931,   8232],
                        [  6848,   8123],
                        [  6741,   7987],
                        [  6616,   7830],
                        [  6476,   7655],
                        [  6323,   7468],
                        [  6161,   7269],
                        [  5997,   7064],
                        [  5830,   6856],
                        [  5665,   6649],
                        [  5505,   6446],
                        [  5348,   6249],
                        [  5199,   6063],
                        [  5059,   5887],
                        [  4931,   5727],
                        [  4810,   5584],
                        [  4698,   5458],
                        [  4596,   5353],
                        [  4504,   5269],
                        [  4429,   5207],
                        [  4371,   5168],
                        [  4333,   5151],
                        [  4315,   5159],
                        [  4317,   5188],
                        [  4341,   5240],
                        [  4386,   5313],
                        [  4454,   5408],
                        [  4544,   5525],
                        [  4656,   5661],
                        [  4783,   5811],
                        [  4928,   5976],
                        [  5071,   6135],
                        [  5212,   6291],
                        [  5319,   6408],
                        [  5391,   6487],
                        [  5415,   6515],
                        [  5391,   6491],
                        [  5311,   6409],
                        [  5176,   6268],
                        [  5037,   6121],
                        [  4889,   5963],
                        [  4750,   5810],
                        [  4616,   5662],
                        [  4495,   5523],
                        [  4383,   5396],
                        [  4288,   5282],
                        [  4206,   5182],
                        [  4140,   5095],
                        [  4087,   5023],
                        [  4050,   4963],
                        [  4026,   4914],
                        [  4013,   4875],
                        [  4013,   4847],
                        [  4020,   4823],
                        [  4034,   4804],
                        [  4052,   4788],
                        [  4073,   4772],
                        [  4093,   4755],
                        [  4112,   4736],
                        [  4127,   4715],
                        [  4137,   4691],
                        [  4143,   4661],
                        [  4143,   4628],
                        [  4135,   4587],
                        [  4121,   4539],
                        [  4098,   4483],
                        [  4068,   4418],
                        [  4028,   4344],
                        [  3980,   4262],
                        [  3922,   4168],
                        [  3854,   4067],
                        [  3776,   3954],
                        [  3686,   3831],
                        [  3587,   3698],
                        [  3478,   3555],
                        [  3354,   3401],
                        [  3217,   3237],
                        [  3059,   3062],
                        [  2882,   2878],
                        [  2676,   2680],
                        [  2458,   2482],
                        [  2286,   2342],
                        [  2212,   2312],
                        [  2260,   2402],
                        [  2429,   2612],
                        [  2705,   2924],
                        [  3031,   3279],
                        [  3307,   3580],
                        [  3492,   3785],
                        [  3593,   3899],
                        [  3614,   3928],
                        [  3559,   3876],
                        [  3436,   3752],
                        [  3251,   3560],
                        [  3013,   3311],
                        [  2728,   3010],
                        [  2406,   2668],
                        [  2053,   2290],
                        [  1677,   1884],
                        [  1282,   1457],
                        [   877,   1014],
                        [   463,    561],
                        [    46,    102],
                        [  -366,   -360],
                        [  -771,   -821],
                        [ -1165,  -1281],
                        [ -1543,  -1735],
                        [ -1905,  -2179],
                        [ -2249,  -2611],
                        [ -2576,  -3023],
                        [ -2884,  -3413],
                        [ -3175,  -3773],
                        [ -3448,  -4103],
                        [ -3704,  -4405],
                        [ -3942,  -4675],
                        [ -4166,  -4920],
                        [ -4374,  -5140],
                        [ -4571,  -5345],
                        [ -4757,  -5536],
                        [ -4933,  -5713],
                        [ -5100,  -5876],
                        [ -5257,  -6027],
                        [ -5405,  -6167],
                        [ -5541,  -6296],
                        [ -5667,  -6414],
                        [ -5782,  -6522],
                        [ -5886,  -6621],
                        [ -5978,  -6711],
                        [ -6058,  -6791],
                        [ -6127,  -6862],
                        [ -6186,  -6924],
                        [ -6232,  -6976],
                        [ -6268,  -7018],
                        [ -6291,  -7051],
                        [ -6302,  -7073],
                        [ -6303,  -7083],
                        [ -6294,  -7085],
                        [ -6273,  -7074],
                        [ -6240,  -7052],
                        [ -6187,  -7018],
                        [ -6116,  -6974],
                        [ -6025,  -6918],
                        [ -5914,  -6851],
                        [ -5789,  -6774],
                        [ -5648,  -6686],
                        [ -5495,  -6588],
                        [ -5332,  -6482],
                        [ -5162,  -6368],
                        [ -4986,  -6245],
                        [ -4807,  -6117],
                        [ -4630,  -5988],
                        [ -4457,  -5856],
                        [ -4285,  -5721],
                        [ -4117,  -5581],
                        [ -3954,  -5440],
                        [ -3778,  -5277],
                        [ -3592,  -5098],
                        [ -3391,  -4895],
                        [ -3178,  -4669],
                        [ -2935,  -4408],
                        [ -2666,  -4111],
                        [ -2389,  -3798],
                        [ -2104,  -3470],
                        [ -1848,  -3161],
                        [ -1618,  -2873],
                        [ -1424,  -2615],
                        [ -1268,  -2389],
                        [ -1159,  -2208],
                        [ -1098,  -2070],
                        [ -1088,  -1984],
                        [ -1133,  -1948],
                        [ -1233,  -1967],
                        [ -1387,  -2040],
                        [ -1597,  -2165],
                        [ -1861,  -2343],
                        [ -2176,  -2572],
                        [ -2539,  -2848],
                        [ -2945,  -3168],
                        [ -3393,  -3530],
                        [ -3876,  -3929],
                        [ -4391,  -4362],
                        [ -4928,  -4822],
                        [ -5486,  -5306],
                        [ -6058,  -5810],
                        [ -6638,  -6329],
                        [ -7221,  -6856],
                        [ -7802,  -7387],
                        [ -8373,  -7915],
                        [ -8933,  -8435],
                        [ -9471,  -8941],
                        [ -9985,  -9428],
                        [-10468,  -9891],
                        [-10918, -10325],
                        [-11328, -10725],
                        [-11694, -11087],
                        [-12011, -11407],
                        [-12279, -11680],
                        [-12490, -11902],
                        [-12643, -12072],
                        [-12730, -12186],
                        [-12751, -12243],
                        [-12700, -12241],
                        [-12568, -12173],
                        [-12385, -12064],
                        [-12227, -11994],
                        [-12158, -12019],
                        [-12192, -12150],
                        [-12340, -12390],
                        [-12597, -12732],
                        [-12898, -13113],
                        [-13127, -13413],
                        [-13225, -13574],
                        [-13200, -13604],
                        [-13058, -13506],
                        [-12803, -13288],
                        [-12445, -12956],
                        [-11993, -12520],
                        [-11457, -11992],
                        [-10847, -11379],
                        [-10177, -10697],
                        [ -9456,  -9954],
                        [ -8695,  -9164],
                        [ -7905,  -8337],
                        [ -7095,  -7487],
                        [ -6273,  -6623],
                        [ -5451,  -5756],
                        [ -4638,  -4895],
                        [ -3843,  -4045],
                        [ -3075,  -3212],
                        [ -2340,  -2401],
                        [ -1645,  -1617],
                        [  -991,   -870],
                        [  -384,   -163],
                        [   176,    493],
                        [   685,   1096],
                        [  1143,   1640],
                        [  1551,   2124],
                        [  1909,   2547],
                        [  2216,   2910],
                        [  2477,   3222],
                        [  2696,   3482],
                        [  2876,   3699],
                        [  3020,   3875],
                        [  3132,   4011],
                        [  3214,   4110],
                        [  3270,   4178],
                        [  3303,   4218],
                        [  3313,   4233],
                        [  3308,   4227],
                        [  3288,   4207],
                        [  3257,   4173],
                        [  3219,   4130],
                        [  3178,   4080],
                        [  3136,   4030],
                        [  3098,   3980],
                        [  3064,   3934],
                        [  3038,   3895],
                        [  3024,   3863],
                        [  3026,   3842],
                        [  3047,   3833],
                        [  3088,   3836],
                        [  3144,   3853],
                        [  3215,   3885],
                        [  3291,   3932],
                        [  3373,   3993],
                        [  3456,   4067],
                        [  3546,   4157],
                        [  3637,   4258],
                        [  3731,   4370],
                        [  3828,   4492],
                        [  3927,   4623],
                        [  4027,   4758],
                        [  4128,   4899],
                        [  4228,   5043],
                        [  4327,   5188],
                        [  4421,   5328],
                        [  4508,   5463],
                        [  4581,   5584],
                        [  4639,   5688],
                        [  4677,   5770],
                        [  4694,   5829],
                        [  4678,   5853],
                        [  4630,   5842],
                        [  4527,   5771],
                        [  4370,   5643],
                        [  4178,   5474],
                        [  3949,   5263],
                        [  3694,   5022],
                        [  3413,   4750],
                        [  3117,   4460],
                        [  2804,   4149],
                        [  2485,   3828],
                        [  2157,   3496],
                        [  1830,   3161],
                        [  1502,   2823],
                        [  1179,   2485],
                        [   860,   2147],
                        [   553,   1812],
                        [   254,   1481],
                        [   -33,   1155],
                        [  -310,    836],
                        [  -572,    525],
                        [  -821,    221],
                        [ -1057,    -75],
                        [ -1279,   -361],
                        [ -1489,   -638],
                        [ -1687,   -905],
                        [ -1872,  -1162],
                        [ -2045,  -1407],
                        [ -2208,  -1643],
                        [ -2358,  -1868],
                        [ -2498,  -2084],
                        [ -2629,  -2290],
                        [ -2751,  -2487],
                        [ -2863,  -2675],
                        [ -2970,  -2855],
                        [ -3069,  -3026],
                        [ -3162,  -3190],
                        [ -3252,  -3347],
                        [ -3339,  -3498],
                        [ -3421,  -3643],
                        [ -3508,  -3785],
                        [ -3598,  -3924],
                        [ -3696,  -4061],
                        [ -3803,  -4195],
                        [ -3930,  -4336],
                        [ -4037,  -4444],
                        [ -4032,  -4427],
                        [ -3857,  -4228],
                        [ -3497,  -3842],
                        [ -2949,  -3266],
                        [ -2212,  -2500],
                        [ -1350,  -1612],
                        [  -511,   -748],
                        [   234,     20],
                        [   885,    692],
                        [  1444,   1268],
                        [  1905,   1742],
                        [  2269,   2116],
                        [  2537,   2391],
                        [  2715,   2570],
                        [  2805,   2658],
                        [  2814,   2659],
                        [  2744,   2578],
                        [  2604,   2424],
                        [  2399,   2204],
                        [  2131,   1923],
                        [  1809,   1594],
                        [  1437,   1222],
                        [  1029,    813],
                        [   587,    375],
                        [   123,    -97],
                        [  -358,   -593],
                        [  -849,  -1112],
                        [ -1347,  -1651],
                        [ -1847,  -2199],
                        [ -2345,  -2752],
                        [ -2838,  -3300],
                        [ -3320,  -3841],
                        [ -3789,  -4367],
                        [ -4242,  -4877],
                        [ -4676,  -5367],
                        [ -5091,  -5835],
                        [ -5486,  -6285],
                        [ -5861,  -6715],
                        [ -6215,  -7124],
                        [ -6548,  -7509],
                        [ -6858,  -7870],
                        [ -7145,  -8208],
                        [ -7405,  -8519],
                        [ -7639,  -8805],
                        [ -7847,  -9065],
                        [ -8028,  -9298],
                        [ -8180,  -9504],
                        [ -8307,  -9683],
                        [ -8408,  -9837],
                        [ -8482,  -9963],
                        [ -8531, -10064],
                        [ -8556, -10139],
                        [ -8561, -10189],
                        [ -8546, -10214],
                        [ -8520, -10215],
                        [ -8484, -10193],
                        [ -8440, -10150],
                        [ -8387, -10085],
                        [ -8318, -10001],
                        [ -8232,  -9899],
                        [ -8123,  -9778],
                        [ -7992,  -9644],
                        [ -7841,  -9496],
                        [ -7672,  -9335],
                        [ -7490,  -9164],
                        [ -7294,  -8985],
                        [ -7091,  -8799],
                        [ -6881,  -8609],
                        [ -6669,  -8416],
                        [ -6459,  -8225],
                        [ -6252,  -8035],
                        [ -6050,  -7847],
                        [ -5855,  -7664],
                        [ -5670,  -7488],
                        [ -5504,  -7327],
                        [ -5357,  -7180],
                        [ -5238,  -7057],
                        [ -5149,  -6959],
                        [ -5066,  -6862],
                        [ -4992,  -6767],
                        [ -4909,  -6658],
                        [ -4820,  -6537],
                        [ -4735,  -6416],
                        [ -4654,  -6294],
                        [ -4587,  -6180],
                        [ -4531,  -6075],
                        [ -4497,  -5991],
                        [ -4483,  -5925],
                        [ -4496,  -5886],
                        [ -4534,  -5873],
                        [ -4600,  -5889],
                        [ -4695,  -5933],
                        [ -4819,  -6005],
                        [ -4969,  -6103],
                        [ -5146,  -6225],
                        [ -5345,  -6370],
                        [ -5566,  -6535],
                        [ -5805,  -6719],
                        [ -6059,  -6916],
                        [ -6323,  -7125],
                        [ -6591,  -7339],
                        [ -6862,  -7556],
                        [ -7127,  -7771],
                        [ -7386,  -7981],
                        [ -7629,  -8179],
                        [ -7854,  -8366],
                        [ -8058,  -8531],
                        [ -8236,  -8675],
                        [ -8383,  -8791],
                        [ -8498,  -8877],
                        [ -8575,  -8930],
                        [ -8614,  -8947],
                        [ -8611,  -8926],
                        [ -8565,  -8865],
                        [ -8471,  -8760],
                        [ -8333,  -8614],
                        [ -8146,  -8422],
                        [ -7910,  -8184],
                        [ -7622,  -7901],
                        [ -7285,  -7576],
                        [ -6897,  -7205],
                        [ -6451,  -6785],
                        [ -6003,  -6370],
                        [ -5654,  -6063],
                        [ -5462,  -5915],
                        [ -5436,  -5939],
                        [ -5594,  -6143],
                        [ -5949,  -6540],
                        [ -6436,  -7066],
                        [ -6902,  -7566],
                        [ -7276,  -7967],
                        [ -7562,  -8274],
                        [ -7762,  -8488],
                        [ -7873,  -8606],
                        [ -7896,  -8630],
                        [ -7835,  -8561],
                        [ -7695,  -8406],
                        [ -7481,  -8170],
                        [ -7200,  -7859],
                        [ -6858,  -7482],
                        [ -6462,  -7048],
                        [ -6019,  -6565],
                        [ -5532,  -6047],
                        [ -5012,  -5502],
                        [ -4467,  -4942],
                        [ -3905,  -4373],
                        [ -3335,  -3798],
                        [ -2766,  -3225],
                        [ -2204,  -2648],
                        [ -1656,  -2075],
                        [ -1125,  -1509],
                        [  -613,   -951],
                        [  -124,   -412],
                        [   339,    107],
                        [   774,    602],
                        [  1179,   1070],
                        [  1554,   1508],
                        [  1900,   1915],
                        [  2217,   2293],
                        [  2508,   2641],
                        [  2776,   2966],
                        [  3022,   3266],
                        [  3250,   3544],
                        [  3461,   3801],
                        [  3658,   4041],
                        [  3842,   4265],
                        [  4013,   4474],
                        [  4175,   4673],
                        [  4330,   4863],
                        [  4479,   5045],
                        [  4624,   5222],
                        [  4768,   5396],
                        [  4910,   5568],
                        [  5054,   5741],
                        [  5200,   5914],
                        [  5349,   6089],
                        [  5511,   6265],
                        [  5686,   6444],
                        [  5878,   6624],
                        [  6088,   6808],
                        [  6308,   6992],
                        [  6539,   7176],
                        [  6763,   7359],
                        [  6979,   7541],
                        [  7179,   7717],
                        [  7363,   7890],
                        [  7527,   8054],
                        [  7672,   8211],
                        [  7795,   8356],
                        [  7897,   8487],
                        [  7974,   8603],
                        [  8028,   8702],
                        [  8056,   8782],
                        [  8058,   8842],
                        [  8033,   8877],
                        [  7980,   8888],
                        [  7906,   8882],
                        [  7815,   8859],
                        [  7725,   8837],
                        [  7636,   8815],
                        [  7541,   8786],
                        [  7440,   8747],
                        [  7295,   8660],
                        [  7107,   8527],
                        [  6863,   8331],
                        [  6562,   8072],
                        [  6215,   7762],
                        [  5822,   7399],
                        [  5395,   6995],
                        [  4934,   6552],
                        [  4450,   6083],
                        [  3944,   5588],
                        [  3428,   5077],
                        [  2902,   4552],
                        [  2376,   4020],
                        [  1849,   3483],
                        [  1332,   2947],
                        [   825,   2413],
                        [   333,   1887],
                        [  -141,   1372],
                        [  -593,    869],
                        [ -1022,    384],
                        [ -1425,    -82],
                        [ -1802,   -529],
                        [ -2153,   -955],
                        [ -2477,  -1359],
                        [ -2776,  -1739],
                        [ -3047,  -2095],
                        [ -3293,  -2428],
                        [ -3516,  -2737],
                        [ -3713,  -3024],
                        [ -3887,  -3287],
                        [ -4040,  -3527],
                        [ -4171,  -3746],
                        [ -4284,  -3945],
                        [ -4378,  -4122],
                        [ -4458,  -4282],
                        [ -4524,  -4422],
                        [ -4578,  -4548],
                        [ -4621,  -4657],
                        [ -4659,  -4756],
                        [ -4692,  -4843],
                        [ -4721,  -4918],
                        [ -4750,  -4986],
                        [ -4789,  -5055],
                        [ -4774,  -5060],
                        [ -4613,  -4908],
                        [ -4262,  -4556],
                        [ -3717,  -4004],
                        [ -2963,  -3237],
                        [ -1982,  -2238],
                        [  -843,  -1081],
                        [   294,     78],
                        [  1352,   1159],
                        [  2333,   2161],
                        [  3231,   3081],
                        [  4034,   3904],
                        [  4737,   4624],
                        [  5339,   5241],
                        [  5837,   5749],
                        [  6231,   6151],
                        [  6524,   6447],
                        [  6715,   6641],
                        [  6810,   6736],
                        [  6810,   6741],
                        [  6723,   6666],
                        [  6552,   6519],
                        [  6305,   6309],
                        [  5993,   6044],
                        [  5625,   5731],
                        [  5211,   5367],
                        [  4759,   4959],
                        [  4279,   4507],
                        [  3774,   4017],
                        [  3254,   3495],
                        [  2725,   2950],
                        [  2194,   2388],
                        [  1665,   1815],
                        [  1147,   1242],
                        [   644,    670],
                        [   160,    112],
                        [  -300,   -429],
                        [  -735,   -950],
                        [ -1143,  -1449],
                        [ -1523,  -1920],
                        [ -1874,  -2363],
                        [ -2193,  -2776],
                        [ -2479,  -3155],
                        [ -2732,  -3501],
                        [ -2949,  -3811],
                        [ -3132,  -4086],
                        [ -3281,  -4325],
                        [ -3395,  -4528],
                        [ -3475,  -4695],
                        [ -3524,  -4828],
                        [ -3542,  -4927],
                        [ -3531,  -4993],
                        [ -3493,  -5028],
                        [ -3437,  -5034],
                        [ -3363,  -5012],
                        [ -3285,  -4964],
                        [ -3205,  -4891],
                        [ -3125,  -4799],
                        [ -3050,  -4686],
                        [ -2968,  -4555],
                        [ -2884,  -4410],
                        [ -2784,  -4253],
                        [ -2671,  -4086],
                        [ -2544,  -3911],
                        [ -2407,  -3732],
                        [ -2260,  -3549],
                        [ -2108,  -3365],
                        [ -1952,  -3183],
                        [ -1796,  -3005],
                        [ -1642,  -2832],
                        [ -1490,  -2666],
                        [ -1345,  -2508],
                        [ -1206,  -2362],
                        [ -1081,  -2231],
                        [  -972,  -2118],
                        [  -913,  -2057],
                        [  -903,  -2045],
                        [  -956,  -2098],
                        [ -1071,  -2212],
                        [ -1222,  -2363],
                        [ -1412,  -2551],
                        [ -1585,  -2721],
                        [ -1744,  -2875],
                        [ -1882,  -3006],
                        [ -1997,  -3113],
                        [ -2095,  -3200],
                        [ -2174,  -3269],
                        [ -2240,  -3324],
                        [ -2290,  -3364],
                        [ -2331,  -3398],
                        [ -2360,  -3421],
                        [ -2382,  -3439],
                        [ -2394,  -3448],
                        [ -2399,  -3451],
                        [ -2395,  -3444],
                        [ -2385,  -3428],
                        [ -2365,  -3401],
                        [ -2338,  -3365],
                        [ -2302,  -3317],
                        [ -2256,  -3258],
                        [ -2197,  -3183],
                        [ -2125,  -3092],
                        [ -2035,  -2983],
                        [ -1926,  -2851],
                        [ -1796,  -2698],
                        [ -1641,  -2520],
                        [ -1462,  -2317],
                        [ -1255,  -2087],
                        [ -1021,  -1827],
                        [  -760,  -1540],
                        [  -469,  -1222],
                        [  -149,   -876],
                        [   199,   -501],
                        [   575,    -98],
                        [   977,    331],
                        [  1408,    787],
                        [  1861,   1265],
                        [  2338,   1766],
                        [  2836,   2289],
                        [  3352,   2831],
                        [  3880,   3382],
                        [  4423,   3951],
                        [  4978,   4532],
                        [  5480,   5055],
                        [  5835,   5429],
                        [  6011,   5620],
                        [  6002,   5621],
                        [  5782,   5410],
                        [  5320,   4955],
                        [  4681,   4323],
                        [  4010,   3659],
                        [  3375,   3033],
                        [  2771,   2439],
                        [  2205,   1886],
                        [  1689,   1385],
                        [  1228,    941],
                        [   823,    558],
                        [   481,    238],
                        [   199,    -17],
                        [   -20,   -206],
                        [  -176,   -332],
                        [  -268,   -401],
                        [  -301,   -412],
                        [  -273,   -379],
                        [  -190,   -306],
                        [   -57,   -201],
                        [   122,    -71],
                        [   337,     89],
                        [   583,    269],
                        [   856,    483],
                        [  1150,    722],
                        [  1463,    993],
                        [  1789,   1291],
                        [  2127,   1614],
                        [  2472,   1958],
                        [  2823,   2322],
                        [  3175,   2703],
                        [  3526,   3092],
                        [  3874,   3489],
                        [  4219,   3888],
                        [  4561,   4287],
                        [  4898,   4685],
                        [  5232,   5083],
                        [  5563,   5480],
                        [  5892,   5873],
                        [  6218,   6264],
                        [  6540,   6652],
                        [  6857,   7035],
                        [  7170,   7414],
                        [  7477,   7789],
                        [  7780,   8158],
                        [  8075,   8521],
                        [  8364,   8877],
                        [  8645,   9226],
                        [  8918,   9566],
                        [  9184,   9898],
                        [  9443,  10220],
                        [  9702,  10528],
                        [  9962,  10825],
                        [ 10227,  11106],
                        [ 10496,  11373],
                        [ 10763,  11620],
                        [ 11028,  11848],
                        [ 11271,  12054],
                        [ 11491,  12238],
                        [ 11677,  12397],
                        [ 11827,  12529],
                        [ 11939,  12633],
                        [ 12011,  12708],
                        [ 12044,  12751],
                        [ 12034,  12762],
                        [ 11983,  12740],
                        [ 11890,  12684],
                        [ 11754,  12591],
                        [ 11576,  12464],
                        [ 11358,  12301],
                        [ 11100,  12104],
                        [ 10832,  11900],
                        [ 10554,  11688],
                        [ 10304,  11507],
                        [ 10082,  11352],
                        [  9886,  11225],
                        [  9718,  11123],
                        [  9524,  10992],
                        [  9311,  10838],
                        [  9037,  10618],
                        [  8704,  10333],
                        [  8320,   9993],
                        [  7887,   9596],
                        [  7413,   9154],
                        [  6901,   8666],
                        [  6361,   8146],
                        [  5795,   7596],
                        [  5213,   7028],
                        [  4617,   6441],
                        [  4019,   5846],
                        [  3418,   5243],
                        [  2825,   4642],
                        [  2240,   4042],
                        [  1674,   3453],
                        [  1125,   2875],
                        [   602,   2315],
                        [   106,   1775],
                        [  -360,   1259],
                        [  -796,    768],
                        [ -1202,    302],
                        [ -1575,   -137],
                        [ -1920,   -548],
                        [ -2234,   -933],
                        [ -2520,  -1289],
                        [ -2776,  -1619],
                        [ -3005,  -1922],
                        [ -3208,  -2199],
                        [ -3387,  -2451],
                        [ -3541,  -2676],
                        [ -3675,  -2880],
                        [ -3788,  -3060],
                        [ -3883,  -3220],
                        [ -3963,  -3359],
                        [ -4029,  -3482],
                        [ -4081,  -3585],
                        [ -4124,  -3677],
                        [ -4154,  -3754],
                        [ -4171,  -3816],
                        [ -4180,  -3872],
                        [ -4186,  -3920],
                        [ -4120,  -3894],
                        [ -3920,  -3725],
                        [ -3566,  -3395],
                        [ -3058,  -2901],
                        [ -2373,  -2222],
                        [ -1473,  -1325],
                        [  -417,   -264],
                        [   659,    820],
                        [  1695,   1868],
                        [  2694,   2880],
                        [  3643,   3843],
                        [  4528,   4742],
                        [  5340,   5566],
                        [  6073,   6311],
                        [  6720,   6968],
                        [  7280,   7534],
                        [  7748,   8006],
                        [  8123,   8387],
                        [  8405,   8673],
                        [  8595,   8877],
                        [  8696,   9000],
                        [  8712,   9055],
                        [  8648,   9048],
                        [  8516,   8986],
                        [  8319,   8875],
                        [  8071,   8712],
                        [  7778,   8504],
                        [  7448,   8244],
                        [  7087,   7941],
                        [  6702,   7594],
                        [  6300,   7213],
                        [  5890,   6801],
                        [  5475,   6364],
                        [  5065,   5911],
                        [  4664,   5446],
                        [  4277,   4984],
                        [  3908,   4527],
                        [  3560,   4084],
                        [  3238,   3660],
                        [  2939,   3257],
                        [  2667,   2878],
                        [  2420,   2524],
                        [  2203,   2198],
                        [  2013,   1901],
                        [  1851,   1635],
                        [  1718,   1399],
                        [  1611,   1192],
                        [  1532,   1016],
                        [  1478,    870],
                        [  1446,    750],
                        [  1438,    657],
                        [  1448,    590],
                        [  1475,    544],
                        [  1508,    519],
                        [  1546,    513],
                        [  1577,    522],
                        [  1598,    546],
                        [  1604,    581],
                        [  1591,    625],
                        [  1569,    675],
                        [  1534,    730],
                        [  1501,    787],
                        [  1468,    844],
                        [  1438,    899],
                        [  1409,    950],
                        [  1381,    996],
                        [  1353,   1035],
                        [  1323,   1066],
                        [  1290,   1088],
                        [  1259,   1102],
                        [  1224,   1106],
                        [  1187,   1099],
                        [  1146,   1081],
                        [  1090,   1039],
                        [  1019,    975],
                        [   882,    839],
                        [   683,    634],
                        [   407,    346],
                        [    56,    -23],
                        [  -345,   -444],
                        [  -794,   -919],
                        [ -1212,  -1366],
                        [ -1602,  -1788],
                        [ -1946,  -2165],
                        [ -2243,  -2494],
                        [ -2491,  -2778],
                        [ -2689,  -3013],
                        [ -2841,  -3202],
                        [ -2942,  -3344],
                        [ -2997,  -3442],
                        [ -3005,  -3495],
                        [ -2971,  -3507],
                        [ -2890,  -3474],
                        [ -2771,  -3402],
                        [ -2609,  -3287],
                        [ -2412,  -3134],
                        [ -2176,  -2938],
                        [ -1909,  -2708],
                        [ -1611,  -2442],
                        [ -1285,  -2143],
                        [  -930,  -1811],
                        [  -550,  -1448],
                        [  -143,  -1054],
                        [   289,   -630],
                        [   745,   -176],
                        [  1225,    305],
                        [  1727,    811],
                        [  2247,   1342],
                        [  2785,   1896],
                        [  3338,   2467],
                        [  3904,   3055],
                        [  4479,   3658],
                        [  5063,   4271],
                        [  5650,   4890],
                        [  6240,   5514],
                        [  6827,   6138],
                        [  7409,   6758],
                        [  7981,   7372],
                        [  8541,   7977],
                        [  9077,   8566],
                        [  9587,   9135],
                        [ 10072,   9687],
                        [ 10523,  10212],
                        [ 10887,  10649],
                        [ 11109,  10945],
                        [ 11187,  11091],
                        [ 11114,  11078],
                        [ 10859,  10878],
                        [ 10381,  10447],
                        [  9718,   9828],
                        [  8982,   9132],
                        [  8221,   8405],
                        [  7433,   7646],
                        [  6632,   6872],
                        [  5835,   6099],
                        [  5051,   5337],
                        [  4289,   4595],
                        [  3560,   3882],
                        [  2871,   3209],
                        [  2230,   2579],
                        [  1640,   1999],
                        [  1111,   1468],
                        [   642,    990],
                        [   240,    560],
                        [   -97,    176],
                        [  -369,   -167],
                        [  -578,   -469],
                        [  -727,   -727],
                        [  -822,   -945],
                        [  -866,  -1109],
                        [  -859,  -1222],
                        [  -805,  -1276],
                        [  -709,  -1274],
                        [  -572,  -1214],
                        [  -401,  -1099],
                        [  -196,   -927],
                        [    37,   -705],
                        [   293,   -440],
                        [   570,   -136],
                        [   862,    197],
                        [  1169,    553],
                        [  1487,    930],
                        [  1814,   1322],
                        [  2149,   1728],
                        [  2490,   2143],
                        [  2832,   2566],
                        [  3176,   2992],
                        [  3517,   3419],
                        [  3854,   3844],
                        [  4182,   4263],
                        [  4500,   4675],
                        [  4805,   5074],
                        [  5096,   5460],
                        [  5370,   5830],
                        [  5623,   6181],
                        [  5858,   6510],
                        [  6074,   6817],
                        [  6277,   7096],
                        [  6464,   7348],
                        [  6644,   7571],
                        [  6812,   7762],
                        [  6966,   7919],
                        [  7105,   8041],
                        [  7216,   8127],
                        [  7295,   8176],
                        [  7333,   8187],
                        [  7329,   8159],
                        [  7280,   8091],
                        [  7187,   7984],
                        [  7050,   7838],
                        [  6868,   7653],
                        [  6642,   7430],
                        [  6371,   7167],
                        [  6056,   6866],
                        [  5701,   6532],
                        [  5311,   6166],
                        [  4887,   5771],
                        [  4474,   5391],
                        [  4071,   5024],
                        [  3721,   4713],
                        [  3426,   4457],
                        [  3187,   4258],
                        [  3007,   4120],
                        [  2830,   3983],
                        [  2659,   3851],
                        [  2442,   3669],
                        [  2181,   3441],
                        [  1881,   3170],
                        [  1543,   2858],
                        [  1171,   2507],
                        [   766,   2121],
                        [   337,   1709],
                        [  -116,   1269],
                        [  -585,    812],
                        [ -1068,    338],
                        [ -1558,   -143],
                        [ -2052,   -632],
                        [ -2545,  -1123],
                        [ -3033,  -1614],
                        [ -3508,  -2095],
                        [ -3972,  -2571],
                        [ -4418,  -3031],
                        [ -4843,  -3476],
                        [ -5246,  -3902],
                        [ -5625,  -4307],
                        [ -5981,  -4693],
                        [ -6315,  -5058],
                        [ -6626,  -5402],
                        [ -6914,  -5726],
                        [ -7182,  -6030],
                        [ -7427,  -6312],
                        [ -7653,  -6576],
                        [ -7859,  -6820],
                        [ -8046,  -7045],
                        [ -8217,  -7253],
                        [ -8372,  -7443],
                        [ -8509,  -7616],
                        [ -8634,  -7774],
                        [ -8747,  -7915],
                        [ -8845,  -8043],
                        [ -8930,  -8156],
                        [ -9001,  -8258],
                        [ -9052,  -8346],
                        [ -9081,  -8420],
                        [ -9094,  -8486],
                        [ -9089,  -8536],
                        [ -9022,  -8530],
                        [ -8877,  -8439],
                        [ -8656,  -8267],
                        [ -8357,  -8010],
                        [ -7950,  -7636],
                        [ -7388,  -7100],
                        [ -6691,  -6424],
                        [ -5942,  -5692],
                        [ -5178,  -4939],
                        [ -4398,  -4167],
                        [ -3616,  -3389],
                        [ -2847,  -2624],
                        [ -2102,  -1881],
                        [ -1386,  -1168],
                        [  -710,   -494],
                        [   -81,    132],
                        [   496,    705],
                        [  1015,   1224],
                        [  1474,   1684],
                        [  1869,   2090],
                        [  2199,   2441],
                        [  2468,   2747],
                        [  2675,   3010],
                        [  2826,   3235],
                        [  2924,   3422],
                        [  2978,   3572],
                        [  2989,   3686],
                        [  2964,   3755],
                        [  2906,   3785],
                        [  2821,   3771],
                        [  2715,   3718],
                        [  2591,   3625],
                        [  2455,   3497],
                        [  2312,   3338],
                        [  2164,   3152],
                        [  2017,   2952],
                        [  1873,   2740],
                        [  1737,   2529],
                        [  1610,   2321],
                        [  1489,   2117],
                        [  1381,   1920],
                        [  1281,   1731],
                        [  1190,   1553],
                        [  1109,   1385],
                        [  1038,   1228],
                        [   973,   1082],
                        [   919,    947],
                        [   873,    825],
                        [   831,    711],
                        [   795,    606],
                        [   762,    510],
                        [   730,    421],
                        [   698,    336],
                        [   657,    254],
                        [   606,    176],
                        [   536,     98],
                        [   447,     20],
                        [   332,    -62],
                        [   189,   -146],
                        [    26,   -235],
                        [  -160,   -331],
                        [  -357,   -432],
                        [  -563,   -540],
                        [  -775,   -656],
                        [  -990,   -778],
                        [ -1208,   -907],
                        [ -1428,  -1043],
                        [ -1646,  -1185],
                        [ -1862,  -1333],
                        [ -2071,  -1483],
                        [ -2273,  -1635],
                        [ -2467,  -1789],
                        [ -2653,  -1945],
                        [ -2845,  -2118],
                        [ -3043,  -2306],
                        [ -3298,  -2561],
                        [ -3606,  -2879],
                        [ -3977,  -3270],
                        [ -4412,  -3731],
                        [ -4888,  -4243],
                        [ -5406,  -4804],
                        [ -5878,  -5325],
                        [ -6309,  -5810],
                        [ -6677,  -6237],
                        [ -6981,  -6602],
                        [ -7216,  -6903],
                        [ -7381,  -7136],
                        [ -7476,  -7303],
                        [ -7500,  -7400],
                        [ -7455,  -7431],
                        [ -7340,  -7393],
                        [ -7161,  -7292],
                        [ -6916,  -7127],
                        [ -6612,  -6902],
                        [ -6250,  -6619],
                        [ -5837,  -6280],
                        [ -5373,  -5887],
                        [ -4869,  -5451],
                        [ -4325,  -4968],
                        [ -3749,  -4449],
                        [ -3144,  -3894],
                        [ -2514,  -3311],
                        [ -1862,  -2700],
                        [ -1194,  -2065],
                        [  -510,  -1410],
                        [   182,   -740],
                        [   882,    -56],
                        [  1581,    634],
                        [  2277,   1326],
                        [  2966,   2017],
                        [  3644,   2701],
                        [  4305,   3374],
                        [  4947,   4032],
                        [  5565,   4671],
                        [  6156,   5286],
                        [  6716,   5872],
                        [  7241,   6426],
                        [  7722,   6944],
                        [  8158,   7424],
                        [  8538,   7861],
                        [  8858,   8251],
                        [  9122,   8596],
                        [  9320,   8886],
                        [  9440,   9098],
                        [  9478,   9231],
                        [  9452,   9290],
                        [  9354,   9271],
                        [  9155,   9141],
                        [  8805,   8851],
                        [  8301,   8397],
                        [  7695,   7835],
                        [  7015,   7189],
                        [  6264,   6463],
                        [  5459,   5678],
                        [  4619,   4849],
                        [  3755,   3989],
                        [  2878,   3112],
                        [  2004,   2231],
                        [  1142,   1358],
                        [   307,    505],
                        [  -496,   -320],
                        [ -1253,  -1111],
                        [ -1958,  -1858],
                        [ -2607,  -2566],
                        [ -3195,  -3229],
                        [ -3716,  -3846],
                        [ -4170,  -4417],
                        [ -4559,  -4938],
                        [ -4881,  -5408],
                        [ -5139,  -5817],
                        [ -5333,  -6164],
                        [ -5467,  -6442],
                        [ -5543,  -6652],
                        [ -5563,  -6787],
                        [ -5533,  -6850],
                        [ -5457,  -6841],
                        [ -5337,  -6764],
                        [ -5181,  -6627],
                        [ -4991,  -6432],
                        [ -4774,  -6197],
                        [ -4534,  -5924],
                        [ -4277,  -5625],
                        [ -4006,  -5302],
                        [ -3725,  -4960],
                        [ -3437,  -4604],
                        [ -3146,  -4240],
                        [ -2856,  -3871],
                        [ -2571,  -3503],
                        [ -2295,  -3140],
                        [ -2032,  -2785],
                        [ -1785,  -2445],
                        [ -1558,  -2121],
                        [ -1353,  -1818],
                        [ -1172,  -1540],
                        [ -1019,  -1289],
                        [  -891,  -1066],
                        [  -792,   -874],
                        [  -717,   -717],
                        [  -666,   -595],
                        [  -635,   -509],
                        [  -627,   -462],
                        [  -638,   -453],
                        [  -669,   -481],
                        [  -726,   -548],
                        [  -811,   -655],
                        [  -930,   -798],
                        [ -1081,   -978],
                        [ -1268,  -1194],
                        [ -1488,  -1444],
                        [ -1740,  -1726],
                        [ -2022,  -2037],
                        [ -2335,  -2377],
                        [ -2680,  -2746],
                        [ -3051,  -3137],
                        [ -3445,  -3549],
                        [ -3855,  -3972],
                        [ -4280,  -4407],
                        [ -4673,  -4806],
                        [ -5032,  -5168],
                        [ -5324,  -5459],
                        [ -5549,  -5680],
                        [ -5696,  -5819],
                        [ -5764,  -5877],
                        [ -5805,  -5905],
                        [ -5813,  -5899],
                        [ -5842,  -5913],
                        [ -5888,  -5944],
                        [ -5955,  -5995],
                        [ -6039,  -6062],
                        [ -6145,  -6151],
                        [ -6270,  -6259],
                        [ -6415,  -6385],
                        [ -6578,  -6529],
                        [ -6756,  -6689],
                        [ -6949,  -6862],
                        [ -7153,  -7044],
                        [ -7369,  -7239],
                        [ -7592,  -7438],
                        [ -7820,  -7646],
                        [ -8050,  -7854],
                        [ -8282,  -8065],
                        [ -8509,  -8274],
                        [ -8733,  -8479],
                        [ -8951,  -8679],
                        [ -9162,  -8874],
                        [ -9366,  -9062],
                        [ -9564,  -9245],
                        [ -9756,  -9423],
                        [ -9941,  -9594],
                        [-10120,  -9761],
                        [-10291,  -9922],
                        [-10455, -10077],
                        [-10612, -10225],
                        [-10762, -10367],
                        [-10905, -10502],
                        [-11038, -10629],
                        [-11162, -10749],
                        [-11278, -10860],
                        [-11386, -10963],
                        [-11478, -11055],
                        [-11559, -11138],
                        [-11616, -11209],
                        [-11647, -11268],
                        [-11651, -11312],
                        [-11628, -11343],
                        [-11577, -11357],
                        [-11501, -11356],
                        [-11434, -11360],
                        [-11385, -11381],
                        [-11350, -11408],
                        [-11298, -11415],
                        [-11175, -11343],
                        [-10948, -11161],
                        [-10632, -10886],
                        [-10246, -10534],
                        [ -9791, -10109],
                        [ -9279,  -9622],
                        [ -8721,  -9085],
                        [ -8128,  -8511],
                        [ -7507,  -7904],
                        [ -6868,  -7278],
                        [ -6221,  -6643],
                        [ -5575,  -6004],
                        [ -4934,  -5367],
                        [ -4306,  -4740],
                        [ -3699,  -4124],
                        [ -3114,  -3524],
                        [ -2559,  -2937],
                        [ -2035,  -2365],
                        [ -1542,  -1809],
                        [ -1083,  -1271],
                        [  -657,   -752],
                        [  -262,   -254],
                        [   102,    214],
                        [   433,    650],
                        [   736,   1047],
                        [  1012,   1408],
                        [  1261,   1724],
                        [  1486,   1996],
                        [  1688,   2225],
                        [  1869,   2414],
                        [  2028,   2568],
                        [  2171,   2693],
                        [  2299,   2796],
                        [  2411,   2879],
                        [  2507,   2944],
                        [  2592,   2992],
                        [  2659,   3024],
                        [  2713,   3040],
                        [  2750,   3043],
                        [  2773,   3030],
                        [  2781,   3003],
                        [  2775,   2964],
                        [  2754,   2910],
                        [  2718,   2843],
                        [  2667,   2764],
                        [  2601,   2672],
                        [  2519,   2567],
                        [  2419,   2448],
                        [  2302,   2318],
                        [  2164,   2173],
                        [  2004,   2017],
                        [  1822,   1848],
                        [  1615,   1667],
                        [  1385,   1476],
                        [  1130,   1273],
                        [   853,   1060],
                        [   562,    838],
                        [   256,    608],
                        [   -55,    371],
                        [  -373,    129],
                        [  -691,   -117],
                        [ -1010,   -365],
                        [ -1324,   -614],
                        [ -1630,   -861],
                        [ -1922,  -1103],
                        [ -2201,  -1338],
                        [ -2465,  -1567],
                        [ -2712,  -1789],
                        [ -2957,  -2019],
                        [ -3199,  -2255],
                        [ -3475,  -2534],
                        [ -3782,  -2854],
                        [ -4130,  -3224],
                        [ -4515,  -3641],
                        [ -4930,  -4095],
                        [ -5375,  -4587],
                        [ -5776,  -5043],
                        [ -6137,  -5464],
                        [ -6438,  -5832],
                        [ -6681,  -6145],
                        [ -6856,  -6394],
                        [ -6964,  -6580],
                        [ -7001,  -6697],
                        [ -6969,  -6747],
                        [ -6866,  -6728],
                        [ -6693,  -6637],
                        [ -6455,  -6481],
                        [ -6151,  -6261],
                        [ -5788,  -5980],
                        [ -5367,  -5639],
                        [ -4896,  -5246],
                        [ -4377,  -4801],
                        [ -3819,  -4314],
                        [ -3226,  -3787],
                        [ -2604,  -3229],
                        [ -1960,  -2642],
                        [ -1298,  -2034],
                        [  -624,  -1408],
                        [    55,   -772],
                        [   739,   -128],
                        [  1418,    519],
                        [  2090,   1164],
                        [  2746,   1800],
                        [  3387,   2424],
                        [  4002,   3028],
                        [  4591,   3611],
                        [  5147,   4165],
                        [  5669,   4687],
                        [  6151,   5174],
                        [  6591,   5623],
                        [  6984,   6027],
                        [  7329,   6386],
                        [  7615,   6697],
                        [  7841,   6957],
                        [  8000,   7164],
                        [  8091,   7317],
                        [  8113,   7414],
                        [  8070,   7460],
                        [  8006,   7484],
                        [  7956,   7526],
                        [  7946,   7599],
                        [  7971,   7698],
                        [  8008,   7800],
                        [  8001,   7849],
                        [  7888,   7782],
                        [  7662,   7592],
                        [  7337,   7292],
                        [  6918,   6889],
                        [  6420,   6398],
                        [  5856,   5831],
                        [  5237,   5202],
                        [  4576,   4523],
                        [  3885,   3808],
                        [  3178,   3069],
                        [  2464,   2318],
                        [  1753,   1565],
                        [  1056,    821],
                        [   384,     93],
                        [  -258,   -612],
                        [  -860,  -1290],
                        [ -1420,  -1936],
                        [ -1929,  -2543],
                        [ -2388,  -3114],
                        [ -2793,  -3642],
                        [ -3144,  -4123],
                        [ -3441,  -4557],
                        [ -3686,  -4934],
                        [ -3881,  -5254],
                        [ -4027,  -5511],
                        [ -4127,  -5707],
                        [ -4186,  -5838],
                        [ -4206,  -5909],
                        [ -4190,  -5923],
                        [ -4145,  -5886],
                        [ -4076,  -5811],
                        [ -3985,  -5702],
                        [ -3881,  -5571],
                        [ -3766,  -5420],
                        [ -3644,  -5255],
                        [ -3520,  -5078],
                        [ -3397,  -4899],
                        [ -3279,  -4719],
                        [ -3169,  -4542],
                        [ -3070,  -4373],
                        [ -2989,  -4217],
                        [ -2925,  -4076],
                        [ -2882,  -3954],
                        [ -2862,  -3852],
                        [ -2866,  -3777],
                        [ -2894,  -3726],
                        [ -2948,  -3703],
                        [ -3027,  -3709],
                        [ -3130,  -3743],
                        [ -3258,  -3809],
                        [ -3408,  -3904],
                        [ -3580,  -4028],
                        [ -3768,  -4182],
                        [ -3971,  -4362],
                        [ -4185,  -4569],
                        [ -4412,  -4800],
                        [ -4650,  -5053],
                        [ -4900,  -5327],
                        [ -5160,  -5618],
                        [ -5429,  -5924],
                        [ -5706,  -6242],
                        [ -5987,  -6569],
                        [ -6274,  -6903],
                        [ -6566,  -7244],
                        [ -6858,  -7586],
                        [ -7148,  -7923],
                        [ -7428,  -8250],
                        [ -7698,  -8565],
                        [ -7925,  -8832],
                        [ -8107,  -9052],
                        [ -8227,  -9205],
                        [ -8283,  -9291],
                        [ -8261,  -9294],
                        [ -8160,  -9213],
                        [ -8013,  -9081],
                        [ -7817,  -8895],
                        [ -7616,  -8699],
                        [ -7404,  -8488],
                        [ -7193,  -8272],
                        [ -6979,  -8049],
                        [ -6775,  -7831],
                        [ -6578,  -7615],
                        [ -6393,  -7408],
                        [ -6222,  -7213],
                        [ -6068,  -7030],
                        [ -5930,  -6861],
                        [ -5810,  -6707],
                        [ -5709,  -6568],
                        [ -5627,  -6445],
                        [ -5564,  -6338],
                        [ -5519,  -6245],
                        [ -5491,  -6169],
                        [ -5479,  -6105],
                        [ -5483,  -6056],
                        [ -5500,  -6017],
                        [ -5531,  -5991],
                        [ -5573,  -5976],
                        [ -5627,  -5974],
                        [ -5692,  -5982],
                        [ -5768,  -6000],
                        [ -5852,  -6029],
                        [ -5943,  -6066],
                        [ -6039,  -6109],
                        [ -6139,  -6160],
                        [ -6240,  -6214],
                        [ -6342,  -6271],
                        [ -6442,  -6327],
                        [ -6537,  -6383],
                        [ -6627,  -6436],
                        [ -6706,  -6483],
                        [ -6771,  -6524],
                        [ -6820,  -6554],
                        [ -6840,  -6572],
                        [ -6830,  -6576],
                        [ -6788,  -6564],
                        [ -6706,  -6530],
                        [ -6602,  -6487],
                        [ -6533,  -6492],
                        [ -6556,  -6588],
                        [ -6684,  -6789],
                        [ -6913,  -7087],
                        [ -7222,  -7464],
                        [ -7547,  -7851],
                        [ -7796,  -8157],
                        [ -7929,  -8342],
                        [ -7954,  -8413],
                        [ -7874,  -8374],
                        [ -7695,  -8229],
                        [ -7425,  -7987],
                        [ -7069,  -7655],
                        [ -6637,  -7240],
                        [ -6137,  -6753],
                        [ -5578,  -6203],
                        [ -4969,  -5597],
                        [ -4318,  -4945],
                        [ -3634,  -4257],
                        [ -2924,  -3537],
                        [ -2198,  -2794],
                        [ -1465,  -2036],
                        [  -732,  -1269],
                        [    -7,   -499],
                        [   704,    271],
                        [  1399,   1038],
                        [  2072,   1797],
                        [  2719,   2540],
                        [  3339,   3263],
                        [  3928,   3954],
                        [  4483,   4613],
                        [  5005,   5228],
                        [  5491,   5796],
                        [  5939,   6315],
                        [  6349,   6784],
                        [  6719,   7203],
                        [  7051,   7573],
                        [  7344,   7905],
                        [  7600,   8196],
                        [  7819,   8447],
                        [  8002,   8660],
                        [  8147,   8834],
                        [  8256,   8969],
                        [  8329,   9068],
                        [  8367,   9131],
                        [  8372,   9159],
                        [  8346,   9154],
                        [  8288,   9117],
                        [  8202,   9049],
                        [  8088,   8951],
                        [  7947,   8827],
                        [  7781,   8678],
                        [  7592,   8504],
                        [  7382,   8309],
                        [  7153,   8094],
                        [  6910,   7862],
                        [  6653,   7614],
                        [  6382,   7352],
                        [  6102,   7080],
                        [  5808,   6798],
                        [  5502,   6510],
                        [  5186,   6217],
                        [  4862,   5923],
                        [  4535,   5630],
                        [  4209,   5339],
                        [  3887,   5055],
                        [  3571,   4776],
                        [  3266,   4508],
                        [  2975,   4253],
                        [  2706,   4014],
                        [  2455,   3791],
                        [  2228,   3586],
                        [  2023,   3399],
                        [  1833,   3218],
                        [  1658,   3049],
                        [  1483,   2872],
                        [  1311,   2693],
                        [  1132,   2499],
                        [   948,   2295],
                        [   750,   2069],
                        [   536,   1821],
                        [   349,   1595],
                        [   187,   1387],
                        [    61,   1211],
                        [   -28,   1067],
                        [   -72,    965],
                        [   -71,    904],
                        [   -22,    890],
                        [    74,    921],
                        [   219,   1002],
                        [   413,   1130],
                        [   651,   1307],
                        [   932,   1527],
                        [  1254,   1788],
                        [  1614,   2089],
                        [  2006,   2423],
                        [  2429,   2789],
                        [  2872,   3176],
                        [  3337,   3586],
                        [  3815,   4010],
                        [  4301,   4444],
                        [  4789,   4884],
                        [  5276,   5324],
                        [  5755,   5759],
                        [  6224,   6186],
                        [  6677,   6600],
                        [  7110,   6998],
                        [  7520,   7374],
                        [  7902,   7727],
                        [  8252,   8049],
                        [  8568,   8341],
                        [  8848,   8597],
                        [  9089,   8816],
                        [  9288,   8995],
                        [  9445,   9133],
                        [  9555,   9229],
                        [  9619,   9282],
                        [  9630,   9289],
                        [  9586,   9252],
                        [  9487,   9171],
                        [  9332,   9046],
                        [  9115,   8873],
                        [  8870,   8682],
                        [  8685,   8553],
                        [  8614,   8542],
                        [  8680,   8660],
                        [  8881,   8909],
                        [  9214,   9281],
                        [  9609,   9710],
                        [  9950,  10077],
                        [ 10186,  10331],
                        [ 10324,  10479],
                        [ 10370,  10526],
                        [ 10328,  10476],
                        [ 10205,  10338],
                        [ 10008,  10121],
                        [  9747,   9830],
                        [  9427,   9476],
                        [  9059,   9070],
                        [  8651,   8620],
                        [  8210,   8135],
                        [  7744,   7625],
                        [  7261,   7097],
                        [  6771,   6560],
                        [  6278,   6022],
                        [  5795,   5491],
                        [  5324,   4972],
                        [  4872,   4464],
                        [  4441,   3972],
                        [  4033,   3494],
                        [  3651,   3034],
                        [  3292,   2596],
                        [  2960,   2182],
                        [  2652,   1799],
                        [  2368,   1447],
                        [  2108,   1131],
                        [  1869,    848],
                        [  1649,    598],
                        [  1448,    379],
                        [  1261,    181],
                        [  1086,      6],
                        [   918,   -160],
                        [   756,   -316],
                        [   596,   -463],
                        [   436,   -606],
                        [   272,   -748],
                        [   106,   -892],
                        [   -67,  -1038],
                        [  -249,  -1190],
                        [  -440,  -1350],
                        [  -642,  -1519],
                        [  -855,  -1698],
                        [ -1080,  -1889],
                        [ -1315,  -2092],
                        [ -1563,  -2308],
                        [ -1821,  -2537],
                        [ -2090,  -2778],
                        [ -2370,  -3030],
                        [ -2662,  -3292],
                        [ -2966,  -3564],
                        [ -3281,  -3843],
                        [ -3598,  -4128],
                        [ -3917,  -4417],
                        [ -4226,  -4706],
                        [ -4524,  -4996],
                        [ -4805,  -5281],
                        [ -5069,  -5562],
                        [ -5314,  -5833],
                        [ -5539,  -6095],
                        [ -5743,  -6342],
                        [ -5922,  -6574],
                        [ -6080,  -6788],
                        [ -6216,  -6985],
                        [ -6326,  -7160],
                        [ -6409,  -7308],
                        [ -6465,  -7430],
                        [ -6491,  -7521],
                        [ -6481,  -7573],
                        [ -6433,  -7586],
                        [ -6348,  -7556],
                        [ -6226,  -7486],
                        [ -6047,  -7353],
                        [ -5810,  -7157],
                        [ -5522,  -6903],
                        [ -5182,  -6589],
                        [ -4815,  -6241],
                        [ -4419,  -5857],
                        [ -4009,  -5450],
                        [ -3583,  -5020],
                        [ -3156,  -4581],
                        [ -2726,  -4132],
                        [ -2306,  -3689],
                        [ -1895,  -3248],
                        [ -1501,  -2822],
                        [ -1125,  -2410],
                        [  -774,  -2018],
                        [  -445,  -1645],
                        [  -145,  -1297],
                        [   125,   -972],
                        [   367,   -672],
                        [   577,   -399],
                        [   757,   -150],
                        [   906,     71],
                        [  1028,    266],
                        [  1122,    436],
                        [  1191,    581],
                        [  1237,    704],
                        [  1260,    804],
                        [  1263,    884],
                        [  1250,    947],
                        [  1223,    990],
                        [  1184,   1021],
                        [  1136,   1040],
                        [  1082,   1051],
                        [  1025,   1057],
                        [   971,   1060],
                        [   918,   1061],
                        [   876,   1068],
                        [   843,   1078],
                        [   828,   1097],
                        [   834,   1128],
                        [   871,   1174],
                        [   934,   1233],
                        [  1034,   1315],
                        [  1175,   1423],
                        [  1315,   1518],
                        [  1364,   1508],
                        [  1259,   1341],
                        [   994,   1013],
                        [   564,    522],
                        [   -30,   -133],
                        [  -713,   -874],
                        [ -1343,  -1559],
                        [ -1857,  -2121],
                        [ -2256,  -2566],
                        [ -2545,  -2891],
                        [ -2719,  -3096],
                        [ -2783,  -3184],
                        [ -2739,  -3157],
                        [ -2594,  -3021],
                        [ -2352,  -2782],
                        [ -2022,  -2450],
                        [ -1610,  -2030],
                        [ -1124,  -1533],
                        [  -573,   -968],
                        [    34,   -345],
                        [   687,    327],
                        [  1372,   1030],
                        [  2081,   1757],
                        [  2800,   2502],
                        [  3522,   3252],
                        [  4240,   4011],
                        [  4947,   4770],
                        [  5636,   5527],
                        [  6303,   6274],
                        [  6940,   7000],
                        [  7544,   7701],
                        [  8111,   8366],
                        [  8637,   8990],
                        [  9119,   9567],
                        [  9553,  10095],
                        [  9938,  10571],
                        [ 10273,  10994],
                        [ 10558,  11367],
                        [ 10793,  11689],
                        [ 10980,  11961],
                        [ 11118,  12184],
                        [ 11211,  12357],
                        [ 11259,  12482],
                        [ 11262,  12561],
                        [ 11224,  12595],
                        [ 11148,  12586],
                        [ 11035,  12537],
                        [ 10888,  12449],
                        [ 10710,  12325],
                        [ 10505,  12169],
                        [ 10273,  11983],
                        [ 10021,  11771],
                        [  9748,  11535],
                        [  9463,  11280],
                        [  9169,  11009],
                        [  8876,  10723],
                        [  8586,  10428],
                        [  8303,  10125],
                        [  8029,   9818],
                        [  7759,   9510],
                        [  7494,   9204],
                        [  7227,   8903],
                        [  6962,   8608],
                        [  6702,   8324],
                        [  6446,   8051],
                        [  6199,   7792],
                        [  5962,   7549],
                        [  5740,   7323],
                        [  5532,   7117],
                        [  5344,   6932],
                        [  5175,   6769],
                        [  5025,   6626],
                        [  4898,   6506],
                        [  4794,   6408],
                        [  4713,   6334],
                        [  4666,   6293],
                        [  4652,   6282],
                        [  4662,   6294],
                        [  4695,   6326],
                        [  4720,   6348],
                        [  4739,   6361],
                        [  4755,   6367],
                        [  4763,   6362],
                        [  4774,   6356],
                        [  4786,   6348],
                        [  4805,   6344],
                        [  4831,   6343],
                        [  4869,   6353],
                        [  4916,   6371],
                        [  4977,   6403],
                        [  5050,   6448],
                        [  5134,   6506],
                        [  5230,   6576],
                        [  5338,   6658],
                        [  5454,   6749],
                        [  5579,   6846],
                        [  5709,   6945],
                        [  5843,   7046],
                        [  5980,   7147],
                        [  6114,   7242],
                        [  6245,   7332],
                        [  6367,   7412],
                        [  6478,   7482],
                        [  6576,   7535],
                        [  6658,   7573],
                        [  6720,   7590],
                        [  6763,   7588],
                        [  6784,   7563],
                        [  6782,   7514],
                        [  6754,   7438],
                        [  6702,   7337],
                        [  6623,   7209],
                        [  6517,   7053],
                        [  6383,   6869],
                        [  6223,   6658],
                        [  6034,   6422],
                        [  5818,   6162],
                        [  5572,   5876],
                        [  5297,   5568],
                        [  4995,   5241],
                        [  4666,   4894],
                        [  4302,   4522],
                        [  3965,   4187],
                        [  3762,   3990],
                        [  3742,   3980],
                        [  3916,   4164],
                        [  4297,   4554],
                        [  4895,   5159],
                        [  5635,   5905],
                        [  6365,   6638],
                        [  7017,   7289],
                        [  7596,   7863],
                        [  8101,   8357],
                        [  8526,   8769],
                        [  8869,   9094],
                        [  9133,   9336],
                        [  9320,   9498],
                        [  9430,   9580],
                        [  9468,   9589],
                        [  9434,   9528],
                        [  9334,   9403],
                        [  9172,   9220],
                        [  8954,   8985],
                        [  8686,   8710],
                        [  8375,   8400],
                        [  8032,   8067],
                        [  7662,   7715],
                        [  7269,   7342],
                        [  6859,   6953],
                        [  6433,   6539],
                        [  5997,   6108],
                        [  5551,   5657],
                        [  5099,   5192],
                        [  4643,   4718],
                        [  4183,   4237],
                        [  3722,   3754],
                        [  3262,   3269],
                        [  2804,   2786],
                        [  2348,   2306],
                        [  1896,   1830],
                        [  1445,   1357],
                        [   998,    884],
                        [   553,    411],
                        [   108,    -60],
                        [  -336,   -530],
                        [  -779,   -998],
                        [ -1221,  -1466],
                        [ -1662,  -1931],
                        [ -2101,  -2396],
                        [ -2536,  -2856],
                        [ -2970,  -3315],
                        [ -3398,  -3770],
                        [ -3820,  -4219],
                        [ -4236,  -4662],
                        [ -4643,  -5098],
                        [ -5041,  -5525],
                        [ -5429,  -5943],
                        [ -5813,  -6347],
                        [ -6190,  -6739],
                        [ -6566,  -7113],
                        [ -6937,  -7472],
                        [ -7298,  -7809],
                        [ -7646,  -8125],
                        [ -7964,  -8417],
                        [ -8255,  -8684],
                        [ -8505,  -8923],
                        [ -8716,  -9133],
                        [ -8886,  -9312],
                        [ -9014,  -9460],
                        [ -9099,  -9575],
                        [ -9142,  -9655],
                        [ -9145,  -9700],
                        [ -9106,  -9712],
                        [ -9029,  -9688],
                        [ -8911,  -9628],
                        [ -8759,  -9536],
                        [ -8573,  -9410],
                        [ -8377,  -9272],
                        [ -8169,  -9123],
                        [ -7963,  -8972],
                        [ -7759,  -8821],
                        [ -7534,  -8644],
                        [ -7290,  -8444],
                        [ -6997,  -8189],
                        [ -6658,  -7881],
                        [ -6281,  -7527],
                        [ -5866,  -7128],
                        [ -5428,  -6697],
                        [ -4964,  -6234],
                        [ -4491,  -5753],
                        [ -4007,  -5256],
                        [ -3525,  -4756],
                        [ -3046,  -4253],
                        [ -2579,  -3759],
                        [ -2125,  -3278],
                        [ -1691,  -2814],
                        [ -1279,  -2369],
                        [  -892,  -1947],
                        [  -534,  -1547],
                        [  -206,  -1174],
                        [    90,   -826],
                        [   353,   -507],
                        [   587,   -215],
                        [   790,     49],
                        [   964,    284],
                        [  1113,    496],
                        [  1239,    683],
                        [  1344,    849],
                        [  1431,    996],
                        [  1503,   1126],
                        [  1562,   1241],
                        [  1612,   1346],
                        [  1656,   1441],
                        [  1698,   1532],
                        [  1740,   1621],
                        [  1785,   1711],
                        [  1837,   1803],
                        [  1900,   1902],
                        [  1975,   2009],
                        [  2067,   2126],
                        [  2179,   2256],
                        [  2314,   2402],
                        [  2468,   2560],
                        [  2654,   2741],
                        [  2871,   2944],
                        [  3056,   3105],
                        [  3110,   3127],
                        [  2992,   2971],
                        [  2696,   2636],
                        [  2206,   2104],
                        [  1504,   1362],
                        [   666,    484],
                        [  -151,   -371],
                        [  -882,  -1133],
                        [ -1529,  -1810],
                        [ -2091,  -2394],
                        [ -2557,  -2877],
                        [ -2927,  -3257],
                        [ -3200,  -3532],
                        [ -3378,  -3706],
                        [ -3461,  -3778],
                        [ -3453,  -3755],
                        [ -3360,  -3642],
                        [ -3183,  -3443],
                        [ -2932,  -3170],
                        [ -2613,  -2832],
                        [ -2236,  -2438],
                        [ -1816,  -2009],
                        [ -1358,  -1549],
                        [  -878,  -1071],
                        [  -382,   -581],
                        [   122,    -77],
                        [   625,    432],
                        [  1121,    950],
                        [  1605,   1470],
                        [  2069,   1983],
                        [  2507,   2485],
                        [  2918,   2967],
                        [  3295,   3426],
                        [  3633,   3855],
                        [  3931,   4253],
                        [  4185,   4609],
                        [  4396,   4925],
                        [  4562,   5199],
                        [  4682,   5429],
                        [  4760,   5616],
                        [  4796,   5761],
                        [  4794,   5864],
                        [  4755,   5926],
                        [  4681,   5948],
                        [  4574,   5935],
                        [  4439,   5887],
                        [  4277,   5808],
                        [  4093,   5699],
                        [  3888,   5565],
                        [  3667,   5407],
                        [  3432,   5230],
                        [  3187,   5038],
                        [  2936,   4831],
                        [  2687,   4616],
                        [  2443,   4395],
                        [  2218,   4171],
                        [  2015,   3946],
                        [  1836,   3725],
                        [  1685,   3507],
                        [  1553,   3297],
                        [  1442,   3097],
                        [  1338,   2909],
                        [  1243,   2733],
                        [  1155,   2572],
                        [  1074,   2427],
                        [  1001,   2298],
                        [   935,   2186],
                        [   878,   2091],
                        [   830,   2013],
                        [   791,   1952],
                        [   761,   1909],
                        [   740,   1880],
                        [   728,   1867],
                        [   745,   1887],
                        [   787,   1939],
                        [   886,   2050],
                        [  1035,   2217],
                        [  1229,   2429],
                        [  1464,   2687],
                        [  1692,   2937],
                        [  1913,   3182],
                        [  2094,   3386],
                        [  2237,   3550],
                        [  2345,   3678],
                        [  2416,   3766],
                        [  2455,   3821],
                        [  2461,   3840],
                        [  2440,   3830],
                        [  2390,   3790],
                        [  2316,   3726],
                        [  2218,   3638],
                        [  2101,   3531],
                        [  1963,   3404],
                        [  1811,   3261],
                        [  1641,   3100],
                        [  1462,   2923],
                        [  1268,   2728],
                        [  1068,   2520],
                        [   859,   2295],
                        [   642,   2059],
                        [   418,   1810],
                        [   185,   1549],
                        [   -56,   1277],
                        [  -306,    994],
                        [  -564,    699],
                        [  -829,    392],
                        [ -1103,     75],
                        [ -1382,   -252],
                        [ -1667,   -588],
                        [ -1959,   -934],
                        [ -2255,  -1287],
                        [ -2554,  -1646],
                        [ -2856,  -2010],
                        [ -3161,  -2379],
                        [ -3466,  -2750],
                        [ -3772,  -3120],
                        [ -4075,  -3488],
                        [ -4376,  -3855],
                        [ -4673,  -4214],
                        [ -4961,  -4565],
                        [ -5246,  -4910],
                        [ -5530,  -5247],
                        [ -5737,  -5502],
                        [ -5783,  -5588],
                        [ -5635,  -5473],
                        [ -5289,  -5156],
                        [ -4721,  -4613],
                        [ -3909,  -3822],
                        [ -2923,  -2854],
                        [ -1914,  -1861],
                        [  -947,   -908],
                        [   -16,      7],
                        [   866,    876],
                        [  1686,   1683],
                        [  2438,   2420],
                        [  3114,   3082],
                        [  3712,   3665],
                        [  4223,   4164],
                        [  4649,   4578],
                        [  4982,   4904],
                        [  5226,   5146],
                        [  5380,   5306],
                        [  5445,   5384],
                        [  5428,   5395],
                        [  5333,   5342],
                        [  5169,   5236],
                        [  4941,   5078],
                        [  4653,   4870],
                        [  4312,   4617],
                        [  3921,   4305],
                        [  3486,   3943],
                        [  3010,   3527],
                        [  2499,   3062],
                        [  1957,   2554],
                        [  1389,   2004],
                        [   801,   1419],
                        [   194,    800],
                        [  -423,    159],
                        [ -1050,   -504],
                        [ -1679,  -1178],
                        [ -2311,  -1861],
                        [ -2939,  -2549],
                        [ -3563,  -3239],
                        [ -4181,  -3925],
                        [ -4791,  -4609],
                        [ -5392,  -5284],
                        [ -5978,  -5948],
                        [ -6549,  -6598],
                        [ -7102,  -7234],
                        [ -7635,  -7850],
                        [ -8147,  -8447],
                        [ -8634,  -9018],
                        [ -9095,  -9565],
                        [ -9528, -10082],
                        [ -9930, -10571],
                        [-10304, -11026],
                        [-10646, -11448],
                        [-10966, -11835],
                        [-11264, -12185],
                        [-11544, -12496],
                        [-11806, -12769],
                        [-12048, -13001],
                        [-12266, -13192],
                        [-12447, -13340],
                        [-12590, -13447],
                        [-12683, -13512],
                        [-12726, -13534],
                        [-12720, -13514],
                        [-12664, -13454],
                        [-12562, -13353],
                        [-12412, -13213],
                        [-12216, -13035],
                        [-11976, -12819],
                        [-11698, -12569],
                        [-11382, -12285],
                        [-11041, -11980],
                        [-10678, -11656],
                        [-10340, -11359],
                        [-10027, -11088],
                        [ -9757, -10860],
                        [ -9530, -10675],
                        [ -9323, -10510],
                        [ -9141, -10367],
                        [ -8920, -10181],
                        [ -8667,  -9958],
                        [ -8374,  -9692],
                        [ -8045,  -9384],
                        [ -7685,  -9041],
                        [ -7300,  -8666],
                        [ -6895,  -8267],
                        [ -6472,  -7846],
                        [ -6042,  -7414],
                        [ -5604,  -6971],
                        [ -5167,  -6530],
                        [ -4730,  -6088],
                        [ -4301,  -5655],
                        [ -3882,  -5228],
                        [ -3477,  -4815],
                        [ -3085,  -4413],
                        [ -2713,  -4026],
                        [ -2360,  -3652],
                        [ -2027,  -3296],
                        [ -1715,  -2956],
                        [ -1420,  -2633],
                        [ -1143,  -2327],
                        [  -879,  -2035],
                        [  -629,  -1758],
                        [  -388,  -1491],
                        [  -156,  -1233],
                        [    71,   -982],
                        [   293,   -735],
                        [   513,   -491],
                        [   733,   -247],
                        [   956,      0],
                        [  1181,    249],
                        [  1414,    503],
                        [  1653,    764],
                        [  1901,   1034],
                        [  2158,   1308],
                        [  2422,   1593],
                        [  2697,   1887],
                        [  2978,   2190],
                        [  3261,   2498],
                        [  3558,   2819],
                        [  3863,   3147],
                        [  4110,   3411],
                        [  4226,   3538],
                        [  4193,   3512],
                        [  4008,   3329],
                        [  3638,   2959],
                        [  3051,   2371],
                        [  2309,   1627],
                        [  1545,    861],
                        [   810,    127],
                        [   100,   -581],
                        [  -576,  -1250],
                        [ -1203,  -1868],
                        [ -1777,  -2428],
                        [ -2295,  -2927],
                        [ -2750,  -3359],
                        [ -3141,  -3722],
                        [ -3465,  -4016],
                        [ -3722,  -4244],
                        [ -3912,  -4405],
                        [ -4038,  -4503],
                        [ -4106,  -4550],
                        [ -4117,  -4550],
                        [ -4084,  -4518],
                        [ -4012,  -4461],
                        [ -3910,  -4385],
                        [ -3783,  -4297],
                        [ -3636,  -4190],
                        [ -3476,  -4073],
                        [ -3308,  -3936],
                        [ -3138,  -3785],
                        [ -2969,  -3621],
                        [ -2806,  -3450],
                        [ -2653,  -3271],
                        [ -2513,  -3089],
                        [ -2389,  -2907],
                        [ -2284,  -2729],
                        [ -2200,  -2563],
                        [ -2139,  -2408],
                        [ -2100,  -2273],
                        [ -2086,  -2159],
                        [ -2090,  -2062],
                        [ -2116,  -1987],
                        [ -2159,  -1932],
                        [ -2217,  -1893],
                        [ -2288,  -1872],
                        [ -2372,  -1866],
                        [ -2464,  -1873],
                        [ -2564,  -1892],
                        [ -2667,  -1919],
                        [ -2774,  -1954],
                        [ -2880,  -1995],
                        [ -2984,  -2039],
                        [ -3081,  -2083],
                        [ -3172,  -2126],
                        [ -3248,  -2166],
                        [ -3308,  -2201],
                        [ -3337,  -2230],
                        [ -3335,  -2250],
                        [ -3298,  -2261],
                        [ -3227,  -2263],
                        [ -3129,  -2253],
                        [ -3001,  -2231],
                        [ -2866,  -2199],
                        [ -2721,  -2154],
                        [ -2572,  -2099],
                        [ -2420,  -2032],
                        [ -2268,  -1956],
                        [ -2117,  -1870],
                        [ -1968,  -1776],
                        [ -1826,  -1677],
                        [ -1689,  -1574],
                        [ -1559,  -1467],
                        [ -1436,  -1357],
                        [ -1320,  -1246],
                        [ -1179,  -1098],
                        [ -1012,   -917],
                        [  -786,   -670],
                        [  -501,   -356],
                        [  -167,     13],
                        [   219,    438],
                        [   593,    855],
                        [   955,   1263],
                        [  1253,   1610],
                        [  1489,   1896],
                        [  1665,   2119],
                        [  1778,   2280],
                        [  1831,   2378],
                        [  1824,   2415],
                        [  1762,   2394],
                        [  1643,   2316],
                        [  1476,   2187],
                        [  1258,   2008],
                        [  1000,   1787],
                        [   699,   1521],
                        [   365,   1220],
                        [    -3,    883],
                        [  -396,    515],
                        [  -812,    117],
                        [ -1244,   -306],
                        [ -1691,   -752],
                        [ -2148,  -1213],
                        [ -2614,  -1690],
                        [ -3085,  -2177],
                        [ -3561,  -2672],
                        [ -4039,  -3171],
                        [ -4516,  -3674],
                        [ -4990,  -4179],
                        [ -5459,  -4682],
                        [ -5919,  -5181],
                        [ -6368,  -5674],
                        [ -6807,  -6160],
                        [ -7230,  -6633],
                        [ -7637,  -7093],
                        [ -8025,  -7538],
                        [ -8393,  -7965],
                        [ -8740,  -8372],
                        [ -9060,  -8756],
                        [ -9354,  -9115],
                        [ -9616,  -9448],
                        [ -9843,  -9752],
                        [-10035, -10025],
                        [-10198, -10270],
                        [-10328, -10480],
                        [-10366, -10593],
                        [-10268, -10559],
                        [-10027, -10374],
                        [ -9639, -10033],
                        [ -9072,  -9504],
                        [ -8291,  -8754],
                        [ -7344,  -7831],
                        [ -6347,  -6851],
                        [ -5344,  -5860],
                        [ -4336,  -4858],
                        [ -3339,  -3862],
                        [ -2372,  -2892],
                        [ -1445,  -1959],
                        [  -570,  -1075],
                        [   245,   -248],
                        [   989,    510],
                        [  1653,   1194],
                        [  2233,   1799],
                        [  2723,   2320],
                        [  3120,   2756],
                        [  3426,   3108],
                        [  3638,   3384],
                        [  3762,   3586],
                        [  3803,   3722],
                        [  3764,   3794],
                        [  3650,   3801],
                        [  3464,   3750],
                        [  3213,   3627],
                        [  2900,   3439],
                        [  2533,   3182],
                        [  2116,   2862],
                        [  1656,   2478],
                        [  1159,   2038],
                        [   633,   1542],
                        [    80,    996],
                        [  -488,    413],
                        [ -1069,   -206],
                        [ -1656,   -843],
                        [ -2243,  -1496],
                        [ -2826,  -2152],
                        [ -3399,  -2809],
                        [ -3960,  -3460],
                        [ -4505,  -4102],
                        [ -5031,  -4730],
                        [ -5533,  -5337],
                        [ -6009,  -5922],
                        [ -6455,  -6481],
                        [ -6871,  -7009],
                        [ -7251,  -7506],
                        [ -7595,  -7966],
                        [ -7902,  -8387],
                        [ -8169,  -8767],
                        [ -8396,  -9105],
                        [ -8585,  -9400],
                        [ -8733,  -9649],
                        [ -8852,  -9854],
                        [ -8942, -10012],
                        [ -9009, -10125],
                        [ -9055, -10191],
                        [ -9080, -10212],
                        [ -9085, -10190],
                        [ -9057, -10123],
                        [ -8999, -10013],
                        [ -8899,  -9864],
                        [ -8759,  -9676],
                        [ -8578,  -9451],
                        [ -8361,  -9192],
                        [ -8106,  -8902],
                        [ -7816,  -8581],
                        [ -7493,  -8232],
                        [ -7139,  -7858],
                        [ -6758,  -7462],
                        [ -6355,  -7049],
                        [ -5950,  -6639],
                        [ -5542,  -6231],
                        [ -5192,  -5885],
                        [ -4898,  -5598],
                        [ -4678,  -5389],
                        [ -4531,  -5258],
                        [ -4440,  -5182],
                        [ -4403,  -5165],
                        [ -4343,  -5124],
                        [ -4264,  -5066],
                        [ -4152,  -4975],
                        [ -4009,  -4852],
                        [ -3835,  -4698],
                        [ -3630,  -4513],
                        [ -3400,  -4301],
                        [ -3144,  -4063],
                        [ -2867,  -3804],
                        [ -2569,  -3523],
                        [ -2254,  -3228],
                        [ -1922,  -2917],
                        [ -1580,  -2598],
                        [ -1224,  -2268],
                        [  -862,  -1931],
                        [  -493,  -1586],
                        [  -123,  -1237],
                        [   250,   -882],
                        [   624,   -524],
                        [   998,   -163],
                        [  1371,    197],
                        [  1746,    560],
                        [  2123,    923],
                        [  2504,   1289],
                        [  2888,   1656],
                        [  3276,   2028],
                        [  3667,   2405],
                        [  4062,   2787],
                        [  4461,   3175],
                        [  4864,   3569],
                        [  5270,   3967],
                        [  5679,   4372],
                        [  6090,   4782],
                        [  6502,   5194],
                        [  6913,   5610],
                        [  7320,   6025],
                        [  7716,   6440],
                        [  8101,   6851],
                        [  8469,   7257],
                        [  8815,   7654],
                        [  9149,   8045],
                        [  9458,   8418],
                        [  9705,   8726],
                        [  9862,   8942],
                        [  9932,   9064],
                        [  9906,   9087],
                        [  9745,   8972],
                        [  9406,   8675],
                        [  8912,   8222],
                        [  8348,   7697],
                        [  7743,   7130],
                        [  7096,   6519],
                        [  6420,   5880],
                        [  5731,   5227],
                        [  5035,   4569],
                        [  4343,   3915],
                        [  3662,   3271],
                        [  3000,   2647],
                        [  2365,   2048],
                        [  1761,   1479],
                        [  1191,    939],
                        [   660,    436],
                        [   169,    -40],
                        [  -281,   -485],
                        [  -694,   -910],
                        [ -1070,  -1313],
                        [ -1412,  -1701],
                        [ -1723,  -2074],
                        [ -2003,  -2424],
                        [ -2255,  -2756],
                        [ -2481,  -3057],
                        [ -2684,  -3330],
                        [ -2865,  -3571],
                        [ -3028,  -3782],
                        [ -3174,  -3956],
                        [ -3304,  -4097],
                        [ -3421,  -4204],
                        [ -3527,  -4279],
                        [ -3621,  -4331],
                        [ -3707,  -4359],
                        [ -3785,  -4375],
                        [ -3854,  -4379],
                        [ -3913,  -4371],
                        [ -3967,  -4354],
                        [ -4008,  -4326],
                        [ -4039,  -4288],
                        [ -4060,  -4239],
                        [ -4068,  -4180],
                        [ -4065,  -4109],
                        [ -4049,  -4028],
                        [ -4019,  -3935],
                        [ -3976,  -3831],
                        [ -3917,  -3716],
                        [ -3843,  -3589],
                        [ -3755,  -3451],
                        [ -3651,  -3302],
                        [ -3527,  -3141],
                        [ -3384,  -2971],
                        [ -3212,  -2789],
                        [ -3010,  -2598],
                        [ -2780,  -2399],
                        [ -2522,  -2192],
                        [ -2238,  -1978],
                        [ -1931,  -1759],
                        [ -1620,  -1536],
                        [ -1307,  -1311],
                        [  -996,  -1085],
                        [  -692,   -860],
                        [  -398,   -637],
                        [  -116,   -419],
                        [   149,   -207],
                        [   393,     -7],
                        [   617,    181],
                        [   819,    359],
                        [  1000,    526],
                        [  1159,    681],
                        [  1341,    866],
                        [  1539,   1079],
                        [  1790,   1352],
                        [  2089,   1682],
                        [  2438,   2069],
                        [  2836,   2511],
                        [  3221,   2945],
                        [  3594,   3372],
                        [  3898,   3733],
                        [  4137,   4031],
                        [  4309,   4262],
                        [  4414,   4427],
                        [  4451,   4524],
                        [  4421,   4552],
                        [  4327,   4517],
                        [  4171,   4415],
                        [  3959,   4256],
                        [  3690,   4040],
                        [  3376,   3774],
                        [  3014,   3459],
                        [  2615,   3105],
                        [  2181,   2711],
                        [  1721,   2287],
                        [  1237,   1833],
                        [   740,   1358],
                        [   231,    863],
                        [  -284,    358],
                        [  -800,   -155],
                        [ -1314,   -669],
                        [ -1824,  -1181],
                        [ -2325,  -1686],
                        [ -2816,  -2182],
                        [ -3291,  -2667],
                        [ -3750,  -3138],
                        [ -4185,  -3590],
                        [ -4598,  -4023],
                        [ -4986,  -4433],
                        [ -5345,  -4818],
                        [ -5675,  -5175],
                        [ -5973,  -5502],
                        [ -6238,  -5800],
                        [ -6468,  -6064],
                        [ -6658,  -6293],
                        [ -6806,  -6485],
                        [ -6906,  -6643],
                        [ -6958,  -6762],
                        [ -6964,  -6843],
                        [ -6927,  -6888],
                        [ -6850,  -6890],
                        [ -6710,  -6828],
                        [ -6517,  -6702],
                        [ -6279,  -6519],
                        [ -5990,  -6275],
                        [ -5616,  -5938],
                        [ -5113,  -5462],
                        [ -4483,  -4849],
                        [ -3785,  -4159],
                        [ -3040,  -3414],
                        [ -2255,  -2621],
                        [ -1445,  -1797],
                        [  -631,   -962],
                        [   179,   -127],
                        [   970,    696],
                        [  1732,   1493],
                        [  2453,   2252],
                        [  3122,   2966],
                        [  3735,   3625],
                        [  4284,   4223],
                        [  4760,   4758],
                        [  5163,   5224],
                        [  5492,   5629],
                        [  5744,   5969],
                        [  5923,   6250],
                        [  6029,   6471],
                        [  6066,   6637],
                        [  6038,   6747],
                        [  5948,   6796],
                        [  5802,   6786],
                        [  5604,   6714],
                        [  5359,   6584],
                        [  5076,   6394],
                        [  4756,   6149],
                        [  4410,   5849],
                        [  4042,   5501],
                        [  3660,   5111],
                        [  3266,   4686],
                        [  2870,   4243],
                        [  2475,   3786],
                        [  2088,   3330],
                        [  1713,   2876],
                        [  1354,   2431],
                        [  1016,   2000],
                        [   701,   1588],
                        [   413,   1197],
                        [   154,    831],
                        [   -74,    494],
                        [  -269,    189],
                        [  -429,    -83],
                        [  -554,   -319],
                        [  -644,   -518],
                        [  -697,   -677],
                        [  -715,   -798],
                        [  -700,   -879],
                        [  -649,   -921],
                        [  -576,   -924],
                        [  -480,   -889],
                        [  -366,   -817],
                        [  -236,   -710],
                        [   -96,   -570],
                        [    53,   -397],
                        [   215,   -195],
                        [   390,     34],
                        [   585,    288],
                        [   798,    564],
                        [  1028,    858],
                        [  1273,   1168],
                        [  1534,   1492],
                        [  1808,   1827],
                        [  2096,   2173],
                        [  2395,   2528],
                        [  2701,   2882],
                        [  3010,   3236],
                        [  3303,   3568],
                        [  3577,   3875],
                        [  3782,   4106],
                        [  3920,   4264],
                        [  3976,   4333],
                        [  3950,   4315],
                        [  3859,   4224],
                        [  3698,   4058],
                        [  3551,   3900],
                        [  3410,   3743],
                        [  3296,   3608],
                        [  3205,   3491],
                        [  3146,   3402],
                        [  3119,   3341],
                        [  3126,   3310],
                        [  3167,   3311],
                        [  3243,   3343],
                        [  3354,   3408],
                        [  3499,   3505],
                        [  3681,   3634],
                        [  3894,   3793],
                        [  4139,   3982],
                        [  4414,   4199],
                        [  4717,   4444],
                        [  5044,   4713],
                        [  5397,   5010],
                        [  5769,   5328],
                        [  6160,   5668],
                        [  6571,   6026],
                        [  6998,   6403],
                        [  7440,   6793],
                        [  7898,   7198],
                        [  8367,   7616],
                        [  8847,   8046],
                        [  9335,   8487],
                        [  9828,   8937],
                        [ 10324,   9393],
                        [ 10820,   9854],
                        [ 11313,  10316],
                        [ 11800,  10779],
                        [ 12277,  11235],
                        [ 12742,  11686],
                        [ 13187,  12127],
                        [ 13609,  12553],
                        [ 13997,  12962],
                        [ 14348,  13350],
                        [ 14656,  13713],
                        [ 14917,  14047],
                        [ 15136,  14350],
                        [ 15307,  14617],
                        [ 15443,  14846],
                        [ 15560,  15056],
                        [ 15670,  15254],
                        [ 15763,  15431],
                        [ 15802,  15552],
                        [ 15736,  15562],
                        [ 15532,  15431],
                        [ 15215,  15181],
                        [ 14796,  14824],
                        [ 14279,  14366],
                        [ 13679,  13820],
                        [ 13009,  13199],
                        [ 12279,  12513],
                        [ 11498,  11773],
                        [ 10679,  10991],
                        [  9832,  10177],
                        [  8968,   9341],
                        [  8095,   8491],
                        [  7222,   7638],
                        [  6357,   6785],
                        [  5510,   5939],
                        [  4683,   5102],
                        [  3884,   4276],
                        [  3116,   3466],
                        [  2381,   2672],
                        [  1684,   1898],
                        [  1025,   1149],
                        [   406,    427],
                        [  -171,   -256],
                        [  -705,   -899],
                        [ -1198,  -1493],
                        [ -1648,  -2039],
                        [ -2055,  -2525],
                        [ -2420,  -2953],
                        [ -2745,  -3320],
                        [ -3028,  -3626],
                        [ -3271,  -3877],
                        [ -3475,  -4075],
                        [ -3641,  -4231],
                        [ -3769,  -4344],
                        [ -3863,  -4421],
                        [ -3924,  -4460],
                        [ -3954,  -4464],
                        [ -3952,  -4434],
                        [ -3921,  -4371],
                        [ -3862,  -4279],
                        [ -3777,  -4158],
                        [ -3666,  -4010],
                        [ -3533,  -3837],
                        [ -3376,  -3641],
                        [ -3200,  -3426],
                        [ -3006,  -3192],
                        [ -2794,  -2941],
                        [ -2568,  -2678],
                        [ -2326,  -2403],
                        [ -2072,  -2120],
                        [ -1802,  -1831],
                        [ -1518,  -1536],
                        [ -1221,  -1242],
                        [  -914,   -947],
                        [  -594,   -656],
                        [  -266,   -371],
                        [    59,    -93],
                        [   379,    176],
                        [   687,    433],
                        [   983,    676],
                        [  1260,    903],
                        [  1518,   1113],
                        [  1750,   1303],
                        [  1956,   1470],
                        [  2131,   1614],
                        [  2279,   1736],
                        [  2403,   1839],
                        [  2499,   1923],
                        [  2609,   2026],
                        [  2729,   2147],
                        [  2884,   2309],
                        [  3070,   2509],
                        [  3299,   2758],
                        [  3571,   3054],
                        [  3836,   3349],
                        [  4099,   3647],
                        [  4311,   3896],
                        [  4476,   4102],
                        [  4591,   4261],
                        [  4655,   4370],
                        [  4666,   4427],
                        [  4626,   4434],
                        [  4534,   4388],
                        [  4393,   4292],
                        [  4207,   4149],
                        [  3976,   3962],
                        [  3707,   3733],
                        [  3401,   3465],
                        [  3066,   3167],
                        [  2703,   2839],
                        [  2321,   2489],
                        [  1921,   2118],
                        [  1512,   1734],
                        [  1096,   1340],
                        [   681,    943],
                        [   267,    546],
                        [  -141,    156],
                        [  -540,   -226],
                        [  -925,   -595],
                        [ -1298,   -948],
                        [ -1651,  -1284],
                        [ -1984,  -1601],
                        [ -2295,  -1895],
                        [ -2580,  -2165],
                        [ -2838,  -2411],
                        [ -3069,  -2628],
                        [ -3270,  -2817],
                        [ -3441,  -2976],
                        [ -3580,  -3105],
                        [ -3685,  -3204],
                        [ -3750,  -3270],
                        [ -3775,  -3305],
                        [ -3755,  -3309],
                        [ -3690,  -3280],
                        [ -3585,  -3222],
                        [ -3438,  -3132],
                        [ -3266,  -3018],
                        [ -3103,  -2913],
                        [ -2995,  -2853],
                        [ -2953,  -2850],
                        [ -2972,  -2901],
                        [ -3026,  -2980],
                        [ -3058,  -3029],
                        [ -3010,  -2988],
                        [ -2878,  -2855],
                        [ -2671,  -2641],
                        [ -2397,  -2351],
                        [ -2068,  -2000],
                        [ -1694,  -1599],
                        [ -1288,  -1159],
                        [  -856,   -691],
                        [  -411,   -204],
                        [    38,    289],
                        [   483,    779],
                        [   917,   1260],
                        [  1332,   1722],
                        [  1720,   2160],
                        [  2077,   2571],
                        [  2399,   2953],
                        [  2680,   3302],
                        [  2921,   3619],
                        [  3121,   3902],
                        [  3280,   4154],
                        [  3400,   4376],
                        [  3482,   4563],
                        [  3528,   4718],
                        [  3543,   4837],
                        [  3529,   4922],
                        [  3490,   4968],
                        [  3430,   4977],
                        [  3354,   4948],
                        [  3265,   4884],
                        [  3166,   4790],
                        [  3062,   4669],
                        [  2956,   4535],
                        [  2853,   4391],
                        [  2754,   4249],
                        [  2667,   4113],
                        [  2593,   3985],
                        [  2535,   3868],
                        [  2496,   3765],
                        [  2478,   3680],
                        [  2481,   3612],
                        [  2507,   3567],
                        [  2555,   3543],
                        [  2625,   3542],
                        [  2718,   3564],
                        [  2832,   3610],
                        [  2966,   3679],
                        [  3121,   3772],
                        [  3292,   3887],
                        [  3480,   4024],
                        [  3678,   4180],
                        [  3888,   4356],
                        [  4104,   4547],
                        [  4325,   4752],
                        [  4544,   4969],
                        [  4758,   5197],
                        [  4964,   5431],
                        [  5162,   5670],
                        [  5353,   5912],
                        [  5536,   6153],
                        [  5710,   6391],
                        [  5875,   6626],
                        [  6032,   6853],
                        [  6178,   7071],
                        [  6320,   7282],
                        [  6451,   7483],
                        [  6572,   7668],
                        [  6680,   7838],
                        [  6760,   7973],
                        [  6812,   8075],
                        [  6807,   8111],
                        [  6746,   8086],
                        [  6620,   7987],
                        [  6429,   7815],
                        [  6179,   7576],
                        [  5866,   7265],
                        [  5553,   6945],
                        [  5238,   6615],
                        [  4938,   6290],
                        [  4652,   5974],
                        [  4395,   5678],
                        [  4165,   5402],
                        [  3969,   5155],
                        [  3810,   4939],
                        [  3690,   4760],
                        [  3612,   4617],
                        [  3577,   4515],
                        [  3587,   4457],
                        [  3641,   4439],
                        [  3738,   4464],
                        [  3877,   4530],
                        [  4058,   4636],
                        [  4275,   4780],
                        [  4530,   4961],
                        [  4814,   5175],
                        [  5130,   5421],
                        [  5471,   5693],
                        [  5837,   5991],
                        [  6221,   6309],
                        [  6624,   6645],
                        [  7038,   6996],
                        [  7462,   7358],
                        [  7888,   7727],
                        [  8316,   8101],
                        [  8738,   8476],
                        [  9152,   8848],
                        [  9552,   9211],
                        [  9933,   9561],
                        [ 10290,   9895],
                        [ 10622,  10207],
                        [ 10914,  10494],
                        [ 11168,  10753],
                        [ 11369,  10978],
                        [ 11514,  11165],
                        [ 11600,  11312],
                        [ 11625,  11416],
                        [ 11587,  11468],
                        [ 11503,  11486],
                        [ 11438,  11522],
                        [ 11439,  11623],
                        [ 11516,  11796],
                        [ 11662,  12034],
                        [ 11858,  12319],
                        [ 12038,  12580],
                        [ 12110,  12728],
                        [ 12047,  12732],
                        [ 11854,  12600],
                        [ 11538,  12337],
                        [ 11110,  11954],
                        [ 10577,  11457],
                        [  9950,  10857],
                        [  9239,  10166],
                        [  8455,   9394],
                        [  7609,   8554],
                        [  6713,   7659],
                        [  5775,   6717],
                        [  4810,   5741],
                        [  3827,   4743],
                        [  2839,   3729],
                        [  1855,   2710],
                        [   887,   1695],
                        [   -59,    691],
                        [  -973,   -293],
                        [ -1854,  -1257],
                        [ -2694,  -2192],
                        [ -3488,  -3093],
                        [ -4234,  -3955],
                        [ -4929,  -4773],
                        [ -5568,  -5536],
                        [ -6154,  -6245],
                        [ -6682,  -6884],
                        [ -7152,  -7456],
                        [ -7566,  -7955],
                        [ -7922,  -8382],
                        [ -8221,  -8738],
                        [ -8462,  -9025],
                        [ -8651,  -9256],
                        [ -8786,  -9430],
                        [ -8873,  -9551],
                        [ -8914,  -9622],
                        [ -8914,  -9646],
                        [ -8875,  -9625],
                        [ -8802,  -9564],
                        [ -8696,  -9464],
                        [ -8561,  -9329],
                        [ -8399,  -9164],
                        [ -8214,  -8972],
                        [ -8008,  -8756],
                        [ -7786,  -8520],
                        [ -7551,  -8267],
                        [ -7304,  -8002],
                        [ -7049,  -7729],
                        [ -6791,  -7449],
                        [ -6531,  -7168],
                        [ -6275,  -6888],
                        [ -6025,  -6611],
                        [ -5782,  -6342],
                        [ -5547,  -6082],
                        [ -5317,  -5835],
                        [ -5094,  -5601],
                        [ -4877,  -5383],
                        [ -4670,  -5182],
                        [ -4475,  -5000],
                        [ -4295,  -4839],
                        [ -4132,  -4700],
                        [ -3985,  -4581],
                        [ -3859,  -4485],
                        [ -3759,  -4415],
                        [ -3679,  -4367],
                        [ -3621,  -4340],
                        [ -3582,  -4331],
                        [ -3561,  -4338],
                        [ -3536,  -4339],
                        [ -3508,  -4334],
                        [ -3467,  -4314],
                        [ -3413,  -4277],
                        [ -3326,  -4205],
                        [ -3207,  -4096],
                        [ -3075,  -3971],
                        [ -2929,  -3827],
                        [ -2798,  -3694],
                        [ -2679,  -3569],
                        [ -2578,  -3459],
                        [ -2495,  -3363],
                        [ -2435,  -3287],
                        [ -2396,  -3231],
                        [ -2382,  -3196],
                        [ -2390,  -3184],
                        [ -2423,  -3196],
                        [ -2477,  -3228],
                        [ -2553,  -3283],
                        [ -2649,  -3358],
                        [ -2762,  -3450],
                        [ -2890,  -3557],
                        [ -3030,  -3676],
                        [ -3181,  -3803],
                        [ -3339,  -3936],
                        [ -3501,  -4072],
                        [ -3664,  -4207],
                        [ -3827,  -4340],
                        [ -3985,  -4467],
                        [ -4140,  -4587],
                        [ -4286,  -4695],
                        [ -4425,  -4792],
                        [ -4552,  -4876],
                        [ -4669,  -4947],
                        [ -4773,  -5003],
                        [ -4862,  -5044],
                        [ -4937,  -5068],
                        [ -4996,  -5077],
                        [ -5038,  -5068],
                        [ -5064,  -5041],
                        [ -5070,  -4997],
                        [ -5057,  -4937],
                        [ -5017,  -4859],
                        [ -4952,  -4765],
                        [ -4859,  -4655],
                        [ -4738,  -4531],
                        [ -4591,  -4392],
                        [ -4414,  -4234],
                        [ -4248,  -4090],
                        [ -4173,  -4040],
                        [ -4246,  -4132],
                        [ -4477,  -4378],
                        [ -4864,  -4777],
                        [ -5395,  -5316],
                        [ -5999,  -5922],
                        [ -6558,  -6478],
                        [ -7022,  -6935],
                        [ -7399,  -7299],
                        [ -7692,  -7572],
                        [ -7902,  -7758],
                        [ -8033,  -7861],
                        [ -8093,  -7888],
                        [ -8084,  -7844],
                        [ -8015,  -7736],
                        [ -7888,  -7573],
                        [ -7711,  -7360],
                        [ -7490,  -7105],
                        [ -7232,  -6815],
                        [ -6945,  -6497],
                        [ -6635,  -6155],
                        [ -6308,  -5796],
                        [ -5974,  -5428],
                        [ -5635,  -5055],
                        [ -5294,  -4678],
                        [ -4954,  -4298],
                        [ -4618,  -3919],
                        [ -4287,  -3538],
                        [ -3961,  -3156],
                        [ -3642,  -2777],
                        [ -3329,  -2403],
                        [ -3023,  -2039],
                        [ -2722,  -1688],
                        [ -2429,  -1355],
                        [ -2139,  -1038],
                        [ -1857,   -739],
                        [ -1580,   -457],
                        [ -1309,   -185],
                        [ -1042,     76],
                        [  -779,    334],
                        [  -518,    590],
                        [  -257,    843],
                        [     6,   1095],
                        [   270,   1346],
                        [   537,   1598],
                        [   804,   1849],
                        [  1074,   2101],
                        [  1343,   2352],
                        [  1612,   2602],
                        [  1878,   2851],
                        [  2141,   3099],
                        [  2400,   3343],
                        [  2653,   3585],
                        [  2898,   3822],
                        [  3136,   4053],
                        [  3368,   4277],
                        [  3594,   4493],
                        [  3813,   4699],
                        [  4027,   4895],
                        [  4226,   5077],
                        [  4410,   5247],
                        [  4570,   5402],
                        [  4705,   5541],
                        [  4813,   5663],
                        [  4893,   5767],
                        [  4947,   5852],
                        [  4973,   5917],
                        [  4976,   5965],
                        [  4955,   5991],
                        [  4916,   6001],
                        [  4856,   5992],
                        [  4778,   5963],
                        [  4681,   5915],
                        [  4563,   5841],
                        [  4426,   5744],
                        [  4267,   5620],
                        [  4088,   5471],
                        [  3883,   5289],
                        [  3652,   5076],
                        [  3382,   4814],
                        [  3075,   4507],
                        [  2757,   4182],
                        [  2429,   3838],
                        [  2106,   3490],
                        [  1787,   3139],
                        [  1488,   2799],
                        [  1207,   2470],
                        [   952,   2164],
                        [   728,   1879],
                        [   539,   1628],
                        [   385,   1410],
                        [   271,   1229],
                        [   197,   1088],
                        [   165,    989],
                        [   172,    930],
                        [   220,    910],
                        [   307,    930],
                        [   429,    984],
                        [   586,   1073],
                        [   770,   1190],
                        [   983,   1337],
                        [  1216,   1504],
                        [  1467,   1692],
                        [  1728,   1893],
                        [  2000,   2106],
                        [  2275,   2325],
                        [  2550,   2546],
                        [  2817,   2763],
                        [  3075,   2975],
                        [  3316,   3174],
                        [  3538,   3359],
                        [  3733,   3522],
                        [  3899,   3660],
                        [  4031,   3770],
                        [  4125,   3846],
                        [  4172,   3888],
                        [  4171,   3890],
                        [  4115,   3850],
                        [  4000,   3767],
                        [  3825,   3638],
                        [  3588,   3463],
                        [  3287,   3232],
                        [  2968,   2993],
                        [  2736,   2841],
                        [  2637,   2820],
                        [  2680,   2941],
                        [  2872,   3208],
                        [  3213,   3617],
                        [  3621,   4089],
                        [  3963,   4486],
                        [  4180,   4752],
                        [  4281,   4894],
                        [  4270,   4913],
                        [  4147,   4812],
                        [  3918,   4595],
                        [  3590,   4269],
                        [  3170,   3842],
                        [  2664,   3323],
                        [  2082,   2722],
                        [  1432,   2049],
                        [   726,   1315],
                        [   -28,    530],
                        [  -816,   -294],
                        [ -1625,  -1144],
                        [ -2446,  -2012],
                        [ -3264,  -2880],
                        [ -4071,  -3742],
                        [ -4862,  -4588],
                        [ -5626,  -5412],
                        [ -6358,  -6212],
                        [ -7053,  -6984],
                        [ -7706,  -7724],
                        [ -8313,  -8429],
                        [ -8871,  -9090],
                        [ -9376,  -9705],
                        [ -9830, -10263],
                        [-10229, -10765],
                        [-10573, -11204],
                        [-10862, -11582],
                        [-11095, -11897],
                        [-11273, -12152],
                        [-11400, -12352],
                        [-11477, -12500],
                        [-11508, -12601],
                        [-11498, -12656],
                        [-11451, -12668],
                        [-11371, -12641],
                        [-11264, -12578],
                        [-11130, -12484],
                        [-10974, -12362],
                        [-10801, -12217],
                        [-10612, -12051],
                        [-10412, -11870],
                        [-10204, -11675],
                        [ -9991, -11471],
                        [ -9776, -11263],
                        [ -9562, -11052],
                        [ -9355, -10843],
                        [ -9158, -10638],
                        [ -8980, -10440],
                        [ -8822, -10251],
                        [ -8686, -10072],
                        [ -8574,  -9906],
                        [ -8475,  -9754],
                        [ -8392,  -9618],
                        [ -8314,  -9497],
                        [ -8242,  -9392],
                        [ -8176,  -9302],
                        [ -8115,  -9230],
                        [ -8058,  -9172],
                        [ -8008,  -9128],
                        [ -7964,  -9099],
                        [ -7927,  -9085],
                        [ -7895,  -9083],
                        [ -7867,  -9089],
                        [ -7843,  -9102],
                        [ -7820,  -9121],
                        [ -7806,  -9150],
                        [ -7796,  -9185],
                        [ -7795,  -9229],
                        [ -7800,  -9280],
                        [ -7786,  -9310],
                        [ -7751,  -9319],
                        [ -7682,  -9291],
                        [ -7577,  -9222],
                        [ -7448,  -9126],
                        [ -7294,  -8999],
                        [ -7122,  -8851],
                        [ -6932,  -8678],
                        [ -6731,  -8490],
                        [ -6519,  -8286],
                        [ -6302,  -8074],
                        [ -6078,  -7851],
                        [ -5856,  -7627],
                        [ -5632,  -7399],
                        [ -5413,  -7173],
                        [ -5198,  -6949],
                        [ -4988,  -6729],
                        [ -4784,  -6513],
                        [ -4589,  -6299],
                        [ -4401,  -6090],
                        [ -4222,  -5881],
                        [ -4051,  -5676],
                        [ -3887,  -5472],
                        [ -3730,  -5270],
                        [ -3578,  -5070],
                        [ -3433,  -4872],
                        [ -3292,  -4674],
                        [ -3157,  -4479],
                        [ -3025,  -4283],
                        [ -2899,  -4088],
                        [ -2776,  -3894],
                        [ -2658,  -3702],
                        [ -2542,  -3510],
                        [ -2429,  -3319],
                        [ -2317,  -3129],
                        [ -2208,  -2940],
                        [ -2099,  -2753],
                        [ -1988,  -2567],
                        [ -1874,  -2384],
                        [ -1756,  -2204],
                        [ -1630,  -2025],
                        [ -1502,  -1854],
                        [ -1363,  -1684],
                        [ -1211,  -1515],
                        [ -1116,  -1404],
                        [ -1175,  -1454],
                        [ -1434,  -1707],
                        [ -1900,  -2167],
                        [ -2580,  -2842],
                        [ -3480,  -3739],
                        [ -4516,  -4770],
                        [ -5535,  -5783],
                        [ -6471,  -6712],
                        [ -7329,  -7561],
                        [ -8104,  -8325],
                        [ -8790,  -8997],
                        [ -9382,  -9573],
                        [ -9882, -10054],
                        [-10287, -10440],
                        [-10599, -10732],
                        [-10816, -10932],
                        [-10942, -11046],
                        [-10981, -11075],
                        [-10939, -11026],
                        [-10821, -10904],
                        [-10633, -10714],
                        [-10387, -10468],
                        [-10088, -10172],
                        [ -9742,  -9836],
                        [ -9355,  -9465],
                        [ -8930,  -9058],
                        [ -8474,  -8620],
                        [ -7992,  -8148],
                        [ -7486,  -7645],
                        [ -6961,  -7112],
                        [ -6420,  -6552],
                        [ -5870,  -5978],
                        [ -5310,  -5388],
                        [ -4744,  -4791],
                        [ -4177,  -4188],
                        [ -3613,  -3589],
                        [ -3054,  -2993],
                        [ -2503,  -2403],
                        [ -1962,  -1821],
                        [ -1434,  -1247],
                        [  -919,   -682],
                        [  -417,   -128],
                        [    72,    412],
                        [   547,    938],
                        [  1006,   1446],
                        [  1447,   1937],
                        [  1871,   2410],
                        [  2275,   2862],
                        [  2658,   3292],
                        [  3018,   3699],
                        [  3356,   4084],
                        [  3668,   4442],
                        [  3955,   4775],
                        [  4218,   5081],
                        [  4456,   5360],
                        [  4677,   5611],
                        [  4882,   5835],
                        [  5075,   6030],
                        [  5255,   6197],
                        [  5420,   6335],
                        [  5571,   6446],
                        [  5689,   6528],
                        [  5780,   6584],
                        [  5835,   6612],
                        [  5856,   6614],
                        [  5844,   6592],
                        [  5799,   6545],
                        [  5726,   6476],
                        [  5626,   6386],
                        [  5502,   6277],
                        [  5358,   6151],
                        [  5196,   6009],
                        [  5016,   5852],
                        [  4836,   5692],
                        [  4656,   5533],
                        [  4497,   5395],
                        [  4362,   5279],
                        [  4246,   5178],
                        [  4149,   5094],
                        [  4034,   4988],
                        [  3907,   4864],
                        [  3756,   4713],
                        [  3585,   4535],
                        [  3403,   4341],
                        [  3211,   4131],
                        [  3018,   3916],
                        [  2826,   3695],
                        [  2641,   3480],
                        [  2465,   3269],
                        [  2304,   3071],
                        [  2158,   2887],
                        [  2030,   2723],
                        [  1922,   2579],
                        [  1835,   2459],
                        [  1768,   2360],
                        [  1723,   2285],
                        [  1697,   2230],
                        [  1690,   2192],
                        [  1699,   2170],
                        [  1721,   2160],
                        [  1754,   2160],
                        [  1791,   2167],
                        [  1831,   2179],
                        [  1867,   2190],
                        [  1899,   2199],
                        [  1919,   2199],
                        [  1927,   2188],
                        [  1918,   2161],
                        [  1888,   2117],
                        [  1835,   2049],
                        [  1755,   1957],
                        [  1645,   1837],
                        [  1505,   1687],
                        [  1328,   1502],
                        [  1115,   1285],
                        [   863,   1030],
                        [   572,    741],
                        [   239,    414],
                        [  -136,     51],
                        [  -550,   -344],
                        [ -1010,   -777],
                        [ -1512,  -1247],
                        [ -1983,  -1679],
                        [ -2321,  -1978],
                        [ -2489,  -2105],
                        [ -2477,  -2055],
                        [ -2265,  -1808],
                        [ -1838,  -1348],
                        [ -1278,   -760],
                        [  -735,   -196],
                        [  -271,    284],
                        [   127,    690],
                        [   451,   1015],
                        [   696,   1252],
                        [   864,   1403],
                        [   953,   1469],
                        [   966,   1452],
                        [   904,   1355],
                        [   771,   1185],
                        [   572,    947],
                        [   312,    647],
                        [    -1,    293],
                        [  -357,   -107],
                        [  -746,   -540],
                        [ -1161,   -999],
                        [ -1589,  -1466],
                        [ -2025,  -1934],
                        [ -2461,  -2396],
                        [ -2892,  -2845],
                        [ -3312,  -3285],
                        [ -3715,  -3708],
                        [ -4098,  -4123],
                        [ -4457,  -4522],
                        [ -4788,  -4904],
                        [ -5090,  -5266],
                        [ -5361,  -5601],
                        [ -5599,  -5910],
                        [ -5803,  -6190],
                        [ -5973,  -6437],
                        [ -6108,  -6651],
                        [ -6208,  -6831],
                        [ -6276,  -6979],
                        [ -6311,  -7096],
                        [ -6319,  -7183],
                        [ -6300,  -7245],
                        [ -6262,  -7282],
                        [ -6206,  -7296],
                        [ -6136,  -7292],
                        [ -6054,  -7271],
                        [ -5963,  -7236],
                        [ -5865,  -7190],
                        [ -5765,  -7135],
                        [ -5662,  -7075],
                        [ -5558,  -7011],
                        [ -5458,  -6944],
                        [ -5360,  -6879],
                        [ -5269,  -6817],
                        [ -5190,  -6758],
                        [ -5126,  -6702],
                        [ -5085,  -6654],
                        [ -5068,  -6612],
                        [ -5079,  -6577],
                        [ -5116,  -6550],
                        [ -5165,  -6528],
                        [ -5230,  -6515],
                        [ -5291,  -6506],
                        [ -5350,  -6502],
                        [ -5398,  -6502],
                        [ -5437,  -6504],
                        [ -5465,  -6507],
                        [ -5480,  -6509],
                        [ -5480,  -6509],
                        [ -5466,  -6504],
                        [ -5436,  -6494],
                        [ -5389,  -6475],
                        [ -5331,  -6452],
                        [ -5260,  -6424],
                        [ -5209,  -6420],
                        [ -5175,  -6439],
                        [ -5168,  -6488],
                        [ -5186,  -6565],
                        [ -5202,  -6640],
                        [ -5214,  -6712],
                        [ -5174,  -6730],
                        [ -5082,  -6694],
                        [ -4939,  -6603],
                        [ -4743,  -6455],
                        [ -4503,  -6257],
                        [ -4218,  -6008],
                        [ -3897,  -5718],
                        [ -3540,  -5386],
                        [ -3157,  -5023],
                        [ -2748,  -4627],
                        [ -2323,  -4211],
                        [ -1881,  -3774],
                        [ -1431,  -3326],
                        [  -973,  -2867],
                        [  -518,  -2407],
                        [   -63,  -1941],
                        [   384,  -1478],
                        [   820,  -1017],
                        [  1244,   -561],
                        [  1653,   -111],
                        [  2046,    329],
                        [  2423,    760],
                        [  2782,   1176],
                        [  3123,   1578],
                        [  3447,   1965],
                        [  3751,   2335],
                        [  4035,   2689],
                        [  4298,   3026],
                        [  4543,   3347],
                        [  4766,   3650],
                        [  4971,   3937],
                        [  5155,   4204],
                        [  5323,   4456],
                        [  5471,   4689],
                        [  5604,   4907],
                        [  5718,   5105],
                        [  5818,   5288],
                        [  5903,   5454],
                        [  5975,   5602],
                        [  6030,   5730],
                        [  6086,   5846],
                        [  6135,   5947],
                        [  6104,   5957],
                        [  5904,   5791],
                        [  5513,   5428],
                        [  4928,   4863],
                        [  4126,   4076],
                        [  3088,   3049],
                        [  1896,   1865],
                        [   703,    676],
                        [  -434,   -458],
                        [ -1517,  -1540],
                        [ -2533,  -2555],
                        [ -3469,  -3491],
                        [ -4316,  -4337],
                        [ -5069,  -5090],
                        [ -5721,  -5741],
                        [ -6267,  -6290],
                        [ -6704,  -6733],
                        [ -7032,  -7070],
                        [ -7252,  -7304],
                        [ -7366,  -7436],
                        [ -7382,  -7470],
                        [ -7301,  -7411],
                        [ -7137,  -7274],
                        [ -6895,  -7063],
                        [ -6579,  -6791],
                        [ -6197,  -6463],
                        [ -5756,  -6085],
                        [ -5262,  -5658],
                        [ -4722,  -5180],
                        [ -4144,  -4655],
                        [ -3532,  -4081],
                        [ -2895,  -3467],
                        [ -2238,  -2818],
                        [ -1567,  -2140],
                        [  -887,  -1440],
                        [  -205,   -722],
                        [   474,      5],
                        [  1143,    735],
                        [  1798,   1458],
                        [  2437,   2173],
                        [  3052,   2874],
                        [  3642,   3556],
                        [  4206,   4215],
                        [  4742,   4850],
                        [  5250,   5456],
                        [  5727,   6033],
                        [  6173,   6576],
                        [  6585,   7086],
                        [  6962,   7560],
                        [  7306,   7998],
                        [  7615,   8398],
                        [  7889,   8761],
                        [  8127,   9085],
                        [  8331,   9371],
                        [  8504,   9618],
                        [  8645,   9828],
                        [  8767,  10001],
                        [  8872,  10138],
                        [  8967,  10241],
                        [  9054,  10310],
                        [  9131,  10347],
                        [  9200,  10354],
                        [  9247,  10333],
                        [  9273,  10285],
                        [  9270,  10214],
                        [  9238,  10119],
                        [  9180,  10005],
                        [  9096,   9873],
                        [  8989,   9725],
                        [  8860,   9562],
                        [  8714,   9388],
                        [  8552,   9206],
                        [  8379,   9018],
                        [  8197,   8825],
                        [  8037,   8659],
                        [  7901,   8521],
                        [  7824,   8446],
                        [  7807,   8434],
                        [  7843,   8478],
                        [  7934,   8579],
                        [  8024,   8681],
                        [  8119,   8786],
                        [  8175,   8855],
                        [  8198,   8888],
                        [  8192,   8892],
                        [  8157,   8865],
                        [  8097,   8812],
                        [  8010,   8731],
                        [  7905,   8631],
                        [  7778,   8509],
                        [  7637,   8372],
                        [  7479,   8220],
                        [  7311,   8059],
                        [  7129,   7887],
                        [  6939,   7711],
                        [  6740,   7527],
                        [  6533,   7338],
                        [  6319,   7142],
                        [  6099,   6939],
                        [  5872,   6725],
                        [  5637,   6502],
                        [  5393,   6266],
                        [  5135,   6019],
                        [  4864,   5759],
                        [  4577,   5486],
                        [  4271,   5197],
                        [  3948,   4890],
                        [  3606,   4565],
                        [  3243,   4218],
                        [  2860,   3849],
                        [  2456,   3456],
                        [  2030,   3040],
                        [  1584,   2601],
                        [  1117,   2139],
                        [   631,   1654],
                        [   124,   1147],
                        [  -394,    621],
                        [  -925,     76],
                        [ -1467,   -486],
                        [ -2016,  -1059],
                        [ -2571,  -1639],
                        [ -3135,  -2230],
                        [ -3705,  -2820],
                        [ -4202,  -3336],
                        [ -4552,  -3702],
                        [ -4739,  -3902],
                        [ -4752,  -3929],
                        [ -4560,  -3751],
                        [ -4130,  -3337],
                        [ -3533,  -2756],
                        [ -2899,  -2142],
                        [ -2275,  -1541],
                        [ -1654,   -945],
                        [ -1048,   -370],
                        [  -470,    176],
                        [    76,    683],
                        [   583,   1149],
                        [  1047,   1569],
                        [  1460,   1939],
                        [  1822,   2260],
                        [  2131,   2529],
                        [  2389,   2750],
                        [  2596,   2922],
                        [  2756,   3049],
                        [  2876,   3140],
                        [  2959,   3196],
                        [  3010,   3236],
                        [  3032,   3260],
                        [  3030,   3274],
                        [  3007,   3284],
                        [  2967,   3283],
                        [  2914,   3274],
                        [  2848,   3247],
                        [  2774,   3203],
                        [  2696,   3143],
                        [  2614,   3068],
                        [  2530,   2979],
                        [  2446,   2875],
                        [  2364,   2761],
                        [  2285,   2636],
                        [  2208,   2506],
                        [  2138,   2372],
                        [  2072,   2238],
                        [  2013,   2107],
                        [  1958,   1978],
                        [  1909,   1849],
                        [  1861,   1724],
                        [  1813,   1600],
                        [  1764,   1476],
                        [  1714,   1353],
                        [  1662,   1230],
                        [  1607,   1105],
                        [  1550,    981],
                        [  1489,    854],
                        [  1424,    726],
                        [  1357,    599],
                        [  1287,    470],
                        [  1214,    341],
                        [  1130,    213],
                        [  1039,     85],
                        [   930,    -40],
                        [   804,   -163],
                        [   660,   -280],
                        [   496,   -393],
                        [   329,   -499],
                        [   155,   -598],
                        [    -4,   -686],
                        [  -150,   -763],
                        [  -271,   -826],
                        [  -367,   -875],
                        [  -437,   -909],
                        [  -479,   -925],
                        [  -490,   -921],
                        [  -468,   -895],
                        [  -415,   -847],
                        [  -332,   -778],
                        [  -230,   -700],
                        [  -110,   -609],
                        [   -24,   -560],
                        [    34,   -545],
                        [    47,   -580],
                        [    17,   -661],
                        [   -29,   -761],
                        [   -93,   -881],
                        [  -102,   -944],
                        [   -58,   -955],
                        [    47,   -902],
                        [   211,   -786],
                        [   429,   -611],
                        [   701,   -379],
                        [  1018,    -95],
                        [  1379,    238],
                        [  1775,    611],
                        [  2205,   1025],
                        [  2659,   1466],
                        [  3135,   1935],
                        [  3623,   2418],
                        [  4123,   2917],
                        [  4623,   3421],
                        [  5123,   3928],
                        [  5614,   4431],
                        [  6093,   4932],
                        [  6554,   5422],
                        [  6998,   5902],
                        [  7421,   6366],
                        [  7820,   6813],
                        [  8197,   7237],
                        [  8549,   7638],
                        [  8876,   8012],
                        [  9176,   8360],
                        [  9449,   8683],
                        [  9693,   8979],
                        [  9910,   9249],
                        [ 10099,   9493],
                        [ 10262,   9711],
                        [ 10398,   9903],
                        [ 10508,  10070],
                        [ 10593,  10212],
                        [ 10652,  10332],
                        [ 10683,  10427],
                        [ 10687,  10500],
                        [ 10665,  10551],
                        [ 10619,  10580],
                        [ 10547,  10584],
                        [ 10471,  10576],
                        [ 10374,  10541],
                        [ 10203,  10421],
                        [  9908,  10168],
                        [  9488,   9779],
                        [  8938,   9250],
                        [  8223,   8552],
                        [  7311,   7649],
                        [  6262,   6603],
                        [  5189,   5528],
                        [  4132,   4466],
                        [  3092,   3417],
                        [  2084,   2399],
                        [  1127,   1428],
                        [   231,    518],
                        [  -597,   -324],
                        [ -1345,  -1089],
                        [ -2004,  -1768],
                        [ -2570,  -2358],
                        [ -3040,  -2854],
                        [ -3413,  -3256],
                        [ -3688,  -3561],
                        [ -3869,  -3774],
                        [ -3959,  -3896],
                        [ -3965,  -3941],
                        [ -3891,  -3913],
                        [ -3742,  -3824],
                        [ -3525,  -3680],
                        [ -3244,  -3484],
                        [ -2908,  -3242],
                        [ -2523,  -2946],
                        [ -2095,  -2605],
                        [ -1632,  -2214],
                        [ -1142,  -1780],
                        [  -631,  -1307],
                        [  -105,   -800],
                        [   431,   -263],
                        [   968,    299],
                        [  1501,    875],
                        [  2025,   1462],
                        [  2535,   2047],
                        [  3026,   2624],
                        [  3493,   3185],
                        [  3932,   3725],
                        [  4341,   4240],
                        [  4720,   4728],
                        [  5067,   5185],
                        [  5381,   5610],
                        [  5662,   6001],
                        [  5909,   6357],
                        [  6122,   6676],
                        [  6303,   6959],
                        [  6450,   7206],
                        [  6566,   7417],
                        [  6650,   7592],
                        [  6705,   7731],
                        [  6736,   7837],
                        [  6743,   7910],
                        [  6739,   7953],
                        [  6724,   7966],
                        [  6710,   7952],
                        [  6697,   7914],
                        [  6687,   7853],
                        [  6682,   7772],
                        [  6671,   7672],
                        [  6654,   7559],
                        [  6623,   7431],
                        [  6578,   7291],
                        [  6520,   7144],
                        [  6450,   6990],
                        [  6367,   6832],
                        [  6273,   6667],
                        [  6168,   6502],
                        [  6056,   6338],
                        [  5941,   6179],
                        [  5822,   6026],
                        [  5747,   5923],
                        [  5711,   5868],
                        [  5753,   5899],
                        [  5869,   6013],
                        [  6058,   6207],
                        [  6320,   6481],
                        [  6586,   6767],
                        [  6862,   7068],
                        [  7093,   7328],
                        [  7279,   7547],
                        [  7421,   7727],
                        [  7516,   7863],
                        [  7563,   7954],
                        [  7562,   7998],
                        [  7515,   7999],
                        [  7420,   7953],
                        [  7280,   7864],
                        [  7094,   7731],
                        [  6867,   7560],
                        [  6597,   7347],
                        [  6289,   7100],
                        [  5942,   6815],
                        [  5562,   6498],
                        [  5149,   6147],
                        [  4708,   5764],
                        [  4237,   5349],
                        [  3740,   4903],
                        [  3218,   4427],
                        [  2671,   3926],
                        [  2097,   3398],
                        [  1502,   2849],
                        [   885,   2277],
                        [   249,   1687],
                        [  -405,   1077],
                        [ -1073,    449],
                        [ -1753,   -196],
                        [ -2441,   -855],
                        [ -3136,  -1525],
                        [ -3834,  -2205],
                        [ -4532,  -2890],
                        [ -5224,  -3578],
                        [ -5908,  -4266],
                        [ -6570,  -4947],
                        [ -7210,  -5621],
                        [ -7824,  -6282],
                        [ -8406,  -6925],
                        [ -8957,  -7544],
                        [ -9479,  -8141],
                        [ -9969,  -8701],
                        [-10373,  -9173],
                        [-10666,  -9531],
                        [-10847,  -9773],
                        [-10905,  -9888],
                        [-10802,  -9840],
                        [-10496,  -9587],
                        [-10018,  -9159],
                        [ -9453,  -8642],
                        [ -8829,  -8063],
                        [ -8146,  -7426],
                        [ -7420,  -6743],
                        [ -6667,  -6031],
                        [ -5896,  -5302],
                        [ -5120,  -4563],
                        [ -4347,  -3826],
                        [ -3590,  -3101],
                        [ -2857,  -2394],
                        [ -2153,  -1711],
                        [ -1484,  -1059],
                        [  -854,   -442],
                        [  -267,    138],
                        [   279,    683],
                        [   782,   1191],
                        [  1240,   1672],
                        [  1655,   2126],
                        [  2024,   2551],
                        [  2350,   2952],
                        [  2633,   3322],
                        [  2875,   3664],
                        [  3076,   3959],
                        [  3241,   4212],
                        [  3369,   4418],
                        [  3464,   4578],
                        [  3525,   4689],
                        [  3556,   4751],
                        [  3558,   4764],
                        [  3534,   4730],
                        [  3486,   4656],
                        [  3417,   4545],
                        [  3328,   4407],
                        [  3223,   4244],
                        [  3105,   4062],
                        [  2973,   3861],
                        [  2830,   3644],
                        [  2677,   3413],
                        [  2516,   3170],
                        [  2346,   2918],
                        [  2169,   2657],
                        [  1988,   2390],
                        [  1805,   2121],
                        [  1619,   1849],
                        [  1434,   1579],
                        [  1251,   1310],
                        [  1072,   1047],
                        [   897,    790],
                        [   723,    544],
                        [   553,    308],
                        [   378,     86],
                        [   202,   -120],
                        [    21,   -310],
                        [  -163,   -479],
                        [  -341,   -629],
                        [  -515,   -757],
                        [  -666,   -860],
                        [  -798,   -940],
                        [  -898,   -994],
                        [  -968,  -1021],
                        [ -1007,  -1021],
                        [ -1011,   -994],
                        [  -977,   -936],
                        [  -908,   -849],
                        [  -808,   -736],
                        [  -673,   -597],
                        [  -527,   -453],
                        [  -367,   -301],
                        [  -254,   -200],
                        [  -180,   -145],
                        [  -164,   -151],
                        [  -204,   -218],
                        [  -280,   -323],
                        [  -395,   -470],
                        [  -466,   -576],
                        [  -502,   -647],
                        [  -491,   -669],
                        [  -431,   -643],
                        [  -327,   -569],
                        [  -179,   -449],
                        [    10,   -286],
                        [   236,    -82],
                        [   494,    157],
                        [   783,    430],
                        [  1094,    729],
                        [  1428,   1051],
                        [  1774,   1390],
                        [  2131,   1742],
                        [  2492,   2100],
                        [  2855,   2461],
                        [  3210,   2819],
                        [  3558,   3174],
                        [  3891,   3520],
                        [  4210,   3855],
                        [  4510,   4175],
                        [  4792,   4478],
                        [  5055,   4760],
                        [  5298,   5018],
                        [  5519,   5253],
                        [  5717,   5462],
                        [  5893,   5648],
                        [  6046,   5808],
                        [  6175,   5944],
                        [  6281,   6059],
                        [  6365,   6150],
                        [  6426,   6218],
                        [  6465,   6266],
                        [  6482,   6293],
                        [  6472,   6301],
                        [  6435,   6287],
                        [  6368,   6257],
                        [  6273,   6208],
                        [  6152,   6143],
                        [  6007,   6058],
                        [  5853,   5962],
                        [  5680,   5843],
                        [  5475,   5681],
                        [  5235,   5475],
                        [  4968,   5234],
                        [  4665,   4950],
                        [  4292,   4589],
                        [  3804,   4105],
                        [  3208,   3508],
                        [  2560,   2853],
                        [  1880,   2161],
                        [  1172,   1439],
                        [   453,    701],
                        [  -264,    -36],
                        [  -968,   -762],
                        [ -1649,  -1467],
                        [ -2295,  -2139],
                        [ -2897,  -2771],
                        [ -3452,  -3355],
                        [ -3950,  -3885],
                        [ -4391,  -4358],
                        [ -4768,  -4769],
                        [ -5084,  -5120],
                        [ -5339,  -5409],
                        [ -5534,  -5645],
                        [ -5671,  -5829],
                        [ -5753,  -5970],
                        [ -5780,  -6069],
                        [ -5759,  -6133],
                        [ -5693,  -6164],
                        [ -5587,  -6154],
                        [ -5445,  -6109],
                        [ -5272,  -6023],
                        [ -5074,  -5900],
                        [ -4855,  -5741],
                        [ -4619,  -5549],
                        [ -4371,  -5322],
                        [ -4117,  -5064],
                        [ -3859,  -4782],
                        [ -3600,  -4479],
                        [ -3347,  -4168],
                        [ -3101,  -3851],
                        [ -2867,  -3543],
                        [ -2649,  -3244],
                        [ -2446,  -2958],
                        [ -2265,  -2686],
                        [ -2101,  -2432],
                        [ -1956,  -2195],
                        [ -1830,  -1979],
                        [ -1723,  -1783],
                        [ -1633,  -1608],
                        [ -1562,  -1454],
                        [ -1506,  -1320],
                        [ -1467,  -1206],
                        [ -1441,  -1112],
                        [ -1430,  -1036],
                        [ -1426,   -977],
                        [ -1432,   -937],
                        [ -1436,   -910],
                        [ -1439,   -898],
                        [ -1433,   -898],
                        [ -1418,   -908],
                        [ -1389,   -927],
                        [ -1347,   -955],
                        [ -1297,   -987],
                        [ -1239,  -1025],
                        [ -1182,  -1066],
                        [ -1125,  -1109],
                        [ -1071,  -1152],
                        [ -1019,  -1195],
                        [  -972,  -1238],
                        [  -933,  -1284],
                        [  -900,  -1328],
                        [  -873,  -1369],
                        [  -846,  -1402],
                        [  -823,  -1430],
                        [  -760,  -1407],
                        [  -657,  -1335],
                        [  -488,  -1187],
                        [  -258,   -967],
                        [    39,   -671],
                        [   400,   -301],
                        [   761,     81],
                        [  1127,    475],
                        [  1441,    826],
                        [  1705,   1136],
                        [  1915,   1398],
                        [  2069,   1609],
                        [  2159,   1762],
                        [  2188,   1857],
                        [  2152,   1892],
                        [  2052,   1865],
                        [  1887,   1776],
                        [  1659,   1626],
                        [  1371,   1417],
                        [  1021,   1149],
                        [   617,    826],
                        [   157,    449],
                        [  -349,     24],
                        [  -901,   -451],
                        [ -1492,   -967],
                        [ -2121,  -1526],
                        [ -2780,  -2120],
                        [ -3469,  -2748],
                        [ -4182,  -3403],
                        [ -4917,  -4082],
                        [ -5669,  -4778],
                        [ -6434,  -5488],
                        [ -7206,  -6208],
                        [ -7982,  -6934],
                        [ -8754,  -7661],
                        [ -9520,  -8387],
                        [-10273,  -9107],
                        [-11011,  -9817],
                        [-11725, -10512],
                        [-12413, -11188],
                        [-13064, -11840],
                        [-13677, -12463],
                        [-14235, -13053],
                        [-14739, -13606],
                        [-15182, -14118],
                        [-15563, -14584],
                        [-15884, -14999],
                        [-16141, -15363],
                        [-16346, -15668],
                        [-16496, -15917],
                        [-16610, -16123],
                        [-16696, -16298],
                        [-16745, -16430],
                        [-16721, -16484],
                        [-16574, -16408],
                        [-16277, -16177],
                        [-15858, -15818],
                        [-15333, -15345],
                        [-14705, -14766],
                        [-13992, -14094],
                        [-13210, -13348],
                        [-12371, -12538],
                        [-11487, -11676],
                        [-10571, -10779],
                        [ -9640,  -9858],
                        [ -8700,  -8924],
                        [ -7766,  -7987],
                        [ -6845,  -7058],
                        [ -5949,  -6147],
                        [ -5083,  -5261],
                        [ -4252,  -4403],
                        [ -3464,  -3577],
                        [ -2721,  -2786],
                        [ -2030,  -2030],
                        [ -1392,  -1313],
                        [  -808,   -635],
                        [  -282,     -1],
                        [   188,    591],
                        [   601,   1124],
                        [   958,   1600],
                        [  1262,   2015],
                        [  1511,   2368],
                        [  1710,   2653],
                        [  1861,   2871],
                        [  1965,   3020],
                        [  2025,   3104],
                        [  2044,   3128],
                        [  2026,   3096],
                        [  1977,   3023],
                        [  1899,   2911],
                        [  1797,   2769],
                        [  1676,   2600],
                        [  1539,   2407],
                        [  1389,   2195],
                        [  1229,   1967],
                        [  1060,   1727],
                        [   889,   1479],
                        [   716,   1226],
                        [   544,    972],
                        [   377,    721],
                        [   216,    475],
                        [    65,    239],
                        [   -76,     14],
                        [  -205,   -197],
                        [  -321,   -391],
                        [  -423,   -565],
                        [  -516,   -717],
                        [  -596,   -847],
                        [  -666,   -952],
                        [  -727,  -1031],
                        [  -777,  -1084],
                        [  -815,  -1110],
                        [  -834,  -1108],
                        [  -835,  -1079],
                        [  -813,  -1023],
                        [  -768,   -940],
                        [  -700,   -833],
                        [  -606,   -700],
                        [  -486,   -542],
                        [  -341,   -360],
                        [  -177,   -161],
                        [     7,     56],
                        [   187,    266],
                        [   362,    468],
                        [   492,    620],
                        [   574,    722],
                        [   596,    761],
                        [   557,    735],
                        [   466,    652],
                        [   320,    510],
                        [   189,    380],
                        [    67,    256],
                        [   -35,    150],
                        [  -116,     63],
                        [  -174,     -3],
                        [  -209,    -47],
                        [  -219,    -67],
                        [  -207,    -66],
                        [  -173,    -42],
                        [  -117,      2],
                        [   -43,     64],
                        [    48,    143],
                        [   153,    235],
                        [   271,    341],
                        [   397,    454],
                        [   531,    574],
                        [   665,    697],
                        [   803,    821],
                        [   936,    944],
                        [  1068,   1064],
                        [  1194,   1178],
                        [  1315,   1286],
                        [  1431,   1384],
                        [  1541,   1471],
                        [  1642,   1547],
                        [  1737,   1610],
                        [  1822,   1661],
                        [  1900,   1699],
                        [  1967,   1727],
                        [  2025,   1744],
                        [  2073,   1752],
                        [  2110,   1749],
                        [  2135,   1736],
                        [  2148,   1714],
                        [  2140,   1682],
                        [  2113,   1640],
                        [  2061,   1591],
                        [  1984,   1532],
                        [  1888,   1464],
                        [  1770,   1388],
                        [  1644,   1301],
                        [  1512,   1209],
                        [  1415,   1146],
                        [  1385,   1144],
                        [  1432,   1214],
                        [  1545,   1346],
                        [  1699,   1512],
                        [  1831,   1651],
                        [  1882,   1705],
                        [  1852,   1672],
                        [  1748,   1562],
                        [  1575,   1379],
                        [  1342,   1133],
                        [  1062,    837],
                        [   739,    496],
                        [   384,    119],
                        [     3,   -282],
                        [  -392,   -700],
                        [  -795,  -1126],
                        [ -1201,  -1556],
                        [ -1601,  -1982],
                        [ -1990,  -2397],
                        [ -2364,  -2799],
                        [ -2722,  -3185],
                        [ -3059,  -3557],
                        [ -3373,  -3911],
                        [ -3661,  -4247],
                        [ -3926,  -4566],
                        [ -4166,  -4872],
                        [ -4381,  -5164],
                        [ -4574,  -5440],
                        [ -4744,  -5699],
                        [ -4895,  -5935],
                        [ -5026,  -6151],
                        [ -5142,  -6339],
                        [ -5241,  -6503],
                        [ -5328,  -6637],
                        [ -5402,  -6740],
                        [ -5465,  -6815],
                        [ -5520,  -6866],
                        [ -5566,  -6897],
                        [ -5608,  -6911],
                        [ -5645,  -6920],
                        [ -5682,  -6927],
                        [ -5718,  -6928],
                        [ -5753,  -6927],
                        [ -5790,  -6925],
                        [ -5827,  -6922],
                        [ -5862,  -6917],
                        [ -5897,  -6911],
                        [ -5929,  -6905],
                        [ -5960,  -6897],
                        [ -5986,  -6888],
                        [ -6007,  -6877],
                        [ -6023,  -6864],
                        [ -6033,  -6848],
                        [ -6034,  -6828],
                        [ -6027,  -6804],
                        [ -6009,  -6775],
                        [ -5980,  -6741],
                        [ -5937,  -6702],
                        [ -5880,  -6657],
                        [ -5805,  -6606],
                        [ -5713,  -6549],
                        [ -5602,  -6484],
                        [ -5474,  -6414],
                        [ -5336,  -6338],
                        [ -5185,  -6254],
                        [ -5029,  -6165],
                        [ -4865,  -6071],
                        [ -4702,  -5974],
                        [ -4540,  -5877],
                        [ -4383,  -5778],
                        [ -4227,  -5676],
                        [ -4075,  -5569],
                        [ -3925,  -5459],
                        [ -3750,  -5314],
                        [ -3551,  -5137],
                        [ -3317,  -4916],
                        [ -3051,  -4652],
                        [ -2741,  -4335],
                        [ -2389,  -3967],
                        [ -2040,  -3590],
                        [ -1691,  -3205],
                        [ -1383,  -2853],
                        [ -1117,  -2533],
                        [  -901,  -2257],
                        [  -735,  -2024],
                        [  -628,  -1845],
                        [  -580,  -1720],
                        [  -594,  -1654],
                        [  -671,  -1648],
                        [  -811,  -1702],
                        [ -1013,  -1818],
                        [ -1275,  -1993],
                        [ -1596,  -2228],
                        [ -1971,  -2519],
                        [ -2399,  -2864],
                        [ -2870,  -3257],
                        [ -3385,  -3696],
                        [ -3934,  -4174],
                        [ -4517,  -4689],
                        [ -5122,  -5232],
                        [ -5748,  -5800],
                        [ -6387,  -6383],
                        [ -7037,  -6981],
                        [ -7690,  -7582],
                        [ -8340,  -8185],
                        [ -8982,  -8781],
                        [ -9612,  -9366],
                        [-10220,  -9934],
                        [-10804, -10481],
                        [-11356, -11002],
                        [-11875, -11494],
                        [-12351, -11951],
                        [-12781, -12370],
                        [-13157, -12744],
                        [-13474, -13072],
                        [-13722, -13348],
                        [-13898, -13570],
                        [-14001, -13736],
                        [-14029, -13844],
                        [-13989, -13891],
                        [-13873, -13873],
                        [-13717, -13810],
                        [-13574, -13757],
                        [-13491, -13758],
                        [-13475, -13821],
                        [-13527, -13945],
                        [-13624, -14107],
                        [-13696, -14236],
                        [-13661, -14249],
                        [-13496, -14124],
                        [-13209, -13869],
                        [-12810, -13492],
                        [-12308, -13003],
                        [-11715, -12416],
                        [-11042, -11741],
                        [-10300, -10990],
                        [ -9501, -10175],
                        [ -8660,  -9311],
                        [ -7785,  -8409],
                        [ -6888,  -7481],
                        [ -5986,  -6539],
                        [ -5085,  -5593],
                        [ -4195,  -4653],
                        [ -3326,  -3727],
                        [ -2485,  -2823],
                        [ -1679,  -1947],
                        [  -915,  -1107],
                        [  -195,   -305],
                        [   476,    457],
                        [  1095,   1176],
                        [  1662,   1851],
                        [  2173,   2475],
                        [  2631,   3048],
                        [  3035,   3564],
                        [  3387,   4024],
                        [  3687,   4420],
                        [  3938,   4753],
                        [  4144,   5022],
                        [  4305,   5228],
                        [  4423,   5376],
                        [  4506,   5470],
                        [  4556,   5522],
                        [  4577,   5536],
                        [  4576,   5523],
                        [  4556,   5483],
                        [  4522,   5423],
                        [  4479,   5344],
                        [  4429,   5253],
                        [  4375,   5154],
                        [  4322,   5049],
                        [  4271,   4943],
                        [  4225,   4840],
                        [  4186,   4742],
                        [  4158,   4652],
                        [  4141,   4574],
                        [  4136,   4509],
                        [  4145,   4459],
                        [  4169,   4427],
                        [  4210,   4413],
                        [  4268,   4418],
                        [  4345,   4444],
                        [  4435,   4489],
                        [  4542,   4555],
                        [  4656,   4640],
                        [  4778,   4745],
                        [  4903,   4867],
                        [  5033,   5007],
                        [  5166,   5160],
                        [  5303,   5328],
                        [  5442,   5505],
                        [  5584,   5692],
                        [  5729,   5887],
                        [  5874,   6088],
                        [  6018,   6289],
                        [  6156,   6487],
                        [  6277,   6667],
                        [  6375,   6827],
                        [  6434,   6945],
                        [  6453,   7022],
                        [  6420,   7046],
                        [  6336,   7013],
                        [  6190,   6916],
                        [  5984,   6754],
                        [  5759,   6568],
                        [  5513,   6355],
                        [  5257,   6128],
                        [  4990,   5885],
                        [  4724,   5637],
                        [  4456,   5382],
                        [  4194,   5129],
                        [  3937,   4877],
                        [  3693,   4631],
                        [  3458,   4392],
                        [  3238,   4162],
                        [  3031,   3944],
                        [  2841,   3738],
                        [  2667,   3546],
                        [  2509,   3366],
                        [  2367,   3201],
                        [  2241,   3049],
                        [  2130,   2909],
                        [  2033,   2780],
                        [  1951,   2661],
                        [  1881,   2552],
                        [  1824,   2453],
                        [  1779,   2360],
                        [  1748,   2276],
                        [  1726,   2197],
                        [  1716,   2126],
                        [  1714,   2058],
                        [  1722,   1996],
                        [  1736,   1938],
                        [  1757,   1886],
                        [  1780,   1837],
                        [  1809,   1793],
                        [  1835,   1753],
                        [  1860,   1714],
                        [  1873,   1676],
                        [  1876,   1640],
                        [  1863,   1602],
                        [  1834,   1563],
                        [  1790,   1523],
                        [  1729,   1480],
                        [  1656,   1428],
                        [  1605,   1402],
                        [  1657,   1479],
                        [  1859,   1704],
                        [  2217,   2082],
                        [  2728,   2612],
                        [  3376,   3278],
                        [  4082,   3997],
                        [  4728,   4654],
                        [  5272,   5206],
                        [  5718,   5657],
                        [  6069,   6008],
                        [  6325,   6261],
                        [  6489,   6420],
                        [  6565,   6489],
                        [  6560,   6475],
                        [  6477,   6383],
                        [  6325,   6221],
                        [  6109,   5996],
                        [  5836,   5715],
                        [  5518,   5384],
                        [  5161,   5012],
                        [  4771,   4602],
                        [  4355,   4163],
                        [  3920,   3703],
                        [  3471,   3227],
                        [  3014,   2741],
                        [  2553,   2249],
                        [  2092,   1752],
                        [  1636,   1252],
                        [  1187,    749],
                        [   748,    247],
                        [   321,   -249],
                        [   -92,   -736],
                        [  -488,  -1207],
                        [  -866,  -1660],
                        [ -1224,  -2084],
                        [ -1562,  -2481],
                        [ -1876,  -2845],
                        [ -2168,  -3179],
                        [ -2435,  -3481],
                        [ -2679,  -3751],
                        [ -2898,  -3999],
                        [ -3096,  -4225],
                        [ -3271,  -4427],
                        [ -3426,  -4606],
                        [ -3557,  -4762],
                        [ -3669,  -4895],
                        [ -3759,  -5003],
                        [ -3829,  -5091],
                        [ -3878,  -5155],
                        [ -3906,  -5198],
                        [ -3913,  -5220],
                        [ -3900,  -5220],
                        [ -3868,  -5200],
                        [ -3816,  -5161],
                        [ -3746,  -5103],
                        [ -3661,  -5027],
                        [ -3563,  -4934],
                        [ -3452,  -4825],
                        [ -3336,  -4704],
                        [ -3213,  -4568],
                        [ -3080,  -4420],
                        [ -2940,  -4263],
                        [ -2784,  -4097],
                        [ -2615,  -3924],
                        [ -2433,  -3745],
                        [ -2241,  -3563],
                        [ -2041,  -3378],
                        [ -1836,  -3192],
                        [ -1634,  -3010],
                        [ -1434,  -2832],
                        [ -1241,  -2660],
                        [ -1053,  -2494],
                        [  -874,  -2333],
                        [  -705,  -2180],
                        [  -540,  -2026],
                        [  -382,  -1874],
                        [  -231,  -1723],
                        [   -87,  -1575],
                        [    68,  -1410],
                        [   234,  -1227],
                        [   401,  -1038],
                        [   568,   -839],
                        [   716,   -657],
                        [   843,   -487],
                        [   939,   -342],
                        [  1008,   -220],
                        [  1040,   -132],
                        [  1036,    -76],
                        [   991,    -59],
                        [   907,    -79],
                        [   781,   -140],
                        [   614,   -240],
                        [   410,   -380],
                        [   167,   -560],
                        [  -111,   -778],
                        [  -419,  -1029],
                        [  -754,  -1311],
                        [ -1113,  -1621],
                        [ -1491,  -1951],
                        [ -1883,  -2299],
                        [ -2282,  -2655],
                        [ -2684,  -3019],
                        [ -3083,  -3382],
                        [ -3476,  -3740],
                        [ -3857,  -4088],
                        [ -4221,  -4421],
                        [ -4562,  -4732],
                        [ -4879,  -5019],
                        [ -5163,  -5276],
                        [ -5414,  -5500],
                        [ -5624,  -5687],
                        [ -5793,  -5835],
                        [ -5914,  -5939],
                        [ -5988,  -5998],
                        [ -6004,  -6008],
                        [ -5965,  -5969],
                        [ -5862,  -5879],
                        [ -5696,  -5738],
                        [ -5467,  -5544],
                        [ -5176,  -5300],
                        [ -4827,  -5005],
                        [ -4415,  -4654],
                        [ -4006,  -4302],
                        [ -3690,  -4042],
                        [ -3519,  -3922],
                        [ -3497,  -3948],
                        [ -3636,  -4127],
                        [ -3931,  -4457],
                        [ -4299,  -4851],
                        [ -4606,  -5177],
                        [ -4804,  -5385],
                        [ -4902,  -5485],
                        [ -4903,  -5480],
                        [ -4807,  -5369],
                        [ -4622,  -5162],
                        [ -4352,  -4862],
                        [ -4002,  -4479],
                        [ -3582,  -4021],
                        [ -3098,  -3498],
                        [ -2561,  -2919],
                        [ -1981,  -2293],
                        [ -1367,  -1631],
                        [  -731,   -941],
                        [   -82,   -231],
                        [   573,    487],
                        [  1225,   1203],
                        [  1870,   1909],
                        [  2499,   2597],
                        [  3109,   3261],
                        [  3694,   3898],
                        [  4251,   4512],
                        [  4778,   5098],
                        [  5273,   5659],
                        [  5734,   6191],
                        [  6161,   6692],
                        [  6554,   7161],
                        [  6915,   7592],
                        [  7243,   7985],
                        [  7538,   8337],
                        [  7802,   8651],
                        [  8039,   8925],
                        [  8249,   9164],
                        [  8437,   9375],
                        [  8604,   9558],
                        [  8755,   9722],
                        [  8891,   9871],
                        [  9019,  10005],
                        [  9139,  10128],
                        [  9255,  10242],
                        [  9370,  10350],
                        [  9484,  10454],
                        [  9601,  10558],
                        [  9718,  10662],
                        [  9841,  10768],
                        [  9966,  10879],
                        [ 10098,  10995],
                        [ 10234,  11116],
                        [ 10376,  11243],
                        [ 10524,  11376],
                        [ 10680,  11516],
                        [ 10850,  11660],
                        [ 11032,  11810],
                        [ 11224,  11963],
                        [ 11425,  12120],
                        [ 11623,  12277],
                        [ 11816,  12435],
                        [ 11993,  12589],
                        [ 12152,  12739],
                        [ 12289,  12882],
                        [ 12404,  13017],
                        [ 12496,  13140],
                        [ 12565,  13251],
                        [ 12611,  13348],
                        [ 12630,  13427],
                        [ 12623,  13486],
                        [ 12589,  13522],
                        [ 12528,  13535],
                        [ 12439,  13525],
                        [ 12333,  13496],
                        [ 12208,  13449],
                        [ 12053,  13371],
                        [ 11868,  13262],
                        [ 11629,  13093],
                        [ 11334,  12864],
                        [ 10996,  12586],
                        [ 10611,  12256],
                        [ 10195,  11886],
                        [  9745,  11477],
                        [  9276,  11039],
                        [  8786,  10576],
                        [  8289,  10097],
                        [  7784,   9602],
                        [  7282,   9103],
                        [  6782,   8600],
                        [  6294,   8101],
                        [  5818,   7610],
                        [  5361,   7132],
                        [  4923,   6670],
                        [  4510,   6228],
                        [  4122,   5807],
                        [  3760,   5409],
                        [  3428,   5035],
                        [  3124,   4684],
                        [  2849,   4357],
                        [  2602,   4054],
                        [  2384,   3775],
                        [  2191,   3519],
                        [  2027,   3287],
                        [  1887,   3077],
                        [  1772,   2889],
                        [  1679,   2720],
                        [  1607,   2572],
                        [  1554,   2440],
                        [  1518,   2324],
                        [  1494,   2222],
                        [  1484,   2135],
                        [  1479,   2058],
                        [  1480,   1991],
                        [  1480,   1931],
                        [  1477,   1877],
                        [  1466,   1825],
                        [  1445,   1776],
                        [  1415,   1730],
                        [  1369,   1681],
                        [  1310,   1625],
                        [  1302,   1627],
                        [  1444,   1783],
                        [  1775,   2130],
                        [  2298,   2669],
                        [  3023,   3412],
                        [  3949,   4357],
                        [  4984,   5409],
                        [  5977,   6417],
                        [  6870,   7323],
                        [  7668,   8131],
                        [  8366,   8835],
                        [  8955,   9429],
                        [  9438,   9912],
                        [  9811,  10282],
                        [ 10074,  10543],
                        [ 10230,  10697],
                        [ 10283,  10748],
                        [ 10239,  10700],
                        [ 10103,  10561],
                        [  9887,  10337],
                        [  9599,  10034],
                        [  9246,   9661],
                        [  8837,   9226],
                        [  8379,   8745],
                        [  7882,   8224],
                        [  7352,   7676],
                        [  6797,   7105],
                        [  6223,   6517],
                        [  5638,   5918],
                        [  5048,   5303],
                        [  4458,   4678],
                        [  3875,   4049],
                        [  3302,   3417],
                        [  2745,   2794],
                        [  2206,   2182],
                        [  1692,   1591],
                        [  1204,   1024],
                        [   746,    486],
                        [   320,    -20],
                        [   -72,   -490],
                        [  -427,   -922],
                        [  -748,  -1320],
                        [ -1031,  -1684],
                        [ -1279,  -2012],
                        [ -1491,  -2303],
                        [ -1671,  -2557],
                        [ -1816,  -2776],
                        [ -1931,  -2960],
                        [ -2016,  -3109],
                        [ -2071,  -3226],
                        [ -2099,  -3309],
                        [ -2100,  -3364],
                        [ -2078,  -3388],
                        [ -2031,  -3387],
                        [ -1965,  -3361],
                        [ -1883,  -3311],
                        [ -1786,  -3242],
                        [ -1685,  -3154],
                        [ -1582,  -3050],
                        [ -1487,  -2933],
                        [ -1399,  -2806],
                        [ -1318,  -2669],
                        [ -1245,  -2527],
                        [ -1166,  -2381],
                        [ -1087,  -2234],
                        [  -999,  -2088],
                        [  -906,  -1945],
                        [  -810,  -1807],
                        [  -713,  -1675],
                        [  -620,  -1553],
                        [  -531,  -1442],
                        [  -449,  -1342],
                        [  -374,  -1255],
                        [  -313,  -1185],
                        [  -266,  -1133],
                        [  -255,  -1117],
                        [  -279,  -1138],
                        [  -346,  -1204],
                        [  -457,  -1314],
                        [  -582,  -1437],
                        [  -723,  -1575],
                        [  -850,  -1698],
                        [  -961,  -1804],
                        [ -1064,  -1897],
                        [ -1153,  -1977],
                        [ -1239,  -2051],
                        [ -1320,  -2116],
                        [ -1400,  -2179],
                        [ -1480,  -2240],
                        [ -1562,  -2303],
                        [ -1647,  -2367],
                        [ -1738,  -2437],
                        [ -1832,  -2509],
                        [ -1931,  -2588],
                        [ -2033,  -2671],
                        [ -2139,  -2760],
                        [ -2245,  -2853],
                        [ -2352,  -2947],
                        [ -2458,  -3042],
                        [ -2559,  -3132],
                        [ -2651,  -3215],
                        [ -2733,  -3287],
                        [ -2801,  -3343],
                        [ -2850,  -3381],
                        [ -2880,  -3400],
                        [ -2885,  -3395],
                        [ -2866,  -3365],
                        [ -2818,  -3305],
                        [ -2741,  -3217],
                        [ -2633,  -3095],
                        [ -2492,  -2939],
                        [ -2316,  -2745],
                        [ -2106,  -2517],
                        [ -1859,  -2251],
                        [ -1576,  -1950],
                        [ -1256,  -1610],
                        [  -901,  -1237],
                        [  -509,   -829],
                        [   -83,   -386],
                        [   380,     86],
                        [   872,    583],
                        [  1398,   1108],
                        [  1951,   1655],
                        [  2447,   2147],
                        [  2789,   2484],
                        [  2943,   2633],
                        [  2900,   2588],
                        [  2637,   2327],
                        [  2143,   1839],
                        [  1507,   1212],
                        [   882,    600],
                        [   319,     57],
                        [  -190,   -427],
                        [  -639,   -846],
                        [ -1021,  -1192],
                        [ -1331,  -1464],
                        [ -1571,  -1663],
                        [ -1738,  -1789],
                        [ -1833,  -1844],
                        [ -1859,  -1831],
                        [ -1821,  -1755],
                        [ -1723,  -1619],
                        [ -1573,  -1431],
                        [ -1378,  -1194],
                        [ -1144,   -913],
                        [  -876,   -602],
                        [  -579,   -264],
                        [  -261,     85],
                        [    77,    444],
                        [   429,    803],
                        [   790,   1160],
                        [  1157,   1522],
                        [  1526,   1883],
                        [  1896,   2253],
                        [  2264,   2627],
                        [  2627,   3005],
                        [  2985,   3386],
                        [  3336,   3764],
                        [  3679,   4139],
                        [  4013,   4509],
                        [  4338,   4874],
                        [  4654,   5229],
                        [  4958,   5575],
                        [  5253,   5910],
                        [  5537,   6237],
                        [  5813,   6557],
                        [  6079,   6869],
                        [  6339,   7174],
                        [  6592,   7473],
                        [  6840,   7765],
                        [  7085,   8052],
                        [  7324,   8332],
                        [  7558,   8607],
                        [  7786,   8875],
                        [  8008,   9137],
                        [  8223,   9391],
                        [  8430,   9638],
                        [  8627,   9874],
                        [  8815,  10103],
                        [  8996,  10318],
                        [  9171,  10522],
                        [  9347,  10711],
                        [  9524,  10884],
                        [  9700,  11040],
                        [  9874,  11177],
                        [ 10032,  11292],
                        [ 10175,  11386],
                        [ 10282,  11455],
                        [ 10353,  11499],
                        [ 10384,  11515],
                        [ 10374,  11503],
                        [ 10322,  11460],
                        [ 10228,  11386],
                        [ 10092,  11281],
                        [  9914,  11142],
                        [  9697,  10972],
                        [  9440,  10768],
                        [  9166,  10552],
                        [  8876,  10324],
                        [  8598,  10111],
                        [  8332,   9911],
                        [  8073,   9716],
                        [  7820,   9528],
                        [  7529,   9298],
                        [  7202,   9030],
                        [  6819,   8700],
                        [  6381,   8312],
                        [  5903,   7874],
                        [  5382,   7388],
                        [  4831,   6866],
                        [  4253,   6307],
                        [  3659,   5726],
                        [  3049,   5121],
                        [  2438,   4508],
                        [  1823,   3884],
                        [  1218,   3263],
                        [   622,   2646],
                        [    45,   2043],
                        [  -514,   1456],
                        [ -1045,    892],
                        [ -1548,    353],
                        [ -2018,   -159],
                        [ -2455,   -641],
                        [ -2858,  -1093],
                        [ -3226,  -1515],
                        [ -3562,  -1907],
                        [ -3863,  -2269],
                        [ -4134,  -2598],
                        [ -4373,  -2899],
                        [ -4583,  -3170],
                        [ -4763,  -3411],
                        [ -4917,  -3626],
                        [ -5046,  -3816],
                        [ -5157,  -3987],
                        [ -5247,  -4136],
                        [ -5321,  -4270],
                        [ -5382,  -4388],
                        [ -5432,  -4493],
                        [ -5472,  -4588],
                        [ -5506,  -4675],
                        [ -5535,  -4756],
                        [ -5567,  -4835],
                        [ -5601,  -4912],
                        [ -5640,  -4983],
                        [ -5696,  -5061],
                        [ -5758,  -5138],
                        [ -5749,  -5137],
                        [ -5585,  -4975],
                        [ -5245,  -4631],
                        [ -4725,  -4106],
                        [ -4000,  -3372],
                        [ -3054,  -2416],
                        [ -1977,  -1328],
                        [  -918,   -261],
                        [    72,    737],
                        [   997,   1667],
                        [  1848,   2520],
                        [  2610,   3281],
                        [  3278,   3945],
                        [  3846,   4509],
                        [  4312,   4968],
                        [  4673,   5324],
                        [  4929,   5575],
                        [  5085,   5725],
                        [  5144,   5776],
                        [  5116,   5735],
                        [  5005,   5604],
                        [  4821,   5394],
                        [  4570,   5111],
                        [  4261,   4774],
                        [  3898,   4389],
                        [  3493,   3971],
                        [  3052,   3525],
                        [  2583,   3058],
                        [  2091,   2577],
                        [  1588,   2075],
                        [  1077,   1560],
                        [   564,   1029],
                        [    57,    491],
                        [  -440,    -49],
                        [  -921,   -586],
                        [ -1383,  -1115],
                        [ -1822,  -1632],
                        [ -2235,  -2132],
                        [ -2618,  -2611],
                        [ -2969,  -3060],
                        [ -3286,  -3480],
                        [ -3567,  -3868],
                        [ -3812,  -4220],
                        [ -4024,  -4539],
                        [ -4200,  -4823],
                        [ -4346,  -5072],
                        [ -4461,  -5289],
                        [ -4548,  -5471],
                        [ -4610,  -5623],
                        [ -4649,  -5745],
                        [ -4666,  -5839],
                        [ -4664,  -5909],
                        [ -4645,  -5954],
                        [ -4613,  -5979],
                        [ -4567,  -5987],
                        [ -4516,  -5978],
                        [ -4458,  -5954],
                        [ -4410,  -5918],
                        [ -4373,  -5874],
                        [ -4355,  -5822],
                        [ -4359,  -5765],
                        [ -4383,  -5705],
                        [ -4429,  -5644],
                        [ -4479,  -5584],
                        [ -4538,  -5527],
                        [ -4591,  -5475],
                        [ -4643,  -5428],
                        [ -4693,  -5387],
                        [ -4741,  -5355],
                        [ -4788,  -5331],
                        [ -4833,  -5315],
                        [ -4879,  -5309],
                        [ -4925,  -5312],
                        [ -4984,  -5337],
                        [ -5054,  -5381],
                        [ -5179,  -5488],
                        [ -5354,  -5654],
                        [ -5592,  -5889],
                        [ -5892,  -6191],
                        [ -6221,  -6527],
                        [ -6576,  -6897],
                        [ -6896,  -7233],
                        [ -7181,  -7539],
                        [ -7424,  -7805],
                        [ -7622,  -8028],
                        [ -7779,  -8211],
                        [ -7894,  -8353],
                        [ -7971,  -8459],
                        [ -8009,  -8524],
                        [ -8011,  -8555],
                        [ -7978,  -8550],
                        [ -7913,  -8513],
                        [ -7815,  -8444],
                        [ -7690,  -8348],
                        [ -7534,  -8222],
                        [ -7356,  -8073],
                        [ -7149,  -7898],
                        [ -6923,  -7703],
                        [ -6674,  -7485],
                        [ -6404,  -7243],
                        [ -6114,  -6979],
                        [ -5802,  -6690],
                        [ -5468,  -6377],
                        [ -5113,  -6039],
                        [ -4736,  -5679],
                        [ -4340,  -5298],
                        [ -3922,  -4894],
                        [ -3486,  -4470],
                        [ -3032,  -4026],
                        [ -2562,  -3562],
                        [ -2076,  -3079],
                        [ -1575,  -2578],
                        [ -1064,  -2062],
                        [  -543,  -1530],
                        [   -14,   -985],
                        [   517,   -430],
                        [  1047,    132],
                        [  1574,    699],
                        [  2097,   1268],
                        [  2618,   1835],
                        [  3129,   2393],
                        [  3642,   2949],
                        [  4140,   3485],
                        [  4542,   3924],
                        [  4780,   4194],
                        [  4837,   4283],
                        [  4706,   4181],
                        [  4353,   3857],
                        [  3752,   3285],
                        [  2984,   2545],
                        [  2178,   1769],
                        [  1379,    999],
                        [   582,    232],
                        [  -199,   -516],
                        [  -949,  -1234],
                        [ -1657,  -1912],
                        [ -2319,  -2543],
                        [ -2923,  -3122],
                        [ -3465,  -3643],
                        [ -3941,  -4103],
                        [ -4350,  -4500],
                        [ -4692,  -4832],
                        [ -4968,  -5100],
                        [ -5182,  -5304],
                        [ -5336,  -5445],
                        [ -5431,  -5533],
                        [ -5470,  -5571],
                        [ -5457,  -5569],
                        [ -5393,  -5532],
                        [ -5283,  -5466],
                        [ -5130,  -5374],
                        [ -4938,  -5249],
                        [ -4710,  -5094],
                        [ -4451,  -4900],
                        [ -4163,  -4672],
                        [ -3850,  -4407],
                        [ -3515,  -4108],
                        [ -3161,  -3778],
                        [ -2793,  -3419],
                        [ -2412,  -3032],
                        [ -2022,  -2621],
                        [ -1626,  -2193],
                        [ -1228,  -1751],
                        [  -831,  -1302],
                        [  -436,   -848],
                        [   -49,   -397],
                        [   331,     54],
                        [   701,    501],
                        [  1061,    941],
                        [  1410,   1370],
                        [  1745,   1789],
                        [  2066,   2193],
                        [  2370,   2582],
                        [  2656,   2953],
                        [  2922,   3305],
                        [  3166,   3635],
                        [  3386,   3942],
                        [  3582,   4223],
                        [  3751,   4477],
                        [  3899,   4701],
                        [  4024,   4895],
                        [  4139,   5056],
                        [  4240,   5184],
                        [  4330,   5276],
                        [  4407,   5332],
                        [  4461,   5352],
                        [  4494,   5333],
                        [  4483,   5278],
                        [  4430,   5184],
                        [  4331,   5052],
                        [  4186,   4883],
                        [  3995,   4676],
                        [  3758,   4431],
                        [  3477,   4150],
                        [  3154,   3835],
                        [  2795,   3491],
                        [  2400,   3117],
                        [  2013,   2755],
                        [  1632,   2406],
                        [  1299,   2106],
                        [  1011,   1854],
                        [   767,   1649],
                        [   570,   1490],
                        [   358,   1318],
                        [   137,   1135],
                        [  -133,    900],
                        [  -451,    617],
                        [  -806,    291],
                        [ -1199,    -76],
                        [ -1622,   -479],
                        [ -2072,   -914],
                        [ -2542,  -1372],
                        [ -3027,  -1853],
                        [ -3522,  -2347],
                        [ -4024,  -2853],
                        [ -4522,  -3360],
                        [ -5017,  -3867],
                        [ -5500,  -4364],
                        [ -5970,  -4852],
                        [ -6420,  -5322],
                        [ -6849,  -5773],
                        [ -7252,  -6200],
                        [ -7629,  -6604],
                        [ -7979,  -6983],
                        [ -8301,  -7339],
                        [ -8599,  -7668],
                        [ -8870,  -7973],
                        [ -9117,  -8253],
                        [ -9341,  -8506],
                        [ -9542,  -8735],
                        [ -9721,  -8939],
                        [ -9881,  -9122],
                        [-10022,  -9284],
                        [-10149,  -9432],
                        [-10261,  -9562],
                        [-10361,  -9682],
                        [-10450,  -9791],
                        [-10527,  -9891],
                        [-10592,  -9984],
                        [-10644, -10073],
                        [-10685, -10156],
                        [-10723, -10240],
                        [-10753, -10320],
                        [-10785, -10395],
                        [-10827, -10475],
                        [-10866, -10545],
                        [-10837, -10540],
                        [-10693, -10414],
                        [-10429, -10164],
                        [-10038,  -9783],
                        [ -9485,  -9237],
                        [ -8737,  -8495],
                        [ -7859,  -7621],
                        [ -6962,  -6728],
                        [ -6078,  -5849],
                        [ -5207,  -4986],
                        [ -4362,  -4149],
                        [ -3560,  -3358],
                        [ -2810,  -2620],
                        [ -2117,  -1940],
                        [ -1492,  -1327],
                        [  -938,   -785],
                        [  -458,   -316],
                        [   -53,     78],
                        [   276,    396],
                        [   538,    639],
                        [   730,    811],
                        [   862,    917],
                        [   934,    960],
                        [   954,    956],
                        [   924,    910],
                        [   851,    834],
                        [   740,    733],
                        [   597,    612],
                        [   428,    477],
                        [   237,    319],
                        [    32,    145],
                        [  -185,    -49],
                        [  -407,   -259],
                        [  -631,   -485],
                        [  -854,   -720],
                        [ -1071,   -968],
                        [ -1280,  -1222],
                        [ -1476,  -1479],
                        [ -1658,  -1738],
                        [ -1824,  -1988],
                        [ -1972,  -2229],
                        [ -2101,  -2453],
                        [ -2211,  -2660],
                        [ -2302,  -2849],
                        [ -2373,  -3018],
                        [ -2429,  -3170],
                        [ -2472,  -3306],
                        [ -2503,  -3426],
                        [ -2523,  -3530],
                        [ -2536,  -3620],
                        [ -2542,  -3699],
                        [ -2545,  -3766],
                        [ -2546,  -3827],
                        [ -2548,  -3881],
                        [ -2551,  -3931],
                        [ -2561,  -3978],
                        [ -2578,  -4024],
                        [ -2615,  -4071],
                        [ -2676,  -4120],
                        [ -2765,  -4171],
                        [ -2884,  -4228],
                        [ -3034,  -4290],
                        [ -3216,  -4358],
                        [ -3411,  -4434],
                        [ -3622,  -4517],
                        [ -3834,  -4608],
                        [ -4049,  -4707],
                        [ -4262,  -4812],
                        [ -4473,  -4926],
                        [ -4678,  -5043],
                        [ -4877,  -5165],
                        [ -5068,  -5292],
                        [ -5253,  -5422],
                        [ -5447,  -5572],
                        [ -5648,  -5742],
                        [ -5907,  -5982],
                        [ -6221,  -6286],
                        [ -6598,  -6664],
                        [ -7036,  -7113],
                        [ -7503,  -7601],
                        [ -8002,  -8128],
                        [ -8444,  -8608],
                        [ -8834,  -9042],
                        [ -9159,  -9414],
                        [ -9414,  -9724],
                        [ -9603,  -9969],
                        [ -9720, -10144],
                        [ -9769, -10254],
                        [ -9748, -10296],
                        [ -9661, -10272],
                        [ -9508, -10183],
                        [ -9294, -10033],
                        [ -9019,  -9820],
                        [ -8691,  -9553],
                        [ -8307,  -9229],
                        [ -7879,  -8860],
                        [ -7404,  -8443],
                        [ -6893,  -7985],
                        [ -6346,  -7489],
                        [ -5770,  -6957],
                        [ -5163,  -6393],
                        [ -4534,  -5800],
                        [ -3881,  -5181],
                        [ -3210,  -4538],
                        [ -2523,  -3877],
                        [ -1824,  -3202],
                        [ -1118,  -2517],
                        [  -408,  -1827],
                        [   304,  -1132],
                        [  1012,   -437],
                        [  1713,    254],
                        [  2404,    941],
                        [  3082,   1619],
                        [  3738,   2285],
                        [  4371,   2937],
                        [  4971,   3571],
                        [  5533,   4181],
                        [  6059,   4768],
                        [  6543,   5326],
                        [  6992,   5852],
                        [  7399,   6341],
                        [  7781,   6797],
                        [  8114,   7202],
                        [  8354,   7508],
                        [  8476,   7690],
                        [  8479,   7748],
                        [  8356,   7673],
                        [  8067,   7429],
                        [  7577,   6976],
                        [  6924,   6359],
                        [  6199,   5664],
                        [  5424,   4916],
                        [  4604,   4120],
                        [  3759,   3294],
                        [  2904,   2456],
                        [  2055,   1619],
                        [  1222,    791],
                        [   418,    -13],
                        [  -346,   -782],
                        [ -1061,  -1510],
                        [ -1723,  -2188],
                        [ -2324,  -2810],
                        [ -2861,  -3371],
                        [ -3335,  -3868],
                        [ -3743,  -4299],
                        [ -4084,  -4668],
                        [ -4357,  -4975],
                        [ -4564,  -5228],
                        [ -4706,  -5431],
                        [ -4785,  -5584],
                        [ -4803,  -5693],
                        [ -4764,  -5753],
                        [ -4670,  -5767],
                        [ -4527,  -5726],
                        [ -4338,  -5633],
                        [ -4107,  -5487],
                        [ -3839,  -5291],
                        [ -3538,  -5042],
                        [ -3209,  -4748],
                        [ -2858,  -4408],
                        [ -2489,  -4025],
                        [ -2108,  -3611],
                        [ -1719,  -3169],
                        [ -1328,  -2714],
                        [  -940,  -2247],
                        [  -559,  -1780],
                        [  -189,  -1316],
                        [   167,   -860],
                        [   506,   -413],
                        [   825,     17],
                        [  1123,    430],
                        [  1396,    820],
                        [  1643,   1185],
                        [  1861,   1523],
                        [  2049,   1830],
                        [  2205,   2104],
                        [  2329,   2345],
                        [  2418,   2549],
                        [  2473,   2715],
                        [  2498,   2843],
                        [  2494,   2931],
                        [  2470,   2978],
                        [  2426,   2984],
                        [  2365,   2949],
                        [  2288,   2874],
                        [  2191,   2760],
                        [  2078,   2606],
                        [  1928,   2415],
                        [  1746,   2188],
                        [  1529,   1926],
                        [  1281,   1634],
                        [   998,   1311],
                        [   682,    957],
                        [   336,    578],
                        [   -34,    178],
                        [  -423,   -236],
                        [  -830,   -663],
                        [ -1201,  -1050],
                        [ -1537,  -1399],
                        [ -1803,  -1673],
                        [ -1999,  -1872],
                        [ -2120,  -1993],
                        [ -2165,  -2035],
                        [ -2198,  -2061],
                        [ -2214,  -2069],
                        [ -2263,  -2108],
                        [ -2338,  -2172],
                        [ -2441,  -2263],
                        [ -2568,  -2378],
                        [ -2719,  -2519],
                        [ -2896,  -2683],
                        [ -3091,  -2867],
                        [ -3305,  -3072],
                        [ -3534,  -3291],
                        [ -3776,  -3525],
                        [ -4026,  -3768],
                        [ -4285,  -4019],
                        [ -4545,  -4271],
                        [ -4808,  -4526],
                        [ -5066,  -4778],
                        [ -5320,  -5025],
                        [ -5567,  -5266],
                        [ -5805,  -5498],
                        [ -6035,  -5722],
                        [ -6255,  -5937],
                        [ -6468,  -6142],
                        [ -6674,  -6339],
                        [ -6871,  -6524],
                        [ -7059,  -6699],
                        [ -7241,  -6862],
                        [ -7415,  -7015],
                        [ -7583,  -7158],
                        [ -7744,  -7291],
                        [ -7898,  -7417],
                        [ -8049,  -7537],
                        [ -8190,  -7651],
                        [ -8323,  -7763],
                        [ -8443,  -7871],
                        [ -8547,  -7974],
                        [ -8632,  -8073],
                        [ -8700,  -8170],
                        [ -8755,  -8262],
                        [ -8793,  -8348],
                        [ -8825,  -8426],
                        [ -8855,  -8502],
                        [ -8873,  -8560],
                        [ -8852,  -8576],
                        [ -8792,  -8548],
                        [ -8697,  -8482],
                        [ -8555,  -8366],
                        [ -8328,  -8162],
                        [ -7968,  -7824],
                        [ -7489,  -7365],
                        [ -6944,  -6839],
                        [ -6351,  -6264],
                        [ -5710,  -5641],
                        [ -5038,  -4989],
                        [ -4348,  -4318],
                        [ -3651,  -3638],
                        [ -2953,  -2958],
                        [ -2266,  -2289],
                        [ -1599,  -1637],
                        [  -958,  -1010],
                        [  -345,   -410],
                        [   231,    154],
                        [   772,    683],
                        [  1275,   1172],
                        [  1741,   1623],
                        [  2169,   2036],
                        [  2559,   2419],
                        [  2910,   2771],
                        [  3227,   3102],
                        [  3510,   3413],
                        [  3760,   3704],
                        [  3979,   3979],
                        [  4169,   4231],
                        [  4334,   4463],
                        [  4474,   4666],
                        [  4593,   4845],
                        [  4692,   4994],
                        [  4773,   5116],
                        [  4838,   5203],
                        [  4888,   5261],
                        [  4927,   5289],
                        [  4955,   5287],
                        [  4975,   5267],
                        [  4987,   5227],
                        [  4991,   5177],
                        [  4990,   5120],
                        [  4983,   5055],
                        [  4969,   4984],
                        [  4949,   4906],
                        [  4921,   4821],
                        [  4883,   4730],
                        [  4837,   4631],
                        [  4779,   4526],
                        [  4712,   4413],
                        [  4631,   4292],
                        [  4539,   4162],
                        [  4433,   4025],
                        [  4314,   3878],
                        [  4181,   3722],
                        [  4032,   3558],
                        [  3862,   3385],
                        [  3669,   3204],
                        [  3452,   3014],
                        [  3211,   2819],
                        [  2945,   2618],
                        [  2654,   2411],
                        [  2350,   2200],
                        [  2034,   1987],
                        [  1719,   1772],
                        [  1406,   1557],
                        [  1099,   1342],
                        [   803,   1133],
                        [   522,    930],
                        [   258,    735],
                        [    12,    550],
                        [  -215,    373],
                        [  -443,    184],
                        [  -667,    -12],
                        [  -935,   -263],
                        [ -1242,   -564],
                        [ -1595,   -922],
                        [ -1993,  -1336],
                        [ -2414,  -1783],
                        [ -2858,  -2262],
                        [ -3242,  -2689],
                        [ -3570,  -3068],
                        [ -3829,  -3383],
                        [ -4016,  -3633],
                        [ -4128,  -3811],
                        [ -4162,  -3916],
                        [ -4121,  -3947],
                        [ -4003,  -3903],
                        [ -3811,  -3787],
                        [ -3548,  -3599],
                        [ -3216,  -3340],
                        [ -2818,  -3015],
                        [ -2361,  -2630],
                        [ -1846,  -2184],
                        [ -1284,  -1688],
                        [  -676,  -1141],
                        [   -33,   -554],
                        [   645,     72],
                        [  1346,    726],
                        [  2070,   1407],
                        [  2809,   2108],
                        [  3560,   2827],
                        [  4317,   3553],
                        [  5075,   4284],
                        [  5828,   5012],
                        [  6574,   5734],
                        [  7304,   6441],
                        [  8015,   7131],
                        [  8704,   7800],
                        [  9365,   8444],
                        [  9995,   9059],
                        [ 10589,   9644],
                        [ 11138,  10195],
                        [ 11639,  10710],
                        [ 12084,  11185],
                        [ 12469,  11616],
                        [ 12794,  12003],
                        [ 13058,  12344],
                        [ 13269,  12636],
                        [ 13424,  12876],
                        [ 13535,  13066],
                        [ 13596,  13201],
                        [ 13612,  13284],
                        [ 13601,  13334],
                        [ 13573,  13359],
                        [ 13518,  13349],
                        [ 13404,  13273],
                        [ 13176,  13076],
                        [ 12821,  12745],
                        [ 12367,  12306],
                        [ 11828,  11776],
                        [ 11213,  11165],
                        [ 10537,  10486],
                        [  9818,   9758],
                        [  9069,   8994],
                        [  8300,   8205],
                        [  7526,   7406],
                        [  6761,   6610],
                        [  6014,   5826],
                        [  5295,   5066],
                        [  4612,   4338],
                        [  3973,   3650],
                        [  3381,   3008],
                        [  2840,   2416],
                        [  2352,   1876],
                        [  1924,   1390],
                        [  1554,    954],
                        [  1242,    570],
                        [   987,    232],
                        [   791,    -58],
                        [   649,   -300],
                        [   560,   -496],
                        [   520,   -641],
                        [   527,   -737],
                        [   575,   -782],
                        [   662,   -779],
                        [   782,   -724],
                        [   930,   -623],
                        [  1099,   -475],
                        [  1287,   -283],
                        [  1486,    -57],
                        [  1692,    200],
                        [  1899,    470],
                        [  2104,    754],
                        [  2300,   1034],
                        [  2485,   1310],
                        [  2654,   1578],
                        [  2803,   1833],
                        [  2932,   2070],
                        [  3036,   2287],
                        [  3114,   2481],
                        [  3166,   2648],
                        [  3190,   2786],
                        [  3183,   2895],
                        [  3148,   2972],
                        [  3083,   3016],
                        [  2988,   3027],
                        [  2863,   3004],
                        [  2715,   2947],
                        [  2542,   2856],
                        [  2351,   2733],
                        [  2143,   2577],
                        [  1922,   2392],
                        [  1692,   2177],
                        [  1454,   1936],
                        [  1211,   1670],
                        [   957,   1382],
                        [   694,   1074],
                        [   420,    750],
                        [   139,    413],
                        [  -151,     63],
                        [  -450,   -297],
                        [  -753,   -661],
                        [ -1056,  -1026],
                        [ -1353,  -1383],
                        [ -1641,  -1730],
                        [ -1878,  -2020],
                        [ -2062,  -2256],
                        [ -2173,  -2411],
                        [ -2208,  -2487],
                        [ -2157,  -2472],
                        [ -2021,  -2364],
                        [ -1853,  -2221],
                        [ -1649,  -2037],
                        [ -1456,  -1857],
                        [ -1268,  -1676],
                        [ -1093,  -1504],
                        [  -930,  -1339],
                        [  -784,  -1188],
                        [  -658,  -1051],
                        [  -553,   -931],
                        [  -469,   -828],
                        [  -406,   -743],
                        [  -367,   -679],
                        [  -349,   -634],
                        [  -355,   -607],
                        [  -379,   -597],
                        [  -425,   -608],
                        [  -486,   -633],
                        [  -566,   -675],
                        [  -660,   -730],
                        [  -769,   -800],
                        [  -891,   -881],
                        [ -1026,   -974],
                        [ -1173,  -1077],
                        [ -1332,  -1190],
                        [ -1501,  -1311],
                        [ -1680,  -1439],
                        [ -1866,  -1570],
                        [ -2059,  -1705],
                        [ -2256,  -1842],
                        [ -2457,  -1980],
                        [ -2659,  -2120],
                        [ -2861,  -2260],
                        [ -3055,  -2399],
                        [ -3244,  -2539],
                        [ -3412,  -2676],
                        [ -3560,  -2807],
                        [ -3686,  -2933],
                        [ -3784,  -3051],
                        [ -3858,  -3157],
                        [ -3904,  -3252],
                        [ -3936,  -3332],
                        [ -3946,  -3394],
                        [ -3945,  -3441],
                        [ -3961,  -3505],
                        [ -4025,  -3616],
                        [ -4144,  -3778],
                        [ -4306,  -3982],
                        [ -4480,  -4196],
                        [ -4600,  -4353],
                        [ -4614,  -4401],
                        [ -4522,  -4340],
                        [ -4331,  -4179],
                        [ -4045,  -3921],
                        [ -3677,  -3577],
                        [ -3234,  -3157],
                        [ -2727,  -2671],
                        [ -2163,  -2126],
                        [ -1554,  -1536],
                        [  -911,   -907],
                        [  -242,   -249],
                        [   444,    429],
                        [  1138,   1120],
                        [  1832,   1816],
                        [  2523,   2511],
                        [  3204,   3200],
                        [  3871,   3879],
                        [  4518,   4546],
                        [  5142,   5196],
                        [  5741,   5830],
                        [  6312,   6446],
                        [  6849,   7042],
                        [  7354,   7618],
                        [  7824,   8168],
                        [  8257,   8693],
                        [  8653,   9182],
                        [  9011,   9638],
                        [  9330,  10050],
                        [  9612,  10420],
                        [  9855,  10738],
                        [ 10061,  11005],
                        [ 10233,  11221],
                        [ 10369,  11383],
                        [ 10472,  11499],
                        [ 10541,  11569],
                        [ 10578,  11604],
                        [ 10584,  11606],
                        [ 10560,  11576],
                        [ 10509,  11516],
                        [ 10431,  11427],
                        [ 10326,  11310],
                        [ 10197,  11167],
                        [ 10043,  10999],
                        [  9867,  10808],
                        [  9670,  10595],
                        [  9451,  10361],
                        [  9213,  10108],
                        [  8958,   9839],
                        [  8687,   9555],
                        [  8402,   9258],
                        [  8103,   8948],
                        [  7792,   8630],
                        [  7471,   8306],
                        [  7139,   7977],
                        [  6801,   7647],
                        [  6455,   7316],
                        [  6101,   6988],
                        [  5743,   6664],
                        [  5384,   6348],
                        [  5032,   6042],
                        [  4687,   5746],
                        [  4357,   5463],
                        [  4043,   5198],
                        [  3752,   4952],
                        [  3484,   4726],
                        [  3242,   4522],
                        [  3026,   4337],
                        [  2818,   4155],
                        [  2623,   3980],
                        [  2412,   3780],
                        [  2188,   3560],
                        [  1942,   3309],
                        [  1674,   3029],
                        [  1390,   2727],
                        [  1091,   2401],
                        [   836,   2114],
                        [   620,   1860],
                        [   457,   1653],
                        [   345,   1493],
                        [   293,   1389],
                        [   299,   1338],
                        [   366,   1347],
                        [   492,   1411],
                        [   675,   1534],
                        [   917,   1713],
                        [  1211,   1945],
                        [  1556,   2230],
                        [  1947,   2560],
                        [  2381,   2936],
                        [  2850,   3351],
                        [  3352,   3802],
                        [  3878,   4281],
                        [  4426,   4786],
                        [  4985,   5305],
                        [  5554,   5839],
                        [  6126,   6377],
                        [  6697,   6918],
                        [  7261,   7452],
                        [  7815,   7977],
                        [  8351,   8484],
                        [  8868,   8972],
                        [  9360,   9433],
                        [  9822,   9864],
                        [ 10251,  10261],
                        [ 10645,  10623],
                        [ 10996,  10945],
                        [ 11307,  11228],
                        [ 11565,  11469],
                        [ 11769,  11667],
                        [ 11914,  11818],
                        [ 11998,  11924],
                        [ 12022,  11984],
                        [ 11984,  11996],
                        [ 11897,  11962],
                        [ 11760,  11880],
                        [ 11578,  11750],
                        [ 11376,  11594],
                        [ 11212,  11473],
                        [ 11127,  11425],
                        [ 11135,  11461],
                        [ 11230,  11578],
                        [ 11390,  11753],
                        [ 11544,  11915],
                        [ 11611,  11980],
                        [ 11572,  11935],
                        [ 11438,  11787],
                        [ 11214,  11543],
                        [ 10911,  11215],
                        [ 10539,  10812],
                        [ 10107,  10345],
                        [  9623,   9825],
                        [  9101,   9263],
                        [  8550,   8670],
                        [  7982,   8058],
                        [  7405,   7433],
                        [  6831,   6806],
                        [  6266,   6186],
                        [  5714,   5577],
                        [  5184,   4989],
                        [  4676,   4423],
                        [  4197,   3885],
                        [  3748,   3378],
                        [  3331,   2901],
                        [  2948,   2457],
                        [  2598,   2045],
                        [  2282,   1662],
                        [  1999,   1307],
                        [  1747,    982],
                        [  1525,    685],
                        [  1330,    418],
                        [  1159,    180],
                        [  1009,    -24],
                        [   878,   -199],
                        [   758,   -340],
                        [   649,   -453],
                        [   544,   -540],
                        [   443,   -605],
                        [   340,   -660],
                        [   234,   -707],
                        [   120,   -759],
                        [    -2,   -817],
                        [  -137,   -882],
                        [  -287,   -959],
                        [  -453,  -1049],
                        [  -636,  -1156],
                        [  -837,  -1280],
                        [ -1055,  -1420],
                        [ -1292,  -1580],
                        [ -1547,  -1761],
                        [ -1816,  -1958],
                        [ -2102,  -2175],
                        [ -2401,  -2410],
                        [ -2712,  -2662],
                        [ -3032,  -2929],
                        [ -3362,  -3211],
                        [ -3699,  -3504],
                        [ -4041,  -3808],
                        [ -4382,  -4119],
                        [ -4723,  -4436],
                        [ -5052,  -4756],
                        [ -5368,  -5076],
                        [ -5668,  -5394],
                        [ -5950,  -5707],
                        [ -6213,  -6013],
                        [ -6455,  -6306],
                        [ -6679,  -6588],
                        [ -6883,  -6858],
                        [ -7066,  -7109],
                        [ -7223,  -7339],
                        [ -7353,  -7542],
                        [ -7455,  -7717],
                        [ -7505,  -7838],
                        [ -7505,  -7906],
                        [ -7447,  -7914],
                        [ -7333,  -7858],
                        [ -7144,  -7722],
                        [ -6882,  -7508],
                        [ -6576,  -7243],
                        [ -6226,  -6927],
                        [ -5863,  -6592],
                        [ -5487,  -6234],
                        [ -5111,  -5870],
                        [ -4734,  -5497],
                        [ -4368,  -5128],
                        [ -4013,  -4763],
                        [ -3678,  -4411],
                        [ -3365,  -4074],
                        [ -3079,  -3759],
                        [ -2820,  -3465],
                        [ -2592,  -3196],
                        [ -2397,  -2957],
                        [ -2234,  -2747],
                        [ -2107,  -2569],
                        [ -2011,  -2422],
                        [ -1950,  -2308],
                        [ -1920,  -2225],
                        [ -1921,  -2172],
                        [ -1951,  -2147],
                        [ -2009,  -2151],
                        [ -2093,  -2178],
                        [ -2214,  -2241],
                        [ -2353,  -2321],
                        [ -2511,  -2418],
                        [ -2681,  -2526],
                        [ -2863,  -2646],
                        [ -3052,  -2770],
                        [ -3244,  -2899],
                        [ -3436,  -3029],
                        [ -3625,  -3158],
                        [ -3802,  -3284],
                        [ -3966,  -3404],
                        [ -4106,  -3516],
                        [ -4219,  -3616],
                        [ -4301,  -3702],
                        [ -4350,  -3771],
                        [ -4364,  -3820],
                        [ -4344,  -3850],
                        [ -4297,  -3854],
                        [ -4215,  -3829],
                        [ -4141,  -3809],
                        [ -4148,  -3874],
                        [ -4280,  -4063],
                        [ -4544,  -4380],
                        [ -4934,  -4824],
                        [ -5436,  -5376],
                        [ -5964,  -5949],
                        [ -6406,  -6433],
                        [ -6725,  -6789],
                        [ -6928,  -7027],
                        [ -7019,  -7145],
                        [ -7000,  -7149],
                        [ -6875,  -7044],
                        [ -6658,  -6844],
                        [ -6346,  -6546],
                        [ -5949,  -6160],
                        [ -5476,  -5694],
                        [ -4938,  -5158],
                        [ -4347,  -4561],
                        [ -3712,  -3912],
                        [ -3041,  -3221],
                        [ -2347,  -2497],
                        [ -1636,  -1749],
                        [  -915,   -986],
                        [  -194,   -219],
                        [   521,    548],
                        [  1223,   1304],
                        [  1905,   2043],
                        [  2562,   2764],
                        [  3186,   3459],
                        [  3774,   4128],
                        [  4322,   4769],
                        [  4826,   5374],
                        [  5285,   5942],
                        [  5693,   6462],
                        [  6053,   6933],
                        [  6361,   7346],
                        [  6619,   7699],
                        [  6827,   7990],
                        [  6983,   8217],
                        [  7092,   8383],
                        [  7150,   8489],
                        [  7161,   8544],
                        [  7126,   8549],
                        [  7048,   8508],
                        [  6933,   8430],
                        [  6784,   8312],
                        [  6603,   8156],
                        [  6392,   7966],
                        [  6153,   7746],
                        [  5891,   7497],
                        [  5607,   7222],
                        [  5306,   6927],
                        [  4989,   6612],
                        [  4661,   6284],
                        [  4323,   5942],
                        [  3980,   5592],
                        [  3635,   5238],
                        [  3295,   4882],
                        [  2961,   4526],
                        [  2640,   4175],
                        [  2338,   3837],
                        [  2048,   3507],
                        [  1773,   3190],
                        [  1505,   2887],
                        [  1248,   2601],
                        [  1002,   2334],
                        [   768,   2087],
                        [   550,   1861],
                        [   350,   1661],
                        [   172,   1485],
                        [    16,   1335],
                        [  -118,   1208],
                        [  -229,   1107],
                        [  -323,   1021],
                        [  -400,    952],
                        [  -464,    895],
                        [  -514,    850],
                        [  -562,    804],
                        [  -609,    757],
                        [  -671,    692],
                        [  -748,    610],
                        [  -815,    535],
                        [  -874,    465],
                        [  -915,    409],
                        [  -942,    366],
                        [  -943,    345],
                        [  -921,    343],
                        [  -871,    367],
                        [  -795,    415],
                        [  -691,    491],
                        [  -560,    592],
                        [  -401,    719],
                        [  -217,    872],
                        [    -9,   1049],
                        [   220,   1247],
                        [   468,   1465],
                        [   730,   1700],
                        [  1004,   1948],
                        [  1286,   2206],
                        [  1571,   2469],
                        [  1858,   2734],
                        [  2139,   2995],
                        [  2415,   3248],
                        [  2678,   3488],
                        [  2929,   3714],
                        [  3161,   3919],
                        [  3375,   4102],
                        [  3564,   4259],
                        [  3729,   4388],
                        [  3866,   4486],
                        [  3973,   4552],
                        [  4046,   4584],
                        [  4087,   4583],
                        [  4086,   4546],
                        [  4045,   4474],
                        [  3962,   4369],
                        [  3835,   4228],
                        [  3664,   4053],
                        [  3451,   3845],
                        [  3205,   3608],
                        [  2924,   3338],
                        [  2615,   3036],
                        [  2333,   2760],
                        [  2173,   2602],
                        [  2178,   2607],
                        [  2357,   2780],
                        [  2716,   3129],
                        [  3247,   3643],
                        [  3859,   4235],
                        [  4420,   4769],
                        [  4886,   5204],
                        [  5265,   5547],
                        [  5557,   5797],
                        [  5759,   5956],
                        [  5877,   6027],
                        [  5910,   6015],
                        [  5865,   5926],
                        [  5748,   5765],
                        [  5566,   5540],
                        [  5327,   5258],
                        [  5039,   4925],
                        [  4711,   4548],
                        [  4349,   4135],
                        [  3959,   3690],
                        [  3545,   3222],
                        [  3113,   2737],
                        [  2667,   2240],
                        [  2212,   1741],
                        [  1750,   1243],
                        [  1285,    748],
                        [   819,    259],
                        [   353,   -228],
                        [  -107,   -713],
                        [  -564,  -1198],
                        [ -1015,  -1684],
                        [ -1458,  -2165],
                        [ -1896,  -2644],
                        [ -2329,  -3114],
                        [ -2755,  -3575],
                        [ -3178,  -4023],
                        [ -3597,  -4458],
                        [ -4014,  -4880],
                        [ -4428,  -5289],
                        [ -4839,  -5690],
                        [ -5248,  -6082],
                        [ -5654,  -6474],
                        [ -6059,  -6865],
                        [ -6463,  -7253],
                        [ -6865,  -7641],
                        [ -7267,  -8028],
                        [ -7669,  -8415],
                        [ -8069,  -8801],
                        [ -8466,  -9185],
                        [ -8860,  -9566],
                        [ -9248,  -9943],
                        [ -9628, -10316],
                        [-10002, -10684],
                        [-10363, -11044],
                        [-10713, -11395],
                        [-11052, -11734],
                        [-11378, -12062],
                        [-11695, -12374],
                        [-12002, -12669],
                        [-12296, -12946],
                        [-12575, -13202],
                        [-12826, -13436],
                        [-13050, -13646],
                        [-13237, -13831],
                        [-13384, -13989],
                        [-13492, -14117],
                        [-13558, -14217],
                        [-13586, -14286],
                        [-13574, -14327],
                        [-13526, -14334],
                        [-13438, -14309],
                        [-13315, -14252],
                        [-13157, -14161],
                        [-12972, -14042],
                        [-12762, -13898],
                        [-12530, -13730],
                        [-12279, -13539],
                        [-11985, -13301],
                        [-11651, -13017],
                        [-11272, -12683],
                        [-10849, -12299],
                        [-10399, -11880],
                        [ -9923, -11429],
                        [ -9436, -10958],
                        [ -8940, -10468],
                        [ -8446,  -9975],
                        [ -7956,  -9478],
                        [ -7482,  -8988],
                        [ -7022,  -8507],
                        [ -6589,  -8045],
                        [ -6179,  -7602],
                        [ -5802,  -7185],
                        [ -5457,  -6796],
                        [ -5147,  -6440],
                        [ -4874,  -6117],
                        [ -4639,  -5830],
                        [ -4440,  -5580],
                        [ -4278,  -5367],
                        [ -4151,  -5189],
                        [ -4056,  -5043],
                        [ -3992,  -4929],
                        [ -3954,  -4841],
                        [ -3943,  -4778],
                        [ -3952,  -4738],
                        [ -3980,  -4716],
                        [ -4021,  -4707],
                        [ -4074,  -4712],
                        [ -4132,  -4723],
                        [ -4193,  -4739],
                        [ -4250,  -4755],
                        [ -4303,  -4768],
                        [ -4342,  -4773],
                        [ -4366,  -4770],
                        [ -4366,  -4752],
                        [ -4341,  -4719],
                        [ -4285,  -4666],
                        [ -4196,  -4591],
                        [ -4071,  -4492],
                        [ -3912,  -4370],
                        [ -3718,  -4215],
                        [ -3490,  -4031],
                        [ -3298,  -3884],
                        [ -3237,  -3871],
                        [ -3346,  -4025],
                        [ -3627,  -4352],
                        [ -4093,  -4860],
                        [ -4744,  -5550],
                        [ -5480,  -6321],
                        [ -6155,  -7026],
                        [ -6721,  -7616],
                        [ -7187,  -8099],
                        [ -7547,  -8471],
                        [ -7799,  -8730],
                        [ -7941,  -8874],
                        [ -7977,  -8909],
                        [ -7911,  -8839],
                        [ -7746,  -8669],
                        [ -7496,  -8408],
                        [ -7165,  -8060],
                        [ -6768,  -7638],
                        [ -6315,  -7148],
                        [ -5813,  -6601],
                        [ -5272,  -6004],
                        [ -4701,  -5371],
                        [ -4110,  -4710],
                        [ -3506,  -4037],
                        [ -2898,  -3359],
                        [ -2294,  -2689],
                        [ -1700,  -2037],
                        [ -1123,  -1403],
                        [  -570,   -795],
                        [   -46,   -207],
                        [   445,    353],
                        [   896,    886],
                        [  1307,   1389],
                        [  1674,   1853],
                        [  1994,   2277],
                        [  2269,   2655],
                        [  2498,   2986],
                        [  2680,   3265],
                        [  2818,   3494],
                        [  2910,   3670],
                        [  2958,   3795],
                        [  2964,   3874],
                        [  2929,   3909],
                        [  2858,   3905],
                        [  2750,   3863],
                        [  2614,   3786],
                        [  2451,   3678],
                        [  2266,   3543],
                        [  2062,   3382],
                        [  1844,   3200],
                        [  1615,   3001],
                        [  1377,   2789],
                        [  1136,   2567],
                        [   893,   2338],
                        [   653,   2105],
                        [   418,   1874],
                        [   194,   1645],
                        [   -11,   1423],
                        [  -194,   1209],
                        [  -349,   1007],
                        [  -472,    817],
                        [  -570,    644],
                        [  -638,    487],
                        [  -691,    348],
                        [  -726,    229],
                        [  -754,    131],
                        [  -769,     54],
                        [  -775,     -3],
                        [  -769,    -38],
                        [  -752,    -52],
                        [  -724,    -46],
                        [  -685,    -21],
                        [  -635,     22],
                        [  -564,     93],
                        [  -473,    189],
                        [  -345,    327],
                        [  -181,    503],
                        [     3,    704],
                        [   209,    929],
                        [   394,   1135],
                        [   560,   1324],
                        [   696,   1483],
                        [   803,   1612],
                        [   886,   1717],
                        [   942,   1793],
                        [   982,   1851],
                        [  1001,   1886],
                        [  1007,   1905],
                        [   996,   1907],
                        [   977,   1896],
                        [   947,   1872],
                        [   909,   1837],
                        [   862,   1792],
                        [   811,   1740],
                        [   753,   1679],
                        [   692,   1612],
                        [   625,   1537],
                        [   554,   1459],
                        [   479,   1373],
                        [   397,   1281],
                        [   307,   1181],
                        [   210,   1068],
                        [   104,    945],
                        [   -11,    808],
                        [  -137,    658],
                        [  -274,    492],
                        [  -422,    313],
                        [  -580,    119],
                        [  -750,    -90],
                        [  -933,   -315],
                        [ -1127,   -554],
                        [ -1334,   -808],
                        [ -1552,  -1077],
                        [ -1783,  -1359],
                        [ -2026,  -1653],
                        [ -2281,  -1957],
                        [ -2547,  -2272],
                        [ -2829,  -2596],
                        [ -3122,  -2926],
                        [ -3420,  -3257],
                        [ -3729,  -3597],
                        [ -4039,  -3935],
                        [ -4268,  -4192],
                        [ -4322,  -4273],
                        [ -4170,  -4147],
                        [ -3807,  -3812],
                        [ -3213,  -3247],
                        [ -2384,  -2446],
                        [ -1417,  -1510],
                        [  -467,   -592],
                        [   420,    262],
                        [  1247,   1055],
                        [  2008,   1779],
                        [  2687,   2424],
                        [  3283,   2987],
                        [  3789,   3465],
                        [  4206,   3857],
                        [  4531,   4163],
                        [  4768,   4384],
                        [  4922,   4522],
                        [  4996,   4580],
                        [  4997,   4561],
                        [  4928,   4468],
                        [  4792,   4307],
                        [  4595,   4083],
                        [  4340,   3803],
                        [  4035,   3476],
                        [  3681,   3113],
                        [  3285,   2717],
                        [  2850,   2297],
                        [  2381,   1856],
                        [  1882,   1389],
                        [  1358,    899],
                        [   813,    380],
                        [   250,   -165],
                        [  -325,   -734],
                        [  -912,  -1324],
                        [ -1506,  -1926],
                        [ -2104,  -2542],
                        [ -2705,  -3163],
                        [ -3305,  -3790],
                        [ -3903,  -4414],
                        [ -4496,  -5036],
                        [ -5078,  -5649],
                        [ -5651,  -6253],
                        [ -6208,  -6847],
                        [ -6749,  -7430],
                        [ -7274,  -7997],
                        [ -7778,  -8549],
                        [ -8264,  -9084],
                        [ -8729,  -9599],
                        [ -9171, -10093],
                        [ -9589, -10563],
                        [ -9982, -11008],
                        [-10348, -11426],
                        [-10686, -11816],
                        [-10994, -12177],
                        [-11271, -12506],
                        [-11516, -12803],
                        [-11733, -13066],
                        [-11923, -13293],
                        [-12091, -13485],
                        [-12237, -13639],
                        [-12363, -13756],
                        [-12470, -13834],
                        [-12545, -13874],
                        [-12588, -13875],
                        [-12586, -13838],
                        [-12540, -13763],
                        [-12448, -13651],
                        [-12308, -13502],
                        [-12125, -13318],
                        [-11900, -13100],
                        [-11635, -12849],
                        [-11332, -12566],
                        [-11004, -12261],
                        [-10649, -11936],
                        [-10307, -11624],
                        [ -9977, -11326],
                        [ -9672, -11053],
                        [ -9393, -10807],
                        [ -9111, -10557],
                        [ -8831, -10307],
                        [ -8509, -10014],
                        [ -8151,  -9680],
                        [ -7760,  -9310],
                        [ -7337,  -8903],
                        [ -6895,  -8472],
                        [ -6433,  -8016],
                        [ -5963,  -7547],
                        [ -5487,  -7066],
                        [ -5014,  -6584],
                        [ -4544,  -6100],
                        [ -4088,  -5627],
                        [ -3643,  -5160],
                        [ -3219,  -4712],
                        [ -2814,  -4279],
                        [ -2433,  -3870],
                        [ -2078,  -3483],
                        [ -1749,  -3124],
                        [ -1448,  -2791],
                        [ -1172,  -2486],
                        [  -921,  -2208],
                        [  -693,  -1952],
                        [  -486,  -1721],
                        [  -295,  -1506],
                        [  -119,  -1309],
                        [    46,  -1125],
                        [   201,   -951],
                        [   351,   -783],
                        [   497,   -622],
                        [   644,   -463],
                        [   795,   -303],
                        [   954,   -137],
                        [  1120,     35],
                        [  1299,    220],
                        [  1493,    418],
                        [  1701,    631],
                        [  1926,    860],
                        [  2173,   1110],
                        [  2445,   1380],
                        [  2742,   1670],
                        [  3062,   1977],
                        [  3411,   2311],
                        [  3778,   2659],
                        [  4076,   2938],
                        [  4224,   3066],
                        [  4199,   3022],
                        [  3993,   2799],
                        [  3581,   2373],
                        [  2946,   1727],
                        [  2185,    960],
                        [  1441,    215],
                        [   756,   -466],
                        [   123,  -1088],
                        [  -447,  -1641],
                        [  -944,  -2117],
                        [ -1363,  -2511],
                        [ -1701,  -2823],
                        [ -1959,  -3053],
                        [ -2136,  -3199],
                        [ -2238,  -3267],
                        [ -2269,  -3260],
                        [ -2239,  -3182],
                        [ -2153,  -3039],
                        [ -2017,  -2836],
                        [ -1836,  -2583],
                        [ -1619,  -2286],
                        [ -1372,  -1953],
                        [ -1102,  -1603],
                        [  -816,  -1241],
                        [  -518,   -882],
                        [  -217,   -531],
                        [    84,   -193],
                        [   379,    128],
                        [   662,    441],
                        [   930,    739],
                        [  1180,   1030],
                        [  1407,   1308],
                        [  1612,   1571],
                        [  1791,   1816],
                        [  1944,   2042],
                        [  2069,   2247],
                        [  2169,   2429],
                        [  2243,   2589],
                        [  2290,   2723],
                        [  2312,   2829],
                        [  2311,   2910],
                        [  2286,   2967],
                        [  2241,   3001],
                        [  2178,   3016],
                        [  2102,   3013],
                        [  2013,   2994],
                        [  1919,   2963],
                        [  1821,   2923],
                        [  1723,   2877],
                        [  1626,   2826],
                        [  1534,   2774],
                        [  1450,   2723],
                        [  1376,   2677],
                        [  1315,   2639],
                        [  1270,   2607],
                        [  1242,   2586],
                        [  1238,   2575],
                        [  1262,   2574],
                        [  1320,   2585],
                        [  1412,   2608],
                        [  1534,   2644],
                        [  1687,   2693],
                        [  1853,   2754],
                        [  2035,   2828],
                        [  2217,   2915],
                        [  2400,   3013],
                        [  2581,   3121],
                        [  2758,   3236],
                        [  2929,   3359],
                        [  3096,   3490],
                        [  3256,   3625],
                        [  3408,   3764],
                        [  3584,   3936],
                        [  3780,   4138],
                        [  4026,   4398],
                        [  4318,   4713],
                        [  4646,   5072],
                        [  5008,   5471],
                        [  5344,   5848],
                        [  5654,   6204],
                        [  5904,   6503],
                        [  6094,   6744],
                        [  6229,   6930],
                        [  6306,   7059],
                        [  6333,   7136],
                        [  6309,   7160],
                        [  6239,   7135],
                        [  6122,   7061],
                        [  5965,   6944],
                        [  5767,   6781],
                        [  5539,   6584],
                        [  5276,   6349],
                        [  4990,   6085],
                        [  4677,   5790],
                        [  4349,   5475],
                        [  4002,   5137],
                        [  3647,   4785],
                        [  3280,   4419],
                        [  2907,   4043],
                        [  2529,   3657],
                        [  2147,   3265],
                        [  1761,   2867],
                        [  1376,   2463],
                        [   990,   2056],
                        [   609,   1648],
                        [   232,   1242],
                        [  -139,    839],
                        [  -503,    440],
                        [  -859,     50],
                        [ -1204,   -334],
                        [ -1537,   -710],
                        [ -1856,  -1075],
                        [ -2159,  -1432],
                        [ -2442,  -1775],
                        [ -2708,  -2106],
                        [ -2956,  -2422],
                        [ -3194,  -2727],
                        [ -3415,  -3012],
                        [ -3624,  -3279],
                        [ -3826,  -3534],
                        [ -4004,  -3761],
                        [ -4078,  -3880],
                        [ -3983,  -3824],
                        [ -3708,  -3586],
                        [ -3248,  -3158],
                        [ -2570,  -2509],
                        [ -1656,  -1621],
                        [  -594,   -582],
                        [   482,    472],
                        [  1532,   1504],
                        [  2559,   2513],
                        [  3545,   3484],
                        [  4470,   4398],
                        [  5325,   5249],
                        [  6104,   6026],
                        [  6797,   6726],
                        [  7399,   7339],
                        [  7906,   7863],
                        [  8322,   8295],
                        [  8647,   8634],
                        [  8881,   8881],
                        [  9026,   9034],
                        [  9084,   9099],
                        [  9059,   9076],
                        [  8954,   8977],
                        [  8774,   8803],
                        [  8524,   8574],
                        [  8209,   8292],
                        [  7834,   7966],
                        [  7405,   7601],
                        [  6928,   7195],
                        [  6408,   6754],
                        [  5852,   6266],
                        [  5267,   5738],
                        [  4656,   5172],
                        [  4026,   4573],
                        [  3384,   3946],
                        [  2734,   3297],
                        [  2082,   2628],
                        [  1430,   1944],
                        [   786,   1255],
                        [   152,    564],
                        [  -464,   -119],
                        [ -1060,   -789],
                        [ -1632,  -1441],
                        [ -2175,  -2071],
                        [ -2687,  -2675],
                        [ -3166,  -3250],
                        [ -3611,  -3794],
                        [ -4019,  -4303],
                        [ -4391,  -4776],
                        [ -4724,  -5211],
                        [ -5018,  -5605],
                        [ -5272,  -5956],
                        [ -5486,  -6264],
                        [ -5659,  -6529],
                        [ -5791,  -6749],
                        [ -5882,  -6925],
                        [ -5939,  -7055],
                        [ -5961,  -7140],
                        [ -5961,  -7181],
                        [ -5938,  -7178],
                        [ -5896,  -7131],
                        [ -5837,  -7041],
                        [ -5753,  -6911],
                        [ -5646,  -6741],
                        [ -5501,  -6534],
                        [ -5321,  -6292],
                        [ -5103,  -6017],
                        [ -4848,  -5710],
                        [ -4558,  -5375],
                        [ -4235,  -5013],
                        [ -3883,  -4628],
                        [ -3504,  -4223],
                        [ -3120,  -3818],
                        [ -2730,  -3413],
                        [ -2390,  -3063],
                        [ -2099,  -2766],
                        [ -1870,  -2535],
                        [ -1704,  -2373],
                        [ -1572,  -2247],
                        [ -1477,  -2160],
                        [ -1348,  -2042],
                        [ -1190,  -1896],
                        [  -997,  -1716],
                        [  -770,  -1503],
                        [  -515,  -1261],
                        [  -231,   -990],
                        [    74,   -697],
                        [   401,   -381],
                        [   742,    -50],
                        [  1098,    296],
                        [  1462,    651],
                        [  1834,   1015],
                        [  2208,   1381],
                        [  2587,   1752],
                        [  2961,   2120],
                        [  3335,   2486],
                        [  3700,   2846],
                        [  4061,   3200],
                        [  4414,   3546],
                        [  4764,   3885],
                        [  5107,   4217],
                        [  5449,   4544],
                        [  5789,   4869],
                        [  6129,   5190],
                        [  6470,   5512],
                        [  6813,   5835],
                        [  7158,   6159],
                        [  7508,   6485],
                        [  7862,   6814],
                        [  8222,   7146],
                        [  8587,   7485],
                        [  8958,   7829],
                        [  9330,   8184],
                        [  9704,   8547],
                        [ 10077,   8920],
                        [ 10447,   9300],
                        [ 10822,   9689],
                        [ 11197,  10085],
                        [ 11578,  10486],
                        [ 11962,  10888],
                        [ 12354,  11298],
                        [ 12735,  11695],
                        [ 13033,  12010],
                        [ 13202,  12195],
                        [ 13236,  12246],
                        [ 13123,  12153],
                        [ 12824,  11875],
                        [ 12309,  11385],
                        [ 11648,  10752],
                        [ 10950,  10085],
                        [ 10241,   9411],
                        [  9518,   8729],
                        [  8800,   8053],
                        [  8098,   7396],
                        [  7421,   6765],
                        [  6776,   6166],
                        [  6170,   5605],
                        [  5608,   5089],
                        [  5090,   4617],
                        [  4617,   4193],
                        [  4188,   3817],
                        [  3799,   3489],
                        [  3454,   3207],
                        [  3149,   2971],
                        [  2881,   2774],
                        [  2649,   2615],
                        [  2448,   2479],
                        [  2275,   2362],
                        [  2129,   2254],
                        [  2004,   2151],
                        [  1901,   2050],
                        [  1814,   1947],
                        [  1744,   1856],
                        [  1684,   1772],
                        [  1634,   1705],
                        [  1593,   1653],
                        [  1558,   1616],
                        [  1527,   1591],
                        [  1501,   1584],
                        [  1477,   1590],
                        [  1457,   1614],
                        [  1438,   1650],
                        [  1422,   1697],
                        [  1407,   1751],
                        [  1394,   1808],
                        [  1384,   1868],
                        [  1376,   1931],
                        [  1371,   1996],
                        [  1372,   2065],
                        [  1377,   2139],
                        [  1393,   2219],
                        [  1419,   2306],
                        [  1454,   2399],
                        [  1502,   2501],
                        [  1564,   2611],
                        [  1639,   2730],
                        [  1727,   2858],
                        [  1829,   2996],
                        [  1946,   3141],
                        [  2078,   3296],
                        [  2234,   3460],
                        [  2411,   3632],
                        [  2616,   3810],
                        [  2847,   3993],
                        [  3101,   4180],
                        [  3379,   4370],
                        [  3661,   4561],
                        [  3950,   4751],
                        [  4228,   4939],
                        [  4497,   5124],
                        [  4748,   5301],
                        [  4981,   5468],
                        [  5190,   5624],
                        [  5379,   5770],
                        [  5545,   5906],
                        [  5689,   6030],
                        [  5856,   6186],
                        [  6040,   6370],
                        [  6274,   6614],
                        [  6555,   6914],
                        [  6877,   7264],
                        [  7241,   7662],
                        [  7574,   8036],
                        [  7880,   8389],
                        [  8113,   8671],
                        [  8271,   8883],
                        [  8361,   9027],
                        [  8379,   9101],
                        [  8330,   9107],
                        [  8212,   9043],
                        [  8034,   8917],
                        [  7795,   8729],
                        [  7504,   8483],
                        [  7162,   8184],
                        [  6777,   7837],
                        [  6351,   7445],
                        [  5892,   7016],
                        [  5405,   6552],
                        [  4898,   6063],
                        [  4374,   5550],
                        [  3840,   5023],
                        [  3298,   4483],
                        [  2755,   3937],
                        [  2212,   3389],
                        [  1671,   2841],
                        [  1138,   2297],
                        [   612,   1760],
                        [    98,   1230],
                        [  -401,    714],
                        [  -882,    214],
                        [ -1344,   -267],
                        [ -1784,   -725],
                        [ -2202,  -1160],
                        [ -2594,  -1571],
                        [ -2955,  -1956],
                        [ -3285,  -2314],
                        [ -3578,  -2649],
                        [ -3833,  -2955],
                        [ -4051,  -3235],
                        [ -4234,  -3486],
                        [ -4390,  -3711],
                        [ -4516,  -3904],
                        [ -4619,  -4068],
                        [ -4705,  -4208],
                        [ -4757,  -4307],
                        [ -4725,  -4316],
                        [ -4589,  -4216],
                        [ -4353,  -4009],
                        [ -4009,  -3686],
                        [ -3517,  -3211],
                        [ -2844,  -2550],
                        [ -2042,  -1756],
                        [ -1198,   -914],
                        [  -334,    -50],
                        [   543,    833],
                        [  1415,   1714],
                        [  2263,   2575],
                        [  3075,   3406],
                        [  3839,   4195],
                        [  4546,   4931],
                        [  5185,   5603],
                        [  5751,   6206],
                        [  6242,   6732],
                        [  6652,   7179],
                        [  6982,   7542],
                        [  7229,   7820],
                        [  7395,   8012],
                        [  7481,   8120],
                        [  7490,   8152],
                        [  7423,   8110],
                        [  7287,   8008],
                        [  7084,   7851],
                        [  6821,   7648],
                        [  6502,   7402],
                        [  6134,   7116],
                        [  5722,   6796],
                        [  5272,   6429],
                        [  4791,   6024],
                        [  4284,   5580],
                        [  3760,   5107],
                        [  3225,   4604],
                        [  2684,   4076],
                        [  2144,   3526],
                        [  1611,   2960],
                        [  1090,   2386],
                        [   584,   1808],
                        [   102,   1241],
                        [  -355,    687],
                        [  -781,    160],
                        [ -1174,   -340],
                        [ -1530,   -807],
                        [ -1847,  -1239],
                        [ -2124,  -1633],
                        [ -2360,  -1987],
                        [ -2557,  -2301],
                        [ -2711,  -2571],
                        [ -2827,  -2797],
                        [ -2901,  -2979],
                        [ -2936,  -3117],
                        [ -2933,  -3212],
                        [ -2893,  -3263],
                        [ -2819,  -3272],
                        [ -2716,  -3242],
                        [ -2587,  -3172],
                        [ -2441,  -3065],
                        [ -2281,  -2923],
                        [ -2113,  -2748],
                        [ -1939,  -2542],
                        [ -1757,  -2308],
                        [ -1569,  -2048],
                        [ -1365,  -1766],
                        [ -1148,  -1464],
                        [  -912,  -1146],
                        [  -662,   -814],
                        [  -395,   -469],
                        [  -115,   -115],
                        [   173,    243],
                        [   470,    604],
                        [   748,    939],
                        [  1008,   1250],
                        [  1195,   1480],
                        [  1311,   1632],
                        [  1345,   1694],
                        [  1294,   1665],
                        [  1188,   1573],
                        [  1023,   1415],
                        [   883,   1276],
                        [   764,   1150],
                        [   675,   1051],
                        [   619,    977],
                        [   599,    936],
                        [   613,    925],
                        [   663,    946],
                        [   747,    997],
                        [   865,   1079],
                        [  1016,   1193],
                        [  1198,   1335],
                        [  1413,   1506],
                        [  1653,   1703],
                        [  1923,   1927],
                        [  2215,   2173],
                        [  2529,   2442],
                        [  2862,   2731],
                        [  3213,   3038],
                        [  3580,   3360],
                        [  3963,   3699],
                        [  4359,   4050],
                        [  4772,   4414],
                        [  5198,   4792],
                        [  5636,   5181],
                        [  6086,   5582],
                        [  6546,   5994],
                        [  7014,   6411],
                        [  7487,   6835],
                        [  7963,   7262],
                        [  8444,   7691],
                        [  8920,   8122],
                        [  9389,   8551],
                        [  9844,   8979],
                        [ 10281,   9403],
                        [ 10697,   9823],
                        [ 11087,  10236],
                        [ 11456,  10637],
                        [ 11802,  11027],
                        [ 12128,  11399],
                        [ 12432,  11750],
                        [ 12716,  12081],
                        [ 12966,  12376],
                        [ 13150,  12608],
                        [ 13268,  12772],
                        [ 13321,  12872],
                        [ 13297,  12893],
                        [ 13151,  12795],
                        [ 12841,  12532],
                        [ 12383,  12122],
                        [ 11834,  11621],
                        [ 11208,  11044],
                        [ 10508,  10394],
                        [  9752,   9686],
                        [  8955,   8936],
                        [  8126,   8152],
                        [  7274,   7344],
                        [  6415,   6524],
                        [  5554,   5701],
                        [  4701,   4883],
                        [  3863,   4076],
                        [  3042,   3288],
                        [  2244,   2524],
                        [  1476,   1788],
                        [   738,   1081],
                        [    34,    409],
                        [  -633,   -229],
                        [ -1261,   -840],
                        [ -1852,  -1422],
                        [ -2403,  -1981],
                        [ -2914,  -2516],
                        [ -3384,  -3028],
                        [ -3815,  -3521],
                        [ -4205,  -3980],
                        [ -4554,  -4409],
                        [ -4864,  -4795],
                        [ -5137,  -5143],
                        [ -5372,  -5446],
                        [ -5573,  -5708],
                        [ -5740,  -5918],
                        [ -5874,  -6081],
                        [ -5978,  -6193],
                        [ -6052,  -6256],
                        [ -6096,  -6279],
                        [ -6113,  -6260],
                        [ -6105,  -6212],
                        [ -6073,  -6134],
                        [ -6017,  -6032],
                        [ -5942,  -5908],
                        [ -5846,  -5761],
                        [ -5731,  -5593],
                        [ -5598,  -5407],
                        [ -5449,  -5205],
                        [ -5283,  -4986],
                        [ -5101,  -4753],
                        [ -4907,  -4509],
                        [ -4700,  -4255],
                        [ -4482,  -3993],
                        [ -4256,  -3724],
                        [ -4022,  -3450],
                        [ -3782,  -3174],
                        [ -3532,  -2898],
                        [ -3274,  -2624],
                        [ -3005,  -2355],
                        [ -2727,  -2091],
                        [ -2442,  -1838],
                        [ -2151,  -1594],
                        [ -1864,  -1364],
                        [ -1584,  -1151],
                        [ -1320,   -952],
                        [ -1076,   -773],
                        [  -859,   -615],
                        [  -670,   -482],
                        [  -509,   -372],
                        [  -379,   -285],
                        [  -275,   -218],
                        [  -197,   -171],
                        [  -101,    -95],
                        [    13,      4],
                        [   169,    153],
                        [   366,    349],
                        [   608,    597],
                        [   895,    897],
                        [  1159,   1180],
                        [  1407,   1451],
                        [  1593,   1663],
                        [  1718,   1818],
                        [  1781,   1914],
                        [  1783,   1952],
                        [  1726,   1929],
                        [  1607,   1847],
                        [  1433,   1708],
                        [  1204,   1513],
                        [   926,   1268],
                        [   601,    973],
                        [   236,    635],
                        [  -167,    258],
                        [  -599,   -152],
                        [ -1059,   -592],
                        [ -1534,  -1055],
                        [ -2026,  -1536],
                        [ -2523,  -2029],
                        [ -3025,  -2530],
                        [ -3526,  -3033],
                        [ -4024,  -3534],
                        [ -4515,  -4028],
                        [ -4998,  -4513],
                        [ -5467,  -4984],
                        [ -5920,  -5439],
                        [ -6354,  -5874],
                        [ -6767,  -6287],
                        [ -7157,  -6673],
                        [ -7521,  -7031],
                        [ -7858,  -7360],
                        [ -8164,  -7657],
                        [ -8433,  -7922],
                        [ -8665,  -8155],
                        [ -8852,  -8357],
                        [ -8994,  -8528],
                        [ -9097,  -8667],
                        [ -9157,  -8775],
                        [ -9185,  -8851],
                        [ -9180,  -8895],
                        [ -9154,  -8908],
                        [ -9107,  -8893],
                        [ -9033,  -8843],
                        [ -8935,  -8767],
                        [ -8837,  -8681],
                        [ -8743,  -8593],
                        [ -8646,  -8495],
                        [ -8508,  -8350],
                        [ -8278,  -8108],
                        [ -7946,  -7759],
                        [ -7542,  -7333],
                        [ -7079,  -6843],
                        [ -6565,  -6299],
                        [ -6016,  -5716],
                        [ -5445,  -5107],
                        [ -4864,  -4487],
                        [ -4284,  -3865],
                        [ -3716,  -3253],
                        [ -3173,  -2663],
                        [ -2661,  -2104],
                        [ -2185,  -1580],
                        [ -1753,  -1101],
                        [ -1367,   -671],
                        [ -1034,   -294],
                        [  -751,     26],
                        [  -522,    290],
                        [  -345,    501],
                        [  -222,    657],
                        [  -147,    770],
                        [  -120,    840],
                        [  -137,    873],
                        [  -196,    873],
                        [  -292,    843],
                        [  -422,    789],
                        [  -581,    701],
                        [  -766,    586],
                        [  -969,    444],
                        [ -1186,    280],
                        [ -1411,     89],
                        [ -1640,   -121],
                        [ -1867,   -354],
                        [ -2088,   -605],
                        [ -2300,   -867],
                        [ -2498,  -1137],
                        [ -2680,  -1402],
                        [ -2841,  -1659],
                        [ -2980,  -1898],
                        [ -3094,  -2114],
                        [ -3181,  -2307],
                        [ -3239,  -2472],
                        [ -3270,  -2608],
                        [ -3270,  -2716],
                        [ -3244,  -2793],
                        [ -3189,  -2840],
                        [ -3109,  -2857],
                        [ -3002,  -2843],
                        [ -2873,  -2800],
                        [ -2722,  -2729],
                        [ -2552,  -2633],
                        [ -2364,  -2511],
                        [ -2165,  -2367],
                        [ -1953,  -2202],
                        [ -1740,  -2019],
                        [ -1524,  -1821],
                        [ -1314,  -1608],
                        [ -1109,  -1384],
                        [  -914,  -1151],
                        [  -730,   -912],
                        [  -552,   -670],
                        [  -381,   -424],
                        [  -216,   -182],
                        [   -55,     60],
                        [   102,    299],
                        [   255,    531],
                        [   401,    754],
                        [   539,    966],
                        [   647,   1142],
                        [   723,   1281],
                        [   731,   1342],
                        [   672,   1329],
                        [   536,   1232],
                        [   324,   1049],
                        [    54,    799],
                        [  -274,    482],
                        [  -585,    171],
                        [  -884,   -135],
                        [ -1156,   -423],
                        [ -1400,   -691],
                        [ -1606,   -929],
                        [ -1773,  -1137],
                        [ -1896,  -1307],
                        [ -1976,  -1439],
                        [ -2009,  -1531],
                        [ -1996,  -1580],
                        [ -1934,  -1585],
                        [ -1825,  -1548],
                        [ -1670,  -1467],
                        [ -1469,  -1342],
                        [ -1228,  -1177],
                        [  -946,   -972],
                        [  -629,   -729],
                        [  -276,   -449],
                        [   105,   -139],
                        [   516,    204],
                        [   952,    572],
                        [  1412,    965],
                        [  1892,   1377],
                        [  2389,   1809],
                        [  2897,   2252],
                        [  3413,   2707],
                        [  3933,   3166],
                        [  4453,   3628],
                        [  4968,   4086],
                        [  5475,   4538],
                        [  5961,   4977],
                        [  6427,   5404],
                        [  6857,   5813],
                        [  7250,   6203],
                        [  7600,   6568],
                        [  7902,   6907],
                        [  8162,   7214],
                        [  8372,   7488],
                        [  8543,   7723],
                        [  8669,   7916],
                        [  8751,   8064],
                        [  8792,   8171],
                        [  8822,   8268],
                        [  8870,   8382],
                        [  8942,   8517],
                        [  9026,   8662],
                        [  9088,   8785],
                        [  9064,   8818],
                        [  8908,   8716],
                        [  8624,   8483],
                        [  8222,   8128],
                        [  7707,   7659],
                        [  7093,   7085],
                        [  6393,   6423],
                        [  5618,   5681],
                        [  4778,   4870],
                        [  3889,   4006],
                        [  2963,   3098],
                        [  2011,   2159],
                        [  1044,   1198],
                        [    73,    228],
                        [  -895,   -743],
                        [ -1849,  -1706],
                        [ -2784,  -2654],
                        [ -3691,  -3581],
                        [ -4565,  -4478],
                        [ -5401,  -5344],
                        [ -6194,  -6177],
                        [ -6940,  -6972],
                        [ -7638,  -7729],
                        [ -8283,  -8447],
                        [ -8873,  -9124],
                        [ -9406,  -9753],
                        [ -9880, -10335],
                        [-10297, -10862],
                        [-10656, -11333],
                        [-10959, -11742],
                        [-11208, -12092],
                        [-11403, -12374],
                        [-11548, -12587],
                        [-11645, -12733],
                        [-11694, -12811],
                        [-11698, -12828],
                        [-11662, -12786],
                        [-11587, -12700],
                        [-11475, -12572],
                        [-11332, -12407],
                        [-11159, -12209],
                        [-10961, -11980],
                        [-10740, -11726],
                        [-10500, -11451],
                        [-10244, -11155],
                        [ -9974, -10844],
                        [ -9694, -10522],
                        [ -9406, -10191],
                        [ -9113,  -9854],
                        [ -8818,  -9515],
                        [ -8524,  -9178],
                        [ -8232,  -8844],
                        [ -7945,  -8517],
                        [ -7665,  -8199],
                        [ -7392,  -7893],
                        [ -7129,  -7603],
                        [ -6875,  -7328],
                        [ -6631,  -7072],
                        [ -6397,  -6837],
                        [ -6173,  -6624],
                        [ -5962,  -6434],
                        [ -5770,  -6268],
                        [ -5596,  -6128],
                        [ -5446,  -6014],
                        [ -5323,  -5930],
                        [ -5224,  -5870],
                        [ -5149,  -5835],
                        [ -5093,  -5819],
                        [ -5057,  -5820],
                        [ -5006,  -5804],
                        [ -4939,  -5770],
                        [ -4844,  -5704],
                        [ -4720,  -5605],
                        [ -4552,  -5458],
                        [ -4340,  -5264],
                        [ -4128,  -5067],
                        [ -3913,  -4863],
                        [ -3729,  -4687],
                        [ -3575,  -4535],
                        [ -3455,  -4414],
                        [ -3366,  -4323],
                        [ -3316,  -4266],
                        [ -3300,  -4243],
                        [ -3319,  -4253],
                        [ -3374,  -4297],
                        [ -3463,  -4371],
                        [ -3582,  -4477],
                        [ -3729,  -4609],
                        [ -3904,  -4768],
                        [ -4100,  -4948],
                        [ -4315,  -5148],
                        [ -4544,  -5363],
                        [ -4784,  -5591],
                        [ -5032,  -5826],
                        [ -5285,  -6069],
                        [ -5536,  -6312],
                        [ -5788,  -6555],
                        [ -6037,  -6791],
                        [ -6281,  -7019],
                        [ -6515,  -7235],
                        [ -6741,  -7439],
                        [ -6953,  -7626],
                        [ -7151,  -7796],
                        [ -7333,  -7945],
                        [ -7499,  -8072],
                        [ -7642,  -8177],
                        [ -7766,  -8257],
                        [ -7860,  -8315],
                        [ -7925,  -8350],
                        [ -7956,  -8362],
                        [ -7954,  -8353],
                        [ -7922,  -8323],
                        [ -7859,  -8272],
                        [ -7776,  -8201],
                        [ -7672,  -8112],
                        [ -7555,  -8004],
                        [ -7425,  -7876],
                        [ -7303,  -7753],
                        [ -7248,  -7693],
                        [ -7300,  -7733],
                        [ -7467,  -7884],
                        [ -7740,  -8136],
                        [ -8094,  -8465],
                        [ -8453,  -8796],
                        [ -8739,  -9048],
                        [ -8935,  -9208],
                        [ -9049,  -9283],
                        [ -9085,  -9277],
                        [ -9050,  -9199],
                        [ -8950,  -9057],
                        [ -8795,  -8860],
                        [ -8590,  -8615],
                        [ -8347,  -8331],
                        [ -8075,  -8019],
                        [ -7781,  -7683],
                        [ -7473,  -7331],
                        [ -7157,  -6972],
                        [ -6836,  -6609],
                        [ -6516,  -6248],
                        [ -6201,  -5892],
                        [ -5896,  -5548],
                        [ -5599,  -5215],
                        [ -5315,  -4895],
                        [ -5042,  -4588],
                        [ -4782,  -4296],
                        [ -4536,  -4015],
                        [ -4302,  -3746],
                        [ -4081,  -3482],
                        [ -3872,  -3224],
                        [ -3673,  -2975],
                        [ -3483,  -2731],
                        [ -3300,  -2494],
                        [ -3122,  -2264],
                        [ -2946,  -2048],
                        [ -2769,  -1840],
                        [ -2590,  -1649],
                        [ -2408,  -1471],
                        [ -2221,  -1305],
                        [ -2030,  -1151],
                        [ -1831,   -999],
                        [ -1624,   -848],
                        [ -1411,   -691],
                        [ -1190,   -527],
                        [  -960,   -354],
                        [  -722,   -172],
                        [  -476,     18],
                        [  -222,    219],
                        [    37,    427],
                        [   304,    644],
                        [   573,    867],
                        [   844,   1096],
                        [  1116,   1329],
                        [  1386,   1567],
                        [  1652,   1804],
                        [  1913,   2042],
                        [  2168,   2277],
                        [  2414,   2508],
                        [  2651,   2734],
                        [  2878,   2953],
                        [  3091,   3164],
                        [  3289,   3365],
                        [  3465,   3553],
                        [  3619,   3729],
                        [  3749,   3891],
                        [  3854,   4038],
                        [  3937,   4170],
                        [  3999,   4288],
                        [  4045,   4391],
                        [  4071,   4478],
                        [  4081,   4547],
                        [  4075,   4599],
                        [  4038,   4617],
                        [  3973,   4604],
                        [  3867,   4543],
                        [  3720,   4435],
                        [  3525,   4273],
                        [  3282,   4055],
                        [  2992,   3785],
                        [  2659,   3461],
                        [  2328,   3132],
                        [  2000,   2797],
                        [  1689,   2471],
                        [  1396,   2153],
                        [  1134,   1860],
                        [   904,   1590],
                        [   713,   1354],
                        [   563,   1151],
                        [   459,    990],
                        [   402,    869],
                        [   392,    794],
                        [   432,    763],
                        [   518,    778],
                        [   653,    839],
                        [   831,    943],
                        [  1053,   1092],
                        [  1312,   1282],
                        [  1608,   1510],
                        [  1935,   1774],
                        [  2290,   2070],
                        [  2667,   2392],
                        [  3065,   2738],
                        [  3476,   3099],
                        [  3898,   3473],
                        [  4323,   3853],
                        [  4748,   4236],
                        [  5164,   4613],
                        [  5571,   4983],
                        [  5959,   5337],
                        [  6325,   5673],
                        [  6657,   5983],
                        [  6953,   6267],
                        [  7202,   6517],
                        [  7400,   6732],
                        [  7542,   6908],
                        [  7628,   7042],
                        [  7655,   7131],
                        [  7625,   7170],
                        [  7543,   7161],
                        [  7408,   7100],
                        [  7215,   6980],
                        [  7007,   6845],
                        [  6862,   6767],
                        [  6820,   6791],
                        [  6887,   6920],
                        [  7061,   7151],
                        [  7324,   7466],
                        [  7589,   7778],
                        [  7750,   7980],
                        [  7778,   8043],
                        [  7683,   7976],
                        [  7469,   7785],
                        [  7143,   7475],
                        [  6710,   7055],
                        [  6182,   6535],
                        [  5567,   5925],
                        [  4882,   5237],
                        [  4136,   4481],
                        [  3343,   3670],
                        [  2516,   2815],
                        [  1666,   1928],
                        [   803,   1021],
                        [   -65,    102],
                        [  -927,   -819],
                        [ -1773,  -1729],
                        [ -2597,  -2623],
                        [ -3391,  -3490],
                        [ -4149,  -4323],
                        [ -4866,  -5116],
                        [ -5538,  -5865],
                        [ -6160,  -6567],
                        [ -6728,  -7222],
                        [ -7240,  -7828],
                        [ -7694,  -8383],
                        [ -8088,  -8885],
                        [ -8425,  -9333],
                        [ -8704,  -9722],
                        [ -8927, -10051],
                        [ -9098, -10315],
                        [ -9215, -10514],
                        [ -9284, -10648],
                        [ -9305, -10719],
                        [ -9283, -10729],
                        [ -9219, -10684],
                        [ -9119, -10593],
                        [ -8984, -10461],
                        [ -8819, -10295],
                        [ -8628, -10098],
                        [ -8414,  -9875],
                        [ -8184,  -9630],
                        [ -7941,  -9368],
                        [ -7687,  -9093],
                        [ -7428,  -8808],
                        [ -7166,  -8517],
                        [ -6906,  -8226],
                        [ -6649,  -7935],
                        [ -6397,  -7649],
                        [ -6154,  -7371],
                        [ -5921,  -7104],
                        [ -5701,  -6849],
                        [ -5498,  -6608],
                        [ -5315,  -6384],
                        [ -5153,  -6178],
                        [ -5015,  -5992],
                        [ -4896,  -5826],
                        [ -4796,  -5679],
                        [ -4706,  -5554],
                        [ -4627,  -5450],
                        [ -4557,  -5367],
                        [ -4496,  -5302],
                        [ -4444,  -5259],
                        [ -4404,  -5236],
                        [ -4373,  -5228],
                        [ -4349,  -5236],
                        [ -4328,  -5252],
                        [ -4313,  -5276],
                        [ -4289,  -5296],
                        [ -4258,  -5310],
                        [ -4214,  -5312],
                        [ -4156,  -5303],
                        [ -4062,  -5255],
                        [ -3929,  -5170],
                        [ -3771,  -5056],
                        [ -3583,  -4912],
                        [ -3388,  -4756],
                        [ -3183,  -4587],
                        [ -2976,  -4413],
                        [ -2767,  -4231],
                        [ -2563,  -4050],
                        [ -2363,  -3870],
                        [ -2174,  -3694],
                        [ -1994,  -3524],
                        [ -1827,  -3362],
                        [ -1671,  -3207],
                        [ -1530,  -3062],
                        [ -1402,  -2927],
                        [ -1289,  -2802],
                        [ -1189,  -2685],
                        [ -1102,  -2579],
                        [ -1027,  -2481],
                        [  -963,  -2393],
                        [  -908,  -2312],
                        [  -863,  -2238],
                        [  -825,  -2170],
                        [  -792,  -2104],
                        [  -766,  -2041],
                        [  -743,  -1976],
                        [  -725,  -1911],
                        [  -708,  -1842],
                        [  -691,  -1769],
                        [  -674,  -1691],
                        [  -657,  -1609],
                        [  -633,  -1519],
                        [  -605,  -1423],
                        [  -566,  -1320],
                        [  -516,  -1210],
                        [  -450,  -1093],
                        [  -372,   -971],
                        [  -280,   -843],
                        [  -169,   -709],
                        [   -53,   -569],
                        [    69,   -427],
                        [   197,   -275],
                        [   332,   -119],
                        [   413,    -13],
                        [   350,    -49],
                        [   106,   -266],
                        [  -327,   -666],
                        [  -947,  -1255],
                        [ -1743,  -2017],
                        [ -2615,  -2856],
                        [ -3435,  -3638],
                        [ -4159,  -4324],
                        [ -4793,  -4920],
                        [ -5332,  -5422],
                        [ -5777,  -5831],
                        [ -6124,  -6146],
                        [ -6378,  -6372],
                        [ -6542,  -6509],
                        [ -6623,  -6566],
                        [ -6626,  -6545],
                        [ -6559,  -6453],
                        [ -6428,  -6294],
                        [ -6241,  -6075],
                        [ -6000,  -5801],
                        [ -5710,  -5478],
                        [ -5379,  -5111],
                        [ -5012,  -4708],
                        [ -4613,  -4274],
                        [ -4186,  -3813],
                        [ -3736,  -3335],
                        [ -3265,  -2843],
                        [ -2779,  -2339],
                        [ -2279,  -1828],
                        [ -1770,  -1304],
                        [ -1255,   -771],
                        [  -735,   -227],
                        [  -214,    328],
                        [   308,    888],
                        [   829,   1453],
                        [  1346,   2013],
                        [  1861,   2568],
                        [  2372,   3111],
                        [  2875,   3642],
                        [  3370,   4157],
                        [  3858,   4654],
                        [  4334,   5135],
                        [  4798,   5601],
                        [  5246,   6052],
                        [  5682,   6491],
                        [  6099,   6915],
                        [  6502,   7325],
                        [  6887,   7719],
                        [  7254,   8097],
                        [  7604,   8458],
                        [  7935,   8802],
                        [  8247,   9126],
                        [  8539,   9432],
                        [  8808,   9717],
                        [  9056,   9980],
                        [  9280,  10222],
                        [  9482,  10441],
                        [  9662,  10638],
                        [  9822,  10812],
                        [  9966,  10962],
                        [ 10097,  11089],
                        [ 10214,  11191],
                        [ 10316,  11271],
                        [ 10396,  11326],
                        [ 10455,  11360],
                        [ 10482,  11370],
                        [ 10480,  11359],
                        [ 10449,  11327],
                        [ 10393,  11277],
                        [ 10314,  11210],
                        [ 10212,  11126],
                        [ 10093,  11026],
                        [  9956,  10910],
                        [  9806,  10783],
                        [  9645,  10644],
                        [  9484,  10503],
                        [  9324,  10362],
                        [  9156,  10210],
                        [  8981,  10047],
                        [  8777,   9852],
                        [  8548,   9627],
                        [  8305,   9384],
                        [  8050,   9125],
                        [  7797,   8860],
                        [  7545,   8592],
                        [  7307,   8332],
                        [  7082,   8080],
                        [  6880,   7847],
                        [  6702,   7633],
                        [  6553,   7445],
                        [  6433,   7282],
                        [  6345,   7151],
                        [  6290,   7049],
                        [  6269,   6981],
                        [  6280,   6944],
                        [  6322,   6938],
                        [  6394,   6962],
                        [  6492,   7015],
                        [  6614,   7096],
                        [  6755,   7200],
                        [  6912,   7326],
                        [  7079,   7467],
                        [  7253,   7620],
                        [  7430,   7777],
                        [  7603,   7937],
                        [  7769,   8089],
                        [  7924,   8233],
                        [  8059,   8361],
                        [  8175,   8471],
                        [  8263,   8556],
                        [  8322,   8616],
                        [  8344,   8643],
                        [  8326,   8636],
                        [  8262,   8590],
                        [  8151,   8504],
                        [  7988,   8376],
                        [  7772,   8205],
                        [  7503,   7987],
                        [  7183,   7724],
                        [  6819,   7417],
                        [  6405,   7061],
                        [  5948,   6658],
                        [  5524,   6286],
                        [  5230,   6040],
                        [  5100,   5952],
                        [  5142,   6030],
                        [  5367,   6287],
                        [  5776,   6720],
                        [  6264,   7226],
                        [  6692,   7663],
                        [  7018,   7991],
                        [  7251,   8220],
                        [  7390,   8348],
                        [  7430,   8374],
                        [  7375,   8302],
                        [  7230,   8136],
                        [  7001,   7884],
                        [  6697,   7550],
                        [  6328,   7144],
                        [  5904,   6675],
                        [  5436,   6149],
                        [  4930,   5579],
                        [  4396,   4973],
                        [  3842,   4339],
                        [  3277,   3687],
                        [  2707,   3028],
                        [  2143,   2369],
                        [  1589,   1724],
                        [  1052,   1099],
                        [   537,    505],
                        [    48,    -53],
                        [  -410,   -574],
                        [  -834,  -1056],
                        [ -1220,  -1504],
                        [ -1569,  -1917],
                        [ -1877,  -2295],
                        [ -2144,  -2637],
                        [ -2373,  -2941],
                        [ -2563,  -3209],
                        [ -2716,  -3433],
                        [ -2832,  -3616],
                        [ -2915,  -3759],
                        [ -2967,  -3861],
                        [ -2989,  -3924],
                        [ -2984,  -3950],
                        [ -2954,  -3946],
                        [ -2901,  -3915],
                        [ -2829,  -3861],
                        [ -2741,  -3789],
                        [ -2639,  -3702],
                        [ -2528,  -3601],
                        [ -2412,  -3492],
                        [ -2294,  -3380],
                        [ -2178,  -3265],
                        [ -2064,  -3150],
                        [ -1956,  -3038],
                        [ -1855,  -2932],
                        [ -1762,  -2833],
                        [ -1678,  -2741],
                        [ -1605,  -2660],
                        [ -1544,  -2590],
                        [ -1502,  -2532],
                        [ -1480,  -2485],
                        [ -1484,  -2451],
                        [ -1514,  -2429],
                        [ -1562,  -2416],
                        [ -1629,  -2415],
                        [ -1699,  -2422],
                        [ -1771,  -2438],
                        [ -1835,  -2459],
                        [ -1890,  -2485],
                        [ -1935,  -2516],
                        [ -1971,  -2549],
                        [ -1996,  -2580],
                        [ -2006,  -2608],
                        [ -2006,  -2635],
                        [ -1994,  -2658],
                        [ -1987,  -2693],
                        [ -1983,  -2738],
                        [ -1988,  -2796],
                        [ -1999,  -2864],
                        [ -1985,  -2910],
                        [ -1948,  -2935],
                        [ -1860,  -2909],
                        [ -1722,  -2832],
                        [ -1543,  -2713],
                        [ -1320,  -2546],
                        [ -1065,  -2344],
                        [  -778,  -2104],
                        [  -469,  -1836],
                        [  -137,  -1540],
                        [   208,  -1225],
                        [   566,   -891],
                        [   926,   -547],
                        [  1292,   -191],
                        [  1653,    168],
                        [  2013,    531],
                        [  2360,    891],
                        [  2698,   1247],
                        [  3022,   1595],
                        [  3330,   1935],
                        [  3621,   2261],
                        [  3893,   2573],
                        [  4148,   2870],
                        [  4384,   3150],
                        [  4603,   3416],
                        [  4803,   3664],
                        [  4985,   3900],
                        [  5148,   4121],
                        [  5295,   4330],
                        [  5425,   4525],
                        [  5540,   4707],
                        [  5640,   4876],
                        [  5727,   5033],
                        [  5801,   5178],
                        [  5866,   5312],
                        [  5922,   5436],
                        [  5974,   5553],
                        [  6019,   5659],
                        [  6065,   5757],
                        [  6112,   5849],
                        [  6156,   5934],
                        [  6195,   6008],
                        [  6238,   6084],
                        [  6276,   6151],
                        [  6223,   6127],
                        [  5991,   5923],
                        [  5557,   5516],
                        [  4916,   4900],
                        [  4050,   4059],
                        [  2959,   2992],
                        [  1757,   1814],
                        [   589,    670],
                        [  -496,   -394],
                        [ -1506,  -1381],
                        [ -2424,  -2280],
                        [ -3242,  -3082],
                        [ -3953,  -3782],
                        [ -4555,  -4378],
                        [ -5048,  -4867],
                        [ -5432,  -5250],
                        [ -5714,  -5526],
                        [ -5896,  -5700],
                        [ -5982,  -5774],
                        [ -5980,  -5753],
                        [ -5890,  -5640],
                        [ -5718,  -5442],
                        [ -5472,  -5165],
                        [ -5158,  -4817],
                        [ -4782,  -4407],
                        [ -4350,  -3943],
                        [ -3868,  -3439],
                        [ -3344,  -2900],
                        [ -2782,  -2335],
                        [ -2190,  -1751],
                        [ -1573,  -1142],
                        [  -936,   -517],
                        [  -287,    130],
                        [   371,    794],
                        [  1033,   1471],
                        [  1692,   2157],
                        [  2348,   2845],
                        [  2995,   3530],
                        [  3629,   4206],
                        [  4247,   4871],
                        [  4844,   5517],
                        [  5420,   6143],
                        [  5971,   6744],
                        [  6494,   7316],
                        [  6984,   7859],
                        [  7443,   8373],
                        [  7867,   8854],
                        [  8256,   9303],
                        [  8609,   9718],
                        [  8929,  10097],
                        [  9214,  10442],
                        [  9466,  10752],
                        [  9683,  11026],
                        [  9869,  11266],
                        [ 10023,  11470],
                        [ 10143,  11639],
                        [ 10232,  11774],
                        [ 10291,  11876],
                        [ 10325,  11945],
                        [ 10337,  11984],
                        [ 10338,  11993],
                        [ 10330,  11975],
                        [ 10318,  11930],
                        [ 10301,  11860],
                        [ 10272,  11766],
                        [ 10234,  11651],
                        [ 10170,  11516],
                        [ 10083,  11363],
                        [  9973,  11196],
                        [  9842,  11016],
                        [  9693,  10825],
                        [  9528,  10626],
                        [  9351,  10420],
                        [  9163,  10211],
                        [  8990,  10021],
                        [  8833,   9851],
                        [  8717,   9727],
                        [  8646,   9651],
                        [  8606,   9609],
                        [  8600,   9605],
                        [  8581,   9589],
                        [  8550,   9564],
                        [  8490,   9510],
                        [  8401,   9427],
                        [  8292,   9323],
                        [  8162,   9198],
                        [  8019,   9061],
                        [  7864,   8909],
                        [  7703,   8750],
                        [  7535,   8583],
                        [  7367,   8416],
                        [  7196,   8245],
                        [  7029,   8078],
                        [  6862,   7911],
                        [  6702,   7749],
                        [  6543,   7590],
                        [  6390,   7434],
                        [  6239,   7281],
                        [  6091,   7133],
                        [  5944,   6986],
                        [  5794,   6840],
                        [  5640,   6694],
                        [  5477,   6544],
                        [  5304,   6389],
                        [  5117,   6221],
                        [  4915,   6041],
                        [  4693,   5842],
                        [  4451,   5623],
                        [  4186,   5381],
                        [  3896,   5116],
                        [  3579,   4824],
                        [  3235,   4505],
                        [  2864,   4157],
                        [  2464,   3780],
                        [  2035,   3370],
                        [  1578,   2932],
                        [  1089,   2463],
                        [   570,   1964],
                        [    17,   1435],
                        [  -563,    880],
                        [ -1164,    304],
                        [ -1793,   -301],
                        [ -2429,   -917],
                        [ -2984,  -1454],
                        [ -3374,  -1832],
                        [ -3578,  -2030],
                        [ -3587,  -2038],
                        [ -3373,  -1827],
                        [ -2921,  -1385],
                        [ -2335,   -816],
                        [ -1756,   -259],
                        [ -1218,    250],
                        [  -717,    719],
                        [  -261,   1137],
                        [   136,   1496],
                        [   473,   1794],
                        [   749,   2030],
                        [   963,   2204],
                        [  1118,   2314],
                        [  1217,   2364],
                        [  1268,   2357],
                        [  1272,   2296],
                        [  1234,   2186],
                        [  1158,   2033],
                        [  1047,   1840],
                        [   910,   1614],
                        [   748,   1363],
                        [   568,   1091],
                        [   374,    814],
                        [   170,    535],
                        [   -41,    267],
                        [  -252,     12],
                        [  -464,   -228],
                        [  -671,   -451],
                        [  -873,   -666],
                        [ -1068,   -871],
                        [ -1254,  -1074],
                        [ -1428,  -1271],
                        [ -1594,  -1463],
                        [ -1748,  -1649],
                        [ -1891,  -1830],
                        [ -2023,  -2004],
                        [ -2146,  -2171],
                        [ -2260,  -2333],
                        [ -2364,  -2485],
                        [ -2460,  -2630],
                        [ -2549,  -2765],
                        [ -2631,  -2893],
                        [ -2706,  -3012],
                        [ -2776,  -3129],
                        [ -2841,  -3240],
                        [ -2905,  -3348],
                        [ -2968,  -3456],
                        [ -3033,  -3564],
                        [ -3100,  -3672],
                        [ -3171,  -3781],
                        [ -3245,  -3893],
                        [ -3323,  -4006],
                        [ -3403,  -4121],
                        [ -3485,  -4237],
                        [ -3569,  -4355],
                        [ -3655,  -4474],
                        [ -3753,  -4591],
                        [ -3862,  -4709],
                        [ -3987,  -4824],
                        [ -4128,  -4935],
                        [ -4281,  -5041],
                        [ -4445,  -5140],
                        [ -4598,  -5229],
                        [ -4740,  -5308],
                        [ -4858,  -5376],
                        [ -4950,  -5429],
                        [ -5014,  -5467],
                        [ -5050,  -5487],
                        [ -5055,  -5488],
                        [ -5030,  -5471],
                        [ -4988,  -5445],
                        [ -4925,  -5409],
                        [ -4887,  -5404],
                        [ -4869,  -5428],
                        [ -4881,  -5485],
                        [ -4921,  -5578],
                        [ -4957,  -5670],
                        [ -4990,  -5761],
                        [ -4962,  -5793],
                        [ -4875,  -5767],
                        [ -4730,  -5681],
                        [ -4526,  -5535],
                        [ -4275,  -5336],
                        [ -3972,  -5083],
                        [ -3633,  -4786],
                        [ -3255,  -4446],
                        [ -2852,  -4075],
                        [ -2422,  -3670],
                        [ -1978,  -3245],
                        [ -1519,  -2798],
                        [ -1057,  -2341],
                        [  -592,  -1874],
                        [  -134,  -1406],
                        [   316,   -937],
                        [   750,   -478],
                        [  1168,    -27],
                        [  1563,    405],
                        [  1938,    821],
                        [  2289,   1213],
                        [  2615,   1582],
                        [  2917,   1926],
                        [  3192,   2245],
                        [  3442,   2540],
                        [  3664,   2810],
                        [  3862,   3055],
                        [  4033,   3275],
                        [  4180,   3472],
                        [  4302,   3643],
                        [  4401,   3791],
                        [  4474,   3914],
                        [  4523,   4016],
                        [  4549,   4097],
                        [  4557,   4162],
                        [  4546,   4207],
                        [  4527,   4239],
                        [  4501,   4257],
                        [  4468,   4262],
                        [  4427,   4251],
                        [  4389,   4240],
                        [  4335,   4206],
                        [  4183,   4073],
                        [  3872,   3777],
                        [  3397,   3314],
                        [  2750,   2676],
                        [  1897,   1831],
                        [   828,    768],
                        [  -360,   -416],
                        [ -1537,  -1589],
                        [ -2667,  -2718],
                        [ -3751,  -3801],
                        [ -4770,  -4823],
                        [ -5709,  -5770],
                        [ -6559,  -6631],
                        [ -7313,  -7400],
                        [ -7969,  -8072],
                        [ -8521,  -8642],
                        [ -8972,  -9106],
                        [ -9323,  -9465],
                        [ -9575,  -9718],
                        [ -9728,  -9868],
                        [ -9787,  -9916],
                        [ -9755,  -9866],
                        [ -9637,  -9726],
                        [ -9440,  -9500],
                        [ -9167,  -9199],
                        [ -8829,  -8831],
                        [ -8429,  -8413],
                        [ -7975,  -7950],
                        [ -7474,  -7454],
                        [ -6934,  -6931],
                        [ -6360,  -6381],
                        [ -5760,  -5809],
                        [ -5142,  -5212],
                        [ -4510,  -4596],
                        [ -3872,  -3960],
                        [ -3233,  -3312],
                        [ -2599,  -2657],
                        [ -1975,  -2000],
                        [ -1367,  -1345],
                        [  -777,   -695],
                        [  -209,    -57],
                        [   332,    564],
                        [   843,   1158],
                        [  1321,   1724],
                        [  1762,   2256],
                        [  2166,   2750],
                        [  2531,   3206],
                        [  2855,   3623],
                        [  3140,   3999],
                        [  3387,   4335],
                        [  3596,   4630],
                        [  3770,   4884],
                        [  3911,   5098],
                        [  4017,   5275],
                        [  4092,   5413],
                        [  4136,   5514],
                        [  4151,   5583],
                        [  4138,   5617],
                        [  4106,   5620],
                        [  4058,   5595],
                        [  4008,   5544],
                        [  3959,   5468],
                        [  3914,   5371],
                        [  3876,   5255],
                        [  3841,   5121],
                        [  3810,   4973],
                        [  3762,   4812],
                        [  3702,   4640],
                        [  3627,   4460],
                        [  3538,   4273],
                        [  3436,   4080],
                        [  3324,   3887],
                        [  3206,   3696],
                        [  3083,   3508],
                        [  2997,   3367],
                        [  2945,   3270],
                        [  2963,   3249],
                        [  3049,   3305],
                        [  3192,   3428],
                        [  3395,   3617],
                        [  3588,   3806],
                        [  3776,   3995],
                        [  3916,   4144],
                        [  4011,   4253],
                        [  4063,   4325],
                        [  4071,   4357],
                        [  4039,   4352],
                        [  3964,   4308],
                        [  3852,   4229],
                        [  3701,   4113],
                        [  3517,   3966],
                        [  3296,   3785],
                        [  3046,   3577],
                        [  2764,   3336],
                        [  2456,   3070],
                        [  2121,   2777],
                        [  1764,   2460],
                        [  1385,   2118],
                        [   984,   1755],
                        [   563,   1371],
                        [   121,    968],
                        [  -340,    546],
                        [  -825,    106],
                        [ -1329,   -353],
                        [ -1854,   -831],
                        [ -2399,  -1328],
                        [ -2962,  -1845],
                        [ -3544,  -2382],
                        [ -4142,  -2938],
                        [ -4756,  -3511],
                        [ -5381,  -4099],
                        [ -6017,  -4701],
                        [ -6657,  -5315],
                        [ -7297,  -5939],
                        [ -7937,  -6572],
                        [ -8573,  -7211],
                        [ -9206,  -7854],
                        [ -9838,  -8501],
                        [-10468,  -9148],
                        [-11092,  -9788],
                        [-11707, -10420],
                        [-12313, -11045],
                        [-12887, -11640],
                        [-13356, -12133],
                        [-13673, -12478],
                        [-13833, -12668],
                        [-13821, -12692],
                        [-13600, -12509],
                        [-13142, -12093],
                        [-12526, -11523],
                        [-11858, -10905],
                        [-11162, -10261],
                        [-10441,  -9592],
                        [ -9710,  -8913],
                        [ -8986,  -8240],
                        [ -8275,  -7579],
                        [ -7587,  -6936],
                        [ -6928,  -6322],
                        [ -6302,  -5741],
                        [ -5712,  -5198],
                        [ -5159,  -4695],
                        [ -4647,  -4236],
                        [ -4177,  -3823],
                        [ -3751,  -3455],
                        [ -3367,  -3133],
                        [ -3027,  -2855],
                        [ -2728,  -2619],
                        [ -2469,  -2420],
                        [ -2250,  -2251],
                        [ -2067,  -2108],
                        [ -1920,  -1982],
                        [ -1806,  -1870],
                        [ -1723,  -1770],
                        [ -1670,  -1683],
                        [ -1644,  -1616],
                        [ -1643,  -1568],
                        [ -1665,  -1550],
                        [ -1709,  -1558],
                        [ -1771,  -1593],
                        [ -1853,  -1654],
                        [ -1949,  -1744],
                        [ -2061,  -1861],
                        [ -2186,  -2005],
                        [ -2322,  -2175],
                        [ -2468,  -2365],
                        [ -2624,  -2573],
                        [ -2785,  -2792],
                        [ -2953,  -3020],
                        [ -3122,  -3253],
                        [ -3293,  -3491],
                        [ -3464,  -3730],
                        [ -3635,  -3972],
                        [ -3805,  -4214],
                        [ -3974,  -4456],
                        [ -4141,  -4695],
                        [ -4305,  -4930],
                        [ -4465,  -5160],
                        [ -4618,  -5384],
                        [ -4763,  -5597],
                        [ -4899,  -5802],
                        [ -5024,  -5995],
                        [ -5137,  -6173],
                        [ -5250,  -6338],
                        [ -5360,  -6486],
                        [ -5471,  -6615],
                        [ -5584,  -6726],
                        [ -5697,  -6814],
                        [ -5809,  -6881],
                        [ -5903,  -6923],
                        [ -5978,  -6940],
                        [ -6020,  -6932],
                        [ -6029,  -6897],
                        [ -6001,  -6831],
                        [ -5939,  -6737],
                        [ -5840,  -6616],
                        [ -5708,  -6470],
                        [ -5563,  -6317],
                        [ -5405,  -6159],
                        [ -5288,  -6049],
                        [ -5210,  -5984],
                        [ -5183,  -5974],
                        [ -5205,  -6021],
                        [ -5247,  -6090],
                        [ -5311,  -6186],
                        [ -5319,  -6227],
                        [ -5279,  -6221],
                        [ -5182,  -6161],
                        [ -5031,  -6047],
                        [ -4832,  -5881],
                        [ -4584,  -5666],
                        [ -4296,  -5406],
                        [ -3968,  -5104],
                        [ -3611,  -4769],
                        [ -3224,  -4401],
                        [ -2818,  -4009],
                        [ -2394,  -3594],
                        [ -1962,  -3166],
                        [ -1523,  -2726],
                        [ -1087,  -2283],
                        [  -655,  -1839],
                        [  -235,  -1400],
                        [   171,   -969],
                        [   560,   -555],
                        [   930,   -155],
                        [  1278,    222],
                        [  1606,    578],
                        [  1912,    908],
                        [  2194,   1213],
                        [  2452,   1493],
                        [  2686,   1747],
                        [  2897,   1976],
                        [  3082,   2180],
                        [  3244,   2358],
                        [  3382,   2511],
                        [  3492,   2639],
                        [  3575,   2741],
                        [  3629,   2821],
                        [  3655,   2880],
                        [  3660,   2921],
                        [  3641,   2943],
                        [  3613,   2952],
                        [  3575,   2949],
                        [  3531,   2932],
                        [  3482,   2901],
                        [  3435,   2869],
                        [  3369,   2811],
                        [  3235,   2683],
                        [  3015,   2464],
                        [  2711,   2159],
                        [  2313,   1756],
                        [  1781,   1218],
                        [  1084,    512],
                        [   280,   -303],
                        [  -548,  -1141],
                        [ -1379,  -1984],
                        [ -2208,  -2826],
                        [ -3015,  -3651],
                        [ -3787,  -4441],
                        [ -4513,  -5188],
                        [ -5186,  -5884],
                        [ -5796,  -6517],
                        [ -6337,  -7082],
                        [ -6810,  -7572],
                        [ -7209,  -7984],
                        [ -7535,  -8318],
                        [ -7785,  -8571],
                        [ -7963,  -8744],
                        [ -8068,  -8838],
                        [ -8104,  -8857],
                        [ -8074,  -8805],
                        [ -7983,  -8692],
                        [ -7835,  -8522],
                        [ -7638,  -8311],
                        [ -7394,  -8063],
                        [ -7110,  -7790],
                        [ -6793,  -7497],
                        [ -6448,  -7185],
                        [ -6081,  -6860],
                        [ -5697,  -6515],
                        [ -5304,  -6156],
                        [ -4904,  -5783],
                        [ -4505,  -5398],
                        [ -4109,  -5005],
                        [ -3722,  -4609],
                        [ -3348,  -4205],
                        [ -2988,  -3800],
                        [ -2647,  -3397],
                        [ -2328,  -3001],
                        [ -2031,  -2619],
                        [ -1760,  -2256],
                        [ -1516,  -1919],
                        [ -1299,  -1609],
                        [ -1110,  -1328],
                        [  -950,  -1077],
                        [  -817,   -856],
                        [  -709,   -663],
                        [  -625,   -499],
                        [  -563,   -363],
                        [  -521,   -253],
                        [  -497,   -167],
                        [  -490,   -104],
                        [  -497,    -63],
                        [  -518,    -41],
                        [  -549,    -36],
                        [  -584,    -46],
                        [  -621,    -70],
                        [  -647,   -104],
                        [  -661,   -146],
                        [  -658,   -197],
                        [  -637,   -252],
                        [  -601,   -310],
                        [  -548,   -371],
                        [  -495,   -433],
                        [  -440,   -494],
                        [  -388,   -555],
                        [  -342,   -617],
                        [  -301,   -676],
                        [  -265,   -731],
                        [  -228,   -777],
                        [  -191,   -814],
                        [  -106,   -792],
                        [    24,   -715],
                        [   224,   -556],
                        [   495,   -314],
                        [   831,      2],
                        [  1233,    396],
                        [  1623,    789],
                        [  2004,   1185],
                        [  2329,   1532],
                        [  2598,   1834],
                        [  2808,   2085],
                        [  2958,   2283],
                        [  3045,   2425],
                        [  3068,   2507],
                        [  3028,   2533],
                        [  2924,   2499],
                        [  2760,   2407],
                        [  2535,   2257],
                        [  2252,   2052],
                        [  1913,   1792],
                        [  1525,   1482],
                        [  1086,   1120],
                        [   605,    713],
                        [    82,    260],
                        [  -476,   -232],
                        [ -1069,   -761],
                        [ -1693,  -1323],
                        [ -2346,  -1914],
                        [ -3023,  -2530],
                        [ -3725,  -3170],
                        [ -4443,  -3829],
                        [ -5176,  -4504],
                        [ -5919,  -5191],
                        [ -6670,  -5889],
                        [ -7421,  -6593],
                        [ -8171,  -7297],
                        [ -8911,  -7999],
                        [ -9635,  -8693],
                        [-10334,  -9374],
                        [-11003, -10040],
                        [-11639, -10687],
                        [-12238, -11311],
                        [-12802, -11909],
                        [-13328, -12479],
                        [-13823, -13019],
                        [-14280, -13520],
                        [-14697, -13981],
                        [-15074, -14402],
                        [-15394, -14766],
                        [-15628, -15043],
                        [-15773, -15234],
                        [-15833, -15339],
                        [-15794, -15346],
                        [-15615, -15211],
                        [-15251, -14893],
                        [-14731, -14418],
                        [-14113, -13843],
                        [-13410, -13183],
                        [-12630, -12443],
                        [-11790, -11641],
                        [-10909, -10794],
                        [ -9998,  -9913],
                        [ -9069,  -9009],
                        [ -8136,  -8095],
                        [ -7206,  -7183],
                        [ -6290,  -6282],
                        [ -5394,  -5402],
                        [ -4526,  -4548],
                        [ -3694,  -3731],
                        [ -2901,  -2952],
                        [ -2154,  -2218],
                        [ -1455,  -1532],
                        [  -808,   -896],
                        [  -215,   -310],
                        [   325,    231],
                        [   808,    725],
                        [  1237,   1180],
                        [  1611,   1597],
                        [  1931,   1975],
                        [  2199,   2317],
                        [  2416,   2616],
                        [  2585,   2874],
                        [  2709,   3081],
                        [  2789,   3240],
                        [  2830,   3349],
                        [  2833,   3413],
                        [  2802,   3423],
                        [  2740,   3385],
                        [  2650,   3298],
                        [  2536,   3164],
                        [  2400,   2992],
                        [  2247,   2786],
                        [  2082,   2557],
                        [  1905,   2308],
                        [  1721,   2049],
                        [  1533,   1783],
                        [  1346,   1512],
                        [  1160,   1240],
                        [   980,    970],
                        [   806,    705],
                        [   641,    449],
                        [   486,    203],
                        [   345,    -28],
                        [   219,   -244],
                        [   110,   -440],
                        [    20,   -617],
                        [   -52,   -771],
                        [  -103,   -901],
                        [  -141,  -1005],
                        [  -165,  -1084],
                        [  -178,  -1135],
                        [  -180,  -1157],
                        [  -174,  -1151],
                        [  -160,  -1116],
                        [  -128,  -1052],
                        [   -80,   -960],
                        [    -5,   -839],
                        [    96,   -690],
                        [   227,   -511],
                        [   384,   -306],
                        [   566,    -80],
                        [   771,    169],
                        [   972,    410],
                        [  1168,    644],
                        [  1311,    819],
                        [  1403,    940],
                        [  1429,    991],
                        [  1389,    973],
                        [  1309,    910],
                        [  1183,    798],
                        [  1090,    715],
                        [  1022,    653],
                        [   989,    625],
                        [   988,    626],
                        [  1024,    661],
                        [  1093,    730],
                        [  1193,    827],
                        [  1324,    956],
                        [  1480,   1109],
                        [  1663,   1289],
                        [  1866,   1488],
                        [  2087,   1707],
                        [  2322,   1939],
                        [  2568,   2184],
                        [  2818,   2435],
                        [  3072,   2693],
                        [  3323,   2951],
                        [  3572,   3208],
                        [  3813,   3459],
                        [  4049,   3703],
                        [  4275,   3937],
                        [  4493,   4158],
                        [  4700,   4366],
                        [  4899,   4560],
                        [  5084,   4738],
                        [  5259,   4901],
                        [  5419,   5049],
                        [  5569,   5181],
                        [  5703,   5297],
                        [  5823,   5397],
                        [  5922,   5480],
                        [  5999,   5545],
                        [  6052,   5597],
                        [  6082,   5632],
                        [  6093,   5656],
                        [  6084,   5666],
                        [  6068,   5670],
                        [  6045,   5663],
                        [  6019,   5649],
                        [  5991,   5625],
                        [  5961,   5596],
                        [  5923,   5554],
                        [  5881,   5505],
                        [  5852,   5465],
                        [  5841,   5441],
                        [  5835,   5420],
                        [  5794,   5363],
                        [  5666,   5218],
                        [  5443,   4978],
                        [  5156,   4674],
                        [  4815,   4315],
                        [  4425,   3909],
                        [  4001,   3469],
                        [  3556,   3006],
                        [  3097,   2531],
                        [  2634,   2052],
                        [  2178,   1580],
                        [  1738,   1123],
                        [  1315,    687],
                        [   916,    279],
                        [   545,    -98],
                        [   208,   -438],
                        [   -97,   -741],
                        [  -364,  -1003],
                        [  -595,  -1225],
                        [  -789,  -1407],
                        [  -947,  -1554],
                        [ -1069,  -1666],
                        [ -1160,  -1753],
                        [ -1219,  -1818],
                        [ -1250,  -1865],
                        [ -1255,  -1899],
                        [ -1239,  -1921],
                        [ -1204,  -1935],
                        [ -1153,  -1934],
                        [ -1090,  -1923],
                        [ -1017,  -1897],
                        [  -938,  -1859],
                        [  -852,  -1806],
                        [  -765,  -1741],
                        [  -678,  -1658],
                        [  -593,  -1558],
                        [  -509,  -1445],
                        [  -431,  -1320],
                        [  -358,  -1189],
                        [  -289,  -1055],
                        [  -228,   -927],
                        [  -174,   -807],
                        [  -126,   -696],
                        [   -85,   -592],
                        [   -50,   -498],
                        [   -20,   -413],
                        [     7,   -334],
                        [    28,   -265],
                        [    50,   -200],
                        [    72,   -141],
                        [    93,    -87],
                        [   116,    -36],
                        [   141,     13],
                        [   170,     60],
                        [   206,    108],
                        [   251,    156],
                        [   310,    206],
                        [   382,    258],
                        [   470,    312],
                        [   576,    371],
                        [   700,    432],
                        [   840,    496],
                        [   989,    565],
                        [  1144,    635],
                        [  1300,    708],
                        [  1452,    778],
                        [  1600,    848],
                        [  1745,    921],
                        [  1889,    999],
                        [  2030,   1082],
                        [  2210,   1214],
                        [  2425,   1389],
                        [  2690,   1625],
                        [  3005,   1919],
                        [  3371,   2277],
                        [  3789,   2697],
                        [  4193,   3113],
                        [  4585,   3529],
                        [  4922,   3899],
                        [  5207,   4226],
                        [  5428,   4500],
                        [  5588,   4719],
                        [  5679,   4877],
                        [  5701,   4973],
                        [  5653,   5004],
                        [  5536,   4969],
                        [  5348,   4868],
                        [  5091,   4700],
                        [  4771,   4470],
                        [  4386,   4177],
                        [  3946,   3826],
                        [  3448,   3417],
                        [  2906,   2959],
                        [  2317,   2450],
                        [  1692,   1900],
                        [  1032,   1309],
                        [   345,    688],
                        [  -367,     37],
                        [ -1096,   -633],
                        [ -1840,  -1321],
                        [ -2589,  -2017],
                        [ -3341,  -2719],
                        [ -4087,  -3419],
                        [ -4823,  -4113],
                        [ -5540,  -4793],
                        [ -6237,  -5457],
                        [ -6899,  -6095],
                        [ -7524,  -6706],
                        [ -8097,  -7279],
                        [ -8617,  -7815],
                        [ -9080,  -8306],
                        [ -9481,  -8751],
                        [ -9824,  -9147],
                        [-10106,  -9491],
                        [-10335,  -9780],
                        [-10508, -10012],
                        [-10623, -10186],
                        [-10676, -10295],
                        [-10679, -10350],
                        [-10659, -10378],
                        [-10646, -10411],
                        [-10646, -10453],
                        [-10648, -10493],
                        [-10618, -10498],
                        [-10493, -10405],
                        [-10232, -10172],
                        [ -9847,  -9809],
                        [ -9346,  -9328],
                        [ -8739,  -8735],
                        [ -8041,  -8048],
                        [ -7266,  -7280],
                        [ -6426,  -6442],
                        [ -5537,  -5549],
                        [ -4614,  -4616],
                        [ -3668,  -3655],
                        [ -2710,  -2676],
                        [ -1752,  -1695],
                        [  -804,   -718],
                        [   127,    241],
                        [  1029,   1177],
                        [  1896,   2079],
                        [  2724,   2942],
                        [  3505,   3761],
                        [  4235,   4531],
                        [  4911,   5253],
                        [  5531,   5922],
                        [  6091,   6542],
                        [  6594,   7112],
                        [  7039,   7632],
                        [  7425,   8104],
                        [  7757,   8526],
                        [  8035,   8899],
                        [  8262,   9217],
                        [  8440,   9483],
                        [  8573,   9696],
                        [  8663,   9858],
                        [  8715,   9964],
                        [  8732,  10017],
                        [  8718,  10017],
                        [  8678,   9968],
                        [  8615,   9876],
                        [  8533,   9745],
                        [  8437,   9590],
                        [  8330,   9414],
                        [  8216,   9228],
                        [  8099,   9035],
                        [  7983,   8839],
                        [  7871,   8644],
                        [  7765,   8455],
                        [  7670,   8274],
                        [  7586,   8105],
                        [  7516,   7950],
                        [  7462,   7812],
                        [  7425,   7694],
                        [  7406,   7595],
                        [  7406,   7520],
                        [  7425,   7467],
                        [  7464,   7438],
                        [  7519,   7434],
                        [  7591,   7455],
                        [  7677,   7498],
                        [  7777,   7566],
                        [  7885,   7655],
                        [  7999,   7768],
                        [  8120,   7900],
                        [  8245,   8050],
                        [  8378,   8218],
                        [  8518,   8403],
                        [  8667,   8601],
                        [  8821,   8812],
                        [  8978,   9029],
                        [  9136,   9250],
                        [  9271,   9450],
                        [  9382,   9627],
                        [  9440,   9752],
                        [  9443,   9821],
                        [  9380,   9821],
                        [  9250,   9752],
                        [  9062,   9622],
                        [  8814,   9430],
                        [  8567,   9232],
                        [  8314,   9025],
                        [  8067,   8820],
                        [  7826,   8613],
                        [  7599,   8417],
                        [  7384,   8228],
                        [  7187,   8052],
                        [  7008,   7888],
                        [  6847,   7737],
                        [  6706,   7603],
                        [  6585,   7483],
                        [  6481,   7378],
                        [  6397,   7289],
                        [  6331,   7213],
                        [  6280,   7151],
                        [  6244,   7102],
                        [  6221,   7064],
                        [  6210,   7036],
                        [  6210,   7018],
                        [  6221,   7009],
                        [  6242,   7006],
                        [  6272,   7010],
                        [  6310,   7018],
                        [  6356,   7031],
                        [  6408,   7045],
                        [  6467,   7061],
                        [  6528,   7078],
                        [  6592,   7094],
                        [  6655,   7109],
                        [  6717,   7122],
                        [  6769,   7132],
                        [  6810,   7139],
                        [  6836,   7139],
                        [  6849,   7135],
                        [  6847,   7127],
                        [  6832,   7113],
                        [  6813,   7096],
                        [  6788,   7074],
                        [  6762,   7047],
                        [  6731,   7013],
                        [  6693,   6969],
                        [  6673,   6941],
                        [  6726,   6983],
                        [  6887,   7131],
                        [  7159,   7387],
                        [  7534,   7746],
                        [  7978,   8172],
                        [  8413,   8591],
                        [  8764,   8924],
                        [  9015,   9159],
                        [  9172,   9300],
                        [  9240,   9353],
                        [  9223,   9323],
                        [  9129,   9219],
                        [  8967,   9047],
                        [  8744,   8816],
                        [  8470,   8531],
                        [  8154,   8204],
                        [  7803,   7840],
                        [  7422,   7446],
                        [  7019,   7029],
                        [  6600,   6596],
                        [  6170,   6151],
                        [  5733,   5701],
                        [  5295,   5249],
                        [  4860,   4800],
                        [  4432,   4355],
                        [  4012,   3918],
                        [  3604,   3488],
                        [  3210,   3067],
                        [  2831,   2656],
                        [  2467,   2255],
                        [  2119,   1860],
                        [  1788,   1473],
                        [  1471,   1097],
                        [  1172,    732],
                        [   890,    384],
                        [   623,     50],
                        [   375,   -260],
                        [   142,   -549],
                        [   -72,   -807],
                        [  -271,  -1034],
                        [  -452,  -1231],
                        [  -618,  -1397],
                        [  -766,  -1536],
                        [  -898,  -1649],
                        [ -1013,  -1745],
                        [ -1113,  -1825],
                        [ -1195,  -1889],
                        [ -1261,  -1939],
                        [ -1311,  -1974],
                        [ -1347,  -1995],
                        [ -1367,  -2002],
                        [ -1374,  -1996],
                        [ -1365,  -1978],
                        [ -1342,  -1949],
                        [ -1307,  -1908],
                        [ -1257,  -1854],
                        [ -1194,  -1790],
                        [ -1120,  -1715],
                        [ -1034,  -1631],
                        [  -938,  -1538],
                        [  -835,  -1437],
                        [  -726,  -1328],
                        [  -608,  -1214],
                        [  -485,  -1094],
                        [  -351,   -971],
                        [  -209,   -846],
                        [   -61,   -720],
                        [    94,   -593],
                        [   246,   -472],
                        [   395,   -358],
                        [   537,   -249],
                        [   674,   -145],
                        [   805,    -45],
                        [   929,     51],
                        [  1067,    165],
                        [  1216,    293],
                        [  1380,    444],
                        [  1558,    614],
                        [  1766,    821],
                        [  2001,   1061],
                        [  2227,   1299],
                        [  2446,   1539],
                        [  2628,   1748],
                        [  2775,   1929],
                        [  2875,   2071],
                        [  2932,   2175],
                        [  2935,   2231],
                        [  2886,   2240],
                        [  2781,   2197],
                        [  2621,   2104],
                        [  2406,   1958],
                        [  2138,   1760],
                        [  1819,   1513],
                        [  1451,   1217],
                        [  1040,    877],
                        [   588,    494],
                        [   102,     74],
                        [  -415,   -379],
                        [  -956,   -860],
                        [ -1516,  -1367],
                        [ -2088,  -1889],
                        [ -2669,  -2426],
                        [ -3251,  -2968],
                        [ -3830,  -3512],
                        [ -4399,  -4048],
                        [ -4953,  -4573],
                        [ -5484,  -5077],
                        [ -5990,  -5560],
                        [ -6462,  -6012],
                        [ -6897,  -6430],
                        [ -7282,  -6808],
                        [ -7619,  -7144],
                        [ -7894,  -7430],
                        [ -8107,  -7665],
                        [ -8256,  -7846],
                        [ -8337,  -7971],
                        [ -8356,  -8040],
                        [ -8309,  -8049],
                        [ -8208,  -8001],
                        [ -8051,  -7895],
                        [ -7838,  -7729],
                        [ -7567,  -7502],
                        [ -7287,  -7260],
                        [ -7074,  -7078],
                        [ -6967,  -6997],
                        [ -6974,  -7023],
                        [ -7094,  -7156],
                        [ -7305,  -7375],
                        [ -7520,  -7591],
                        [ -7637,  -7703],
                        [ -7633,  -7690],
                        [ -7518,  -7562],
                        [ -7296,  -7324],
                        [ -6975,  -6983],
                        [ -6564,  -6551],
                        [ -6074,  -6035],
                        [ -5518,  -5449],
                        [ -4906,  -4800],
                        [ -4252,  -4103],
                        [ -3566,  -3367],
                        [ -2857,  -2604],
                        [ -2136,  -1824],
                        [ -1411,  -1037],
                        [  -689,   -249],
                        [    19,    527],
                        [   709,   1285],
                        [  1372,   2020],
                        [  2004,   2724],
                        [  2602,   3393],
                        [  3160,   4022],
                        [  3678,   4609],
                        [  4153,   5150],
                        [  4586,   5650],
                        [  4976,   6106],
                        [  5326,   6524],
                        [  5636,   6903],
                        [  5908,   7244],
                        [  6143,   7548],
                        [  6344,   7814],
                        [  6514,   8043],
                        [  6654,   8229],
                        [  6768,   8378],
                        [  6860,   8486],
                        [  6932,   8558],
                        [  6988,   8599],
                        [  7032,   8608],
                        [  7066,   8600],
                        [  7092,   8576],
                        [  7112,   8544],
                        [  7131,   8509],
                        [  7150,   8471],
                        [  7171,   8435],
                        [  7198,   8405],
                        [  7232,   8381],
                        [  7274,   8367],
                        [  7326,   8364],
                        [  7388,   8372],
                        [  7460,   8394],
                        [  7541,   8429],
                        [  7633,   8477],
                        [  7733,   8538],
                        [  7842,   8613],
                        [  7962,   8698],
                        [  8091,   8794],
                        [  8228,   8898],
                        [  8375,   9011],
                        [  8522,   9128],
                        [  8668,   9250],
                        [  8803,   9373],
                        [  8925,   9495],
                        [  9030,   9613],
                        [  9120,   9728],
                        [  9192,   9837],
                        [  9245,   9935],
                        [  9275,  10020],
                        [  9283,  10089],
                        [  9258,  10130],
                        [  9198,  10143],
                        [  9102,  10121],
                        [  8966,  10061],
                        [  8779,   9951],
                        [  8541,   9788],
                        [  8242,   9562],
                        [  7881,   9271],
                        [  7489,   8945],
                        [  7065,   8582],
                        [  6620,   8192],
                        [  6156,   7777],
                        [  5687,   7350],
                        [  5211,   6908],
                        [  4738,   6462],
                        [  4270,   6013],
                        [  3815,   5571],
                        [  3373,   5132],
                        [  2949,   4707],
                        [  2547,   4294],
                        [  2168,   3898],
                        [  1813,   3521],
                        [  1484,   3164],
                        [  1184,   2828],
                        [   910,   2516],
                        [   665,   2229],
                        [   448,   1965],
                        [   258,   1727],
                        [    95,   1515],
                        [   -41,   1327],
                        [  -152,   1163],
                        [  -239,   1021],
                        [  -305,    898],
                        [  -349,    795],
                        [  -375,    706],
                        [  -385,    634],
                        [  -384,    573],
                        [  -372,    524],
                        [  -360,    483],
                        [  -347,    449],
                        [  -339,    420],
                        [  -335,    395],
                        [  -340,    371],
                        [  -353,    346],
                        [  -371,    319],
                        [  -396,    289],
                        [  -422,    257],
                        [  -458,    215],
                        [  -505,    163],
                        [  -498,    163],
                        [  -353,    297],
                        [   -36,    605],
                        [   454,   1082],
                        [  1120,   1735],
                        [  1943,   2544],
                        [  2819,   3404],
                        [  3617,   4188],
                        [  4304,   4859],
                        [  4882,   5424],
                        [  5350,   5881],
                        [  5704,   6227],
                        [  5948,   6466],
                        [  6087,   6599],
                        [  6126,   6632],
                        [  6076,   6571],
                        [  5940,   6420],
                        [  5727,   6189],
                        [  5445,   5883],
                        [  5100,   5508],
                        [  4700,   5074],
                        [  4251,   4588],
                        [  3761,   4057],
                        [  3239,   3489],
                        [  2690,   2891],
                        [  2124,   2272],
                        [  1544,   1637],
                        [   959,    997],
                        [   371,    358],
                        [  -212,   -278],
                        [  -789,   -904],
                        [ -1354,  -1522],
                        [ -1906,  -2130],
                        [ -2442,  -2728],
                        [ -2958,  -3314],
                        [ -3450,  -3883],
                        [ -3918,  -4432],
                        [ -4358,  -4955],
                        [ -4770,  -5448],
                        [ -5152,  -5904],
                        [ -5503,  -6324],
                        [ -5822,  -6702],
                        [ -6109,  -7039],
                        [ -6364,  -7334],
                        [ -6587,  -7590],
                        [ -6776,  -7811],
                        [ -6933,  -7997],
                        [ -7057,  -8150],
                        [ -7150,  -8270],
                        [ -7213,  -8361],
                        [ -7248,  -8421],
                        [ -7257,  -8452],
                        [ -7240,  -8458],
                        [ -7200,  -8438],
                        [ -7138,  -8394],
                        [ -7057,  -8329],
                        [ -6957,  -8244],
                        [ -6841,  -8140],
                        [ -6711,  -8019],
                        [ -6573,  -7885],
                        [ -6429,  -7738],
                        [ -6287,  -7582],
                        [ -6150,  -7419],
                        [ -6019,  -7249],
                        [ -5896,  -7078],
                        [ -5775,  -6904],
                        [ -5658,  -6732],
                        [ -5539,  -6565],
                        [ -5419,  -6402],
                        [ -5302,  -6248],
                        [ -5190,  -6107],
                        [ -5084,  -5975],
                        [ -4985,  -5857],
                        [ -4896,  -5753],
                        [ -4818,  -5662],
                        [ -4759,  -5593],
                        [ -4718,  -5545],
                        [ -4698,  -5519],
                        [ -4700,  -5514],
                        [ -4697,  -5506],
                        [ -4692,  -5496],
                        [ -4681,  -5477],
                        [ -4662,  -5450],
                        [ -4650,  -5429],
                        [ -4643,  -5410],
                        [ -4652,  -5404],
                        [ -4674,  -5410],
                        [ -4717,  -5434],
                        [ -4780,  -5475],
                        [ -4868,  -5540],
                        [ -4977,  -5626],
                        [ -5111,  -5735],
                        [ -5269,  -5867],
                        [ -5450,  -6021],
                        [ -5651,  -6196],
                        [ -5871,  -6390],
                        [ -6106,  -6601],
                        [ -6355,  -6824],
                        [ -6612,  -7058],
                        [ -6874,  -7300],
                        [ -7138,  -7544],
                        [ -7397,  -7789],
                        [ -7650,  -8032],
                        [ -7889,  -8265],
                        [ -8112,  -8487],
                        [ -8313,  -8691],
                        [ -8491,  -8873],
                        [ -8639,  -9026],
                        [ -8756,  -9150],
                        [ -8836,  -9237],
                        [ -8878,  -9288],
                        [ -8877,  -9297],
                        [ -8830,  -9264],
                        [ -8734,  -9186],
                        [ -8587,  -9063],
                        [ -8388,  -8894],
                        [ -8138,  -8678],
                        [ -7839,  -8416],
                        [ -7492,  -8108],
                        [ -7105,  -7757],
                        [ -6681,  -7367],
                        [ -6218,  -6931],
                        [ -5722,  -6460],
                        [ -5279,  -6034],
                        [ -4980,  -5744],
                        [ -4860,  -5627],
                        [ -4925,  -5687],
                        [ -5189,  -5939],
                        [ -5648,  -6377],
                        [ -6188,  -6893],
                        [ -6674,  -7349],
                        [ -7070,  -7711],
                        [ -7385,  -7990],
                        [ -7614,  -8182],
                        [ -7755,  -8286],
                        [ -7812,  -8305],
                        [ -7789,  -8243],
                        [ -7695,  -8106],
                        [ -7534,  -7899],
                        [ -7317,  -7628],
                        [ -7048,  -7300],
                        [ -6735,  -6923],
                        [ -6384,  -6504],
                        [ -6000,  -6049],
                        [ -5592,  -5567],
                        [ -5164,  -5064],
                        [ -4724,  -4548],
                        [ -4276,  -4023],
                        [ -3828,  -3497],
                        [ -3380,  -2979],
                        [ -2940,  -2475],
                        [ -2508,  -1991],
                        [ -2087,  -1531],
                        [ -1679,  -1092],
                        [ -1285,   -678],
                        [  -904,   -279],
                        [  -537,    106],
                        [  -184,    479],
                        [   154,    841],
                        [   479,   1190],
                        [   790,   1527],
                        [  1087,   1846],
                        [  1373,   2149],
                        [  1648,   2435],
                        [  1913,   2706],
                        [  2170,   2959],
                        [  2420,   3196],
                        [  2661,   3423],
                        [  2897,   3641],
                        [  3125,   3850],
                        [  3347,   4054],
                        [  3564,   4253],
                        [  3776,   4449],
                        [  3983,   4643],
                        [  4188,   4835],
                        [  4388,   5026],
                        [  4583,   5215],
                        [  4774,   5403],
                        [  4960,   5588],
                        [  5139,   5770],
                        [  5311,   5948],
                        [  5473,   6119],
                        [  5627,   6283],
                        [  5777,   6438],
                        [  5922,   6584],
                        [  6065,   6716],
                        [  6205,   6836],
                        [  6334,   6938],
                        [  6452,   7023],
                        [  6544,   7088],
                        [  6607,   7132],
                        [  6635,   7152],
                        [  6626,   7148],
                        [  6580,   7119],
                        [  6495,   7062],
                        [  6372,   6977],
                        [  6211,   6862],
                        [  6024,   6728],
                        [  5810,   6575],
                        [  5589,   6419],
                        [  5359,   6257],
                        [  5110,   6078],
                        [  4842,   5881],
                        [  4522,   5631],
                        [  4151,   5329],
                        [  3731,   4974],
                        [  3262,   4566],
                        [  2758,   4119],
                        [  2220,   3630],
                        [  1662,   3116],
                        [  1084,   2573],
                        [   501,   2017],
                        [   -87,   1450],
                        [  -669,    879],
                        [ -1242,    309],
                        [ -1799,   -252],
                        [ -2338,   -803],
                        [ -2849,  -1335],
                        [ -3335,  -1848],
                        [ -3788,  -2334],
                        [ -4207,  -2795],
                        [ -4591,  -3226],
                        [ -4937,  -3626],
                        [ -5246,  -3991],
                        [ -5520,  -4323],
                        [ -5758,  -4617],
                        [ -5961,  -4877],
                        [ -6132,  -5102],
                        [ -6270,  -5293],
                        [ -6380,  -5455],
                        [ -6461,  -5589],
                        [ -6519,  -5700],
                        [ -6554,  -5787],
                        [ -6572,  -5857],
                        [ -6573,  -5908],
                        [ -6564,  -5945],
                        [ -6547,  -5970],
                        [ -6528,  -5987],
                        [ -6507,  -5996],
                        [ -6492,  -6002],
                        [ -6484,  -6006],
                        [ -6484,  -6014],
                        [ -6490,  -6024],
                        [ -6502,  -6038],
                        [ -6530,  -6064],
                        [ -6563,  -6095],
                        [ -6513,  -6044],
                        [ -6295,  -5827],
                        [ -5888,  -5422],
                        [ -5290,  -4827],
                        [ -4480,  -4023],
                        [ -3464,  -3014],
                        [ -2358,  -1918],
                        [ -1311,   -882],
                        [  -357,     62],
                        [   505,    913],
                        [  1263,   1665],
                        [  1912,   2308],
                        [  2447,   2841],
                        [  2875,   3262],
                        [  3192,   3573],
                        [  3408,   3772],
                        [  3525,   3868],
                        [  3549,   3862],
                        [  3485,   3760],
                        [  3339,   3569],
                        [  3119,   3296],
                        [  2832,   2949],
                        [  2485,   2535],
                        [  2087,   2065],
                        [  1645,   1544],
                        [  1170,    987],
                        [   667,    400],
                        [   145,   -199],
                        [  -388,   -802],
                        [  -930,  -1402],
                        [ -1471,  -1991],
                        [ -2006,  -2570],
                        [ -2533,  -3135],
                        [ -3045,  -3695],
                        [ -3540,  -4245],
                        [ -4011,  -4778],
                        [ -4457,  -5295],
                        [ -4874,  -5787],
                        [ -5261,  -6251],
                        [ -5615,  -6685],
                        [ -5935,  -7085],
                        [ -6220,  -7449],
                        [ -6470,  -7776],
                        [ -6685,  -8062],
                        [ -6865,  -8308],
                        [ -7009,  -8516],
                        [ -7120,  -8687],
                        [ -7197,  -8822],
                        [ -7243,  -8922],
                        [ -7260,  -8991],
                        [ -7249,  -9030],
                        [ -7216,  -9042],
                        [ -7162,  -9028],
                        [ -7091,  -8993],
                        [ -7005,  -8938],
                        [ -6907,  -8868],
                        [ -6800,  -8783],
                        [ -6687,  -8687],
                        [ -6570,  -8583],
                        [ -6458,  -8473],
                        [ -6353,  -8358],
                        [ -6267,  -8243],
                        [ -6202,  -8129],
                        [ -6160,  -8019],
                        [ -6146,  -7915],
                        [ -6147,  -7818],
                        [ -6169,  -7729],
                        [ -6195,  -7652],
                        [ -6228,  -7586],
                        [ -6264,  -7533],
                        [ -6304,  -7492],
                        [ -6349,  -7465],
                        [ -6398,  -7453],
                        [ -6461,  -7463],
                        [ -6536,  -7494],
                        [ -6654,  -7577],
                        [ -6815,  -7711],
                        [ -7022,  -7900],
                        [ -7276,  -8142],
                        [ -7540,  -8400],
                        [ -7815,  -8676],
                        [ -8058,  -8922],
                        [ -8266,  -9141],
                        [ -8444,  -9331],
                        [ -8586,  -9490],
                        [ -8702,  -9623],
                        [ -8787,  -9728],
                        [ -8849,  -9811],
                        [ -8886,  -9868],
                        [ -8903,  -9906],
                        [ -8898,  -9923],
                        [ -8877,  -9923],
                        [ -8835,  -9903],
                        [ -8780,  -9868],
                        [ -8707,  -9813],
                        [ -8620,  -9744],
                        [ -8517,  -9657],
                        [ -8401,  -9553],
                        [ -8270,  -9432],
                        [ -8122,  -9293],
                        [ -7956,  -9135],
                        [ -7771,  -8959],
                        [ -7564,  -8765],
                        [ -7336,  -8552],
                        [ -7085,  -8318],
                        [ -6810,  -8063],
                        [ -6511,  -7785],
                        [ -6186,  -7480],
                        [ -5836,  -7149],
                        [ -5462,  -6790],
                        [ -5064,  -6404],
                        [ -4642,  -5991],
                        [ -4198,  -5553],
                        [ -3733,  -5090],
                        [ -3247,  -4604],
                        [ -2737,  -4095],
                        [ -2207,  -3569],
                        [ -1656,  -3022],
                        [ -1088,  -2459],
                        [  -509,  -1885],
                        [    76,  -1302],
                        [   671,   -706],
                        [  1256,   -116],
                        [  1736,    375],
                        [  2034,    687],
                        [  2130,    804],
                        [  2015,    717],
                        [  1661,    396],
                        [  1061,   -166],
                        [   328,   -857],
                        [  -399,  -1539],
                        [ -1086,  -2182],
                        [ -1740,  -2791],
                        [ -2345,  -3353],
                        [ -2892,  -3860],
                        [ -3377,  -4307],
                        [ -3798,  -4691],
                        [ -4157,  -5010],
                        [ -4450,  -5262],
                        [ -4682,  -5446],
                        [ -4853,  -5566],
                        [ -4963,  -5623],
                        [ -5016,  -5618],
                        [ -5014,  -5555],
                        [ -4959,  -5437],
                        [ -4856,  -5270],
                        [ -4708,  -5057],
                        [ -4520,  -4803],
                        [ -4297,  -4513],
                        [ -4039,  -4200],
                        [ -3753,  -3868],
                        [ -3441,  -3527],
                        [ -3107,  -3183],
                        [ -2753,  -2835],
                        [ -2381,  -2487],
                        [ -1995,  -2126],
                        [ -1595,  -1753],
                        [ -1185,  -1365],
                        [  -766,   -960],
                        [  -342,   -545],
                        [    87,   -118],
                        [   517,    317],
                        [   947,    758],
                        [  1376,   1203],
                        [  1802,   1653],
                        [  2224,   2100],
                        [  2640,   2543],
                        [  3046,   2980],
                        [  3443,   3410],
                        [  3827,   3829],
                        [  4197,   4236],
                        [  4552,   4629],
                        [  4890,   5009],
                        [  5208,   5373],
                        [  5509,   5722],
                        [  5787,   6052],
                        [  6046,   6364],
                        [  6281,   6656],
                        [  6493,   6926],
                        [  6678,   7171],
                        [  6837,   7394],
                        [  6971,   7588],
                        [  7079,   7755],
                        [  7168,   7892],
                        [  7238,   7999],
                        [  7295,   8074],
                        [  7339,   8116],
                        [  7365,   8125],
                        [  7373,   8101],
                        [  7347,   8041],
                        [  7290,   7946],
                        [  7187,   7816],
                        [  7041,   7651],
                        [  6852,   7449],
                        [  6619,   7214],
                        [  6346,   6948],
                        [  6035,   6651],
                        [  5722,   6359],
                        [  5406,   6071],
                        [  5120,   5817],
                        [  4862,   5597],
                        [  4626,   5400],
                        [  4412,   5228],
                        [  4165,   5025],
                        [  3889,   4795],
                        [  3560,   4509],
                        [  3181,   4173],
                        [  2763,   3795],
                        [  2308,   3376],
                        [  1826,   2926],
                        [  1318,   2446],
                        [   798,   1948],
                        [   266,   1432],
                        [  -267,    911],
                        [  -799,    384],
                        [ -1320,   -137],
                        [ -1830,   -652],
                        [ -2319,  -1152],
                        [ -2788,  -1638],
                        [ -3226,  -2101],
                        [ -3637,  -2543],
                        [ -4015,  -2957],
                        [ -4360,  -3342],
                        [ -4672,  -3696],
                        [ -4951,  -4019],
                        [ -5201,  -4306],
                        [ -5419,  -4561],
                        [ -5610,  -4783],
                        [ -5774,  -4973],
                        [ -5913,  -5136],
                        [ -6027,  -5272],
                        [ -6121,  -5385],
                        [ -6196,  -5480],
                        [ -6253,  -5557],
                        [ -6294,  -5618],
                        [ -6319,  -5666],
                        [ -6333,  -5704],
                        [ -6342,  -5735],
                        [ -6346,  -5757],
                        [ -6356,  -5778],
                        [ -6371,  -5796],
                        [ -6395,  -5819],
                        [ -6426,  -5844],
                        [ -6463,  -5871],
                        [ -6518,  -5913],
                        [ -6565,  -5946],
                        [ -6520,  -5888],
                        [ -6325,  -5683],
                        [ -5974,  -5321],
                        [ -5454,  -4795],
                        [ -4734,  -4073],
                        [ -3804,  -3144],
                        [ -2767,  -2111],
                        [ -1752,  -1101],
                        [  -784,   -140],
                        [   134,    773],
                        [   990,   1623],
                        [  1770,   2397],
                        [  2470,   3091],
                        [  3088,   3699],
                        [  3620,   4217],
                        [  4068,   4643],
                        [  4433,   4978],
                        [  4717,   5223],
                        [  4921,   5380],
                        [  5049,   5453],
                        [  5106,   5445],
                        [  5095,   5364],
                        [  5025,   5215],
                        [  4900,   5004],
                        [  4728,   4741],
                        [  4515,   4436],
                        [  4269,   4097],
                        [  3995,   3744],
                        [  3699,   3382],
                        [  3390,   3021],
                        [  3070,   2667],
                        [  2747,   2321],
                        [  2424,   1986],
                        [  2105,   1649],
                        [  1795,   1318],
                        [  1497,    991],
                        [  1214,    673],
                        [   950,    367],
                        [   705,     75],
                        [   482,   -205],
                        [   281,   -469],
                        [   102,   -716],
                        [   -52,   -944],
                        [  -184,  -1149],
                        [  -293,  -1331],
                        [  -380,  -1488],
                        [  -446,  -1619],
                        [  -492,  -1727],
                        [  -518,  -1810],
                        [  -529,  -1874],
                        [  -525,  -1918],
                        [  -509,  -1948],
                        [  -484,  -1962],
                        [  -454,  -1966],
                        [  -419,  -1961],
                        [  -384,  -1949],
                        [  -349,  -1934],
                        [  -319,  -1917],
                        [  -293,  -1899],
                        [  -282,  -1883],
                        [  -286,  -1871],
                        [  -316,  -1864],
                        [  -374,  -1864],
                        [  -462,  -1871],
                        [  -583,  -1888],
                        [  -726,  -1914],
                        [  -894,  -1949],
                        [ -1067,  -1995],
                        [ -1247,  -2049],
                        [ -1424,  -2110],
                        [ -1599,  -2180],
                        [ -1770,  -2257],
                        [ -1936,  -2342],
                        [ -2115,  -2450],
                        [ -2303,  -2580],
                        [ -2548,  -2778],
                        [ -2845,  -3040],
                        [ -3200,  -3372],
                        [ -3611,  -3772],
                        [ -4037,  -4197],
                        [ -4479,  -4648],
                        [ -4864,  -5051],
                        [ -5194,  -5407],
                        [ -5461,  -5708],
                        [ -5663,  -5951],
                        [ -5804,  -6137],
                        [ -5879,  -6262],
                        [ -5896,  -6332],
                        [ -5850,  -6342],
                        [ -5751,  -6299],
                        [ -5593,  -6200],
                        [ -5387,  -6052],
                        [ -5129,  -5852],
                        [ -4826,  -5606],
                        [ -4479,  -5315],
                        [ -4097,  -4981],
                        [ -3677,  -4607],
                        [ -3227,  -4197],
                        [ -2746,  -3752],
                        [ -2240,  -3276],
                        [ -1709,  -2771],
                        [ -1154,  -2242],
                        [  -575,  -1689],
                        [    22,  -1118],
                        [   637,   -531],
                        [  1266,     72],
                        [  1908,    687],
                        [  2559,   1314],
                        [  3218,   1951],
                        [  3876,   2596],
                        [  4535,   3246],
                        [  5185,   3899],
                        [  5824,   4551],
                        [  6451,   5198],
                        [  7063,   5839],
                        [  7665,   6470],
                        [  8251,   7087],
                        [  8827,   7690],
                        [  9388,   8275],
                        [  9929,   8841],
                        [ 10446,   9381],
                        [ 10944,   9904],
                        [ 11395,  10380],
                        [ 11726,  10737],
                        [ 11894,  10935],
                        [ 11898,  10970],
                        [ 11724,  10828],
                        [ 11332,  10472],
                        [ 10703,   9882],
                        [  9926,   9143],
                        [  9109,   8364],
                        [  8275,   7564],
                        [  7425,   6746],
                        [  6581,   5930],
                        [  5757,   5129],
                        [  4962,   4353],
                        [  4206,   3612],
                        [  3492,   2916],
                        [  2830,   2272],
                        [  2224,   1686],
                        [  1676,   1160],
                        [  1194,    702],
                        [   777,    310],
                        [   427,    -11],
                        [   145,   -263],
                        [   -71,   -446],
                        [  -220,   -562],
                        [  -306,   -614],
                        [  -331,   -605],
                        [  -296,   -547],
                        [  -206,   -444],
                        [   -63,   -308],
                        [   126,   -141],
                        [   360,     54],
                        [   634,    270],
                        [   943,    520],
                        [  1285,    800],
                        [  1654,   1115],
                        [  2048,   1463],
                        [  2460,   1840],
                        [  2888,   2243],
                        [  3328,   2672],
                        [  3774,   3122],
                        [  4224,   3593],
                        [  4673,   4080],
                        [  5117,   4575],
                        [  5554,   5075],
                        [  5978,   5569],
                        [  6388,   6056],
                        [  6778,   6526],
                        [  7146,   6977],
                        [  7488,   7406],
                        [  7802,   7811],
                        [  8087,   8188],
                        [  8340,   8536],
                        [  8558,   8851],
                        [  8743,   9135],
                        [  8890,   9382],
                        [  9003,   9594],
                        [  9079,   9768],
                        [  9116,   9902],
                        [  9118,   9996],
                        [  9085,  10051],
                        [  9024,  10064],
                        [  8939,  10037],
                        [  8836,   9970],
                        [  8717,   9863],
                        [  8578,   9717],
                        [  8426,   9533],
                        [  8245,   9313],
                        [  8040,   9057],
                        [  7797,   8768],
                        [  7517,   8443],
                        [  7204,   8088],
                        [  6859,   7706],
                        [  6490,   7305],
                        [  6097,   6886],
                        [  5733,   6500],
                        [  5397,   6147],
                        [  5122,   5861],
                        [  4909,   5642],
                        [  4756,   5486],
                        [  4663,   5395],
                        [  4560,   5298],
                        [  4453,   5199],
                        [  4305,   5061],
                        [  4116,   4887],
                        [  3894,   4680],
                        [  3640,   4442],
                        [  3358,   4176],
                        [  3050,   3884],
                        [  2724,   3573],
                        [  2378,   3241],
                        [  2024,   2900],
                        [  1659,   2546],
                        [  1293,   2190],
                        [   925,   1831],
                        [   563,   1475],
                        [   207,   1122],
                        [  -134,    779],
                        [  -463,    444],
                        [  -774,    124],
                        [ -1070,   -183],
                        [ -1349,   -473],
                        [ -1612,   -746],
                        [ -1861,   -999],
                        [ -2095,  -1235],
                        [ -2316,  -1450],
                        [ -2524,  -1648],
                        [ -2719,  -1829],
                        [ -2903,  -1995],
                        [ -3075,  -2148],
                        [ -3238,  -2292],
                        [ -3385,  -2427],
                        [ -3517,  -2552],
                        [ -3635,  -2670],
                        [ -3739,  -2781],
                        [ -3837,  -2887],
                        [ -3927,  -2986],
                        [ -4019,  -3083],
                        [ -4115,  -3178],
                        [ -4215,  -3272],
                        [ -4318,  -3364],
                        [ -4422,  -3455],
                        [ -4533,  -3551],
                        [ -4626,  -3629],
                        [ -4650,  -3637],
                        [ -4583,  -3557],
                        [ -4427,  -3391],
                        [ -4167,  -3125],
                        [ -3762,  -2716],
                        [ -3181,  -2135],
                        [ -2486,  -1446],
                        [ -1763,   -730],
                        [ -1024,      1],
                        [  -272,    742],
                        [   475,   1476],
                        [  1203,   2192],
                        [  1905,   2880],
                        [  2577,   3534],
                        [  3210,   4145],
                        [  3801,   4708],
                        [  4345,   5217],
                        [  4843,   5672],
                        [  5289,   6070],
                        [  5683,   6411],
                        [  6027,   6694],
                        [  6322,   6923],
                        [  6568,   7098],
                        [  6769,   7223],
                        [  6927,   7303],
                        [  7046,   7345],
                        [  7128,   7355],
                        [  7178,   7346],
                        [  7200,   7323],
                        [  7196,   7294],
                        [  7172,   7262],
                        [  7131,   7227],
                        [  7077,   7195],
                        [  7010,   7148],
                        [  6936,   7093],
                        [  6853,   7027],
                        [  6767,   6953],
                        [  6676,   6867],
                        [  6584,   6773],
                        [  6490,   6666],
                        [  6398,   6546],
                        [  6304,   6415],
                        [  6212,   6271],
                        [  6119,   6124],
                        [  6026,   5972],
                        [  5934,   5822],
                        [  5841,   5674],
                        [  5748,   5529],
                        [  5653,   5387],
                        [  5558,   5246],
                        [  5458,   5107],
                        [  5355,   4966],
                        [  5247,   4825],
                        [  5133,   4680],
                        [  5011,   4533],
                        [  4881,   4381],
                        [  4741,   4224],
                        [  4592,   4063],
                        [  4433,   3894],
                        [  4258,   3720],
                        [  4067,   3539],
                        [  3854,   3353],
                        [  3617,   3161],
                        [  3355,   2962],
                        [  3068,   2759],
                        [  2763,   2552],
                        [  2441,   2342],
                        [  2118,   2130],
                        [  1796,   1920],
                        [  1487,   1714],
                        [  1188,   1511],
                        [   904,   1314],
                        [   636,   1122],
                        [   361,    912],
                        [    82,    688],
                        [  -249,    401],
                        [  -626,     55],
                        [ -1055,   -355],
                        [ -1535,   -827],
                        [ -2029,  -1324],
                        [ -2537,  -1848],
                        [ -2976,  -2312],
                        [ -3349,  -2719],
                        [ -3646,  -3059],
                        [ -3864,  -3330],
                        [ -4004,  -3526],
                        [ -4062,  -3648],
                        [ -4042,  -3697],
                        [ -3943,  -3670],
                        [ -3771,  -3572],
                        [ -3525,  -3401],
                        [ -3212,  -3165],
                        [ -2832,  -2862],
                        [ -2397,  -2499],
                        [ -1904,  -2078],
                        [ -1366,  -1607],
                        [  -783,  -1086],
                        [  -167,   -524],
                        [   483,     78],
                        [  1157,    710],
                        [  1855,   1372],
                        [  2570,   2052],
                        [  3301,   2751],
                        [  4041,   3459],
                        [  4786,   4174],
                        [  5531,   4888],
                        [  6272,   5601],
                        [  7002,   6305],
                        [  7719,   6999],
                        [  8410,   7678],
                        [  9075,   8340],
                        [  9703,   8980],
                        [ 10291,   9592],
                        [ 10839,  10175],
                        [ 11343,  10723],
                        [ 11808,  11235],
                        [ 12234,  11707],
                        [ 12625,  12139],
                        [ 12977,  12529],
                        [ 13289,  12874],
                        [ 13558,  13175],
                        [ 13790,  13433],
                        [ 13961,  13630],
                        [ 14051,  13742],
                        [ 14055,  13767],
                        [ 13981,  13713],
                        [ 13813,  13562],
                        [ 13511,  13277],
                        [ 13037,  12819],
                        [ 12427,  12223],
                        [ 11741,  11548],
                        [ 10992,  10806],
                        [ 10188,  10007],
                        [  9351,   9168],
                        [  8496,   8309],
                        [  7636,   7440],
                        [  6782,   6575],
                        [  5946,   5726],
                        [  5139,   4905],
                        [  4368,   4121],
                        [  3641,   3382],
                        [  2966,   2696],
                        [  2348,   2069],
                        [  1791,   1504],
                        [  1297,   1004],
                        [   869,    574],
                        [   509,    212],
                        [   215,    -82],
                        [   -13,   -309],
                        [  -176,   -480],
                        [  -278,   -597],
                        [  -322,   -669],
                        [  -312,   -698],
                        [  -253,   -691],
                        [  -149,   -653],
                        [    -5,   -577],
                        [   174,   -468],
                        [   384,   -321],
                        [   618,   -141],
                        [   873,     71],
                        [  1145,    309],
                        [  1426,    575],
                        [  1712,    865],
                        [  2000,   1177],
                        [  2283,   1509],
                        [  2558,   1850],
                        [  2820,   2198],
                        [  3066,   2538],
                        [  3293,   2869],
                        [  3495,   3177],
                        [  3671,   3462],
                        [  3817,   3720],
                        [  3932,   3948],
                        [  4011,   4141],
                        [  4055,   4301],
                        [  4063,   4424],
                        [  4034,   4509],
                        [  3969,   4557],
                        [  3868,   4564],
                        [  3730,   4532],
                        [  3559,   4462],
                        [  3354,   4353],
                        [  3120,   4206],
                        [  2864,   4024],
                        [  2587,   3806],
                        [  2297,   3555],
                        [  1996,   3274],
                        [  1690,   2965],
                        [  1378,   2629],
                        [  1058,   2271],
                        [   733,   1892],
                        [   392,   1494],
                        [    37,   1078],
                        [  -330,    650],
                        [  -702,    215],
                        [ -1073,   -219],
                        [ -1443,   -650],
                        [ -1756,  -1021],
                        [ -2014,  -1336],
                        [ -2193,  -1567],
                        [ -2291,  -1713],
                        [ -2307,  -1771],
                        [ -2237,  -1740],
                        [ -2153,  -1688],
                        [ -2051,  -1613],
                        [ -1970,  -1554],
                        [ -1909,  -1508],
                        [ -1870,  -1480],
                        [ -1854,  -1469],
                        [ -1861,  -1478],
                        [ -1892,  -1506],
                        [ -1947,  -1554],
                        [ -2024,  -1620],
                        [ -2122,  -1704],
                        [ -2241,  -1806],
                        [ -2377,  -1923],
                        [ -2531,  -2056],
                        [ -2698,  -2200],
                        [ -2879,  -2359],
                        [ -3066,  -2525],
                        [ -3263,  -2702],
                        [ -3466,  -2886],
                        [ -3675,  -3077],
                        [ -3889,  -3271],
                        [ -4110,  -3471],
                        [ -4337,  -3673],
                        [ -4570,  -3875],
                        [ -4805,  -4078],
                        [ -5046,  -4282],
                        [ -5289,  -4485],
                        [ -5533,  -4687],
                        [ -5776,  -4889],
                        [ -6016,  -5090],
                        [ -6244,  -5290],
                        [ -6460,  -5488],
                        [ -6662,  -5683],
                        [ -6847,  -5874],
                        [ -7021,  -6058],
                        [ -7182,  -6234],
                        [ -7339,  -6404],
                        [ -7493,  -6564],
                        [ -7641,  -6717],
                        [ -7780,  -6858],
                        [ -7910,  -6989],
                        [ -8031,  -7109],
                        [ -8132,  -7209],
                        [ -8215,  -7291],
                        [ -8294,  -7369],
                        [ -8372,  -7449],
                        [ -8432,  -7512],
                        [ -8431,  -7517],
                        [ -8318,  -7413],
                        [ -8088,  -7196],
                        [ -7775,  -6897],
                        [ -7383,  -6523],
                        [ -6921,  -6079],
                        [ -6402,  -5581],
                        [ -5838,  -5039],
                        [ -5239,  -4464],
                        [ -4614,  -3863],
                        [ -3972,  -3247],
                        [ -3322,  -2624],
                        [ -2670,  -2004],
                        [ -2024,  -1391],
                        [ -1390,   -793],
                        [  -774,   -213],
                        [  -177,    344],
                        [   393,    873],
                        [   937,   1374],
                        [  1449,   1844],
                        [  1928,   2281],
                        [  2373,   2690],
                        [  2784,   3070],
                        [  3159,   3427],
                        [  3500,   3762],
                        [  3808,   4079],
                        [  4084,   4379],
                        [  4328,   4661],
                        [  4543,   4928],
                        [  4727,   5168],
                        [  4883,   5382],
                        [  5011,   5567],
                        [  5111,   5725],
                        [  5182,   5848],
                        [  5228,   5939],
                        [  5248,   5990],
                        [  5242,   6002],
                        [  5212,   5974],
                        [  5159,   5905],
                        [  5082,   5805],
                        [  4983,   5672],
                        [  4862,   5517],
                        [  4721,   5341],
                        [  4560,   5147],
                        [  4379,   4936],
                        [  4181,   4708],
                        [  3967,   4466],
                        [  3738,   4209],
                        [  3494,   3940],
                        [  3236,   3659],
                        [  2966,   3366],
                        [  2685,   3065],
                        [  2394,   2755],
                        [  2094,   2438],
                        [  1787,   2117],
                        [  1471,   1791],
                        [  1148,   1463],
                        [   817,   1134],
                        [   476,    806],
                        [   128,    481],
                        [  -226,    162],
                        [  -585,   -151],
                        [  -947,   -455],
                        [ -1299,   -749],
                        [ -1642,  -1028],
                        [ -1964,  -1289],
                        [ -2266,  -1533],
                        [ -2546,  -1759],
                        [ -2802,  -1965],
                        [ -3057,  -2178],
                        [ -3308,  -2394],
                        [ -3590,  -2647],
                        [ -3902,  -2938],
                        [ -4249,  -3272],
                        [ -4630,  -3648],
                        [ -5020,  -4042],
                        [ -5419,  -4455],
                        [ -5757,  -4812],
                        [ -6035,  -5120],
                        [ -6243,  -5364],
                        [ -6383,  -5546],
                        [ -6446,  -5657],
                        [ -6434,  -5698],
                        [ -6347,  -5668],
                        [ -6186,  -5567],
                        [ -5953,  -5396],
                        [ -5649,  -5157],
                        [ -5281,  -4853],
                        [ -4851,  -4487],
                        [ -4367,  -4066],
                        [ -3831,  -3590],
                        [ -3253,  -3069],
                        [ -2637,  -2504],
                        [ -1992,  -1905],
                        [ -1321,  -1275],
                        [  -632,   -622],
                        [    70,     49],
                        [   779,    729],
                        [  1493,   1416],
                        [  2202,   2100],
                        [  2902,   2777],
                        [  3588,   3440],
                        [  4256,   4086],
                        [  4896,   4708],
                        [  5507,   5302],
                        [  6076,   5863],
                        [  6600,   6389],
                        [  7071,   6874],
                        [  7487,   7317],
                        [  7846,   7711],
                        [  8146,   8057],
                        [  8397,   8352],
                        [  8595,   8592],
                        [  8747,   8780],
                        [  8853,   8914],
                        [  8912,   8994],
                        [  8922,   9022],
                        [  8888,   8998],
                        [  8816,   8930],
                        [  8739,   8852],
                        [  8686,   8791],
                        [  8662,   8755],
                        [  8656,   8732],
                        [  8635,   8689],
                        [  8535,   8563],
                        [  8320,   8320],
                        [  8005,   7974],
                        [  7599,   7534],
                        [  7110,   7010],
                        [  6556,   6416],
                        [  5949,   5768],
                        [  5302,   5077],
                        [  4626,   4354],
                        [  3936,   3614],
                        [  3240,   2868],
                        [  2550,   2127],
                        [  1873,   1400],
                        [  1218,    695],
                        [   592,     22],
                        [     1,   -615],
                        [  -552,  -1211],
                        [ -1060,  -1759],
                        [ -1523,  -2259],
                        [ -1935,  -2708],
                        [ -2300,  -3107],
                        [ -2615,  -3460],
                        [ -2884,  -3766],
                        [ -3107,  -4031],
                        [ -3287,  -4258],
                        [ -3430,  -4452],
                        [ -3538,  -4617],
                        [ -3616,  -4752],
                        [ -3668,  -4861],
                        [ -3697,  -4943],
                        [ -3707,  -5001],
                        [ -3702,  -5035],
                        [ -3686,  -5049],
                        [ -3664,  -5041],
                        [ -3640,  -5015],
                        [ -3616,  -4968],
                        [ -3598,  -4903],
                        [ -3587,  -4830],
                        [ -3589,  -4748],
                        [ -3603,  -4671],
                        [ -3636,  -4600],
                        [ -3686,  -4548],
                        [ -3758,  -4517],
                        [ -3851,  -4506],
                        [ -3968,  -4519],
                        [ -4109,  -4558],
                        [ -4275,  -4625],
                        [ -4463,  -4717],
                        [ -4677,  -4838],
                        [ -4913,  -4987],
                        [ -5172,  -5163],
                        [ -5449,  -5363],
                        [ -5746,  -5588],
                        [ -6056,  -5835],
                        [ -6381,  -6104],
                        [ -6712,  -6389],
                        [ -7050,  -6691],
                        [ -7388,  -7005],
                        [ -7725,  -7330],
                        [ -8054,  -7660],
                        [ -8372,  -7997],
                        [ -8675,  -8333],
                        [ -8962,  -8668],
                        [ -9237,  -9000],
                        [ -9501,  -9329],
                        [ -9748,  -9646],
                        [ -9975,  -9951],
                        [-10177, -10231],
                        [-10353, -10488],
                        [-10464, -10681],
                        [-10514, -10811],
                        [-10489, -10864],
                        [-10389, -10838],
                        [-10203, -10722],
                        [ -9933, -10517],
                        [ -9631, -10272],
                        [ -9295,  -9987],
                        [ -8960,  -9696],
                        [ -8625,  -9396],
                        [ -8299,  -9098],
                        [ -7984,  -8802],
                        [ -7689,  -8518],
                        [ -7413,  -8245],
                        [ -7164,  -7992],
                        [ -6940,  -7756],
                        [ -6747,  -7544],
                        [ -6583,  -7356],
                        [ -6450,  -7192],
                        [ -6351,  -7057],
                        [ -6281,  -6948],
                        [ -6242,  -6867],
                        [ -6233,  -6813],
                        [ -6252,  -6787],
                        [ -6298,  -6785],
                        [ -6370,  -6810],
                        [ -6468,  -6858],
                        [ -6590,  -6931],
                        [ -6734,  -7023],
                        [ -6900,  -7135],
                        [ -7083,  -7265],
                        [ -7282,  -7410],
                        [ -7493,  -7567],
                        [ -7716,  -7735],
                        [ -7939,  -7909],
                        [ -8164,  -8089],
                        [ -8378,  -8271],
                        [ -8580,  -8453],
                        [ -8764,  -8631],
                        [ -8930,  -8803],
                        [ -9078,  -8966],
                        [ -9204,  -9116],
                        [ -9317,  -9250],
                        [ -9414,  -9367],
                        [ -9493,  -9464],
                        [ -9552,  -9540],
                        [ -9588,  -9592],
                        [ -9596,  -9616],
                        [ -9604,  -9639],
                        [ -9663,  -9713],
                        [ -9805,  -9867],
                        [-10032, -10107],
                        [-10333, -10419],
                        [-10673, -10771],
                        [-10971, -11083],
                        [-11156, -11283],
                        [-11219, -11362],
                        [-11165, -11327],
                        [-11000, -11182],
                        [-10732, -10936],
                        [-10372, -10598],
                        [ -9929, -10175],
                        [ -9414,  -9677],
                        [ -8838,  -9115],
                        [ -8209,  -8498],
                        [ -7538,  -7837],
                        [ -6833,  -7139],
                        [ -6105,  -6416],
                        [ -5362,  -5675],
                        [ -4611,  -4922],
                        [ -3860,  -4168],
                        [ -3117,  -3418],
                        [ -2390,  -2680],
                        [ -1683,  -1957],
                        [ -1003,  -1255],
                        [  -353,   -579],
                        [   264,     72],
                        [   844,    692],
                        [  1385,   1282],
                        [  1887,   1840],
                        [  2348,   2366],
                        [  2767,   2859],
                        [  3143,   3313],
                        [  3474,   3731],
                        [  3762,   4105],
                        [  4005,   4436],
                        [  4202,   4718],
                        [  4356,   4953],
                        [  4466,   5130],
                        [  4533,   5253],
                        [  4559,   5318],
                        [  4545,   5328],
                        [  4493,   5288],
                        [  4405,   5199],
                        [  4284,   5072],
                        [  4129,   4910],
                        [  3946,   4717],
                        [  3733,   4496],
                        [  3498,   4250],
                        [  3239,   3980],
                        [  2963,   3693],
                        [  2672,   3388],
                        [  2368,   3070],
                        [  2053,   2742],
                        [  1733,   2407],
                        [  1409,   2068],
                        [  1084,   1727],
                        [   761,   1386],
                        [   441,   1050],
                        [   128,    719],
                        [  -174,    398],
                        [  -464,     88],
                        [  -740,   -209],
                        [ -1000,   -490],
                        [ -1249,   -753],
                        [ -1484,   -997],
                        [ -1705,  -1220],
                        [ -1907,  -1417],
                        [ -2087,  -1588],
                        [ -2245,  -1734],
                        [ -2380,  -1854],
                        [ -2490,  -1948],
                        [ -2594,  -2035],
                        [ -2687,  -2110],
                        [ -2786,  -2194],
                        [ -2889,  -2282],
                        [ -3009,  -2390],
                        [ -3145,  -2517],
                        [ -3294,  -2660],
                        [ -3457,  -2821],
                        [ -3589,  -2955],
                        [ -3693,  -3065],
                        [ -3759,  -3142],
                        [ -3790,  -3187],
                        [ -3777,  -3192],
                        [ -3722,  -3159],
                        [ -3621,  -3083],
                        [ -3478,  -2967],
                        [ -3289,  -2809],
                        [ -3058,  -2611],
                        [ -2789,  -2375],
                        [ -2481,  -2103],
                        [ -2142,  -1798],
                        [ -1772,  -1463],
                        [ -1379,  -1102],
                        [  -964,   -719],
                        [  -536,   -320],
                        [   -94,     93],
                        [   351,    513],
                        [   799,    937],
                        [  1243,   1359],
                        [  1683,   1777],
                        [  2108,   2183],
                        [  2520,   2578],
                        [  2912,   2952],
                        [  3282,   3305],
                        [  3622,   3629],
                        [  3933,   3924],
                        [  4201,   4185],
                        [  4428,   4411],
                        [  4609,   4598],
                        [  4741,   4745],
                        [  4823,   4850],
                        [  4856,   4912],
                        [  4848,   4931],
                        [  4799,   4907],
                        [  4713,   4839],
                        [  4592,   4730],
                        [  4440,   4582],
                        [  4253,   4393],
                        [  4036,   4167],
                        [  3836,   3950],
                        [  3730,   3822],
                        [  3755,   3816],
                        [  3914,   3940],
                        [  4207,   4190],
                        [  4609,   4544],
                        [  5025,   4908],
                        [  5358,   5186],
                        [  5587,   5360],
                        [  5719,   5439],
                        [  5761,   5428],
                        [  5718,   5330],
                        [  5597,   5156],
                        [  5411,   4913],
                        [  5165,   4609],
                        [  4870,   4254],
                        [  4535,   3857],
                        [  4166,   3426],
                        [  3771,   2967],
                        [  3357,   2492],
                        [  2932,   2006],
                        [  2499,   1514],
                        [  2065,   1023],
                        [  1636,    539],
                        [  1216,     66],
                        [   808,   -394],
                        [   414,   -838],
                        [    34,  -1262],
                        [  -327,  -1666],
                        [  -675,  -2051],
                        [ -1007,  -2414],
                        [ -1326,  -2761],
                        [ -1632,  -3093],
                        [ -1928,  -3415],
                        [ -2215,  -3727],
                        [ -2494,  -4031],
                        [ -2769,  -4329],
                        [ -3038,  -4618],
                        [ -3305,  -4902],
                        [ -3571,  -5173],
                        [ -3837,  -5436],
                        [ -4104,  -5686],
                        [ -4375,  -5923],
                        [ -4648,  -6151],
                        [ -4929,  -6372],
                        [ -5213,  -6589],
                        [ -5505,  -6806],
                        [ -5801,  -7029],
                        [ -6104,  -7259],
                        [ -6411,  -7495],
                        [ -6723,  -7739],
                        [ -7037,  -7991],
                        [ -7356,  -8249],
                        [ -7675,  -8514],
                        [ -7996,  -8786],
                        [ -8316,  -9062],
                        [ -8635,  -9341],
                        [ -8949,  -9622],
                        [ -9258,  -9903],
                        [ -9557, -10180],
                        [ -9846, -10453],
                        [-10125, -10718],
                        [-10393, -10974],
                        [-10649, -11217],
                        [-10892, -11447],
                        [-11114, -11659],
                        [-11316, -11854],
                        [-11484, -12028],
                        [-11619, -12179],
                        [-11721, -12307],
                        [-11788, -12412],
                        [-11819, -12489],
                        [-11814, -12538],
                        [-11770, -12552],
                        [-11686, -12534],
                        [-11557, -12471],
                        [-11382, -12364],
                        [-11159, -12209],
                        [-10891, -12008],
                        [-10558, -11739],
                        [-10164, -11404],
                        [ -9728, -11023],
                        [ -9251, -10595],
                        [ -8759, -10144],
                        [ -8249,  -9670],
                        [ -7739,  -9187],
                        [ -7228,  -8694],
                        [ -6730,  -8205],
                        [ -6245,  -7723],
                        [ -5784,  -7256],
                        [ -5349,  -6806],
                        [ -4944,  -6379],
                        [ -4573,  -5978],
                        [ -4239,  -5610],
                        [ -3942,  -5272],
                        [ -3686,  -4969],
                        [ -3469,  -4703],
                        [ -3292,  -4472],
                        [ -3155,  -4279],
                        [ -3055,  -4121],
                        [ -2992,  -3998],
                        [ -2962,  -3909],
                        [ -2965,  -3853],
                        [ -2995,  -3826],
                        [ -3053,  -3829],
                        [ -3131,  -3856],
                        [ -3230,  -3907],
                        [ -3341,  -3973],
                        [ -3465,  -4054],
                        [ -3589,  -4143],
                        [ -3712,  -4237],
                        [ -3824,  -4331],
                        [ -3924,  -4422],
                        [ -4003,  -4504],
                        [ -4060,  -4575],
                        [ -4093,  -4631],
                        [ -4098,  -4669],
                        [ -4081,  -4685],
                        [ -4038,  -4675],
                        [ -3967,  -4637],
                        [ -3868,  -4572],
                        [ -3736,  -4472],
                        [ -3573,  -4340],
                        [ -3445,  -4239],
                        [ -3434,  -4253],
                        [ -3573,  -4413],
                        [ -3863,  -4721],
                        [ -4307,  -5179],
                        [ -4885,  -5768],
                        [ -5486,  -6377],
                        [ -5990,  -6888],
                        [ -6366,  -7271],
                        [ -6621,  -7534],
                        [ -6758,  -7679],
                        [ -6775,  -7706],
                        [ -6684,  -7619],
                        [ -6490,  -7425],
                        [ -6203,  -7131],
                        [ -5831,  -6745],
                        [ -5384,  -6276],
                        [ -4869,  -5734],
                        [ -4298,  -5128],
                        [ -3680,  -4468],
                        [ -3024,  -3765],
                        [ -2340,  -3027],
                        [ -1638,  -2264],
                        [  -927,  -1487],
                        [  -217,   -704],
                        [   486,     78],
                        [  1173,    847],
                        [  1839,   1600],
                        [  2477,   2324],
                        [  3084,   3015],
                        [  3656,   3668],
                        [  4190,   4281],
                        [  4682,   4853],
                        [  5130,   5384],
                        [  5534,   5874],
                        [  5891,   6322],
                        [  6199,   6726],
                        [  6463,   7086],
                        [  6676,   7395],
                        [  6842,   7655],
                        [  6962,   7859],
                        [  7036,   8010],
                        [  7069,   8106],
                        [  7059,   8149],
                        [  7011,   8140],
                        [  6928,   8085],
                        [  6812,   7991],
                        [  6666,   7860],
                        [  6493,   7698],
                        [  6294,   7510],
                        [  6075,   7298],
                        [  5839,   7066],
                        [  5588,   6819],
                        [  5330,   6560],
                        [  5067,   6294],
                        [  4801,   6025],
                        [  4539,   5755],
                        [  4281,   5488],
                        [  4032,   5228],
                        [  3794,   4977],
                        [  3572,   4737],
                        [  3369,   4512],
                        [  3192,   4302],
                        [  3046,   4112],
                        [  2930,   3941],
                        [  2846,   3791],
                        [  2785,   3665],
                        [  2750,   3562],
                        [  2727,   3482],
                        [  2721,   3429],
                        [  2730,   3401],
                        [  2754,   3397],
                        [  2793,   3416],
                        [  2845,   3457],
                        [  2910,   3520],
                        [  2989,   3603],
                        [  3088,   3711],
                        [  3205,   3842],
                        [  3323,   3978],
                        [  3444,   4120],
                        [  3543,   4242],
                        [  3619,   4343],
                        [  3685,   4435],
                        [  3738,   4513],
                        [  3785,   4586],
                        [  3825,   4650],
                        [  3870,   4716],
                        [  3914,   4779],
                        [  3964,   4847],
                        [  4018,   4916],
                        [  4081,   4990],
                        [  4151,   5068],
                        [  4230,   5154],
                        [  4315,   5243],
                        [  4409,   5337],
                        [  4509,   5434],
                        [  4613,   5534],
                        [  4721,   5635],
                        [  4832,   5734],
                        [  4942,   5831],
                        [  5049,   5923],
                        [  5152,   6009],
                        [  5247,   6087],
                        [  5333,   6156],
                        [  5408,   6215],
                        [  5470,   6261],
                        [  5516,   6293],
                        [  5547,   6308],
                        [  5558,   6303],
                        [  5549,   6279],
                        [  5515,   6230],
                        [  5456,   6158],
                        [  5371,   6061],
                        [  5259,   5940],
                        [  5116,   5794],
                        [  4946,   5624],
                        [  4754,   5432],
                        [  4539,   5216],
                        [  4307,   4977],
                        [  4058,   4720],
                        [  3798,   4446],
                        [  3522,   4150],
                        [  3242,   3846],
                        [  3040,   3613],
                        [  3007,   3543],
                        [  3170,   3663],
                        [  3534,   3978],
                        [  4112,   4502],
                        [  4889,   5221],
                        [  5747,   6018],
                        [  6547,   6759],
                        [  7261,   7415],
                        [  7893,   7991],
                        [  8437,   8484],
                        [  8891,   8890],
                        [  9257,   9211],
                        [  9539,   9445],
                        [  9740,   9596],
                        [  9865,   9670],
                        [  9917,   9668],
                        [  9898,   9596],
                        [  9815,   9458],
                        [  9673,   9262],
                        [  9476,   9011],
                        [  9229,   8709],
                        [  8938,   8365],
                        [  8608,   7983],
                        [  8245,   7568],
                        [  7853,   7124],
                        [  7434,   6658],
                        [  6995,   6177],
                        [  6537,   5684],
                        [  6060,   5186],
                        [  5570,   4687],
                        [  5066,   4183],
                        [  4550,   3678],
                        [  4026,   3164],
                        [  3493,   2643],
                        [  2954,   2111],
                        [  2411,   1571],
                        [  1863,   1024],
                        [  1314,    472],
                        [   765,    -79],
                        [   217,   -627],
                        [  -327,  -1168],
                        [  -868,  -1702],
                        [ -1401,  -2224],
                        [ -1928,  -2735],
                        [ -2446,  -3234],
                        [ -2953,  -3719],
                        [ -3446,  -4192],
                        [ -3924,  -4653],
                        [ -4384,  -5099],
                        [ -4825,  -5530],
                        [ -5242,  -5943],
                        [ -5636,  -6340],
                        [ -6008,  -6716],
                        [ -6353,  -7072],
                        [ -6672,  -7406],
                        [ -6966,  -7717],
                        [ -7229,  -8002],
                        [ -7463,  -8262],
                        [ -7667,  -8493],
                        [ -7838,  -8695],
                        [ -7986,  -8864],
                        [ -8109,  -9003],
                        [ -8213,  -9109],
                        [ -8296,  -9180],
                        [ -8355,  -9217],
                        [ -8390,  -9219],
                        [ -8385,  -9186],
                        [ -8341,  -9118],
                        [ -8253,  -9016],
                        [ -8120,  -8881],
                        [ -7945,  -8712],
                        [ -7729,  -8509],
                        [ -7477,  -8279],
                        [ -7193,  -8022],
                        [ -6897,  -7758],
                        [ -6590,  -7486],
                        [ -6281,  -7214],
                        [ -5969,  -6942],
                        [ -5628,  -6640],
                        [ -5262,  -6312],
                        [ -4852,  -5939],
                        [ -4402,  -5523],
                        [ -3924,  -5074],
                        [ -3419,  -4596],
                        [ -2902,  -4099],
                        [ -2374,  -3587],
                        [ -1848,  -3070],
                        [ -1324,  -2551],
                        [  -817,  -2041],
                        [  -324,  -1540],
                        [   145,  -1057],
                        [   589,   -594],
                        [  1003,   -157],
                        [  1385,    254],
                        [  1731,    633],
                        [  2044,    982],
                        [  2320,   1298],
                        [  2559,   1581],
                        [  2765,   1832],
                        [  2939,   2052],
                        [  3083,   2241],
                        [  3201,   2401],
                        [  3296,   2533],
                        [  3370,   2641],
                        [  3429,   2726],
                        [  3473,   2791],
                        [  3511,   2844],
                        [  3542,   2886],
                        [  3574,   2924],
                        [  3611,   2962],
                        [  3657,   3006],
                        [  3715,   3057],
                        [  3792,   3119],
                        [  3890,   3196],
                        [  4015,   3292],
                        [  4167,   3406],
                        [  4344,   3544],
                        [  4549,   3708],
                        [  4782,   3898],
                        [  5038,   4111],
                        [  5329,   4362],
                        [  5636,   4631],
                        [  5867,   4830],
                        [  5940,   4875],
                        [  5834,   4747],
                        [  5541,   4440],
                        [  5042,   3933],
                        [  4344,   3234],
                        [  3572,   2464],
                        [  2862,   1760],
                        [  2246,   1151],
                        [  1717,    631],
                        [  1280,    206],
                        [   942,   -119],
                        [   696,   -345],
                        [   543,   -474],
                        [   474,   -506],
                        [   484,   -449],
                        [   571,   -307],
                        [   729,    -86],
                        [   947,    206],
                        [  1220,    561],
                        [  1541,    970],
                        [  1900,   1428],
                        [  2290,   1921],
                        [  2702,   2442],
                        [  3127,   2984],
                        [  3557,   3536],
                        [  3987,   4088],
                        [  4409,   4633],
                        [  4820,   5155],
                        [  5212,   5652],
                        [  5584,   6114],
                        [  5930,   6537],
                        [  6249,   6927],
                        [  6537,   7278],
                        [  6793,   7599],
                        [  7014,   7889],
                        [  7203,   8148],
                        [  7357,   8376],
                        [  7477,   8570],
                        [  7562,   8730],
                        [  7615,   8855],
                        [  7636,   8945],
                        [  7628,   9001],
                        [  7592,   9025],
                        [  7533,   9016],
                        [  7451,   8977],
                        [  7350,   8912],
                        [  7232,   8825],
                        [  7099,   8718],
                        [  6953,   8594],
                        [  6797,   8457],
                        [  6634,   8311],
                        [  6468,   8160],
                        [  6301,   8006],
                        [  6138,   7853],
                        [  5982,   7704],
                        [  5836,   7563],
                        [  5702,   7430],
                        [  5581,   7309],
                        [  5476,   7201],
                        [  5392,   7108],
                        [  5329,   7031],
                        [  5303,   6970],
                        [  5311,   6927],
                        [  5355,   6901],
                        [  5436,   6892],
                        [  5542,   6901],
                        [  5674,   6928],
                        [  5809,   6970],
                        [  5949,   7028],
                        [  6090,   7100],
                        [  6231,   7183],
                        [  6371,   7278],
                        [  6508,   7382],
                        [  6663,   7516],
                        [  6835,   7677],
                        [  7044,   7886],
                        [  7286,   8138],
                        [  7546,   8415],
                        [  7823,   8718],
                        [  8065,   8993],
                        [  8275,   9240],
                        [  8433,   9440],
                        [  8539,   9592],
                        [  8601,   9702],
                        [  8617,   9767],
                        [  8595,   9795],
                        [  8533,   9781],
                        [  8440,   9735],
                        [  8314,   9653],
                        [  8165,   9544],
                        [  7989,   9406],
                        [  7794,   9245],
                        [  7578,   9060],
                        [  7350,   8857],
                        [  7107,   8634],
                        [  6857,   8396],
                        [  6598,   8143],
                        [  6331,   7876],
                        [  6060,   7599],
                        [  5784,   7312],
                        [  5502,   7015],
                        [  5215,   6713],
                        [  4925,   6405],
                        [  4630,   6093],
                        [  4333,   5779],
                        [  4033,   5462],
                        [  3732,   5145],
                        [  3430,   4824],
                        [  3127,   4500],
                        [  2824,   4172],
                        [  2524,   3842],
                        [  2224,   3509],
                        [  1925,   3175],
                        [  1622,   2839],
                        [  1318,   2505],
                        [  1014,   2173],
                        [   711,   1845],
                        [   410,   1519],
                        [   115,   1200],
                        [  -171,    888],
                        [  -457,    577],
                        [  -716,    287],
                        [  -856,    113],
                        [  -806,    126],
                        [  -551,    341],
                        [   -85,    763],
                        [   621,   1422],
                        [  1561,   2314],
                        [  2614,   3317],
                        [  3639,   4297],
                        [  4611,   5225],
                        [  5528,   6105],
                        [  6378,   6923],
                        [  7150,   7665],
                        [  7839,   8330],
                        [  8446,   8908],
                        [  8965,   9398],
                        [  9395,   9796],
                        [  9735,  10103],
                        [  9985,  10317],
                        [ 10146,  10442],
                        [ 10219,  10478],
                        [ 10208,  10428],
                        [ 10117,  10295],
                        [  9950,  10086],
                        [  9711,   9804],
                        [  9407,   9456],
                        [  9042,   9048],
                        [  8621,   8585],
                        [  8151,   8080],
                        [  7634,   7538],
                        [  7077,   6972],
                        [  6485,   6386],
                        [  5861,   5784],
                        [  5212,   5170],
                        [  4542,   4535],
                        [  3855,   3888],
                        [  3157,   3220],
                        [  2451,   2537],
                        [  1742,   1844],
                        [  1034,   1142],
                        [   332,    439],
                        [  -362,   -262],
                        [ -1043,   -957],
                        [ -1709,  -1645],
                        [ -2353,  -2316],
                        [ -2977,  -2971],
                        [ -3575,  -3602],
                        [ -4145,  -4206],
                        [ -4682,  -4779],
                        [ -5186,  -5322],
                        [ -5652,  -5830],
                        [ -6077,  -6301],
                        [ -6459,  -6734],
                        [ -6799,  -7129],
                        [ -7096,  -7485],
                        [ -7352,  -7798],
                        [ -7564,  -8071],
                        [ -7733,  -8304],
                        [ -7861,  -8494],
                        [ -7947,  -8642],
                        [ -7993,  -8748],
                        [ -7999,  -8812],
                        [ -7978,  -8835],
                        [ -7932,  -8818],
                        [ -7868,  -8760],
                        [ -7789,  -8664],
                        [ -7694,  -8530],
                        [ -7584,  -8361],
                        [ -7443,  -8159],
                        [ -7274,  -7925],
                        [ -7065,  -7659],
                        [ -6820,  -7366],
                        [ -6544,  -7048],
                        [ -6235,  -6705],
                        [ -5914,  -6356],
                        [ -5580,  -6003],
                        [ -5280,  -5688],
                        [ -5012,  -5412],
                        [ -4787,  -5184],
                        [ -4606,  -5004],
                        [ -4434,  -4838],
                        [ -4276,  -4688],
                        [ -4077,  -4501],
                        [ -3842,  -4279],
                        [ -3573,  -4026],
                        [ -3272,  -3740],
                        [ -2947,  -3430],
                        [ -2598,  -3096],
                        [ -2238,  -2749],
                        [ -1865,  -2387],
                        [ -1488,  -2020],
                        [ -1107,  -1648],
                        [  -732,  -1278],
                        [  -361,   -911],
                        [    -1,   -553],
                        [   349,   -203],
                        [   683,    134],
                        [  1003,    458],
                        [  1303,    768],
                        [  1588,   1064],
                        [  1857,   1344],
                        [  2110,   1611],
                        [  2353,   1864],
                        [  2585,   2104],
                        [  2811,   2331],
                        [  3031,   2546],
                        [  3247,   2752],
                        [  3461,   2950],
                        [  3677,   3144],
                        [  3895,   3336],
                        [  4116,   3532],
                        [  4341,   3732],
                        [  4572,   3941],
                        [  4809,   4159],
                        [  5060,   4389],
                        [  5325,   4633],
                        [  5610,   4890],
                        [  5913,   5160],
                        [  6236,   5445],
                        [  6577,   5744],
                        [  6932,   6056],
                        [  7299,   6380],
                        [  7684,   6725],
                        [  8058,   7063],
                        [  8331,   7306],
                        [  8448,   7397],
                        [  8396,   7328],
                        [  8166,   7087],
                        [  7720,   6639],
                        [  7050,   5975],
                        [  6270,   5205],
                        [  5499,   4450],
                        [  4758,   3728],
                        [  4045,   3036],
                        [  3374,   2388],
                        [  2751,   1793],
                        [  2180,   1257],
                        [  1662,    780],
                        [  1197,    368],
                        [   787,     21],
                        [   433,   -262],
                        [   134,   -483],
                        [  -114,   -644],
                        [  -313,   -748],
                        [  -466,   -800],
                        [  -578,   -803],
                        [  -653,   -765],
                        [  -697,   -691],
                        [  -713,   -586],
                        [  -709,   -457],
                        [  -687,   -313],
                        [  -652,   -161],
                        [  -607,    -15],
                        [  -558,    123],
                        [  -506,    242],
                        [  -455,    341],
                        [  -405,    424],
                        [  -362,    488],
                        [  -323,    544],
                        [  -293,    592],
                        [  -270,    637],
                        [  -255,    676],
                        [  -249,    709],
                        [  -249,    738],
                        [  -258,    764],
                        [  -273,    787],
                        [  -293,    809],
                        [  -316,    831],
                        [  -342,    849],
                        [  -368,    865],
                        [  -395,    878],
                        [  -420,    887],
                        [  -444,    895],
                        [  -466,    900],
                        [  -486,    908],
                        [  -502,    917],
                        [  -512,    932],
                        [  -515,    951],
                        [  -509,    979],
                        [  -493,   1015],
                        [  -466,   1060],
                        [  -426,   1115],
                        [  -375,   1181],
                        [  -311,   1256],
                        [  -231,   1342],
                        [  -133,   1437],
                        [    -7,   1541],
                        [   147,   1654],
                        [   328,   1773],
                        [   538,   1897],
                        [   763,   2026],
                        [  1004,   2157],
                        [  1237,   2290],
                        [  1461,   2419],
                        [  1669,   2545],
                        [  1861,   2667],
                        [  2038,   2784],
                        [  2195,   2895],
                        [  2377,   3041],
                        [  2576,   3218],
                        [  2821,   3451],
                        [  3109,   3738],
                        [  3427,   4064],
                        [  3773,   4429],
                        [  4078,   4760],
                        [  4342,   5059],
                        [  4533,   5290],
                        [  4649,   5453],
                        [  4696,   5550],
                        [  4674,   5579],
                        [  4588,   5548],
                        [  4437,   5451],
                        [  4232,   5299],
                        [  3972,   5090],
                        [  3664,   4832],
                        [  3311,   4525],
                        [  2922,   4178],
                        [  2496,   3790],
                        [  2046,   3371],
                        [  1571,   2920],
                        [  1081,   2447],
                        [   577,   1951],
                        [    66,   1441],
                        [  -452,    916],
                        [  -971,    384],
                        [ -1492,   -153],
                        [ -2010,   -690],
                        [ -2525,  -1224],
                        [ -3032,  -1751],
                        [ -3530,  -2267],
                        [ -4015,  -2771],
                        [ -4483,  -3258],
                        [ -4934,  -3729],
                        [ -5362,  -4183],
                        [ -5764,  -4618],
                        [ -6137,  -5034],
                        [ -6483,  -5429],
                        [ -6802,  -5803],
                        [ -7102,  -6154],
                        [ -7378,  -6479],
                        [ -7636,  -6777],
                        [ -7875,  -7049],
                        [ -8094,  -7296],
                        [ -8289,  -7514],
                        [ -8461,  -7704],
                        [ -8617,  -7876],
                        [ -8729,  -8001],
                        [ -8722,  -8008],
                        [ -8564,  -7863],
                        [ -8251,  -7563],
                        [ -7774,  -7099],
                        [ -7094,  -6433],
                        [ -6203,  -5554],
                        [ -5194,  -4558],
                        [ -4180,  -3551],
                        [ -3174,  -2551],
                        [ -2186,  -1563],
                        [ -1233,   -606],
                        [  -331,    302],
                        [   514,   1155],
                        [  1293,   1941],
                        [  1998,   2650],
                        [  2623,   3274],
                        [  3162,   3811],
                        [  3612,   4254],
                        [  3972,   4603],
                        [  4238,   4856],
                        [  4413,   5012],
                        [  4497,   5076],
                        [  4494,   5047],
                        [  4407,   4932],
                        [  4241,   4734],
                        [  4000,   4459],
                        [  3690,   4115],
                        [  3317,   3714],
                        [  2887,   3262],
                        [  2407,   2776],
                        [  1881,   2260],
                        [  1319,   1720],
                        [   725,   1163],
                        [   107,    584],
                        [  -530,     -9],
                        [ -1179,   -625],
                        [ -1834,  -1255],
                        [ -2490,  -1897],
                        [ -3140,  -2546],
                        [ -3780,  -3195],
                        [ -4405,  -3842],
                        [ -5012,  -4487],
                        [ -5593,  -5122],
                        [ -6147,  -5741],
                        [ -6671,  -6342],
                        [ -7161,  -6914],
                        [ -7613,  -7453],
                        [ -8024,  -7953],
                        [ -8392,  -8411],
                        [ -8714,  -8824],
                        [ -8989,  -9191],
                        [ -9215,  -9510],
                        [ -9392,  -9783],
                        [ -9521, -10007],
                        [ -9604, -10183],
                        [ -9642, -10313],
                        [ -9637, -10395],
                        [ -9589, -10432],
                        [ -9501, -10424],
                        [ -9377, -10375],
                        [ -9218, -10284],
                        [ -9038, -10155],
                        [ -8841,  -9989],
                        [ -8634,  -9788],
                        [ -8422,  -9557],
                        [ -8205,  -9295],
                        [ -7989,  -9008],
                        [ -7758,  -8699],
                        [ -7516,  -8369],
                        [ -7252,  -8020],
                        [ -6970,  -7655],
                        [ -6672,  -7280],
                        [ -6362,  -6897],
                        [ -6064,  -6533],
                        [ -5778,  -6187],
                        [ -5560,  -5916],
                        [ -5407,  -5717],
                        [ -5328,  -5600],
                        [ -5325,  -5566],
                        [ -5360,  -5577],
                        [ -5435,  -5636],
                        [ -5474,  -5667],
                        [ -5482,  -5675],
                        [ -5454,  -5652],
                        [ -5389,  -5600],
                        [ -5291,  -5518],
                        [ -5157,  -5406],
                        [ -4993,  -5267],
                        [ -4798,  -5101],
                        [ -4577,  -4913],
                        [ -4330,  -4701],
                        [ -4063,  -4471],
                        [ -3773,  -4222],
                        [ -3468,  -3958],
                        [ -3146,  -3677],
                        [ -2815,  -3387],
                        [ -2471,  -3081],
                        [ -2120,  -2767],
                        [ -1760,  -2442],
                        [ -1394,  -2110],
                        [ -1020,  -1769],
                        [  -636,  -1422],
                        [  -244,  -1068],
                        [   157,   -709],
                        [   566,   -344],
                        [   985,     25],
                        [  1411,    397],
                        [  1841,    774],
                        [  2276,   1154],
                        [  2709,   1540],
                        [  3140,   1932],
                        [  3566,   2329],
                        [  3986,   2732],
                        [  4406,   3140],
                        [  4824,   3549],
                        [  5246,   3959],
                        [  5669,   4366],
                        [  6093,   4769],
                        [  6515,   5168],
                        [  6929,   5556],
                        [  7333,   5934],
                        [  7728,   6307],
                        [  8084,   6644],
                        [  8348,   6893],
                        [  8498,   7035],
                        [  8534,   7068],
                        [  8437,   6976],
                        [  8163,   6714],
                        [  7688,   6257],
                        [  7081,   5672],
                        [  6420,   5039],
                        [  5716,   4366],
                        [  4973,   3658],
                        [  4209,   2932],
                        [  3436,   2198],
                        [  2659,   1467],
                        [  1886,    745],
                        [  1124,     41],
                        [   380,   -637],
                        [  -340,  -1286],
                        [ -1030,  -1900],
                        [ -1689,  -2478],
                        [ -2313,  -3016],
                        [ -2899,  -3512],
                        [ -3447,  -3968],
                        [ -3955,  -4383],
                        [ -4427,  -4759],
                        [ -4858,  -5096],
                        [ -5254,  -5397],
                        [ -5613,  -5668],
                        [ -5939,  -5911],
                        [ -6230,  -6137],
                        [ -6492,  -6349],
                        [ -6723,  -6551],
                        [ -6927,  -6748],
                        [ -7102,  -6933],
                        [ -7252,  -7112],
                        [ -7377,  -7268],
                        [ -7479,  -7406],
                        [ -7559,  -7516],
                        [ -7616,  -7603],
                        [ -7651,  -7664],
                        [ -7666,  -7698],
                        [ -7660,  -7703],
                        [ -7634,  -7675],
                        [ -7588,  -7616],
                        [ -7522,  -7527],
                        [ -7438,  -7412],
                        [ -7334,  -7272],
                        [ -7215,  -7115],
                        [ -7078,  -6940],
                        [ -6928,  -6756],
                        [ -6766,  -6558],
                        [ -6592,  -6349],
                        [ -6407,  -6130],
                        [ -6215,  -5901],
                        [ -6013,  -5665],
                        [ -5804,  -5421],
                        [ -5588,  -5170],
                        [ -5365,  -4914],
                        [ -5137,  -4654],
                        [ -4907,  -4392],
                        [ -4674,  -4129],
                        [ -4436,  -3868],
                        [ -4194,  -3608],
                        [ -3941,  -3354],
                        [ -3678,  -3106],
                        [ -3404,  -2866],
                        [ -3121,  -2637],
                        [ -2835,  -2418],
                        [ -2547,  -2213],
                        [ -2280,  -2026],
                        [ -2033,  -1858],
                        [ -1812,  -1710],
                        [ -1617,  -1580],
                        [ -1444,  -1465],
                        [ -1298,  -1368],
                        [ -1125,  -1236],
                        [  -930,  -1074],
                        [  -691,   -858],
                        [  -406,   -588],
                        [   -84,   -271],
                        [   279,     93],
                        [   602,    427],
                        [   891,    734],
                        [  1107,    973],
                        [  1250,   1145],
                        [  1321,   1251],
                        [  1323,   1290],
                        [  1257,   1263],
                        [  1124,   1172],
                        [   930,   1020],
                        [   678,    808],
                        [   374,    545],
                        [    20,    230],
                        [  -374,   -128],
                        [  -806,   -527],
                        [ -1266,   -960],
                        [ -1752,  -1424],
                        [ -2252,  -1909],
                        [ -2767,  -2416],
                        [ -3288,  -2935],
                        [ -3812,  -3464],
                        [ -4336,  -3995],
                        [ -4856,  -4527],
                        [ -5369,  -5052],
                        [ -5873,  -5569],
                        [ -6363,  -6070],
                        [ -6836,  -6554],
                        [ -7289,  -7018],
                        [ -7719,  -7456],
                        [ -8119,  -7871],
                        [ -8486,  -8258],
                        [ -8815,  -8618],
                        [ -9105,  -8951],
                        [ -9360,  -9254],
                        [ -9578,  -9527],
                        [ -9770,  -9770],
                        [ -9931,  -9979],
                        [-10073, -10156],
                        [-10192, -10301],
                        [-10290, -10414],
                        [-10362, -10493],
                        [-10414, -10544],
                        [-10446, -10568],
                        [-10441, -10551],
                        [-10375, -10467],
                        [-10247, -10320],
                        [-10064, -10116],
                        [ -9812,  -9839],
                        [ -9447,  -9447],
                        [ -8938,  -8911],
                        [ -8325,  -8268],
                        [ -7668,  -7579],
                        [ -6976,  -6853],
                        [ -6260,  -6101],
                        [ -5536,  -5341],
                        [ -4821,  -4587],
                        [ -4125,  -3852],
                        [ -3454,  -3145],
                        [ -2821,  -2479],
                        [ -2234,  -1864],
                        [ -1701,  -1306],
                        [ -1224,   -810],
                        [  -813,   -383],
                        [  -467,    -27],
                        [  -190,    256],
                        [    19,    465],
                        [   158,    601],
                        [   232,    666],
                        [   240,    662],
                        [   189,    596],
                        [    82,    469],
                        [   -76,    296],
                        [  -280,     80],
                        [  -524,   -163],
                        [  -803,   -431],
                        [ -1110,   -717],
                        [ -1440,  -1013],
                        [ -1787,  -1321],
                        [ -2144,  -1636],
                        [ -2506,  -1962],
                        [ -2869,  -2298],
                        [ -3226,  -2637],
                        [ -3573,  -2975],
                        [ -3907,  -3314],
                        [ -4223,  -3650],
                        [ -4518,  -3983],
                        [ -4789,  -4310],
                        [ -5032,  -4626],
                        [ -5246,  -4929],
                        [ -5428,  -5207],
                        [ -5578,  -5458],
                        [ -5692,  -5675],
                        [ -5768,  -5854],
                        [ -5808,  -5995],
                        [ -5809,  -6096],
                        [ -5774,  -6159],
                        [ -5701,  -6182],
                        [ -5593,  -6168],
                        [ -5453,  -6117],
                        [ -5280,  -6029],
                        [ -5080,  -5907],
                        [ -4854,  -5754],
                        [ -4604,  -5571],
                        [ -4336,  -5362],
                        [ -4050,  -5127],
                        [ -3758,  -4870],
                        [ -3463,  -4595],
                        [ -3172,  -4303],
                        [ -2888,  -3998],
                        [ -2617,  -3682],
                        [ -2360,  -3359],
                        [ -2113,  -3032],
                        [ -1872,  -2701],
                        [ -1632,  -2368],
                        [ -1395,  -2037],
                        [ -1163,  -1712],
                        [  -936,  -1395],
                        [  -744,  -1116],
                        [  -585,   -875],
                        [  -506,   -721],
                        [  -503,   -649],
                        [  -584,   -670],
                        [  -750,   -783],
                        [  -965,   -956],
                        [ -1233,  -1190],
                        [ -1471,  -1407],
                        [ -1688,  -1610],
                        [ -1869,  -1788],
                        [ -2015,  -1940],
                        [ -2120,  -2060],
                        [ -2182,  -2144],
                        [ -2199,  -2193],
                        [ -2172,  -2204],
                        [ -2101,  -2177],
                        [ -1983,  -2109],
                        [ -1822,  -2004],
                        [ -1619,  -1861],
                        [ -1376,  -1681],
                        [ -1092,  -1463],
                        [  -774,  -1211],
                        [  -423,   -924],
                        [   -41,   -606],
                        [   370,   -257],
                        [   807,    119],
                        [  1269,    522],
                        [  1754,    947],
                        [  2262,   1395],
                        [  2788,   1858],
                        [  3330,   2338],
                        [  3883,   2828],
                        [  4447,   3330],
                        [  5010,   3836],
                        [  5572,   4345],
                        [  6121,   4856],
                        [  6654,   5364],
                        [  7167,   5868],
                        [  7658,   6364],
                        [  8129,   6848],
                        [  8578,   7318],
                        [  9008,   7767],
                        [  9419,   8193],
                        [  9805,   8592],
                        [ 10166,   8962],
                        [ 10493,   9297],
                        [ 10788,   9596],
                        [ 11044,   9858],
                        [ 11253,  10073],
                        [ 11415,  10244],
                        [ 11541,  10382],
                        [ 11633,  10489],
                        [ 11676,  10550],
                        [ 11622,  10518],
                        [ 11424,  10345],
                        [ 11085,  10034],
                        [ 10638,   9618],
                        [ 10090,   9103],
                        [  9450,   8499],
                        [  8734,   7820],
                        [  7957,   7079],
                        [  7126,   6286],
                        [  6253,   5454],
                        [  5352,   4594],
                        [  4431,   3718],
                        [  3503,   2836],
                        [  2576,   1955],
                        [  1658,   1084],
                        [   757,    232],
                        [  -118,   -596],
                        [  -964,  -1396],
                        [ -1772,  -2160],
                        [ -2540,  -2885],
                        [ -3263,  -3569],
                        [ -3940,  -4210],
                        [ -4569,  -4808],
                        [ -5148,  -5362],
                        [ -5676,  -5877],
                        [ -6154,  -6355],
                        [ -6579,  -6796],
                        [ -6953,  -7202],
                        [ -7276,  -7573],
                        [ -7549,  -7910],
                        [ -7774,  -8202],
                        [ -7951,  -8452],
                        [ -8082,  -8652],
                        [ -8169,  -8806],
                        [ -8212,  -8910],
                        [ -8214,  -8968],
                        [ -8175,  -8969],
                        [ -8097,  -8919],
                        [ -7985,  -8816],
                        [ -7839,  -8661],
                        [ -7661,  -8463],
                        [ -7456,  -8223],
                        [ -7225,  -7955],
                        [ -6970,  -7659],
                        [ -6699,  -7345],
                        [ -6411,  -7013],
                        [ -6111,  -6666],
                        [ -5800,  -6309],
                        [ -5484,  -5944],
                        [ -5163,  -5574],
                        [ -4842,  -5202],
                        [ -4521,  -4832],
                        [ -4204,  -4466],
                        [ -3893,  -4106],
                        [ -3590,  -3754],
                        [ -3296,  -3413],
                        [ -3012,  -3087],
                        [ -2739,  -2776],
                        [ -2473,  -2481],
                        [ -2218,  -2207],
                        [ -1971,  -1954],
                        [ -1732,  -1723],
                        [ -1504,  -1516],
                        [ -1285,  -1333],
                        [ -1089,  -1177],
                        [  -917,  -1050],
                        [  -770,   -949],
                        [  -648,   -874],
                        [  -545,   -817],
                        [  -462,   -778],
                        [  -353,   -712],
                        [  -223,   -619],
                        [   -51,   -483],
                        [   159,   -302],
                        [   415,    -72],
                        [   717,    207],
                        [   997,    471],
                        [  1263,    726],
                        [  1479,    936],
                        [  1646,   1102],
                        [  1763,   1221],
                        [  1831,   1295],
                        [  1846,   1320],
                        [  1812,   1298],
                        [  1730,   1230],
                        [  1601,   1118],
                        [  1432,    966],
                        [  1221,    775],
                        [   977,    550],
                        [   702,    293],
                        [   402,     11],
                        [    80,   -297],
                        [  -254,   -620],
                        [  -603,   -959],
                        [  -956,  -1306],
                        [ -1313,  -1659],
                        [ -1670,  -2013],
                        [ -2024,  -2364],
                        [ -2373,  -2710],
                        [ -2714,  -3045],
                        [ -3042,  -3366],
                        [ -3357,  -3673],
                        [ -3654,  -3959],
                        [ -3930,  -4226],
                        [ -4175,  -4468],
                        [ -4391,  -4687],
                        [ -4570,  -4879],
                        [ -4713,  -5045],
                        [ -4823,  -5185],
                        [ -4900,  -5298],
                        [ -4955,  -5382],
                        [ -4985,  -5438],
                        [ -4998,  -5466],
                        [ -4994,  -5465],
                        [ -4973,  -5436],
                        [ -4934,  -5380],
                        [ -4880,  -5300],
                        [ -4810,  -5195],
                        [ -4734,  -5078],
                        [ -4684,  -4981],
                        [ -4685,  -4930],
                        [ -4742,  -4931],
                        [ -4841,  -4972],
                        [ -4943,  -5013],
                        [ -4985,  -4993],
                        [ -4936,  -4881],
                        [ -4807,  -4691],
                        [ -4607,  -4431],
                        [ -4344,  -4108],
                        [ -4032,  -3737],
                        [ -3681,  -3327],
                        [ -3301,  -2890],
                        [ -2899,  -2434],
                        [ -2487,  -1970],
                        [ -2072,  -1508],
                        [ -1662,  -1054],
                        [ -1262,   -616],
                        [  -880,   -201],
                        [  -520,    188],
                        [  -186,    546],
                        [   119,    870],
                        [   391,   1159],
                        [   632,   1412],
                        [   840,   1629],
                        [  1018,   1811],
                        [  1166,   1960],
                        [  1289,   2082],
                        [  1386,   2180],
                        [  1463,   2260],
                        [  1521,   2327],
                        [  1563,   2386],
                        [  1595,   2439],
                        [  1619,   2490],
                        [  1639,   2543],
                        [  1657,   2591],
                        [  1678,   2638],
                        [  1703,   2685],
                        [  1736,   2735],
                        [  1778,   2781],
                        [  1831,   2828],
                        [  1896,   2871],
                        [  1974,   2910],
                        [  2068,   2949],
                        [  2177,   2988],
                        [  2302,   3036],
                        [  2444,   3096],
                        [  2602,   3170],
                        [  2776,   3264],
                        [  2966,   3375],
                        [  3171,   3506],
                        [  3390,   3654],
                        [  3621,   3819],
                        [  3863,   4000],
                        [  4115,   4195],
                        [  4375,   4403],
                        [  4639,   4622],
                        [  4906,   4849],
                        [  5175,   5084],
                        [  5441,   5323],
                        [  5704,   5565],
                        [  5957,   5805],
                        [  6200,   6044],
                        [  6429,   6278],
                        [  6641,   6505],
                        [  6832,   6724],
                        [  7000,   6933],
                        [  7144,   7130],
                        [  7268,   7316],
                        [  7375,   7490],
                        [  7461,   7650],
                        [  7529,   7792],
                        [  7580,   7918],
                        [  7590,   8001],
                        [  7561,   8043],
                        [  7469,   8018],
                        [  7317,   7927],
                        [  7096,   7760],
                        [  6807,   7519],
                        [  6472,   7222],
                        [  6090,   6870],
                        [  5725,   6525],
                        [  5374,   6184],
                        [  5051,   5862],
                        [  4757,   5559],
                        [  4506,   5289],
                        [  4296,   5051],
                        [  4134,   4854],
                        [  4022,   4698],
                        [  3963,   4587],
                        [  3958,   4523],
                        [  4006,   4508],
                        [  4109,   4541],
                        [  4262,   4623],
                        [  4468,   4754],
                        [  4720,   4930],
                        [  5017,   5153],
                        [  5355,   5416],
                        [  5732,   5721],
                        [  6143,   6060],
                        [  6585,   6434],
                        [  7052,   6836],
                        [  7543,   7264],
                        [  8051,   7710],
                        [  8574,   8173],
                        [  9102,   8647],
                        [  9634,   9128],
                        [ 10154,   9608],
                        [ 10662,  10086],
                        [ 11142,  10552],
                        [ 11594,  11006],
                        [ 12010,  11439],
                        [ 12388,  11850],
                        [ 12728,  12231],
                        [ 13027,  12580],
                        [ 13288,  12890],
                        [ 13510,  13158],
                        [ 13689,  13380],
                        [ 13819,  13553],
                        [ 13903,  13674],
                        [ 13935,  13740],
                        [ 13913,  13750],
                        [ 13865,  13730],
                        [ 13843,  13735],
                        [ 13878,  13795],
                        [ 13970,  13911],
                        [ 14111,  14073],
                        [ 14263,  14247],
                        [ 14348,  14353],
                        [ 14299,  14325],
                        [ 14114,  14161],
                        [ 13803,  13872],
                        [ 13371,  13462],
                        [ 12835,  12944],
                        [ 12205,  12330],
                        [ 11490,  11629],
                        [ 10706,  10853],
                        [  9863,  10017],
                        [  8974,   9132],
                        [  8050,   8210],
                        [  7105,   7261],
                        [  6148,   6299],
                        [  5190,   5334],
                        [  4242,   4374],
                        [  3312,   3426],
                        [  2410,   2504],
                        [  1542,   1612],
                        [   714,    756],
                        [   -67,    -58],
                        [  -800,   -825],
                        [ -1480,  -1543],
                        [ -2106,  -2211],
                        [ -2674,  -2826],
                        [ -3184,  -3388],
                        [ -3634,  -3896],
                        [ -4024,  -4353],
                        [ -4357,  -4761],
                        [ -4630,  -5116],
                        [ -4849,  -5418],
                        [ -5014,  -5665],
                        [ -5127,  -5858],
                        [ -5190,  -5996],
                        [ -5206,  -6081],
                        [ -5177,  -6105],
                        [ -5107,  -6074],
                        [ -4998,  -5987],
                        [ -4855,  -5848],
                        [ -4681,  -5662],
                        [ -4480,  -5433],
                        [ -4256,  -5174],
                        [ -4011,  -4889],
                        [ -3751,  -4586],
                        [ -3479,  -4267],
                        [ -3200,  -3939],
                        [ -2914,  -3605],
                        [ -2628,  -3269],
                        [ -2345,  -2935],
                        [ -2068,  -2606],
                        [ -1799,  -2286],
                        [ -1541,  -1978],
                        [ -1298,  -1684],
                        [ -1071,  -1409],
                        [  -861,  -1151],
                        [  -670,   -914],
                        [  -499,   -700],
                        [  -349,   -509],
                        [  -223,   -342],
                        [  -116,   -200],
                        [   -30,    -84],
                        [    42,     10],
                        [    99,     79],
                        [   141,    122],
                        [   168,    138],
                        [   181,    133],
                        [   183,    109],
                        [   178,     72],
                        [   168,     24],
                        [   178,     -7],
                        [   208,    -21],
                        [   267,     -9],
                        [   353,     30],
                        [   487,    116],
                        [   666,    249],
                        [   856,    392],
                        [  1057,    550],
                        [  1246,    700],
                        [  1426,    842],
                        [  1588,    970],
                        [  1733,   1086],
                        [  1856,   1183],
                        [  1957,   1263],
                        [  2034,   1321],
                        [  2087,   1361],
                        [  2115,   1379],
                        [  2120,   1378],
                        [  2102,   1359],
                        [  2063,   1320],
                        [  2006,   1267],
                        [  1931,   1198],
                        [  1842,   1117],
                        [  1740,   1025],
                        [  1627,    925],
                        [  1507,    818],
                        [  1380,    709],
                        [  1249,    595],
                        [  1115,    483],
                        [   979,    371],
                        [   844,    262],
                        [   712,    158],
                        [   587,     61],
                        [   470,    -29],
                        [   370,   -110],
                        [   286,   -179],
                        [   223,   -235],
                        [   179,   -279],
                        [   154,   -308],
                        [   150,   -323],
                        [   155,   -323],
                        [   171,   -309],
                        [   195,   -278],
                        [   226,   -232],
                        [   265,   -170],
                        [   310,    -94],
                        [   362,     -3],
                        [   419,    102],
                        [   434,    169],
                        [   332,    127],
                        [    83,    -59],
                        [  -316,   -388],
                        [  -858,   -860],
                        [ -1515,  -1444],
                        [ -2182,  -2040],
                        [ -2768,  -2555],
                        [ -3254,  -2974],
                        [ -3647,  -3302],
                        [ -3948,  -3542],
                        [ -4164,  -3699],
                        [ -4302,  -3777],
                        [ -4366,  -3785],
                        [ -4364,  -3725],
                        [ -4301,  -3607],
                        [ -4182,  -3437],
                        [ -4016,  -3222],
                        [ -3808,  -2967],
                        [ -3564,  -2682],
                        [ -3291,  -2368],
                        [ -2993,  -2034],
                        [ -2676,  -1683],
                        [ -2347,  -1319],
                        [ -2005,   -947],
                        [ -1657,   -570],
                        [ -1302,   -191],
                        [  -943,    189],
                        [  -580,    570],
                        [  -216,    947],
                        [   148,   1322],
                        [   512,   1692],
                        [   875,   2061],
                        [  1238,   2430],
                        [  1600,   2803],
                        [  1961,   3181],
                        [  2323,   3560],
                        [  2684,   3942],
                        [  3044,   4323],
                        [  3403,   4704],
                        [  3760,   5077],
                        [  4116,   5443],
                        [  4469,   5794],
                        [  4817,   6131],
                        [  5162,   6452],
                        [  5501,   6758],
                        [  5834,   7050],
                        [  6160,   7331],
                        [  6476,   7604],
                        [  6784,   7871],
                        [  7080,   8129],
                        [  7365,   8378],
                        [  7635,   8619],
                        [  7891,   8851],
                        [  8132,   9072],
                        [  8358,   9282],
                        [  8568,   9479],
                        [  8761,   9666],
                        [  8938,   9839],
                        [  9097,   9997],
                        [  9237,  10141],
                        [  9360,  10268],
                        [  9466,  10380],
                        [  9557,  10473],
                        [  9634,  10549],
                        [  9696,  10607],
                        [  9740,  10647],
                        [  9765,  10669],
                        [  9765,  10673],
                        [  9744,  10661],
                        [  9699,  10634],
                        [  9631,  10591],
                        [  9541,  10531],
                        [  9433,  10456],
                        [  9297,  10356],
                        [  9137,  10233],
                        [  8952,  10083],
                        [  8743,   9909],
                        [  8500,   9698],
                        [  8225,   9452],
                        [  7915,   9166],
                        [  7572,   8841],
                        [  7230,   8511],
                        [  6887,   8175],
                        [  6558,   7845],
                        [  6242,   7522],
                        [  5954,   7222],
                        [  5694,   6940],
                        [  5471,   6690],
                        [  5285,   6470],
                        [  5142,   6287],
                        [  5040,   6142],
                        [  4984,   6037],
                        [  4972,   5973],
                        [  5003,   5949],
                        [  5077,   5966],
                        [  5190,   6021],
                        [  5341,   6114],
                        [  5526,   6241],
                        [  5741,   6399],
                        [  5980,   6585],
                        [  6241,   6795],
                        [  6516,   7023],
                        [  6806,   7267],
                        [  7098,   7521],
                        [  7394,   7781],
                        [  7681,   8042],
                        [  7960,   8301],
                        [  8216,   8548],
                        [  8447,   8782],
                        [  8643,   8994],
                        [  8800,   9180],
                        [  8914,   9335],
                        [  8980,   9455],
                        [  8999,   9536],
                        [  8970,   9573],
                        [  8895,   9565],
                        [  8773,   9507],
                        [  8599,   9397],
                        [  8374,   9236],
                        [  8105,   9023],
                        [  7781,   8751],
                        [  7412,   8426],
                        [  7066,   8119],
                        [  6827,   7915],
                        [  6726,   7841],
                        [  6767,   7902],
                        [  6953,   8104],
                        [  7260,   8423],
                        [  7578,   8749],
                        [  7792,   8968],
                        [  7880,   9059],
                        [  7856,   9035],
                        [  7720,   8897],
                        [  7482,   8649],
                        [  7147,   8299],
                        [  6725,   7854],
                        [  6226,   7325],
                        [  5658,   6720],
                        [  5033,   6051],
                        [  4359,   5328],
                        [  3647,   4561],
                        [  2910,   3764],
                        [  2156,   2942],
                        [  1394,   2109],
                        [   635,   1272],
                        [  -112,    443],
                        [  -839,   -372],
                        [ -1541,  -1164],
                        [ -2212,  -1927],
                        [ -2847,  -2654],
                        [ -3443,  -3342],
                        [ -3995,  -3980],
                        [ -4502,  -4568],
                        [ -4961,  -5101],
                        [ -5371,  -5578],
                        [ -5731,  -6005],
                        [ -6043,  -6382],
                        [ -6307,  -6715],
                        [ -6524,  -7005],
                        [ -6698,  -7251],
                        [ -6829,  -7456],
                        [ -6921,  -7615],
                        [ -6976,  -7733],
                        [ -6996,  -7807],
                        [ -6985,  -7838],
                        [ -6946,  -7828],
                        [ -6883,  -7779],
                        [ -6798,  -7696],
                        [ -6696,  -7582],
                        [ -6578,  -7447],
                        [ -6450,  -7294],
                        [ -6312,  -7129],
                        [ -6169,  -6956],
                        [ -6022,  -6779],
                        [ -5874,  -6600],
                        [ -5730,  -6424],
                        [ -5591,  -6256],
                        [ -5459,  -6095],
                        [ -5338,  -5945],
                        [ -5229,  -5808],
                        [ -5135,  -5687],
                        [ -5055,  -5582],
                        [ -4990,  -5494],
                        [ -4945,  -5424],
                        [ -4918,  -5373],
                        [ -4916,  -5338],
                        [ -4936,  -5320],
                        [ -4978,  -5319],
                        [ -5042,  -5333],
                        [ -5114,  -5361],
                        [ -5196,  -5401],
                        [ -5277,  -5454],
                        [ -5357,  -5517],
                        [ -5431,  -5586],
                        [ -5496,  -5661],
                        [ -5552,  -5735],
                        [ -5597,  -5810],
                        [ -5633,  -5885],
                        [ -5659,  -5958],
                        [ -5674,  -6026],
                        [ -5676,  -6087],
                        [ -5638,  -6111],
                        [ -5561,  -6099],
                        [ -5444,  -6048],
                        [ -5285,  -5956],
                        [ -5100,  -5838],
                        [ -4885,  -5688],
                        [ -4654,  -5520],
                        [ -4405,  -5330],
                        [ -4148,  -5128],
                        [ -3883,  -4912],
                        [ -3618,  -4691],
                        [ -3353,  -4464],
                        [ -3095,  -4237],
                        [ -2843,  -4011],
                        [ -2602,  -3790],
                        [ -2373,  -3574],
                        [ -2159,  -3366],
                        [ -1959,  -3166],
                        [ -1776,  -2975],
                        [ -1610,  -2795],
                        [ -1459,  -2626],
                        [ -1325,  -2468],
                        [ -1206,  -2321],
                        [ -1102,  -2186],
                        [ -1013,  -2061],
                        [  -939,  -1948],
                        [  -878,  -1846],
                        [  -830,  -1757],
                        [  -791,  -1678],
                        [  -761,  -1610],
                        [  -734,  -1549],
                        [  -711,  -1497],
                        [  -688,  -1449],
                        [  -666,  -1405],
                        [  -642,  -1363],
                        [  -616,  -1324],
                        [  -591,  -1285],
                        [  -570,  -1247],
                        [  -549,  -1209],
                        [  -529,  -1168],
                        [  -511,  -1125],
                        [  -499,  -1085],
                        [  -483,  -1034],
                        [  -475,   -988],
                        [  -559,  -1029],
                        [  -820,  -1243],
                        [ -1279,  -1651],
                        [ -1939,  -2257],
                        [ -2809,  -3071],
                        [ -3867,  -4072],
                        [ -4983,  -5135],
                        [ -6028,  -6129],
                        [ -6973,  -7026],
                        [ -7823,  -7832],
                        [ -8572,  -8539],
                        [ -9217,  -9145],
                        [ -9760,  -9647],
                        [-10202, -10047],
                        [-10542, -10345],
                        [-10785, -10544],
                        [-10932, -10647],
                        [-10989, -10659],
                        [-10959, -10584],
                        [-10849, -10429],
                        [-10662, -10198],
                        [-10407,  -9896],
                        [-10089,  -9531],
                        [ -9715,  -9108],
                        [ -9291,  -8636],
                        [ -8823,  -8118],
                        [ -8316,  -7561],
                        [ -7773,  -6970],
                        [ -7202,  -6356],
                        [ -6606,  -5724],
                        [ -5990,  -5083],
                        [ -5359,  -4437],
                        [ -4718,  -3789],
                        [ -4070,  -3141],
                        [ -3419,  -2487],
                        [ -2768,  -1829],
                        [ -2121,  -1169],
                        [ -1480,   -508],
                        [  -850,    149],
                        [  -230,    798],
                        [   374,   1431],
                        [   960,   2048],
                        [  1527,   2640],
                        [  2070,   3207],
                        [  2589,   3744],
                        [  3083,   4250],
                        [  3547,   4723],
                        [  3982,   5163],
                        [  4384,   5572],
                        [  4754,   5949],
                        [  5089,   6292],
                        [  5388,   6602],
                        [  5651,   6877],
                        [  5878,   7121],
                        [  6071,   7331],
                        [  6229,   7509],
                        [  6355,   7655],
                        [  6450,   7769],
                        [  6514,   7854],
                        [  6550,   7909],
                        [  6559,   7936],
                        [  6545,   7936],
                        [  6514,   7909],
                        [  6469,   7859],
                        [  6417,   7784],
                        [  6359,   7686],
                        [  6293,   7568],
                        [  6219,   7433],
                        [  6128,   7279],
                        [  6021,   7113],
                        [  5896,   6933],
                        [  5750,   6742],
                        [  5588,   6543],
                        [  5413,   6337],
                        [  5237,   6136],
                        [  5062,   5942],
                        [  4908,   5772],
                        [  4772,   5626],
                        [  4645,   5490],
                        [  4526,   5365],
                        [  4383,   5218],
                        [  4221,   5051],
                        [  4038,   4865],
                        [  3837,   4661],
                        [  3629,   4448],
                        [  3412,   4227],
                        [  3199,   4006],
                        [  2988,   3787],
                        [  2790,   3578],
                        [  2602,   3378],
                        [  2432,   3192],
                        [  2278,   3023],
                        [  2145,   2871],
                        [  2030,   2738],
                        [  1937,   2625],
                        [  1863,   2530],
                        [  1808,   2453],
                        [  1770,   2393],
                        [  1747,   2347],
                        [  1735,   2312],
                        [  1729,   2288],
                        [  1727,   2269],
                        [  1723,   2253],
                        [  1716,   2237],
                        [  1701,   2217],
                        [  1674,   2191],
                        [  1629,   2155],
                        [  1566,   2106],
                        [  1476,   2039],
                        [  1359,   1953],
                        [  1210,   1840],
                        [  1026,   1699],
                        [   803,   1524],
                        [   538,   1315],
                        [   232,   1068],
                        [  -116,    782],
                        [  -503,    457],
                        [  -929,     93],
                        [ -1393,   -311],
                        [ -1893,   -752],
                        [ -2421,  -1229],
                        [ -2988,  -1749],
                        [ -3568,  -2289],
                        [ -4065,  -2756],
                        [ -4398,  -3066],
                        [ -4545,  -3200],
                        [ -4498,  -3149],
                        [ -4235,  -2890],
                        [ -3769,  -2434],
                        [ -3229,  -1909],
                        [ -2744,  -1443],
                        [ -2337,  -1060],
                        [ -1999,   -748],
                        [ -1736,   -518],
                        [ -1547,   -368],
                        [ -1430,   -300],
                        [ -1380,   -309],
                        [ -1398,   -392],
                        [ -1476,   -545],
                        [ -1613,   -763],
                        [ -1800,  -1038],
                        [ -2031,  -1364],
                        [ -2301,  -1735],
                        [ -2602,  -2141],
                        [ -2927,  -2576],
                        [ -3270,  -3034],
                        [ -3622,  -3504],
                        [ -3980,  -3982],
                        [ -4337,  -4460],
                        [ -4688,  -4933],
                        [ -5030,  -5393],
                        [ -5359,  -5835],
                        [ -5673,  -6247],
                        [ -5966,  -6624],
                        [ -6240,  -6965],
                        [ -6491,  -7265],
                        [ -6719,  -7534],
                        [ -6923,  -7767],
                        [ -7105,  -7979],
                        [ -7265,  -8170],
                        [ -7403,  -8341],
                        [ -7521,  -8495],
                        [ -7620,  -8628],
                        [ -7703,  -8745],
                        [ -7771,  -8842],
                        [ -7826,  -8922],
                        [ -7869,  -8985],
                        [ -7902,  -9035],
                        [ -7928,  -9071],
                        [ -7948,  -9094],
                        [ -7962,  -9107],
                        [ -7972,  -9114],
                        [ -7980,  -9116],
                        [ -7985,  -9116],
                        [ -7989,  -9115],
                        [ -7993,  -9113],
                        [ -7996,  -9115],
                        [ -8002,  -9120],
                        [ -8009,  -9130],
                        [ -8020,  -9146],
                        [ -8036,  -9167],
                        [ -8056,  -9195],
                        [ -8081,  -9229],
                        [ -8110,  -9270],
                        [ -8148,  -9315],
                        [ -8193,  -9364],
                        [ -8253,  -9415],
                        [ -8327,  -9469],
                        [ -8414,  -9520],
                        [ -8514,  -9570],
                        [ -8614,  -9617],
                        [ -8712,  -9657],
                        [ -8791,  -9690],
                        [ -8852,  -9714],
                        [ -8888,  -9726],
                        [ -8897,  -9726],
                        [ -8887,  -9719],
                        [ -8857,  -9705],
                        [ -8838,  -9711],
                        [ -8825,  -9734],
                        [ -8825,  -9777],
                        [ -8834,  -9837],
                        [ -8817,  -9878],
                        [ -8777,  -9901],
                        [ -8675,  -9865],
                        [ -8514,  -9774],
                        [ -8300,  -9629],
                        [ -8032,  -9432],
                        [ -7721,  -9189],
                        [ -7368,  -8902],
                        [ -6985,  -8581],
                        [ -6573,  -8226],
                        [ -6143,  -7847],
                        [ -5694,  -7444],
                        [ -5239,  -7028],
                        [ -4778,  -6598],
                        [ -4320,  -6165],
                        [ -3866,  -5727],
                        [ -3426,  -5294],
                        [ -2997,  -4864],
                        [ -2588,  -4445],
                        [ -2199,  -4037],
                        [ -1831,  -3643],
                        [ -1487,  -3266],
                        [ -1165,  -2907],
                        [  -867,  -2568],
                        [  -593,  -2251],
                        [  -345,  -1956],
                        [  -119,  -1685],
                        [    80,  -1439],
                        [   257,  -1219],
                        [   409,  -1023],
                        [   540,   -850],
                        [   648,   -699],
                        [   739,   -566],
                        [   813,   -453],
                        [   877,   -353],
                        [   931,   -268],
                        [   976,   -196],
                        [  1011,   -136],
                        [  1040,    -85],
                        [  1064,    -42],
                        [  1079,    -10],
                        [  1086,     13],
                        [  1098,     41],
                        [  1085,     45],
                        [   957,    -64],
                        [   645,   -356],
                        [   141,   -837],
                        [  -563,  -1515],
                        [ -1489,  -2416],
                        [ -2628,  -3530],
                        [ -3846,  -4726],
                        [ -5013,  -5874],
                        [ -6106,  -6949],
                        [ -7124,  -7954],
                        [ -8056,  -8872],
                        [ -8892,  -9693],
                        [ -9630, -10412],
                        [-10268, -11027],
                        [-10799, -11533],
                        [-11224, -11928],
                        [-11542, -12212],
                        [-11756, -12388],
                        [-11867, -12459],
                        [-11881, -12427],
                        [-11802, -12298],
                        [-11633, -12077],
                        [-11384, -11771],
                        [-11061, -11386],
                        [-10669, -10931],
                        [-10217, -10411],
                        [ -9711,  -9836],
                        [ -9159,  -9213],
                        [ -8565,  -8558],
                        [ -7939,  -7877],
                        [ -7287,  -7184],
                        [ -6615,  -6487],
                        [ -5930,  -5789],
                        [ -5236,  -5098],
                        [ -4541,  -4405],
                        [ -3849,  -3715],
                        [ -3166,  -3026],
                        [ -2494,  -2340],
                        [ -1839,  -1663],
                        [ -1203,   -999],
                        [  -592,   -353],
                        [    -4,    271],
                        [   554,    871],
                        [  1081,   1444],
                        [  1575,   1986],
                        [  2035,   2496],
                        [  2457,   2967],
                        [  2841,   3400],
                        [  3187,   3794],
                        [  3493,   4148],
                        [  3759,   4459],
                        [  3984,   4730],
                        [  4169,   4961],
                        [  4316,   5154],
                        [  4427,   5310],
                        [  4502,   5429],
                        [  4547,   5514],
                        [  4561,   5568],
                        [  4550,   5592],
                        [  4513,   5588],
                        [  4460,   5558],
                        [  4388,   5506],
                        [  4311,   5432],
                        [  4232,   5340],
                        [  4159,   5230],
                        [  4096,   5106],
                        [  4040,   4969],
                        [  3994,   4823],
                        [  3946,   4669],
                        [  3894,   4507],
                        [  3832,   4342],
                        [  3761,   4175],
                        [  3683,   4011],
                        [  3599,   3849],
                        [  3545,   3726],
                        [  3520,   3642],
                        [  3551,   3621],
                        [  3637,   3665],
                        [  3763,   3756],
                        [  3930,   3898],
                        [  4078,   4026],
                        [  4210,   4145],
                        [  4300,   4230],
                        [  4349,   4281],
                        [  4364,   4302],
                        [  4344,   4293],
                        [  4295,   4258],
                        [  4214,   4197],
                        [  4111,   4115],
                        [  3983,   4010],
                        [  3836,   3888],
                        [  3669,   3748],
                        [  3487,   3595],
                        [  3287,   3426],
                        [  3077,   3244],
                        [  2853,   3049],
                        [  2619,   2843],
                        [  2373,   2624],
                        [  2117,   2392],
                        [  1847,   2147],
                        [  1562,   1888],
                        [  1261,   1615],
                        [   942,   1327],
                        [   604,   1021],
                        [   246,    700],
                        [  -132,    362],
                        [  -529,      7],
                        [  -947,   -364],
                        [ -1384,   -754],
                        [ -1838,  -1162],
                        [ -2311,  -1590],
                        [ -2801,  -2038],
                        [ -3313,  -2507],
                        [ -3846,  -2998],
                        [ -4404,  -3510],
                        [ -4981,  -4041],
                        [ -5576,  -4589],
                        [ -6186,  -5151],
                        [ -6808,  -5727],
                        [ -7435,  -6309],
                        [ -8062,  -6896],
                        [ -8697,  -7493],
                        [ -9302,  -8067],
                        [ -9785,  -8526],
                        [-10091,  -8818],
                        [-10211,  -8933],
                        [-10130,  -8855],
                        [ -9813,  -8549],
                        [ -9259,  -8011],
                        [ -8585,  -7358],
                        [ -7907,  -6705],
                        [ -7239,  -6067],
                        [ -6580,  -5443],
                        [ -5944,  -4847],
                        [ -5337,  -4286],
                        [ -4760,  -3767],
                        [ -4221,  -3291],
                        [ -3721,  -2865],
                        [ -3267,  -2490],
                        [ -2857,  -2166],
                        [ -2493,  -1893],
                        [ -2173,  -1671],
                        [ -1898,  -1497],
                        [ -1665,  -1369],
                        [ -1473,  -1285],
                        [ -1318,  -1241],
                        [ -1197,  -1232],
                        [ -1107,  -1255],
                        [ -1046,  -1305],
                        [ -1009,  -1380],
                        [  -996,  -1471],
                        [ -1003,  -1575],
                        [ -1028,  -1679],
                        [ -1068,  -1781],
                        [ -1122,  -1873],
                        [ -1187,  -1954],
                        [ -1263,  -2030],
                        [ -1346,  -2097],
                        [ -1437,  -2173],
                        [ -1535,  -2254],
                        [ -1640,  -2346],
                        [ -1750,  -2446],
                        [ -1866,  -2556],
                        [ -1987,  -2675],
                        [ -2113,  -2802],
                        [ -2245,  -2940],
                        [ -2381,  -3087],
                        [ -2521,  -3244],
                        [ -2663,  -3407],
                        [ -2808,  -3576],
                        [ -2953,  -3746],
                        [ -3098,  -3918],
                        [ -3241,  -4088],
                        [ -3382,  -4257],
                        [ -3518,  -4422],
                        [ -3648,  -4583],
                        [ -3772,  -4742],
                        [ -3887,  -4895],
                        [ -3995,  -5043],
                        [ -4094,  -5185],
                        [ -4185,  -5319],
                        [ -4266,  -5446],
                        [ -4336,  -5563],
                        [ -4396,  -5670],
                        [ -4448,  -5763],
                        [ -4493,  -5844],
                        [ -4539,  -5909],
                        [ -4586,  -5957],
                        [ -4633,  -5987],
                        [ -4682,  -5998],
                        [ -4721,  -5988],
                        [ -4749,  -5956],
                        [ -4749,  -5899],
                        [ -4721,  -5818],
                        [ -4658,  -5714],
                        [ -4561,  -5585],
                        [ -4450,  -5452],
                        [ -4323,  -5314],
                        [ -4229,  -5216],
                        [ -4164,  -5158],
                        [ -4136,  -5144],
                        [ -4145,  -5174],
                        [ -4151,  -5207],
                        [ -4158,  -5247],
                        [ -4098,  -5226],
                        [ -3978,  -5148],
                        [ -3800,  -5013],
                        [ -3561,  -4821],
                        [ -3272,  -4577],
                        [ -2933,  -4283],
                        [ -2555,  -3946],
                        [ -2138,  -3569],
                        [ -1693,  -3161],
                        [ -1224,  -2722],
                        [  -739,  -2264],
                        [  -241,  -1788],
                        [   260,  -1302],
                        [   762,   -809],
                        [  1255,   -318],
                        [  1736,    172],
                        [  2201,    652],
                        [  2646,   1123],
                        [  3070,   1576],
                        [  3473,   2013],
                        [  3850,   2429],
                        [  4205,   2823],
                        [  4534,   3191],
                        [  4836,   3533],
                        [  5111,   3846],
                        [  5359,   4132],
                        [  5576,   4388],
                        [  5763,   4613],
                        [  5920,   4812],
                        [  6045,   4982],
                        [  6147,   5129],
                        [  6222,   5252],
                        [  6286,   5357],
                        [  6335,   5442],
                        [  6377,   5511],
                        [  6407,   5563],
                        [  6433,   5603],
                        [  6453,   5630],
                        [  6465,   5642],
                        [  6472,   5643],
                        [  6481,   5644],
                        [  6460,   5611],
                        [  6338,   5476],
                        [  6081,   5207],
                        [  5691,   4805],
                        [  5153,   4257],
                        [  4432,   3525],
                        [  3521,   2602],
                        [  2526,   1594],
                        [  1545,    600],
                        [   594,   -366],
                        [  -325,  -1298],
                        [ -1194,  -2178],
                        [ -2002,  -2992],
                        [ -2744,  -3734],
                        [ -3412,  -4396],
                        [ -3998,  -4970],
                        [ -4498,  -5452],
                        [ -4910,  -5838],
                        [ -5232,  -6128],
                        [ -5463,  -6320],
                        [ -5605,  -6418],
                        [ -5662,  -6424],
                        [ -5634,  -6339],
                        [ -5528,  -6172],
                        [ -5350,  -5926],
                        [ -5105,  -5609],
                        [ -4799,  -5226],
                        [ -4439,  -4786],
                        [ -4032,  -4297],
                        [ -3584,  -3775],
                        [ -3101,  -3226],
                        [ -2593,  -2668],
                        [ -2064,  -2104],
                        [ -1521,  -1544],
                        [  -969,   -992],
                        [  -416,   -443],
                        [   134,     98],
                        [   676,    637],
                        [  1207,   1169],
                        [  1720,   1692],
                        [  2213,   2202],
                        [  2686,   2697],
                        [  3134,   3174],
                        [  3555,   3635],
                        [  3948,   4076],
                        [  4310,   4496],
                        [  4641,   4893],
                        [  4940,   5259],
                        [  5205,   5595],
                        [  5437,   5896],
                        [  5637,   6162],
                        [  5803,   6392],
                        [  5937,   6585],
                        [  6040,   6746],
                        [  6114,   6875],
                        [  6160,   6974],
                        [  6182,   7043],
                        [  6181,   7087],
                        [  6161,   7106],
                        [  6125,   7105],
                        [  6076,   7084],
                        [  6018,   7048],
                        [  5954,   6996],
                        [  5894,   6933],
                        [  5841,   6861],
                        [  5805,   6781],
                        [  5787,   6695],
                        [  5789,   6606],
                        [  5809,   6515],
                        [  5837,   6421],
                        [  5872,   6326],
                        [  5902,   6234],
                        [  5930,   6144],
                        [  5960,   6065],
                        [  5989,   5995],
                        [  6067,   5985],
                        [  6190,   6031],
                        [  6385,   6160],
                        [  6649,   6369],
                        [  6970,   6647],
                        [  7348,   6994],
                        [  7704,   7330],
                        [  8041,   7659],
                        [  8320,   7941],
                        [  8542,   8175],
                        [  8705,   8362],
                        [  8810,   8500],
                        [  8856,   8587],
                        [  8842,   8620],
                        [  8773,   8604],
                        [  8647,   8538],
                        [  8470,   8422],
                        [  8237,   8257],
                        [  7957,   8049],
                        [  7628,   7793],
                        [  7258,   7495],
                        [  6846,   7155],
                        [  6400,   6778],
                        [  5917,   6362],
                        [  5403,   5912],
                        [  4859,   5428],
                        [  4284,   4913],
                        [  3681,   4370],
                        [  3053,   3801],
                        [  2399,   3207],
                        [  1726,   2594],
                        [  1034,   1961],
                        [   332,   1316],
                        [  -379,    658],
                        [ -1090,     -7],
                        [ -1798,   -678],
                        [ -2500,  -1354],
                        [ -3194,  -2030],
                        [ -3881,  -2703],
                        [ -4560,  -3374],
                        [ -5234,  -4038],
                        [ -5900,  -4691],
                        [ -6550,  -5329],
                        [ -7183,  -5949],
                        [ -7796,  -6547],
                        [ -8380,  -7115],
                        [ -8933,  -7652],
                        [ -9457,  -8161],
                        [ -9915,  -8608],
                        [-10256,  -8941],
                        [-10459,  -9141],
                        [-10525,  -9211],
                        [-10436,  -9129],
                        [-10146,  -8852],
                        [ -9638,  -8361],
                        [ -8987,  -7729],
                        [ -8272,  -7036],
                        [ -7501,  -6290],
                        [ -6680,  -5497],
                        [ -5828,  -4677],
                        [ -4955,  -3842],
                        [ -4072,  -3002],
                        [ -3189,  -2167],
                        [ -2316,  -1348],
                        [ -1463,   -553],
                        [  -636,    211],
                        [   158,    939],
                        [   912,   1625],
                        [  1623,   2264],
                        [  2287,   2856],
                        [  2901,   3397],
                        [  3465,   3886],
                        [  3976,   4323],
                        [  4435,   4708],
                        [  4842,   5042],
                        [  5198,   5327],
                        [  5503,   5567],
                        [  5760,   5766],
                        [  5970,   5935],
                        [  6134,   6074],
                        [  6255,   6191],
                        [  6336,   6289],
                        [  6377,   6364],
                        [  6383,   6420],
                        [  6355,   6444],
                        [  6297,   6439],
                        [  6209,   6400],
                        [  6096,   6331],
                        [  5959,   6231],
                        [  5800,   6102],
                        [  5623,   5943],
                        [  5427,   5755],
                        [  5219,   5539],
                        [  4999,   5295],
                        [  4772,   5033],
                        [  4539,   4753],
                        [  4305,   4467],
                        [  4073,   4175],
                        [  3845,   3886],
                        [  3623,   3603],
                        [  3413,   3327],
                        [  3214,   3062],
                        [  3031,   2809],
                        [  2865,   2571],
                        [  2717,   2349],
                        [  2589,   2146],
                        [  2481,   1963],
                        [  2395,   1802],
                        [  2332,   1664],
                        [  2291,   1552],
                        [  2269,   1464],
                        [  2268,   1403],
                        [  2275,   1370],
                        [  2294,   1364],
                        [  2319,   1387],
                        [  2353,   1439],
                        [  2397,   1518],
                        [  2453,   1627],
                        [  2537,   1766],
                        [  2644,   1931],
                        [  2779,   2121],
                        [  2943,   2335],
                        [  3103,   2542],
                        [  3261,   2741],
                        [  3368,   2884],
                        [  3424,   2970],
                        [  3420,   2990],
                        [  3356,   2945],
                        [  3267,   2872],
                        [  3153,   2767],
                        [  3088,   2706],
                        [  3066,   2685],
                        [  3090,   2706],
                        [  3159,   2769],
                        [  3273,   2875],
                        [  3430,   3021],
                        [  3621,   3202],
                        [  3850,   3419],
                        [  4105,   3664],
                        [  4387,   3936],
                        [  4687,   4227],
                        [  5006,   4538],
                        [  5332,   4859],
                        [  5666,   5191],
                        [  5996,   5525],
                        [  6325,   5861],
                        [  6644,   6194],
                        [  6954,   6520],
                        [  7251,   6837],
                        [  7534,   7144],
                        [  7803,   7434],
                        [  8058,   7710],
                        [  8296,   7966],
                        [  8517,   8204],
                        [  8719,   8422],
                        [  8901,   8617],
                        [  9056,   8791],
                        [  9185,   8943],
                        [  9286,   9072],
                        [  9361,   9181],
                        [  9413,   9271],
                        [  9444,   9342],
                        [  9466,   9398],
                        [  9479,   9438],
                        [  9488,   9465],
                        [  9492,   9478],
                        [  9492,   9479],
                        [  9490,   9468],
                        [  9484,   9444],
                        [  9475,   9408],
                        [  9466,   9367],
                        [  9436,   9297],
                        [  9358,   9178],
                        [  9235,   9011],
                        [  9070,   8803],
                        [  8845,   8535],
                        [  8517,   8165],
                        [  8056,   7660],
                        [  7505,   7068],
                        [  6920,   6443],
                        [  6309,   5795],
                        [  5679,   5129],
                        [  5043,   4462],
                        [  4418,   3811],
                        [  3806,   3180],
                        [  3218,   2582],
                        [  2663,   2024],
                        [  2150,   1514],
                        [  1680,   1055],
                        [  1261,    654],
                        [   895,    314],
                        [   584,     34],
                        [   328,   -184],
                        [   129,   -339],
                        [   -17,   -436],
                        [  -111,   -475],
                        [  -157,   -462],
                        [  -157,   -399],
                        [  -116,   -292],
                        [   -40,   -146],
                        [    71,     26],
                        [   209,    220],
                        [   370,    423],
                        [   550,    632],
                        [   744,    839],
                        [   949,   1038],
                        [  1161,   1236],
                        [  1374,   1428],
                        [  1587,   1620],
                        [  1794,   1809],
                        [  1996,   1995],
                        [  2187,   2177],
                        [  2368,   2355],
                        [  2537,   2529],
                        [  2695,   2702],
                        [  2838,   2875],
                        [  2967,   3046],
                        [  3081,   3213],
                        [  3180,   3372],
                        [  3263,   3521],
                        [  3332,   3651],
                        [  3387,   3767],
                        [  3426,   3863],
                        [  3453,   3942],
                        [  3468,   4005],
                        [  3472,   4053],
                        [  3466,   4087],
                        [  3452,   4108],
                        [  3431,   4119],
                        [  3407,   4120],
                        [  3379,   4113],
                        [  3352,   4101],
                        [  3326,   4084],
                        [  3302,   4063],
                        [  3289,   4041],
                        [  3288,   4017],
                        [  3304,   3993],
                        [  3340,   3971],
                        [  3395,   3950],
                        [  3470,   3930],
                        [  3556,   3911],
                        [  3649,   3891],
                        [  3741,   3872],
                        [  3833,   3858],
                        [  3928,   3852],
                        [  4025,   3856],
                        [  4172,   3920],
                        [  4365,   4037],
                        [  4621,   4230],
                        [  4937,   4495],
                        [  5308,   4826],
                        [  5734,   5224],
                        [  6134,   5610],
                        [  6513,   5987],
                        [  6828,   6311],
                        [  7081,   6585],
                        [  7266,   6803],
                        [  7382,   6962],
                        [  7424,   7057],
                        [  7394,   7089],
                        [  7290,   7054],
                        [  7113,   6954],
                        [  6866,   6790],
                        [  6550,   6560],
                        [  6170,   6271],
                        [  5726,   5919],
                        [  5227,   5513],
                        [  4674,   5051],
                        [  4075,   4540],
                        [  3432,   3982],
                        [  2752,   3384],
                        [  2037,   2745],
                        [  1292,   2076],
                        [   520,   1376],
                        [  -271,    655],
                        [ -1081,    -88],
                        [ -1900,   -841],
                        [ -2724,  -1605],
                        [ -3540,  -2369],
                        [ -4346,  -3131],
                        [ -5129,  -3885],
                        [ -5883,  -4627],
                        [ -6607,  -5351],
                        [ -7295,  -6052],
                        [ -7950,  -6728],
                        [ -8569,  -7373],
                        [ -9157,  -7985],
                        [ -9709,  -8559],
                        [-10220,  -9090],
                        [-10687,  -9575],
                        [-11107, -10010],
                        [-11477, -10389],
                        [-11793, -10714],
                        [-12055, -10978],
                        [-12252, -11176],
                        [-12384, -11308],
                        [-12466, -11390],
                        [-12500, -11425],
                        [-12469, -11395],
                        [-12329, -11258],
                        [-12035, -10967],
                        [-11598, -10535],
                        [-11053,  -9996],
                        [-10408,  -9357],
                        [ -9674,  -8629],
                        [ -8870,  -7830],
                        [ -8008,  -6977],
                        [ -7100,  -6080],
                        [ -6161,  -5154],
                        [ -5203,  -4210],
                        [ -4240,  -3264],
                        [ -3283,  -2323],
                        [ -2340,  -1399],
                        [ -1424,   -501],
                        [  -540,    362],
                        [   302,   1186],
                        [  1097,   1963],
                        [  1840,   2688],
                        [  2529,   3358],
                        [  3158,   3971],
                        [  3729,   4523],
                        [  4240,   5016],
                        [  4688,   5451],
                        [  5077,   5829],
                        [  5405,   6157],
                        [  5674,   6437],
                        [  5887,   6674],
                        [  6047,   6871],
                        [  6155,   7030],
                        [  6215,   7153],
                        [  6230,   7233],
                        [  6204,   7275],
                        [  6143,   7276],
                        [  6048,   7239],
                        [  5925,   7163],
                        [  5776,   7054],
                        [  5605,   6907],
                        [  5416,   6727],
                        [  5214,   6512],
                        [  5001,   6267],
                        [  4782,   6000],
                        [  4561,   5712],
                        [  4342,   5418],
                        [  4128,   5120],
                        [  3923,   4829],
                        [  3729,   4547],
                        [  3550,   4278],
                        [  3389,   4024],
                        [  3246,   3790],
                        [  3126,   3576],
                        [  3028,   3385],
                        [  2954,   3219],
                        [  2906,   3080],
                        [  2882,   2968],
                        [  2883,   2884],
                        [  2910,   2828],
                        [  2958,   2802],
                        [  3027,   2804],
                        [  3111,   2832],
                        [  3208,   2889],
                        [  3313,   2971],
                        [  3427,   3079],
                        [  3544,   3208],
                        [  3668,   3361],
                        [  3803,   3535],
                        [  3946,   3726],
                        [  4097,   3930],
                        [  4256,   4145],
                        [  4391,   4339],
                        [  4502,   4509],
                        [  4552,   4617],
                        [  4541,   4663],
                        [  4457,   4634],
                        [  4299,   4529],
                        [  4096,   4375],
                        [  3843,   4170],
                        [  3610,   3978],
                        [  3391,   3797],
                        [  3192,   3633],
                        [  3015,   3485],
                        [  2865,   3360],
                        [  2739,   3256],
                        [  2640,   3173],
                        [  2565,   3112],
                        [  2516,   3072],
                        [  2490,   3053],
                        [  2485,   3050],
                        [  2502,   3066],
                        [  2533,   3097],
                        [  2581,   3142],
                        [  2638,   3197],
                        [  2706,   3262],
                        [  2780,   3334],
                        [  2860,   3412],
                        [  2944,   3492],
                        [  3032,   3576],
                        [  3123,   3660],
                        [  3218,   3743],
                        [  3313,   3824],
                        [  3409,   3904],
                        [  3501,   3980],
                        [  3589,   4050],
                        [  3663,   4114],
                        [  3724,   4173],
                        [  3769,   4225],
                        [  3800,   4271],
                        [  3819,   4308],
                        [  3825,   4338],
                        [  3832,   4361],
                        [  3837,   4377],
                        [  3842,   4386],
                        [  3849,   4387],
                        [  3855,   4380],
                        [  3860,   4364],
                        [  3863,   4337],
                        [  3866,   4300],
                        [  3863,   4251],
                        [  3866,   4200],
                        [  3902,   4180],
                        [  3993,   4210],
                        [  4141,   4298],
                        [  4331,   4426],
                        [  4516,   4552],
                        [  4634,   4613],
                        [  4656,   4583],
                        [  4598,   4473],
                        [  4462,   4289],
                        [  4258,   4038],
                        [  3993,   3733],
                        [  3680,   3382],
                        [  3324,   2996],
                        [  2935,   2581],
                        [  2520,   2147],
                        [  2090,   1703],
                        [  1650,   1255],
                        [  1207,    810],
                        [   768,    373],
                        [   337,    -52],
                        [   -81,   -459],
                        [  -483,   -847],
                        [  -867,  -1214],
                        [ -1230,  -1556],
                        [ -1572,  -1874],
                        [ -1893,  -2168],
                        [ -2191,  -2438],
                        [ -2469,  -2685],
                        [ -2726,  -2915],
                        [ -2962,  -3129],
                        [ -3179,  -3332],
                        [ -3377,  -3525],
                        [ -3559,  -3713],
                        [ -3725,  -3899],
                        [ -3876,  -4080],
                        [ -4016,  -4259],
                        [ -4144,  -4429],
                        [ -4262,  -4592],
                        [ -4369,  -4744],
                        [ -4468,  -4888],
                        [ -4558,  -5016],
                        [ -4639,  -5129],
                        [ -4712,  -5220],
                        [ -4775,  -5288],
                        [ -4828,  -5333],
                        [ -4872,  -5355],
                        [ -4905,  -5360],
                        [ -4929,  -5347],
                        [ -4943,  -5324],
                        [ -4947,  -5293],
                        [ -4942,  -5254],
                        [ -4925,  -5207],
                        [ -4899,  -5153],
                        [ -4862,  -5092],
                        [ -4815,  -5024],
                        [ -4758,  -4949],
                        [ -4692,  -4867],
                        [ -4617,  -4779],
                        [ -4533,  -4686],
                        [ -4440,  -4587],
                        [ -4340,  -4482],
                        [ -4233,  -4373],
                        [ -4117,  -4261],
                        [ -3993,  -4145],
                        [ -3859,  -4027],
                        [ -3720,  -3907],
                        [ -3569,  -3788],
                        [ -3410,  -3668],
                        [ -3248,  -3554],
                        [ -3083,  -3446],
                        [ -2922,  -3343],
                        [ -2764,  -3244],
                        [ -2607,  -3144],
                        [ -2454,  -3046],
                        [ -2269,  -2911],
                        [ -2059,  -2746],
                        [ -1814,  -2539],
                        [ -1536,  -2292],
                        [ -1220,  -1999],
                        [  -868,  -1662],
                        [  -539,  -1338],
                        [  -230,  -1026],
                        [    24,   -760],
                        [   227,   -536],
                        [   368,   -366],
                        [   447,   -249],
                        [   457,   -194],
                        [   400,   -199],
                        [   273,   -268],
                        [    76,   -401],
                        [  -188,   -597],
                        [  -518,   -856],
                        [  -909,  -1172],
                        [ -1359,  -1548],
                        [ -1862,  -1976],
                        [ -2416,  -2455],
                        [ -3008,  -2977],
                        [ -3641,  -3542],
                        [ -4302,  -4140],
                        [ -4989,  -4768],
                        [ -5695,  -5418],
                        [ -6416,  -6086],
                        [ -7143,  -6764],
                        [ -7873,  -7449],
                        [ -8595,  -8131],
                        [ -9306,  -8808],
                        [ -9991,  -9469],
                        [-10646, -10113],
                        [-11258, -10732],
                        [-11825, -11321],
                        [-12342, -11873],
                        [-12806, -12386],
                        [-13218, -12852],
                        [-13576, -13270],
                        [-13886, -13635],
                        [-14142, -13944],
                        [-14344, -14194],
                        [-14488, -14384],
                        [-14574, -14508],
                        [-14601, -14568],
                        [-14571, -14561],
                        [-14480, -14485],
                        [-14359, -14374],
                        [-14263, -14280],
                        [-14221, -14234],
                        [-14237, -14242],
                        [-14298, -14294],
                        [-14370, -14353],
                        [-14372, -14341],
                        [-14247, -14201],
                        [-13998, -13935],
                        [-13634, -13552],
                        [-13167, -13061],
                        [-12609, -12477],
                        [-11972, -11812],
                        [-11267, -11077],
                        [-10506, -10285],
                        [ -9704,  -9452],
                        [ -8872,  -8587],
                        [ -8020,  -7703],
                        [ -7161,  -6812],
                        [ -6308,  -5924],
                        [ -5467,  -5048],
                        [ -4648,  -4193],
                        [ -3858,  -3368],
                        [ -3104,  -2578],
                        [ -2391,  -1831],
                        [ -1723,  -1129],
                        [ -1100,   -477],
                        [  -530,    122],
                        [   -11,    669],
                        [   457,   1161],
                        [   870,   1602],
                        [  1233,   1992],
                        [  1545,   2334],
                        [  1808,   2631],
                        [  2026,   2887],
                        [  2199,   3105],
                        [  2334,   3286],
                        [  2433,   3432],
                        [  2499,   3543],
                        [  2538,   3623],
                        [  2554,   3673],
                        [  2548,   3694],
                        [  2528,   3685],
                        [  2493,   3647],
                        [  2448,   3580],
                        [  2398,   3489],
                        [  2344,   3378],
                        [  2291,   3252],
                        [  2242,   3122],
                        [  2199,   2990],
                        [  2164,   2865],
                        [  2139,   2749],
                        [  2127,   2645],
                        [  2129,   2556],
                        [  2145,   2484],
                        [  2177,   2431],
                        [  2225,   2397],
                        [  2290,   2384],
                        [  2373,   2390],
                        [  2471,   2418],
                        [  2585,   2467],
                        [  2713,   2535],
                        [  2854,   2622],
                        [  3006,   2727],
                        [  3166,   2847],
                        [  3335,   2980],
                        [  3506,   3126],
                        [  3679,   3279],
                        [  3842,   3439],
                        [  3999,   3607],
                        [  4145,   3777],
                        [  4277,   3945],
                        [  4392,   4107],
                        [  4491,   4262],
                        [  4551,   4385],
                        [  4571,   4476],
                        [  4538,   4516],
                        [  4449,   4505],
                        [  4292,   4426],
                        [  4066,   4279],
                        [  3781,   4071],
                        [  3434,   3801],
                        [  3075,   3513],
                        [  2698,   3205],
                        [  2316,   2887],
                        [  1926,   2558],
                        [  1545,   2230],
                        [  1168,   1900],
                        [   807,   1580],
                        [   458,   1264],
                        [   129,    962],
                        [  -179,    674],
                        [  -464,    401],
                        [  -726,    146],
                        [  -963,    -91],
                        [ -1175,   -308],
                        [ -1363,   -506],
                        [ -1525,   -683],
                        [ -1663,   -840],
                        [ -1778,   -977],
                        [ -1870,  -1095],
                        [ -1939,  -1194],
                        [ -1985,  -1274],
                        [ -2009,  -1337],
                        [ -2014,  -1383],
                        [ -2000,  -1413],
                        [ -1974,  -1429],
                        [ -1933,  -1430],
                        [ -1891,  -1419],
                        [ -1845,  -1397],
                        [ -1800,  -1365],
                        [ -1756,  -1324],
                        [ -1713,  -1280],
                        [ -1671,  -1230],
                        [ -1624,  -1180],
                        [ -1573,  -1129],
                        [ -1519,  -1079],
                        [ -1464,  -1033],
                        [ -1411,   -992],
                        [ -1357,   -960],
                        [ -1306,   -934],
                        [ -1261,   -923],
                        [ -1222,   -924],
                        [ -1138,   -886],
                        [  -941,   -740],
                        [  -605,   -458],
                        [  -132,    -40],
                        [   472,    509],
                        [  1169,   1155],
                        [  1857,   1794],
                        [  2444,   2337],
                        [  2919,   2769],
                        [  3288,   3096],
                        [  3553,   3322],
                        [  3719,   3449],
                        [  3792,   3483],
                        [  3776,   3431],
                        [  3677,   3299],
                        [  3505,   3095],
                        [  3266,   2828],
                        [  2968,   2502],
                        [  2618,   2126],
                        [  2226,   1708],
                        [  1797,   1255],
                        [  1340,    774],
                        [   860,    270],
                        [   365,   -249],
                        [  -142,   -779],
                        [  -656,  -1314],
                        [ -1171,  -1849],
                        [ -1683,  -2382],
                        [ -2188,  -2908],
                        [ -2683,  -3425],
                        [ -3166,  -3928],
                        [ -3632,  -4417],
                        [ -4080,  -4888],
                        [ -4509,  -5344],
                        [ -4916,  -5784],
                        [ -5299,  -6208],
                        [ -5659,  -6617],
                        [ -5995,  -7007],
                        [ -6305,  -7378],
                        [ -6591,  -7728],
                        [ -6851,  -8054],
                        [ -7086,  -8351],
                        [ -7295,  -8618],
                        [ -7477,  -8848],
                        [ -7633,  -9041],
                        [ -7762,  -9195],
                        [ -7865,  -9312],
                        [ -7941,  -9393],
                        [ -7993,  -9442],
                        [ -8021,  -9465],
                        [ -8025,  -9463],
                        [ -8006,  -9438],
                        [ -7967,  -9391],
                        [ -7906,  -9324],
                        [ -7827,  -9241],
                        [ -7730,  -9141],
                        [ -7618,  -9027],
                        [ -7493,  -8900],
                        [ -7357,  -8763],
                        [ -7213,  -8617],
                        [ -7063,  -8464],
                        [ -6908,  -8305],
                        [ -6751,  -8145],
                        [ -6596,  -7982],
                        [ -6446,  -7820],
                        [ -6304,  -7660],
                        [ -6173,  -7503],
                        [ -6049,  -7352],
                        [ -5935,  -7207],
                        [ -5824,  -7073],
                        [ -5719,  -6951],
                        [ -5619,  -6840],
                        [ -5527,  -6741],
                        [ -5438,  -6650],
                        [ -5355,  -6569],
                        [ -5271,  -6488],
                        [ -5185,  -6407],
                        [ -5098,  -6323],
                        [ -5007,  -6237],
                        [ -4897,  -6127],
                        [ -4767,  -5996],
                        [ -4642,  -5866],
                        [ -4518,  -5736],
                        [ -4418,  -5625],
                        [ -4338,  -5532],
                        [ -4290,  -5466],
                        [ -4273,  -5428],
                        [ -4293,  -5423],
                        [ -4350,  -5451],
                        [ -4448,  -5517],
                        [ -4586,  -5618],
                        [ -4763,  -5758],
                        [ -4979,  -5934],
                        [ -5231,  -6144],
                        [ -5516,  -6387],
                        [ -5831,  -6661],
                        [ -6173,  -6961],
                        [ -6535,  -7282],
                        [ -6916,  -7625],
                        [ -7306,  -7980],
                        [ -7703,  -8344],
                        [ -8101,  -8713],
                        [ -8496,  -9082],
                        [ -8881,  -9445],
                        [ -9254,  -9796],
                        [ -9605, -10132],
                        [ -9930, -10449],
                        [-10220, -10740],
                        [-10472, -11003],
                        [-10678, -11233],
                        [-10835, -11428],
                        [-10939, -11581],
                        [-10989, -11691],
                        [-10987, -11753],
                        [-10933, -11764],
                        [-10830, -11724],
                        [-10679, -11630],
                        [-10477, -11482],
                        [-10225, -11280],
                        [ -9928, -11023],
                        [ -9588, -10715],
                        [ -9199, -10349],
                        [ -8774,  -9938],
                        [ -8387,  -9553],
                        [ -8119,  -9277],
                        [ -7999,  -9141],
                        [ -8031,  -9150],
                        [ -8218,  -9310],
                        [ -8532,  -9593],
                        [ -8860,  -9888],
                        [ -9095, -10086],
                        [ -9223, -10173],
                        [ -9253, -10159],
                        [ -9191, -10045],
                        [ -9041,  -9836],
                        [ -8809,  -9541],
                        [ -8504,  -9167],
                        [ -8131,  -8724],
                        [ -7699,  -8218],
                        [ -7220,  -7663],
                        [ -6699,  -7064],
                        [ -6147,  -6433],
                        [ -5574,  -5778],
                        [ -4985,  -5107],
                        [ -4388,  -4427],
                        [ -3791,  -3747],
                        [ -3201,  -3075],
                        [ -2621,  -2416],
                        [ -2056,  -1776],
                        [ -1510,  -1158],
                        [  -986,   -566],
                        [  -486,     -3],
                        [   -13,    527],
                        [   432,   1021],
                        [   849,   1478],
                        [  1238,   1899],
                        [  1600,   2283],
                        [  1935,   2638],
                        [  2246,   2965],
                        [  2533,   3271],
                        [  2799,   3557],
                        [  3049,   3825],
                        [  3282,   4078],
                        [  3502,   4314],
                        [  3712,   4536],
                        [  3911,   4739],
                        [  4105,   4925],
                        [  4292,   5093],
                        [  4476,   5246],
                        [  4657,   5386],
                        [  4837,   5513],
                        [  5016,   5636],
                        [  5195,   5756],
                        [  5376,   5875],
                        [  5558,   5996],
                        [  5741,   6120],
                        [  5925,   6247],
                        [  6108,   6379],
                        [  6292,   6515],
                        [  6474,   6657],
                        [  6656,   6802],
                        [  6835,   6952],
                        [  7012,   7103],
                        [  7184,   7256],
                        [  7352,   7409],
                        [  7514,   7560],
                        [  7670,   7707],
                        [  7824,   7850],
                        [  7973,   7985],
                        [  8116,   8110],
                        [  8251,   8223],
                        [  8366,   8320],
                        [  8461,   8404],
                        [  8524,   8470],
                        [  8552,   8514],
                        [  8544,   8535],
                        [  8500,   8533],
                        [  8418,   8503],
                        [  8300,   8446],
                        [  8152,   8366],
                        [  7971,   8260],
                        [  7747,   8113],
                        [  7478,   7924],
                        [  7149,   7677],
                        [  6760,   7369],
                        [  6332,   7020],
                        [  5863,   6628],
                        [  5367,   6206],
                        [  4845,   5754],
                        [  4314,   5286],
                        [  3771,   4801],
                        [  3231,   4312],
                        [  2695,   3819],
                        [  2173,   3331],
                        [  1667,   2852],
                        [  1185,   2386],
                        [   726,   1938],
                        [   297,   1511],
                        [   -99,   1108],
                        [  -462,    732],
                        [  -788,    384],
                        [ -1080,     65],
                        [ -1334,   -222],
                        [ -1553,   -478],
                        [ -1736,   -701],
                        [ -1885,   -895],
                        [ -2000,  -1056],
                        [ -2083,  -1190],
                        [ -2135,  -1293],
                        [ -2163,  -1368],
                        [ -2167,  -1418],
                        [ -2155,  -1442],
                        [ -2126,  -1443],
                        [ -2087,  -1425],
                        [ -2040,  -1389],
                        [ -1987,  -1340],
                        [ -1931,  -1280],
                        [ -1870,  -1216],
                        [ -1806,  -1146],
                        [ -1741,  -1077],
                        [ -1677,  -1010],
                        [ -1619,   -950],
                        [ -1564,   -895],
                        [ -1512,   -848],
                        [ -1476,   -820],
                        [ -1439,   -797],
                        [ -1317,   -693],
                        [ -1031,   -430],
                        [  -561,     14],
                        [    90,    640],
                        [   934,   1458],
                        [  1940,   2441],
                        [  2981,   3459],
                        [  3928,   4386],
                        [  4763,   5202],
                        [  5493,   5910],
                        [  6113,   6505],
                        [  6621,   6983],
                        [  7018,   7347],
                        [  7307,   7599],
                        [  7490,   7742],
                        [  7572,   7781],
                        [  7558,   7723],
                        [  7456,   7573],
                        [  7274,   7339],
                        [  7018,   7027],
                        [  6696,   6647],
                        [  6317,   6206],
                        [  5888,   5712],
                        [  5419,   5175],
                        [  4916,   4602],
                        [  4386,   4002],
                        [  3837,   3379],
                        [  3275,   2745],
                        [  2707,   2104],
                        [  2141,   1467],
                        [  1580,    839],
                        [  1030,    232],
                        [   497,   -353],
                        [   -17,   -912],
                        [  -507,  -1442],
                        [  -971,  -1949],
                        [ -1406,  -2429],
                        [ -1811,  -2886],
                        [ -2183,  -3317],
                        [ -2523,  -3720],
                        [ -2830,  -4093],
                        [ -3102,  -4431],
                        [ -3341,  -4732],
                        [ -3545,  -4994],
                        [ -3715,  -5215],
                        [ -3850,  -5394],
                        [ -3951,  -5533],
                        [ -4021,  -5632],
                        [ -4060,  -5694],
                        [ -4070,  -5723],
                        [ -4053,  -5722],
                        [ -4011,  -5691],
                        [ -3945,  -5632],
                        [ -3856,  -5552],
                        [ -3749,  -5450],
                        [ -3624,  -5332],
                        [ -3486,  -5198],
                        [ -3337,  -5052],
                        [ -3182,  -4897],
                        [ -3023,  -4736],
                        [ -2862,  -4571],
                        [ -2706,  -4406],
                        [ -2554,  -4242],
                        [ -2417,  -4083],
                        [ -2299,  -3930],
                        [ -2205,  -3785],
                        [ -2139,  -3650],
                        [ -2095,  -3525],
                        [ -2079,  -3414],
                        [ -2073,  -3317],
                        [ -2079,  -3235],
                        [ -2091,  -3169],
                        [ -2108,  -3118],
                        [ -2137,  -3086],
                        [ -2175,  -3075],
                        [ -2243,  -3101],
                        [ -2337,  -3161],
                        [ -2459,  -3257],
                        [ -2610,  -3387],
                        [ -2755,  -3516],
                        [ -2897,  -3647],
                        [ -3014,  -3758],
                        [ -3109,  -3849],
                        [ -3189,  -3928],
                        [ -3251,  -3993],
                        [ -3304,  -4051],
                        [ -3344,  -4099],
                        [ -3383,  -4145],
                        [ -3416,  -4185],
                        [ -3449,  -4226],
                        [ -3482,  -4265],
                        [ -3517,  -4306],
                        [ -3551,  -4347],
                        [ -3589,  -4389],
                        [ -3626,  -4430],
                        [ -3664,  -4470],
                        [ -3701,  -4507],
                        [ -3733,  -4540],
                        [ -3761,  -4566],
                        [ -3779,  -4584],
                        [ -3785,  -4591],
                        [ -3777,  -4585],
                        [ -3751,  -4562],
                        [ -3705,  -4521],
                        [ -3638,  -4458],
                        [ -3546,  -4373],
                        [ -3426,  -4263],
                        [ -3277,  -4128],
                        [ -3096,  -3966],
                        [ -2880,  -3776],
                        [ -2628,  -3556],
                        [ -2339,  -3305],
                        [ -2013,  -3023],
                        [ -1650,  -2707],
                        [ -1252,  -2358],
                        [  -823,  -1974],
                        [  -366,  -1559],
                        [   120,  -1112],
                        [   633,   -635],
                        [  1164,   -131],
                        [  1710,    395],
                        [  2276,    951],
                        [  2837,   1509],
                        [  3294,   1971],
                        [  3565,   2259],
                        [  3638,   2355],
                        [  3500,   2247],
                        [  3136,   1917],
                        [  2560,   1377],
                        [  1907,    764],
                        [  1303,    202],
                        [   764,   -291],
                        [   284,   -720],
                        [  -132,  -1077],
                        [  -482,  -1359],
                        [  -762,  -1567],
                        [  -975,  -1700],
                        [ -1120,  -1762],
                        [ -1201,  -1756],
                        [ -1218,  -1684],
                        [ -1177,  -1552],
                        [ -1083,  -1363],
                        [  -940,  -1124],
                        [  -751,   -838],
                        [  -521,   -512],
                        [  -256,   -152],
                        [    38,    237],
                        [   361,    651],
                        [   705,   1083],
                        [  1069,   1531],
                        [  1448,   1989],
                        [  1839,   2452],
                        [  2238,   2916],
                        [  2645,   3372],
                        [  3056,   3817],
                        [  3469,   4248],
                        [  3882,   4662],
                        [  4297,   5066],
                        [  4708,   5458],
                        [  5119,   5850],
                        [  5527,   6241],
                        [  5933,   6632],
                        [  6338,   7027],
                        [  6738,   7419],
                        [  7136,   7811],
                        [  7530,   8198],
                        [  7920,   8579],
                        [  8303,   8953],
                        [  8680,   9321],
                        [  9049,   9678],
                        [  9409,  10025],
                        [  9758,  10361],
                        [ 10097,  10688],
                        [ 10423,  11004],
                        [ 10736,  11306],
                        [ 11031,  11595],
                        [ 11308,  11870],
                        [ 11565,  12129],
                        [ 11801,  12374],
                        [ 12013,  12601],
                        [ 12201,  12811],
                        [ 12366,  13000],
                        [ 12507,  13169],
                        [ 12621,  13317],
                        [ 12708,  13442],
                        [ 12773,  13542],
                        [ 12814,  13618],
                        [ 12841,  13665],
                        [ 12852,  13686],
                        [ 12850,  13677],
                        [ 12833,  13639],
                        [ 12790,  13568],
                        [ 12721,  13466],
                        [ 12609,  13333],
                        [ 12456,  13167],
                        [ 12261,  12972],
                        [ 12023,  12745],
                        [ 11769,  12512],
                        [ 11499,  12271],
                        [ 11234,  12045],
                        [ 10976,  11834],
                        [ 10711,  11620],
                        [ 10441,  11405],
                        [ 10121,  11143],
                        [  9757,  10839],
                        [  9340,  10483],
                        [  8872,  10076],
                        [  8367,   9631],
                        [  7827,   9148],
                        [  7265,   8639],
                        [  6682,   8106],
                        [  6093,   7562],
                        [  5499,   7007],
                        [  4912,   6452],
                        [  4333,   5898],
                        [  3773,   5357],
                        [  3233,   4827],
                        [  2721,   4319],
                        [  2239,   3832],
                        [  1792,   3372],
                        [  1379,   2940],
                        [  1003,   2541],
                        [   665,   2173],
                        [   364,   1838],
                        [    98,   1537],
                        [  -132,   1270],
                        [  -329,   1035],
                        [  -494,    832],
                        [  -628,    661],
                        [  -734,    518],
                        [  -814,    404],
                        [  -872,    316],
                        [  -908,    254],
                        [  -931,    211],
                        [  -942,    189],
                        [  -948,    179],
                        [  -951,    180],
                        [  -956,    186],
                        [  -960,    196],
                        [  -968,    205],
                        [  -982,    210],
                        [ -1004,    209],
                        [ -1032,    202],
                        [ -1066,    189],
                        [ -1118,    156],
                        [ -1159,    132],
                        [ -1090,    216],
                        [  -851,    466],
                        [  -431,    892],
                        [   172,   1503],
                        [   989,   2325],
                        [  2001,   3343],
                        [  3074,   4422],
                        [  4085,   5436],
                        [  5017,   6371],
                        [  5876,   7225],
                        [  6650,   7986],
                        [  7331,   8647],
                        [  7919,   9202],
                        [  8409,   9654],
                        [  8802,  10000],
                        [  9097,  10242],
                        [  9297,  10381],
                        [  9407,  10424],
                        [  9432,  10374],
                        [  9375,  10236],
                        [  9246,  10018],
                        [  9049,   9726],
                        [  8792,   9370],
                        [  8483,   8956],
                        [  8129,   8495],
                        [  7737,   7993],
                        [  7316,   7458],
                        [  6871,   6900],
                        [  6411,   6325],
                        [  5942,   5748],
                        [  5470,   5176],
                        [  5000,   4622],
                        [  4539,   4093],
                        [  4091,   3590],
                        [  3659,   3119],
                        [  3247,   2672],
                        [  2858,   2252],
                        [  2492,   1852],
                        [  2153,   1473],
                        [  1842,   1117],
                        [  1558,    786],
                        [  1302,    482],
                        [  1075,    206],
                        [   876,    -44],
                        [   704,   -265],
                        [   560,   -458],
                        [   441,   -625],
                        [   348,   -763],
                        [   276,   -873],
                        [   226,   -960],
                        [   193,  -1025],
                        [   179,  -1065],
                        [   177,  -1086],
                        [   190,  -1091],
                        [   214,  -1081],
                        [   245,  -1060],
                        [   284,  -1031],
                        [   325,   -998],
                        [   366,   -960],
                        [   402,   -922],
                        [   433,   -887],
                        [   455,   -856],
                        [   466,   -831],
                        [   452,   -815],
                        [   414,   -808],
                        [   344,   -812],
                        [   240,   -826],
                        [   104,   -853],
                        [   -63,   -892],
                        [  -241,   -942],
                        [  -431,  -1003],
                        [  -622,  -1077],
                        [  -813,  -1160],
                        [ -1018,  -1271],
                        [ -1235,  -1405],
                        [ -1502,  -1601],
                        [ -1814,  -1857],
                        [ -2173,  -2170],
                        [ -2577,  -2542],
                        [ -2984,  -2926],
                        [ -3393,  -3323],
                        [ -3749,  -3677],
                        [ -4053,  -3988],
                        [ -4305,  -4255],
                        [ -4500,  -4474],
                        [ -4646,  -4651],
                        [ -4739,  -4781],
                        [ -4787,  -4869],
                        [ -4786,  -4915],
                        [ -4747,  -4922],
                        [ -4664,  -4890],
                        [ -4545,  -4822],
                        [ -4389,  -4718],
                        [ -4203,  -4583],
                        [ -3985,  -4413],
                        [ -3740,  -4215],
                        [ -3469,  -3986],
                        [ -3174,  -3731],
                        [ -2855,  -3448],
                        [ -2513,  -3140],
                        [ -2147,  -2806],
                        [ -1758,  -2450],
                        [ -1347,  -2069],
                        [  -916,  -1667],
                        [  -465,  -1243],
                        [     3,   -800],
                        [   488,   -338],
                        [   985,    141],
                        [  1492,    633],
                        [  2010,   1137],
                        [  2536,   1652],
                        [  3075,   2177],
                        [  3625,   2709],
                        [  4184,   3250],
                        [  4753,   3796],
                        [  5324,   4348],
                        [  5897,   4902],
                        [  6468,   5456],
                        [  7036,   6009],
                        [  7591,   6554],
                        [  8132,   7088],
                        [  8664,   7618],
                        [  9149,   8106],
                        [  9494,   8460],
                        [  9649,   8629],
                        [  9610,   8608],
                        [  9361,   8382],
                        [  8871,   7916],
                        [  8144,   7216],
                        [  7306,   6404],
                        [  6468,   5596],
                        [  5642,   4803],
                        [  4828,   4026],
                        [  4041,   3283],
                        [  3290,   2585],
                        [  2584,   1938],
                        [  1928,   1346],
                        [  1330,    817],
                        [   793,    353],
                        [   321,    -44],
                        [   -86,   -372],
                        [  -427,   -631],
                        [  -700,   -823],
                        [  -906,   -947],
                        [ -1049,  -1005],
                        [ -1129,  -1003],
                        [ -1151,   -943],
                        [ -1116,   -826],
                        [ -1027,   -659],
                        [  -889,   -444],
                        [  -704,   -188],
                        [  -478,    105],
                        [  -212,    429],
                        [    87,    769],
                        [   417,   1125],
                        [   774,   1484],
                        [  1155,   1848],
                        [  1554,   2215],
                        [  1970,   2584],
                        [  2399,   2967],
                        [  2839,   3361],
                        [  3285,   3768],
                        [  3735,   4186],
                        [  4186,   4612],
                        [  4636,   5042],
                        [  5081,   5476],
                        [  5518,   5911],
                        [  5943,   6343],
                        [  6354,   6773],
                        [  6747,   7192],
                        [  7122,   7601],
                        [  7475,   7992],
                        [  7802,   8363],
                        [  8104,   8709],
                        [  8376,   9031],
                        [  8616,   9322],
                        [  8821,   9581],
                        [  8989,   9809],
                        [  9119,  10003],
                        [  9211,  10162],
                        [  9263,  10285],
                        [  9277,  10372],
                        [  9251,  10423],
                        [  9188,  10436],
                        [  9085,  10411],
                        [  8952,  10349],
                        [  8789,  10249],
                        [  8607,  10111],
                        [  8406,   9937],
                        [  8193,   9726],
                        [  7967,   9481],
                        [  7721,   9201],
                        [  7455,   8886],
                        [  7154,   8539],
                        [  6822,   8163],
                        [  6459,   7765],
                        [  6069,   7344],
                        [  5696,   6951],
                        [  5341,   6582],
                        [  5033,   6267],
                        [  4772,   6005],
                        [  4548,   5786],
                        [  4362,   5611],
                        [  4149,   5411],
                        [  3913,   5194],
                        [  3629,   4930],
                        [  3299,   4624],
                        [  2932,   4283],
                        [  2531,   3907],
                        [  2103,   3505],
                        [  1649,   3078],
                        [  1183,   2635],
                        [   703,   2177],
                        [   220,   1713],
                        [  -265,   1245],
                        [  -742,    780],
                        [ -1211,    319],
                        [ -1663,   -129],
                        [ -2098,   -567],
                        [ -2510,   -986],
                        [ -2898,  -1388],
                        [ -3262,  -1768],
                        [ -3602,  -2126],
                        [ -3916,  -2460],
                        [ -4207,  -2771],
                        [ -4477,  -3060],
                        [ -4725,  -3325],
                        [ -4950,  -3567],
                        [ -5155,  -3788],
                        [ -5337,  -3988],
                        [ -5497,  -4169],
                        [ -5638,  -4331],
                        [ -5759,  -4475],
                        [ -5871,  -4606],
                        [ -5973,  -4722],
                        [ -6074,  -4830],
                        [ -6177,  -4929],
                        [ -6284,  -5026],
                        [ -6395,  -5119],
                        [ -6512,  -5214],
                        [ -6636,  -5311],
                        [ -6767,  -5412],
                        [ -6901,  -5514],
                        [ -7040,  -5619],
                        [ -7190,  -5733],
                        [ -7313,  -5822],
                        [ -7337,  -5810],
                        [ -7229,  -5670],
                        [ -6988,  -5399],
                        [ -6599,  -4983],
                        [ -6024,  -4380],
                        [ -5259,  -3591],
                        [ -4410,  -2721],
                        [ -3572,  -1866],
                        [ -2753,  -1034],
                        [ -1951,   -230],
                        [ -1183,    530],
                        [  -461,   1233],
                        [   212,   1876],
                        [   830,   2451],
                        [  1384,   2954],
                        [  1873,   3382],
                        [  2295,   3733],
                        [  2651,   4010],
                        [  2940,   4210],
                        [  3164,   4339],
                        [  3326,   4397],
                        [  3428,   4392],
                        [  3477,   4324],
                        [  3475,   4202],
                        [  3429,   4032],
                        [  3343,   3818],
                        [  3222,   3568],
                        [  3070,   3287],
                        [  2894,   2983],
                        [  2698,   2668],
                        [  2489,   2349],
                        [  2268,   2039],
                        [  2041,   1744],
                        [  1811,   1465],
                        [  1582,   1210],
                        [  1355,    968],
                        [  1133,    743],
                        [   919,    523],
                        [   713,    310],
                        [   514,    104],
                        [   327,    -95],
                        [   149,   -288],
                        [   -20,   -473],
                        [  -176,   -654],
                        [  -325,   -832],
                        [  -464,  -1008],
                        [  -596,  -1181],
                        [  -720,  -1350],
                        [  -839,  -1513],
                        [  -955,  -1669],
                        [ -1067,  -1818],
                        [ -1176,  -1961],
                        [ -1285,  -2096],
                        [ -1393,  -2227],
                        [ -1501,  -2355],
                        [ -1610,  -2481],
                        [ -1723,  -2608],
                        [ -1839,  -2737],
                        [ -1961,  -2868],
                        [ -2090,  -3003],
                        [ -2227,  -3143],
                        [ -2375,  -3288],
                        [ -2533,  -3439],
                        [ -2713,  -3597],
                        [ -2914,  -3761],
                        [ -3143,  -3931],
                        [ -3397,  -4106],
                        [ -3677,  -4287],
                        [ -3980,  -4470],
                        [ -4285,  -4652],
                        [ -4595,  -4834],
                        [ -4895,  -5014],
                        [ -5183,  -5192],
                        [ -5482,  -5393],
                        [ -5788,  -5612],
                        [ -6147,  -5897],
                        [ -6553,  -6243],
                        [ -7008,  -6651],
                        [ -7510,  -7120],
                        [ -8012,  -7601],
                        [ -8514,  -8095],
                        [ -8941,  -8525],
                        [ -9293,  -8892],
                        [ -9567,  -9192],
                        [ -9760,  -9420],
                        [ -9873,  -9577],
                        [ -9904,  -9660],
                        [ -9859,  -9673],
                        [ -9736,  -9614],
                        [ -9544,  -9490],
                        [ -9282,  -9297],
                        [ -8957,  -9046],
                        [ -8571,  -8733],
                        [ -8133,  -8366],
                        [ -7643,  -7946],
                        [ -7113,  -7482],
                        [ -6542,  -6971],
                        [ -5939,  -6424],
                        [ -5305,  -5840],
                        [ -4644,  -5228],
                        [ -3960,  -4588],
                        [ -3258,  -3928],
                        [ -2539,  -3248],
                        [ -1810,  -2556],
                        [ -1074,  -1853],
                        [  -340,  -1146],
                        [   388,   -436],
                        [  1103,    271],
                        [  1799,    969],
                        [  2477,   1657],
                        [  3131,   2329],
                        [  3770,   2983],
                        [  4388,   3616],
                        [  4988,   4226],
                        [  5567,   4809],
                        [  6122,   5367],
                        [  6648,   5894],
                        [  7145,   6390],
                        [  7610,   6853],
                        [  8036,   7275],
                        [  8424,   7659],
                        [  8777,   8005],
                        [  9059,   8279],
                        [  9219,   8431],
                        [  9241,   8444],
                        [  9130,   8324],
                        [  8867,   8051],
                        [  8409,   7583],
                        [  7744,   6909],
                        [  6957,   6112],
                        [  6124,   5267],
                        [  5250,   4385],
                        [  4346,   3475],
                        [  3428,   2558],
                        [  2513,   1649],
                        [  1611,    758],
                        [   734,   -102],
                        [  -107,   -922],
                        [  -902,  -1692],
                        [ -1643,  -2404],
                        [ -2325,  -3055],
                        [ -2942,  -3638],
                        [ -3491,  -4149],
                        [ -3968,  -4587],
                        [ -4373,  -4951],
                        [ -4705,  -5240],
                        [ -4966,  -5456],
                        [ -5156,  -5600],
                        [ -5278,  -5675],
                        [ -5334,  -5683],
                        [ -5327,  -5627],
                        [ -5261,  -5518],
                        [ -5141,  -5356],
                        [ -4970,  -5160],
                        [ -4755,  -4933],
                        [ -4499,  -4684],
                        [ -4207,  -4418],
                        [ -3887,  -4138],
                        [ -3540,  -3848],
                        [ -3174,  -3538],
                        [ -2793,  -3213],
                        [ -2402,  -2870],
                        [ -2005,  -2514],
                        [ -1608,  -2148],
                        [ -1215,  -1777],
                        [  -831,  -1401],
                        [  -461,  -1023],
                        [  -107,   -644],
                        [   227,   -267],
                        [   536,     99],
                        [   819,    454],
                        [  1071,    786],
                        [  1292,   1093],
                        [  1476,   1367],
                        [  1626,   1607],
                        [  1735,   1809],
                        [  1803,   1970],
                        [  1831,   2092],
                        [  1814,   2172],
                        [  1757,   2210],
                        [  1657,   2206],
                        [  1517,   2160],
                        [  1337,   2074],
                        [  1120,   1946],
                        [   867,   1779],
                        [   587,   1575],
                        [   283,   1335],
                        [   -37,   1061],
                        [  -367,    756],
                        [  -702,    422],
                        [ -1039,     61],
                        [ -1382,   -326],
                        [ -1730,   -736],
                        [ -2091,  -1165],
                        [ -2464,  -1609],
                        [ -2840,  -2055],
                        [ -3220,  -2503],
                        [ -3547,  -2894],
                        [ -3823,  -3230],
                        [ -4022,  -3484],
                        [ -4145,  -3655],
                        [ -4194,  -3749],
                        [ -4171,  -3764],
                        [ -4152,  -3777],
                        [ -4131,  -3784],
                        [ -4143,  -3817],
                        [ -4186,  -3876],
                        [ -4258,  -3958],
                        [ -4358,  -4063],
                        [ -4486,  -4193],
                        [ -4640,  -4343],
                        [ -4815,  -4512],
                        [ -5011,  -4699],
                        [ -5223,  -4899],
                        [ -5451,  -5113],
                        [ -5688,  -5335],
                        [ -5935,  -5566],
                        [ -6184,  -5800],
                        [ -6437,  -6039],
                        [ -6687,  -6278],
                        [ -6936,  -6517],
                        [ -7181,  -6754],
                        [ -7423,  -6988],
                        [ -7663,  -7216],
                        [ -7900,  -7442],
                        [ -8134,  -7660],
                        [ -8366,  -7875],
                        [ -8592,  -8084],
                        [ -8813,  -8288],
                        [ -9021,  -8486],
                        [ -9217,  -8679],
                        [ -9399,  -8865],
                        [ -9568,  -9046],
                        [ -9731,  -9222],
                        [ -9887,  -9391],
                        [-10049,  -9556],
                        [-10214,  -9716],
                        [-10381,  -9873],
                        [-10552, -10026],
                        [-10724, -10176],
                        [-10898, -10324],
                        [-11072, -10467],
                        [-11241, -10602],
                        [-11405, -10729],
                        [-11566, -10850],
                        [-11695, -10939],
                        [-11768, -10970],
                        [-11784, -10944],
                        [-11741, -10862],
                        [-11624, -10707],
                        [-11382, -10430],
                        [-10987, -10005],
                        [-10489,  -9481],
                        [ -9938,  -8910],
                        [ -9340,  -8297],
                        [ -8697,  -7650],
                        [ -8027,  -6983],
                        [ -7341,  -6312],
                        [ -6645,  -5642],
                        [ -5952,  -4983],
                        [ -5267,  -4344],
                        [ -4600,  -3732],
                        [ -3957,  -3152],
                        [ -3343,  -2607],
                        [ -2761,  -2102],
                        [ -2214,  -1639],
                        [ -1705,  -1219],
                        [ -1235,   -843],
                        [  -803,   -509],
                        [  -410,   -219],
                        [   -54,     30],
                        [   262,    241],
                        [   543,    414],
                        [   789,    553],
                        [  1003,    661],
                        [  1185,    748],
                        [  1337,    817],
                        [  1463,    879],
                        [  1565,    935],
                        [  1641,    990],
                        [  1698,   1046],
                        [  1733,   1096],
                        [  1750,   1145],
                        [  1749,   1177],
                        [  1731,   1194],
                        [  1697,   1195],
                        [  1648,   1183],
                        [  1584,   1151],
                        [  1509,   1102],
                        [  1419,   1027],
                        [  1317,    930],
                        [  1202,    806],
                        [  1074,    658],
                        [   934,    492],
                        [   780,    306],
                        [   614,    108],
                        [   438,   -100],
                        [   249,   -316],
                        [    51,   -540],
                        [  -155,   -769],
                        [  -371,  -1005],
                        [  -594,  -1246],
                        [  -824,  -1493],
                        [ -1060,  -1743],
                        [ -1301,  -1997],
                        [ -1546,  -2253],
                        [ -1795,  -2511],
                        [ -2047,  -2770],
                        [ -2303,  -3029],
                        [ -2567,  -3285],
                        [ -2839,  -3538],
                        [ -3121,  -3787],
                        [ -3411,  -4029],
                        [ -3710,  -4264],
                        [ -4014,  -4487],
                        [ -4310,  -4696],
                        [ -4600,  -4892],
                        [ -4872,  -5074],
                        [ -5124,  -5241],
                        [ -5385,  -5423],
                        [ -5650,  -5618],
                        [ -5959,  -5865],
                        [ -6307,  -6164],
                        [ -6701,  -6517],
                        [ -7137,  -6925],
                        [ -7574,  -7344],
                        [ -8015,  -7777],
                        [ -8383,  -8148],
                        [ -8678,  -8457],
                        [ -8898,  -8699],
                        [ -9037,  -8872],
                        [ -9094,  -8969],
                        [ -9070,  -8992],
                        [ -8964,  -8940],
                        [ -8780,  -8815],
                        [ -8521,  -8619],
                        [ -8187,  -8353],
                        [ -7787,  -8021],
                        [ -7322,  -7626],
                        [ -6803,  -7176],
                        [ -6230,  -6671],
                        [ -5617,  -6119],
                        [ -4963,  -5523],
                        [ -4279,  -4893],
                        [ -3567,  -4228],
                        [ -2835,  -3541],
                        [ -2085,  -2832],
                        [ -1325,  -2109],
                        [  -557,  -1377],
                        [   209,   -643],
                        [   971,     91],
                        [  1713,    816],
                        [  2433,   1530],
                        [  3121,   2225],
                        [  3773,   2900],
                        [  4388,   3547],
                        [  4963,   4166],
                        [  5504,   4748],
                        [  6008,   5293],
                        [  6480,   5800],
                        [  6914,   6263],
                        [  7311,   6682],
                        [  7667,   7056],
                        [  7981,   7383],
                        [  8253,   7662],
                        [  8479,   7889],
                        [  8661,   8065],
                        [  8799,   8190],
                        [  8881,   8253],
                        [  8914,   8260],
                        [  8910,   8225],
                        [  8873,   8153],
                        [  8786,   8027],
                        [  8606,   7805],
                        [  8290,   7446],
                        [  7857,   6969],
                        [  7342,   6407],
                        [  6752,   5770],
                        [  6098,   5070],
                        [  5397,   4326],
                        [  4662,   3551],
                        [  3907,   2759],
                        [  3144,   1964],
                        [  2387,   1178],
                        [  1646,    414],
                        [   932,   -323],
                        [   252,  -1021],
                        [  -385,  -1671],
                        [  -974,  -2271],
                        [ -1510,  -2815],
                        [ -1991,  -3298],
                        [ -2414,  -3719],
                        [ -2778,  -4076],
                        [ -3082,  -4368],
                        [ -3327,  -4597],
                        [ -3514,  -4765],
                        [ -3646,  -4873],
                        [ -3725,  -4929],
                        [ -3753,  -4933],
                        [ -3738,  -4901],
                        [ -3680,  -4835],
                        [ -3586,  -4745],
                        [ -3462,  -4634],
                        [ -3311,  -4509],
                        [ -3139,  -4375],
                        [ -2950,  -4226],
                        [ -2750,  -4067],
                        [ -2543,  -3895],
                        [ -2335,  -3716],
                        [ -2132,  -3532],
                        [ -1937,  -3347],
                        [ -1754,  -3158],
                        [ -1587,  -2970],
                        [ -1440,  -2780],
                        [ -1314,  -2592],
                        [ -1213,  -2411],
                        [ -1138,  -2240],
                        [ -1092,  -2088],
                        [ -1077,  -1959],
                        [ -1092,  -1859],
                        [ -1138,  -1791],
                        [ -1218,  -1757],
                        [ -1331,  -1756],
                        [ -1476,  -1790],
                        [ -1652,  -1859],
                        [ -1859,  -1961],
                        [ -2095,  -2096],
                        [ -2357,  -2263],
                        [ -2644,  -2459],
                        [ -2952,  -2683],
                        [ -3279,  -2933],
                        [ -3618,  -3205],
                        [ -3967,  -3499],
                        [ -4317,  -3808],
                        [ -4665,  -4134],
                        [ -5005,  -4469],
                        [ -5333,  -4812],
                        [ -5649,  -5162],
                        [ -5951,  -5517],
                        [ -6240,  -5870],
                        [ -6514,  -6216],
                        [ -6765,  -6544],
                        [ -6992,  -6852],
                        [ -7150,  -7090],
                        [ -7237,  -7257],
                        [ -7239,  -7337],
                        [ -7154,  -7328],
                        [ -6982,  -7226],
                        [ -6721,  -7032],
                        [ -6445,  -6816],
                        [ -6147,  -6572],
                        [ -5863,  -6335],
                        [ -5590,  -6102],
                        [ -5336,  -5881],
                        [ -5102,  -5672],
                        [ -4892,  -5480],
                        [ -4708,  -5307],
                        [ -4553,  -5155],
                        [ -4427,  -5024],
                        [ -4328,  -4916],
                        [ -4260,  -4831],
                        [ -4219,  -4769],
                        [ -4206,  -4730],
                        [ -4219,  -4713],
                        [ -4255,  -4719],
                        [ -4314,  -4745],
                        [ -4394,  -4792],
                        [ -4495,  -4859],
                        [ -4616,  -4943],
                        [ -4756,  -5045],
                        [ -4916,  -5163],
                        [ -5091,  -5294],
                        [ -5285,  -5441],
                        [ -5484,  -5597],
                        [ -5694,  -5766],
                        [ -5900,  -5943],
                        [ -6104,  -6128],
                        [ -6300,  -6317],
                        [ -6489,  -6511],
                        [ -6674,  -6704],
                        [ -6853,  -6898],
                        [ -7035,  -7088],
                        [ -7218,  -7274],
                        [ -7398,  -7453],
                        [ -7573,  -7622],
                        [ -7741,  -7781],
                        [ -7900,  -7926],
                        [ -8046,  -8055],
                        [ -8177,  -8166],
                        [ -8290,  -8253],
                        [ -8382,  -8317],
                        [ -8458,  -8361],
                        [ -8547,  -8417],
                        [ -8668,  -8503],
                        [ -8820,  -8619],
                        [ -8982,  -8750],
                        [ -9112,  -8849],
                        [ -9144,  -8855],
                        [ -9057,  -8745],
                        [ -8864,  -8535],
                        [ -8573,  -8228],
                        [ -8188,  -7833],
                        [ -7721,  -7361],
                        [ -7184,  -6825],
                        [ -6585,  -6232],
                        [ -5933,  -5594],
                        [ -5241,  -4922],
                        [ -4521,  -4225],
                        [ -3777,  -3512],
                        [ -3023,  -2789],
                        [ -2264,  -2065],
                        [ -1508,  -1348],
                        [  -761,   -642],
                        [   -29,     46],
                        [   683,    713],
                        [  1371,   1353],
                        [  2030,   1964],
                        [  2658,   2542],
                        [  3252,   3088],
                        [  3807,   3598],
                        [  4324,   4071],
                        [  4800,   4513],
                        [  5236,   4921],
                        [  5629,   5300],
                        [  5981,   5651],
                        [  6290,   5976],
                        [  6558,   6276],
                        [  6784,   6550],
                        [  6970,   6798],
                        [  7115,   7011],
                        [  7222,   7190],
                        [  7291,   7334],
                        [  7324,   7443],
                        [  7322,   7512],
                        [  7287,   7544],
                        [  7222,   7530],
                        [  7126,   7473],
                        [  7001,   7371],
                        [  6849,   7227],
                        [  6672,   7047],
                        [  6472,   6831],
                        [  6250,   6591],
                        [  6008,   6329],
                        [  5750,   6051],
                        [  5478,   5757],
                        [  5194,   5453],
                        [  4900,   5139],
                        [  4600,   4819],
                        [  4295,   4496],
                        [  3989,   4170],
                        [  3683,   3846],
                        [  3381,   3526],
                        [  3084,   3213],
                        [  2795,   2907],
                        [  2516,   2612],
                        [  2246,   2331],
                        [  1986,   2065],
                        [  1738,   1816],
                        [  1502,   1585],
                        [  1278,   1376],
                        [  1069,   1190],
                        [   878,   1031],
                        [   703,    895],
                        [   550,    784],
                        [   420,    698],
                        [   288,    609],
                        [   157,    521],
                        [     3,    407],
                        [  -172,    267],
                        [  -377,     93],
                        [  -613,   -117],
                        [  -855,   -339],
                        [ -1104,   -574],
                        [ -1302,   -765],
                        [ -1454,   -915],
                        [ -1551,  -1016],
                        [ -1593,  -1067],
                        [ -1572,  -1062],
                        [ -1492,  -1003],
                        [ -1349,   -885],
                        [ -1146,   -713],
                        [  -886,   -486],
                        [  -568,   -205],
                        [  -199,    125],
                        [   219,    501],
                        [   678,    921],
                        [  1178,   1380],
                        [  1708,   1870],
                        [  2264,   2391],
                        [  2841,   2934],
                        [  3433,   3497],
                        [  4034,   4071],
                        [  4641,   4653],
                        [  5248,   5237],
                        [  5852,   5818],
                        [  6443,   6389],
                        [  7019,   6948],
                        [  7565,   7488],
                        [  8080,   8007],
                        [  8554,   8498],
                        [  8986,   8960],
                        [  9374,   9389],
                        [  9715,   9783],
                        [ 10018,  10136],
                        [ 10281,  10447],
                        [ 10507,  10714],
                        [ 10694,  10936],
                        [ 10841,  11112],
                        [ 10948,  11239],
                        [ 11017,  11321],
                        [ 11045,  11354],
                        [ 11037,  11340],
                        [ 10990,  11277],
                        [ 10905,  11167],
                        [ 10818,  11044],
                        [ 10778,  10961],
                        [ 10814,  10944],
                        [ 10929,  11001],
                        [ 11110,  11120],
                        [ 11319,  11264],
                        [ 11476,  11353],
                        [ 11529,  11337],
                        [ 11482,  11217],
                        [ 11343,  11005],
                        [ 11122,  10708],
                        [ 10827,  10338],
                        [ 10471,   9906],
                        [ 10060,   9422],
                        [  9607,   8898],
                        [  9124,   8346],
                        [  8619,   7776],
                        [  8101,   7198],
                        [  7582,   6620],
                        [  7066,   6051],
                        [  6560,   5496],
                        [  6069,   4961],
                        [  5598,   4452],
                        [  5150,   3972],
                        [  4729,   3525],
                        [  4335,   3113],
                        [  3971,   2736],
                        [  3636,   2395],
                        [  3332,   2091],
                        [  3057,   1818],
                        [  2809,   1577],
                        [  2585,   1362],
                        [  2387,   1170],
                        [  2208,    998],
                        [  2047,    841],
                        [  1899,    692],
                        [  1763,    548],
                        [  1634,    409],
                        [  1510,    271],
                        [  1387,    137],
                        [  1263,      1],
                        [  1133,   -134],
                        [   997,   -272],
                        [   852,   -407],
                        [   693,   -543],
                        [   523,   -672],
                        [   338,   -799],
                        [   140,   -925],
                        [   -74,  -1051],
                        [  -301,  -1185],
                        [  -544,  -1327],
                        [  -800,  -1483],
                        [ -1069,  -1654],
                        [ -1351,  -1840],
                        [ -1645,  -2039],
                        [ -1945,  -2251],
                        [ -2253,  -2478],
                        [ -2566,  -2715],
                        [ -2883,  -2962],
                        [ -3200,  -3216],
                        [ -3517,  -3475],
                        [ -3829,  -3738],
                        [ -4137,  -4002],
                        [ -4435,  -4265],
                        [ -4721,  -4524],
                        [ -4994,  -4777],
                        [ -5251,  -5021],
                        [ -5486,  -5252],
                        [ -5699,  -5470],
                        [ -5885,  -5675],
                        [ -6043,  -5862],
                        [ -6168,  -6029],
                        [ -6257,  -6171],
                        [ -6306,  -6281],
                        [ -6315,  -6357],
                        [ -6258,  -6372],
                        [ -6138,  -6327],
                        [ -5948,  -6214],
                        [ -5691,  -6032],
                        [ -5354,  -5769],
                        [ -4939,  -5424],
                        [ -4493,  -5044],
                        [ -4014,  -4625],
                        [ -3530,  -4195],
                        [ -3040,  -3753],
                        [ -2560,  -3313],
                        [ -2089,  -2875],
                        [ -1640,  -2449],
                        [ -1211,  -2037],
                        [  -815,  -1648],
                        [  -450,  -1281],
                        [  -123,   -945],
                        [   166,   -639],
                        [   415,   -365],
                        [   623,   -126],
                        [   791,     78],
                        [   917,    245],
                        [  1004,    376],
                        [  1053,    471],
                        [  1065,    531],
                        [  1042,    557],
                        [   985,    553],
                        [   895,    516],
                        [   777,    454],
                        [   632,    365],
                        [   471,    254],
                        [   297,    124],
                        [   117,    -23],
                        [   -65,   -184],
                        [  -243,   -353],
                        [  -415,   -531],
                        [  -581,   -711],
                        [  -739,   -891],
                        [  -892,  -1066],
                        [ -1038,  -1233],
                        [ -1172,  -1385],
                        [ -1290,  -1521],
                        [ -1391,  -1637],
                        [ -1471,  -1729],
                        [ -1527,  -1794],
                        [ -1559,  -1832],
                        [ -1560,  -1833],
                        [ -1532,  -1801],
                        [ -1527,  -1786],
                        [ -1610,  -1857],
                        [ -1806,  -2037],
                        [ -2113,  -2326],
                        [ -2520,  -2719],
                        [ -2993,  -3179],
                        [ -3428,  -3600],
                        [ -3742,  -3902],
                        [ -3928,  -4076],
                        [ -3995,  -4129],
                        [ -3946,  -4064],
                        [ -3786,  -3887],
                        [ -3524,  -3607],
                        [ -3166,  -3231],
                        [ -2724,  -2770],
                        [ -2207,  -2234],
                        [ -1627,  -1635],
                        [  -993,   -981],
                        [  -316,   -283],
                        [   394,    450],
                        [  1128,   1207],
                        [  1877,   1981],
                        [  2633,   2762],
                        [  3387,   3541],
                        [  4132,   4310],
                        [  4860,   5064],
                        [  5565,   5796],
                        [  6241,   6500],
                        [  6883,   7172],
                        [  7486,   7808],
                        [  8048,   8405],
                        [  8563,   8958],
                        [  9031,   9466],
                        [  9449,   9928],
                        [  9817,  10344],
                        [ 10133,  10714],
                        [ 10398,  11042],
                        [ 10611,  11329],
                        [ 10775,  11572],
                        [ 10890,  11772],
                        [ 10957,  11927],
                        [ 10979,  12039],
                        [ 10958,  12105],
                        [ 10896,  12125],
                        [ 10797,  12095],
                        [ 10663,  12017],
                        [ 10496,  11891],
                        [ 10299,  11720],
                        [ 10076,  11511],
                        [  9828,  11263],
                        [  9561,  10991],
                        [  9276,  10695],
                        [  8978,  10383],
                        [  8669,  10056],
                        [  8354,   9722],
                        [  8034,   9380],
                        [  7713,   9038],
                        [  7395,   8698],
                        [  7081,   8362],
                        [  6776,   8035],
                        [  6484,   7720],
                        [  6205,   7417],
                        [  5945,   7132],
                        [  5705,   6866],
                        [  5488,   6621],
                        [  5298,   6399],
                        [  5135,   6201],
                        [  5003,   6030],
                        [  4895,   5883],
                        [  4817,   5767],
                        [  4760,   5679],
                        [  4721,   5617],
                        [  4701,   5581],
                        [  4697,   5571],
                        [  4699,   5571],
                        [  4706,   5584],
                        [  4713,   5602],
                        [  4722,   5625],
                        [  4716,   5636],
                        [  4694,   5632],
                        [  4653,   5612],
                        [  4593,   5571],
                        [  4544,   5541],
                        [  4501,   5518],
                        [  4474,   5509],
                        [  4461,   5513],
                        [  4472,   5537],
                        [  4503,   5581],
                        [  4561,   5649],
                        [  4642,   5736],
                        [  4750,   5848],
                        [  4882,   5982],
                        [  5038,   6138],
                        [  5218,   6312],
                        [  5415,   6504],
                        [  5631,   6712],
                        [  5860,   6932],
                        [  6099,   7163],
                        [  6346,   7399],
                        [  6596,   7640],
                        [  6845,   7880],
                        [  7092,   8117],
                        [  7332,   8347],
                        [  7564,   8568],
                        [  7780,   8774],
                        [  7980,   8964],
                        [  8153,   9136],
                        [  8300,   9287],
                        [  8414,   9414],
                        [  8496,   9515],
                        [  8543,   9591],
                        [  8554,   9639],
                        [  8538,   9658],
                        [  8493,   9648],
                        [  8420,   9605],
                        [  8321,   9530],
                        [  8197,   9423],
                        [  8046,   9283],
                        [  7872,   9110],
                        [  7677,   8906],
                        [  7464,   8674],
                        [  7226,   8409],
                        [  6979,   8121],
                        [  6797,   7889],
                        [  6755,   7789],
                        [  6880,   7849],
                        [  7173,   8072],
                        [  7635,   8462],
                        [  8234,   8987],
                        [  8851,   9528],
                        [  9386,   9983],
                        [  9825,  10340],
                        [ 10176,  10606],
                        [ 10440,  10779],
                        [ 10617,  10866],
                        [ 10712,  10867],
                        [ 10728,  10791],
                        [ 10673,  10643],
                        [ 10552,  10430],
                        [ 10372,  10160],
                        [ 10140,   9841],
                        [  9861,   9479],
                        [  9541,   9080],
                        [  9188,   8651],
                        [  8802,   8196],
                        [  8392,   7723],
                        [  7962,   7236],
                        [  7516,   6741],
                        [  7057,   6240],
                        [  6590,   5737],
                        [  6117,   5234],
                        [  5640,   4734],
                        [  5162,   4238],
                        [  4683,   3749],
                        [  4206,   3269],
                        [  3729,   2798],
                        [  3254,   2338],
                        [  2781,   1889],
                        [  2311,   1442],
                        [  1841,    999],
                        [  1374,    553],
                        [   907,    102],
                        [   441,   -349],
                        [   -24,   -804],
                        [  -488,  -1260],
                        [  -952,  -1716],
                        [ -1415,  -2166],
                        [ -1879,  -2610],
                        [ -2338,  -3043],
                        [ -2797,  -3465],
                        [ -3252,  -3874],
                        [ -3702,  -4271],
                        [ -4145,  -4656],
                        [ -4580,  -5032],
                        [ -5005,  -5398],
                        [ -5420,  -5757],
                        [ -5822,  -6104],
                        [ -6208,  -6439],
                        [ -6576,  -6763],
                        [ -6923,  -7074],
                        [ -7250,  -7369],
                        [ -7554,  -7649],
                        [ -7833,  -7911],
                        [ -8087,  -8154],
                        [ -8314,  -8377],
                        [ -8516,  -8577],
                        [ -8692,  -8755],
                        [ -8842,  -8908],
                        [ -8970,  -9036],
                        [ -9076,  -9138],
                        [ -9158,  -9212],
                        [ -9216,  -9258],
                        [ -9244,  -9276],
                        [ -9241,  -9267],
                        [ -9198,  -9228],
                        [ -9114,  -9158],
                        [ -8990,  -9056],
                        [ -8826,  -8925],
                        [ -8630,  -8765],
                        [ -8399,  -8580],
                        [ -8138,  -8366],
                        [ -7847,  -8126],
                        [ -7505,  -7834],
                        [ -7113,  -7494],
                        [ -6682,  -7112],
                        [ -6212,  -6689],
                        [ -5722,  -6242],
                        [ -5213,  -5773],
                        [ -4701,  -5295],
                        [ -4187,  -4809],
                        [ -3684,  -4329],
                        [ -3193,  -3855],
                        [ -2728,  -3399],
                        [ -2287,  -2960],
                        [ -1880,  -2548],
                        [ -1507,  -2164],
                        [ -1174,  -1812],
                        [  -880,  -1493],
                        [  -627,  -1211],
                        [  -417,   -965],
                        [  -246,   -757],
                        [  -116,   -586],
                        [   -24,   -451],
                        [    33,   -353],
                        [    58,   -285],
                        [    51,   -250],
                        [    19,   -242],
                        [   -38,   -259],
                        [  -109,   -297],
                        [  -193,   -352],
                        [  -280,   -422],
                        [  -369,   -502],
                        [  -453,   -589],
                        [  -528,   -680],
                        [  -591,   -769],
                        [  -640,   -855],
                        [  -675,   -931],
                        [  -694,   -995],
                        [  -691,  -1038],
                        [  -666,  -1063],
                        [  -616,  -1059],
                        [  -538,  -1027],
                        [  -434,   -964],
                        [  -303,   -871],
                        [  -136,   -737],
                        [    49,   -579],
                        [   163,   -487],
                        [   130,   -537],
                        [   -67,   -749],
                        [  -432,  -1126],
                        [  -973,  -1679],
                        [ -1663,  -2380],
                        [ -2369,  -3095],
                        [ -2977,  -3707],
                        [ -3474,  -4202],
                        [ -3868,  -4587],
                        [ -4158,  -4859],
                        [ -4341,  -5016],
                        [ -4422,  -5064],
                        [ -4404,  -5006],
                        [ -4296,  -4851],
                        [ -4103,  -4604],
                        [ -3834,  -4275],
                        [ -3499,  -3872],
                        [ -3104,  -3408],
                        [ -2661,  -2888],
                        [ -2178,  -2325],
                        [ -1662,  -1725],
                        [ -1123,  -1100],
                        [  -570,   -459],
                        [   -12,    189],
                        [   544,    837],
                        [  1090,   1476],
                        [  1619,   2100],
                        [  2126,   2702],
                        [  2606,   3278],
                        [  3052,   3816],
                        [  3462,   4314],
                        [  3833,   4762],
                        [  4162,   5161],
                        [  4448,   5510],
                        [  4691,   5805],
                        [  4889,   6059],
                        [  5043,   6269],
                        [  5154,   6442],
                        [  5223,   6577],
                        [  5252,   6676],
                        [  5243,   6737],
                        [  5198,   6762],
                        [  5120,   6753],
                        [  5012,   6704],
                        [  4878,   6620],
                        [  4721,   6503],
                        [  4544,   6356],
                        [  4349,   6181],
                        [  4141,   5981],
                        [  3922,   5765],
                        [  3696,   5536],
                        [  3467,   5297],
                        [  3235,   5051],
                        [  3006,   4803],
                        [  2780,   4556],
                        [  2559,   4314],
                        [  2347,   4081],
                        [  2146,   3858],
                        [  1959,   3649],
                        [  1788,   3454],
                        [  1634,   3278],
                        [  1502,   3121],
                        [  1393,   2984],
                        [  1314,   2868],
                        [  1264,   2776],
                        [  1250,   2705],
                        [  1272,   2657],
                        [  1324,   2631],
                        [  1405,   2628],
                        [  1501,   2644],
                        [  1611,   2680],
                        [  1727,   2732],
                        [  1846,   2800],
                        [  1978,   2893],
                        [  2121,   3009],
                        [  2286,   3156],
                        [  2470,   3334],
                        [  2654,   3520],
                        [  2838,   3715],
                        [  2987,   3880],
                        [  3100,   4015],
                        [  3179,   4123],
                        [  3222,   4197],
                        [  3237,   4248],
                        [  3222,   4270],
                        [  3187,   4274],
                        [  3127,   4255],
                        [  3055,   4222],
                        [  2967,   4172],
                        [  2871,   4112],
                        [  2763,   4038],
                        [  2652,   3957],
                        [  2533,   3864],
                        [  2413,   3767],
                        [  2289,   3660],
                        [  2163,   3548],
                        [  2035,   3429],
                        [  1905,   3305],
                        [  1772,   3175],
                        [  1636,   3040],
                        [  1496,   2898],
                        [  1353,   2751],
                        [  1206,   2597],
                        [  1053,   2436],
                        [   895,   2268],
                        [   730,   2092],
                        [   557,   1909],
                        [   375,   1719],
                        [   184,   1523],
                        [   -20,   1320],
                        [  -234,   1112],
                        [  -456,    898],
                        [  -684,    679],
                        [  -919,    453],
                        [ -1159,    221],
                        [ -1402,    -19],
                        [ -1649,   -266],
                        [ -1897,   -522],
                        [ -2143,   -781],
                        [ -2386,  -1045],
                        [ -2632,  -1321],
                        [ -2854,  -1580],
                        [ -2954,  -1725],
                        [ -2863,  -1681],
                        [ -2565,  -1434],
                        [ -2058,   -980],
                        [ -1321,   -296],
                        [  -382,    591],
                        [   620,   1538],
                        [  1563,   2425],
                        [  2435,   3236],
                        [  3237,   3972],
                        [  3961,   4625],
                        [  4598,   5186],
                        [  5146,   5654],
                        [  5602,   6029],
                        [  5967,   6309],
                        [  6242,   6497],
                        [  6428,   6596],
                        [  6526,   6608],
                        [  6543,   6539],
                        [  6480,   6393],
                        [  6341,   6172],
                        [  6130,   5883],
                        [  5852,   5531],
                        [  5514,   5121],
                        [  5118,   4661],
                        [  4672,   4153],
                        [  4180,   3604],
                        [  3647,   3018],
                        [  3078,   2401],
                        [  2478,   1759],
                        [  1851,   1096],
                        [  1203,    426],
                        [   536,   -249],
                        [  -145,   -924],
                        [  -838,  -1594],
                        [ -1536,  -2263],
                        [ -2240,  -2927],
                        [ -2945,  -3598],
                        [ -3647,  -4271],
                        [ -4344,  -4944],
                        [ -5034,  -5618],
                        [ -5712,  -6287],
                        [ -6377,  -6949],
                        [ -7026,  -7599],
                        [ -7657,  -8232],
                        [ -8267,  -8846],
                        [ -8855,  -9438],
                        [ -9418, -10004],
                        [ -9954, -10542],
                        [-10459, -11051],
                        [-10934, -11529],
                        [-11375, -11974],
                        [-11781, -12387],
                        [-12150, -12763],
                        [-12480, -13102],
                        [-12768, -13404],
                        [-13015, -13670],
                        [-13219, -13895],
                        [-13379, -14084],
                        [-13497, -14233],
                        [-13573, -14344],
                        [-13609, -14416],
                        [-13606, -14451],
                        [-13570, -14448],
                        [-13502, -14408],
                        [-13413, -14333],
                        [-13302, -14223],
                        [-13175, -14079],
                        [-13032, -13904],
                        [-12865, -13697],
                        [-12677, -13462],
                        [-12454, -13198],
                        [-12200, -12908],
                        [-11923, -12605],
                        [-11624, -12288],
                        [-11337, -11991],
                        [-11061, -11713],
                        [-10801, -11458],
                        [-10561, -11227],
                        [-10303, -10985],
                        [-10034, -10735],
                        [ -9723, -10446],
                        [ -9371, -10118],
                        [ -8991,  -9763],
                        [ -8581,  -9380],
                        [ -8154,  -8980],
                        [ -7711,  -8562],
                        [ -7265,  -8140],
                        [ -6816,  -7713],
                        [ -6376,  -7293],
                        [ -5943,  -6877],
                        [ -5529,  -6476],
                        [ -5133,  -6089],
                        [ -4760,  -5722],
                        [ -4409,  -5375],
                        [ -4088,  -5051],
                        [ -3793,  -4750],
                        [ -3526,  -4475],
                        [ -3284,  -4223],
                        [ -3067,  -3995],
                        [ -2872,  -3790],
                        [ -2696,  -3607],
                        [ -2536,  -3442],
                        [ -2390,  -3292],
                        [ -2257,  -3158],
                        [ -2131,  -3033],
                        [ -2011,  -2917],
                        [ -1893,  -2805],
                        [ -1774,  -2696],
                        [ -1646,  -2585],
                        [ -1507,  -2472],
                        [ -1352,  -2354],
                        [ -1181,  -2229],
                        [  -990,  -2091],
                        [  -778,  -1939],
                        [  -545,  -1770],
                        [  -292,  -1583],
                        [   -15,  -1372],
                        [   285,  -1137],
                        [   602,   -879],
                        [   938,   -600],
                        [  1301,   -288],
                        [  1653,     20],
                        [  1896,    225],
                        [  1970,    264],
                        [  1866,    128],
                        [  1571,   -194],
                        [  1060,   -730],
                        [   350,  -1463],
                        [  -426,  -2255],
                        [ -1149,  -2987],
                        [ -1816,  -3650],
                        [ -2428,  -4246],
                        [ -2975,  -4765],
                        [ -3450,  -5201],
                        [ -3853,  -5552],
                        [ -4184,  -5819],
                        [ -4443,  -6003],
                        [ -4632,  -6105],
                        [ -4755,  -6132],
                        [ -4815,  -6088],
                        [ -4818,  -5979],
                        [ -4769,  -5812],
                        [ -4674,  -5592],
                        [ -4539,  -5328],
                        [ -4370,  -5027],
                        [ -4175,  -4695],
                        [ -3958,  -4342],
                        [ -3727,  -3973],
                        [ -3487,  -3595],
                        [ -3245,  -3214],
                        [ -3004,  -2836],
                        [ -2770,  -2468],
                        [ -2546,  -2121],
                        [ -2336,  -1798],
                        [ -2143,  -1510],
                        [ -1967,  -1259],
                        [ -1811,  -1046],
                        [ -1676,   -874],
                        [ -1562,   -729],
                        [ -1469,   -614],
                        [ -1397,   -517],
                        [ -1344,   -438],
                        [ -1310,   -376],
                        [ -1294,   -329],
                        [ -1293,   -297],
                        [ -1307,   -277],
                        [ -1330,   -271],
                        [ -1363,   -275],
                        [ -1402,   -288],
                        [ -1445,   -306],
                        [ -1491,   -332],
                        [ -1535,   -361],
                        [ -1577,   -392],
                        [ -1615,   -424],
                        [ -1648,   -456],
                        [ -1672,   -485],
                        [ -1691,   -510],
                        [ -1701,   -530],
                        [ -1701,   -540],
                        [ -1692,   -541],
                        [ -1673,   -531],
                        [ -1643,   -511],
                        [ -1600,   -477],
                        [ -1544,   -430],
                        [ -1473,   -371],
                        [ -1385,   -298],
                        [ -1276,   -213],
                        [ -1142,   -116],
                        [  -981,     -9],
                        [  -791,    108],
                        [  -579,    233],
                        [  -349,    364],
                        [  -115,    500],
                        [   123,    637],
                        [   349,    778],
                        [   566,    920],
                        [   802,   1096],
                        [  1055,   1302],
                        [  1345,   1558],
                        [  1667,   1860],
                        [  2005,   2189],
                        [  2356,   2543],
                        [  2658,   2858],
                        [  2912,   3135],
                        [  3099,   3352],
                        [  3217,   3509],
                        [  3273,   3609],
                        [  3265,   3652],
                        [  3204,   3644],
                        [  3086,   3583],
                        [  2923,   3477],
                        [  2714,   3325],
                        [  2468,   3135],
                        [  2186,   2907],
                        [  1877,   2649],
                        [  1541,   2360],
                        [  1187,   2046],
                        [   815,   1708],
                        [   433,   1354],
                        [    41,    982],
                        [  -357,    600],
                        [  -761,    205],
                        [ -1166,   -195],
                        [ -1575,   -600],
                        [ -1982,  -1008],
                        [ -2388,  -1419],
                        [ -2787,  -1827],
                        [ -3179,  -2233],
                        [ -3560,  -2635],
                        [ -3928,  -3031],
                        [ -4286,  -3421],
                        [ -4631,  -3801],
                        [ -4970,  -4170],
                        [ -5300,  -4526],
                        [ -5622,  -4869],
                        [ -5935,  -5196],
                        [ -6238,  -5510],
                        [ -6530,  -5810],
                        [ -6809,  -6096],
                        [ -7074,  -6369],
                        [ -7327,  -6631],
                        [ -7560,  -6875],
                        [ -7776,  -7105],
                        [ -7982,  -7327],
                        [ -8138,  -7503],
                        [ -8154,  -7541],
                        [ -7989,  -7396],
                        [ -7638,  -7064],
                        [ -7092,  -6534],
                        [ -6315,  -5770],
                        [ -5324,  -4791],
                        [ -4249,  -3726],
                        [ -3195,  -2687],
                        [ -2173,  -1684],
                        [ -1185,   -721],
                        [  -252,    184],
                        [   616,   1016],
                        [  1411,   1770],
                        [  2125,   2439],
                        [  2753,   3017],
                        [  3290,   3499],
                        [  3733,   3885],
                        [  4082,   4173],
                        [  4337,   4366],
                        [  4497,   4462],
                        [  4566,   4467],
                        [  4546,   4383],
                        [  4441,   4212],
                        [  4255,   3963],
                        [  3994,   3638],
                        [  3664,   3244],
                        [  3269,   2787],
                        [  2816,   2274],
                        [  2312,   1710],
                        [  1762,   1107],
                        [  1174,    469],
                        [   553,   -186],
                        [   -94,   -853],
                        [  -761,  -1521],
                        [ -1444,  -2185],
                        [ -2135,  -2845],
                        [ -2830,  -3496],
                        [ -3523,  -4148],
                        [ -4210,  -4795],
                        [ -4885,  -5438],
                        [ -5543,  -6074],
                        [ -6180,  -6699],
                        [ -6792,  -7309],
                        [ -7375,  -7899],
                        [ -7928,  -8468],
                        [ -8446,  -9011],
                        [ -8928,  -9528],
                        [ -9371, -10013],
                        [ -9774, -10466],
                        [-10133, -10878],
                        [-10449, -11249],
                        [-10719, -11576],
                        [-10944, -11858],
                        [-11122, -12092],
                        [-11252, -12277],
                        [-11333, -12415],
                        [-11366, -12506],
                        [-11351, -12550],
                        [-11291, -12549],
                        [-11187, -12504],
                        [-11040, -12416],
                        [-10857, -12288],
                        [-10637, -12122],
                        [-10390, -11918],
                        [-10120, -11681],
                        [ -9838, -11412],
                        [ -9548, -11114],
                        [ -9256, -10791],
                        [ -8963, -10442],
                        [ -8664, -10072],
                        [ -8362,  -9683],
                        [ -8044,  -9280],
                        [ -7712,  -8863],
                        [ -7387,  -8460],
                        [ -7069,  -8070],
                        [ -6806,  -7744],
                        [ -6597,  -7480],
                        [ -6447,  -7282],
                        [ -6358,  -7154],
                        [ -6286,  -7050],
                        [ -6234,  -6975],
                        [ -6140,  -6866],
                        [ -6010,  -6726],
                        [ -5844,  -6558],
                        [ -5642,  -6359],
                        [ -5408,  -6134],
                        [ -5145,  -5884],
                        [ -4859,  -5614],
                        [ -4548,  -5326],
                        [ -4225,  -5025],
                        [ -3885,  -4710],
                        [ -3538,  -4390],
                        [ -3180,  -4060],
                        [ -2822,  -3729],
                        [ -2459,  -3394],
                        [ -2100,  -3060],
                        [ -1743,  -2726],
                        [ -1389,  -2394],
                        [ -1036,  -2063],
                        [  -685,  -1735],
                        [  -334,  -1407],
                        [    18,  -1083],
                        [   372,   -759],
                        [   728,   -435],
                        [  1086,   -109],
                        [  1441,    219],
                        [  1797,    549],
                        [  2154,    885],
                        [  2511,   1224],
                        [  2876,   1570],
                        [  3249,   1921],
                        [  3637,   2277],
                        [  4038,   2637],
                        [  4453,   3005],
                        [  4882,   3378],
                        [  5320,   3758],
                        [  5768,   4143],
                        [  6225,   4538],
                        [  6687,   4938],
                        [  7147,   5341],
                        [  7606,   5745],
                        [  8067,   6156],
                        [  8485,   6532],
                        [  8786,   6793],
                        [  8939,   6909],
                        [  8942,   6878],
                        [  8775,   6680],
                        [  8395,   6272],
                        [  7804,   5659],
                        [  7111,   4951],
                        [  6404,   4238],
                        [  5683,   3525],
                        [  4953,   2815],
                        [  4230,   2125],
                        [  3524,   1465],
                        [  2840,    841],
                        [  2185,    259],
                        [  1566,   -275],
                        [   986,   -759],
                        [   448,  -1191],
                        [   -48,  -1571],
                        [  -500,  -1900],
                        [  -908,  -2178],
                        [ -1273,  -2408],
                        [ -1597,  -2592],
                        [ -1880,  -2732],
                        [ -2127,  -2833],
                        [ -2338,  -2899],
                        [ -2519,  -2932],
                        [ -2670,  -2936],
                        [ -2795,  -2917],
                        [ -2895,  -2876],
                        [ -2975,  -2820],
                        [ -3036,  -2759],
                        [ -3080,  -2696],
                        [ -3109,  -2641],
                        [ -3126,  -2595],
                        [ -3129,  -2562],
                        [ -3121,  -2542],
                        [ -3103,  -2527],
                        [ -3075,  -2515],
                        [ -3036,  -2494],
                        [ -2989,  -2467],
                        [ -2935,  -2429],
                        [ -2871,  -2379],
                        [ -2799,  -2317],
                        [ -2718,  -2243],
                        [ -2628,  -2154],
                        [ -2528,  -2048],
                        [ -2416,  -1925],
                        [ -2294,  -1783],
                        [ -2160,  -1627],
                        [ -2016,  -1455],
                        [ -1860,  -1274],
                        [ -1693,  -1083],
                        [ -1516,   -884],
                        [ -1329,   -678],
                        [ -1136,   -467],
                        [  -935,   -251],
                        [  -730,    -30],
                        [  -520,    197],
                        [  -307,    426],
                        [   -93,    659],
                        [   124,    894],
                        [   341,   1129],
                        [   560,   1363],
                        [   779,   1597],
                        [  1008,   1826],
                        [  1241,   2049],
                        [  1489,   2267],
                        [  1746,   2477],
                        [  2011,   2676],
                        [  2278,   2860],
                        [  2537,   3031],
                        [  2786,   3187],
                        [  3016,   3333],
                        [  3225,   3467],
                        [  3462,   3639],
                        [  3722,   3846],
                        [  4026,   4108],
                        [  4373,   4424],
                        [  4747,   4778],
                        [  5149,   5172],
                        [  5499,   5523],
                        [  5800,   5836],
                        [  6022,   6079],
                        [  6165,   6251],
                        [  6234,   6356],
                        [  6229,   6393],
                        [  6152,   6363],
                        [  6007,   6268],
                        [  5802,   6115],
                        [  5537,   5904],
                        [  5223,   5643],
                        [  4860,   5333],
                        [  4461,   4984],
                        [  4024,   4595],
                        [  3564,   4177],
                        [  3082,   3729],
                        [  2585,   3261],
                        [  2077,   2774],
                        [  1564,   2277],
                        [  1047,   1770],
                        [   530,   1261],
                        [    15,    751],
                        [  -492,    246],
                        [  -989,   -252],
                        [ -1467,   -739],
                        [ -1923,  -1213],
                        [ -2353,  -1671],
                        [ -2753,  -2113],
                        [ -3127,  -2532],
                        [ -3472,  -2930],
                        [ -3797,  -3304],
                        [ -4098,  -3650],
                        [ -4382,  -3968],
                        [ -4646,  -4258],
                        [ -4891,  -4521],
                        [ -5112,  -4754],
                        [ -5312,  -4960],
                        [ -5492,  -5140],
                        [ -5649,  -5295],
                        [ -5781,  -5421],
                        [ -5891,  -5523],
                        [ -5983,  -5605],
                        [ -6021,  -5629],
                        [ -5954,  -5546],
                        [ -5775,  -5345],
                        [ -5485,  -5028],
                        [ -5066,  -4577],
                        [ -4475,  -3950],
                        [ -3707,  -3144],
                        [ -2852,  -2247],
                        [ -1977,  -1334],
                        [ -1090,   -414],
                        [  -200,    505],
                        [   674,   1402],
                        [  1515,   2260],
                        [  2317,   3071],
                        [  3066,   3824],
                        [  3754,   4509],
                        [  4372,   5119],
                        [  4916,   5647],
                        [  5381,   6091],
                        [  5765,   6449],
                        [  6065,   6718],
                        [  6283,   6899],
                        [  6420,   6995],
                        [  6476,   7005],
                        [  6455,   6936],
                        [  6361,   6790],
                        [  6199,   6572],
                        [  5974,   6289],
                        [  5692,   5946],
                        [  5358,   5550],
                        [  4978,   5112],
                        [  4561,   4639],
                        [  4110,   4146],
                        [  3635,   3640],
                        [  3140,   3134],
                        [  2633,   2633],
                        [  2117,   2140],
                        [  1601,   1661],
                        [  1091,   1188],
                        [   591,    727],
                        [   107,    275],
                        [  -358,   -165],
                        [  -795,   -587],
                        [ -1205,   -990],
                        [ -1582,  -1372],
                        [ -1923,  -1732],
                        [ -2228,  -2070],
                        [ -2494,  -2385],
                        [ -2719,  -2672],
                        [ -2904,  -2932],
                        [ -3048,  -3154],
                        [ -3149,  -3340],
                        [ -3209,  -3485],
                        [ -3228,  -3589],
                        [ -3206,  -3649],
                        [ -3144,  -3666],
                        [ -3043,  -3641],
                        [ -2904,  -3576],
                        [ -2730,  -3473],
                        [ -2522,  -3335],
                        [ -2284,  -3161],
                        [ -2019,  -2958],
                        [ -1731,  -2725],
                        [ -1422,  -2466],
                        [ -1103,  -2185],
                        [  -774,  -1883],
                        [  -449,  -1566],
                        [  -131,  -1233],
                        [   174,   -891],
                        [   466,   -537],
                        [   745,   -177],
                        [  1008,    186],
                        [  1268,    548],
                        [  1522,    908],
                        [  1743,   1230],
                        [  1931,   1515],
                        [  2038,   1714],
                        [  2068,   1828],
                        [  2016,   1852],
                        [  1880,   1783],
                        [  1709,   1668],
                        [  1499,   1506],
                        [  1326,   1369],
                        [  1187,   1257],
                        [  1087,   1173],
                        [  1028,   1121],
                        [  1012,   1103],
                        [  1040,   1119],
                        [  1111,   1170],
                        [  1224,   1256],
                        [  1378,   1375],
                        [  1572,   1529],
                        [  1801,   1714],
                        [  2069,   1930],
                        [  2365,   2175],
                        [  2693,   2449],
                        [  3047,   2748],
                        [  3426,   3073],
                        [  3828,   3421],
                        [  4253,   3792],
                        [  4696,   4181],
                        [  5163,   4591],
                        [  5647,   5017],
                        [  6151,   5460],
                        [  6664,   5916],
                        [  7189,   6385],
                        [  7714,   6866],
                        [  8239,   7356],
                        [  8760,   7854],
                        [  9279,   8357],
                        [  9796,   8864],
                        [ 10312,   9371],
                        [ 10832,   9876],
                        [ 11354,  10376],
                        [ 11872,  10870],
                        [ 12387,  11353],
                        [ 12893,  11824],
                        [ 13387,  12279],
                        [ 13865,  12718],
                        [ 14324,  13139],
                        [ 14757,  13535],
                        [ 15163,  13907],
                        [ 15539,  14251],
                        [ 15857,  14540],
                        [ 16088,  14744],
                        [ 16233,  14863],
                        [ 16291,  14897],
                        [ 16238,  14821],
                        [ 16026,  14590],
                        [ 15632,  14179],
                        [ 15108,  13646],
                        [ 14504,  13039],
                        [ 13821,  12364],
                        [ 13069,  11629],
                        [ 12266,  10853],
                        [ 11422,  10047],
                        [ 10550,   9224],
                        [  9659,   8391],
                        [  8761,   7560],
                        [  7867,   6741],
                        [  6983,   5941],
                        [  6117,   5164],
                        [  5276,   4418],
                        [  4462,   3707],
                        [  3682,   3033],
                        [  2940,   2400],
                        [  2238,   1809],
                        [  1578,   1264],
                        [   964,    764],
                        [   395,    308],
                        [  -127,   -102],
                        [  -602,   -467],
                        [ -1030,   -791],
                        [ -1411,  -1073],
                        [ -1747,  -1322],
                        [ -2037,  -1539],
                        [ -2282,  -1732],
                        [ -2485,  -1904],
                        [ -2645,  -2057],
                        [ -2763,  -2195],
                        [ -2843,  -2308],
                        [ -2884,  -2399],
                        [ -2891,  -2457],
                        [ -2862,  -2485],
                        [ -2802,  -2480],
                        [ -2712,  -2443],
                        [ -2595,  -2373],
                        [ -2451,  -2270],
                        [ -2283,  -2130],
                        [ -2093,  -1956],
                        [ -1883,  -1745],
                        [ -1653,  -1501],
                        [ -1406,  -1229],
                        [ -1145,   -931],
                        [  -871,   -618],
                        [  -587,   -292],
                        [  -295,     42],
                        [     2,    384],
                        [   301,    725],
                        [   599,   1065],
                        [   893,   1402],
                        [  1182,   1735],
                        [  1463,   2060],
                        [  1735,   2375],
                        [  1994,   2678],
                        [  2240,   2967],
                        [  2474,   3241],
                        [  2692,   3498],
                        [  2901,   3734],
                        [  3100,   3950],
                        [  3291,   4145],
                        [  3477,   4316],
                        [  3652,   4461],
                        [  3817,   4578],
                        [  3967,   4669],
                        [  4100,   4734],
                        [  4214,   4783],
                        [  4310,   4816],
                        [  4438,   4885],
                        [  4593,   4986],
                        [  4795,   5140],
                        [  5042,   5345],
                        [  5328,   5597],
                        [  5656,   5897],
                        [  5943,   6166],
                        [  6199,   6409],
                        [  6388,   6593],
                        [  6514,   6721],
                        [  6575,   6789],
                        [  6572,   6801],
                        [  6507,   6753],
                        [  6382,   6649],
                        [  6200,   6492],
                        [  5963,   6282],
                        [  5679,   6028],
                        [  5349,   5727],
                        [  4984,   5391],
                        [  4583,   5018],
                        [  4160,   4617],
                        [  3714,   4191],
                        [  3255,   3747],
                        [  2784,   3287],
                        [  2308,   2819],
                        [  1829,   2344],
                        [  1351,   1870],
                        [   876,   1396],
                        [   411,    931],
                        [   -41,    476],
                        [  -470,     36],
                        [  -875,   -389],
                        [ -1246,   -794],
                        [ -1586,  -1179],
                        [ -1896,  -1540],
                        [ -2173,  -1877],
                        [ -2430,  -2186],
                        [ -2663,  -2468],
                        [ -2879,  -2722],
                        [ -3075,  -2945],
                        [ -3252,  -3140],
                        [ -3405,  -3303],
                        [ -3540,  -3438],
                        [ -3656,  -3543],
                        [ -3753,  -3624],
                        [ -3829,  -3675],
                        [ -3887,  -3702],
                        [ -3926,  -3703],
                        [ -3938,  -3670],
                        [ -3926,  -3607],
                        [ -3905,  -3527],
                        [ -3876,  -3432],
                        [ -3821,  -3306],
                        [ -3693,  -3102],
                        [ -3455,  -2785],
                        [ -3127,  -2377],
                        [ -2740,  -1911],
                        [ -2301,  -1395],
                        [ -1818,   -840],
                        [ -1309,   -263],
                        [  -785,    323],
                        [  -257,    907],
                        [   266,   1478],
                        [   769,   2025],
                        [  1249,   2539],
                        [  1696,   3013],
                        [  2104,   3441],
                        [  2469,   3817],
                        [  2789,   4140],
                        [  3062,   4405],
                        [  3285,   4615],
                        [  3458,   4766],
                        [  3582,   4862],
                        [  3658,   4902],
                        [  3689,   4891],
                        [  3676,   4832],
                        [  3625,   4730],
                        [  3538,   4587],
                        [  3421,   4414],
                        [  3277,   4214],
                        [  3110,   4001],
                        [  2927,   3778],
                        [  2731,   3556],
                        [  2526,   3340],
                        [  2319,   3134],
                        [  2113,   2943],
                        [  1911,   2762],
                        [  1719,   2595],
                        [  1541,   2439],
                        [  1379,   2298],
                        [  1237,   2170],
                        [  1116,   2061],
                        [  1021,   1962],
                        [   951,   1879],
                        [   908,   1805],
                        [   894,   1744],
                        [   906,   1693],
                        [   945,   1655],
                        [  1010,   1638],
                        [  1101,   1641],
                        [  1216,   1669],
                        [  1354,   1721],
                        [  1514,   1799],
                        [  1695,   1900],
                        [  1895,   2027],
                        [  2111,   2175],
                        [  2342,   2342],
                        [  2584,   2527],
                        [  2835,   2726],
                        [  3093,   2940],
                        [  3355,   3162],
                        [  3618,   3394],
                        [  3877,   3630],
                        [  4131,   3870],
                        [  4369,   4110],
                        [  4591,   4349],
                        [  4792,   4583],
                        [  4974,   4815],
                        [  5133,   5042],
                        [  5267,   5259],
                        [  5381,   5463],
                        [  5477,   5655],
                        [  5526,   5798],
                        [  5528,   5896],
                        [  5454,   5912],
                        [  5303,   5848],
                        [  5071,   5695],
                        [  4758,   5454],
                        [  4403,   5163],
                        [  4005,   4817],
                        [  3634,   4491],
                        [  3289,   4177],
                        [  2979,   3889],
                        [  2706,   3627],
                        [  2481,   3401],
                        [  2303,   3213],
                        [  2178,   3066],
                        [  2105,   2962],
                        [  2087,   2903],
                        [  2122,   2891],
                        [  2211,   2925],
                        [  2353,   3005],
                        [  2542,   3131],
                        [  2781,   3300],
                        [  3062,   3512],
                        [  3386,   3764],
                        [  3746,   4054],
                        [  4144,   4382],
                        [  4573,   4739],
                        [  5034,   5129],
                        [  5519,   5544],
                        [  6030,   5982],
                        [  6550,   6438],
                        [  7079,   6911],
                        [  7604,   7394],
                        [  8123,   7885],
                        [  8630,   8378],
                        [  9124,   8871],
                        [  9603,   9358],
                        [ 10068,   9835],
                        [ 10520,  10298],
                        [ 10957,  10743],
                        [ 11373,  11165],
                        [ 11762,  11559],
                        [ 12123,  11922],
                        [ 12450,  12249],
                        [ 12741,  12539],
                        [ 12991,  12786],
                        [ 13196,  12988],
                        [ 13354,  13142],
                        [ 13462,  13244],
                        [ 13525,  13302],
                        [ 13572,  13342],
                        [ 13621,  13383],
                        [ 13670,  13425],
                        [ 13700,  13447],
                        [ 13667,  13405],
                        [ 13510,  13241],
                        [ 13215,  12938],
                        [ 12797,  12515],
                        [ 12261,  11979],
                        [ 11619,  11340],
                        [ 10883,  10613],
                        [ 10069,   9810],
                        [  9189,   8945],
                        [  8253,   8028],
                        [  7277,   7074],
                        [  6273,   6094],
                        [  5251,   5100],
                        [  4223,   4104],
                        [  3199,   3114],
                        [  2187,   2141],
                        [  1195,   1190],
                        [   232,    268],
                        [  -696,   -616],
                        [ -1582,  -1458],
                        [ -2422,  -2253],
                        [ -3210,  -2998],
                        [ -3944,  -3690],
                        [ -4620,  -4326],
                        [ -5236,  -4906],
                        [ -5792,  -5429],
                        [ -6285,  -5899],
                        [ -6717,  -6315],
                        [ -7087,  -6683],
                        [ -7397,  -7004],
                        [ -7647,  -7282],
                        [ -7840,  -7516],
                        [ -7976,  -7710],
                        [ -8061,  -7863],
                        [ -8095,  -7971],
                        [ -8082,  -8037],
                        [ -8026,  -8059],
                        [ -7931,  -8041],
                        [ -7799,  -7980],
                        [ -7635,  -7880],
                        [ -7443,  -7737],
                        [ -7226,  -7551],
                        [ -6988,  -7326],
                        [ -6732,  -7064],
                        [ -6463,  -6772],
                        [ -6182,  -6455],
                        [ -5893,  -6123],
                        [ -5600,  -5779],
                        [ -5306,  -5433],
                        [ -5014,  -5086],
                        [ -4729,  -4744],
                        [ -4453,  -4409],
                        [ -4188,  -4087],
                        [ -3936,  -3779],
                        [ -3700,  -3486],
                        [ -3482,  -3213],
                        [ -3283,  -2962],
                        [ -3105,  -2734],
                        [ -2949,  -2529],
                        [ -2817,  -2351],
                        [ -2705,  -2199],
                        [ -2615,  -2076],
                        [ -2542,  -1979],
                        [ -2490,  -1910],
                        [ -2455,  -1872],
                        [ -2437,  -1864],
                        [ -2432,  -1881],
                        [ -2439,  -1924],
                        [ -2453,  -1978],
                        [ -2474,  -2045],
                        [ -2464,  -2084],
                        [ -2423,  -2096],
                        [ -2342,  -2068],
                        [ -2218,  -1997],
                        [ -2045,  -1877],
                        [ -1823,  -1705],
                        [ -1612,  -1540],
                        [ -1406,  -1377],
                        [ -1231,  -1243],
                        [ -1086,  -1133],
                        [  -975,  -1055],
                        [  -899,  -1008],
                        [  -862,   -995],
                        [  -861,  -1014],
                        [  -899,  -1067],
                        [  -973,  -1152],
                        [ -1081,  -1269],
                        [ -1221,  -1415],
                        [ -1389,  -1587],
                        [ -1584,  -1783],
                        [ -1799,  -2000],
                        [ -2034,  -2237],
                        [ -2281,  -2486],
                        [ -2541,  -2750],
                        [ -2809,  -3019],
                        [ -3083,  -3296],
                        [ -3361,  -3575],
                        [ -3641,  -3855],
                        [ -3915,  -4129],
                        [ -4184,  -4400],
                        [ -4437,  -4661],
                        [ -4672,  -4913],
                        [ -4885,  -5153],
                        [ -5075,  -5379],
                        [ -5245,  -5590],
                        [ -5393,  -5784],
                        [ -5529,  -5962],
                        [ -5653,  -6123],
                        [ -5767,  -6264],
                        [ -5871,  -6387],
                        [ -5964,  -6489],
                        [ -6044,  -6572],
                        [ -6115,  -6636],
                        [ -6175,  -6677],
                        [ -6225,  -6700],
                        [ -6266,  -6703],
                        [ -6295,  -6687],
                        [ -6316,  -6652],
                        [ -6359,  -6632],
                        [ -6474,  -6679],
                        [ -6685,  -6814],
                        [ -6993,  -7040],
                        [ -7382,  -7343],
                        [ -7808,  -7681],
                        [ -8191,  -7971],
                        [ -8482,  -8166],
                        [ -8682,  -8271],
                        [ -8798,  -8292],
                        [ -8833,  -8234],
                        [ -8796,  -8108],
                        [ -8696,  -7923],
                        [ -8540,  -7685],
                        [ -8337,  -7404],
                        [ -8096,  -7090],
                        [ -7822,  -6750],
                        [ -7525,  -6393],
                        [ -7209,  -6025],
                        [ -6881,  -5653],
                        [ -6544,  -5282],
                        [ -6203,  -4917],
                        [ -5862,  -4560],
                        [ -5526,  -4215],
                        [ -5197,  -3885],
                        [ -4876,  -3572],
                        [ -4565,  -3274],
                        [ -4266,  -2994],
                        [ -3978,  -2731],
                        [ -3701,  -2484],
                        [ -3435,  -2249],
                        [ -3179,  -2026],
                        [ -2933,  -1811],
                        [ -2694,  -1602],
                        [ -2463,  -1395],
                        [ -2236,  -1188],
                        [ -2014,   -975],
                        [ -1795,   -757],
                        [ -1577,   -533],
                        [ -1359,   -301],
                        [ -1141,    -67],
                        [  -920,    174],
                        [  -697,    415],
                        [  -470,    661],
                        [  -241,    901],
                        [    -6,   1138],
                        [   232,   1364],
                        [   475,   1580],
                        [   720,   1783],
                        [   967,   1975],
                        [  1213,   2160],
                        [  1458,   2338],
                        [  1700,   2513],
                        [  1939,   2686],
                        [  2172,   2856],
                        [  2400,   3023],
                        [  2620,   3185],
                        [  2830,   3343],
                        [  3029,   3496],
                        [  3215,   3642],
                        [  3388,   3781],
                        [  3547,   3911],
                        [  3690,   4032],
                        [  3819,   4143],
                        [  3932,   4241],
                        [  4028,   4329],
                        [  4109,   4405],
                        [  4171,   4466],
                        [  4217,   4515],
                        [  4249,   4554],
                        [  4258,   4582],
                        [  4244,   4595],
                        [  4206,   4593],
                        [  4147,   4578],
                        [  4048,   4526],
                        [  3911,   4439],
                        [  3724,   4304],
                        [  3491,   4122],
                        [  3201,   3880],
                        [  2858,   3580],
                        [  2477,   3239],
                        [  2062,   2857],
                        [  1661,   2481],
                        [  1272,   2111],
                        [   908,   1759],
                        [   572,   1426],
                        [   276,   1125],
                        [    21,    856],
                        [  -185,    627],
                        [  -343,    439],
                        [  -447,    297],
                        [  -496,    202],
                        [  -492,    154],
                        [  -434,    155],
                        [  -326,    204],
                        [  -167,    299],
                        [    37,    438],
                        [   284,    620],
                        [   570,    841],
                        [   891,   1099],
                        [  1242,   1386],
                        [  1621,   1703],
                        [  2019,   2042],
                        [  2435,   2401],
                        [  2853,   2771],
                        [  3271,   3152],
                        [  3677,   3533],
                        [  4067,   3914],
                        [  4434,   4285],
                        [  4775,   4645],
                        [  5091,   4988],
                        [  5378,   5308],
                        [  5637,   5601],
                        [  5865,   5864],
                        [  6055,   6091],
                        [  6203,   6277],
                        [  6309,   6420],
                        [  6370,   6515],
                        [  6382,   6558],
                        [  6343,   6547],
                        [  6256,   6483],
                        [  6112,   6358],
                        [  5919,   6178],
                        [  5728,   6000],
                        [  5607,   5886],
                        [  5579,   5861],
                        [  5643,   5927],
                        [  5794,   6078],
                        [  5994,   6274],
                        [  6142,   6413],
                        [  6164,   6422],
                        [  6056,   6299],
                        [  5830,   6052],
                        [  5489,   5688],
                        [  5044,   5217],
                        [  4503,   4648],
                        [  3878,   3992],
                        [  3181,   3261],
                        [  2424,   2468],
                        [  1618,   1623],
                        [   775,    740],
                        [   -93,   -169],
                        [  -977,  -1092],
                        [ -1867,  -2019],
                        [ -2754,  -2941],
                        [ -3626,  -3848],
                        [ -4475,  -4731],
                        [ -5295,  -5584],
                        [ -6077,  -6399],
                        [ -6817,  -7171],
                        [ -7509,  -7895],
                        [ -8149,  -8568],
                        [ -8734,  -9186],
                        [ -9263,  -9747],
                        [ -9731, -10251],
                        [-10142, -10694],
                        [-10492, -11080],
                        [-10784, -11408],
                        [-11018, -11681],
                        [-11196, -11902],
                        [-11322, -12078],
                        [-11397, -12209],
                        [-11424, -12297],
                        [-11407, -12346],
                        [-11351, -12357],
                        [-11259, -12331],
                        [-11135, -12270],
                        [-10983, -12175],
                        [-10810, -12045],
                        [-10618, -11883],
                        [-10412, -11688],
                        [-10195, -11464],
                        [ -9972, -11219],
                        [ -9744, -10955],
                        [ -9516, -10684],
                        [ -9290, -10407],
                        [ -9071, -10134],
                        [ -8858,  -9864],
                        [ -8656,  -9603],
                        [ -8467,  -9352],
                        [ -8290,  -9116],
                        [ -8128,  -8899],
                        [ -7982,  -8699],
                        [ -7853,  -8518],
                        [ -7740,  -8360],
                        [ -7646,  -8224],
                        [ -7572,  -8110],
                        [ -7517,  -8019],
                        [ -7483,  -7950],
                        [ -7471,  -7904],
                        [ -7479,  -7879],
                        [ -7510,  -7874],
                        [ -7557,  -7889],
                        [ -7618,  -7924],
                        [ -7681,  -7974],
                        [ -7742,  -8036],
                        [ -7796,  -8101],
                        [ -7840,  -8170],
                        [ -7860,  -8225],
                        [ -7859,  -8266],
                        [ -7826,  -8283],
                        [ -7763,  -8277],
                        [ -7650,  -8224],
                        [ -7485,  -8124],
                        [ -7296,  -8001],
                        [ -7079,  -7851],
                        [ -6853,  -7692],
                        [ -6615,  -7521],
                        [ -6377,  -7348],
                        [ -6137,  -7172],
                        [ -5905,  -7000],
                        [ -5679,  -6829],
                        [ -5469,  -6669],
                        [ -5271,  -6516],
                        [ -5090,  -6376],
                        [ -4925,  -6246],
                        [ -4778,  -6130],
                        [ -4649,  -6026],
                        [ -4538,  -5935],
                        [ -4444,  -5858],
                        [ -4366,  -5793],
                        [ -4304,  -5740],
                        [ -4256,  -5697],
                        [ -4223,  -5665],
                        [ -4201,  -5641],
                        [ -4193,  -5626],
                        [ -4192,  -5617],
                        [ -4197,  -5614],
                        [ -4203,  -5615],
                        [ -4209,  -5620],
                        [ -4210,  -5627],
                        [ -4208,  -5634],
                        [ -4202,  -5642],
                        [ -4193,  -5649],
                        [ -4186,  -5655],
                        [ -4182,  -5660],
                        [ -4180,  -5662],
                        [ -4179,  -5662],
                        [ -4178,  -5657],
                        [ -4179,  -5649],
                        [ -4179,  -5632],
                        [ -4180,  -5608],
                        [ -4180,  -5575],
                        [ -4183,  -5535],
                        [ -4180,  -5480],
                        [ -4183,  -5423],
                        [ -4265,  -5442],
                        [ -4500,  -5609],
                        [ -4907,  -5943],
                        [ -5484,  -6446],
                        [ -6234,  -7119],
                        [ -7115,  -7922],
                        [ -8006,  -8732],
                        [ -8808,  -9449],
                        [ -9510, -10064],
                        [-10117, -10582],
                        [-10625, -11000],
                        [-11034, -11319],
                        [-11347, -11543],
                        [-11568, -11676],
                        [-11702, -11722],
                        [-11752, -11687],
                        [-11725, -11578],
                        [-11626, -11400],
                        [-11460, -11161],
                        [-11234, -10868],
                        [-10951, -10525],
                        [-10617, -10140],
                        [-10241,  -9718],
                        [ -9826,  -9265],
                        [ -9379,  -8786],
                        [ -8904,  -8284],
                        [ -8407,  -7765],
                        [ -7891,  -7233],
                        [ -7360,  -6689],
                        [ -6818,  -6138],
                        [ -6268,  -5583],
                        [ -5714,  -5025],
                        [ -5155,  -4470],
                        [ -4597,  -3920],
                        [ -4042,  -3376],
                        [ -3490,  -2841],
                        [ -2944,  -2309],
                        [ -2405,  -1783],
                        [ -1876,  -1258],
                        [ -1357,   -735],
                        [  -851,   -218],
                        [  -356,    296],
                        [   124,    799],
                        [   589,   1293],
                        [  1039,   1768],
                        [  1473,   2225],
                        [  1891,   2656],
                        [  2290,   3061],
                        [  2671,   3437],
                        [  3032,   3785],
                        [  3372,   4105],
                        [  3690,   4398],
                        [  3985,   4668],
                        [  4256,   4915],
                        [  4503,   5136],
                        [  4726,   5333],
                        [  4922,   5506],
                        [  5094,   5657],
                        [  5238,   5785],
                        [  5356,   5891],
                        [  5448,   5975],
                        [  5515,   6038],
                        [  5559,   6080],
                        [  5581,   6102],
                        [  5586,   6106],
                        [  5575,   6092],
                        [  5557,   6061],
                        [  5530,   6015],
                        [  5499,   5955],
                        [  5466,   5883],
                        [  5421,   5801],
                        [  5366,   5709],
                        [  5292,   5607],
                        [  5202,   5496],
                        [  5095,   5376],
                        [  4974,   5249],
                        [  4847,   5120],
                        [  4715,   4990],
                        [  4562,   4843],
                        [  4392,   4680],
                        [  4192,   4488],
                        [  3963,   4268],
                        [  3728,   4040],
                        [  3484,   3802],
                        [  3245,   3567],
                        [  3011,   3335],
                        [  2795,   3116],
                        [  2595,   2912],
                        [  2423,   2730],
                        [  2277,   2572],
                        [  2164,   2441],
                        [  2082,   2338],
                        [  2036,   2269],
                        [  2022,   2229],
                        [  2043,   2221],
                        [  2095,   2243],
                        [  2175,   2292],
                        [  2282,   2369],
                        [  2411,   2469],
                        [  2560,   2589],
                        [  2723,   2727],
                        [  2897,   2878],
                        [  3075,   3037],
                        [  3254,   3202],
                        [  3425,   3366],
                        [  3583,   3526],
                        [  3721,   3676],
                        [  3837,   3812],
                        [  3922,   3929],
                        [  3974,   4025],
                        [  3993,   4093],
                        [  3976,   4134],
                        [  3924,   4141],
                        [  3833,   4115],
                        [  3700,   4050],
                        [  3525,   3945],
                        [  3309,   3797],
                        [  3048,   3605],
                        [  2744,   3365],
                        [  2400,   3079],
                        [  2017,   2746],
                        [  1588,   2360],
                        [  1136,   1944],
                        [   754,   1593],
                        [   514,   1378],
                        [   436,   1323],
                        [   528,   1432],
                        [   800,   1717],
                        [  1225,   2147],
                        [  1665,   2585],
                        [  2018,   2925],
                        [  2274,   3158],
                        [  2443,   3295],
                        [  2520,   3331],
                        [  2507,   3269],
                        [  2411,   3114],
                        [  2237,   2873],
                        [  1991,   2553],
                        [  1681,   2161],
                        [  1315,   1706],
                        [   901,   1200],
                        [   448,    649],
                        [   -37,     67],
                        [  -545,   -540],
                        [ -1069,  -1162],
                        [ -1600,  -1790],
                        [ -2130,  -2416],
                        [ -2651,  -3032],
                        [ -3158,  -3634],
                        [ -3646,  -4214],
                        [ -4108,  -4766],
                        [ -4541,  -5287],
                        [ -4943,  -5774],
                        [ -5310,  -6222],
                        [ -5640,  -6627],
                        [ -5933,  -6988],
                        [ -6188,  -7298],
                        [ -6406,  -7559],
                        [ -6587,  -7772],
                        [ -6732,  -7941],
                        [ -6843,  -8074],
                        [ -6920,  -8172],
                        [ -6969,  -8245],
                        [ -6988,  -8295],
                        [ -6984,  -8322],
                        [ -6958,  -8331],
                        [ -6914,  -8321],
                        [ -6856,  -8295],
                        [ -6786,  -8249],
                        [ -6708,  -8187],
                        [ -6625,  -8109],
                        [ -6541,  -8019],
                        [ -6455,  -7918],
                        [ -6372,  -7809],
                        [ -6291,  -7699],
                        [ -6216,  -7590],
                        [ -6147,  -7482],
                        [ -6086,  -7382],
                        [ -6033,  -7285],
                        [ -5987,  -7196],
                        [ -5948,  -7117],
                        [ -5917,  -7048],
                        [ -5890,  -6990],
                        [ -5870,  -6943],
                        [ -5856,  -6906],
                        [ -5847,  -6879],
                        [ -5844,  -6863],
                        [ -5848,  -6855],
                        [ -5865,  -6855],
                        [ -5891,  -6862],
                        [ -5934,  -6873],
                        [ -5989,  -6888],
                        [ -6052,  -6904],
                        [ -6121,  -6921],
                        [ -6177,  -6935],
                        [ -6219,  -6944],
                        [ -6242,  -6949],
                        [ -6246,  -6949],
                        [ -6245,  -6957],
                        [ -6237,  -6970],
                        [ -6220,  -6983],
                        [ -6193,  -6999],
                        [ -6123,  -6979],
                        [ -6011,  -6924],
                        [ -5846,  -6821],
                        [ -5626,  -6668],
                        [ -5363,  -6476],
                        [ -5055,  -6242],
                        [ -4718,  -5978],
                        [ -4348,  -5681],
                        [ -3960,  -5364],
                        [ -3552,  -5024],
                        [ -3138,  -4672],
                        [ -2716,  -4308],
                        [ -2297,  -3941],
                        [ -1881,  -3569],
                        [ -1474,  -3201],
                        [ -1077,  -2837],
                        [  -699,  -2483],
                        [  -335,  -2137],
                        [     9,  -1805],
                        [   332,  -1485],
                        [   634,  -1182],
                        [   913,   -895],
                        [  1171,   -626],
                        [  1406,   -375],
                        [  1619,   -141],
                        [  1812,     73],
                        [  1986,    271],
                        [  2139,    449],
                        [  2279,    613],
                        [  2403,    760],
                        [  2515,    891],
                        [  2614,   1008],
                        [  2699,   1112],
                        [  2771,   1200],
                        [  2832,   1277],
                        [  2882,   1341],
                        [  2923,   1397],
                        [  2954,   1442],
                        [  2979,   1484],
                        [  2997,   1523],
                        [  3007,   1559],
                        [  3010,   1594],
                        [  3018,   1640],
                        [  3000,   1665],
                        [  2862,   1571],
                        [  2535,   1291],
                        [  2015,    817],
                        [  1293,    137],
                        [   352,   -760],
                        [  -775,  -1842],
                        [ -1942,  -2962],
                        [ -3034,  -4002],
                        [ -4041,  -4951],
                        [ -4961,  -5809],
                        [ -5782,  -6563],
                        [ -6497,  -7210],
                        [ -7105,  -7746],
                        [ -7607,  -8170],
                        [ -7997,  -8482],
                        [ -8279,  -8683],
                        [ -8457,  -8777],
                        [ -8533,  -8769],
                        [ -8510,  -8662],
                        [ -8394,  -8464],
                        [ -8188,  -8180],
                        [ -7901,  -7817],
                        [ -7539,  -7382],
                        [ -7110,  -6884],
                        [ -6620,  -6327],
                        [ -6076,  -5718],
                        [ -5486,  -5067],
                        [ -4856,  -4378],
                        [ -4194,  -3659],
                        [ -3506,  -2915],
                        [ -2797,  -2156],
                        [ -2075,  -1385],
                        [ -1343,   -618],
                        [  -607,    144],
                        [   128,    889],
                        [   856,   1614],
                        [  1574,   2323],
                        [  2277,   3010],
                        [  2962,   3686],
                        [  3625,   4345],
                        [  4263,   4990],
                        [  4876,   5617],
                        [  5458,   6222],
                        [  6010,   6804],
                        [  6530,   7356],
                        [  7018,   7879],
                        [  7471,   8366],
                        [  7890,   8816],
                        [  8275,   9229],
                        [  8626,   9605],
                        [  8939,   9941],
                        [  9219,  10238],
                        [  9463,  10498],
                        [  9673,  10723],
                        [  9848,  10910],
                        [  9991,  11061],
                        [ 10099,  11177],
                        [ 10175,  11261],
                        [ 10220,  11315],
                        [ 10235,  11339],
                        [ 10222,  11338],
                        [ 10184,  11312],
                        [ 10124,  11262],
                        [ 10043,  11193],
                        [  9952,  11105],
                        [  9852,  11001],
                        [  9757,  10884],
                        [  9666,  10755],
                        [  9588,  10618],
                        [  9520,  10474],
                        [  9456,  10324],
                        [  9397,  10172],
                        [  9331,  10019],
                        [  9259,   9867],
                        [  9204,   9742],
                        [  9167,   9644],
                        [  9164,   9588],
                        [  9198,   9578],
                        [  9249,   9592],
                        [  9318,   9633],
                        [  9359,   9653],
                        [  9375,   9653],
                        [  9359,   9628],
                        [  9310,   9576],
                        [  9238,   9505],
                        [  9141,   9414],
                        [  9029,   9310],
                        [  8900,   9192],
                        [  8764,   9068],
                        [  8618,   8936],
                        [  8471,   8803],
                        [  8320,   8667],
                        [  8171,   8532],
                        [  8021,   8397],
                        [  7874,   8265],
                        [  7728,   8132],
                        [  7583,   8002],
                        [  7438,   7871],
                        [  7291,   7739],
                        [  7140,   7604],
                        [  6982,   7464],
                        [  6814,   7320],
                        [  6636,   7165],
                        [  6443,   7001],
                        [  6234,   6822],
                        [  6009,   6628],
                        [  5763,   6416],
                        [  5495,   6186],
                        [  5198,   5932],
                        [  4874,   5656],
                        [  4518,   5355],
                        [  4134,   5030],
                        [  3719,   4680],
                        [  3276,   4305],
                        [  2803,   3906],
                        [  2304,   3483],
                        [  1781,   3036],
                        [  1233,   2565],
                        [   666,   2068],
                        [    85,   1551],
                        [  -509,   1015],
                        [ -1121,    451],
                        [ -1711,    -98],
                        [ -2176,   -527],
                        [ -2459,   -779],
                        [ -2549,   -843],
                        [ -2431,   -703],
                        [ -2076,   -329],
                        [ -1503,    252],
                        [  -856,    899],
                        [  -241,   1503],
                        [   340,   2057],
                        [   886,   2564],
                        [  1384,   3012],
                        [  1828,   3395],
                        [  2221,   3714],
                        [  2557,   3967],
                        [  2839,   4155],
                        [  3066,   4278],
                        [  3239,   4340],
                        [  3363,   4344],
                        [  3440,   4297],
                        [  3473,   4203],
                        [  3466,   4067],
                        [  3424,   3894],
                        [  3352,   3693],
                        [  3253,   3467],
                        [  3135,   3220],
                        [  2998,   2960],
                        [  2851,   2690],
                        [  2693,   2414],
                        [  2531,   2137],
                        [  2365,   1861],
                        [  2199,   1592],
                        [  2035,   1337],
                        [  1873,   1096],
                        [  1715,    882],
                        [  1562,    694],
                        [  1414,    531],
                        [  1272,    396],
                        [  1137,    275],
                        [  1008,    168],
                        [   884,     63],
                        [   767,    -40],
                        [   653,   -144],
                        [   544,   -248],
                        [   436,   -353],
                        [   332,   -460],
                        [   227,   -566],
                        [   120,   -673],
                        [    14,   -782],
                        [   -95,   -893],
                        [  -205,  -1004],
                        [  -318,  -1117],
                        [  -431,  -1229],
                        [  -545,  -1342],
                        [  -661,  -1454],
                        [  -775,  -1565],
                        [  -887,  -1672],
                        [  -997,  -1776],
                        [ -1099,  -1877],
                        [ -1195,  -1975],
                        [ -1281,  -2067],
                        [ -1358,  -2155],
                        [ -1424,  -2236],
                        [ -1476,  -2309],
                        [ -1519,  -2373],
                        [ -1550,  -2428],
                        [ -1580,  -2470],
                        [ -1607,  -2500],
                        [ -1637,  -2516],
                        [ -1668,  -2517],
                        [ -1697,  -2500],
                        [ -1722,  -2467],
                        [ -1725,  -2414],
                        [ -1707,  -2342],
                        [ -1674,  -2267],
                        [ -1623,  -2186],
                        [ -1594,  -2138],
                        [ -1581,  -2119],
                        [ -1588,  -2130],
                        [ -1613,  -2169],
                        [ -1614,  -2194],
                        [ -1593,  -2206],
                        [ -1505,  -2157],
                        [ -1351,  -2051],
                        [ -1140,  -1891],
                        [  -869,  -1676],
                        [  -551,  -1415],
                        [  -184,  -1109],
                        [   216,   -768],
                        [   651,   -392],
                        [  1106,      9],
                        [  1581,    433],
                        [  2064,    869],
                        [  2554,   1320],
                        [  3040,   1771],
                        [  3521,   2225],
                        [  3987,   2672],
                        [  4438,   3112],
                        [  4869,   3538],
                        [  5279,   3951],
                        [  5664,   4345],
                        [  6025,   4719],
                        [  6359,   5070],
                        [  6666,   5397],
                        [  6942,   5701],
                        [  7188,   5978],
                        [  7403,   6230],
                        [  7586,   6457],
                        [  7742,   6659],
                        [  7872,   6836],
                        [  7982,   6990],
                        [  8073,   7122],
                        [  8147,   7230],
                        [  8204,   7318],
                        [  8248,   7386],
                        [  8278,   7434],
                        [  8297,   7467],
                        [  8305,   7482],
                        [  8305,   7486],
                        [  8298,   7482],
                        [  8280,   7469],
                        [  8257,   7450],
                        [  8237,   7438],
                        [  8179,   7386],
                        [  7996,   7209],
                        [  7646,   6864],
                        [  7131,   6350],
                        [  6437,   5651],
                        [  5527,   4736],
                        [  4425,   3629],
                        [  3265,   2467],
                        [  2147,   1352],
                        [  1080,    294],
                        [    67,   -702],
                        [  -872,  -1618],
                        [ -1727,  -2442],
                        [ -2493,  -3170],
                        [ -3163,  -3796],
                        [ -3733,  -4315],
                        [ -4200,  -4725],
                        [ -4565,  -5025],
                        [ -4827,  -5216],
                        [ -4988,  -5302],
                        [ -5051,  -5286],
                        [ -5020,  -5174],
                        [ -4899,  -4969],
                        [ -4697,  -4681],
                        [ -4418,  -4314],
                        [ -4071,  -3879],
                        [ -3660,  -3380],
                        [ -3196,  -2826],
                        [ -2686,  -2225],
                        [ -2136,  -1584],
                        [ -1554,   -912],
                        [  -947,   -219],
                        [  -322,    489],
                        [   314,   1192],
                        [   957,   1886],
                        [  1597,   2559],
                        [  2233,   3205],
                        [  2856,   3825],
                        [  3462,   4414],
                        [  4048,   4984],
                        [  4608,   5531],
                        [  5140,   6058],
                        [  5641,   6563],
                        [  6109,   7042],
                        [  6543,   7494],
                        [  6941,   7916],
                        [  7303,   8307],
                        [  7629,   8668],
                        [  7918,   8996],
                        [  8170,   9292],
                        [  8387,   9557],
                        [  8570,   9786],
                        [  8720,   9980],
                        [  8837,  10140],
                        [  8922,  10265],
                        [  8978,  10356],
                        [  9006,  10412],
                        [  9007,  10438],
                        [  8981,  10433],
                        [  8933,  10403],
                        [  8862,  10350],
                        [  8772,  10275],
                        [  8665,  10181],
                        [  8544,  10071],
                        [  8413,   9947],
                        [  8282,   9812],
                        [  8151,   9667],
                        [  8036,   9516],
                        [  7936,   9360],
                        [  7858,   9202],
                        [  7801,   9041],
                        [  7757,   8880],
                        [  7730,   8723],
                        [  7707,   8574],
                        [  7690,   8435],
                        [  7718,   8351],
                        [  7788,   8319],
                        [  7923,   8362],
                        [  8119,   8479],
                        [  8358,   8651],
                        [  8642,   8878],
                        [  8894,   9087],
                        [  9119,   9280],
                        [  9290,   9432],
                        [  9408,   9540],
                        [  9476,   9609],
                        [  9490,   9636],
                        [  9458,   9624],
                        [  9375,   9571],
                        [  9249,   9481],
                        [  9077,   9353],
                        [  8868,   9191],
                        [  8620,   8994],
                        [  8339,   8767],
                        [  8023,   8509],
                        [  7678,   8222],
                        [  7304,   7906],
                        [  6905,   7566],
                        [  6480,   7199],
                        [  6030,   6808],
                        [  5555,   6393],
                        [  5057,   5956],
                        [  4534,   5497],
                        [  3990,   5015],
                        [  3426,   4513],
                        [  2849,   3991],
                        [  2257,   3450],
                        [  1653,   2891],
                        [  1037,   2315],
                        [   405,   1723],
                        [  -242,   1116],
                        [  -907,    496],
                        [ -1584,   -134],
                        [ -2274,   -771],
                        [ -2971,  -1413],
                        [ -3675,  -2056],
                        [ -4380,  -2698],
                        [ -5081,  -3335],
                        [ -5778,  -3968],
                        [ -6463,  -4595],
                        [ -7132,  -5207],
                        [ -7782,  -5809],
                        [ -8414,  -6399],
                        [ -8984,  -6931],
                        [ -9414,  -7330],
                        [ -9674,  -7561],
                        [ -9762,  -7625],
                        [ -9657,  -7498],
                        [ -9315,  -7136],
                        [ -8743,  -6553],
                        [ -8056,  -5861],
                        [ -7335,  -5149],
                        [ -6586,  -4418],
                        [ -5814,  -3677],
                        [ -5038,  -2943],
                        [ -4268,  -2227],
                        [ -3512,  -1536],
                        [ -2780,   -877],
                        [ -2077,   -258],
                        [ -1410,    316],
                        [  -782,    843],
                        [  -199,   1318],
                        [   338,   1740],
                        [   826,   2110],
                        [  1264,   2427],
                        [  1653,   2693],
                        [  1992,   2911],
                        [  2284,   3080],
                        [  2529,   3205],
                        [  2730,   3286],
                        [  2887,   3326],
                        [  3004,   3330],
                        [  3082,   3300],
                        [  3123,   3239],
                        [  3131,   3148],
                        [  3105,   3039],
                        [  3049,   2914],
                        [  2965,   2787],
                        [  2854,   2658],
                        [  2720,   2530],
                        [  2565,   2407],
                        [  2392,   2276],
                        [  2201,   2142],
                        [  1996,   1989],
                        [  1779,   1818],
                        [  1550,   1632],
                        [  1312,   1430],
                        [  1067,   1214],
                        [   815,    984],
                        [   560,    742],
                        [   301,    487],
                        [    44,    219],
                        [  -215,    -59],
                        [  -470,   -341],
                        [  -721,   -630],
                        [  -964,   -914],
                        [ -1201,  -1195],
                        [ -1425,  -1467],
                        [ -1639,  -1727],
                        [ -1837,  -1972],
                        [ -2017,  -2200],
                        [ -2178,  -2411],
                        [ -2318,  -2602],
                        [ -2434,  -2774],
                        [ -2525,  -2923],
                        [ -2592,  -3049],
                        [ -2631,  -3152],
                        [ -2647,  -3229],
                        [ -2639,  -3281],
                        [ -2617,  -3306],
                        [ -2581,  -3304],
                        [ -2540,  -3277],
                        [ -2490,  -3221],
                        [ -2431,  -3137],
                        [ -2367,  -3026],
                        [ -2283,  -2891],
                        [ -2180,  -2731],
                        [ -2078,  -2577],
                        [ -1975,  -2429],
                        [ -1920,  -2336],
                        [ -1909,  -2293],
                        [ -1945,  -2307],
                        [ -2030,  -2377],
                        [ -2118,  -2456],
                        [ -2212,  -2550],
                        [ -2245,  -2588],
                        [ -2221,  -2577],
                        [ -2143,  -2518],
                        [ -2011,  -2410],
                        [ -1829,  -2256],
                        [ -1601,  -2058],
                        [ -1334,  -1824],
                        [ -1030,  -1554],
                        [  -700,  -1257],
                        [  -343,   -932],
                        [    28,   -592],
                        [   412,   -234],
                        [   799,    131],
                        [  1187,    502],
                        [  1567,    871],
                        [  1940,   1238],
                        [  2298,   1596],
                        [  2640,   1944],
                        [  2966,   2277],
                        [  3272,   2595],
                        [  3558,   2893],
                        [  3822,   3173],
                        [  4056,   3430],
                        [  4262,   3665],
                        [  4436,   3878],
                        [  4579,   4069],
                        [  4697,   4236],
                        [  4788,   4383],
                        [  4864,   4509],
                        [  4926,   4614],
                        [  4977,   4700],
                        [  5016,   4765],
                        [  5047,   4813],
                        [  5071,   4843],
                        [  5086,   4858],
                        [  5095,   4856],
                        [  5101,   4845],
                        [  5101,   4821],
                        [  5094,   4789],
                        [  5084,   4751],
                        [  5077,   4712],
                        [  5030,   4632],
                        [  4900,   4465],
                        [  4674,   4197],
                        [  4354,   3832],
                        [  3919,   3347],
                        [  3322,   2698],
                        [  2564,   1887],
                        [  1735,   1009],
                        [   899,    129],
                        [    63,   -745],
                        [  -766,  -1604],
                        [ -1568,  -2428],
                        [ -2332,  -3205],
                        [ -3051,  -3927],
                        [ -3714,  -4585],
                        [ -4315,  -5172],
                        [ -4848,  -5681],
                        [ -5311,  -6109],
                        [ -5701,  -6455],
                        [ -6016,  -6718],
                        [ -6257,  -6897],
                        [ -6424,  -6996],
                        [ -6521,  -7018],
                        [ -6550,  -6966],
                        [ -6516,  -6846],
                        [ -6423,  -6664],
                        [ -6277,  -6424],
                        [ -6083,  -6133],
                        [ -5847,  -5798],
                        [ -5574,  -5425],
                        [ -5271,  -5021],
                        [ -4943,  -4596],
                        [ -4595,  -4154],
                        [ -4232,  -3713],
                        [ -3861,  -3281],
                        [ -3485,  -2865],
                        [ -3108,  -2471],
                        [ -2736,  -2101],
                        [ -2373,  -1761],
                        [ -2021,  -1433],
                        [ -1683,  -1124],
                        [ -1362,   -826],
                        [ -1060,   -544],
                        [  -779,   -275],
                        [  -519,    -25],
                        [  -280,    212],
                        [   -65,    433],
                        [   128,    643],
                        [   298,    841],
                        [   447,   1027],
                        [   575,   1203],
                        [   685,   1363],
                        [   776,   1509],
                        [   850,   1634],
                        [   908,   1742],
                        [   952,   1830],
                        [   982,   1899],
                        [   999,   1950],
                        [  1005,   1984],
                        [  1001,   2004],
                        [   988,   2012],
                        [   968,   2009],
                        [   940,   1995],
                        [   909,   1973],
                        [   876,   1944],
                        [   847,   1910],
                        [   823,   1871],
                        [   816,   1830],
                        [   825,   1786],
                        [   852,   1739],
                        [   896,   1688],
                        [   956,   1636],
                        [  1030,   1584],
                        [  1113,   1541],
                        [  1204,   1507],
                        [  1350,   1536],
                        [  1547,   1622],
                        [  1810,   1787],
                        [  2140,   2027],
                        [  2519,   2329],
                        [  2948,   2693],
                        [  3339,   3033],
                        [  3698,   3353],
                        [  3989,   3619],
                        [  4212,   3832],
                        [  4366,   3986],
                        [  4446,   4082],
                        [  4453,   4115],
                        [  4388,   4087],
                        [  4252,   3997],
                        [  4044,   3845],
                        [  3770,   3634],
                        [  3431,   3363],
                        [  3034,   3038],
                        [  2577,   2657],
                        [  2071,   2227],
                        [  1514,   1748],
                        [   916,   1226],
                        [   275,    661],
                        [  -401,     61],
                        [ -1112,   -575],
                        [ -1853,  -1241],
                        [ -2620,  -1934],
                        [ -3404,  -2649],
                        [ -4203,  -3384],
                        [ -5003,  -4133],
                        [ -5803,  -4894],
                        [ -6598,  -5662],
                        [ -7386,  -6433],
                        [ -8168,  -7201],
                        [ -8942,  -7966],
                        [ -9710,  -8721],
                        [-10470,  -9463],
                        [-11213, -10186],
                        [-11936, -10888],
                        [-12636, -11562],
                        [-13307, -12205],
                        [-13946, -12812],
                        [-14549, -13383],
                        [-15110, -13912],
                        [-15625, -14397],
                        [-16093, -14837],
                        [-16512, -15230],
                        [-16851, -15546],
                        [-17085, -15758],
                        [-17214, -15867],
                        [-17239, -15871],
                        [-17134, -15746],
                        [-16853, -15446],
                        [-16376, -14952],
                        [-15763, -14327],
                        [-15065, -13622],
                        [-14282, -12840],
                        [-13431, -11997],
                        [-12528, -11110],
                        [-11590, -10196],
                        [-10628,  -9266],
                        [ -9656,  -8332],
                        [ -8685,  -7407],
                        [ -7726,  -6502],
                        [ -6788,  -5623],
                        [ -5880,  -4782],
                        [ -5009,  -3983],
                        [ -4183,  -3235],
                        [ -3405,  -2539],
                        [ -2681,  -1900],
                        [ -2014,  -1320],
                        [ -1407,   -800],
                        [  -860,   -341],
                        [  -377,     55],
                        [    46,    392],
                        [   408,    669],
                        [   709,    887],
                        [   951,   1051],
                        [  1138,   1162],
                        [  1268,   1230],
                        [  1346,   1259],
                        [  1376,   1259],
                        [  1361,   1232],
                        [  1303,   1186],
                        [  1207,   1125],
                        [  1077,   1042],
                        [   917,    943],
                        [   731,    816],
                        [   523,    665],
                        [   297,    489],
                        [    55,    295],
                        [  -196,     82],
                        [  -454,   -148],
                        [  -715,   -395],
                        [  -977,   -657],
                        [ -1233,   -933],
                        [ -1483,  -1222],
                        [ -1723,  -1515],
                        [ -1952,  -1813],
                        [ -2165,  -2101],
                        [ -2361,  -2380],
                        [ -2537,  -2641],
                        [ -2693,  -2884],
                        [ -2823,  -3103],
                        [ -2929,  -3295],
                        [ -3007,  -3460],
                        [ -3057,  -3596],
                        [ -3078,  -3703],
                        [ -3068,  -3778],
                        [ -3030,  -3823],
                        [ -2961,  -3837],
                        [ -2867,  -3820],
                        [ -2746,  -3772],
                        [ -2609,  -3696],
                        [ -2455,  -3590],
                        [ -2295,  -3456],
                        [ -2123,  -3295],
                        [ -1946,  -3106],
                        [ -1768,  -2896],
                        [ -1584,  -2667],
                        [ -1393,  -2420],
                        [ -1229,  -2196],
                        [ -1087,  -1994],
                        [ -1010,  -1857],
                        [  -996,  -1785],
                        [ -1055,  -1788],
                        [ -1186,  -1866],
                        [ -1346,  -1978],
                        [ -1540,  -2129],
                        [ -1697,  -2247],
                        [ -1823,  -2341],
                        [ -1914,  -2404],
                        [ -1970,  -2439],
                        [ -1990,  -2442],
                        [ -1974,  -2415],
                        [ -1926,  -2358],
                        [ -1845,  -2274],
                        [ -1738,  -2167],
                        [ -1604,  -2035],
                        [ -1451,  -1887],
                        [ -1279,  -1718],
                        [ -1095,  -1539],
                        [  -900,  -1346],
                        [  -701,  -1148],
                        [  -497,   -943],
                        [  -295,   -738],
                        [   -92,   -531],
                        [   108,   -327],
                        [   306,   -128],
                        [   496,     67],
                        [   678,    254],
                        [   845,    433],
                        [   995,    604],
                        [  1125,    764],
                        [  1237,    915],
                        [  1334,   1055],
                        [  1417,   1185],
                        [  1498,   1306],
                        [  1578,   1416],
                        [  1656,   1517],
                        [  1735,   1607],
                        [  1812,   1688],
                        [  1889,   1759],
                        [  1965,   1820],
                        [  2042,   1870],
                        [  2117,   1913],
                        [  2192,   1945],
                        [  2264,   1969],
                        [  2334,   1986],
                        [  2401,   1996],
                        [  2453,   1986],
                        [  2493,   1961],
                        [  2532,   1932],
                        [  2570,   1899],
                        [  2585,   1838],
                        [  2525,   1702],
                        [  2356,   1454],
                        [  2099,   1120],
                        [  1783,    732],
                        [  1411,    293],
                        [   995,   -184],
                        [   546,   -686],
                        [    78,  -1198],
                        [  -403,  -1715],
                        [  -886,  -2225],
                        [ -1363,  -2719],
                        [ -1827,  -3191],
                        [ -2272,  -3633],
                        [ -2693,  -4040],
                        [ -3087,  -4409],
                        [ -3448,  -4735],
                        [ -3775,  -5018],
                        [ -4067,  -5257],
                        [ -4323,  -5452],
                        [ -4543,  -5603],
                        [ -4726,  -5714],
                        [ -4875,  -5786],
                        [ -4991,  -5822],
                        [ -5078,  -5824],
                        [ -5137,  -5796],
                        [ -5170,  -5744],
                        [ -5180,  -5670],
                        [ -5170,  -5582],
                        [ -5142,  -5488],
                        [ -5100,  -5394],
                        [ -5046,  -5305],
                        [ -4982,  -5224],
                        [ -4912,  -5158],
                        [ -4838,  -5106],
                        [ -4760,  -5059],
                        [ -4683,  -5020],
                        [ -4605,  -4981],
                        [ -4531,  -4948],
                        [ -4459,  -4916],
                        [ -4390,  -4886],
                        [ -4326,  -4852],
                        [ -4265,  -4817],
                        [ -4209,  -4773],
                        [ -4157,  -4720],
                        [ -4109,  -4656],
                        [ -4064,  -4582],
                        [ -4021,  -4502],
                        [ -3980,  -4418],
                        [ -3939,  -4334],
                        [ -3898,  -4250],
                        [ -3856,  -4169],
                        [ -3813,  -4089],
                        [ -3768,  -4014],
                        [ -3722,  -3941],
                        [ -3673,  -3869],
                        [ -3622,  -3798],
                        [ -3569,  -3729],
                        [ -3512,  -3661],
                        [ -3452,  -3595],
                        [ -3391,  -3528],
                        [ -3323,  -3463],
                        [ -3250,  -3398],
                        [ -3166,  -3335],
                        [ -3075,  -3273],
                        [ -2974,  -3216],
                        [ -2864,  -3166],
                        [ -2746,  -3118],
                        [ -2620,  -3073],
                        [ -2482,  -3021],
                        [ -2337,  -2964],
                        [ -2143,  -2854],
                        [ -1905,  -2698],
                        [ -1613,  -2479],
                        [ -1268,  -2201],
                        [  -878,  -1868],
                        [  -441,  -1480],
                        [   -38,  -1115],
                        [   336,   -769],
                        [   648,   -470],
                        [   899,   -223],
                        [  1080,    -34],
                        [  1191,     98],
                        [  1228,    164],
                        [  1190,    167],
                        [  1076,    102],
                        [   887,    -28],
                        [   627,   -222],
                        [   297,   -481],
                        [   -98,   -800],
                        [  -555,  -1179],
                        [ -1065,  -1612],
                        [ -1628,  -2096],
                        [ -2235,  -2626],
                        [ -2883,  -3199],
                        [ -3564,  -3806],
                        [ -4275,  -4446],
                        [ -5009,  -5111],
                        [ -5762,  -5796],
                        [ -6520,  -6496],
                        [ -7277,  -7205],
                        [ -8019,  -7915],
                        [ -8747,  -8625],
                        [ -9450,  -9325],
                        [-10128, -10013],
                        [-10780, -10680],
                        [-11406, -11325],
                        [-12005, -11940],
                        [-12573, -12521],
                        [-13104, -13063],
                        [-13595, -13563],
                        [-14041, -14016],
                        [-14440, -14418],
                        [-14788, -14766],
                        [-15082, -15057],
                        [-15321, -15289],
                        [-15500, -15458],
                        [-15620, -15564],
                        [-15677, -15607],
                        [-15683, -15597],
                        [-15663, -15559],
                        [-15638, -15515],
                        [-15608, -15463],
                        [-15556, -15385],
                        [-15434, -15234],
                        [-15186, -14953],
                        [-14805, -14536],
                        [-14307, -14004],
                        [-13700, -13363],
                        [-12998, -12629],
                        [-12216, -11816],
                        [-11369, -10942],
                        [-10468, -10017],
                        [ -9530,  -9057],
                        [ -8566,  -8075],
                        [ -7590,  -7084],
                        [ -6611,  -6095],
                        [ -5640,  -5121],
                        [ -4688,  -4171],
                        [ -3765,  -3254],
                        [ -2876,  -2377],
                        [ -2030,  -1546],
                        [ -1233,   -769],
                        [  -490,    -48],
                        [   197,    613],
                        [   825,   1214],
                        [  1392,   1752],
                        [  1896,   2227],
                        [  2340,   2639],
                        [  2723,   2992],
                        [  3046,   3284],
                        [  3312,   3525],
                        [  3522,   3717],
                        [  3681,   3868],
                        [  3791,   3979],
                        [  3857,   4058],
                        [  3883,   4111],
                        [  3874,   4140],
                        [  3833,   4145],
                        [  3766,   4127],
                        [  3677,   4086],
                        [  3571,   4026],
                        [  3452,   3950],
                        [  3324,   3856],
                        [  3193,   3752],
                        [  3062,   3633],
                        [  2935,   3499],
                        [  2815,   3355],
                        [  2706,   3200],
                        [  2611,   3040],
                        [  2531,   2878],
                        [  2468,   2726],
                        [  2425,   2586],
                        [  2402,   2464],
                        [  2401,   2360],
                        [  2421,   2279],
                        [  2466,   2223],
                        [  2533,   2192],
                        [  2622,   2186],
                        [  2732,   2207],
                        [  2864,   2254],
                        [  3015,   2324],
                        [  3185,   2420],
                        [  3370,   2537],
                        [  3571,   2676],
                        [  3781,   2835],
                        [  3998,   3010],
                        [  4218,   3200],
                        [  4440,   3407],
                        [  4657,   3625],
                        [  4866,   3850],
                        [  5062,   4077],
                        [  5243,   4305],
                        [  5381,   4499],
                        [  5475,   4658],
                        [  5502,   4754],
                        [  5460,   4787],
                        [  5338,   4743],
                        [  5136,   4619],
                        [  4882,   4444],
                        [  4574,   4213],
                        [  4271,   3984],
                        [  3966,   3751],
                        [  3670,   3522],
                        [  3382,   3296],
                        [  3112,   3083],
                        [  2859,   2882],
                        [  2629,   2698],
                        [  2421,   2529],
                        [  2238,   2378],
                        [  2078,   2247],
                        [  1944,   2134],
                        [  1834,   2041],
                        [  1745,   1967],
                        [  1679,   1912],
                        [  1632,   1874],
                        [  1606,   1855],
                        [  1597,   1850],
                        [  1606,   1861],
                        [  1632,   1887],
                        [  1675,   1926],
                        [  1730,   1976],
                        [  1796,   2038],
                        [  1864,   2108],
                        [  1935,   2189],
                        [  2004,   2277],
                        [  2073,   2373],
                        [  2143,   2472],
                        [  2217,   2579],
                        [  2300,   2688],
                        [  2394,   2800],
                        [  2498,   2913],
                        [  2609,   3027],
                        [  2727,   3140],
                        [  2850,   3252],
                        [  2977,   3361],
                        [  3106,   3465],
                        [  3237,   3562],
                        [  3368,   3651],
                        [  3495,   3731],
                        [  3618,   3799],
                        [  3733,   3856],
                        [  3874,   3936],
                        [  4086,   4084],
                        [  4391,   4324],
                        [  4784,   4651],
                        [  5252,   5049],
                        [  5745,   5469],
                        [  6181,   5829],
                        [  6513,   6085],
                        [  6745,   6241],
                        [  6880,   6304],
                        [  6926,   6278],
                        [  6888,   6175],
                        [  6776,   6002],
                        [  6595,   5766],
                        [  6356,   5477],
                        [  6065,   5144],
                        [  5731,   4774],
                        [  5360,   4376],
                        [  4960,   3957],
                        [  4537,   3525],
                        [  4097,   3084],
                        [  3649,   2641],
                        [  3195,   2203],
                        [  2742,   1771],
                        [  2295,   1352],
                        [  1856,    946],
                        [  1428,    555],
                        [  1016,    181],
                        [   619,   -173],
                        [   241,   -508],
                        [  -118,   -824],
                        [  -455,  -1121],
                        [  -772,  -1399],
                        [ -1066,  -1662],
                        [ -1339,  -1910],
                        [ -1588,  -2144],
                        [ -1816,  -2366],
                        [ -2022,  -2580],
                        [ -2206,  -2786],
                        [ -2368,  -2981],
                        [ -2510,  -3166],
                        [ -2631,  -3335],
                        [ -2732,  -3492],
                        [ -2815,  -3632],
                        [ -2879,  -3755],
                        [ -2924,  -3855],
                        [ -2953,  -3934],
                        [ -2965,  -3983],
                        [ -2961,  -4003],
                        [ -2942,  -3993],
                        [ -2909,  -3954],
                        [ -2861,  -3891],
                        [ -2801,  -3805],
                        [ -2726,  -3704],
                        [ -2639,  -3589],
                        [ -2541,  -3460],
                        [ -2431,  -3322],
                        [ -2312,  -3174],
                        [ -2184,  -3020],
                        [ -2047,  -2860],
                        [ -1903,  -2696],
                        [ -1753,  -2529],
                        [ -1600,  -2361],
                        [ -1445,  -2194],
                        [ -1289,  -2028],
                        [ -1135,  -1865],
                        [  -985,  -1708],
                        [  -839,  -1556],
                        [  -701,  -1411],
                        [  -573,  -1279],
                        [  -454,  -1159],
                        [  -340,  -1051],
                        [  -232,   -955],
                        [  -120,   -862],
                        [    -9,   -775],
                        [   125,   -667],
                        [   279,   -542],
                        [   457,   -391],
                        [   660,   -215],
                        [   894,     -5],
                        [  1159,    241],
                        [  1406,    472],
                        [  1637,    692],
                        [  1828,    879],
                        [  1980,   1034],
                        [  2083,   1146],
                        [  2138,   1217],
                        [  2136,   1239],
                        [  2080,   1213],
                        [  1966,   1135],
                        [  1796,   1008],
                        [  1571,    830],
                        [  1292,    602],
                        [   964,    329],
                        [   591,     11],
                        [   176,   -347],
                        [  -275,   -743],
                        [  -756,  -1170],
                        [ -1263,  -1624],
                        [ -1788,  -2100],
                        [ -2329,  -2594],
                        [ -2876,  -3096],
                        [ -3426,  -3606],
                        [ -3963,  -4113],
                        [ -4486,  -4616],
                        [ -4981,  -5106],
                        [ -5448,  -5579],
                        [ -5878,  -6030],
                        [ -6269,  -6455],
                        [ -6624,  -6845],
                        [ -6940,  -7201],
                        [ -7218,  -7516],
                        [ -7456,  -7788],
                        [ -7646,  -8013],
                        [ -7789,  -8189],
                        [ -7882,  -8313],
                        [ -7925,  -8384],
                        [ -7916,  -8399],
                        [ -7855,  -8357],
                        [ -7742,  -8257],
                        [ -7579,  -8100],
                        [ -7360,  -7881],
                        [ -7094,  -7611],
                        [ -6839,  -7347],
                        [ -6659,  -7154],
                        [ -6579,  -7057],
                        [ -6599,  -7057],
                        [ -6718,  -7147],
                        [ -6892,  -7285],
                        [ -7018,  -7369],
                        [ -7031,  -7331],
                        [ -6931,  -7174],
                        [ -6725,  -6907],
                        [ -6420,  -6537],
                        [ -6026,  -6074],
                        [ -5553,  -5530],
                        [ -5010,  -4914],
                        [ -4407,  -4238],
                        [ -3757,  -3515],
                        [ -3068,  -2755],
                        [ -2351,  -1970],
                        [ -1615,  -1168],
                        [  -871,   -362],
                        [  -126,    440],
                        [   611,   1231],
                        [  1333,   2000],
                        [  2031,   2740],
                        [  2703,   3448],
                        [  3343,   4119],
                        [  3946,   4750],
                        [  4510,   5338],
                        [  5034,   5882],
                        [  5516,   6380],
                        [  5956,   6833],
                        [  6355,   7241],
                        [  6715,   7607],
                        [  7033,   7931],
                        [  7316,   8216],
                        [  7563,   8463],
                        [  7777,   8680],
                        [  7963,   8869],
                        [  8123,   9038],
                        [  8262,   9190],
                        [  8381,   9327],
                        [  8484,   9451],
                        [  8576,   9564],
                        [  8659,   9669],
                        [  8736,   9764],
                        [  8812,   9853],
                        [  8887,   9931],
                        [  8966,  10000],
                        [  9050,  10059],
                        [  9142,  10108],
                        [  9242,  10152],
                        [  9354,  10190],
                        [  9474,  10233],
                        [  9605,  10281],
                        [  9745,  10337],
                        [  9896,  10402],
                        [ 10053,  10476],
                        [ 10220,  10558],
                        [ 10392,  10653],
                        [ 10569,  10756],
                        [ 10746,  10867],
                        [ 10925,  10987],
                        [ 11101,  11113],
                        [ 11274,  11243],
                        [ 11442,  11375],
                        [ 11606,  11510],
                        [ 11762,  11642],
                        [ 11912,  11771],
                        [ 12053,  11893],
                        [ 12187,  12011],
                        [ 12303,  12121],
                        [ 12400,  12217],
                        [ 12467,  12296],
                        [ 12504,  12358],
                        [ 12492,  12386],
                        [ 12433,  12378],
                        [ 12322,  12328],
                        [ 12158,  12235],
                        [ 11927,  12080],
                        [ 11628,  11864],
                        [ 11267,  11590],
                        [ 10844,  11254],
                        [ 10394,  10892],
                        [  9913,  10499],
                        [  9419,  10090],
                        [  8908,   9662],
                        [  8398,   9229],
                        [  7887,   8791],
                        [  7387,   8358],
                        [  6900,   7931],
                        [  6434,   7516],
                        [  5990,   7117],
                        [  5572,   6737],
                        [  5183,   6378],
                        [  4825,   6044],
                        [  4498,   5736],
                        [  4205,   5456],
                        [  3946,   5204],
                        [  3720,   4981],
                        [  3530,   4788],
                        [  3372,   4623],
                        [  3248,   4488],
                        [  3152,   4380],
                        [  3083,   4301],
                        [  3035,   4245],
                        [  3007,   4214],
                        [  2995,   4206],
                        [  3000,   4219],
                        [  3018,   4249],
                        [  3051,   4297],
                        [  3103,   4357],
                        [  3172,   4431],
                        [  3253,   4513],
                        [  3346,   4604],
                        [  3446,   4698],
                        [  3551,   4796],
                        [  3661,   4895],
                        [  3772,   4990],
                        [  3880,   5079],
                        [  3985,   5159],
                        [  4085,   5230],
                        [  4171,   5280],
                        [  4253,   5324],
                        [  4407,   5440],
                        [  4701,   5695],
                        [  5152,   6105],
                        [  5760,   6671],
                        [  6523,   7391],
                        [  7399,   8218],
                        [  8260,   9025],
                        [  9013,   9722],
                        [  9652,  10300],
                        [ 10177,  10762],
                        [ 10589,  11110],
                        [ 10889,  11344],
                        [ 11081,  11470],
                        [ 11167,  11491],
                        [ 11156,  11415],
                        [ 11051,  11248],
                        [ 10862,  10999],
                        [ 10593,  10673],
                        [ 10255,  10281],
                        [  9853,   9830],
                        [  9398,   9328],
                        [  8896,   8786],
                        [  8357,   8210],
                        [  7790,   7609],
                        [  7200,   6990],
                        [  6597,   6360],
                        [  5984,   5723],
                        [  5371,   5087],
                        [  4760,   4455],
                        [  4159,   3833],
                        [  3572,   3223],
                        [  3002,   2632],
                        [  2452,   2061],
                        [  1928,   1516],
                        [  1431,   1000],
                        [   964,    516],
                        [   528,     65],
                        [   126,   -358],
                        [  -243,   -752],
                        [  -576,  -1121],
                        [  -874,  -1463],
                        [ -1138,  -1778],
                        [ -1367,  -2067],
                        [ -1561,  -2326],
                        [ -1723,  -2558],
                        [ -1853,  -2755],
                        [ -1952,  -2919],
                        [ -2023,  -3044],
                        [ -2067,  -3134],
                        [ -2086,  -3184],
                        [ -2082,  -3200],
                        [ -2056,  -3185],
                        [ -2013,  -3141],
                        [ -1952,  -3076],
                        [ -1874,  -2991],
                        [ -1784,  -2888],
                        [ -1683,  -2769],
                        [ -1571,  -2639],
                        [ -1453,  -2499],
                        [ -1328,  -2355],
                        [ -1199,  -2207],
                        [ -1069,  -2058],
                        [  -938,  -1910],
                        [  -813,  -1767],
                        [  -691,  -1630],
                        [  -583,  -1502],
                        [  -489,  -1384],
                        [  -416,  -1277],
                        [  -367,  -1185],
                        [  -344,  -1110],
                        [  -346,  -1051],
                        [  -366,  -1011],
                        [  -405,   -988],
                        [  -451,   -982],
                        [  -505,   -991],
                        [  -570,  -1020],
                        [  -645,  -1066],
                        [  -727,  -1125],
                        [  -816,  -1197],
                        [  -885,  -1254],
                        [  -935,  -1298],
                        [  -977,  -1334],
                        [ -1008,  -1363],
                        [ -1042,  -1395],
                        [ -1077,  -1429],
                        [ -1121,  -1475],
                        [ -1175,  -1529],
                        [ -1246,  -1599],
                        [ -1331,  -1683],
                        [ -1437,  -1785],
                        [ -1561,  -1905],
                        [ -1705,  -2042],
                        [ -1866,  -2195],
                        [ -2047,  -2366],
                        [ -2241,  -2550],
                        [ -2448,  -2748],
                        [ -2666,  -2955],
                        [ -2889,  -3169],
                        [ -3116,  -3387],
                        [ -3339,  -3604],
                        [ -3559,  -3819],
                        [ -3767,  -4025],
                        [ -3962,  -4222],
                        [ -4133,  -4402],
                        [ -4281,  -4565],
                        [ -4397,  -4704],
                        [ -4482,  -4818],
                        [ -4527,  -4903],
                        [ -4535,  -4956],
                        [ -4506,  -4975],
                        [ -4439,  -4958],
                        [ -4335,  -4901],
                        [ -4193,  -4806],
                        [ -4013,  -4670],
                        [ -3793,  -4495],
                        [ -3536,  -4279],
                        [ -3243,  -4024],
                        [ -2913,  -3730],
                        [ -2549,  -3396],
                        [ -2156,  -3025],
                        [ -1735,  -2619],
                        [ -1276,  -2168],
                        [  -813,  -1704],
                        [  -434,  -1320],
                        [  -215,  -1092],
                        [  -175,  -1037],
                        [  -319,  -1161],
                        [  -663,  -1476],
                        [ -1168,  -1943],
                        [ -1698,  -2424],
                        [ -2152,  -2818],
                        [ -2522,  -3119],
                        [ -2816,  -3335],
                        [ -3029,  -3464],
                        [ -3163,  -3505],
                        [ -3220,  -3465],
                        [ -3205,  -3346],
                        [ -3121,  -3157],
                        [ -2975,  -2901],
                        [ -2771,  -2589],
                        [ -2516,  -2224],
                        [ -2215,  -1816],
                        [ -1877,  -1372],
                        [ -1506,   -899],
                        [ -1108,   -403],
                        [  -692,    106],
                        [  -262,    623],
                        [   176,   1142],
                        [   618,   1659],
                        [  1058,   2169],
                        [  1495,   2669],
                        [  1926,   3157],
                        [  2348,   3629],
                        [  2760,   4086],
                        [  3160,   4525],
                        [  3547,   4942],
                        [  3923,   5337],
                        [  4284,   5705],
                        [  4632,   6047],
                        [  4968,   6368],
                        [  5290,   6665],
                        [  5601,   6951],
                        [  5903,   7226],
                        [  6195,   7497],
                        [  6478,   7765],
                        [  6754,   8030],
                        [  7024,   8293],
                        [  7287,   8553],
                        [  7547,   8811],
                        [  7802,   9059],
                        [  8053,   9300],
                        [  8301,   9530],
                        [  8546,   9750],
                        [  8786,   9959],
                        [  9023,  10157],
                        [  9254,  10347],
                        [  9479,  10530],
                        [  9694,  10704],
                        [  9900,  10869],
                        [ 10095,  11022],
                        [ 10275,  11164],
                        [ 10438,  11294],
                        [ 10584,  11412],
                        [ 10707,  11515],
                        [ 10809,  11603],
                        [ 10884,  11673],
                        [ 10934,  11727],
                        [ 10960,  11760],
                        [ 10959,  11773],
                        [ 10940,  11763],
                        [ 10900,  11731],
                        [ 10844,  11674],
                        [ 10775,  11593],
                        [ 10684,  11486],
                        [ 10571,  11352],
                        [ 10423,  11191],
                        [ 10242,  11004],
                        [ 10031,  10800],
                        [  9791,  10579],
                        [  9532,  10351],
                        [  9257,  10117],
                        [  8948,   9856],
                        [  8605,   9572],
                        [  8205,   9233],
                        [  7750,   8844],
                        [  7248,   8412],
                        [  6702,   7937],
                        [  6125,   7432],
                        [  5519,   6897],
                        [  4901,   6347],
                        [  4271,   5783],
                        [  3642,   5215],
                        [  3017,   4645],
                        [  2408,   4084],
                        [  1815,   3534],
                        [  1250,   3004],
                        [   711,   2493],
                        [   207,   2009],
                        [  -262,   1553],
                        [  -692,   1129],
                        [ -1082,    739],
                        [ -1432,    383],
                        [ -1741,     63],
                        [ -2011,   -221],
                        [ -2242,   -469],
                        [ -2437,   -683],
                        [ -2596,   -861],
                        [ -2724,  -1009],
                        [ -2823,  -1126],
                        [ -2897,  -1216],
                        [ -2949,  -1279],
                        [ -2982,  -1321],
                        [ -2998,  -1342],
                        [ -2999,  -1348],
                        [ -2984,  -1339],
                        [ -2961,  -1320],
                        [ -2930,  -1293],
                        [ -2897,  -1261],
                        [ -2861,  -1225],
                        [ -2827,  -1190],
                        [ -2797,  -1156],
                        [ -2774,  -1133],
                        [ -2756,  -1115],
                        [ -2750,  -1111],
                        [ -2764,  -1132],
                        [ -2769,  -1142],
                        [ -2665,  -1044],
                        [ -2391,   -775],
                        [ -1936,   -325],
                        [ -1294,    310],
                        [  -445,   1149],
                        [   574,   2152],
                        [  1613,   3166],
                        [  2563,   4086],
                        [  3416,   4902],
                        [  4174,   5615],
                        [  4827,   6217],
                        [  5371,   6703],
                        [  5805,   7074],
                        [  6130,   7330],
                        [  6347,   7474],
                        [  6460,   7510],
                        [  6475,   7443],
                        [  6395,   7278],
                        [  6229,   7025],
                        [  5982,   6689],
                        [  5662,   6279],
                        [  5278,   5804],
                        [  4839,   5273],
                        [  4354,   4697],
                        [  3832,   4084],
                        [  3280,   3443],
                        [  2707,   2780],
                        [  2121,   2104],
                        [  1528,   1422],
                        [   933,    739],
                        [   345,     63],
                        [  -232,   -598],
                        [  -793,  -1241],
                        [ -1333,  -1852],
                        [ -1849,  -2429],
                        [ -2335,  -2965],
                        [ -2792,  -3458],
                        [ -3214,  -3912],
                        [ -3603,  -4326],
                        [ -3955,  -4708],
                        [ -4272,  -5058],
                        [ -4553,  -5380],
                        [ -4799,  -5674],
                        [ -5012,  -5939],
                        [ -5190,  -6176],
                        [ -5338,  -6382],
                        [ -5456,  -6559],
                        [ -5547,  -6705],
                        [ -5613,  -6821],
                        [ -5657,  -6909],
                        [ -5683,  -6970],
                        [ -5692,  -7007],
                        [ -5686,  -7022],
                        [ -5670,  -7022],
                        [ -5644,  -7008],
                        [ -5612,  -6979],
                        [ -5575,  -6941],
                        [ -5536,  -6895],
                        [ -5497,  -6842],
                        [ -5458,  -6789],
                        [ -5419,  -6736],
                        [ -5384,  -6686],
                        [ -5355,  -6641],
                        [ -5332,  -6602],
                        [ -5319,  -6571],
                        [ -5321,  -6549],
                        [ -5341,  -6537],
                        [ -5389,  -6537],
                        [ -5465,  -6548],
                        [ -5571,  -6572],
                        [ -5706,  -6607],
                        [ -5861,  -6654],
                        [ -6034,  -6715],
                        [ -6221,  -6796],
                        [ -6420,  -6897],
                        [ -6654,  -7046],
                        [ -6919,  -7238],
                        [ -7213,  -7470],
                        [ -7534,  -7742],
                        [ -7841,  -8008],
                        [ -8135,  -8272],
                        [ -8383,  -8500],
                        [ -8587,  -8691],
                        [ -8750,  -8850],
                        [ -8869,  -8973],
                        [ -8954,  -9068],
                        [ -9001,  -9133],
                        [ -9020,  -9173],
                        [ -9007,  -9186],
                        [ -8971,  -9179],
                        [ -8909,  -9149],
                        [ -8828,  -9100],
                        [ -8725,  -9032],
                        [ -8608,  -8947],
                        [ -8472,  -8845],
                        [ -8322,  -8727],
                        [ -8158,  -8593],
                        [ -7978,  -8445],
                        [ -7782,  -8280],
                        [ -7569,  -8099],
                        [ -7339,  -7902],
                        [ -7091,  -7688],
                        [ -6823,  -7456],
                        [ -6538,  -7205],
                        [ -6235,  -6936],
                        [ -5911,  -6648],
                        [ -5567,  -6340],
                        [ -5200,  -6012],
                        [ -4810,  -5664],
                        [ -4398,  -5296],
                        [ -3966,  -4909],
                        [ -3516,  -4503],
                        [ -3049,  -4080],
                        [ -2566,  -3642],
                        [ -2069,  -3188],
                        [ -1561,  -2724],
                        [ -1046,  -2250],
                        [  -524,  -1768],
                        [     1,  -1279],
                        [   522,   -787],
                        [  1041,   -293],
                        [  1566,    212],
                        [  2048,    680],
                        [  2388,   1010],
                        [  2530,   1146],
                        [  2466,   1081],
                        [  2180,    799],
                        [  1640,    271],
                        [   880,   -468],
                        [    47,  -1270],
                        [  -757,  -2032],
                        [ -1526,  -2749],
                        [ -2256,  -3419],
                        [ -2936,  -4029],
                        [ -3559,  -4573],
                        [ -4118,  -5046],
                        [ -4613,  -5448],
                        [ -5038,  -5775],
                        [ -5394,  -6029],
                        [ -5679,  -6209],
                        [ -5896,  -6319],
                        [ -6044,  -6359],
                        [ -6127,  -6333],
                        [ -6147,  -6244],
                        [ -6108,  -6099],
                        [ -6015,  -5901],
                        [ -5870,  -5657],
                        [ -5680,  -5372],
                        [ -5447,  -5051],
                        [ -5176,  -4695],
                        [ -4870,  -4312],
                        [ -4534,  -3902],
                        [ -4171,  -3473],
                        [ -3784,  -3027],
                        [ -3376,  -2566],
                        [ -2952,  -2103],
                        [ -2513,  -1637],
                        [ -2064,  -1181],
                        [ -1606,   -735],
                        [ -1145,   -302],
                        [  -680,    116],
                        [  -215,    530],
                        [   249,    937],
                        [   709,   1345],
                        [  1164,   1753],
                        [  1610,   2162],
                        [  2048,   2569],
                        [  2473,   2971],
                        [  2888,   3369],
                        [  3286,   3755],
                        [  3668,   4130],
                        [  4032,   4490],
                        [  4377,   4835],
                        [  4700,   5160],
                        [  5000,   5465],
                        [  5276,   5746],
                        [  5525,   6004],
                        [  5745,   6234],
                        [  5936,   6437],
                        [  6093,   6608],
                        [  6218,   6745],
                        [  6305,   6849],
                        [  6356,   6920],
                        [  6367,   6957],
                        [  6338,   6960],
                        [  6268,   6927],
                        [  6159,   6861],
                        [  6013,   6758],
                        [  5831,   6621],
                        [  5624,   6450],
                        [  5393,   6247],
                        [  5149,   6009],
                        [  4890,   5740],
                        [  4617,   5441],
                        [  4330,   5112],
                        [  4021,   4761],
                        [  3692,   4388],
                        [  3369,   4032],
                        [  3052,   3692],
                        [  2763,   3389],
                        [  2502,   3124],
                        [  2251,   2880],
                        [  2016,   2657],
                        [  1738,   2399],
                        [  1423,   2109],
                        [  1059,   1777],
                        [   650,   1404],
                        [   206,    999],
                        [  -271,    565],
                        [  -767,    111],
                        [ -1285,   -361],
                        [ -1808,   -841],
                        [ -2337,  -1328],
                        [ -2859,  -1811],
                        [ -3374,  -2291],
                        [ -3872,  -2758],
                        [ -4351,  -3211],
                        [ -4804,  -3643],
                        [ -5229,  -4054],
                        [ -5623,  -4440],
                        [ -5985,  -4800],
                        [ -6314,  -5130],
                        [ -6612,  -5432],
                        [ -6879,  -5703],
                        [ -7113,  -5945],
                        [ -7317,  -6160],
                        [ -7490,  -6346],
                        [ -7633,  -6507],
                        [ -7749,  -6643],
                        [ -7845,  -6758],
                        [ -7922,  -6854],
                        [ -7988,  -6934],
                        [ -8044,  -6999],
                        [ -8094,  -7054],
                        [ -8139,  -7100],
                        [ -8183,  -7139],
                        [ -8227,  -7176],
                        [ -8276,  -7211],
                        [ -8327,  -7244],
                        [ -8384,  -7279],
                        [ -8449,  -7317],
                        [ -8523,  -7362],
                        [ -8601,  -7411],
                        [ -8693,  -7471],
                        [ -8802,  -7550],
                        [ -8883,  -7600],
                        [ -8847,  -7532],
                        [ -8654,  -7308],
                        [ -8301,  -6923],
                        [ -7767,  -6362],
                        [ -7018,  -5590],
                        [ -6080,  -4636],
                        [ -5090,  -3638],
                        [ -4141,  -2693],
                        [ -3240,  -1802],
                        [ -2389,   -972],
                        [ -1602,   -216],
                        [  -889,    456],
                        [  -252,   1040],
                        [   304,   1534],
                        [   777,   1935],
                        [  1165,   2242],
                        [  1471,   2457],
                        [  1695,   2584],
                        [  1840,   2624],
                        [  1913,   2583],
                        [  1915,   2466],
                        [  1854,   2281],
                        [  1736,   2035],
                        [  1569,   1736],
                        [  1358,   1391],
                        [  1110,   1009],
                        [   832,    596],
                        [   531,    160],
                        [   211,   -293],
                        [  -119,   -757],
                        [  -457,  -1225],
                        [  -797,  -1689],
                        [ -1134,  -2144],
                        [ -1465,  -2576],
                        [ -1783,  -2980],
                        [ -2088,  -3350],
                        [ -2377,  -3682],
                        [ -2647,  -3981],
                        [ -2897,  -4244],
                        [ -3127,  -4483],
                        [ -3337,  -4700],
                        [ -3526,  -4899],
                        [ -3695,  -5084],
                        [ -3845,  -5252],
                        [ -3976,  -5406],
                        [ -4092,  -5546],
                        [ -4193,  -5674],
                        [ -4279,  -5790],
                        [ -4355,  -5896],
                        [ -4423,  -5996],
                        [ -4483,  -6090],
                        [ -4540,  -6177],
                        [ -4595,  -6259],
                        [ -4648,  -6336],
                        [ -4704,  -6411],
                        [ -4760,  -6481],
                        [ -4823,  -6549],
                        [ -4889,  -6615],
                        [ -4961,  -6680],
                        [ -5038,  -6748],
                        [ -5120,  -6820],
                        [ -5209,  -6896],
                        [ -5303,  -6977],
                        [ -5406,  -7064],
                        [ -5514,  -7158],
                        [ -5639,  -7258],
                        [ -5776,  -7365],
                        [ -5939,  -7477],
                        [ -6127,  -7594],
                        [ -6339,  -7716],
                        [ -6576,  -7841],
                        [ -6828,  -7970],
                        [ -7094,  -8100],
                        [ -7379,  -8256],
                        [ -7681,  -8435],
                        [ -8032,  -8678],
                        [ -8430,  -8981],
                        [ -8871,  -9339],
                        [ -9354,  -9752],
                        [ -9823, -10168],
                        [-10283, -10585],
                        [-10669, -10942],
                        [-10983, -11241],
                        [-11226, -11480],
                        [-11394, -11656],
                        [-11490, -11772],
                        [-11512, -11824],
                        [-11468, -11819],
                        [-11355, -11753],
                        [-11182, -11633],
                        [-10949, -11459],
                        [-10664, -11235],
                        [-10326, -10961],
                        [ -9945, -10643],
                        [ -9520, -10282],
                        [ -9060,  -9884],
                        [ -8565,  -9448],
                        [ -8040,  -8981],
                        [ -7486,  -8483],
                        [ -6906,  -7959],
                        [ -6303,  -7411],
                        [ -5683,  -6842],
                        [ -5047,  -6253],
                        [ -4405,  -5649],
                        [ -3755,  -5033],
                        [ -3103,  -4405],
                        [ -2447,  -3768],
                        [ -1788,  -3127],
                        [ -1125,  -2483],
                        [  -458,  -1837],
                        [   208,  -1194],
                        [   869,   -557],
                        [  1523,     74],
                        [  2168,    694],
                        [  2801,   1300],
                        [  3417,   1889],
                        [  4013,   2456],
                        [  4589,   3004],
                        [  5139,   3525],
                        [  5660,   4018],
                        [  6151,   4484],
                        [  6619,   4929],
                        [  7013,   5299],
                        [  7258,   5524],
                        [  7330,   5576],
                        [  7226,   5457],
                        [  6924,   5141],
                        [  6381,   4590],
                        [  5616,   3823],
                        [  4751,   2963],
                        [  3864,   2090],
                        [  2964,   1210],
                        [  2059,    331],
                        [  1168,   -526],
                        [   306,  -1347],
                        [  -522,  -2125],
                        [ -1303,  -2849],
                        [ -2029,  -3512],
                        [ -2693,  -4108],
                        [ -3290,  -4630],
                        [ -3816,  -5078],
                        [ -4266,  -5447],
                        [ -4643,  -5738],
                        [ -4942,  -5948],
                        [ -5163,  -6082],
                        [ -5312,  -6140],
                        [ -5388,  -6126],
                        [ -5394,  -6045],
                        [ -5334,  -5900],
                        [ -5212,  -5696],
                        [ -5032,  -5436],
                        [ -4797,  -5127],
                        [ -4512,  -4771],
                        [ -4184,  -4375],
                        [ -3814,  -3946],
                        [ -3411,  -3493],
                        [ -2977,  -3023],
                        [ -2521,  -2550],
                        [ -2045,  -2077],
                        [ -1557,  -1610],
                        [ -1058,  -1155],
                        [  -557,   -704],
                        [   -54,   -262],
                        [   444,    180],
                        [   933,    619],
                        [  1410,   1055],
                        [  1870,   1483],
                        [  2312,   1900],
                        [  2729,   2306],
                        [  3121,   2695],
                        [  3484,   3068],
                        [  3816,   3422],
                        [  4114,   3757],
                        [  4375,   4065],
                        [  4600,   4349],
                        [  4786,   4599],
                        [  4934,   4815],
                        [  5040,   4992],
                        [  5105,   5131],
                        [  5128,   5226],
                        [  5109,   5278],
                        [  5046,   5288],
                        [  4941,   5254],
                        [  4792,   5180],
                        [  4602,   5064],
                        [  4371,   4910],
                        [  4102,   4717],
                        [  3801,   4489],
                        [  3466,   4226],
                        [  3116,   3932],
                        [  2750,   3608],
                        [  2380,   3257],
                        [  2005,   2878],
                        [  1634,   2480],
                        [  1266,   2063],
                        [   902,   1640],
                        [   544,   1214],
                        [   232,    839],
                        [   -33,    516],
                        [  -230,    267],
                        [  -356,     96],
                        [  -427,    -14],
                        [  -439,    -59],
                        [  -472,   -119],
                        [  -519,   -184],
                        [  -605,   -283],
                        [  -726,   -410],
                        [  -880,   -564],
                        [ -1064,   -742],
                        [ -1274,   -941],
                        [ -1510,  -1160],
                        [ -1762,  -1392],
                        [ -2031,  -1638],
                        [ -2308,  -1892],
                        [ -2596,  -2153],
                        [ -2882,  -2415],
                        [ -3170,  -2679],
                        [ -3449,  -2938],
                        [ -3723,  -3194],
                        [ -3985,  -3442],
                        [ -4238,  -3681],
                        [ -4480,  -3911],
                        [ -4713,  -4132],
                        [ -4931,  -4340],
                        [ -5140,  -4539],
                        [ -5331,  -4726],
                        [ -5506,  -4903],
                        [ -5665,  -5070],
                        [ -5809,  -5230],
                        [ -5945,  -5383],
                        [ -6075,  -5529],
                        [ -6207,  -5671],
                        [ -6341,  -5809],
                        [ -6481,  -5945],
                        [ -6625,  -6079],
                        [ -6775,  -6213],
                        [ -6931,  -6346],
                        [ -7093,  -6481],
                        [ -7261,  -6613],
                        [ -7433,  -6745],
                        [ -7610,  -6875],
                        [ -7790,  -7007],
                        [ -7969,  -7132],
                        [ -8153,  -7261],
                        [ -8339,  -7390],
                        [ -8486,  -7478],
                        [ -8541,  -7475],
                        [ -8493,  -7371],
                        [ -8340,  -7162],
                        [ -8055,  -6825],
                        [ -7591,  -6313],
                        [ -6949,  -5631],
                        [ -6223,  -4874],
                        [ -5476,  -4103],
                        [ -4708,  -3321],
                        [ -3928,  -2536],
                        [ -3153,  -1766],
                        [ -2393,  -1024],
                        [ -1655,   -315],
                        [  -946,    353],
                        [  -273,    971],
                        [   358,   1535],
                        [   943,   2043],
                        [  1480,   2493],
                        [  1967,   2881],
                        [  2402,   3209],
                        [  2787,   3478],
                        [  3122,   3690],
                        [  3410,   3848],
                        [  3651,   3955],
                        [  3851,   4017],
                        [  4011,   4037],
                        [  4134,   4019],
                        [  4223,   3969],
                        [  4282,   3889],
                        [  4314,   3785],
                        [  4321,   3661],
                        [  4307,   3524],
                        [  4275,   3377],
                        [  4228,   3231],
                        [  4169,   3092],
                        [  4098,   2966],
                        [  4020,   2857],
                        [  3933,   2759],
                        [  3840,   2678],
                        [  3742,   2600],
                        [  3638,   2525],
                        [  3529,   2446],
                        [  3416,   2361],
                        [  3297,   2270],
                        [  3174,   2173],
                        [  3046,   2065],
                        [  2913,   1950],
                        [  2773,   1819],
                        [  2628,   1676],
                        [  2476,   1516],
                        [  2316,   1341],
                        [  2150,   1154],
                        [  1976,    954],
                        [  1793,    748],
                        [  1603,    535],
                        [  1406,    321],
                        [  1199,    102],
                        [   988,   -119],
                        [   771,   -338],
                        [   552,   -558],
                        [   330,   -778],
                        [   107,   -997],
                        [  -115,  -1214],
                        [  -335,  -1428],
                        [  -553,  -1638],
                        [  -771,  -1843],
                        [  -990,  -2041],
                        [ -1218,  -2231],
                        [ -1451,  -2411],
                        [ -1690,  -2576],
                        [ -1936,  -2729],
                        [ -2183,  -2870],
                        [ -2430,  -2996],
                        [ -2694,  -3142],
                        [ -2971,  -3304],
                        [ -3296,  -3525],
                        [ -3667,  -3800],
                        [ -4081,  -4131],
                        [ -4539,  -4517],
                        [ -4985,  -4903],
                        [ -5420,  -5293],
                        [ -5774,  -5613],
                        [ -6046,  -5864],
                        [ -6234,  -6045],
                        [ -6338,  -6152],
                        [ -6353,  -6185],
                        [ -6282,  -6142],
                        [ -6129,  -6026],
                        [ -5892,  -5837],
                        [ -5582,  -5582],
                        [ -5197,  -5259],
                        [ -4747,  -4873],
                        [ -4233,  -4430],
                        [ -3668,  -3933],
                        [ -3053,  -3385],
                        [ -2398,  -2796],
                        [ -1703,  -2165],
                        [  -980,  -1503],
                        [  -229,   -811],
                        [   540,    -98],
                        [  1328,    635],
                        [  2119,   1380],
                        [  2910,   2134],
                        [  3690,   2889],
                        [  4457,   3645],
                        [  5208,   4394],
                        [  5939,   5133],
                        [  6654,   5860],
                        [  7352,   6567],
                        [  8032,   7254],
                        [  8691,   7918],
                        [  9324,   8552],
                        [  9930,   9156],
                        [ 10504,   9726],
                        [ 11045,  10261],
                        [ 11550,  10755],
                        [ 12016,  11208],
                        [ 12443,  11618],
                        [ 12828,  11982],
                        [ 13169,  12299],
                        [ 13466,  12570],
                        [ 13722,  12798],
                        [ 13905,  12950],
                        [ 13992,  13004],
                        [ 13986,  12964],
                        [ 13886,  12831],
                        [ 13670,  12579],
                        [ 13288,  12164],
                        [ 12731,  11576],
                        [ 12064,  10881],
                        [ 11336,  10125],
                        [ 10553,   9319],
                        [  9728,   8471],
                        [  8881,   7608],
                        [  8027,   6741],
                        [  7177,   5887],
                        [  6342,   5054],
                        [  5536,   4256],
                        [  4769,   3504],
                        [  4047,   2803],
                        [  3378,   2163],
                        [  2771,   1588],
                        [  2227,   1084],
                        [  1751,    652],
                        [  1345,    294],
                        [  1008,     11],
                        [   743,   -198],
                        [   545,   -337],
                        [   414,   -407],
                        [   349,   -412],
                        [   342,   -357],
                        [   393,   -245],
                        [   497,    -80],
                        [   648,    128],
                        [   841,    377],
                        [  1069,    653],
                        [  1330,    954],
                        [  1614,   1262],
                        [  1917,   1574],
                        [  2234,   1881],
                        [  2558,   2179],
                        [  2884,   2469],
                        [  3209,   2747],
                        [  3525,   3019],
                        [  3832,   3283],
                        [  4122,   3538],
                        [  4392,   3781],
                        [  4639,   4008],
                        [  4859,   4219],
                        [  5050,   4416],
                        [  5209,   4595],
                        [  5333,   4759],
                        [  5423,   4905],
                        [  5475,   5031],
                        [  5490,   5136],
                        [  5468,   5211],
                        [  5409,   5257],
                        [  5314,   5267],
                        [  5182,   5244],
                        [  5016,   5185],
                        [  4817,   5089],
                        [  4585,   4958],
                        [  4323,   4793],
                        [  4031,   4596],
                        [  3713,   4370],
                        [  3373,   4118],
                        [  3011,   3841],
                        [  2635,   3543],
                        [  2244,   3224],
                        [  1855,   2890],
                        [  1467,   2543],
                        [  1088,   2185],
                        [   722,   1817],
                        [   375,   1446],
                        [    52,   1077],
                        [  -240,    723],
                        [  -500,    387],
                        [  -683,    126],
                        [  -792,    -62],
                        [  -810,   -157],
                        [  -736,   -158],
                        [  -579,    -73],
                        [  -340,    100],
                        [   -99,    279],
                        [   149,    469],
                        [   372,    644],
                        [   574,    803],
                        [   748,    943],
                        [   895,   1063],
                        [  1012,   1161],
                        [  1098,   1237],
                        [  1155,   1290],
                        [  1181,   1321],
                        [  1180,   1329],
                        [  1150,   1315],
                        [  1098,   1280],
                        [  1021,   1224],
                        [   925,   1150],
                        [   808,   1055],
                        [   675,    947],
                        [   525,    819],
                        [   358,    679],
                        [   175,    524],
                        [   -20,    357],
                        [  -225,    176],
                        [  -431,    -14],
                        [  -641,   -215],
                        [  -850,   -424],
                        [ -1060,   -643],
                        [ -1274,   -869],
                        [ -1494,  -1100],
                        [ -1727,  -1338],
                        [ -1972,  -1580],
                        [ -2225,  -1825],
                        [ -2488,  -2072],
                        [ -2756,  -2318],
                        [ -3028,  -2563],
                        [ -3302,  -2804],
                        [ -3574,  -3038],
                        [ -3844,  -3264],
                        [ -4108,  -3480],
                        [ -4362,  -3681],
                        [ -4603,  -3866],
                        [ -4830,  -4035],
                        [ -5039,  -4183],
                        [ -5215,  -4298],
                        [ -5358,  -4381],
                        [ -5479,  -4442],
                        [ -5571,  -4478],
                        [ -5610,  -4461],
                        [ -5544,  -4344],
                        [ -5336,  -4089],
                        [ -5016,  -3727],
                        [ -4610,  -3286],
                        [ -4124,  -2767],
                        [ -3566,  -2186],
                        [ -2952,  -1554],
                        [ -2292,   -887],
                        [ -1595,   -193],
                        [  -870,    516],
                        [  -130,   1230],
                        [   618,   1940],
                        [  1364,   2640],
                        [  2103,   3321],
                        [  2826,   3976],
                        [  3527,   4603],
                        [  4203,   5195],
                        [  4848,   5750],
                        [  5460,   6265],
                        [  6034,   6738],
                        [  6571,   7170],
                        [  7066,   7558],
                        [  7521,   7905],
                        [  7931,   8210],
                        [  8301,   8475],
                        [  8626,   8701],
                        [  8911,   8889],
                        [  9154,   9043],
                        [  9356,   9164],
                        [  9518,   9263],
                        [  9644,   9338],
                        [  9731,   9397],
                        [  9783,   9441],
                        [  9801,   9471],
                        [  9786,   9490],
                        [  9738,   9488],
                        [  9660,   9469],
                        [  9552,   9423],
                        [  9416,   9352],
                        [  9254,   9255],
                        [  9067,   9134],
                        [  8855,   8985],
                        [  8624,   8811],
                        [  8371,   8603],
                        [  8101,   8365],
                        [  7815,   8097],
                        [  7516,   7798],
                        [  7204,   7477],
                        [  6882,   7135],
                        [  6551,   6784],
                        [  6212,   6422],
                        [  5870,   6056],
                        [  5523,   5687],
                        [  5179,   5321],
                        [  4836,   4960],
                        [  4499,   4605],
                        [  4169,   4259],
                        [  3849,   3925],
                        [  3541,   3603],
                        [  3247,   3298],
                        [  2968,   3010],
                        [  2706,   2740],
                        [  2459,   2492],
                        [  2225,   2266],
                        [  2009,   2067],
                        [  1808,   1896],
                        [  1620,   1751],
                        [  1445,   1632],
                        [  1282,   1538],
                        [  1109,   1436],
                        [   926,   1327],
                        [   709,   1179],
                        [   457,    995],
                        [   166,    764],
                        [  -164,    488],
                        [  -489,    210],
                        [  -813,    -76],
                        [ -1069,   -301],
                        [ -1262,   -472],
                        [ -1386,   -584],
                        [ -1440,   -635],
                        [ -1420,   -622],
                        [ -1328,   -544],
                        [ -1163,   -403],
                        [  -928,   -201],
                        [  -627,     62],
                        [  -262,    382],
                        [   157,    754],
                        [   631,   1177],
                        [  1148,   1644],
                        [  1706,   2152],
                        [  2296,   2693],
                        [  2915,   3265],
                        [  3554,   3859],
                        [  4209,   4474],
                        [  4873,   5098],
                        [  5542,   5732],
                        [  6200,   6365],
                        [  6846,   6996],
                        [  7468,   7618],
                        [  8064,   8227],
                        [  8631,   8817],
                        [  9166,   9387],
                        [  9675,   9930],
                        [ 10158,  10444],
                        [ 10612,  10925],
                        [ 11037,  11371],
                        [ 11427,  11779],
                        [ 11782,  12147],
                        [ 12101,  12473],
                        [ 12381,  12755],
                        [ 12621,  12993],
                        [ 12822,  13183],
                        [ 12982,  13327],
                        [ 13102,  13424],
                        [ 13180,  13473],
                        [ 13217,  13475],
                        [ 13213,  13430],
                        [ 13179,  13351],
                        [ 13145,  13268],
                        [ 13128,  13198],
                        [ 13131,  13144],
                        [ 13133,  13084],
                        [ 13085,  12972],
                        [ 12933,  12752],
                        [ 12675,  12423],
                        [ 12327,  12003],
                        [ 11899,  11500],
                        [ 11401,  10926],
                        [ 10848,  10299],
                        [ 10252,   9631],
                        [  9622,   8936],
                        [  8972,   8225],
                        [  8313,   7512],
                        [  7654,   6807],
                        [  7004,   6118],
                        [  6372,   5455],
                        [  5766,   4825],
                        [  5191,   4234],
                        [  4652,   3687],
                        [  4154,   3187],
                        [  3699,   2738],
                        [  3289,   2342],
                        [  2923,   1996],
                        [  2604,   1703],
                        [  2329,   1458],
                        [  2096,   1261],
                        [  1903,   1107],
                        [  1748,    993],
                        [  1626,    915],
                        [  1534,    868],
                        [  1467,    843],
                        [  1422,    839],
                        [  1393,    843],
                        [  1376,    852],
                        [  1367,    858],
                        [  1362,    858],
                        [  1355,    847],
                        [  1346,    823],
                        [  1328,    790],
                        [  1298,    745],
                        [  1256,    688],
                        [  1198,    618],
                        [  1120,    536],
                        [  1022,    439],
                        [   902,    332],
                        [   759,    215],
                        [   592,     93],
                        [   401,    -37],
                        [   185,   -172],
                        [   -54,   -315],
                        [  -314,   -473],
                        [  -596,   -644],
                        [  -896,   -834],
                        [ -1213,  -1040],
                        [ -1544,  -1263],
                        [ -1887,  -1500],
                        [ -2239,  -1752],
                        [ -2599,  -2017],
                        [ -2963,  -2292],
                        [ -3328,  -2576],
                        [ -3690,  -2863],
                        [ -4046,  -3154],
                        [ -4395,  -3446],
                        [ -4733,  -3734],
                        [ -5054,  -4017],
                        [ -5358,  -4293],
                        [ -5639,  -4561],
                        [ -5899,  -4820],
                        [ -6125,  -5062],
                        [ -6319,  -5288],
                        [ -6464,  -5480],
                        [ -6562,  -5640],
                        [ -6579,  -5727],
                        [ -6519,  -5741],
                        [ -6371,  -5672],
                        [ -6136,  -5519],
                        [ -5815,  -5280],
                        [ -5409,  -4954],
                        [ -4986,  -4607],
                        [ -4540,  -4236],
                        [ -4104,  -3866],
                        [ -3674,  -3498],
                        [ -3265,  -3142],
                        [ -2876,  -2800],
                        [ -2519,  -2480],
                        [ -2193,  -2182],
                        [ -1905,  -1912],
                        [ -1655,  -1674],
                        [ -1447,  -1468],
                        [ -1281,  -1296],
                        [ -1156,  -1161],
                        [ -1074,  -1063],
                        [ -1033,  -1000],
                        [ -1032,   -975],
                        [ -1068,   -985],
                        [ -1145,  -1030],
                        [ -1255,  -1109],
                        [ -1402,  -1221],
                        [ -1575,  -1362],
                        [ -1774,  -1532],
                        [ -1988,  -1727],
                        [ -2218,  -1946],
                        [ -2457,  -2183],
                        [ -2705,  -2440],
                        [ -2964,  -2710],
                        [ -3231,  -2992],
                        [ -3512,  -3282],
                        [ -3805,  -3577],
                        [ -4102,  -3872],
                        [ -4401,  -4166],
                        [ -4698,  -4453],
                        [ -4990,  -4731],
                        [ -5271,  -4996],
                        [ -5540,  -5246],
                        [ -5792,  -5475],
                        [ -6024,  -5681],
                        [ -6231,  -5860],
                        [ -6412,  -6009],
                        [ -6559,  -6123],
                        [ -6672,  -6203],
                        [ -6784,  -6282],
                        [ -6940,  -6407],
                        [ -7160,  -6593],
                        [ -7438,  -6840],
                        [ -7759,  -7129],
                        [ -8072,  -7408],
                        [ -8292,  -7596],
                        [ -8384,  -7655],
                        [ -8353,  -7591],
                        [ -8205,  -7410],
                        [ -7947,  -7121],
                        [ -7590,  -6734],
                        [ -7144,  -6264],
                        [ -6615,  -5717],
                        [ -6018,  -5107],
                        [ -5362,  -4445],
                        [ -4657,  -3744],
                        [ -3916,  -3011],
                        [ -3149,  -2259],
                        [ -2367,  -1497],
                        [ -1578,   -733],
                        [  -791,     24],
                        [   -15,    766],
                        [   743,   1485],
                        [  1474,   2176],
                        [  2175,   2832],
                        [  2838,   3451],
                        [  3460,   4028],
                        [  4037,   4561],
                        [  4567,   5048],
                        [  5046,   5488],
                        [  5471,   5878],
                        [  5844,   6220],
                        [  6162,   6514],
                        [  6425,   6762],
                        [  6636,   6966],
                        [  6792,   7126],
                        [  6897,   7248],
                        [  6951,   7332],
                        [  6957,   7382],
                        [  6916,   7397],
                        [  6830,   7379],
                        [  6702,   7325],
                        [  6536,   7238],
                        [  6333,   7117],
                        [  6097,   6965],
                        [  5831,   6778],
                        [  5540,   6562],
                        [  5225,   6308],
                        [  4893,   6023],
                        [  4545,   5705],
                        [  4187,   5360],
                        [  3821,   4993],
                        [  3450,   4606],
                        [  3079,   4214],
                        [  2707,   3819],
                        [  2342,   3424],
                        [  1984,   3032],
                        [  1637,   2651],
                        [  1304,   2282],
                        [   986,   1928],
                        [   686,   1593],
                        [   405,   1278],
                        [   145,    986],
                        [   -90,    721],
                        [  -301,    481],
                        [  -487,    269],
                        [  -644,     86],
                        [  -771,    -66],
                        [  -866,   -184],
                        [  -930,   -270],
                        [  -967,   -326],
                        [  -986,   -353],
                        [  -984,   -352],
                        [  -988,   -349],
                        [  -997,   -342],
                        [ -1023,   -349],
                        [ -1068,   -369],
                        [ -1143,   -419],
                        [ -1252,   -500],
                        [ -1372,   -594],
                        [ -1509,   -704],
                        [ -1615,   -786],
                        [ -1698,   -847],
                        [ -1747,   -878],
                        [ -1766,   -882],
                        [ -1745,   -852],
                        [ -1688,   -789],
                        [ -1589,   -690],
                        [ -1454,   -558],
                        [ -1279,   -392],
                        [ -1067,   -193],
                        [  -821,     37],
                        [  -545,    297],
                        [  -241,    583],
                        [    88,    892],
                        [   435,   1220],
                        [   799,   1566],
                        [  1174,   1923],
                        [  1558,   2290],
                        [  1943,   2661],
                        [  2327,   3035],
                        [  2697,   3404],
                        [  3053,   3769],
                        [  3386,   4121],
                        [  3697,   4461],
                        [  3981,   4783],
                        [  4238,   5086],
                        [  4475,   5365],
                        [  4690,   5619],
                        [  4882,   5846],
                        [  5051,   6043],
                        [  5194,   6208],
                        [  5310,   6341],
                        [  5399,   6441],
                        [  5461,   6507],
                        [  5494,   6538],
                        [  5501,   6535],
                        [  5479,   6498],
                        [  5432,   6426],
                        [  5358,   6320],
                        [  5252,   6177],
                        [  5127,   6008],
                        [  5039,   5874],
                        [  5054,   5834],
                        [  5190,   5911],
                        [  5451,   6106],
                        [  5828,   6410],
                        [  6273,   6775],
                        [  6682,   7096],
                        [  6991,   7311],
                        [  7200,   7419],
                        [  7316,   7430],
                        [  7343,   7345],
                        [  7285,   7177],
                        [  7152,   6931],
                        [  6949,   6619],
                        [  6682,   6247],
                        [  6362,   5827],
                        [  5995,   5366],
                        [  5589,   4873],
                        [  5152,   4355],
                        [  4691,   3820],
                        [  4213,   3275],
                        [  3722,   2726],
                        [  3224,   2178],
                        [  2725,   1636],
                        [  2229,   1105],
                        [  1736,    587],
                        [  1251,     85],
                        [   777,   -399],
                        [   311,   -867],
                        [  -143,  -1317],
                        [  -586,  -1751],
                        [ -1018,  -2169],
                        [ -1441,  -2572],
                        [ -1853,  -2963],
                        [ -2256,  -3343],
                        [ -2653,  -3713],
                        [ -3044,  -4075],
                        [ -3430,  -4434],
                        [ -3814,  -4790],
                        [ -4194,  -5150],
                        [ -4574,  -5515],
                        [ -4955,  -5884],
                        [ -5335,  -6260],
                        [ -5715,  -6638],
                        [ -6097,  -7020],
                        [ -6480,  -7404],
                        [ -6865,  -7788],
                        [ -7249,  -8165],
                        [ -7635,  -8535],
                        [ -8021,  -8891],
                        [ -8405,  -9233],
                        [ -8788,  -9561],
                        [ -9167,  -9873],
                        [ -9541, -10173],
                        [ -9908, -10461],
                        [-10265, -10740],
                        [-10611, -11009],
                        [-10943, -11266],
                        [-11259, -11508],
                        [-11557, -11737],
                        [-11835, -11953],
                        [-12088, -12151],
                        [-12318, -12332],
                        [-12520, -12495],
                        [-12693, -12638],
                        [-12837, -12760],
                        [-12952, -12861],
                        [-13039, -12938],
                        [-13101, -12993],
                        [-13140, -13025],
                        [-13154, -13034],
                        [-13139, -13018],
                        [-13093, -12976],
                        [-13003, -12903],
                        [-12870, -12798],
                        [-12682, -12648],
                        [-12440, -12456],
                        [-12144, -12217],
                        [-11794, -11930],
                        [-11378, -11580],
                        [-10898, -11169],
                        [-10390, -10730],
                        [ -9854, -10263],
                        [ -9311,  -9787],
                        [ -8764,  -9303],
                        [ -8227,  -8825],
                        [ -7703,  -8355],
                        [ -7205,  -7903],
                        [ -6733,  -7471],
                        [ -6298,  -7069],
                        [ -5900,  -6697],
                        [ -5545,  -6360],
                        [ -5236,  -6060],
                        [ -4973,  -5801],
                        [ -4758,  -5584],
                        [ -4591,  -5408],
                        [ -4470,  -5275],
                        [ -4396,  -5184],
                        [ -4365,  -5133],
                        [ -4375,  -5120],
                        [ -4423,  -5145],
                        [ -4501,  -5202],
                        [ -4607,  -5293],
                        [ -4732,  -5409],
                        [ -4875,  -5549],
                        [ -5027,  -5709],
                        [ -5188,  -5884],
                        [ -5355,  -6069],
                        [ -5526,  -6263],
                        [ -5702,  -6457],
                        [ -5879,  -6650],
                        [ -6051,  -6836],
                        [ -6213,  -7010],
                        [ -6362,  -7170],
                        [ -6494,  -7311],
                        [ -6603,  -7430],
                        [ -6689,  -7524],
                        [ -6748,  -7588],
                        [ -6776,  -7620],
                        [ -6772,  -7620],
                        [ -6735,  -7583],
                        [ -6650,  -7501],
                        [ -6539,  -7391],
                        [ -6478,  -7332],
                        [ -6535,  -7391],
                        [ -6727,  -7583],
                        [ -7055,  -7909],
                        [ -7521,  -8369],
                        [ -8076,  -8913],
                        [ -8596,  -9414],
                        [ -8996,  -9791],
                        [ -9275, -10040],
                        [ -9437, -10167],
                        [ -9484, -10174],
                        [ -9422, -10067],
                        [ -9255,  -9854],
                        [ -8991,  -9543],
                        [ -8639,  -9145],
                        [ -8208,  -8667],
                        [ -7708,  -8123],
                        [ -7149,  -7520],
                        [ -6544,  -6871],
                        [ -5901,  -6185],
                        [ -5232,  -5473],
                        [ -4544,  -4744],
                        [ -3852,  -4011],
                        [ -3161,  -3280],
                        [ -2482,  -2561],
                        [ -1821,  -1862],
                        [ -1186,  -1190],
                        [  -582,   -550],
                        [   -15,     53],
                        [   512,    616],
                        [   993,   1134],
                        [  1426,   1606],
                        [  1809,   2030],
                        [  2142,   2403],
                        [  2422,   2724],
                        [  2650,   2992],
                        [  2827,   3207],
                        [  2953,   3369],
                        [  3032,   3486],
                        [  3065,   3560],
                        [  3054,   3598],
                        [  3003,   3603],
                        [  2914,   3577],
                        [  2791,   3523],
                        [  2637,   3443],
                        [  2457,   3338],
                        [  2255,   3208],
                        [  2034,   3056],
                        [  1800,   2880],
                        [  1556,   2681],
                        [  1306,   2463],
                        [  1055,   2229],
                        [   805,   1983],
                        [   561,   1730],
                        [   327,   1479],
                        [   103,   1233],
                        [  -106,    995],
                        [  -299,    768],
                        [  -473,    554],
                        [  -627,    358],
                        [  -761,    180],
                        [  -873,     24],
                        [  -964,   -109],
                        [ -1033,   -218],
                        [ -1079,   -301],
                        [ -1102,   -358],
                        [ -1099,   -390],
                        [ -1069,   -397],
                        [ -1006,   -377],
                        [  -908,   -331],
                        [  -778,   -260],
                        [  -620,   -168],
                        [  -447,    -57],
                        [  -257,     73],
                        [   -66,    216],
                        [   126,    371],
                        [   318,    538],
                        [   509,    715],
                        [   678,    878],
                        [   823,   1027],
                        [   932,   1147],
                        [  1004,   1236],
                        [  1057,   1311],
                        [  1087,   1367],
                        [  1105,   1413],
                        [  1107,   1445],
                        [  1103,   1474],
                        [  1090,   1495],
                        [  1079,   1516],
                        [  1066,   1535],
                        [  1055,   1554],
                        [  1048,   1575],
                        [  1047,   1600],
                        [  1048,   1625],
                        [  1056,   1654],
                        [  1068,   1684],
                        [  1082,   1717],
                        [  1101,   1750],
                        [  1120,   1783],
                        [  1138,   1814],
                        [  1154,   1844],
                        [  1164,   1869],
                        [  1165,   1889],
                        [  1156,   1903],
                        [  1134,   1909],
                        [  1099,   1905],
                        [  1049,   1891],
                        [   983,   1864],
                        [   908,   1825],
                        [   823,   1772],
                        [   729,   1705],
                        [   626,   1623],
                        [   513,   1524],
                        [   391,   1412],
                        [   258,   1283],
                        [   117,   1140],
                        [   -33,    982],
                        [  -189,    813],
                        [  -354,    627],
                        [  -523,    433],
                        [  -698,    228],
                        [  -887,      2],
                        [ -1063,   -213],
                        [ -1128,   -321],
                        [ -1017,   -258],
                        [  -715,     -7],
                        [  -215,    435],
                        [   492,   1076],
                        [  1357,   1867],
                        [  2240,   2667],
                        [  3040,   3377],
                        [  3755,   3993],
                        [  4383,   4517],
                        [  4921,   4943],
                        [  5363,   5273],
                        [  5714,   5507],
                        [  5970,   5649],
                        [  6137,   5701],
                        [  6216,   5669],
                        [  6211,   5556],
                        [  6127,   5369],
                        [  5971,   5114],
                        [  5747,   4795],
                        [  5460,   4420],
                        [  5116,   3993],
                        [  4721,   3521],
                        [  4282,   3012],
                        [  3803,   2470],
                        [  3291,   1902],
                        [  2748,   1312],
                        [  2181,    706],
                        [  1592,     85],
                        [   986,   -546],
                        [   365,  -1184],
                        [  -265,  -1827],
                        [  -902,  -2471],
                        [ -1543,  -3113],
                        [ -2185,  -3749],
                        [ -2825,  -4373],
                        [ -3463,  -4982],
                        [ -4095,  -5577],
                        [ -4721,  -6157],
                        [ -5336,  -6728],
                        [ -5941,  -7289],
                        [ -6533,  -7846],
                        [ -7110,  -8396],
                        [ -7670,  -8935],
                        [ -8213,  -9466],
                        [ -8734,  -9980],
                        [ -9237, -10480],
                        [ -9714, -10955],
                        [-10169, -11406],
                        [-10598, -11826],
                        [-11001, -12214],
                        [-11375, -12569],
                        [-11721, -12888],
                        [-12036, -13174],
                        [-12319, -13427],
                        [-12569, -13648],
                        [-12786, -13836],
                        [-12968, -13989],
                        [-13114, -14106],
                        [-13223, -14188],
                        [-13294, -14236],
                        [-13327, -14250],
                        [-13319, -14231],
                        [-13273, -14180],
                        [-13188, -14096],
                        [-13067, -13982],
                        [-12911, -13837],
                        [-12731, -13663],
                        [-12530, -13462],
                        [-12315, -13236],
                        [-12088, -12985],
                        [-11845, -12712],
                        [-11590, -12417],
                        [-11313, -12107],
                        [-11017, -11782],
                        [-10714, -11463],
                        [-10406, -11148],
                        [-10090, -10834],
                        [ -9770, -10526],
                        [ -9417, -10191],
                        [ -9033,  -9833],
                        [ -8616,  -9444],
                        [ -8165,  -9027],
                        [ -7697,  -8592],
                        [ -7211,  -8143],
                        [ -6723,  -7691],
                        [ -6233,  -7236],
                        [ -5753,  -6790],
                        [ -5285,  -6353],
                        [ -4838,  -5936],
                        [ -4414,  -5537],
                        [ -4019,  -5164],
                        [ -3655,  -4817],
                        [ -3326,  -4500],
                        [ -3031,  -4213],
                        [ -2773,  -3959],
                        [ -2550,  -3735],
                        [ -2361,  -3543],
                        [ -2204,  -3382],
                        [ -2076,  -3248],
                        [ -1974,  -3140],
                        [ -1892,  -3057],
                        [ -1831,  -2994],
                        [ -1780,  -2949],
                        [ -1740,  -2918],
                        [ -1703,  -2895],
                        [ -1666,  -2880],
                        [ -1625,  -2863],
                        [ -1578,  -2847],
                        [ -1523,  -2823],
                        [ -1459,  -2790],
                        [ -1380,  -2743],
                        [ -1284,  -2680],
                        [ -1166,  -2597],
                        [ -1027,  -2491],
                        [  -863,  -2361],
                        [  -674,  -2207],
                        [  -457,  -2024],
                        [  -212,  -1814],
                        [    59,  -1578],
                        [   357,  -1314],
                        [   695,  -1009],
                        [  1029,   -709],
                        [  1260,   -511],
                        [  1325,   -479],
                        [  1212,   -621],
                        [   909,   -948],
                        [   396,  -1478],
                        [  -285,  -2166],
                        [  -986,  -2862],
                        [ -1607,  -3469],
                        [ -2147,  -3983],
                        [ -2606,  -4407],
                        [ -2979,  -4735],
                        [ -3266,  -4966],
                        [ -3466,  -5104],
                        [ -3582,  -5150],
                        [ -3618,  -5111],
                        [ -3579,  -4990],
                        [ -3470,  -4795],
                        [ -3300,  -4532],
                        [ -3075,  -4210],
                        [ -2802,  -3838],
                        [ -2490,  -3422],
                        [ -2147,  -2971],
                        [ -1782,  -2495],
                        [ -1401,  -2002],
                        [ -1012,  -1500],
                        [  -622,   -997],
                        [  -238,   -501],
                        [   136,    -16],
                        [   494,    451],
                        [   834,    898],
                        [  1150,   1319],
                        [  1440,   1713],
                        [  1701,   2075],
                        [  1933,   2405],
                        [  2134,   2693],
                        [  2304,   2939],
                        [  2444,   3140],
                        [  2554,   3296],
                        [  2635,   3413],
                        [  2690,   3492],
                        [  2722,   3551],
                        [  2732,   3590],
                        [  2723,   3616],
                        [  2697,   3631],
                        [  2658,   3636],
                        [  2608,   3634],
                        [  2552,   3624],
                        [  2492,   3610],
                        [  2431,   3589],
                        [  2373,   3564],
                        [  2319,   3538],
                        [  2273,   3511],
                        [  2238,   3486],
                        [  2214,   3465],
                        [  2204,   3453],
                        [  2211,   3452],
                        [  2233,   3460],
                        [  2272,   3479],
                        [  2329,   3511],
                        [  2402,   3553],
                        [  2490,   3610],
                        [  2593,   3681],
                        [  2707,   3766],
                        [  2836,   3865],
                        [  2974,   3978],
                        [  3120,   4103],
                        [  3282,   4240],
                        [  3457,   4387],
                        [  3655,   4543],
                        [  3874,   4707],
                        [  4114,   4876],
                        [  4371,   5047],
                        [  4636,   5224],
                        [  4906,   5400],
                        [  5188,   5600],
                        [  5478,   5819],
                        [  5785,   6070],
                        [  6108,   6352],
                        [  6421,   6637],
                        [  6724,   6926],
                        [  6971,   7168],
                        [  7162,   7367],
                        [  7294,   7516],
                        [  7364,   7612],
                        [  7382,   7664],
                        [  7343,   7668],
                        [  7263,   7633],
                        [  7137,   7559],
                        [  6977,   7453],
                        [  6781,   7315],
                        [  6561,   7152],
                        [  6315,   6966],
                        [  6053,   6761],
                        [  5775,   6537],
                        [  5488,   6303],
                        [  5194,   6055],
                        [  4895,   5800],
                        [  4593,   5537],
                        [  4291,   5272],
                        [  3989,   5003],
                        [  3689,   4733],
                        [  3391,   4463],
                        [  3097,   4195],
                        [  2809,   3929],
                        [  2525,   3666],
                        [  2247,   3406],
                        [  1970,   3150],
                        [  1698,   2897],
                        [  1431,   2647],
                        [  1172,   2403],
                        [   918,   2161],
                        [   674,   1926],
                        [   436,   1692],
                        [   208,   1464],
                        [   -12,   1240],
                        [  -223,   1021],
                        [  -425,    810],
                        [  -618,    604],
                        [  -803,    403],
                        [  -973,    214],
                        [ -1138,     30],
                        [ -1301,   -155],
                        [ -1420,   -296],
                        [ -1393,   -290],
                        [ -1171,    -93],
                        [  -749,    303],
                        [  -115,    908],
                        [   761,   1747],
                        [  1833,   2776],
                        [  2950,   3842],
                        [  4013,   4846],
                        [  5016,   5783],
                        [  5952,   6650],
                        [  6811,   7431],
                        [  7580,   8119],
                        [  8256,   8711],
                        [  8833,   9202],
                        [  9308,   9589],
                        [  9679,   9873],
                        [  9948,  10053],
                        [ 10116,  10132],
                        [ 10185,  10113],
                        [ 10157,  10000],
                        [ 10038,   9796],
                        [  9832,   9509],
                        [  9546,   9142],
                        [  9186,   8706],
                        [  8759,   8205],
                        [  8270,   7646],
                        [  7725,   7040],
                        [  7134,   6390],
                        [  6499,   5703],
                        [  5830,   4986],
                        [  5132,   4247],
                        [  4411,   3489],
                        [  3675,   2719],
                        [  2930,   1948],
                        [  2179,   1181],
                        [  1432,    433],
                        [   689,   -293],
                        [   -41,   -990],
                        [  -757,  -1655],
                        [ -1454,  -2298],
                        [ -2128,  -2913],
                        [ -2775,  -3511],
                        [ -3393,  -4089],
                        [ -3977,  -4644],
                        [ -4528,  -5175],
                        [ -5041,  -5677],
                        [ -5514,  -6149],
                        [ -5948,  -6586],
                        [ -6339,  -6988],
                        [ -6688,  -7350],
                        [ -6993,  -7673],
                        [ -7254,  -7954],
                        [ -7471,  -8193],
                        [ -7643,  -8389],
                        [ -7773,  -8543],
                        [ -7859,  -8654],
                        [ -7902,  -8725],
                        [ -7903,  -8750],
                        [ -7863,  -8732],
                        [ -7783,  -8673],
                        [ -7664,  -8574],
                        [ -7504,  -8438],
                        [ -7308,  -8266],
                        [ -7075,  -8062],
                        [ -6809,  -7826],
                        [ -6514,  -7562],
                        [ -6192,  -7271],
                        [ -5860,  -6958],
                        [ -5519,  -6623],
                        [ -5181,  -6269],
                        [ -4847,  -5900],
                        [ -4519,  -5518],
                        [ -4200,  -5124],
                        [ -3893,  -4743],
                        [ -3601,  -4375],
                        [ -3352,  -4058],
                        [ -3145,  -3792],
                        [ -2980,  -3577],
                        [ -2858,  -3416],
                        [ -2734,  -3261],
                        [ -2612,  -3117],
                        [ -2451,  -2940],
                        [ -2252,  -2734],
                        [ -2022,  -2503],
                        [ -1762,  -2247],
                        [ -1479,  -1974],
                        [ -1172,  -1684],
                        [  -852,  -1382],
                        [  -518,  -1071],
                        [  -179,   -757],
                        [   167,   -440],
                        [   509,   -126],
                        [   852,    188],
                        [  1185,    494],
                        [  1513,    795],
                        [  1831,   1088],
                        [  2139,   1375],
                        [  2438,   1651],
                        [  2728,   1922],
                        [  3013,   2184],
                        [  3293,   2441],
                        [  3568,   2693],
                        [  3838,   2942],
                        [  4107,   3190],
                        [  4375,   3437],
                        [  4650,   3687],
                        [  4932,   3941],
                        [  5227,   4203],
                        [  5536,   4472],
                        [  5858,   4752],
                        [  6195,   5043],
                        [  6547,   5347],
                        [  6914,   5664],
                        [  7297,   5995],
                        [  7695,   6342],
                        [  8107,   6701],
                        [  8532,   7071],
                        [  8969,   7455],
                        [  9416,   7846],
                        [  9867,   8244],
                        [ 10325,   8647],
                        [ 10795,   9063],
                        [ 11221,   9436],
                        [ 11511,   9674],
                        [ 11626,   9740],
                        [ 11559,   9631],
                        [ 11291,   9323],
                        [ 10779,   8783],
                        [ 10060,   8046],
                        [  9269,   7252],
                        [  8496,   6487],
                        [  7737,   5751],
                        [  7001,   5046],
                        [  6299,   4388],
                        [  5637,   3784],
                        [  5022,   3237],
                        [  4455,   2750],
                        [  3941,   2325],
                        [  3482,   1965],
                        [  3076,   1669],
                        [  2723,   1433],
                        [  2421,   1257],
                        [  2168,   1137],
                        [  1961,   1068],
                        [  1796,   1048],
                        [  1670,   1070],
                        [  1576,   1130],
                        [  1514,   1221],
                        [  1476,   1340],
                        [  1462,   1479],
                        [  1466,   1636],
                        [  1486,   1805],
                        [  1519,   1983],
                        [  1564,   2167],
                        [  1615,   2355],
                        [  1673,   2542],
                        [  1734,   2725],
                        [  1798,   2894],
                        [  1864,   3045],
                        [  1932,   3175],
                        [  2001,   3283],
                        [  2073,   3372],
                        [  2146,   3442],
                        [  2223,   3512],
                        [  2303,   3583],
                        [  2387,   3660],
                        [  2477,   3747],
                        [  2574,   3843],
                        [  2678,   3950],
                        [  2790,   4067],
                        [  2911,   4196],
                        [  3041,   4336],
                        [  3181,   4487],
                        [  3330,   4651],
                        [  3491,   4828],
                        [  3663,   5014],
                        [  3845,   5211],
                        [  4036,   5415],
                        [  4237,   5627],
                        [  4447,   5844],
                        [  4664,   6065],
                        [  4886,   6287],
                        [  5111,   6508],
                        [  5337,   6729],
                        [  5562,   6949],
                        [  5783,   7165],
                        [  5998,   7378],
                        [  6203,   7583],
                        [  6399,   7782],
                        [  6590,   7971],
                        [  6775,   8151],
                        [  6965,   8317],
                        [  7155,   8467],
                        [  7348,   8602],
                        [  7545,   8721],
                        [  7739,   8828],
                        [  7930,   8921],
                        [  8146,   9046],
                        [  8383,   9200],
                        [  8652,   9398],
                        [  8953,   9641],
                        [  9262,   9907],
                        [  9581,  10194],
                        [  9835,  10429],
                        [ 10029,  10617],
                        [ 10144,  10736],
                        [ 10180,  10788],
                        [ 10144,  10775],
                        [ 10034,  10699],
                        [  9861,  10567],
                        [  9623,  10376],
                        [  9333,  10139],
                        [  8990,   9854],
                        [  8606,   9530],
                        [  8182,   9168],
                        [  7732,   8778],
                        [  7254,   8359],
                        [  6762,   7921],
                        [  6255,   7464],
                        [  5744,   6997],
                        [  5228,   6521],
                        [  4713,   6041],
                        [  4201,   5559],
                        [  3699,   5081],
                        [  3207,   4609],
                        [  2734,   4144],
                        [  2281,   3690],
                        [  1845,   3248],
                        [  1430,   2819],
                        [  1029,   2406],
                        [   644,   2009],
                        [   275,   1628],
                        [   -79,   1265],
                        [  -416,    918],
                        [  -735,    591],
                        [ -1035,    280],
                        [ -1318,    -13],
                        [ -1584,   -288],
                        [ -1831,   -545],
                        [ -2060,   -783],
                        [ -2273,  -1003],
                        [ -2469,  -1206],
                        [ -2646,  -1385],
                        [ -2810,  -1551],
                        [ -2965,  -1704],
                        [ -3062,  -1794],
                        [ -3027,  -1751],
                        [ -2842,  -1557],
                        [ -2506,  -1209],
                        [ -1996,   -690],
                        [ -1276,     40],
                        [  -368,    951],
                        [   600,   1918],
                        [  1551,   2863],
                        [  2484,   3785],
                        [  3386,   4673],
                        [  4239,   5507],
                        [  5032,   6276],
                        [  5755,   6970],
                        [  6402,   7583],
                        [  6964,   8107],
                        [  7434,   8535],
                        [  7815,   8866],
                        [  8099,   9099],
                        [  8290,   9232],
                        [  8386,   9269],
                        [  8391,   9211],
                        [  8308,   9062],
                        [  8142,   8826],
                        [  7898,   8511],
                        [  7582,   8122],
                        [  7200,   7666],
                        [  6759,   7152],
                        [  6267,   6586],
                        [  5728,   5978],
                        [  5152,   5332],
                        [  4544,   4659],
                        [  3915,   3964],
                        [  3269,   3255],
                        [  2615,   2546],
                        [  1958,   1844],
                        [  1307,   1165],
                        [   666,    514],
                        [    41,   -101],
                        [  -564,   -676],
                        [ -1144,  -1217],
                        [ -1694,  -1719],
                        [ -2212,  -2195],
                        [ -2693,  -2642],
                        [ -3135,  -3058],
                        [ -3537,  -3442],
                        [ -3896,  -3792],
                        [ -4210,  -4107],
                        [ -4480,  -4386],
                        [ -4705,  -4630],
                        [ -4883,  -4838],
                        [ -5016,  -5012],
                        [ -5105,  -5150],
                        [ -5150,  -5254],
                        [ -5153,  -5318],
                        [ -5116,  -5345],
                        [ -5040,  -5333],
                        [ -4928,  -5287],
                        [ -4782,  -5202],
                        [ -4604,  -5080],
                        [ -4396,  -4926],
                        [ -4162,  -4740],
                        [ -3901,  -4526],
                        [ -3616,  -4288],
                        [ -3313,  -4026],
                        [ -2991,  -3745],
                        [ -2657,  -3448],
                        [ -2313,  -3138],
                        [ -1977,  -2818],
                        [ -1645,  -2487],
                        [ -1333,  -2151],
                        [ -1040,  -1811],
                        [  -772,  -1473],
                        [  -530,  -1138],
                        [  -333,   -841],
                        [  -182,   -583],
                        [  -110,   -407],
                        [  -115,   -314],
                        [  -197,   -306],
                        [  -354,   -383],
                        [  -532,   -489],
                        [  -734,   -629],
                        [  -893,   -737],
                        [ -1012,   -815],
                        [ -1091,   -862],
                        [ -1128,   -876],
                        [ -1121,   -858],
                        [ -1072,   -807],
                        [  -983,   -726],
                        [  -853,   -613],
                        [  -689,   -474],
                        [  -488,   -306],
                        [  -258,   -113],
                        [     3,    106],
                        [   288,    345],
                        [   598,    607],
                        [   927,    888],
                        [  1278,   1190],
                        [  1645,   1508],
                        [  2033,   1844],
                        [  2433,   2195],
                        [  2849,   2560],
                        [  3273,   2940],
                        [  3704,   3332],
                        [  4142,   3737],
                        [  4586,   4152],
                        [  5041,   4578],
                        [  5506,   5014],
                        [  5985,   5458],
                        [  6479,   5910],
                        [  6982,   6368],
                        [  7495,   6832],
                        [  8013,   7298],
                        [  8534,   7765],
                        [  9055,   8231],
                        [  9574,   8695],
                        [ 10085,   9150],
                        [ 10587,   9596],
                        [ 11077,  10031],
                        [ 11550,  10449],
                        [ 11999,  10843],
                        [ 12427,  11217],
                        [ 12832,  11568],
                        [ 13163,  11845],
                        [ 13369,  12002],
                        [ 13440,  12027],
                        [ 13371,  11915],
                        [ 13134,  11643],
                        [ 12680,  11162],
                        [ 12021,  10485],
                        [ 11253,   9709],
                        [ 10433,   8893],
                        [  9563,   8036],
                        [  8654,   7149],
                        [  7722,   6250],
                        [  6779,   5351],
                        [  5835,   4461],
                        [  4898,   3590],
                        [  3980,   2749],
                        [  3086,   1943],
                        [  2225,   1178],
                        [  1401,    460],
                        [   618,   -209],
                        [  -119,   -825],
                        [  -809,  -1386],
                        [ -1450,  -1893],
                        [ -2039,  -2345],
                        [ -2578,  -2742],
                        [ -3066,  -3088],
                        [ -3504,  -3382],
                        [ -3892,  -3628],
                        [ -4232,  -3827],
                        [ -4523,  -3982],
                        [ -4769,  -4096],
                        [ -4970,  -4171],
                        [ -5129,  -4210],
                        [ -5246,  -4217],
                        [ -5324,  -4193],
                        [ -5367,  -4154],
                        [ -5376,  -4100],
                        [ -5350,  -4038],
                        [ -5293,  -3970],
                        [ -5207,  -3896],
                        [ -5092,  -3818],
                        [ -4951,  -3720],
                        [ -4786,  -3607],
                        [ -4596,  -3469],
                        [ -4386,  -3309],
                        [ -4156,  -3126],
                        [ -3907,  -2922],
                        [ -3643,  -2698],
                        [ -3365,  -2453],
                        [ -3076,  -2187],
                        [ -2777,  -1902],
                        [ -2472,  -1599],
                        [ -2160,  -1277],
                        [ -1845,   -947],
                        [ -1530,   -606],
                        [ -1216,   -264],
                        [  -907,     76],
                        [  -603,    411],
                        [  -307,    739],
                        [   -22,   1052],
                        [   249,   1350],
                        [   505,   1632],
                        [   741,   1896],
                        [   956,   2139],
                        [  1149,   2359],
                        [  1317,   2555],
                        [  1459,   2727],
                        [  1581,   2873],
                        [  1682,   2992],
                        [  1769,   3081],
                        [  1839,   3139],
                        [  1901,   3168],
                        [  1955,   3170],
                        [  2005,   3154],
                        [  2053,   3121],
                        [  2139,   3127],
                        [  2259,   3167],
                        [  2427,   3262],
                        [  2641,   3411],
                        [  2886,   3599],
                        [  3164,   3829],
                        [  3389,   4015],
                        [  3568,   4164],
                        [  3675,   4250],
                        [  3712,   4276],
                        [  3682,   4243],
                        [  3586,   4150],
                        [  3426,   4002],
                        [  3205,   3801],
                        [  2930,   3551],
                        [  2602,   3253],
                        [  2233,   2918],
                        [  1822,   2544],
                        [  1382,   2140],
                        [   914,   1708],
                        [   430,   1256],
                        [   -71,    785],
                        [  -578,    302],
                        [ -1090,   -190],
                        [ -1602,   -685],
                        [ -2111,  -1181],
                        [ -2605,  -1674],
                        [ -3085,  -2160],
                        [ -3543,  -2637],
                        [ -3976,  -3101],
                        [ -4387,  -3551],
                        [ -4777,  -3986],
                        [ -5151,  -4403],
                        [ -5509,  -4801],
                        [ -5853,  -5180],
                        [ -6184,  -5539],
                        [ -6499,  -5878],
                        [ -6797,  -6196],
                        [ -7079,  -6494],
                        [ -7346,  -6771],
                        [ -7595,  -7027],
                        [ -7828,  -7263],
                        [ -8045,  -7478],
                        [ -8247,  -7672],
                        [ -8432,  -7845],
                        [ -8600,  -7993],
                        [ -8756,  -8124],
                        [ -8895,  -8233],
                        [ -8990,  -8292],
                        [ -9017,  -8277],
                        [ -8979,  -8194],
                        [ -8876,  -8043],
                        [ -8681,  -7798],
                        [ -8347,  -7412],
                        [ -7867,  -6882],
                        [ -7312,  -6277],
                        [ -6723,  -5640],
                        [ -6103,  -4974],
                        [ -5465,  -4292],
                        [ -4825,  -3612],
                        [ -4196,  -2947],
                        [ -3586,  -2307],
                        [ -3007,  -1704],
                        [ -2468,  -1148],
                        [ -1974,   -647],
                        [ -1533,   -205],
                        [ -1150,    173],
                        [  -826,    482],
                        [  -563,    722],
                        [  -364,    891],
                        [  -226,    992],
                        [  -148,   1025],
                        [  -128,    995],
                        [  -163,    904],
                        [  -247,    758],
                        [  -378,    561],
                        [  -550,    320],
                        [  -758,     40],
                        [  -997,   -272],
                        [ -1261,   -611],
                        [ -1544,   -969],
                        [ -1840,  -1341],
                        [ -2145,  -1713],
                        [ -2452,  -2082],
                        [ -2756,  -2432],
                        [ -3052,  -2760],
                        [ -3337,  -3059],
                        [ -3607,  -3324],
                        [ -3858,  -3559],
                        [ -4087,  -3760],
                        [ -4292,  -3940],
                        [ -4472,  -4094],
                        [ -4624,  -4226],
                        [ -4747,  -4334],
                        [ -4840,  -4418],
                        [ -4903,  -4479],
                        [ -4937,  -4520],
                        [ -4940,  -4542],
                        [ -4914,  -4550],
                        [ -4860,  -4543],
                        [ -4778,  -4522],
                        [ -4671,  -4490],
                        [ -4541,  -4439],
                        [ -4388,  -4371],
                        [ -4218,  -4285],
                        [ -4029,  -4181],
                        [ -3826,  -4059],
                        [ -3612,  -3920],
                        [ -3386,  -3766],
                        [ -3152,  -3599],
                        [ -2913,  -3420],
                        [ -2668,  -3232],
                        [ -2423,  -3038],
                        [ -2177,  -2838],
                        [ -1935,  -2636],
                        [ -1701,  -2433],
                        [ -1480,  -2231],
                        [ -1274,  -2028],
                        [ -1090,  -1827],
                        [  -930,  -1632],
                        [  -800,  -1446],
                        [  -700,  -1268],
                        [  -658,  -1140],
                        [  -675,  -1058],
                        [  -778,  -1063],
                        [  -962,  -1151],
                        [ -1230,  -1327],
                        [ -1581,  -1591],
                        [ -1958,  -1890],
                        [ -2365,  -2227],
                        [ -2729,  -2530],
                        [ -3053,  -2804],
                        [ -3330,  -3041],
                        [ -3556,  -3239],
                        [ -3725,  -3392],
                        [ -3837,  -3500],
                        [ -3891,  -3560],
                        [ -3885,  -3572],
                        [ -3820,  -3535],
                        [ -3696,  -3450],
                        [ -3519,  -3319],
                        [ -3286,  -3140],
                        [ -3005,  -2919],
                        [ -2676,  -2651],
                        [ -2307,  -2347],
                        [ -1895,  -2001],
                        [ -1449,  -1623],
                        [  -967,  -1211],
                        [  -461,   -770],
                        [    71,   -302],
                        [   612,    187],
                        [  1164,    696],
                        [  1722,   1220],
                        [  2282,   1757],
                        [  2849,   2303],
                        [  3420,   2853],
                        [  3997,   3402],
                        [  4577,   3949],
                        [  5153,   4489],
                        [  5722,   5019],
                        [  6277,   5532],
                        [  6818,   6029],
                        [  7336,   6502],
                        [  7828,   6950],
                        [  8290,   7367],
                        [  8717,   7750],
                        [  9106,   8096],
                        [  9453,   8399],
                        [  9751,   8655],
                        [ 10002,   8864],
                        [ 10201,   9020],
                        [ 10331,   9111],
                        [ 10394,   9136],
                        [ 10400,   9107],
                        [ 10346,   9022],
                        [ 10203,   8852],
                        [  9924,   8551],
                        [  9480,   8089],
                        [  8905,   7501],
                        [  8228,   6816],
                        [  7453,   6039],
                        [  6593,   5181],
                        [  5667,   4264],
                        [  4687,   3299],
                        [  3664,   2300],
                        [  2614,   1280],
                        [  1550,    256],
                        [   484,   -763],
                        [  -574,  -1766],
                        [ -1614,  -2742],
                        [ -2626,  -3683],
                        [ -3602,  -4583],
                        [ -4533,  -5435],
                        [ -5416,  -6233],
                        [ -6244,  -6972],
                        [ -7014,  -7651],
                        [ -7720,  -8265],
                        [ -8364,  -8813],
                        [ -8940,  -9296],
                        [ -9449,  -9712],
                        [ -9891, -10064],
                        [-10264, -10351],
                        [-10571, -10576],
                        [-10814, -10742],
                        [-10992, -10853],
                        [-11111, -10910],
                        [-11173, -10926],
                        [-11178, -10902],
                        [-11134, -10846],
                        [-11039, -10761],
                        [-10901, -10652],
                        [-10722, -10521],
                        [-10504, -10363],
                        [-10253, -10180],
                        [ -9972,  -9968],
                        [ -9664,  -9731],
                        [ -9335,  -9469],
                        [ -8986,  -9188],
                        [ -8625,  -8886],
                        [ -8253,  -8566],
                        [ -7874,  -8226],
                        [ -7493,  -7869],
                        [ -7113,  -7495],
                        [ -6739,  -7108],
                        [ -6372,  -6715],
                        [ -6017,  -6319],
                        [ -5677,  -5932],
                        [ -5354,  -5555],
                        [ -5048,  -5194],
                        [ -4765,  -4853],
                        [ -4505,  -4535],
                        [ -4271,  -4242],
                        [ -4064,  -3976],
                        [ -3885,  -3741],
                        [ -3735,  -3534],
                        [ -3614,  -3360],
                        [ -3521,  -3216],
                        [ -3460,  -3105],
                        [ -3422,  -3024],
                        [ -3411,  -2975],
                        [ -3421,  -2961],
                        [ -3452,  -2979],
                        [ -3495,  -3023],
                        [ -3549,  -3096],
                        [ -3598,  -3179],
                        [ -3642,  -3272],
                        [ -3639,  -3324],
                        [ -3590,  -3338],
                        [ -3486,  -3297],
                        [ -3326,  -3200],
                        [ -3113,  -3050],
                        [ -2847,  -2845],
                        [ -2605,  -2661],
                        [ -2381,  -2490],
                        [ -2197,  -2355],
                        [ -2054,  -2256],
                        [ -1955,  -2195],
                        [ -1897,  -2171],
                        [ -1886,  -2186],
                        [ -1916,  -2238],
                        [ -1987,  -2325],
                        [ -2100,  -2449],
                        [ -2247,  -2602],
                        [ -2429,  -2786],
                        [ -2638,  -2995],
                        [ -2873,  -3229],
                        [ -3127,  -3482],
                        [ -3399,  -3754],
                        [ -3682,  -4037],
                        [ -3977,  -4335],
                        [ -4276,  -4638],
                        [ -4578,  -4948],
                        [ -4872,  -5259],
                        [ -5158,  -5572],
                        [ -5429,  -5881],
                        [ -5686,  -6186],
                        [ -5930,  -6485],
                        [ -6163,  -6777],
                        [ -6392,  -7058],
                        [ -6616,  -7330],
                        [ -6838,  -7589],
                        [ -7058,  -7837],
                        [ -7273,  -8071],
                        [ -7481,  -8292],
                        [ -7683,  -8498],
                        [ -7880,  -8690],
                        [ -8069,  -8868],
                        [ -8249,  -9029],
                        [ -8422,  -9176],
                        [ -8585,  -9307],
                        [ -8738,  -9421],
                        [ -8882,  -9517],
                        [ -9016,  -9597],
                        [ -9138,  -9658],
                        [ -9259,  -9713],
                        [ -9406,  -9788],
                        [ -9592,  -9900],
                        [ -9815, -10045],
                        [-10054, -10203],
                        [-10256, -10320],
                        [-10368, -10346],
                        [-10389, -10280],
                        [-10334, -10134],
                        [-10206,  -9916],
                        [-10013,  -9634],
                        [ -9768,  -9302],
                        [ -9478,  -8929],
                        [ -9152,  -8526],
                        [ -8799,  -8103],
                        [ -8429,  -7671],
                        [ -8049,  -7239],
                        [ -7665,  -6811],
                        [ -7285,  -6398],
                        [ -6913,  -6002],
                        [ -6554,  -5628],
                        [ -6210,  -5280],
                        [ -5884,  -4957],
                        [ -5579,  -4665],
                        [ -5294,  -4403],
                        [ -5032,  -4170],
                        [ -4790,  -3966],
                        [ -4569,  -3790],
                        [ -4366,  -3638],
                        [ -4181,  -3509],
                        [ -4011,  -3400],
                        [ -3855,  -3305],
                        [ -3709,  -3223],
                        [ -3572,  -3152],
                        [ -3439,  -3081],
                        [ -3310,  -3010],
                        [ -3183,  -2931],
                        [ -3053,  -2841],
                        [ -2920,  -2736],
                        [ -2783,  -2611],
                        [ -2640,  -2470],
                        [ -2490,  -2309],
                        [ -2333,  -2138],
                        [ -2167,  -1952],
                        [ -1993,  -1759],
                        [ -1812,  -1557],
                        [ -1622,  -1349],
                        [ -1424,  -1135],
                        [ -1220,   -922],
                        [ -1009,   -712],
                        [  -794,   -511],
                        [  -574,   -321],
                        [  -351,   -141],
                        [  -126,     26],
                        [   100,    187],
                        [   324,    338],
                        [   546,    488],
                        [   765,    635],
                        [   977,    778],
                        [  1183,    916],
                        [  1382,   1051],
                        [  1571,   1181],
                        [  1749,   1306],
                        [  1918,   1424],
                        [  2072,   1537],
                        [  2214,   1644],
                        [  2342,   1742],
                        [  2455,   1833],
                        [  2553,   1917],
                        [  2638,   1996],
                        [  2708,   2069],
                        [  2759,   2134],
                        [  2789,   2191],
                        [  2797,   2239],
                        [  2752,   2244],
                        [  2659,   2211],
                        [  2501,   2117],
                        [  2280,   1962],
                        [  1991,   1740],
                        [  1635,   1449],
                        [  1252,   1128],
                        [   842,    775],
                        [   464,    449],
                        [   116,    144],
                        [  -190,   -127],
                        [  -453,   -363],
                        [  -663,   -555],
                        [  -819,   -702],
                        [  -915,   -800],
                        [  -951,   -847],
                        [  -925,   -843],
                        [  -839,   -785],
                        [  -693,   -676],
                        [  -489,   -516],
                        [  -232,   -307],
                        [    76,    -50],
                        [   430,    249],
                        [   828,    591],
                        [  1261,    968],
                        [  1728,   1379],
                        [  2216,   1817],
                        [  2721,   2279],
                        [  3231,   2759],
                        [  3745,   3255],
                        [  4253,   3756],
                        [  4755,   4263],
                        [  5250,   4766],
                        [  5736,   5263],
                        [  6213,   5746],
                        [  6677,   6212],
                        [  7120,   6654],
                        [  7539,   7071],
                        [  7928,   7455],
                        [  8284,   7803],
                        [  8601,   8112],
                        [  8876,   8378],
                        [  9103,   8595],
                        [  9282,   8763],
                        [  9407,   8878],
                        [  9477,   8938],
                        [  9492,   8942],
                        [  9446,   8886],
                        [  9344,   8772],
                        [  9220,   8637],
                        [  9120,   8526],
                        [  9060,   8459],
                        [  9043,   8434],
                        [  9050,   8433],
                        [  9033,   8407],
                        [  8916,   8279],
                        [  8669,   8018],
                        [  8301,   7633],
                        [  7821,   7135],
                        [  7238,   6533],
                        [  6564,   5841],
                        [  5813,   5072],
                        [  4996,   4239],
                        [  4128,   3356],
                        [  3221,   2440],
                        [  2288,   1502],
                        [  1343,    555],
                        [   396,   -391],
                        [  -540,  -1321],
                        [ -1458,  -2230],
                        [ -2347,  -3107],
                        [ -3198,  -3944],
                        [ -4004,  -4734],
                        [ -4760,  -5471],
                        [ -5458,  -6151],
                        [ -6097,  -6769],
                        [ -6673,  -7323],
                        [ -7183,  -7811],
                        [ -7627,  -8232],
                        [ -8004,  -8587],
                        [ -8314,  -8876],
                        [ -8558,  -9102],
                        [ -8738,  -9268],
                        [ -8858,  -9376],
                        [ -8919,  -9433],
                        [ -8925,  -9441],
                        [ -8881,  -9406],
                        [ -8790,  -9333],
                        [ -8656,  -9229],
                        [ -8483,  -9098],
                        [ -8277,  -8941],
                        [ -8041,  -8763],
                        [ -7781,  -8563],
                        [ -7501,  -8345],
                        [ -7205,  -8112],
                        [ -6899,  -7867],
                        [ -6587,  -7609],
                        [ -6272,  -7344],
                        [ -5959,  -7066],
                        [ -5653,  -6778],
                        [ -5355,  -6481],
                        [ -5070,  -6178],
                        [ -4801,  -5874],
                        [ -4551,  -5573],
                        [ -4320,  -5285],
                        [ -4112,  -5012],
                        [ -3928,  -4760],
                        [ -3768,  -4528],
                        [ -3633,  -4320],
                        [ -3524,  -4136],
                        [ -3440,  -3978],
                        [ -3381,  -3848],
                        [ -3344,  -3743],
                        [ -3330,  -3664],
                        [ -3335,  -3610],
                        [ -3360,  -3582],
                        [ -3400,  -3574],
                        [ -3457,  -3590],
                        [ -3532,  -3628],
                        [ -3621,  -3686],
                        [ -3716,  -3759],
                        [ -3818,  -3844],
                        [ -3904,  -3928],
                        [ -3976,  -4008],
                        [ -4002,  -4056],
                        [ -3985,  -4071],
                        [ -3913,  -4040],
                        [ -3787,  -3964],
                        [ -3598,  -3830],
                        [ -3344,  -3637],
                        [ -3079,  -3434],
                        [ -2797,  -3217],
                        [ -2518,  -3003],
                        [ -2240,  -2791],
                        [ -1976,  -2589],
                        [ -1723,  -2397],
                        [ -1489,  -2221],
                        [ -1274,  -2060],
                        [ -1083,  -1918],
                        [  -915,  -1796],
                        [  -774,  -1694],
                        [  -657,  -1613],
                        [  -565,  -1552],
                        [  -498,  -1512],
                        [  -454,  -1493],
                        [  -434,  -1494],
                        [  -434,  -1514],
                        [  -455,  -1551],
                        [  -490,  -1604],
                        [  -540,  -1673],
                        [  -597,  -1755],
                        [  -662,  -1851],
                        [  -729,  -1957],
                        [  -799,  -2074],
                        [  -874,  -2198],
                        [  -955,  -2329],
                        [ -1047,  -2464],
                        [ -1152,  -2602],
                        [ -1268,  -2743],
                        [ -1395,  -2884],
                        [ -1530,  -3024],
                        [ -1672,  -3163],
                        [ -1821,  -3297],
                        [ -1974,  -3426],
                        [ -2129,  -3549],
                        [ -2284,  -3664],
                        [ -2438,  -3771],
                        [ -2587,  -3868],
                        [ -2732,  -3954],
                        [ -2872,  -4028],
                        [ -3000,  -4083],
                        [ -3127,  -4132],
                        [ -3308,  -4235],
                        [ -3600,  -4445],
                        [ -4020,  -4780],
                        [ -4564,  -5238],
                        [ -5222,  -5806],
                        [ -5939,  -6429],
                        [ -6608,  -7001],
                        [ -7174,  -7464],
                        [ -7631,  -7816],
                        [ -7984,  -8061],
                        [ -8234,  -8203],
                        [ -8386,  -8247],
                        [ -8443,  -8199],
                        [ -8412,  -8067],
                        [ -8299,  -7859],
                        [ -8114,  -7584],
                        [ -7860,  -7250],
                        [ -7547,  -6864],
                        [ -7182,  -6433],
                        [ -6772,  -5968],
                        [ -6322,  -5471],
                        [ -5839,  -4948],
                        [ -5328,  -4407],
                        [ -4798,  -3854],
                        [ -4251,  -3291],
                        [ -3692,  -2724],
                        [ -3127,  -2158],
                        [ -2555,  -1593],
                        [ -1984,  -1035],
                        [ -1414,   -483],
                        [  -848,     59],
                        [  -288,    592],
                        [   265,   1115],
                        [   808,   1627],
                        [  1341,   2129],
                        [  1862,   2619],
                        [  2371,   3098],
                        [  2867,   3565],
                        [  3349,   4023],
                        [  3816,   4471],
                        [  4268,   4912],
                        [  4704,   5348],
                        [  5123,   5774],
                        [  5525,   6192],
                        [  5909,   6598],
                        [  6275,   6990],
                        [  6621,   7366],
                        [  6949,   7726],
                        [  7258,   8062],
                        [  7547,   8374],
                        [  7815,   8655],
                        [  8064,   8903],
                        [  8292,   9120],
                        [  8502,   9304],
                        [  8691,   9460],
                        [  8860,   9589],
                        [  9011,   9699],
                        [  9143,   9790],
                        [  9256,   9861],
                        [  9351,   9913],
                        [  9428,   9948],
                        [  9488,   9969],
                        [  9531,   9976],
                        [  9557,   9969],
                        [  9567,   9950],
                        [  9562,   9921],
                        [  9541,   9882],
                        [  9509,   9836],
                        [  9471,   9783],
                        [  9428,   9728],
                        [  9386,   9669],
                        [  9343,   9607],
                        [  9294,   9541],
                        [  9242,   9472],
                        [  9166,   9386],
                        [  9068,   9286],
                        [  8943,   9166],
                        [  8794,   9029],
                        [  8605,   8856],
                        [  8379,   8652],
                        [  8128,   8422],
                        [  7850,   8168],
                        [  7583,   7924],
                        [  7323,   7685],
                        [  7083,   7463],
                        [  6864,   7259],
                        [  6676,   7083],
                        [  6520,   6933],
                        [  6403,   6818],
                        [  6322,   6736],
                        [  6285,   6691],
                        [  6289,   6682],
                        [  6335,   6710],
                        [  6421,   6775],
                        [  6546,   6875],
                        [  6705,   7007],
                        [  6895,   7169],
                        [  7114,   7359],
                        [  7353,   7572],
                        [  7612,   7804],
                        [  7875,   8051],
                        [  8143,   8309],
                        [  8405,   8572],
                        [  8659,   8838],
                        [  8896,   9098],
                        [  9115,   9352],
                        [  9315,   9591],
                        [  9497,   9813],
                        [  9655,  10011],
                        [  9789,  10182],
                        [  9893,  10322],
                        [  9965,  10428],
                        [ 10001,  10495],
                        [ 10000,  10522],
                        [  9956,  10505],
                        [  9870,  10443],
                        [  9739,  10334],
                        [  9562,  10178],
                        [  9338,   9973],
                        [  9068,   9722],
                        [  8754,   9423],
                        [  8389,   9072],
                        [  7995,   8691],
                        [  7655,   8365],
                        [  7434,   8156],
                        [  7350,   8081],
                        [  7405,   8145],
                        [  7601,   8346],
                        [  7893,   8634],
                        [  8153,   8883],
                        [  8309,   9020],
                        [  8361,   9045],
                        [  8317,   8967],
                        [  8179,   8787],
                        [  7954,   8514],
                        [  7646,   8155],
                        [  7268,   7721],
                        [  6826,   7221],
                        [  6332,   6667],
                        [  5794,   6069],
                        [  5223,   5438],
                        [  4630,   4784],
                        [  4023,   4118],
                        [  3411,   3447],
                        [  2802,   2780],
                        [  2205,   2125],
                        [  1627,   1489],
                        [  1075,    881],
                        [   553,    305],
                        [    66,   -235],
                        [  -383,   -733],
                        [  -791,  -1187],
                        [ -1155,  -1597],
                        [ -1476,  -1958],
                        [ -1753,  -2275],
                        [ -1987,  -2545],
                        [ -2178,  -2771],
                        [ -2326,  -2953],
                        [ -2436,  -3093],
                        [ -2510,  -3192],
                        [ -2550,  -3254],
                        [ -2561,  -3280],
                        [ -2544,  -3279],
                        [ -2503,  -3256],
                        [ -2443,  -3217],
                        [ -2367,  -3166],
                        [ -2278,  -3107],
                        [ -2180,  -3043],
                        [ -2077,  -2975],
                        [ -1971,  -2906],
                        [ -1866,  -2835],
                        [ -1766,  -2765],
                        [ -1670,  -2690],
                        [ -1583,  -2614],
                        [ -1506,  -2533],
                        [ -1442,  -2451],
                        [ -1391,  -2369],
                        [ -1355,  -2290],
                        [ -1333,  -2219],
                        [ -1328,  -2158],
                        [ -1337,  -2110],
                        [ -1362,  -2076],
                        [ -1399,  -2053],
                        [ -1450,  -2041],
                        [ -1510,  -2042],
                        [ -1580,  -2053],
                        [ -1653,  -2075],
                        [ -1731,  -2105],
                        [ -1808,  -2143],
                        [ -1885,  -2187],
                        [ -1962,  -2234],
                        [ -2039,  -2285],
                        [ -2121,  -2338],
                        [ -2204,  -2390],
                        [ -2286,  -2437],
                        [ -2364,  -2478],
                        [ -2425,  -2509],
                        [ -2466,  -2528],
                        [ -2481,  -2533],
                        [ -2468,  -2524],
                        [ -2420,  -2492],
                        [ -2337,  -2437],
                        [ -2195,  -2334],
                        [ -1993,  -2181],
                        [ -1749,  -1992],
                        [ -1460,  -1766],
                        [ -1142,  -1514],
                        [  -795,  -1237],
                        [  -433,   -946],
                        [   -55,   -641],
                        [   326,   -332],
                        [   710,    -19],
                        [  1086,    289],
                        [  1453,    592],
                        [  1802,    882],
                        [  2134,   1160],
                        [  2442,   1419],
                        [  2727,   1660],
                        [  2983,   1879],
                        [  3209,   2074],
                        [  3408,   2246],
                        [  3576,   2393],
                        [  3718,   2514],
                        [  3834,   2611],
                        [  3926,   2682],
                        [  3993,   2728],
                        [  4041,   2753],
                        [  4069,   2754],
                        [  4076,   2734],
                        [  4063,   2693],
                        [  4028,   2637],
                        [  3969,   2564],
                        [  3890,   2479],
                        [  3792,   2382],
                        [  3677,   2277],
                        [  3547,   2165],
                        [  3408,   2050],
                        [  3257,   1932],
                        [  3101,   1816],
                        [  2940,   1701],
                        [  2780,   1593],
                        [  2622,   1490],
                        [  2468,   1394],
                        [  2319,   1307],
                        [  2189,   1240],
                        [  2043,   1159],
                        [  1792,    973],
                        [  1375,    619],
                        [   785,     92],
                        [    16,   -613],
                        [  -937,  -1501],
                        [ -2017,  -2512],
                        [ -3082,  -3503],
                        [ -4041,  -4382],
                        [ -4887,  -5144],
                        [ -5624,  -5792],
                        [ -6241,  -6319],
                        [ -6739,  -6724],
                        [ -7117,  -7009],
                        [ -7377,  -7178],
                        [ -7523,  -7235],
                        [ -7560,  -7185],
                        [ -7493,  -7035],
                        [ -7328,  -6792],
                        [ -7073,  -6462],
                        [ -6735,  -6054],
                        [ -6321,  -5575],
                        [ -5839,  -5031],
                        [ -5299,  -4434],
                        [ -4708,  -3789],
                        [ -4074,  -3105],
                        [ -3404,  -2390],
                        [ -2706,  -1651],
                        [ -1987,   -895],
                        [ -1254,   -129],
                        [  -510,    642],
                        [   235,   1412],
                        [   978,   2176],
                        [  1713,   2931],
                        [  2436,   3671],
                        [  3142,   4392],
                        [  3829,   5089],
                        [  4492,   5755],
                        [  5129,   6389],
                        [  5738,   6988],
                        [  6316,   7552],
                        [  6862,   8088],
                        [  7374,   8592],
                        [  7852,   9072],
                        [  8295,   9523],
                        [  8701,   9947],
                        [  9072,  10344],
                        [  9406,  10709],
                        [  9704,  11044],
                        [  9967,  11343],
                        [ 10196,  11607],
                        [ 10391,  11830],
                        [ 10554,  12014],
                        [ 10687,  12159],
                        [ 10790,  12266],
                        [ 10865,  12338],
                        [ 10914,  12378],
                        [ 10940,  12391],
                        [ 10944,  12383],
                        [ 10927,  12349],
                        [ 10892,  12295],
                        [ 10840,  12222],
                        [ 10774,  12131],
                        [ 10691,  12026],
                        [ 10597,  11909],
                        [ 10489,  11782],
                        [ 10372,  11647],
                        [ 10249,  11507],
                        [ 10122,  11363],
                        [ 10003,  11217],
                        [  9893,  11074],
                        [  9800,  10931],
                        [  9722,  10791],
                        [  9657,  10655],
                        [  9604,  10525],
                        [  9562,  10411],
                        [  9534,  10316],
                        [  9522,  10246],
                        [  9526,  10202],
                        [  9524,  10162],
                        [  9518,  10127],
                        [  9483,  10070],
                        [  9419,   9991],
                        [  9334,   9899],
                        [  9227,   9789],
                        [  9107,   9672],
                        [  8975,   9545],
                        [  8839,   9417],
                        [  8697,   9287],
                        [  8558,   9161],
                        [  8418,   9037],
                        [  8287,   8920],
                        [  8159,   8810],
                        [  8041,   8708],
                        [  7932,   8613],
                        [  7829,   8526],
                        [  7733,   8444],
                        [  7642,   8367],
                        [  7552,   8293],
                        [  7461,   8219],
                        [  7365,   8145],
                        [  7260,   8065],
                        [  7143,   7979],
                        [  7009,   7883],
                        [  6858,   7775],
                        [  6683,   7651],
                        [  6481,   7510],
                        [  6256,   7348],
                        [  6005,   7164],
                        [  5728,   6954],
                        [  5425,   6718],
                        [  5094,   6452],
                        [  4734,   6156],
                        [  4349,   5829],
                        [  3934,   5471],
                        [  3492,   5081],
                        [  3023,   4660],
                        [  2529,   4210],
                        [  2009,   3730],
                        [  1464,   3223],
                        [   902,   2695],
                        [   322,   2146],
                        [  -281,   1571],
                        [  -861,   1016],
                        [ -1313,    589],
                        [ -1579,    345],
                        [ -1649,    294],
                        [ -1507,    449],
                        [ -1137,    827],
                        [  -583,   1377],
                        [     0,   1948],
                        [   527,   2448],
                        [   996,   2880],
                        [  1409,   3244],
                        [  1757,   3534],
                        [  2039,   3749],
                        [  2256,   3891],
                        [  2410,   3963],
                        [  2502,   3967],
                        [  2536,   3908],
                        [  2517,   3792],
                        [  2450,   3624],
                        [  2339,   3411],
                        [  2191,   3157],
                        [  2009,   2870],
                        [  1801,   2555],
                        [  1573,   2219],
                        [  1328,   1867],
                        [  1073,   1504],
                        [   810,   1137],
                        [   546,    769],
                        [   281,    405],
                        [    20,     47],
                        [  -236,   -300],
                        [  -484,   -634],
                        [  -724,   -955],
                        [  -955,  -1260],
                        [ -1174,  -1549],
                        [ -1384,  -1822],
                        [ -1582,  -2071],
                        [ -1770,  -2299],
                        [ -1950,  -2502],
                        [ -2121,  -2680],
                        [ -2286,  -2841],
                        [ -2444,  -2988],
                        [ -2597,  -3129],
                        [ -2746,  -3268],
                        [ -2893,  -3410],
                        [ -3040,  -3556],
                        [ -3186,  -3707],
                        [ -3333,  -3863],
                        [ -3480,  -4021],
                        [ -3629,  -4184],
                        [ -3780,  -4345],
                        [ -3933,  -4506],
                        [ -4086,  -4664],
                        [ -4242,  -4818],
                        [ -4398,  -4968],
                        [ -4555,  -5112],
                        [ -4711,  -5254],
                        [ -4865,  -5393],
                        [ -5016,  -5529],
                        [ -5164,  -5663],
                        [ -5305,  -5788],
                        [ -5437,  -5905],
                        [ -5558,  -6013],
                        [ -5666,  -6111],
                        [ -5757,  -6197],
                        [ -5830,  -6270],
                        [ -5884,  -6329],
                        [ -5918,  -6374],
                        [ -5938,  -6402],
                        [ -5943,  -6413],
                        [ -5944,  -6407],
                        [ -5938,  -6381],
                        [ -5924,  -6336],
                        [ -5901,  -6270],
                        [ -5869,  -6196],
                        [ -5825,  -6112],
                        [ -5787,  -6044],
                        [ -5753,  -5991],
                        [ -5716,  -5949],
                        [ -5678,  -5918],
                        [ -5600,  -5859],
                        [ -5484,  -5773],
                        [ -5309,  -5636],
                        [ -5077,  -5451],
                        [ -4799,  -5227],
                        [ -4475,  -4962],
                        [ -4120,  -4668],
                        [ -3733,  -4346],
                        [ -3327,  -4006],
                        [ -2904,  -3651],
                        [ -2477,  -3291],
                        [ -2047,  -2925],
                        [ -1625,  -2565],
                        [ -1214,  -2211],
                        [  -822,  -1870],
                        [  -453,  -1545],
                        [  -111,  -1241],
                        [   205,   -956],
                        [   488,   -698],
                        [   741,   -466],
                        [   962,   -260],
                        [  1151,    -82],
                        [  1307,     67],
                        [  1430,    189],
                        [  1527,    284],
                        [  1594,    351],
                        [  1639,    395],
                        [  1660,    414],
                        [  1658,    414],
                        [  1636,    392],
                        [  1595,    358],
                        [  1537,    309],
                        [  1465,    249],
                        [  1380,    181],
                        [  1286,    109],
                        [  1185,     34],
                        [  1083,    -40],
                        [   978,   -113],
                        [   879,   -180],
                        [   783,   -241],
                        [   694,   -297],
                        [   613,   -343],
                        [   553,   -371],
                        [   461,   -433],
                        [   241,   -626],
                        [  -151,   -996],
                        [  -716,  -1540],
                        [ -1469,  -2274],
                        [ -2435,  -3220],
                        [ -3561,  -4324],
                        [ -4696,  -5431],
                        [ -5748,  -6450],
                        [ -6718,  -7379],
                        [ -7599,  -8214],
                        [ -8378,  -8943],
                        [ -9048,  -9560],
                        [ -9607, -10062],
                        [-10053, -10449],
                        [-10385, -10719],
                        [-10605, -10873],
                        [-10715, -10918],
                        [-10721, -10855],
                        [-10627, -10691],
                        [-10438, -10432],
                        [-10163, -10084],
                        [ -9807,  -9656],
                        [ -9380,  -9155],
                        [ -8890,  -8591],
                        [ -8347,  -7971],
                        [ -7756,  -7305],
                        [ -7127,  -6601],
                        [ -6468,  -5865],
                        [ -5785,  -5109],
                        [ -5085,  -4337],
                        [ -4378,  -3560],
                        [ -3668,  -2781],
                        [ -2961,  -2009],
                        [ -2263,  -1246],
                        [ -1581,   -507],
                        [  -918,    207],
                        [  -278,    883],
                        [   335,   1519],
                        [   919,   2111],
                        [  1470,   2656],
                        [  1987,   3162],
                        [  2468,   3629],
                        [  2914,   4067],
                        [  3321,   4472],
                        [  3691,   4849],
                        [  4025,   5197],
                        [  4323,   5514],
                        [  4584,   5801],
                        [  4810,   6056],
                        [  5003,   6281],
                        [  5163,   6472],
                        [  5294,   6633],
                        [  5397,   6764],
                        [  5472,   6865],
                        [  5525,   6939],
                        [  5555,   6986],
                        [  5566,   7012],
                        [  5560,   7018],
                        [  5539,   7005],
                        [  5504,   6976],
                        [  5458,   6930],
                        [  5402,   6868],
                        [  5334,   6795],
                        [  5259,   6712],
                        [  5177,   6621],
                        [  5089,   6523],
                        [  5002,   6421],
                        [  4917,   6316],
                        [  4847,   6208],
                        [  4791,   6099],
                        [  4758,   5991],
                        [  4747,   5882],
                        [  4755,   5780],
                        [  4781,   5684],
                        [  4846,   5631],
                        [  4947,   5618],
                        [  5094,   5660],
                        [  5284,   5758],
                        [  5492,   5886],
                        [  5718,   6044],
                        [  5903,   6171],
                        [  6046,   6269],
                        [  6136,   6326],
                        [  6172,   6340],
                        [  6160,   6314],
                        [  6096,   6248],
                        [  5988,   6147],
                        [  5835,   6008],
                        [  5642,   5838],
                        [  5409,   5635],
                        [  5144,   5406],
                        [  4844,   5147],
                        [  4519,   4865],
                        [  4167,   4559],
                        [  3793,   4233],
                        [  3395,   3884],
                        [  2979,   3517],
                        [  2541,   3130],
                        [  2084,   2725],
                        [  1607,   2302],
                        [  1115,   1862],
                        [   607,   1406],
                        [    82,    934],
                        [  -458,    444],
                        [ -1019,    -60],
                        [ -1597,   -579],
                        [ -2195,  -1112],
                        [ -2810,  -1659],
                        [ -3439,  -2219],
                        [ -4080,  -2790],
                        [ -4731,  -3373],
                        [ -5391,  -3965],
                        [ -6054,  -4565],
                        [ -6721,  -5171],
                        [ -7388,  -5783],
                        [ -8050,  -6394],
                        [ -8707,  -7005],
                        [ -9356,  -7613],
                        [ -9994,  -8214],
                        [-10614,  -8799],
                        [-11217,  -9373],
                        [-11803,  -9934],
                        [-12315, -10421],
                        [-12660, -10744],
                        [-12803, -10869],
                        [-12740, -10790],
                        [-12450, -10489],
                        [-11898,  -9933],
                        [-11126,  -9164],
                        [-10277,  -8329],
                        [ -9428,  -7508],
                        [ -8580,  -6700],
                        [ -7742,  -5913],
                        [ -6928,  -5159],
                        [ -6149,  -4449],
                        [ -5409,  -3788],
                        [ -4715,  -3180],
                        [ -4072,  -2632],
                        [ -3486,  -2144],
                        [ -2954,  -1719],
                        [ -2481,  -1359],
                        [ -2068,  -1060],
                        [ -1713,   -825],
                        [ -1415,   -650],
                        [ -1172,   -531],
                        [  -982,   -469],
                        [  -843,   -456],
                        [  -751,   -492],
                        [  -704,   -570],
                        [  -698,   -690],
                        [  -731,   -845],
                        [  -800,  -1033],
                        [  -903,  -1248],
                        [ -1035,  -1488],
                        [ -1195,  -1749],
                        [ -1380,  -2029],
                        [ -1586,  -2321],
                        [ -1811,  -2624],
                        [ -2052,  -2927],
                        [ -2308,  -3228],
                        [ -2575,  -3518],
                        [ -2853,  -3797],
                        [ -3139,  -4067],
                        [ -3431,  -4327],
                        [ -3729,  -4587],
                        [ -4029,  -4848],
                        [ -4331,  -5116],
                        [ -4633,  -5390],
                        [ -4932,  -5669],
                        [ -5228,  -5950],
                        [ -5518,  -6231],
                        [ -5801,  -6513],
                        [ -6074,  -6790],
                        [ -6338,  -7062],
                        [ -6587,  -7327],
                        [ -6823,  -7582],
                        [ -7042,  -7824],
                        [ -7244,  -8053],
                        [ -7426,  -8263],
                        [ -7588,  -8457],
                        [ -7728,  -8630],
                        [ -7844,  -8784],
                        [ -7935,  -8912],
                        [ -8000,  -9014],
                        [ -8036,  -9088],
                        [ -8044,  -9135],
                        [ -8020,  -9153],
                        [ -7965,  -9143],
                        [ -7880,  -9105],
                        [ -7765,  -9038],
                        [ -7634,  -8944],
                        [ -7484,  -8821],
                        [ -7326,  -8672],
                        [ -7163,  -8496],
                        [ -6995,  -8296],
                        [ -6823,  -8074],
                        [ -6662,  -7859],
                        [ -6511,  -7649],
                        [ -6403,  -7490],
                        [ -6335,  -7378],
                        [ -6307,  -7314],
                        [ -6318,  -7300],
                        [ -6318,  -7286],
                        [ -6313,  -7274],
                        [ -6251,  -7213],
                        [ -6135,  -7109],
                        [ -5974,  -6964],
                        [ -5766,  -6780],
                        [ -5521,  -6563],
                        [ -5239,  -6315],
                        [ -4930,  -6043],
                        [ -4596,  -5749],
                        [ -4249,  -5444],
                        [ -3888,  -5125],
                        [ -3526,  -4805],
                        [ -3163,  -4482],
                        [ -2811,  -4164],
                        [ -2469,  -3853],
                        [ -2145,  -3554],
                        [ -1838,  -3267],
                        [ -1552,  -2997],
                        [ -1287,  -2742],
                        [ -1050,  -2507],
                        [  -837,  -2292],
                        [  -653,  -2096],
                        [  -496,  -1920],
                        [  -361,  -1763],
                        [  -248,  -1624],
                        [  -147,  -1502],
                        [   -59,  -1397],
                        [    18,  -1304],
                        [    87,  -1224],
                        [   149,  -1153],
                        [   204,  -1090],
                        [   256,  -1033],
                        [   306,   -978],
                        [   355,   -925],
                        [   405,   -869],
                        [   460,   -811],
                        [   518,   -750],
                        [   584,   -683],
                        [   657,   -609],
                        [   735,   -532],
                        [   826,   -448],
                        [   930,   -352],
                        [   990,   -305],
                        [   939,   -371],
                        [   758,   -574],
                        [   445,   -911],
                        [   -24,  -1406],
                        [  -687,  -2095],
                        [ -1512,  -2945],
                        [ -2373,  -3825],
                        [ -3203,  -4668],
                        [ -4004,  -5475],
                        [ -4766,  -6236],
                        [ -5473,  -6936],
                        [ -6116,  -7566],
                        [ -6689,  -8119],
                        [ -7187,  -8591],
                        [ -7605,  -8977],
                        [ -7939,  -9273],
                        [ -8192,  -9480],
                        [ -8363,  -9598],
                        [ -8452,  -9628],
                        [ -8465,  -9575],
                        [ -8404,  -9441],
                        [ -8273,  -9233],
                        [ -8080,  -8956],
                        [ -7830,  -8618],
                        [ -7529,  -8224],
                        [ -7184,  -7782],
                        [ -6802,  -7300],
                        [ -6389,  -6783],
                        [ -5951,  -6241],
                        [ -5494,  -5679],
                        [ -5025,  -5107],
                        [ -4550,  -4529],
                        [ -4074,  -3954],
                        [ -3602,  -3383],
                        [ -3140,  -2832],
                        [ -2690,  -2302],
                        [ -2257,  -1808],
                        [ -1844,  -1351],
                        [ -1453,   -938],
                        [ -1085,   -567],
                        [  -742,   -234],
                        [  -424,     60],
                        [  -133,    331],
                        [   132,    577],
                        [   371,    801],
                        [   584,   1006],
                        [   774,   1191],
                        [   941,   1358],
                        [  1086,   1508],
                        [  1211,   1643],
                        [  1316,   1764],
                        [  1406,   1874],
                        [  1480,   1974],
                        [  1541,   2063],
                        [  1589,   2142],
                        [  1629,   2211],
                        [  1661,   2272],
                        [  1686,   2325],
                        [  1707,   2369],
                        [  1724,   2407],
                        [  1738,   2436],
                        [  1750,   2459],
                        [  1760,   2475],
                        [  1766,   2485],
                        [  1771,   2494],
                        [  1775,   2497],
                        [  1784,   2498],
                        [  1801,   2496],
                        [  1831,   2489],
                        [  1875,   2477],
                        [  1939,   2463],
                        [  2024,   2445],
                        [  2128,   2433],
                        [  2251,   2427],
                        [  2427,   2477],
                        [  2653,   2580],
                        [  2936,   2751],
                        [  3277,   2990],
                        [  3649,   3272],
                        [  4052,   3599],
                        [  4403,   3885],
                        [  4704,   4136],
                        [  4930,   4327],
                        [  5083,   4457],
                        [  5161,   4525],
                        [  5163,   4531],
                        [  5090,   4474],
                        [  4944,   4355],
                        [  4729,   4179],
                        [  4443,   3942],
                        [  4097,   3654],
                        [  3689,   3310],
                        [  3229,   2921],
                        [  2718,   2483],
                        [  2165,   2006],
                        [  1569,   1488],
                        [   940,    936],
                        [   276,    351],
                        [  -410,   -261],
                        [ -1121,   -899],
                        [ -1845,  -1557],
                        [ -2580,  -2234],
                        [ -3322,  -2923],
                        [ -4068,  -3625],
                        [ -4821,  -4334],
                        [ -5579,  -5046],
                        [ -6342,  -5759],
                        [ -7105,  -6468],
                        [ -7864,  -7172],
                        [ -8616,  -7865],
                        [ -9354,  -8547],
                        [-10075,  -9211],
                        [-10775,  -9857],
                        [-11451, -10481],
                        [-12098, -11080],
                        [-12712, -11650],
                        [-13291, -12188],
                        [-13832, -12692],
                        [-14331, -13158],
                        [-14781, -13579],
                        [-15188, -13960],
                        [-15546, -14292],
                        [-15806, -14528],
                        [-15919, -14619],
                        [-15877, -14556],
                        [-15679, -14338],
                        [-15298, -13942],
                        [-14690, -13322],
                        [-13876, -12501],
                        [-12959, -11583],
                        [-11992, -10623],
                        [-10974,  -9623],
                        [ -9924,  -8598],
                        [ -8859,  -7564],
                        [ -7794,  -6539],
                        [ -6738,  -5529],
                        [ -5706,  -4548],
                        [ -4708,  -3609],
                        [ -3755,  -2719],
                        [ -2849,  -1883],
                        [ -2001,  -1112],
                        [ -1215,   -407],
                        [  -496,    226],
                        [   156,    787],
                        [   735,   1272],
                        [  1244,   1685],
                        [  1681,   2024],
                        [  2048,   2290],
                        [  2347,   2487],
                        [  2578,   2618],
                        [  2745,   2685],
                        [  2849,   2690],
                        [  2896,   2641],
                        [  2888,   2539],
                        [  2828,   2392],
                        [  2724,   2204],
                        [  2577,   1980],
                        [  2394,   1727],
                        [  2178,   1456],
                        [  1935,   1173],
                        [  1668,    890],
                        [  1381,    608],
                        [  1081,    330],
                        [   769,     60],
                        [   450,   -210],
                        [   128,   -479],
                        [  -192,   -752],
                        [  -509,  -1026],
                        [  -817,  -1299],
                        [ -1116,  -1569],
                        [ -1399,  -1833],
                        [ -1666,  -2090],
                        [ -1913,  -2338],
                        [ -2139,  -2577],
                        [ -2340,  -2806],
                        [ -2516,  -3021],
                        [ -2662,  -3219],
                        [ -2780,  -3400],
                        [ -2868,  -3555],
                        [ -2924,  -3684],
                        [ -2949,  -3785],
                        [ -2942,  -3859],
                        [ -2904,  -3901],
                        [ -2833,  -3909],
                        [ -2731,  -3885],
                        [ -2598,  -3828],
                        [ -2433,  -3739],
                        [ -2239,  -3621],
                        [ -2021,  -3473],
                        [ -1779,  -3300],
                        [ -1529,  -3100],
                        [ -1267,  -2875],
                        [ -1005,  -2627],
                        [  -747,  -2360],
                        [  -497,  -2079],
                        [  -258,  -1786],
                        [   -57,  -1522],
                        [   107,  -1288],
                        [   197,  -1129],
                        [   215,  -1042],
                        [   159,  -1035],
                        [    27,  -1107],
                        [  -125,  -1206],
                        [  -302,  -1335],
                        [  -439,  -1430],
                        [  -540,  -1497],
                        [  -607,  -1534],
                        [  -638,  -1542],
                        [  -634,  -1522],
                        [  -596,  -1472],
                        [  -527,  -1398],
                        [  -429,  -1299],
                        [  -307,  -1181],
                        [  -162,  -1044],
                        [    -2,   -893],
                        [   175,   -727],
                        [   358,   -554],
                        [   548,   -371],
                        [   742,   -184],
                        [   938,      7],
                        [  1132,    200],
                        [  1324,    394],
                        [  1507,    587],
                        [  1682,    782],
                        [  1845,    973],
                        [  1998,   1163],
                        [  2146,   1351],
                        [  2288,   1538],
                        [  2438,   1724],
                        [  2593,   1909],
                        [  2755,   2094],
                        [  2926,   2279],
                        [  3105,   2466],
                        [  3292,   2654],
                        [  3487,   2845],
                        [  3690,   3038],
                        [  3901,   3235],
                        [  4119,   3435],
                        [  4344,   3638],
                        [  4574,   3845],
                        [  4812,   4054],
                        [  5053,   4265],
                        [  5294,   4472],
                        [  5540,   4681],
                        [  5785,   4886],
                        [  5993,   5049],
                        [  6143,   5150],
                        [  6236,   5191],
                        [  6268,   5170],
                        [  6211,   5057],
                        [  6013,   4804],
                        [  5676,   4414],
                        [  5267,   3954],
                        [  4823,   3465],
                        [  4342,   2946],
                        [  3836,   2410],
                        [  3321,   1870],
                        [  2806,   1337],
                        [  2299,    818],
                        [  1809,    323],
                        [  1343,   -138],
                        [   908,   -560],
                        [   508,   -938],
                        [   145,  -1268],
                        [  -175,  -1546],
                        [  -453,  -1773],
                        [  -687,  -1947],
                        [  -878,  -2069],
                        [ -1026,  -2143],
                        [ -1135,  -2168],
                        [ -1205,  -2149],
                        [ -1240,  -2089],
                        [ -1241,  -1991],
                        [ -1212,  -1857],
                        [ -1155,  -1695],
                        [ -1076,  -1507],
                        [  -975,  -1298],
                        [  -857,  -1073],
                        [  -725,   -836],
                        [  -582,   -592],
                        [  -431,   -348],
                        [  -275,   -106],
                        [  -115,    119],
                        [    47,    327],
                        [   209,    513],
                        [   369,    676],
                        [   527,    821],
                        [   683,    945],
                        [   835,   1064],
                        [   984,   1175],
                        [  1130,   1284],
                        [  1272,   1390],
                        [  1411,   1496],
                        [  1548,   1601],
                        [  1682,   1710],
                        [  1814,   1823],
                        [  1944,   1945],
                        [  2073,   2075],
                        [  2200,   2215],
                        [  2327,   2364],
                        [  2452,   2518],
                        [  2577,   2676],
                        [  2702,   2835],
                        [  2824,   2992],
                        [  2946,   3148],
                        [  3067,   3302],
                        [  3186,   3449],
                        [  3302,   3590],
                        [  3414,   3724],
                        [  3521,   3850],
                        [  3622,   3968],
                        [  3716,   4076],
                        [  3809,   4175],
                        [  3901,   4262],
                        [  3993,   4335],
                        [  4085,   4392],
                        [  4182,   4435],
                        [  4284,   4464],
                        [  4396,   4492],
                        [  4517,   4517],
                        [  4687,   4592],
                        [  4900,   4713],
                        [  5166,   4893],
                        [  5483,   5131],
                        [  5833,   5412],
                        [  6216,   5736],
                        [  6546,   6018],
                        [  6825,   6261],
                        [  7029,   6442],
                        [  7158,   6559],
                        [  7206,   6608],
                        [  7174,   6589],
                        [  7062,   6502],
                        [  6870,   6345],
                        [  6601,   6122],
                        [  6255,   5834],
                        [  5841,   5484],
                        [  5359,   5075],
                        [  4821,   4613],
                        [  4226,   4099],
                        [  3587,   3542],
                        [  2905,   2942],
                        [  2191,   2309],
                        [  1445,   1645],
                        [   685,    956],
                        [   -89,    248],
                        [  -862,   -474],
                        [ -1633,  -1206],
                        [ -2396,  -1939],
                        [ -3147,  -2673],
                        [ -3889,  -3399],
                        [ -4617,  -4115],
                        [ -5333,  -4813],
                        [ -6034,  -5491],
                        [ -6709,  -6143],
                        [ -7358,  -6767],
                        [ -7976,  -7356],
                        [ -8557,  -7910],
                        [ -9098,  -8422],
                        [ -9597,  -8892],
                        [-10049,  -9316],
                        [-10451,  -9692],
                        [-10801, -10016],
                        [-11096, -10288],
                        [-11334, -10504],
                        [-11512, -10662],
                        [-11633, -10764],
                        [-11692, -10803],
                        [-11677, -10769],
                        [-11590, -10662],
                        [-11446, -10497],
                        [-11239, -10269],
                        [-10947,  -9956],
                        [-10519,  -9509],
                        [ -9939,  -8907],
                        [ -9244,  -8193],
                        [ -8461,  -7396],
                        [ -7598,  -6520],
                        [ -6667,  -5582],
                        [ -5689,  -4599],
                        [ -4680,  -3586],
                        [ -3650,  -2556],
                        [ -2615,  -1524],
                        [ -1587,   -503],
                        [  -580,    492],
                        [   398,   1454],
                        [  1337,   2370],
                        [  2229,   3234],
                        [  3066,   4039],
                        [  3844,   4780],
                        [  4558,   5452],
                        [  5206,   6054],
                        [  5785,   6584],
                        [  6294,   7041],
                        [  6734,   7426],
                        [  7105,   7740],
                        [  7408,   7984],
                        [  7647,   8162],
                        [  7824,   8278],
                        [  7943,   8335],
                        [  8009,   8339],
                        [  8023,   8294],
                        [  7995,   8208],
                        [  7926,   8086],
                        [  7824,   7940],
                        [  7692,   7776],
                        [  7536,   7603],
                        [  7360,   7426],
                        [  7172,   7252],
                        [  6974,   7083],
                        [  6771,   6918],
                        [  6567,   6758],
                        [  6367,   6599],
                        [  6174,   6444],
                        [  5992,   6295],
                        [  5823,   6155],
                        [  5672,   6023],
                        [  5540,   5903],
                        [  5429,   5788],
                        [  5341,   5683],
                        [  5277,   5584],
                        [  5240,   5495],
                        [  5227,   5415],
                        [  5242,   5349],
                        [  5285,   5303],
                        [  5353,   5279],
                        [  5446,   5276],
                        [  5565,   5296],
                        [  5705,   5339],
                        [  5867,   5406],
                        [  6047,   5495],
                        [  6246,   5605],
                        [  6458,   5734],
                        [  6683,   5881],
                        [  6915,   6043],
                        [  7152,   6217],
                        [  7383,   6402],
                        [  7612,   6598],
                        [  7828,   6801],
                        [  8026,   7005],
                        [  8200,   7206],
                        [  8348,   7403],
                        [  8437,   7551],
                        [  8468,   7653],
                        [  8413,   7675],
                        [  8274,   7615],
                        [  8044,   7465],
                        [  7720,   7224],
                        [  7355,   6940],
                        [  6943,   6607],
                        [  6548,   6288],
                        [  6167,   5978],
                        [  5805,   5683],
                        [  5466,   5405],
                        [  5155,   5149],
                        [  4872,   4915],
                        [  4622,   4708],
                        [  4404,   4526],
                        [  4219,   4371],
                        [  4069,   4245],
                        [  3950,   4145],
                        [  3864,   4071],
                        [  3807,   4025],
                        [  3779,   4005],
                        [  3777,   4009],
                        [  3802,   4039],
                        [  3847,   4091],
                        [  3915,   4167],
                        [  3994,   4264],
                        [  4088,   4382],
                        [  4192,   4520],
                        [  4307,   4677],
                        [  4438,   4851],
                        [  4582,   5042],
                        [  4751,   5247],
                        [  4943,   5468],
                        [  5157,   5701],
                        [  5391,   5944],
                        [  5644,   6199],
                        [  5913,   6460],
                        [  6197,   6728],
                        [  6494,   7001],
                        [  6798,   7275],
                        [  7111,   7551],
                        [  7426,   7826],
                        [  7742,   8097],
                        [  8056,   8361],
                        [  8364,   8617],
                        [  8661,   8860],
                        [  8947,   9089],
                        [  9218,   9302],
                        [  9481,   9504],
                        [  9760,   9720],
                        [ 10067,   9964],
                        [ 10396,  10229],
                        [ 10720,  10489],
                        [ 10986,  10691],
                        [ 11142,  10784],
                        [ 11190,  10771],
                        [ 11143,  10667],
                        [ 11002,  10472],
                        [ 10777,  10199],
                        [ 10480,   9858],
                        [ 10121,   9459],
                        [  9706,   9011],
                        [  9248,   8525],
                        [  8756,   8011],
                        [  8238,   7480],
                        [  7702,   6940],
                        [  7156,   6398],
                        [  6607,   5863],
                        [  6061,   5339],
                        [  5524,   4831],
                        [  4999,   4343],
                        [  4492,   3880],
                        [  4005,   3443],
                        [  3542,   3036],
                        [  3104,   2658],
                        [  2694,   2312],
                        [  2312,   1997],
                        [  1961,   1714],
                        [  1638,   1463],
                        [  1346,   1242],
                        [  1083,   1051],
                        [   850,    886],
                        [   645,    746],
                        [   468,    627],
                        [   318,    528],
                        [   193,    441],
                        [    94,    365],
                        [    19,    296],
                        [   -33,    233],
                        [   -64,    176],
                        [   -74,    123],
                        [   -64,     82],
                        [   -36,     53],
                        [    11,     40],
                        [    74,     40],
                        [   152,     55],
                        [   245,     84],
                        [   349,    132],
                        [   466,    199],
                        [   592,    288],
                        [   726,    401],
                        [   866,    534],
                        [  1012,    689],
                        [  1160,    855],
                        [  1311,   1033],
                        [  1458,   1211],
                        [  1605,   1392],
                        [  1746,   1570],
                        [  1883,   1744],
                        [  2012,   1911],
                        [  2132,   2067],
                        [  2242,   2212],
                        [  2341,   2343],
                        [  2425,   2459],
                        [  2494,   2558],
                        [  2550,   2638],
                        [  2592,   2698],
                        [  2615,   2735],
                        [  2623,   2747],
                        [  2619,   2737],
                        [  2602,   2704],
                        [  2587,   2663],
                        [  2572,   2612],
                        [  2588,   2589],
                        [  2633,   2594],
                        [  2714,   2635],
                        [  2832,   2713],
                        [  2981,   2827],
                        [  3164,   2978],
                        [  3309,   3098],
                        [  3425,   3193],
                        [  3487,   3243],
                        [  3499,   3248],
                        [  3451,   3201],
                        [  3345,   3105],
                        [  3179,   2954],
                        [  2953,   2753],
                        [  2668,   2498],
                        [  2327,   2195],
                        [  1932,   1844],
                        [  1487,   1448],
                        [  1000,   1012],
                        [   472,    538],
                        [   -87,     34],
                        [  -674,   -498],
                        [ -1280,  -1051],
                        [ -1900,  -1623],
                        [ -2520,  -2204],
                        [ -3136,  -2792],
                        [ -3739,  -3378],
                        [ -4324,  -3962],
                        [ -4886,  -4534],
                        [ -5423,  -5092],
                        [ -5936,  -5628],
                        [ -6424,  -6141],
                        [ -6886,  -6624],
                        [ -7321,  -7074],
                        [ -7720,  -7487],
                        [ -8083,  -7861],
                        [ -8407,  -8190],
                        [ -8689,  -8474],
                        [ -8926,  -8709],
                        [ -9117,  -8894],
                        [ -9259,  -9028],
                        [ -9353,  -9109],
                        [ -9395,  -9137],
                        [ -9385,  -9112],
                        [ -9324,  -9033],
                        [ -9212,  -8902],
                        [ -9046,  -8716],
                        [ -8836,  -8483],
                        [ -8618,  -8240],
                        [ -8439,  -8032],
                        [ -8315,  -7881],
                        [ -8247,  -7781],
                        [ -8218,  -7720],
                        [ -8175,  -7641],
                        [ -8048,  -7473],
                        [ -7810,  -7192],
                        [ -7472,  -6810],
                        [ -7041,  -6333],
                        [ -6529,  -5774],
                        [ -5948,  -5144],
                        [ -5309,  -4456],
                        [ -4623,  -3720],
                        [ -3904,  -2952],
                        [ -3163,  -2163],
                        [ -2410,  -1366],
                        [ -1656,   -570],
                        [  -910,    212],
                        [  -181,    972],
                        [   524,   1703],
                        [  1199,   2399],
                        [  1839,   3054],
                        [  2438,   3664],
                        [  2993,   4225],
                        [  3503,   4735],
                        [  3965,   5194],
                        [  4379,   5600],
                        [  4746,   5954],
                        [  5066,   6256],
                        [  5341,   6511],
                        [  5574,   6717],
                        [  5767,   6881],
                        [  5923,   7005],
                        [  6046,   7096],
                        [  6140,   7157],
                        [  6208,   7196],
                        [  6255,   7215],
                        [  6284,   7222],
                        [  6299,   7222],
                        [  6304,   7220],
                        [  6303,   7221],
                        [  6299,   7226],
                        [  6294,   7239],
                        [  6293,   7256],
                        [  6296,   7279],
                        [  6307,   7308],
                        [  6326,   7347],
                        [  6355,   7391],
                        [  6397,   7443],
                        [  6450,   7493],
                        [  6515,   7544],
                        [  6593,   7590],
                        [  6684,   7635],
                        [  6787,   7677],
                        [  6901,   7716],
                        [  7025,   7761],
                        [  7159,   7811],
                        [  7298,   7867],
                        [  7444,   7929],
                        [  7591,   7995],
                        [  7739,   8064],
                        [  7883,   8136],
                        [  8022,   8207],
                        [  8153,   8277],
                        [  8273,   8344],
                        [  8380,   8406],
                        [  8473,   8461],
                        [  8550,   8507],
                        [  8611,   8546],
                        [  8652,   8574],
                        [  8669,   8587],
                        [  8650,   8581],
                        [  8598,   8556],
                        [  8485,   8482],
                        [  8312,   8361],
                        [  8068,   8178],
                        [  7754,   7933],
                        [  7358,   7612],
                        [  6882,   7214],
                        [  6355,   6768],
                        [  5775,   6272],
                        [  5192,   5770],
                        [  4602,   5261],
                        [  4019,   4756],
                        [  3445,   4255],
                        [  2893,   3772],
                        [  2364,   3305],
                        [  1866,   2864],
                        [  1402,   2450],
                        [   977,   2069],
                        [   595,   1721],
                        [   256,   1411],
                        [   -37,   1139],
                        [  -284,    908],
                        [  -485,    717],
                        [  -641,    566],
                        [  -751,    457],
                        [  -823,    388],
                        [  -854,    360],
                        [  -856,    368],
                        [  -825,    415],
                        [  -767,    495],
                        [  -682,    609],
                        [  -569,    752],
                        [  -430,    924],
                        [  -258,   1119],
                        [   -55,   1337],
                        [   172,   1573],
                        [   423,   1825],
                        [   693,   2087],
                        [   980,   2358],
                        [  1277,   2632],
                        [  1583,   2907],
                        [  1892,   3178],
                        [  2200,   3443],
                        [  2503,   3698],
                        [  2797,   3938],
                        [  3075,   4161],
                        [  3335,   4364],
                        [  3574,   4544],
                        [  3783,   4694],
                        [  3974,   4825],
                        [  4205,   4997],
                        [  4528,   5262],
                        [  4956,   5633],
                        [  5485,   6106],
                        [  6100,   6667],
                        [  6744,   7254],
                        [  7310,   7766],
                        [  7748,   8149],
                        [  8059,   8405],
                        [  8248,   8538],
                        [  8317,   8553],
                        [  8273,   8457],
                        [  8124,   8256],
                        [  7879,   7959],
                        [  7545,   7577],
                        [  7135,   7121],
                        [  6654,   6599],
                        [  6117,   6025],
                        [  5531,   5406],
                        [  4906,   4755],
                        [  4250,   4077],
                        [  3574,   3384],
                        [  2885,   2682],
                        [  2191,   1979],
                        [  1501,   1282],
                        [   819,    597],
                        [   152,    -72],
                        [  -494,   -717],
                        [ -1115,  -1336],
                        [ -1707,  -1925],
                        [ -2268,  -2481],
                        [ -2793,  -3001],
                        [ -3283,  -3485],
                        [ -3732,  -3931],
                        [ -4141,  -4339],
                        [ -4510,  -4709],
                        [ -4838,  -5043],
                        [ -5126,  -5340],
                        [ -5374,  -5601],
                        [ -5583,  -5829],
                        [ -5754,  -6025],
                        [ -5889,  -6197],
                        [ -5990,  -6346],
                        [ -6058,  -6471],
                        [ -6095,  -6573],
                        [ -6104,  -6652],
                        [ -6088,  -6710],
                        [ -6049,  -6747],
                        [ -5990,  -6765],
                        [ -5913,  -6759],
                        [ -5821,  -6733],
                        [ -5717,  -6681],
                        [ -5604,  -6606],
                        [ -5485,  -6508],
                        [ -5363,  -6389],
                        [ -5240,  -6259],
                        [ -5119,  -6118],
                        [ -5003,  -5978],
                        [ -4894,  -5842],
                        [ -4793,  -5709],
                        [ -4701,  -5580],
                        [ -4621,  -5462],
                        [ -4552,  -5355],
                        [ -4496,  -5261],
                        [ -4455,  -5182],
                        [ -4431,  -5120],
                        [ -4424,  -5075],
                        [ -4440,  -5049],
                        [ -4478,  -5044],
                        [ -4544,  -5061],
                        [ -4636,  -5102],
                        [ -4747,  -5162],
                        [ -4878,  -5242],
                        [ -5012,  -5334],
                        [ -5148,  -5437],
                        [ -5272,  -5536],
                        [ -5387,  -5634],
                        [ -5484,  -5718],
                        [ -5560,  -5788],
                        [ -5605,  -5830],
                        [ -5615,  -5840],
                        [ -5627,  -5853],
                        [ -5636,  -5865],
                        [ -5656,  -5889],
                        [ -5687,  -5923],
                        [ -5736,  -5976],
                        [ -5803,  -6044],
                        [ -5893,  -6134],
                        [ -6003,  -6243],
                        [ -6138,  -6376],
                        [ -6296,  -6528],
                        [ -6477,  -6701],
                        [ -6679,  -6892],
                        [ -6899,  -7101],
                        [ -7135,  -7325],
                        [ -7383,  -7560],
                        [ -7640,  -7806],
                        [ -7898,  -8057],
                        [ -8158,  -8310],
                        [ -8404,  -8563],
                        [ -8638,  -8811],
                        [ -8852,  -9050],
                        [ -9045,  -9278],
                        [ -9211,  -9490],
                        [ -9351,  -9684],
                        [ -9468,  -9856],
                        [ -9559, -10005],
                        [ -9627, -10125],
                        [ -9669, -10216],
                        [ -9682, -10276],
                        [ -9666, -10301],
                        [ -9620, -10291],
                        [ -9545, -10245],
                        [ -9438, -10161],
                        [ -9300, -10039],
                        [ -9130,  -9880],
                        [ -8930,  -9683],
                        [ -8698,  -9450],
                        [ -8435,  -9179],
                        [ -8141,  -8875],
                        [ -7821,  -8539],
                        [ -7467,  -8166],
                        [ -7109,  -7786],
                        [ -6827,  -7481],
                        [ -6688,  -7314],
                        [ -6702,  -7300],
                        [ -6874,  -7439],
                        [ -7202,  -7731],
                        [ -7626,  -8117],
                        [ -8025,  -8471],
                        [ -8329,  -8725],
                        [ -8542,  -8882],
                        [ -8667,  -8947],
                        [ -8707,  -8921],
                        [ -8665,  -8809],
                        [ -8547,  -8617],
                        [ -8359,  -8353],
                        [ -8109,  -8025],
                        [ -7803,  -7642],
                        [ -7451,  -7211],
                        [ -7057,  -6742],
                        [ -6632,  -6243],
                        [ -6180,  -5722],
                        [ -5708,  -5186],
                        [ -5222,  -4640],
                        [ -4729,  -4091],
                        [ -4234,  -3546],
                        [ -3742,  -3007],
                        [ -3254,  -2478],
                        [ -2776,  -1965],
                        [ -2311,  -1467],
                        [ -1857,   -988],
                        [ -1419,   -530],
                        [  -995,    -93],
                        [  -588,    323],
                        [  -197,    716],
                        [   178,   1090],
                        [   538,   1444],
                        [   882,   1779],
                        [  1214,   2097],
                        [  1532,   2397],
                        [  1839,   2678],
                        [  2136,   2945],
                        [  2423,   3201],
                        [  2702,   3450],
                        [  2973,   3698],
                        [  3238,   3946],
                        [  3495,   4193],
                        [  3748,   4441],
                        [  3994,   4687],
                        [  4234,   4932],
                        [  4467,   5170],
                        [  4695,   5403],
                        [  4913,   5621],
                        [  5124,   5825],
                        [  5325,   6008],
                        [  5517,   6171],
                        [  5697,   6312],
                        [  5865,   6433],
                        [  6019,   6537],
                        [  6159,   6627],
                        [  6281,   6702],
                        [  6385,   6762],
                        [  6468,   6801],
                        [  6528,   6822],
                        [  6561,   6823],
                        [  6568,   6805],
                        [  6546,   6763],
                        [  6497,   6702],
                        [  6423,   6617],
                        [  6323,   6511],
                        [  6206,   6382],
                        [  6073,   6233],
                        [  5920,   6061],
                        [  5747,   5867],
                        [  5544,   5649],
                        [  5311,   5408],
                        [  5039,   5142],
                        [  4730,   4851],
                        [  4388,   4540],
                        [  4015,   4208],
                        [  3596,   3836],
                        [  3132,   3428],
                        [  2622,   2979],
                        [  2068,   2488],
                        [  1494,   1982],
                        [   903,   1458],
                        [   307,    931],
                        [  -290,    401],
                        [  -873,   -117],
                        [ -1444,   -625],
                        [ -1987,  -1110],
                        [ -2501,  -1571],
                        [ -2977,  -2000],
                        [ -3414,  -2396],
                        [ -3804,  -2752],
                        [ -4149,  -3069],
                        [ -4441,  -3343],
                        [ -4684,  -3572],
                        [ -4877,  -3756],
                        [ -5022,  -3896],
                        [ -5121,  -3991],
                        [ -5176,  -4043],
                        [ -5194,  -4054],
                        [ -5175,  -4024],
                        [ -5124,  -3960],
                        [ -5043,  -3861],
                        [ -4935,  -3733],
                        [ -4801,  -3577],
                        [ -4641,  -3399],
                        [ -4456,  -3201],
                        [ -4253,  -2991],
                        [ -4036,  -2770],
                        [ -3809,  -2544],
                        [ -3574,  -2316],
                        [ -3339,  -2093],
                        [ -3105,  -1876],
                        [ -2878,  -1672],
                        [ -2659,  -1483],
                        [ -2458,  -1314],
                        [ -2274,  -1167],
                        [ -2116,  -1047],
                        [ -1980,   -953],
                        [ -1874,   -888],
                        [ -1806,   -862],
                        [ -1740,   -836],
                        [ -1583,   -717],
                        [ -1276,   -447],
                        [  -813,    -18],
                        [  -191,    573],
                        [   598,   1330],
                        [  1489,   2191],
                        [  2342,   3010],
                        [  3074,   3704],
                        [  3687,   4277],
                        [  4184,   4730],
                        [  4561,   5058],
                        [  4821,   5265],
                        [  4968,   5354],
                        [  5004,   5331],
                        [  4938,   5202],
                        [  4778,   4977],
                        [  4530,   4662],
                        [  4205,   4270],
                        [  3810,   3808],
                        [  3357,   3288],
                        [  2854,   2717],
                        [  2310,   2107],
                        [  1735,   1465],
                        [  1138,    802],
                        [   530,    126],
                        [   -85,   -556],
                        [  -696,  -1235],
                        [ -1298,  -1906],
                        [ -1886,  -2562],
                        [ -2453,  -3196],
                        [ -2995,  -3805],
                        [ -3509,  -4383],
                        [ -3990,  -4929],
                        [ -4436,  -5439],
                        [ -4845,  -5911],
                        [ -5215,  -6342],
                        [ -5546,  -6732],
                        [ -5839,  -7076],
                        [ -6092,  -7373],
                        [ -6308,  -7625],
                        [ -6488,  -7833],
                        [ -6634,  -8010],
                        [ -6747,  -8155],
                        [ -6832,  -8278],
                        [ -6888,  -8381],
                        [ -6921,  -8465],
                        [ -6931,  -8532],
                        [ -6925,  -8584],
                        [ -6902,  -8622],
                        [ -6868,  -8645],
                        [ -6825,  -8655],
                        [ -6777,  -8647],
                        [ -6727,  -8628],
                        [ -6676,  -8595],
                        [ -6630,  -8553],
                        [ -6590,  -8508],
                        [ -6559,  -8461],
                        [ -6538,  -8421],
                        [ -6533,  -8391],
                        [ -6539,  -8370],
                        [ -6560,  -8360],
                        [ -6595,  -8361],
                        [ -6645,  -8376],
                        [ -6708,  -8404],
                        [ -6787,  -8448],
                        [ -6884,  -8506],
                        [ -6997,  -8580],
                        [ -7139,  -8669],
                        [ -7308,  -8775],
                        [ -7508,  -8896],
                        [ -7735,  -9031],
                        [ -7981,  -9178],
                        [ -8246,  -9336],
                        [ -8514,  -9507],
                        [ -8785,  -9688],
                        [ -9065,  -9892],
                        [ -9354, -10117],
                        [ -9642, -10352],
                        [ -9927, -10596],
                        [-10177, -10814],
                        [-10390, -11005],
                        [-10560, -11161],
                        [-10686, -11282],
                        [-10775, -11373],
                        [-10826, -11432],
                        [-10848, -11468],
                        [-10837, -11477],
                        [-10803, -11467],
                        [-10741, -11434],
                        [-10662, -11385],
                        [-10563, -11319],
                        [-10450, -11239],
                        [-10320, -11143],
                        [-10181, -11037],
                        [-10029, -10917],
                        [ -9865, -10785],
                        [ -9691, -10642],
                        [ -9501, -10487],
                        [ -9299, -10320],
                        [ -9079, -10139],
                        [ -8843,  -9947],
                        [ -8588,  -9740],
                        [ -8315,  -9519],
                        [ -8021,  -9283],
                        [ -7707,  -9033],
                        [ -7376,  -8766],
                        [ -7029,  -8483],
                        [ -6669,  -8184],
                        [ -6296,  -7869],
                        [ -5910,  -7537],
                        [ -5513,  -7189],
                        [ -5106,  -6825],
                        [ -4690,  -6446],
                        [ -4266,  -6050],
                        [ -3835,  -5640],
                        [ -3399,  -5218],
                        [ -2959,  -4783],
                        [ -2515,  -4336],
                        [ -2068,  -3880],
                        [ -1623,  -3420],
                        [ -1177,  -2954],
                        [  -725,  -2479],
                        [  -320,  -2047],
                        [   -63,  -1761],
                        [    -8,  -1675],
                        [  -161,  -1796],
                        [  -531,  -2135],
                        [ -1135,  -2705],
                        [ -1910,  -3443],
                        [ -2705,  -4196],
                        [ -3434,  -4877],
                        [ -4097,  -5485],
                        [ -4696,  -6021],
                        [ -5219,  -6476],
                        [ -5662,  -6846],
                        [ -6026,  -7131],
                        [ -6308,  -7331],
                        [ -6511,  -7448],
                        [ -6636,  -7485],
                        [ -6684,  -7444],
                        [ -6661,  -7332],
                        [ -6569,  -7153],
                        [ -6414,  -6912],
                        [ -6199,  -6613],
                        [ -5930,  -6262],
                        [ -5611,  -5865],
                        [ -5250,  -5428],
                        [ -4851,  -4955],
                        [ -4418,  -4452],
                        [ -3956,  -3924],
                        [ -3470,  -3375],
                        [ -2964,  -2810],
                        [ -2442,  -2233],
                        [ -1906,  -1648],
                        [ -1361,  -1060],
                        [  -812,   -470],
                        [  -259,    118],
                        [   293,    700],
                        [   840,   1274],
                        [  1382,   1831],
                        [  1916,   2370],
                        [  2440,   2884],
                        [  2952,   3373],
                        [  3449,   3838],
                        [  3932,   4280],
                        [  4396,   4710],
                        [  4842,   5126],
                        [  5267,   5531],
                        [  5671,   5922],
                        [  6051,   6299],
                        [  6406,   6659],
                        [  6734,   6998],
                        [  7035,   7317],
                        [  7308,   7605],
                        [  7551,   7865],
                        [  7761,   8090],
                        [  7941,   8282],
                        [  8088,   8437],
                        [  8202,   8557],
                        [  8283,   8645],
                        [  8329,   8700],
                        [  8341,   8725],
                        [  8318,   8720],
                        [  8257,   8679],
                        [  8162,   8605],
                        [  8027,   8497],
                        [  7855,   8357],
                        [  7650,   8185],
                        [  7410,   7983],
                        [  7148,   7752],
                        [  6866,   7493],
                        [  6575,   7209],
                        [  6277,   6901],
                        [  5974,   6572],
                        [  5664,   6223],
                        [  5341,   5859],
                        [  5007,   5482],
                        [  4675,   5119],
                        [  4347,   4769],
                        [  4037,   4449],
                        [  3749,   4160],
                        [  3461,   3880],
                        [  3177,   3611],
                        [  2858,   3314],
                        [  2509,   2994],
                        [  2134,   2651],
                        [  1731,   2287],
                        [  1317,   1913],
                        [   890,   1530],
                        [   463,   1148],
                        [    37,    769],
                        [  -375,    401],
                        [  -775,     46],
                        [ -1151,   -288],
                        [ -1503,   -601],
                        [ -1822,   -886],
                        [ -2108,  -1144],
                        [ -2358,  -1370],
                        [ -2572,  -1565],
                        [ -2748,  -1727],
                        [ -2888,  -1856],
                        [ -2996,  -1952],
                        [ -3070,  -2019],
                        [ -3114,  -2056],
                        [ -3131,  -2067],
                        [ -3126,  -2053],
                        [ -3102,  -2019],
                        [ -3064,  -1966],
                        [ -3014,  -1899],
                        [ -2953,  -1821],
                        [ -2886,  -1735],
                        [ -2815,  -1646],
                        [ -2743,  -1557],
                        [ -2675,  -1472],
                        [ -2610,  -1394],
                        [ -2554,  -1328],
                        [ -2509,  -1275],
                        [ -2478,  -1239],
                        [ -2462,  -1221],
                        [ -2465,  -1226],
                        [ -2488,  -1255],
                        [ -2533,  -1308],
                        [ -2598,  -1383],
                        [ -2689,  -1484],
                        [ -2809,  -1616],
                        [ -2901,  -1718],
                        [ -2864,  -1692],
                        [ -2660,  -1494],
                        [ -2282,  -1120],
                        [ -1714,   -555],
                        [  -934,    223],
                        [     2,   1154],
                        [   938,   2083],
                        [  1797,   2931],
                        [  2585,   3697],
                        [  3296,   4379],
                        [  3921,   4968],
                        [  4457,   5460],
                        [  4905,   5855],
                        [  5262,   6153],
                        [  5531,   6355],
                        [  5714,   6467],
                        [  5817,   6491],
                        [  5844,   6434],
                        [  5800,   6303],
                        [  5693,   6103],
                        [  5529,   5842],
                        [  5315,   5527],
                        [  5059,   5166],
                        [  4768,   4769],
                        [  4449,   4340],
                        [  4110,   3888],
                        [  3756,   3420],
                        [  3394,   2941],
                        [  3028,   2459],
                        [  2663,   1978],
                        [  2305,   1504],
                        [  1957,   1042],
                        [  1620,    595],
                        [  1300,    167],
                        [   999,   -241],
                        [   717,   -620],
                        [   456,   -970],
                        [   215,  -1283],
                        [    -6,  -1557],
                        [  -206,  -1793],
                        [  -387,  -1991],
                        [  -551,  -2164],
                        [  -699,  -2312],
                        [  -832,  -2450],
                        [  -954,  -2579],
                        [ -1066,  -2702],
                        [ -1170,  -2822],
                        [ -1268,  -2938],
                        [ -1363,  -3053],
                        [ -1456,  -3167],
                        [ -1550,  -3280],
                        [ -1648,  -3391],
                        [ -1749,  -3503],
                        [ -1857,  -3613],
                        [ -1972,  -3726],
                        [ -2095,  -3843],
                        [ -2229,  -3964],
                        [ -2371,  -4094],
                        [ -2524,  -4233],
                        [ -2686,  -4379],
                        [ -2857,  -4533],
                        [ -3033,  -4689],
                        [ -3214,  -4850],
                        [ -3400,  -5014],
                        [ -3590,  -5181],
                        [ -3785,  -5350],
                        [ -3989,  -5521],
                        [ -4210,  -5691],
                        [ -4448,  -5860],
                        [ -4703,  -6025],
                        [ -4973,  -6184],
                        [ -5248,  -6338],
                        [ -5527,  -6484],
                        [ -5809,  -6639],
                        [ -6089,  -6803],
                        [ -6394,  -7005],
                        [ -6722,  -7243],
                        [ -7063,  -7508],
                        [ -7417,  -7801],
                        [ -7732,  -8067],
                        [ -8010,  -8310],
                        [ -8211,  -8488],
                        [ -8335,  -8601],
                        [ -8386,  -8655],
                        [ -8364,  -8645],
                        [ -8274,  -8578],
                        [ -8115,  -8452],
                        [ -7898,  -8277],
                        [ -7621,  -8048],
                        [ -7295,  -7776],
                        [ -6918,  -7459],
                        [ -6503,  -7105],
                        [ -6049,  -6714],
                        [ -5566,  -6293],
                        [ -5055,  -5843],
                        [ -4522,  -5369],
                        [ -3967,  -4874],
                        [ -3399,  -4362],
                        [ -2815,  -3833],
                        [ -2222,  -3292],
                        [ -1623,  -2741],
                        [ -1018,  -2183],
                        [  -410,  -1618],
                        [   205,  -1050],
                        [   823,   -479],
                        [  1442,     91],
                        [  2060,    661],
                        [  2673,   1226],
                        [  3280,   1788],
                        [  3878,   2343],
                        [  4466,   2893],
                        [  5040,   3433],
                        [  5598,   3963],
                        [  6142,   4483],
                        [  6666,   4991],
                        [  7171,   5486],
                        [  7655,   5966],
                        [  8119,   6434],
                        [  8560,   6884],
                        [  8974,   7314],
                        [  9367,   7726],
                        [  9741,   8122],
                        [ 10031,   8435],
                        [ 10152,   8580],
                        [ 10073,   8524],
                        [  9796,   8267],
                        [  9297,   7789],
                        [  8552,   7062],
                        [  7611,   6141],
                        [  6623,   5176],
                        [  5664,   4242],
                        [  4729,   3340],
                        [  3829,   2480],
                        [  2982,   1677],
                        [  2196,    942],
                        [  1480,    280],
                        [   837,   -303],
                        [   275,   -802],
                        [  -202,  -1216],
                        [  -596,  -1541],
                        [  -903,  -1779],
                        [ -1124,  -1929],
                        [ -1262,  -1994],
                        [ -1317,  -1976],
                        [ -1294,  -1880],
                        [ -1198,  -1709],
                        [ -1033,  -1469],
                        [  -804,  -1164],
                        [  -515,   -802],
                        [  -174,   -387],
                        [   215,     76],
                        [   646,    579],
                        [  1114,   1119],
                        [  1612,   1685],
                        [  2134,   2275],
                        [  2676,   2880],
                        [  3230,   3497],
                        [  3790,   4116],
                        [  4353,   4734],
                        [  4912,   5335],
                        [  5465,   5916],
                        [  6006,   6466],
                        [  6531,   6983],
                        [  7036,   7466],
                        [  7519,   7912],
                        [  7975,   8334],
                        [  8402,   8728],
                        [  8799,   9101],
                        [  9162,   9449],
                        [  9488,   9770],
                        [  9776,  10065],
                        [ 10027,  10330],
                        [ 10238,  10563],
                        [ 10407,  10761],
                        [ 10535,  10924],
                        [ 10621,  11051],
                        [ 10666,  11142],
                        [ 10670,  11196],
                        [ 10632,  11213],
                        [ 10556,  11195],
                        [ 10441,  11142],
                        [ 10287,  11054],
                        [ 10097,  10934],
                        [  9869,  10779],
                        [  9608,  10590],
                        [  9313,  10368],
                        [  8988,  10116],
                        [  8636,   9836],
                        [  8262,   9530],
                        [  7880,   9202],
                        [  7493,   8853],
                        [  7114,   8487],
                        [  6745,   8105],
                        [  6386,   7712],
                        [  6043,   7311],
                        [  5709,   6914],
                        [  5389,   6521],
                        [  5117,   6183],
                        [  4892,   5900],
                        [  4733,   5689],
                        [  4641,   5553],
                        [  4593,   5468],
                        [  4591,   5439],
                        [  4568,   5393],
                        [  4526,   5338],
                        [  4453,   5259],
                        [  4350,   5155],
                        [  4223,   5033],
                        [  4071,   4895],
                        [  3901,   4743],
                        [  3712,   4578],
                        [  3515,   4407],
                        [  3306,   4229],
                        [  3096,   4051],
                        [  2883,   3871],
                        [  2676,   3694],
                        [  2472,   3521],
                        [  2278,   3354],
                        [  2091,   3192],
                        [  1916,   3040],
                        [  1749,   2894],
                        [  1595,   2756],
                        [  1450,   2624],
                        [  1317,   2499],
                        [  1193,   2379],
                        [  1071,   2262],
                        [   949,   2147],
                        [   821,   2031],
                        [   687,   1914],
                        [   545,   1794],
                        [   394,   1668],
                        [   232,   1535],
                        [    61,   1394],
                        [  -123,   1243],
                        [  -317,   1082],
                        [  -523,    909],
                        [  -743,    723],
                        [  -973,    523],
                        [ -1214,    312],
                        [ -1466,     86],
                        [ -1728,   -152],
                        [ -1998,   -401],
                        [ -2271,   -656],
                        [ -2553,   -921],
                        [ -2839,  -1194],
                        [ -3066,  -1407],
                        [ -3165,  -1493],
                        [ -3117,  -1430],
                        [ -2918,  -1214],
                        [ -2540,   -820],
                        [ -1946,   -209],
                        [ -1177,    574],
                        [  -358,   1402],
                        [   450,   2212],
                        [  1252,   3009],
                        [  2039,   3780],
                        [  2797,   4511],
                        [  3518,   5196],
                        [  4195,   5828],
                        [  4824,   6404],
                        [  5400,   6918],
                        [  5918,   7367],
                        [  6380,   7751],
                        [  6784,   8071],
                        [  7129,   8324],
                        [  7417,   8514],
                        [  7651,   8643],
                        [  7833,   8714],
                        [  7967,   8731],
                        [  8054,   8698],
                        [  8100,   8620],
                        [  8107,   8500],
                        [  8080,   8344],
                        [  8022,   8154],
                        [  7936,   7937],
                        [  7824,   7694],
                        [  7692,   7433],
                        [  7540,   7154],
                        [  7372,   6862],
                        [  7191,   6562],
                        [  6998,   6254],
                        [  6796,   5949],
                        [  6585,   5648],
                        [  6367,   5362],
                        [  6143,   5091],
                        [  5911,   4838],
                        [  5673,   4605],
                        [  5431,   4381],
                        [  5181,   4166],
                        [  4926,   3945],
                        [  4665,   3720],
                        [  4396,   3485],
                        [  4122,   3241],
                        [  3841,   2988],
                        [  3553,   2724],
                        [  3258,   2452],
                        [  2957,   2170],
                        [  2650,   1879],
                        [  2336,   1577],
                        [  2018,   1268],
                        [  1697,    949],
                        [  1372,    625],
                        [  1044,    295],
                        [   717,    -36],
                        [   391,   -368],
                        [    69,   -698],
                        [  -248,  -1025],
                        [  -556,  -1341],
                        [  -852,  -1648],
                        [ -1137,  -1940],
                        [ -1408,  -2219],
                        [ -1670,  -2481],
                        [ -1921,  -2724],
                        [ -2173,  -2949],
                        [ -2422,  -3150],
                        [ -2668,  -3327],
                        [ -2912,  -3481],
                        [ -3144,  -3608],
                        [ -3365,  -3711],
                        [ -3587,  -3822],
                        [ -3809,  -3937],
                        [ -4066,  -4099],
                        [ -4353,  -4302],
                        [ -4669,  -4545],
                        [ -5010,  -4827],
                        [ -5319,  -5090],
                        [ -5597,  -5334],
                        [ -5786,  -5501],
                        [ -5887,  -5593],
                        [ -5904,  -5613],
                        [ -5835,  -5558],
                        [ -5683,  -5432],
                        [ -5450,  -5236],
                        [ -5144,  -4975],
                        [ -4765,  -4650],
                        [ -4324,  -4270],
                        [ -3823,  -3833],
                        [ -3274,  -3352],
                        [ -2679,  -2826],
                        [ -2050,  -2264],
                        [ -1389,  -1668],
                        [  -704,  -1049],
                        [     0,   -406],
                        [   713,    251],
                        [  1433,    921],
                        [  2149,   1597],
                        [  2860,   2277],
                        [  3562,   2953],
                        [  4253,   3627],
                        [  4936,   4291],
                        [  5608,   4944],
                        [  6268,   5583],
                        [  6915,   6204],
                        [  7542,   6806],
                        [  8149,   7386],
                        [  8732,   7944],
                        [  9290,   8476],
                        [  9820,   8981],
                        [ 10320,   9458],
                        [ 10790,   9908],
                        [ 11228,  10327],
                        [ 11633,  10716],
                        [ 12002,  11074],
                        [ 12340,  11402],
                        [ 12643,  11698],
                        [ 12907,  11959],
                        [ 13140,  12191],
                        [ 13337,  12387],
                        [ 13448,  12498],
                        [ 13427,  12476],
                        [ 13271,  12316],
                        [ 12981,  12018],
                        [ 12528,  11552],
                        [ 11872,  10883],
                        [ 11044,  10041],
                        [ 10148,   9132],
                        [  9237,   8210],
                        [  8309,   7274],
                        [  7379,   6342],
                        [  6467,   5433],
                        [  5584,   4559],
                        [  4743,   3729],
                        [  3950,   2953],
                        [  3218,   2242],
                        [  2552,   1599],
                        [  1957,   1032],
                        [  1437,    544],
                        [   994,    138],
                        [   631,   -184],
                        [   346,   -423],
                        [   138,   -579],
                        [     5,   -657],
                        [   -58,   -660],
                        [   -53,   -592],
                        [    14,   -458],
                        [   138,   -263],
                        [   314,    -14],
                        [   537,    284],
                        [   799,    625],
                        [  1094,    999],
                        [  1417,   1404],
                        [  1759,   1828],
                        [  2116,   2268],
                        [  2480,   2713],
                        [  2845,   3157],
                        [  3207,   3584],
                        [  3559,   3990],
                        [  3897,   4364],
                        [  4216,   4701],
                        [  4513,   4999],
                        [  4784,   5253],
                        [  5025,   5475],
                        [  5235,   5664],
                        [  5411,   5824],
                        [  5551,   5956],
                        [  5653,   6056],
                        [  5717,   6126],
                        [  5742,   6166],
                        [  5730,   6176],
                        [  5678,   6156],
                        [  5588,   6108],
                        [  5462,   6034],
                        [  5299,   5936],
                        [  5103,   5813],
                        [  4874,   5666],
                        [  4615,   5495],
                        [  4328,   5300],
                        [  4016,   5082],
                        [  3680,   4843],
                        [  3323,   4582],
                        [  2948,   4301],
                        [  2557,   4002],
                        [  2154,   3686],
                        [  1745,   3357],
                        [  1333,   3018],
                        [   934,   2673],
                        [   549,   2324],
                        [   187,   1971],
                        [  -150,   1617],
                        [  -457,   1268],
                        [  -734,    925],
                        [  -976,    608],
                        [ -1184,    314],
                        [ -1310,    103],
                        [ -1359,    -28],
                        [ -1314,    -62],
                        [ -1176,      2],
                        [  -966,    143],
                        [  -683,    364],
                        [  -414,    579],
                        [  -152,    793],
                        [    77,    983],
                        [   275,   1150],
                        [   438,   1290],
                        [   565,   1404],
                        [   656,   1490],
                        [   710,   1547],
                        [   730,   1577],
                        [   714,   1579],
                        [   669,   1555],
                        [   592,   1502],
                        [   489,   1427],
                        [   360,   1327],
                        [   208,   1204],
                        [    32,   1058],
                        [  -161,    894],
                        [  -373,    707],
                        [  -596,    504],
                        [  -831,    281],
                        [ -1075,     42],
                        [ -1329,   -215],
                        [ -1599,   -486],
                        [ -1884,   -774],
                        [ -2191,  -1075],
                        [ -2518,  -1391],
                        [ -2863,  -1719],
                        [ -3225,  -2059],
                        [ -3602,  -2408],
                        [ -3992,  -2767],
                        [ -4392,  -3134],
                        [ -4800,  -3505],
                        [ -5213,  -3881],
                        [ -5629,  -4258],
                        [ -6044,  -4635],
                        [ -6456,  -5007],
                        [ -6860,  -5376],
                        [ -7256,  -5736],
                        [ -7636,  -6086],
                        [ -7997,  -6419],
                        [ -8340,  -6737],
                        [ -8656,  -7031],
                        [ -8907,  -7262],
                        [ -9069,  -7406],
                        [ -9144,  -7462],
                        [ -9127,  -7427],
                        [ -8985,  -7268],
                        [ -8670,  -6936],
                        [ -8188,  -6442],
                        [ -7613,  -5858],
                        [ -6978,  -5221],
                        [ -6284,  -4530],
                        [ -5541,  -3800],
                        [ -4769,  -3049],
                        [ -3977,  -2286],
                        [ -3175,  -1520],
                        [ -2375,   -763],
                        [ -1586,    -24],
                        [  -817,    690],
                        [   -73,   1372],
                        [   638,   2013],
                        [  1310,   2611],
                        [  1939,   3158],
                        [  2523,   3655],
                        [  3057,   4097],
                        [  3542,   4483],
                        [  3975,   4814],
                        [  4355,   5090],
                        [  4682,   5311],
                        [  4959,   5478],
                        [  5182,   5592],
                        [  5356,   5657],
                        [  5479,   5672],
                        [  5555,   5641],
                        [  5584,   5566],
                        [  5569,   5451],
                        [  5512,   5298],
                        [  5415,   5111],
                        [  5281,   4899],
                        [  5112,   4663],
                        [  4909,   4414],
                        [  4674,   4154],
                        [  4411,   3890],
                        [  4121,   3623],
                        [  3806,   3348],
                        [  3469,   3068],
                        [  3110,   2771],
                        [  2733,   2460],
                        [  2341,   2133],
                        [  1935,   1790],
                        [  1516,   1433],
                        [  1089,   1064],
                        [   654,    683],
                        [   216,    290],
                        [  -223,   -115],
                        [  -662,   -531],
                        [ -1097,   -956],
                        [ -1525,  -1387],
                        [ -1944,  -1818],
                        [ -2353,  -2250],
                        [ -2745,  -2671],
                        [ -3122,  -3079],
                        [ -3478,  -3471],
                        [ -3812,  -3847],
                        [ -4122,  -4198],
                        [ -4405,  -4522],
                        [ -4661,  -4818],
                        [ -4888,  -5084],
                        [ -5090,  -5318],
                        [ -5264,  -5519],
                        [ -5421,  -5684],
                        [ -5556,  -5812],
                        [ -5672,  -5902],
                        [ -5771,  -5956],
                        [ -5849,  -5978],
                        [ -5906,  -5963],
                        [ -5971,  -5958],
                        [ -6041,  -5959],
                        [ -6151,  -6004],
                        [ -6296,  -6091],
                        [ -6482,  -6224],
                        [ -6707,  -6404],
                        [ -6915,  -6576],
                        [ -7111,  -6744],
                        [ -7230,  -6845],
                        [ -7279,  -6884],
                        [ -7256,  -6860],
                        [ -7159,  -6773],
                        [ -6991,  -6622],
                        [ -6750,  -6407],
                        [ -6443,  -6133],
                        [ -6071,  -5801],
                        [ -5641,  -5418],
                        [ -5156,  -4983],
                        [ -4628,  -4506],
                        [ -4057,  -3987],
                        [ -3454,  -3435],
                        [ -2820,  -2852],
                        [ -2169,  -2247],
                        [ -1500,  -1622],
                        [  -829,   -986],
                        [  -158,   -340],
                        [   504,    308],
                        [  1152,    956],
                        [  1786,   1596],
                        [  2401,   2228],
                        [  3003,   2845],
                        [  3592,   3447],
                        [  4165,   4027],
                        [  4720,   4586],
                        [  5253,   5118],
                        [  5762,   5623],
                        [  6245,   6098],
                        [  6700,   6542],
                        [  7125,   6953],
                        [  7518,   7330],
                        [  7880,   7672],
                        [  8208,   7978],
                        [  8502,   8249],
                        [  8761,   8481],
                        [  8986,   8680],
                        [  9174,   8840],
                        [  9325,   8964],
                        [  9441,   9052],
                        [  9521,   9101],
                        [  9548,   9097],
                        [  9529,   9043],
                        [  9475,   8951],
                        [  9383,   8816],
                        [  9224,   8613],
                        [  8951,   8292],
                        [  8546,   7838],
                        [  8054,   7296],
                        [  7499,   6691],
                        [  6884,   6030],
                        [  6227,   5327],
                        [  5540,   4598],
                        [  4838,   3856],
                        [  4128,   3112],
                        [  3424,   2377],
                        [  2737,   1662],
                        [  2074,    973],
                        [  1443,    322],
                        [   849,   -287],
                        [   298,   -846],
                        [  -207,  -1353],
                        [  -665,  -1804],
                        [ -1072,  -2199],
                        [ -1430,  -2536],
                        [ -1738,  -2817],
                        [ -1999,  -3044],
                        [ -2215,  -3219],
                        [ -2389,  -3346],
                        [ -2523,  -3428],
                        [ -2622,  -3470],
                        [ -2690,  -3476],
                        [ -2732,  -3451],
                        [ -2753,  -3400],
                        [ -2755,  -3327],
                        [ -2745,  -3239],
                        [ -2728,  -3145],
                        [ -2709,  -3048],
                        [ -2689,  -2960],
                        [ -2676,  -2885],
                        [ -2670,  -2833],
                        [ -2676,  -2806],
                        [ -2695,  -2809],
                        [ -2732,  -2843],
                        [ -2786,  -2902],
                        [ -2860,  -2988],
                        [ -2956,  -3093],
                        [ -3072,  -3219],
                        [ -3211,  -3363],
                        [ -3370,  -3525],
                        [ -3550,  -3703],
                        [ -3751,  -3895],
                        [ -3970,  -4096],
                        [ -4206,  -4305],
                        [ -4460,  -4516],
                        [ -4726,  -4726],
                        [ -5006,  -4938],
                        [ -5296,  -5147],
                        [ -5594,  -5359],
                        [ -5897,  -5571],
                        [ -6203,  -5787],
                        [ -6508,  -6004],
                        [ -6810,  -6221],
                        [ -7109,  -6434],
                        [ -7398,  -6647],
                        [ -7679,  -6857],
                        [ -7945,  -7060],
                        [ -8197,  -7256],
                        [ -8422,  -7443],
                        [ -8623,  -7618],
                        [ -8795,  -7785],
                        [ -8934,  -7941],
                        [ -9038,  -8080],
                        [ -9105,  -8205],
                        [ -9126,  -8294],
                        [ -9102,  -8350],
                        [ -8993,  -8323],
                        [ -8801,  -8218],
                        [ -8520,  -8021],
                        [ -8148,  -7735],
                        [ -7701,  -7370],
                        [ -7178,  -6926],
                        [ -6664,  -6484],
                        [ -6154,  -6040],
                        [ -5674,  -5618],
                        [ -5224,  -5220],
                        [ -4816,  -4855],
                        [ -4449,  -4522],
                        [ -4131,  -4230],
                        [ -3862,  -3977],
                        [ -3646,  -3768],
                        [ -3483,  -3605],
                        [ -3371,  -3486],
                        [ -3313,  -3415],
                        [ -3302,  -3388],
                        [ -3343,  -3408],
                        [ -3427,  -3470],
                        [ -3559,  -3576],
                        [ -3727,  -3720],
                        [ -3933,  -3905],
                        [ -4165,  -4124],
                        [ -4424,  -4379],
                        [ -4704,  -4663],
                        [ -5003,  -4976],
                        [ -5327,  -5312],
                        [ -5673,  -5672],
                        [ -6043,  -6049],
                        [ -6437,  -6442],
                        [ -6846,  -6847],
                        [ -7269,  -7259],
                        [ -7702,  -7674],
                        [ -8140,  -8091],
                        [ -8577,  -8503],
                        [ -9010,  -8908],
                        [ -9434,  -9302],
                        [ -9845,  -9680],
                        [-10238, -10039],
                        [-10610, -10375],
                        [-10955, -10685],
                        [-11270, -10965],
                        [-11549, -11211],
                        [-11789, -11421],
                        [-11988, -11591],
                        [-12140, -11718],
                        [-12257, -11811],
                        [-12359, -11893],
                        [-12461, -11974],
                        [-12556, -12049],
                        [-12615, -12092],
                        [-12585, -12047],
                        [-12421, -11871],
                        [-12131, -11572],
                        [-11733, -11168],
                        [-11230, -10662],
                        [-10638, -10070],
                        [ -9969,  -9406],
                        [ -9236,  -8682],
                        [ -8451,  -7909],
                        [ -7627,  -7100],
                        [ -6777,  -6267],
                        [ -5913,  -5423],
                        [ -5046,  -4578],
                        [ -4185,  -3743],
                        [ -3340,  -2929],
                        [ -2521,  -2144],
                        [ -1733,  -1393],
                        [  -985,   -687],
                        [  -282,    -29],
                        [   371,    577],
                        [   971,   1127],
                        [  1513,   1618],
                        [  1996,   2048],
                        [  2417,   2418],
                        [  2776,   2726],
                        [  3073,   2973],
                        [  3308,   3158],
                        [  3481,   3284],
                        [  3595,   3352],
                        [  3651,   3365],
                        [  3651,   3326],
                        [  3599,   3244],
                        [  3499,   3119],
                        [  3351,   2962],
                        [  3161,   2775],
                        [  2932,   2565],
                        [  2667,   2335],
                        [  2372,   2089],
                        [  2048,   1829],
                        [  1701,   1552],
                        [  1334,   1261],
                        [   953,    956],
                        [   560,    639],
                        [   160,    312],
                        [  -245,    -21],
                        [  -648,   -361],
                        [ -1047,   -704],
                        [ -1438,  -1055],
                        [ -1817,  -1411],
                        [ -2180,  -1768],
                        [ -2524,  -2125],
                        [ -2847,  -2474],
                        [ -3146,  -2815],
                        [ -3418,  -3132],
                        [ -3662,  -3426],
                        [ -3876,  -3695],
                        [ -4059,  -3936],
                        [ -4210,  -4145],
                        [ -4327,  -4319],
                        [ -4409,  -4460],
                        [ -4457,  -4563],
                        [ -4470,  -4630],
                        [ -4451,  -4661],
                        [ -4402,  -4655],
                        [ -4322,  -4609],
                        [ -4218,  -4526],
                        [ -4093,  -4409],
                        [ -3951,  -4263],
                        [ -3793,  -4089],
                        [ -3651,  -3924],
                        [ -3523,  -3770],
                        [ -3432,  -3649],
                        [ -3379,  -3564],
                        [ -3374,  -3526],
                        [ -3418,  -3539],
                        [ -3471,  -3563],
                        [ -3538,  -3602],
                        [ -3567,  -3608],
                        [ -3563,  -3585],
                        [ -3522,  -3528],
                        [ -3446,  -3440],
                        [ -3328,  -3315],
                        [ -3170,  -3156],
                        [ -2973,  -2961],
                        [ -2738,  -2733],
                        [ -2468,  -2474],
                        [ -2166,  -2185],
                        [ -1835,  -1870],
                        [ -1478,  -1530],
                        [ -1101,  -1169],
                        [  -707,   -791],
                        [  -301,   -401],
                        [   111,      1],
                        [   521,    408],
                        [   925,    819],
                        [  1317,   1229],
                        [  1696,   1636],
                        [  2059,   2036],
                        [  2407,   2427],
                        [  2746,   2806],
                        [  3076,   3170],
                        [  3395,   3518],
                        [  3703,   3849],
                        [  3998,   4158],
                        [  4277,   4447],
                        [  4541,   4713],
                        [  4787,   4954],
                        [  5014,   5169],
                        [  5223,   5359],
                        [  5411,   5523],
                        [  5579,   5660],
                        [  5724,   5770],
                        [  5848,   5851],
                        [  5950,   5905],
                        [  6028,   5932],
                        [  6082,   5932],
                        [  6108,   5902],
                        [  6117,   5851],
                        [  6142,   5815],
                        [  6228,   5837],
                        [  6390,   5932],
                        [  6620,   6095],
                        [  6901,   6306],
                        [  7172,   6507],
                        [  7359,   6625],
                        [  7442,   6638],
                        [  7430,   6558],
                        [  7330,   6386],
                        [  7148,   6136],
                        [  6895,   5816],
                        [  6579,   5435],
                        [  6208,   5001],
                        [  5794,   4526],
                        [  5343,   4018],
                        [  4865,   3485],
                        [  4366,   2937],
                        [  3855,   2381],
                        [  3336,   1825],
                        [  2816,   1274],
                        [  2299,    734],
                        [  1787,    208],
                        [  1286,   -299],
                        [   799,   -785],
                        [   325,  -1250],
                        [  -134,  -1691],
                        [  -576,  -2110],
                        [ -1003,  -2507],
                        [ -1413,  -2881],
                        [ -1809,  -3235],
                        [ -2189,  -3569],
                        [ -2557,  -3885],
                        [ -2913,  -4186],
                        [ -3259,  -4473],
                        [ -3595,  -4748],
                        [ -3926,  -5016],
                        [ -4249,  -5280],
                        [ -4569,  -5544],
                        [ -4884,  -5809],
                        [ -5197,  -6080],
                        [ -5506,  -6358],
                        [ -5816,  -6645],
                        [ -6122,  -6939],
                        [ -6428,  -7240],
                        [ -6730,  -7543],
                        [ -7031,  -7849],
                        [ -7328,  -8153],
                        [ -7620,  -8455],
                        [ -7907,  -8749],
                        [ -8188,  -9037],
                        [ -8461,  -9309],
                        [ -8725,  -9563],
                        [ -8978,  -9794],
                        [ -9220, -10000],
                        [ -9449, -10181],
                        [ -9665, -10336],
                        [ -9865, -10471],
                        [-10047, -10584],
                        [-10208, -10680],
                        [-10348, -10758],
                        [-10464, -10815],
                        [-10556, -10853],
                        [-10624, -10874],
                        [-10668, -10874],
                        [-10689, -10856],
                        [-10688, -10818],
                        [-10662, -10762],
                        [-10614, -10688],
                        [-10542, -10598],
                        [-10447, -10493],
                        [-10320, -10370],
                        [-10165, -10230],
                        [ -9969, -10061],
                        [ -9734,  -9865],
                        [ -9439,  -9615],
                        [ -9085,  -9315],
                        [ -8671,  -8955],
                        [ -8198,  -8540],
                        [ -7665,  -8066],
                        [ -7075,  -7534],
                        [ -6487,  -7001],
                        [ -5898,  -6465],
                        [ -5332,  -5947],
                        [ -4787,  -5446],
                        [ -4279,  -4977],
                        [ -3809,  -4539],
                        [ -3387,  -4144],
                        [ -3013,  -3789],
                        [ -2693,  -3482],
                        [ -2428,  -3223],
                        [ -2219,  -3014],
                        [ -2067,  -2858],
                        [ -1970,  -2751],
                        [ -1930,  -2697],
                        [ -1939,  -2690],
                        [ -2000,  -2732],
                        [ -2100,  -2817],
                        [ -2238,  -2945],
                        [ -2407,  -3112],
                        [ -2602,  -3314],
                        [ -2819,  -3545],
                        [ -3054,  -3804],
                        [ -3309,  -4084],
                        [ -3580,  -4382],
                        [ -3868,  -4692],
                        [ -4170,  -5011],
                        [ -4477,  -5331],
                        [ -4787,  -5650],
                        [ -5094,  -5961],
                        [ -5393,  -6260],
                        [ -5680,  -6543],
                        [ -5951,  -6806],
                        [ -6199,  -7043],
                        [ -6421,  -7251],
                        [ -6613,  -7425],
                        [ -6771,  -7564],
                        [ -6892,  -7663],
                        [ -6972,  -7719],
                        [ -7009,  -7731],
                        [ -7001,  -7698],
                        [ -6940,  -7613],
                        [ -6843,  -7492],
                        [ -6771,  -7399],
                        [ -6779,  -7385],
                        [ -6878,  -7463],
                        [ -7065,  -7631],
                        [ -7326,  -7876],
                        [ -7601,  -8137],
                        [ -7789,  -8313],
                        [ -7846,  -8358],
                        [ -7783,  -8281],
                        [ -7606,  -8089],
                        [ -7323,  -7789],
                        [ -6944,  -7392],
                        [ -6481,  -6908],
                        [ -5942,  -6347],
                        [ -5341,  -5722],
                        [ -4689,  -5043],
                        [ -3999,  -4325],
                        [ -3281,  -3577],
                        [ -2546,  -2814],
                        [ -1806,  -2043],
                        [ -1071,  -1279],
                        [  -348,   -528],
                        [   353,    200],
                        [  1025,    896],
                        [  1659,   1555],
                        [  2254,   2173],
                        [  2801,   2743],
                        [  3297,   3263],
                        [  3742,   3729],
                        [  4131,   4142],
                        [  4464,   4498],
                        [  4740,   4797],
                        [  4960,   5040],
                        [  5124,   5228],
                        [  5237,   5363],
                        [  5296,   5446],
                        [  5308,   5484],
                        [  5275,   5476],
                        [  5201,   5430],
                        [  5089,   5348],
                        [  4943,   5237],
                        [  4769,   5100],
                        [  4570,   4947],
                        [  4351,   4780],
                        [  4116,   4603],
                        [  3870,   4422],
                        [  3618,   4235],
                        [  3363,   4048],
                        [  3110,   3861],
                        [  2862,   3678],
                        [  2624,   3498],
                        [  2399,   3323],
                        [  2191,   3149],
                        [  2002,   2980],
                        [  1836,   2815],
                        [  1694,   2659],
                        [  1580,   2515],
                        [  1493,   2384],
                        [  1435,   2279],
                        [  1405,   2199],
                        [  1401,   2146],
                        [  1425,   2120],
                        [  1477,   2121],
                        [  1555,   2151],
                        [  1663,   2208],
                        [  1798,   2292],
                        [  1965,   2403],
                        [  2160,   2538],
                        [  2382,   2699],
                        [  2633,   2885],
                        [  2900,   3093],
                        [  3179,   3317],
                        [  3460,   3556],
                        [  3742,   3805],
                        [  4002,   4045],
                        [  4242,   4275],
                        [  4453,   4485],
                        [  4635,   4675],
                        [  4769,   4822],
                        [  4851,   4925],
                        [  4898,   4995],
                        [  4903,   5029],
                        [  4899,   5055],
                        [  4882,   5070],
                        [  4861,   5082],
                        [  4835,   5090],
                        [  4812,   5102],
                        [  4792,   5116],
                        [  4782,   5138],
                        [  4779,   5166],
                        [  4789,   5204],
                        [  4809,   5251],
                        [  4843,   5309],
                        [  4890,   5376],
                        [  4947,   5454],
                        [  5017,   5541],
                        [  5093,   5637],
                        [  5176,   5741],
                        [  5259,   5852],
                        [  5342,   5969],
                        [  5422,   6088],
                        [  5499,   6212],
                        [  5572,   6336],
                        [  5642,   6461],
                        [  5715,   6584],
                        [  5792,   6704],
                        [  5870,   6820],
                        [  5950,   6931],
                        [  6031,   7035],
                        [  6112,   7131],
                        [  6192,   7217],
                        [  6271,   7292],
                        [  6346,   7356],
                        [  6416,   7408],
                        [  6481,   7446],
                        [  6541,   7470],
                        [  6592,   7477],
                        [  6635,   7469],
                        [  6666,   7443],
                        [  6687,   7400],
                        [  6694,   7340],
                        [  6681,   7256],
                        [  6676,   7178],
                        [  6762,   7187],
                        [  6993,   7341],
                        [  7380,   7651],
                        [  7919,   8115],
                        [  8605,   8729],
                        [  9369,   9423],
                        [ 10082,  10069],
                        [ 10682,  10604],
                        [ 11170,  11027],
                        [ 11552,  11343],
                        [ 11828,  11551],
                        [ 11998,  11655],
                        [ 12069,  11658],
                        [ 12043,  11566],
                        [ 11928,  11385],
                        [ 11728,  11122],
                        [ 11453,  10785],
                        [ 11107,  10381],
                        [ 10698,   9917],
                        [ 10233,   9402],
                        [  9720,   8844],
                        [  9163,   8248],
                        [  8569,   7623],
                        [  7946,   6975],
                        [  7300,   6307],
                        [  6634,   5628],
                        [  5954,   4941],
                        [  5265,   4249],
                        [  4571,   3556],
                        [  3876,   2866],
                        [  3183,   2182],
                        [  2494,   1506],
                        [  1814,    841],
                        [  1144,    189],
                        [   487,   -447],
                        [  -156,  -1065],
                        [  -782,  -1666],
                        [ -1391,  -2247],
                        [ -1980,  -2807],
                        [ -2548,  -3343],
                        [ -3095,  -3856],
                        [ -3619,  -4349],
                        [ -4119,  -4821],
                        [ -4593,  -5276],
                        [ -5042,  -5714],
                        [ -5462,  -6133],
                        [ -5856,  -6533],
                        [ -6220,  -6910],
                        [ -6554,  -7265],
                        [ -6858,  -7591],
                        [ -7131,  -7890],
                        [ -7372,  -8152],
                        [ -7581,  -8378],
                        [ -7760,  -8563],
                        [ -7907,  -8708],
                        [ -8022,  -8811],
                        [ -8106,  -8873],
                        [ -8157,  -8900],
                        [ -8176,  -8893],
                        [ -8161,  -8857],
                        [ -8112,  -8794],
                        [ -8031,  -8700],
                        [ -7917,  -8579],
                        [ -7775,  -8431],
                        [ -7605,  -8257],
                        [ -7417,  -8061],
                        [ -7211,  -7842],
                        [ -6995,  -7605],
                        [ -6771,  -7350],
                        [ -6540,  -7083],
                        [ -6301,  -6801],
                        [ -6045,  -6508],
                        [ -5774,  -6205],
                        [ -5482,  -5890],
                        [ -5171,  -5566],
                        [ -4843,  -5234],
                        [ -4500,  -4897],
                        [ -4141,  -4549],
                        [ -3765,  -4192],
                        [ -3355,  -3803],
                        [ -2914,  -3387],
                        [ -2462,  -2961],
                        [ -1998,  -2525],
                        [ -1540,  -2095],
                        [ -1086,  -1671],
                        [  -651,  -1263],
                        [  -234,   -874],
                        [   153,   -513],
                        [   511,   -178],
                        [   831,    122],
                        [  1116,    388],
                        [  1358,    618],
                        [  1559,    810],
                        [  1719,    964],
                        [  1840,   1081],
                        [  1922,   1162],
                        [  1970,   1208],
                        [  1991,   1222],
                        [  1985,   1206],
                        [  1959,   1164],
                        [  1916,   1099],
                        [  1863,   1016],
                        [  1802,    917],
                        [  1734,    809],
                        [  1662,    694],
                        [  1587,    578],
                        [  1511,    464],
                        [  1442,    358],
                        [  1380,    263],
                        [  1332,    184],
                        [  1298,    124],
                        [  1285,     88],
                        [  1292,     76],
                        [  1324,     95],
                        [  1384,    144],
                        [  1472,    228],
                        [  1591,    345],
                        [  1743,    501],
                        [  1928,    695],
                        [  2145,    923],
                        [  2396,   1190],
                        [  2689,   1500],
                        [  2976,   1808],
                        [  3163,   2016],
                        [  3192,   2067],
                        [  3054,   1952],
                        [  2744,   1662],
                        [  2256,   1194],
                        [  1659,    615],
                        [  1094,     68],
                        [   635,   -374],
                        [   271,   -715],
                        [    -2,   -960],
                        [  -184,  -1106],
                        [  -279,  -1157],
                        [  -291,  -1121],
                        [  -227,  -1002],
                        [   -93,   -807],
                        [   102,   -546],
                        [   349,   -227],
                        [   641,    142],
                        [   969,    549],
                        [  1324,    988],
                        [  1699,   1448],
                        [  2086,   1921],
                        [  2477,   2399],
                        [  2864,   2873],
                        [  3243,   3339],
                        [  3607,   3790],
                        [  3952,   4223],
                        [  4274,   4630],
                        [  4570,   5012],
                        [  4837,   5366],
                        [  5075,   5688],
                        [  5281,   5977],
                        [  5456,   6233],
                        [  5600,   6456],
                        [  5714,   6646],
                        [  5797,   6804],
                        [  5855,   6930],
                        [  5887,   7026],
                        [  5899,   7090],
                        [  5891,   7125],
                        [  5867,   7135],
                        [  5831,   7125],
                        [  5787,   7104],
                        [  5735,   7074],
                        [  5680,   7046],
                        [  5627,   7022],
                        [  5577,   7007],
                        [  5532,   7000],
                        [  5497,   7003],
                        [  5473,   7017],
                        [  5461,   7040],
                        [  5466,   7075],
                        [  5487,   7117],
                        [  5526,   7165],
                        [  5584,   7222],
                        [  5663,   7288],
                        [  5761,   7364],
                        [  5878,   7449],
                        [  6009,   7551],
                        [  6157,   7671],
                        [  6316,   7804],
                        [  6487,   7952],
                        [  6667,   8110],
                        [  6855,   8279],
                        [  7057,   8455],
                        [  7269,   8639],
                        [  7498,   8828],
                        [  7742,   9020],
                        [  8002,   9214],
                        [  8277,   9409],
                        [  8552,   9601],
                        [  8825,   9788],
                        [  9081,   9969],
                        [  9319,  10141],
                        [  9542,  10311],
                        [  9748,  10479],
                        [  9943,  10648],
                        [ 10126,  10816],
                        [ 10271,  10957],
                        [ 10380,  11072],
                        [ 10429,  11136],
                        [ 10420,  11148],
                        [ 10361,  11118],
                        [ 10252,  11044],
                        [ 10104,  10936],
                        [  9917,  10793],
                        [  9703,  10627],
                        [  9459,  10433],
                        [  9200,  10226],
                        [  8924,  10002],
                        [  8643,   9770],
                        [  8354,   9531],
                        [  8069,   9289],
                        [  7786,   9046],
                        [  7510,   8807],
                        [  7239,   8571],
                        [  6979,   8344],
                        [  6726,   8124],
                        [  6482,   7914],
                        [  6248,   7715],
                        [  6025,   7526],
                        [  5810,   7349],
                        [  5605,   7183],
                        [  5410,   7029],
                        [  5228,   6884],
                        [  5060,   6750],
                        [  4907,   6624],
                        [  4766,   6507],
                        [  4639,   6395],
                        [  4525,   6290],
                        [  4420,   6188],
                        [  4327,   6090],
                        [  4240,   5991],
                        [  4162,   5894],
                        [  4089,   5793],
                        [  4019,   5691],
                        [  3953,   5583],
                        [  3886,   5469],
                        [  3816,   5345],
                        [  3745,   5216],
                        [  3667,   5076],
                        [  3575,   4918],
                        [  3522,   4799],
                        [  3610,   4817],
                        [  3881,   5021],
                        [  4344,   5418],
                        [  4999,   6014],
                        [  5862,   6822],
                        [  6857,   7767],
                        [  7827,   8693],
                        [  8695,   9518],
                        [  9461,  10243],
                        [ 10127,  10866],
                        [ 10684,  11376],
                        [ 11128,  11771],
                        [ 11460,  12051],
                        [ 11677,  12216],
                        [ 11783,  12268],
                        [ 11781,  12211],
                        [ 11676,  12050],
                        [ 11471,  11790],
                        [ 11174,  11438],
                        [ 10789,  11000],
                        [ 10325,  10484],
                        [  9790,   9898],
                        [  9189,   9250],
                        [  8535,   8550],
                        [  7831,   7802],
                        [  7087,   7018],
                        [  6310,   6201],
                        [  5508,   5361],
                        [  4686,   4504],
                        [  3854,   3636],
                        [  3016,   2763],
                        [  2179,   1893],
                        [  1349,   1029],
                        [   531,    180],
                        [  -270,   -652],
                        [ -1047,  -1459],
                        [ -1800,  -2238],
                        [ -2522,  -2979],
                        [ -3213,  -3682],
                        [ -3865,  -4336],
                        [ -4482,  -4941],
                        [ -5057,  -5501],
                        [ -5591,  -6012],
                        [ -6081,  -6484],
                        [ -6528,  -6917],
                        [ -6928,  -7314],
                        [ -7284,  -7677],
                        [ -7593,  -8001],
                        [ -7857,  -8288],
                        [ -8075,  -8534],
                        [ -8250,  -8741],
                        [ -8381,  -8903],
                        [ -8470,  -9024],
                        [ -8519,  -9100],
                        [ -8529,  -9133],
                        [ -8501,  -9125],
                        [ -8439,  -9076],
                        [ -8340,  -8994],
                        [ -8210,  -8877],
                        [ -8045,  -8734],
                        [ -7850,  -8565],
                        [ -7627,  -8370],
                        [ -7377,  -8151],
                        [ -7107,  -7910],
                        [ -6819,  -7648],
                        [ -6529,  -7371],
                        [ -6238,  -7079],
                        [ -5958,  -6776],
                        [ -5690,  -6464],
                        [ -5433,  -6148],
                        [ -5190,  -5827],
                        [ -4947,  -5506],
                        [ -4707,  -5185],
                        [ -4473,  -4879],
                        [ -4247,  -4590],
                        [ -4053,  -4343],
                        [ -3891,  -4138],
                        [ -3756,  -3969],
                        [ -3651,  -3837],
                        [ -3534,  -3703],
                        [ -3408,  -3567],
                        [ -3254,  -3409],
                        [ -3074,  -3231],
                        [ -2875,  -3040],
                        [ -2655,  -2835],
                        [ -2426,  -2625],
                        [ -2186,  -2409],
                        [ -1944,  -2195],
                        [ -1699,  -1981],
                        [ -1459,  -1774],
                        [ -1224,  -1572],
                        [ -1000,  -1380],
                        [  -786,  -1196],
                        [  -583,  -1024],
                        [  -392,   -860],
                        [  -209,   -707],
                        [   -35,   -563],
                        [   133,   -427],
                        [   297,   -298],
                        [   457,   -174],
                        [   615,    -54],
                        [   778,     67],
                        [   948,    188],
                        [  1125,    313],
                        [  1312,    444],
                        [  1508,    583],
                        [  1714,    734],
                        [  1934,    897],
                        [  2165,   1075],
                        [  2412,   1270],
                        [  2672,   1482],
                        [  2948,   1714],
                        [  3239,   1964],
                        [  3545,   2235],
                        [  3865,   2527],
                        [  4200,   2837],
                        [  4547,   3167],
                        [  4907,   3516],
                        [  5277,   3881],
                        [  5653,   4259],
                        [  6039,   4652],
                        [  6433,   5059],
                        [  6771,   5416],
                        [  6953,   5618],
                        [  6936,   5626],
                        [  6717,   5432],
                        [  6277,   5016],
                        [  5597,   4357],
                        [  4740,   3523],
                        [  3863,   2668],
                        [  3040,   1868],
                        [  2260,   1120],
                        [  1530,    426],
                        [   856,   -202],
                        [   241,   -762],
                        [  -312,  -1252],
                        [  -803,  -1671],
                        [ -1232,  -2022],
                        [ -1600,  -2303],
                        [ -1909,  -2521],
                        [ -2164,  -2678],
                        [ -2366,  -2778],
                        [ -2520,  -2826],
                        [ -2631,  -2828],
                        [ -2702,  -2786],
                        [ -2737,  -2708],
                        [ -2743,  -2599],
                        [ -2723,  -2464],
                        [ -2680,  -2306],
                        [ -2620,  -2130],
                        [ -2542,  -1939],
                        [ -2454,  -1736],
                        [ -2354,  -1524],
                        [ -2246,  -1306],
                        [ -2132,  -1083],
                        [ -2012,   -859],
                        [ -1889,   -633],
                        [ -1763,   -410],
                        [ -1634,   -189],
                        [ -1502,     27],
                        [ -1367,    236],
                        [ -1230,    428],
                        [ -1088,    607],
                        [  -941,    773],
                        [  -788,    925],
                        [  -629,   1073],
                        [  -463,   1218],
                        [  -289,   1375],
                        [  -107,   1542],
                        [    84,   1723],
                        [   284,   1918],
                        [   492,   2123],
                        [   709,   2342],
                        [   934,   2569],
                        [  1168,   2806],
                        [  1409,   3048],
                        [  1658,   3296],
                        [  1911,   3547],
                        [  2170,   3802],
                        [  2429,   4056],
                        [  2690,   4310],
                        [  2945,   4564],
                        [  3196,   4818],
                        [  3435,   5068],
                        [  3664,   5312],
                        [  3881,   5545],
                        [  4083,   5766],
                        [  4279,   5971],
                        [  4465,   6160],
                        [  4652,   6332],
                        [  4840,   6484],
                        [  5029,   6615],
                        [  5215,   6723],
                        [  5389,   6809],
                        [  5549,   6870],
                        [  5681,   6911],
                        [  5786,   6932],
                        [  5895,   6970],
                        [  6004,   7019],
                        [  6129,   7095],
                        [  6265,   7196],
                        [  6390,   7296],
                        [  6504,   7397],
                        [  6552,   7441],
                        [  6537,   7431],
                        [  6453,   7362],
                        [  6303,   7233],
                        [  6095,   7054],
                        [  5829,   6824],
                        [  5518,   6554],
                        [  5161,   6245],
                        [  4774,   5906],
                        [  4356,   5539],
                        [  3922,   5152],
                        [  3471,   4747],
                        [  3015,   4334],
                        [  2555,   3911],
                        [  2097,   3489],
                        [  1642,   3066],
                        [  1198,   2650],
                        [   763,   2239],
                        [   345,   1841],
                        [   -56,   1455],
                        [  -440,   1085],
                        [  -805,    729],
                        [ -1157,    389],
                        [ -1493,     67],
                        [ -1812,   -240],
                        [ -2115,   -529],
                        [ -2401,   -804],
                        [ -2670,  -1063],
                        [ -2923,  -1310],
                        [ -3161,  -1543],
                        [ -3384,  -1766],
                        [ -3592,  -1978],
                        [ -3789,  -2182],
                        [ -3973,  -2378],
                        [ -4148,  -2570],
                        [ -4314,  -2755],
                        [ -4472,  -2938],
                        [ -4625,  -3119],
                        [ -4775,  -3301],
                        [ -4918,  -3479],
                        [ -5064,  -3664],
                        [ -5212,  -3851],
                        [ -5298,  -3977],
                        [ -5235,  -3955],
                        [ -5001,  -3758],
                        [ -4591,  -3382],
                        [ -3990,  -2810],
                        [ -3170,  -2011],
                        [ -2198,  -1054],
                        [ -1220,    -85],
                        [  -308,    820],
                        [   543,   1666],
                        [  1326,   2441],
                        [  2028,   3130],
                        [  2639,   3725],
                        [  3157,   4222],
                        [  3577,   4617],
                        [  3896,   4906],
                        [  4113,   5091],
                        [  4230,   5173],
                        [  4249,   5154],
                        [  4173,   5037],
                        [  4006,   4826],
                        [  3755,   4528],
                        [  3426,   4149],
                        [  3024,   3696],
                        [  2560,   3177],
                        [  2039,   2599],
                        [  1471,   1970],
                        [   862,   1299],
                        [   220,    594],
                        [  -447,   -140],
                        [ -1130,   -892],
                        [ -1824,  -1658],
                        [ -2520,  -2427],
                        [ -3213,  -3195],
                        [ -3893,  -3953],
                        [ -4557,  -4696],
                        [ -5201,  -5416],
                        [ -5817,  -6108],
                        [ -6403,  -6758],
                        [ -6953,  -7365],
                        [ -7467,  -7915],
                        [ -7941,  -8409],
                        [ -8372,  -8846],
                        [ -8760,  -9225],
                        [ -9105,  -9560],
                        [ -9405,  -9849],
                        [ -9658, -10102],
                        [ -9867, -10318],
                        [-10032, -10496],
                        [-10153, -10638],
                        [-10233, -10744],
                        [-10272, -10815],
                        [-10272, -10851],
                        [-10238, -10855],
                        [-10168, -10828],
                        [-10069, -10772],
                        [ -9939, -10689],
                        [ -9783, -10580],
                        [ -9601, -10450],
                        [ -9396, -10298],
                        [ -9168, -10128],
                        [ -8922,  -9943],
                        [ -8659,  -9744],
                        [ -8382,  -9531],
                        [ -8098,  -9306],
                        [ -7810,  -9069],
                        [ -7534,  -8824],
                        [ -7272,  -8574],
                        [ -7034,  -8319],
                        [ -6820,  -8062],
                        [ -6629,  -7804],
                        [ -6465,  -7548],
                        [ -6310,  -7296],
                        [ -6165,  -7050],
                        [ -6051,  -6840],
                        [ -5965,  -6666],
                        [ -5944,  -6565],
                        [ -5987,  -6537],
                        [ -6086,  -6575],
                        [ -6243,  -6681],
                        [ -6400,  -6796],
                        [ -6559,  -6923],
                        [ -6670,  -7014],
                        [ -6735,  -7067],
                        [ -6756,  -7086],
                        [ -6731,  -7069],
                        [ -6663,  -7019],
                        [ -6552,  -6934],
                        [ -6404,  -6820],
                        [ -6217,  -6676],
                        [ -6002,  -6505],
                        [ -5754,  -6307],
                        [ -5484,  -6086],
                        [ -5188,  -5841],
                        [ -4871,  -5577],
                        [ -4533,  -5293],
                        [ -4177,  -4991],
                        [ -3803,  -4673],
                        [ -3417,  -4340],
                        [ -3018,  -3990],
                        [ -2610,  -3629],
                        [ -2191,  -3256],
                        [ -1758,  -2871],
                        [ -1311,  -2474],
                        [  -848,  -2066],
                        [  -371,  -1650],
                        [   119,  -1224],
                        [   618,   -788],
                        [  1126,   -346],
                        [  1640,    103],
                        [  2158,    557],
                        [  2677,   1016],
                        [  3196,   1477],
                        [  3710,   1939],
                        [  4219,   2400],
                        [  4720,   2858],
                        [  5207,   3309],
                        [  5681,   3751],
                        [  6138,   4185],
                        [  6574,   4605],
                        [  6983,   5006],
                        [  7371,   5392],
                        [  7729,   5756],
                        [  7992,   6030],
                        [  8088,   6142],
                        [  8000,   6074],
                        [  7727,   5823],
                        [  7238,   5358],
                        [  6502,   4643],
                        [  5567,   3732],
                        [  4568,   2757],
                        [  3560,   1773],
                        [  2537,    782],
                        [  1515,   -205],
                        [   505,  -1168],
                        [  -481,  -2100],
                        [ -1436,  -2992],
                        [ -2352,  -3837],
                        [ -3220,  -4628],
                        [ -4037,  -5361],
                        [ -4798,  -6034],
                        [ -5500,  -6642],
                        [ -6139,  -7185],
                        [ -6717,  -7662],
                        [ -7230,  -8070],
                        [ -7681,  -8413],
                        [ -8070,  -8691],
                        [ -8398,  -8907],
                        [ -8667,  -9063],
                        [ -8879,  -9162],
                        [ -9036,  -9206],
                        [ -9141,  -9197],
                        [ -9195,  -9139],
                        [ -9202,  -9034],
                        [ -9163,  -8887],
                        [ -9083,  -8699],
                        [ -8963,  -8475],
                        [ -8806,  -8217],
                        [ -8616,  -7929],
                        [ -8395,  -7615],
                        [ -8145,  -7282],
                        [ -7868,  -6935],
                        [ -7569,  -6585],
                        [ -7247,  -6234],
                        [ -6906,  -5888],
                        [ -6547,  -5547],
                        [ -6174,  -5207],
                        [ -5787,  -4869],
                        [ -5392,  -4519],
                        [ -4987,  -4160],
                        [ -4577,  -3790],
                        [ -4162,  -3412],
                        [ -3747,  -3027],
                        [ -3332,  -2638],
                        [ -2922,  -2248],
                        [ -2516,  -1857],
                        [ -2118,  -1468],
                        [ -1731,  -1081],
                        [ -1356,   -700],
                        [  -995,   -325],
                        [  -654,     38],
                        [  -332,    388],
                        [   -33,    722],
                        [   240,   1037],
                        [   484,   1329],
                        [   699,   1600],
                        [   885,   1840],
                        [  1039,   2052],
                        [  1173,   2231],
                        [  1285,   2377],
                        [  1387,   2491],
                        [  1477,   2572],
                        [  1558,   2617],
                        [  1629,   2628],
                        [  1681,   2606],
                        [  1716,   2551],
                        [  1731,   2480],
                        [  1725,   2390],
                        [  1748,   2337],
                        [  1798,   2317],
                        [  1890,   2348],
                        [  2024,   2430],
                        [  2178,   2542],
                        [  2355,   2683],
                        [  2475,   2777],
                        [  2544,   2830],
                        [  2549,   2826],
                        [  2490,   2767],
                        [  2374,   2656],
                        [  2199,   2497],
                        [  1977,   2294],
                        [  1706,   2049],
                        [  1400,   1771],
                        [  1058,   1461],
                        [   693,   1125],
                        [   306,    767],
                        [   -94,    394],
                        [  -506,      7],
                        [  -922,   -388],
                        [ -1341,   -788],
                        [ -1755,  -1188],
                        [ -2162,  -1587],
                        [ -2553,  -1978],
                        [ -2930,  -2364],
                        [ -3292,  -2740],
                        [ -3640,  -3105],
                        [ -3980,  -3458],
                        [ -4312,  -3798],
                        [ -4635,  -4126],
                        [ -4951,  -4441],
                        [ -5257,  -4745],
                        [ -5553,  -5036],
                        [ -5841,  -5316],
                        [ -6120,  -5587],
                        [ -6392,  -5849],
                        [ -6656,  -6102],
                        [ -6913,  -6348],
                        [ -7164,  -6589],
                        [ -7410,  -6824],
                        [ -7651,  -7055],
                        [ -7888,  -7282],
                        [ -8123,  -7508],
                        [ -8353,  -7732],
                        [ -8578,  -7950],
                        [ -8805,  -8172],
                        [ -9027,  -8390],
                        [ -9189,  -8548],
                        [ -9246,  -8600],
                        [ -9197,  -8543],
                        [ -9034,  -8371],
                        [ -8731,  -8054],
                        [ -8246,  -7551],
                        [ -7618,  -6900],
                        [ -6952,  -6206],
                        [ -6291,  -5518],
                        [ -5638,  -4834],
                        [ -4999,  -4171],
                        [ -4392,  -3543],
                        [ -3824,  -2962],
                        [ -3303,  -2431],
                        [ -2835,  -1961],
                        [ -2427,  -1556],
                        [ -2083,  -1220],
                        [ -1804,   -954],
                        [ -1591,   -760],
                        [ -1444,   -636],
                        [ -1362,   -584],
                        [ -1342,   -600],
                        [ -1380,   -681],
                        [ -1473,   -823],
                        [ -1614,  -1019],
                        [ -1800,  -1265],
                        [ -2023,  -1555],
                        [ -2278,  -1883],
                        [ -2560,  -2243],
                        [ -2863,  -2627],
                        [ -3181,  -3031],
                        [ -3507,  -3447],
                        [ -3837,  -3869],
                        [ -4164,  -4292],
                        [ -4483,  -4711],
                        [ -4791,  -5120],
                        [ -5081,  -5511],
                        [ -5351,  -5882],
                        [ -5599,  -6216],
                        [ -5821,  -6515],
                        [ -6015,  -6764],
                        [ -6181,  -6966],
                        [ -6316,  -7117],
                        [ -6420,  -7218],
                        [ -6494,  -7282],
                        [ -6537,  -7309],
                        [ -6550,  -7311],
                        [ -6533,  -7287],
                        [ -6489,  -7239],
                        [ -6420,  -7170],
                        [ -6325,  -7080],
                        [ -6207,  -6971],
                        [ -6069,  -6849],
                        [ -5911,  -6714],
                        [ -5739,  -6572],
                        [ -5552,  -6425],
                        [ -5353,  -6274],
                        [ -5144,  -6121],
                        [ -4926,  -5963],
                        [ -4702,  -5804],
                        [ -4472,  -5640],
                        [ -4239,  -5477],
                        [ -4004,  -5313],
                        [ -3768,  -5148],
                        [ -3537,  -4980],
                        [ -3313,  -4811],
                        [ -3111,  -4642],
                        [ -2929,  -4474],
                        [ -2775,  -4309],
                        [ -2645,  -4141],
                        [ -2541,  -3976],
                        [ -2464,  -3814],
                        [ -2399,  -3657],
                        [ -2345,  -3504],
                        [ -2335,  -3399],
                        [ -2367,  -3337],
                        [ -2472,  -3356],
                        [ -2651,  -3456],
                        [ -2899,  -3632],
                        [ -3214,  -3885],
                        [ -3532,  -4150],
                        [ -3855,  -4431],
                        [ -4119,  -4663],
                        [ -4325,  -4849],
                        [ -4471,  -4986],
                        [ -4556,  -5073],
                        [ -4577,  -5107],
                        [ -4532,  -5085],
                        [ -4427,  -5011],
                        [ -4259,  -4883],
                        [ -4037,  -4705],
                        [ -3759,  -4477],
                        [ -3433,  -4202],
                        [ -3058,  -3881],
                        [ -2641,  -3520],
                        [ -2181,  -3118],
                        [ -1688,  -2681],
                        [ -1163,  -2211],
                        [  -618,  -1714],
                        [   -54,  -1188],
                        [   523,   -643],
                        [  1113,    -78],
                        [  1717,    500],
                        [  2333,   1090],
                        [  2962,   1686],
                        [  3601,   2287],
                        [  4244,   2888],
                        [  4886,   3488],
                        [  5524,   4081],
                        [  6153,   4665],
                        [  6769,   5236],
                        [  7368,   5790],
                        [  7944,   6325],
                        [  8496,   6836],
                        [  9017,   7322],
                        [  9506,   7779],
                        [  9958,   8202],
                        [ 10369,   8591],
                        [ 10739,   8942],
                        [ 11061,   9251],
                        [ 11332,   9516],
                        [ 11555,   9739],
                        [ 11721,   9909],
                        [ 11791,   9990],
                        [ 11743,   9956],
                        [ 11581,   9811],
                        [ 11299,   9550],
                        [ 10868,   9140],
                        [ 10242,   8536],
                        [  9439,   7755],
                        [  8538,   6876],
                        [  7573,   5935],
                        [  6549,   4935],
                        [  5480,   3895],
                        [  4384,   2835],
                        [  3277,   1768],
                        [  2169,    706],
                        [  1074,   -338],
                        [     7,  -1352],
                        [ -1027,  -2328],
                        [ -2015,  -3256],
                        [ -2951,  -4129],
                        [ -3827,  -4939],
                        [ -4638,  -5683],
                        [ -5379,  -6354],
                        [ -6047,  -6949],
                        [ -6641,  -7468],
                        [ -7158,  -7907],
                        [ -7599,  -8268],
                        [ -7963,  -8551],
                        [ -8251,  -8757],
                        [ -8464,  -8888],
                        [ -8605,  -8947],
                        [ -8677,  -8938],
                        [ -8681,  -8862],
                        [ -8623,  -8724],
                        [ -8506,  -8530],
                        [ -8334,  -8280],
                        [ -8112,  -7983],
                        [ -7844,  -7642],
                        [ -7535,  -7269],
                        [ -7190,  -6865],
                        [ -6812,  -6449],
                        [ -6407,  -6024],
                        [ -5978,  -5597],
                        [ -5532,  -5172],
                        [ -5071,  -4749],
                        [ -4600,  -4333],
                        [ -4123,  -3912],
                        [ -3644,  -3489],
                        [ -3168,  -3066],
                        [ -2698,  -2643],
                        [ -2238,  -2226],
                        [ -1790,  -1816],
                        [ -1359,  -1415],
                        [  -947,  -1024],
                        [  -557,   -641],
                        [  -190,   -271],
                        [   149,     89],
                        [   460,    436],
                        [   741,    764],
                        [   990,   1072],
                        [  1206,   1352],
                        [  1388,   1606],
                        [  1535,   1828],
                        [  1647,   2020],
                        [  1725,   2178],
                        [  1769,   2303],
                        [  1790,   2391],
                        [  1786,   2444],
                        [  1769,   2464],
                        [  1737,   2452],
                        [  1695,   2406],
                        [  1645,   2327],
                        [  1584,   2223],
                        [  1515,   2092],
                        [  1442,   1958],
                        [  1370,   1818],
                        [  1349,   1732],
                        [  1378,   1697],
                        [  1471,   1727],
                        [  1629,   1827],
                        [  1835,   1979],
                        [  2092,   2187],
                        [  2316,   2368],
                        [  2516,   2530],
                        [  2668,   2652],
                        [  2778,   2737],
                        [  2842,   2784],
                        [  2862,   2793],
                        [  2840,   2766],
                        [  2777,   2702],
                        [  2678,   2606],
                        [  2544,   2477],
                        [  2382,   2321],
                        [  2192,   2138],
                        [  1980,   1933],
                        [  1745,   1706],
                        [  1496,   1463],
                        [  1232,   1203],
                        [   963,    932],
                        [   691,    649],
                        [   420,    360],
                        [   153,     64],
                        [  -115,   -235],
                        [  -383,   -538],
                        [  -659,   -842],
                        [  -943,  -1147],
                        [ -1233,  -1451],
                        [ -1534,  -1756],
                        [ -1839,  -2059],
                        [ -2149,  -2360],
                        [ -2464,  -2660],
                        [ -2783,  -2958],
                        [ -3104,  -3254],
                        [ -3426,  -3547],
                        [ -3751,  -3836],
                        [ -4076,  -4123],
                        [ -4401,  -4405],
                        [ -4723,  -4682],
                        [ -5042,  -4954],
                        [ -5358,  -5220],
                        [ -5666,  -5478],
                        [ -5965,  -5726],
                        [ -6258,  -5967],
                        [ -6535,  -6194],
                        [ -6780,  -6388],
                        [ -6996,  -6553],
                        [ -7191,  -6695],
                        [ -7356,  -6809],
                        [ -7460,  -6859],
                        [ -7450,  -6796],
                        [ -7314,  -6607],
                        [ -7096,  -6335],
                        [ -6818,  -6004],
                        [ -6481,  -5614],
                        [ -6097,  -5181],
                        [ -5679,  -4719],
                        [ -5237,  -4237],
                        [ -4776,  -3746],
                        [ -4308,  -3252],
                        [ -3842,  -2766],
                        [ -3381,  -2291],
                        [ -2934,  -1835],
                        [ -2503,  -1402],
                        [ -2095,   -996],
                        [ -1709,   -620],
                        [ -1349,   -277],
                        [ -1015,     32],
                        [  -707,    306],
                        [  -426,    545],
                        [  -170,    753],
                        [    62,    930],
                        [   271,   1077],
                        [   461,   1199],
                        [   631,   1298],
                        [   787,   1377],
                        [   929,   1439],
                        [  1060,   1486],
                        [  1182,   1523],
                        [  1299,   1552],
                        [  1412,   1575],
                        [  1524,   1597],
                        [  1636,   1619],
                        [  1750,   1654],
                        [  1867,   1703],
                        [  1987,   1772],
                        [  2112,   1861],
                        [  2240,   1976],
                        [  2374,   2115],
                        [  2511,   2268],
                        [  2654,   2437],
                        [  2799,   2609],
                        [  2948,   2785],
                        [  3099,   2964],
                        [  3252,   3143],
                        [  3405,   3321],
                        [  3559,   3495],
                        [  3711,   3660],
                        [  3862,   3816],
                        [  4011,   3957],
                        [  4154,   4080],
                        [  4294,   4186],
                        [  4428,   4275],
                        [  4557,   4352],
                        [  4679,   4415],
                        [  4795,   4474],
                        [  4904,   4523],
                        [  5007,   4565],
                        [  5105,   4601],
                        [  5194,   4634],
                        [  5273,   4665],
                        [  5338,   4693],
                        [  5389,   4719],
                        [  5421,   4745],
                        [  5442,   4775],
                        [  5446,   4807],
                        [  5432,   4839],
                        [  5409,   4871],
                        [  5380,   4903],
                        [  5307,   4894],
                        [  5197,   4847],
                        [  5024,   4735],
                        [  4791,   4561],
                        [  4496,   4318],
                        [  4138,   4009],
                        [  3777,   3689],
                        [  3412,   3356],
                        [  3100,   3068],
                        [  2841,   2823],
                        [  2640,   2629],
                        [  2498,   2485],
                        [  2424,   2399],
                        [  2414,   2369],
                        [  2469,   2398],
                        [  2589,   2485],
                        [  2771,   2628],
                        [  3011,   2829],
                        [  3307,   3080],
                        [  3657,   3385],
                        [  4052,   3733],
                        [  4493,   4128],
                        [  4966,   4558],
                        [  5470,   5025],
                        [  5990,   5518],
                        [  6524,   6038],
                        [  7066,   6574],
                        [  7613,   7126],
                        [  8167,   7685],
                        [  8724,   8249],
                        [  9284,   8809],
                        [  9844,   9364],
                        [ 10394,   9907],
                        [ 10932,  10434],
                        [ 11451,  10940],
                        [ 11948,  11421],
                        [ 12417,  11874],
                        [ 12853,  12294],
                        [ 13254,  12677],
                        [ 13614,  13020],
                        [ 13932,  13319],
                        [ 14203,  13574],
                        [ 14424,  13780],
                        [ 14595,  13936],
                        [ 14710,  14039],
                        [ 14770,  14089],
                        [ 14772,  14084],
                        [ 14717,  14024],
                        [ 14603,  13908],
                        [ 14441,  13746],
                        [ 14256,  13564],
                        [ 14063,  13375],
                        [ 13856,  13175],
                        [ 13607,  12935],
                        [ 13267,  12604],
                        [ 12794,  12143],
                        [ 12209,  11568],
                        [ 11526,  10895],
                        [ 10757,  10136],
                        [  9916,   9304],
                        [  9020,   8419],
                        [  8083,   7494],
                        [  7117,   6541],
                        [  6137,   5575],
                        [  5157,   4611],
                        [  4188,   3658],
                        [  3244,   2728],
                        [  2330,   1830],
                        [  1460,    974],
                        [   639,    170],
                        [  -125,   -577],
                        [  -829,  -1260],
                        [ -1465,  -1874],
                        [ -2033,  -2417],
                        [ -2529,  -2885],
                        [ -2953,  -3280],
                        [ -3304,  -3599],
                        [ -3583,  -3845],
                        [ -3792,  -4019],
                        [ -3933,  -4124],
                        [ -4007,  -4164],
                        [ -4020,  -4141],
                        [ -3976,  -4060],
                        [ -3878,  -3924],
                        [ -3733,  -3740],
                        [ -3543,  -3511],
                        [ -3316,  -3248],
                        [ -3055,  -2954],
                        [ -2767,  -2645],
                        [ -2456,  -2322],
                        [ -2128,  -1996],
                        [ -1787,  -1668],
                        [ -1439,  -1349],
                        [ -1087,  -1040],
                        [  -737,   -735],
                        [  -392,   -438],
                        [   -57,   -150],
                        [   265,    128],
                        [   570,    392],
                        [   857,    641],
                        [  1122,    876],
                        [  1362,   1094],
                        [  1576,   1301],
                        [  1762,   1495],
                        [  1921,   1679],
                        [  2050,   1850],
                        [  2152,   2005],
                        [  2225,   2145],
                        [  2270,   2260],
                        [  2289,   2353],
                        [  2282,   2420],
                        [  2249,   2461],
                        [  2192,   2479],
                        [  2113,   2474],
                        [  2017,   2444],
                        [  1906,   2391],
                        [  1786,   2321],
                        [  1656,   2230],
                        [  1523,   2120],
                        [  1390,   1994],
                        [  1263,   1857],
                        [  1143,   1713],
                        [  1043,   1579],
                        [   964,   1458],
                        [   946,   1392],
                        [   986,   1378],
                        [  1094,   1432],
                        [  1274,   1554],
                        [  1518,   1740],
                        [  1827,   1991],
                        [  2131,   2241],
                        [  2437,   2494],
                        [  2724,   2732],
                        [  2993,   2958],
                        [  3235,   3160],
                        [  3451,   3340],
                        [  3634,   3494],
                        [  3787,   3620],
                        [  3906,   3716],
                        [  3992,   3783],
                        [  4044,   3818],
                        [  4063,   3823],
                        [  4049,   3798],
                        [  4001,   3742],
                        [  3926,   3658],
                        [  3822,   3545],
                        [  3699,   3405],
                        [  3555,   3239],
                        [  3396,   3051],
                        [  3221,   2837],
                        [  3028,   2605],
                        [  2815,   2351],
                        [  2577,   2081],
                        [  2313,   1793],
                        [  2026,   1493],
                        [  1715,   1177],
                        [  1385,    852],
                        [  1037,    515],
                        [   673,    172],
                        [   295,   -176],
                        [   -93,   -528],
                        [  -491,   -882],
                        [  -893,  -1234],
                        [ -1299,  -1584],
                        [ -1705,  -1928],
                        [ -2108,  -2264],
                        [ -2503,  -2591],
                        [ -2890,  -2905],
                        [ -3263,  -3203],
                        [ -3621,  -3483],
                        [ -3956,  -3742],
                        [ -4275,  -3982],
                        [ -4612,  -4241],
                        [ -5004,  -4557],
                        [ -5461,  -4940],
                        [ -5975,  -5383],
                        [ -6520,  -5860],
                        [ -7032,  -6309],
                        [ -7439,  -6656],
                        [ -7724,  -6885],
                        [ -7893,  -7001],
                        [ -7953,  -7009],
                        [ -7911,  -6918],
                        [ -7776,  -6739],
                        [ -7558,  -6478],
                        [ -7262,  -6146],
                        [ -6899,  -5750],
                        [ -6481,  -5302],
                        [ -6012,  -4808],
                        [ -5502,  -4278],
                        [ -4960,  -3717],
                        [ -4392,  -3135],
                        [ -3804,  -2540],
                        [ -3202,  -1935],
                        [ -2594,  -1331],
                        [ -1984,   -731],
                        [ -1376,   -139],
                        [  -774,    441],
                        [  -183,   1006],
                        [   397,   1553],
                        [   962,   2081],
                        [  1510,   2589],
                        [  2040,   3075],
                        [  2550,   3540],
                        [  3039,   3982],
                        [  3507,   4402],
                        [  3953,   4799],
                        [  4377,   5172],
                        [  4778,   5523],
                        [  5158,   5853],
                        [  5514,   6166],
                        [  5850,   6463],
                        [  6163,   6745],
                        [  6453,   7014],
                        [  6722,   7274],
                        [  6969,   7526],
                        [  7195,   7768],
                        [  7399,   8001],
                        [  7582,   8217],
                        [  7745,   8417],
                        [  7889,   8600],
                        [  8013,   8765],
                        [  8119,   8912],
                        [  8208,   9039],
                        [  8279,   9143],
                        [  8336,   9224],
                        [  8378,   9275],
                        [  8405,   9297],
                        [  8418,   9292],
                        [  8418,   9261],
                        [  8405,   9211],
                        [  8380,   9142],
                        [  8345,   9066],
                        [  8301,   8981],
                        [  8253,   8890],
                        [  8199,   8791],
                        [  8144,   8692],
                        [  8087,   8592],
                        [  8032,   8494],
                        [  7979,   8399],
                        [  7929,   8309],
                        [  7885,   8231],
                        [  7838,   8160],
                        [  7788,   8097],
                        [  7736,   8041],
                        [  7682,   7993],
                        [  7603,   7924],
                        [  7499,   7837],
                        [  7361,   7720],
                        [  7191,   7572],
                        [  6975,   7379],
                        [  6716,   7143],
                        [  6449,   6896],
                        [  6169,   6634],
                        [  5921,   6400],
                        [  5700,   6190],
                        [  5515,   6014],
                        [  5368,   5870],
                        [  5265,   5766],
                        [  5205,   5701],
                        [  5191,   5678],
                        [  5221,   5696],
                        [  5295,   5758],
                        [  5411,   5859],
                        [  5566,   5998],
                        [  5758,   6173],
                        [  5982,   6380],
                        [  6234,   6616],
                        [  6502,   6876],
                        [  6784,   7157],
                        [  7069,   7454],
                        [  7355,   7762],
                        [  7636,   8075],
                        [  7910,   8391],
                        [  8178,   8700],
                        [  8437,   9003],
                        [  8686,   9291],
                        [  8925,   9562],
                        [  9141,   9811],
                        [  9336,  10034],
                        [  9505,  10227],
                        [  9648,  10388],
                        [  9755,  10511],
                        [  9827,  10596],
                        [  9862,  10639],
                        [  9858,  10639],
                        [  9812,  10593],
                        [  9722,  10502],
                        [  9589,  10364],
                        [  9413,  10179],
                        [  9190,   9946],
                        [  8924,   9667],
                        [  8614,   9342],
                        [  8257,   8968],
                        [  7874,   8567],
                        [  7528,   8202],
                        [  7272,   7927],
                        [  7119,   7755],
                        [  7068,   7687],
                        [  7105,   7709],
                        [  7167,   7757],
                        [  7156,   7735],
                        [  7036,   7604],
                        [  6815,   7373],
                        [  6504,   7049],
                        [  6112,   6642],
                        [  5650,   6163],
                        [  5129,   5620],
                        [  4559,   5026],
                        [  3950,   4392],
                        [  3314,   3729],
                        [  2663,   3048],
                        [  2004,   2357],
                        [  1347,   1666],
                        [   701,    986],
                        [    75,    323],
                        [  -527,   -313],
                        [ -1097,   -917],
                        [ -1631,  -1481],
                        [ -2124,  -2002],
                        [ -2574,  -2477],
                        [ -2979,  -2905],
                        [ -3336,  -3283],
                        [ -3646,  -3610],
                        [ -3908,  -3889],
                        [ -4126,  -4119],
                        [ -4299,  -4305],
                        [ -4430,  -4447],
                        [ -4522,  -4548],
                        [ -4577,  -4611],
                        [ -4600,  -4640],
                        [ -4595,  -4638],
                        [ -4565,  -4609],
                        [ -4513,  -4559],
                        [ -4446,  -4492],
                        [ -4366,  -4411],
                        [ -4275,  -4324],
                        [ -4180,  -4235],
                        [ -4083,  -4150],
                        [ -3987,  -4075],
                        [ -3894,  -4009],
                        [ -3809,  -3955],
                        [ -3733,  -3913],
                        [ -3668,  -3885],
                        [ -3616,  -3869],
                        [ -3580,  -3868],
                        [ -3559,  -3878],
                        [ -3555,  -3902],
                        [ -3567,  -3929],
                        [ -3597,  -3963],
                        [ -3642,  -3998],
                        [ -3701,  -4035],
                        [ -3772,  -4074],
                        [ -3854,  -4116],
                        [ -3944,  -4167],
                        [ -4041,  -4225],
                        [ -4145,  -4292],
                        [ -4252,  -4367],
                        [ -4364,  -4447],
                        [ -4480,  -4529],
                        [ -4600,  -4613],
                        [ -4724,  -4700],
                        [ -4849,  -4784],
                        [ -4976,  -4867],
                        [ -5095,  -4949],
                        [ -5207,  -5027],
                        [ -5294,  -5096],
                        [ -5360,  -5156],
                        [ -5393,  -5196],
                        [ -5392,  -5213],
                        [ -5345,  -5194],
                        [ -5253,  -5139],
                        [ -5107,  -5037],
                        [ -4909,  -4889],
                        [ -4648,  -4682],
                        [ -4327,  -4418],
                        [ -3985,  -4133],
                        [ -3619,  -3826],
                        [ -3248,  -3512],
                        [ -2872,  -3192],
                        [ -2506,  -2879],
                        [ -2148,  -2572],
                        [ -1811,  -2283],
                        [ -1494,  -2010],
                        [ -1207,  -1764],
                        [  -951,  -1544],
                        [  -730,  -1355],
                        [  -545,  -1198],
                        [  -400,  -1077],
                        [  -294,   -991],
                        [  -225,   -942],
                        [  -193,   -930],
                        [  -195,   -954],
                        [  -230,  -1016],
                        [  -294,  -1112],
                        [  -388,  -1244],
                        [  -514,  -1407],
                        [  -670,  -1601],
                        [  -863,  -1823],
                        [ -1090,  -2072],
                        [ -1346,  -2342],
                        [ -1632,  -2635],
                        [ -1942,  -2943],
                        [ -2275,  -3266],
                        [ -2625,  -3598],
                        [ -2992,  -3937],
                        [ -3368,  -4280],
                        [ -3752,  -4623],
                        [ -4138,  -4962],
                        [ -4523,  -5293],
                        [ -4903,  -5613],
                        [ -5274,  -5919],
                        [ -5630,  -6205],
                        [ -5968,  -6471],
                        [ -6285,  -6712],
                        [ -6578,  -6927],
                        [ -6836,  -7105],
                        [ -7087,  -7278],
                        [ -7412,  -7525],
                        [ -7864,  -7899],
                        [ -8446,  -8408],
                        [ -9158,  -9050],
                        [ -9986,  -9817],
                        [-10859, -10636],
                        [-11649, -11377],
                        [-12296, -11984],
                        [-12806, -12457],
                        [-13182, -12800],
                        [-13428, -13013],
                        [-13548, -13101],
                        [-13548, -13069],
                        [-13436, -12924],
                        [-13219, -12677],
                        [-12903, -12331],
                        [-12500, -11898],
                        [-12018, -11386],
                        [-11464, -10805],
                        [-10850, -10163],
                        [-10183,  -9469],
                        [ -9471,  -8733],
                        [ -8725,  -7965],
                        [ -7954,  -7174],
                        [ -7163,  -6368],
                        [ -6360,  -5552],
                        [ -5553,  -4734],
                        [ -4748,  -3920],
                        [ -3950,  -3116],
                        [ -3166,  -2325],
                        [ -2398,  -1551],
                        [ -1652,   -800],
                        [  -931,    -72],
                        [  -239,    626],
                        [   421,   1294],
                        [  1048,   1928],
                        [  1639,   2527],
                        [  2194,   3090],
                        [  2711,   3613],
                        [  3189,   4097],
                        [  3628,   4539],
                        [  4029,   4940],
                        [  4392,   5306],
                        [  4716,   5637],
                        [  5003,   5939],
                        [  5254,   6214],
                        [  5471,   6459],
                        [  5653,   6678],
                        [  5805,   6869],
                        [  5926,   7033],
                        [  6019,   7170],
                        [  6087,   7282],
                        [  6133,   7366],
                        [  6156,   7423],
                        [  6160,   7448],
                        [  6147,   7444],
                        [  6117,   7412],
                        [  6071,   7356],
                        [  6012,   7280],
                        [  5939,   7187],
                        [  5858,   7087],
                        [  5769,   6981],
                        [  5677,   6870],
                        [  5584,   6755],
                        [  5497,   6638],
                        [  5419,   6523],
                        [  5357,   6409],
                        [  5311,   6299],
                        [  5283,   6195],
                        [  5273,   6101],
                        [  5267,   6016],
                        [  5268,   5938],
                        [  5265,   5868],
                        [  5260,   5805],
                        [  5249,   5747],
                        [  5233,   5693],
                        [  5212,   5642],
                        [  5188,   5596],
                        [  5138,   5529],
                        [  5064,   5444],
                        [  4963,   5336],
                        [  4834,   5206],
                        [  4698,   5070],
                        [  4552,   4927],
                        [  4405,   4786],
                        [  4258,   4643],
                        [  4115,   4509],
                        [  3979,   4382],
                        [  3854,   4266],
                        [  3738,   4161],
                        [  3635,   4069],
                        [  3543,   3988],
                        [  3463,   3920],
                        [  3392,   3863],
                        [  3328,   3815],
                        [  3270,   3775],
                        [  3209,   3740],
                        [  3145,   3708],
                        [  3074,   3677],
                        [  2993,   3644],
                        [  2899,   3606],
                        [  2789,   3560],
                        [  2667,   3504],
                        [  2533,   3435],
                        [  2385,   3350],
                        [  2221,   3247],
                        [  2039,   3122],
                        [  1840,   2977],
                        [  1620,   2806],
                        [  1380,   2610],
                        [  1120,   2386],
                        [   837,   2135],
                        [   531,   1856],
                        [   205,   1547],
                        [  -145,   1211],
                        [  -514,    846],
                        [  -904,    454],
                        [ -1314,     37],
                        [ -1743,   -406],
                        [ -2186,   -870],
                        [ -2644,  -1354],
                        [ -3123,  -1865],
                        [ -3573,  -2351],
                        [ -3894,  -2713],
                        [ -4037,  -2897],
                        [ -3989,  -2894],
                        [ -3745,  -2693],
                        [ -3304,  -2295],
                        [ -2739,  -1769],
                        [ -2195,  -1259],
                        [ -1736,   -835],
                        [ -1357,   -489],
                        [ -1053,   -221],
                        [  -827,    -33],
                        [  -672,     77],
                        [  -585,    114],
                        [  -561,     82],
                        [  -597,    -13],
                        [  -686,   -165],
                        [  -820,   -366],
                        [  -995,   -613],
                        [ -1205,   -895],
                        [ -1444,  -1209],
                        [ -1705,  -1547],
                        [ -1983,  -1902],
                        [ -2273,  -2269],
                        [ -2570,  -2639],
                        [ -2869,  -3010],
                        [ -3166,  -3377],
                        [ -3460,  -3738],
                        [ -3746,  -4089],
                        [ -4024,  -4429],
                        [ -4292,  -4756],
                        [ -4549,  -5070],
                        [ -4794,  -5370],
                        [ -5027,  -5656],
                        [ -5247,  -5927],
                        [ -5457,  -6186],
                        [ -5656,  -6431],
                        [ -5844,  -6664],
                        [ -6024,  -6882],
                        [ -6196,  -7087],
                        [ -6362,  -7276],
                        [ -6523,  -7450],
                        [ -6679,  -7611],
                        [ -6833,  -7760],
                        [ -6984,  -7908],
                        [ -7135,  -8055],
                        [ -7282,  -8207],
                        [ -7431,  -8365],
                        [ -7580,  -8527],
                        [ -7729,  -8695],
                        [ -7876,  -8866],
                        [ -8025,  -9041],
                        [ -8174,  -9215],
                        [ -8321,  -9389],
                        [ -8465,  -9555],
                        [ -8606,  -9714],
                        [ -8740,  -9860],
                        [ -8867,  -9992],
                        [ -8982, -10110],
                        [ -9085, -10212],
                        [ -9172, -10304],
                        [ -9244, -10385],
                        [ -9299, -10454],
                        [ -9339, -10511],
                        [ -9365, -10551],
                        [ -9378, -10575],
                        [ -9387, -10580],
                        [ -9389, -10567],
                        [ -9388, -10536],
                        [ -9383, -10485],
                        [ -9367, -10418],
                        [ -9338, -10331],
                        [ -9280, -10225],
                        [ -9193, -10099],
                        [ -9081,  -9960],
                        [ -8940,  -9805],
                        [ -8788,  -9650],
                        [ -8625,  -9493],
                        [ -8446,  -9329],
                        [ -8250,  -9158],
                        [ -8012,  -8950],
                        [ -7733,  -8706],
                        [ -7417,  -8431],
                        [ -7065,  -8121],
                        [ -6691,  -7793],
                        [ -6297,  -7446],
                        [ -5898,  -7094],
                        [ -5493,  -6736],
                        [ -5098,  -6385],
                        [ -4713,  -6043],
                        [ -4349,  -5718],
                        [ -4008,  -5413],
                        [ -3697,  -5133],
                        [ -3417,  -4881],
                        [ -3172,  -4661],
                        [ -2962,  -4474],
                        [ -2789,  -4322],
                        [ -2653,  -4205],
                        [ -2553,  -4124],
                        [ -2489,  -4080],
                        [ -2457,  -4069],
                        [ -2457,  -4093],
                        [ -2487,  -4149],
                        [ -2546,  -4234],
                        [ -2637,  -4346],
                        [ -2754,  -4483],
                        [ -2897,  -4639],
                        [ -3061,  -4812],
                        [ -3242,  -4999],
                        [ -3439,  -5195],
                        [ -3647,  -5395],
                        [ -3862,  -5597],
                        [ -4078,  -5796],
                        [ -4295,  -5988],
                        [ -4505,  -6168],
                        [ -4706,  -6333],
                        [ -4894,  -6481],
                        [ -5065,  -6608],
                        [ -5215,  -6709],
                        [ -5342,  -6784],
                        [ -5445,  -6829],
                        [ -5517,  -6843],
                        [ -5549,  -6814],
                        [ -5603,  -6806],
                        [ -5774,  -6915],
                        [ -6107,  -7187],
                        [ -6604,  -7627],
                        [ -7276,  -8245],
                        [ -8128,  -9051],
                        [ -9084,  -9969],
                        [ -9985, -10839],
                        [-10761, -11593],
                        [-11419, -12231],
                        [-11955, -12752],
                        [-12370, -13150],
                        [-12660, -13420],
                        [-12832, -13569],
                        [-12887, -13596],
                        [-12829, -13509],
                        [-12666, -13313],
                        [-12404, -13015],
                        [-12050, -12621],
                        [-11614, -12141],
                        [-11103, -11584],
                        [-10526, -10959],
                        [ -9892, -10277],
                        [ -9214,  -9546],
                        [ -8497,  -8779],
                        [ -7754,  -7983],
                        [ -6990,  -7166],
                        [ -6216,  -6338],
                        [ -5437,  -5506],
                        [ -4663,  -4675],
                        [ -3898,  -3855],
                        [ -3149,  -3049],
                        [ -2422,  -2262],
                        [ -1721,  -1500],
                        [ -1049,   -766],
                        [  -411,    -65],
                        [   190,    601],
                        [   753,   1228],
                        [  1277,   1814],
                        [  1760,   2349],
                        [  2202,   2836],
                        [  2603,   3269],
                        [  2964,   3649],
                        [  3286,   3981],
                        [  3569,   4266],
                        [  3816,   4518],
                        [  4028,   4736],
                        [  4208,   4928],
                        [  4358,   5095],
                        [  4480,   5239],
                        [  4578,   5362],
                        [  4653,   5464],
                        [  4710,   5549],
                        [  4750,   5616],
                        [  4775,   5667],
                        [  4788,   5700],
                        [  4791,   5718],
                        [  4784,   5721],
                        [  4769,   5713],
                        [  4745,   5695],
                        [  4717,   5670],
                        [  4685,   5646],
                        [  4652,   5623],
                        [  4622,   5601],
                        [  4598,   5579],
                        [  4590,   5558],
                        [  4598,   5540],
                        [  4632,   5523],
                        [  4692,   5510],
                        [  4773,   5499],
                        [  4878,   5492],
                        [  4987,   5488],
                        [  5103,   5488],
                        [  5211,   5492],
                        [  5314,   5501],
                        [  5432,   5536],
                        [  5562,   5597],
                        [  5714,   5689],
                        [  5886,   5813],
                        [  6048,   5939],
                        [  6203,   6067],
                        [  6307,   6155],
                        [  6363,   6204],
                        [  6371,   6213],
                        [  6328,   6180],
                        [  6242,   6112],
                        [  6112,   6005],
                        [  5948,   5870],
                        [  5747,   5702],
                        [  5519,   5511],
                        [  5260,   5293],
                        [  4981,   5055],
                        [  4677,   4797],
                        [  4355,   4522],
                        [  4012,   4230],
                        [  3652,   3924],
                        [  3275,   3602],
                        [  2883,   3268],
                        [  2477,   2921],
                        [  2056,   2563],
                        [  1620,   2192],
                        [  1169,   1812],
                        [   702,   1420],
                        [   223,   1018],
                        [  -267,    607],
                        [  -765,    185],
                        [ -1272,   -245],
                        [ -1785,   -685],
                        [ -2303,  -1133],
                        [ -2823,  -1588],
                        [ -3346,  -2052],
                        [ -3869,  -2522],
                        [ -4390,  -2997],
                        [ -4908,  -3477],
                        [ -5421,  -3960],
                        [ -5929,  -4445],
                        [ -6427,  -4929],
                        [ -6915,  -5411],
                        [ -7391,  -5891],
                        [ -7854,  -6364],
                        [ -8297,  -6827],
                        [ -8727,  -7282],
                        [ -9141,  -7730],
                        [ -9471,  -8099],
                        [ -9618,  -8292],
                        [ -9547,  -8270],
                        [ -9251,  -8026],
                        [ -8717,  -7543],
                        [ -7924,  -6801],
                        [ -6955,  -5877],
                        [ -5962,  -4925],
                        [ -5018,  -4019],
                        [ -4118,  -3154],
                        [ -3267,  -2341],
                        [ -2477,  -1588],
                        [ -1748,   -906],
                        [ -1085,   -294],
                        [  -489,    245],
                        [    36,    707],
                        [   489,   1094],
                        [   873,   1406],
                        [  1189,   1647],
                        [  1438,   1818],
                        [  1623,   1923],
                        [  1748,   1965],
                        [  1814,   1949],
                        [  1829,   1880],
                        [  1794,   1762],
                        [  1714,   1600],
                        [  1594,   1398],
                        [  1437,   1160],
                        [  1247,    891],
                        [  1028,    592],
                        [   782,    269],
                        [   514,    -76],
                        [   228,   -437],
                        [   -76,   -816],
                        [  -392,  -1206],
                        [  -718,  -1606],
                        [ -1052,  -2011],
                        [ -1391,  -2421],
                        [ -1733,  -2826],
                        [ -2076,  -3225],
                        [ -2418,  -3608],
                        [ -2758,  -3972],
                        [ -3092,  -4314],
                        [ -3421,  -4635],
                        [ -3742,  -4942],
                        [ -4053,  -5233],
                        [ -4353,  -5518],
                        [ -4641,  -5795],
                        [ -4914,  -6065],
                        [ -5172,  -6326],
                        [ -5414,  -6576],
                        [ -5637,  -6814],
                        [ -5841,  -7039],
                        [ -6026,  -7249],
                        [ -6187,  -7439],
                        [ -6326,  -7609],
                        [ -6438,  -7755],
                        [ -6524,  -7878],
                        [ -6579,  -7973],
                        [ -6604,  -8042],
                        [ -6598,  -8087],
                        [ -6561,  -8106],
                        [ -6495,  -8101],
                        [ -6402,  -8072],
                        [ -6289,  -8015],
                        [ -6157,  -7930],
                        [ -6019,  -7817],
                        [ -5877,  -7677],
                        [ -5733,  -7513],
                        [ -5588,  -7323],
                        [ -5435,  -7110],
                        [ -5276,  -6877],
                        [ -5094,  -6625],
                        [ -4890,  -6356],
                        [ -4687,  -6095],
                        [ -4481,  -5841],
                        [ -4309,  -5631],
                        [ -4170,  -5462],
                        [ -4060,  -5330],
                        [ -3980,  -5237],
                        [ -3885,  -5137],
                        [ -3778,  -5031],
                        [ -3629,  -4888],
                        [ -3439,  -4713],
                        [ -3222,  -4512],
                        [ -2975,  -4287],
                        [ -2711,  -4046],
                        [ -2430,  -3791],
                        [ -2147,  -3532],
                        [ -1857,  -3268],
                        [ -1576,  -3009],
                        [ -1302,  -2754],
                        [ -1042,  -2513],
                        [  -797,  -2285],
                        [  -570,  -2074],
                        [  -362,  -1881],
                        [  -179,  -1709],
                        [   -18,  -1557],
                        [   118,  -1426],
                        [   229,  -1317],
                        [   320,  -1229],
                        [   392,  -1159],
                        [   449,  -1107],
                        [   494,  -1073],
                        [   527,  -1050],
                        [   550,  -1039],
                        [   566,  -1036],
                        [   577,  -1038],
                        [   586,  -1041],
                        [   594,  -1044],
                        [   605,  -1041],
                        [   622,  -1030],
                        [   646,  -1008],
                        [   681,   -973],
                        [   730,   -919],
                        [   795,   -847],
                        [   877,   -756],
                        [   975,   -642],
                        [  1097,   -502],
                        [  1238,   -339],
                        [  1399,   -154],
                        [  1586,     62],
                        [  1798,    304],
                        [  1961,    501],
                        [  1993,    567],
                        [  1867,    478],
                        [  1581,    226],
                        [  1112,   -212],
                        [   433,   -864],
                        [  -384,  -1659],
                        [ -1189,  -2450],
                        [ -1923,  -3176],
                        [ -2593,  -3841],
                        [ -3189,  -4434],
                        [ -3705,  -4943],
                        [ -4135,  -5363],
                        [ -4481,  -5692],
                        [ -4740,  -5927],
                        [ -4912,  -6069],
                        [ -4997,  -6117],
                        [ -4999,  -6078],
                        [ -4924,  -5954],
                        [ -4773,  -5751],
                        [ -4554,  -5474],
                        [ -4272,  -5129],
                        [ -3935,  -4723],
                        [ -3549,  -4266],
                        [ -3122,  -3763],
                        [ -2660,  -3222],
                        [ -2171,  -2651],
                        [ -1662,  -2057],
                        [ -1140,  -1446],
                        [  -609,   -825],
                        [   -76,   -198],
                        [   454,    427],
                        [   977,   1047],
                        [  1488,   1656],
                        [  1983,   2251],
                        [  2459,   2828],
                        [  2914,   3385],
                        [  3346,   3915],
                        [  3752,   4419],
                        [  4132,   4882],
                        [  4487,   5307],
                        [  4816,   5685],
                        [  5119,   6017],
                        [  5397,   6307],
                        [  5653,   6554],
                        [  5885,   6776],
                        [  6096,   6972],
                        [  6288,   7152],
                        [  6463,   7316],
                        [  6622,   7469],
                        [  6767,   7611],
                        [  6901,   7744],
                        [  7024,   7871],
                        [  7139,   7992],
                        [  7248,   8108],
                        [  7348,   8221],
                        [  7444,   8331],
                        [  7533,   8438],
                        [  7616,   8543],
                        [  7694,   8646],
                        [  7765,   8747],
                        [  7833,   8847],
                        [  7898,   8948],
                        [  7963,   9046],
                        [  8030,   9141],
                        [  8110,   9232],
                        [  8203,   9315],
                        [  8314,   9391],
                        [  8444,   9458],
                        [  8587,   9517],
                        [  8741,   9564],
                        [  8889,   9601],
                        [  9030,   9626],
                        [  9159,   9648],
                        [  9274,   9666],
                        [  9419,   9722],
                        [  9588,   9816],
                        [  9792,   9956],
                        [ 10031,  10144],
                        [ 10273,  10347],
                        [ 10519,  10567],
                        [ 10697,  10731],
                        [ 10809,  10842],
                        [ 10845,  10888],
                        [ 10803,  10866],
                        [ 10689,  10782],
                        [ 10502,  10634],
                        [ 10251,  10428],
                        [  9935,  10164],
                        [  9565,   9848],
                        [  9138,   9481],
                        [  8666,   9071],
                        [  8148,   8617],
                        [  7590,   8126],
                        [  6994,   7601],
                        [  6370,   7047],
                        [  5718,   6465],
                        [  5050,   5863],
                        [  4365,   5241],
                        [  3670,   4604],
                        [  2966,   3954],
                        [  2251,   3297],
                        [  1530,   2635],
                        [   804,   1971],
                        [    74,   1307],
                        [  -651,    647],
                        [ -1370,     -7],
                        [ -2078,   -651],
                        [ -2774,  -1284],
                        [ -3452,  -1904],
                        [ -4110,  -2508],
                        [ -4745,  -3095],
                        [ -5355,  -3662],
                        [ -5936,  -4206],
                        [ -6488,  -4728],
                        [ -7007,  -5224],
                        [ -7490,  -5692],
                        [ -7937,  -6130],
                        [ -8345,  -6539],
                        [ -8713,  -6915],
                        [ -9036,  -7253],
                        [ -9323,  -7562],
                        [ -9564,  -7831],
                        [ -9693,  -7994],
                        [ -9641,  -7984],
                        [ -9399,  -7785],
                        [ -8961,  -7394],
                        [ -8302,  -6782],
                        [ -7391,  -5917],
                        [ -6295,  -4861],
                        [ -5146,  -3748],
                        [ -3998,  -2633],
                        [ -2850,  -1514],
                        [ -1718,   -411],
                        [  -621,    659],
                        [   436,   1682],
                        [  1445,   2652],
                        [  2394,   3558],
                        [  3276,   4392],
                        [  4087,   5150],
                        [  4821,   5829],
                        [  5475,   6424],
                        [  6049,   6936],
                        [  6541,   7364],
                        [  6952,   7707],
                        [  7281,   7969],
                        [  7534,   8152],
                        [  7711,   8257],
                        [  7816,   8290],
                        [  7855,   8253],
                        [  7830,   8153],
                        [  7747,   7993],
                        [  7610,   7776],
                        [  7424,   7511],
                        [  7193,   7200],
                        [  6923,   6850],
                        [  6619,   6466],
                        [  6289,   6052],
                        [  5935,   5614],
                        [  5564,   5159],
                        [  5180,   4690],
                        [  4787,   4219],
                        [  4391,   3751],
                        [  3994,   3300],
                        [  3602,   2871],
                        [  3217,   2468],
                        [  2843,   2096],
                        [  2484,   1751],
                        [  2141,   1433],
                        [  1818,   1133],
                        [  1517,    854],
                        [  1241,    593],
                        [   990,    352],
                        [   769,    132],
                        [   576,    -67],
                        [   413,   -243],
                        [   280,   -396],
                        [   180,   -526],
                        [   111,   -633],
                        [    76,   -716],
                        [    76,   -775],
                        [   108,   -808],
                        [   175,   -817],
                        [   274,   -800],
                        [   404,   -756],
                        [   559,   -690],
                        [   740,   -600],
                        [   934,   -483],
                        [  1141,   -345],
                        [  1344,   -182],
                        [  1542,      3],
                        [  1732,    206],
                        [  1914,    427],
                        [  2092,    665],
                        [  2264,    914],
                        [  2441,   1170],
                        [  2622,   1431],
                        [  2771,   1655],
                        [  2888,   1844],
                        [  2932,   1954],
                        [  2905,   1988],
                        [  2810,   1947],
                        [  2643,   1828],
                        [  2468,   1693],
                        [  2280,   1538],
                        [  2130,   1415],
                        [  2017,   1320],
                        [  1937,   1253],
                        [  1889,   1211],
                        [  1869,   1195],
                        [  1876,   1203],
                        [  1904,   1229],
                        [  1953,   1276],
                        [  2017,   1337],
                        [  2095,   1413],
                        [  2185,   1497],
                        [  2286,   1593],
                        [  2394,   1694],
                        [  2509,   1802],
                        [  2623,   1914],
                        [  2737,   2031],
                        [  2849,   2152],
                        [  2959,   2276],
                        [  3071,   2403],
                        [  3187,   2535],
                        [  3313,   2670],
                        [  3452,   2811],
                        [  3603,   2958],
                        [  3767,   3111],
                        [  3944,   3273],
                        [  4134,   3443],
                        [  4338,   3625],
                        [  4557,   3819],
                        [  4790,   4026],
                        [  5037,   4246],
                        [  5298,   4481],
                        [  5575,   4731],
                        [  5866,   4996],
                        [  6171,   5276],
                        [  6487,   5571],
                        [  6814,   5878],
                        [  7152,   6199],
                        [  7497,   6530],
                        [  7846,   6868],
                        [  8204,   7218],
                        [  8558,   7569],
                        [  8851,   7862],
                        [  9036,   8050],
                        [  9107,   8127],
                        [  9057,   8085],
                        [  8852,   7889],
                        [  8454,   7498],
                        [  7906,   6954],
                        [  7314,   6364],
                        [  6716,   5763],
                        [  6110,   5154],
                        [  5510,   4550],
                        [  4926,   3966],
                        [  4367,   3412],
                        [  3837,   2893],
                        [  3343,   2417],
                        [  2892,   1991],
                        [  2485,   1617],
                        [  2127,   1297],
                        [  1818,   1032],
                        [  1558,    822],
                        [  1349,    667],
                        [  1187,    565],
                        [  1072,    514],
                        [   999,    510],
                        [   968,    553],
                        [   974,    637],
                        [  1015,    760],
                        [  1086,    917],
                        [  1183,   1103],
                        [  1306,   1317],
                        [  1448,   1554],
                        [  1607,   1809],
                        [  1781,   2079],
                        [  1965,   2361],
                        [  2159,   2653],
                        [  2358,   2950],
                        [  2559,   3252],
                        [  2764,   3551],
                        [  2968,   3847],
                        [  3172,   4129],
                        [  3374,   4395],
                        [  3574,   4636],
                        [  3772,   4853],
                        [  3967,   5046],
                        [  4158,   5213],
                        [  4347,   5369],
                        [  4533,   5512],
                        [  4716,   5653],
                        [  4895,   5791],
                        [  5072,   5929],
                        [  5246,   6068],
                        [  5417,   6208],
                        [  5586,   6349],
                        [  5751,   6494],
                        [  5913,   6643],
                        [  6069,   6797],
                        [  6222,   6957],
                        [  6367,   7120],
                        [  6504,   7287],
                        [  6632,   7452],
                        [  6749,   7615],
                        [  6855,   7771],
                        [  6949,   7920],
                        [  7037,   8059],
                        [  7116,   8187],
                        [  7196,   8297],
                        [  7275,   8390],
                        [  7359,   8462],
                        [  7444,   8513],
                        [  7525,   8539],
                        [  7599,   8539],
                        [  7655,   8515],
                        [  7692,   8465],
                        [  7713,   8405],
                        [  7719,   8333],
                        [  7760,   8305],
                        [  7833,   8314],
                        [  7947,   8375],
                        [  8101,   8487],
                        [  8271,   8624],
                        [  8457,   8787],
                        [  8572,   8892],
                        [  8623,   8944],
                        [  8592,   8925],
                        [  8482,   8836],
                        [  8292,   8678],
                        [  8023,   8448],
                        [  7685,   8153],
                        [  7275,   7794],
                        [  6803,   7374],
                        [  6271,   6897],
                        [  5686,   6372],
                        [  5051,   5796],
                        [  4375,   5183],
                        [  3658,   4531],
                        [  2917,   3851],
                        [  2153,   3145],
                        [  1382,   2422],
                        [   605,   1683],
                        [  -172,    938],
                        [  -947,    187],
                        [ -1718,   -561],
                        [ -2485,  -1303],
                        [ -3245,  -2033],
                        [ -3996,  -2747],
                        [ -4728,  -3443],
                        [ -5441,  -4115],
                        [ -6127,  -4761],
                        [ -6785,  -5378],
                        [ -7411,  -5963],
                        [ -8002,  -6514],
                        [ -8554,  -7028],
                        [ -9066,  -7504],
                        [ -9534,  -7940],
                        [ -9959,  -8335],
                        [-10337,  -8688],
                        [-10666,  -8996],
                        [-10947,  -9260],
                        [-11178,  -9480],
                        [-11360,  -9655],
                        [-11489,  -9780],
                        [-11572,  -9866],
                        [-11599,  -9900],
                        [-11533,  -9843],
                        [-11353,  -9680],
                        [-11067,  -9413],
                        [-10669,  -9037],
                        [-10131,  -8521],
                        [ -9410,  -7821],
                        [ -8532,  -6962],
                        [ -7579,  -6025],
                        [ -6584,  -5042],
                        [ -5550,  -4019],
                        [ -4499,  -2975],
                        [ -3447,  -1931],
                        [ -2406,   -900],
                        [ -1387,    106],
                        [  -403,   1072],
                        [   535,   1990],
                        [  1420,   2849],
                        [  2243,   3645],
                        [  2999,   4370],
                        [  3682,   5021],
                        [  4291,   5594],
                        [  4821,   6087],
                        [  5276,   6501],
                        [  5652,   6833],
                        [  5952,   7086],
                        [  6177,   7261],
                        [  6334,   7362],
                        [  6423,   7392],
                        [  6449,   7356],
                        [  6416,   7259],
                        [  6331,   7105],
                        [  6198,   6901],
                        [  6022,   6652],
                        [  5811,   6365],
                        [  5570,   6046],
                        [  5303,   5699],
                        [  5019,   5332],
                        [  4721,   4950],
                        [  4416,   4565],
                        [  4107,   4181],
                        [  3800,   3814],
                        [  3499,   3466],
                        [  3208,   3148],
                        [  2929,   2861],
                        [  2667,   2605],
                        [  2424,   2381],
                        [  2203,   2182],
                        [  2006,   2009],
                        [  1834,   1857],
                        [  1689,   1727],
                        [  1571,   1620],
                        [  1482,   1536],
                        [  1420,   1473],
                        [  1386,   1431],
                        [  1380,   1404],
                        [  1399,   1391],
                        [  1444,   1391],
                        [  1514,   1402],
                        [  1606,   1424],
                        [  1720,   1458],
                        [  1853,   1506],
                        [  2005,   1567],
                        [  2169,   1641],
                        [  2344,   1726],
                        [  2516,   1820],
                        [  2687,   1923],
                        [  2843,   2035],
                        [  2983,   2154],
                        [  3104,   2277],
                        [  3205,   2406],
                        [  3291,   2534],
                        [  3356,   2661],
                        [  3407,   2779],
                        [  3444,   2888],
                        [  3422,   2940],
                        [  3343,   2936],
                        [  3177,   2842],
                        [  2923,   2659],
                        [  2581,   2383],
                        [  2148,   2014],
                        [  1693,   1615],
                        [  1211,   1183],
                        [   760,    776],
                        [   339,    392],
                        [   -49,     34],
                        [  -401,   -295],
                        [  -717,   -592],
                        [  -993,   -853],
                        [ -1232,  -1081],
                        [ -1432,  -1272],
                        [ -1594,  -1429],
                        [ -1716,  -1549],
                        [ -1801,  -1635],
                        [ -1847,  -1684],
                        [ -1858,  -1701],
                        [ -1835,  -1684],
                        [ -1786,  -1635],
                        [ -1712,  -1554],
                        [ -1616,  -1444],
                        [ -1496,  -1302],
                        [ -1350,  -1135],
                        [ -1177,   -940],
                        [  -969,   -720],
                        [  -727,   -474],
                        [  -454,   -205],
                        [  -151,     85],
                        [   179,    396],
                        [   536,    726],
                        [   916,   1073],
                        [  1316,   1435],
                        [  1735,   1812],
                        [  2169,   2201],
                        [  2615,   2600],
                        [  3071,   3005],
                        [  3534,   3417],
                        [  3998,   3829],
                        [  4461,   4241],
                        [  4919,   4650],
                        [  5370,   5053],
                        [  5807,   5444],
                        [  6227,   5821],
                        [  6629,   6183],
                        [  7002,   6521],
                        [  7327,   6814],
                        [  7604,   7065],
                        [  7838,   7278],
                        [  8021,   7442],
                        [  8117,   7523],
                        [  8075,   7468],
                        [  7889,   7269],
                        [  7603,   6973],
                        [  7238,   6598],
                        [  6797,   6147],
                        [  6294,   5635],
                        [  5744,   5077],
                        [  5155,   4486],
                        [  4536,   3869],
                        [  3899,   3239],
                        [  3254,   2607],
                        [  2609,   1978],
                        [  1971,   1362],
                        [  1347,    763],
                        [   743,    189],
                        [   164,   -359],
                        [  -387,   -874],
                        [  -904,  -1355],
                        [ -1387,  -1796],
                        [ -1833,  -2198],
                        [ -2241,  -2556],
                        [ -2610,  -2872],
                        [ -2939,  -3146],
                        [ -3229,  -3378],
                        [ -3480,  -3569],
                        [ -3693,  -3720],
                        [ -3868,  -3832],
                        [ -4006,  -3908],
                        [ -4111,  -3950],
                        [ -4184,  -3959],
                        [ -4225,  -3938],
                        [ -4237,  -3888],
                        [ -4223,  -3815],
                        [ -4184,  -3717],
                        [ -4120,  -3609],
                        [ -4035,  -3489],
                        [ -3930,  -3366],
                        [ -3807,  -3244],
                        [ -3668,  -3123],
                        [ -3513,  -3008],
                        [ -3347,  -2890],
                        [ -3169,  -2772],
                        [ -2982,  -2646],
                        [ -2787,  -2514],
                        [ -2587,  -2374],
                        [ -2383,  -2229],
                        [ -2178,  -2077],
                        [ -1971,  -1920],
                        [ -1766,  -1755],
                        [ -1563,  -1584],
                        [ -1366,  -1402],
                        [ -1176,  -1212],
                        [  -995,  -1016],
                        [  -825,   -817],
                        [  -669,   -620],
                        [  -528,   -428],
                        [  -406,   -249],
                        [  -303,    -85],
                        [  -219,     62],
                        [  -151,    189],
                        [   -98,    293],
                        [   -60,    372],
                        [   -34,    423],
                        [   -23,    444],
                        [   -29,    432],
                        [   -54,    388],
                        [  -104,    313],
                        [  -177,    206],
                        [  -262,     89],
                        [  -358,    -42],
                        [  -419,   -137],
                        [  -449,   -199],
                        [  -439,   -215],
                        [  -387,   -187],
                        [  -309,   -125],
                        [  -202,    -30],
                        [  -147,     20],
                        [  -137,     33],
                        [  -189,     -8],
                        [  -299,   -103],
                        [  -471,   -254],
                        [  -704,   -459],
                        [  -994,   -720],
                        [ -1338,  -1033],
                        [ -1734,  -1395],
                        [ -2177,  -1804],
                        [ -2663,  -2255],
                        [ -3189,  -2745],
                        [ -3747,  -3267],
                        [ -4335,  -3818],
                        [ -4935,  -4391],
                        [ -5549,  -4983],
                        [ -6158,  -5585],
                        [ -6765,  -6195],
                        [ -7363,  -6806],
                        [ -7949,  -7414],
                        [ -8525,  -8012],
                        [ -9090,  -8598],
                        [ -9643,  -9165],
                        [-10180,  -9710],
                        [-10694, -10229],
                        [-11185, -10719],
                        [-11646, -11177],
                        [-12077, -11599],
                        [-12473, -11984],
                        [-12833, -12331],
                        [-13154, -12638],
                        [-13435, -12901],
                        [-13674, -13121],
                        [-13872, -13298],
                        [-14025, -13431],
                        [-14134, -13518],
                        [-14199, -13561],
                        [-14220, -13561],
                        [-14196, -13516],
                        [-14128, -13428],
                        [-14017, -13299],
                        [-13862, -13127],
                        [-13675, -12927],
                        [-13481, -12721],
                        [-13294, -12526],
                        [-13107, -12331],
                        [-12894, -12112],
                        [-12602, -11814],
                        [-12197, -11403],
                        [-11697, -10896],
                        [-11118, -10311],
                        [-10468,  -9655],
                        [ -9764,  -8942],
                        [ -9020,  -8189],
                        [ -8249,  -7408],
                        [ -7460,  -6611],
                        [ -6667,  -5812],
                        [ -5880,  -5021],
                        [ -5109,  -4249],
                        [ -4362,  -3502],
                        [ -3647,  -2789],
                        [ -2971,  -2115],
                        [ -2335,  -1486],
                        [ -1747,   -906],
                        [ -1208,   -378],
                        [  -721,     95],
                        [  -286,    512],
                        [    98,    872],
                        [   429,   1176],
                        [   712,   1424],
                        [   947,   1622],
                        [  1139,   1770],
                        [  1289,   1874],
                        [  1402,   1935],
                        [  1482,   1961],
                        [  1532,   1954],
                        [  1558,   1919],
                        [  1562,   1861],
                        [  1550,   1784],
                        [  1527,   1693],
                        [  1495,   1595],
                        [  1458,   1493],
                        [  1419,   1398],
                        [  1381,   1314],
                        [  1347,   1246],
                        [  1320,   1197],
                        [  1300,   1168],
                        [  1290,   1164],
                        [  1292,   1175],
                        [  1306,   1204],
                        [  1333,   1246],
                        [  1373,   1301],
                        [  1426,   1367],
                        [  1492,   1445],
                        [  1568,   1530],
                        [  1655,   1622],
                        [  1749,   1711],
                        [  1852,   1797],
                        [  1957,   1875],
                        [  2066,   1944],
                        [  2177,   2003],
                        [  2286,   2051],
                        [  2395,   2095],
                        [  2502,   2134],
                        [  2601,   2167],
                        [  2693,   2194],
                        [  2769,   2212],
                        [  2832,   2222],
                        [  2872,   2225],
                        [  2891,   2217],
                        [  2884,   2200],
                        [  2855,   2176],
                        [  2801,   2140],
                        [  2719,   2091],
                        [  2611,   2026],
                        [  2478,   1942],
                        [  2282,   1802],
                        [  2027,   1608],
                        [  1697,   1341],
                        [  1292,   1000],
                        [   805,    579],
                        [   239,     76],
                        [  -354,   -457],
                        [  -977,  -1023],
                        [ -1576,  -1571],
                        [ -2153,  -2101],
                        [ -2698,  -2605],
                        [ -3209,  -3081],
                        [ -3676,  -3517],
                        [ -4098,  -3914],
                        [ -4472,  -4266],
                        [ -4795,  -4570],
                        [ -5063,  -4824],
                        [ -5275,  -5025],
                        [ -5430,  -5174],
                        [ -5527,  -5269],
                        [ -5571,  -5313],
                        [ -5562,  -5302],
                        [ -5513,  -5243],
                        [ -5419,  -5133],
                        [ -5284,  -4975],
                        [ -5110,  -4772],
                        [ -4895,  -4526],
                        [ -4639,  -4240],
                        [ -4338,  -3919],
                        [ -3993,  -3562],
                        [ -3612,  -3178],
                        [ -3195,  -2765],
                        [ -2750,  -2332],
                        [ -2277,  -1880],
                        [ -1783,  -1415],
                        [ -1273,   -938],
                        [  -752,   -457],
                        [  -223,     28],
                        [   306,    508],
                        [   833,    982],
                        [  1351,   1444],
                        [  1857,   1892],
                        [  2343,   2319],
                        [  2808,   2723],
                        [  3244,   3098],
                        [  3651,   3443],
                        [  4019,   3753],
                        [  4348,   4024],
                        [  4636,   4260],
                        [  4923,   4497],
                        [  5241,   4771],
                        [  5601,   5091],
                        [  5996,   5449],
                        [  6400,   5821],
                        [  6748,   6141],
                        [  6972,   6342],
                        [  7061,   6410],
                        [  7022,   6356],
                        [  6865,   6186],
                        [  6598,   5907],
                        [  6238,   5536],
                        [  5792,   5080],
                        [  5273,   4552],
                        [  4693,   3963],
                        [  4063,   3328],
                        [  3395,   2655],
                        [  2699,   1956],
                        [  1985,   1239],
                        [  1263,    514],
                        [   541,   -210],
                        [  -172,   -925],
                        [  -870,  -1625],
                        [ -1544,  -2299],
                        [ -2190,  -2945],
                        [ -2802,  -3553],
                        [ -3377,  -4122],
                        [ -3910,  -4648],
                        [ -4400,  -5128],
                        [ -4844,  -5562],
                        [ -5241,  -5948],
                        [ -5591,  -6285],
                        [ -5893,  -6574],
                        [ -6147,  -6817],
                        [ -6356,  -7014],
                        [ -6520,  -7165],
                        [ -6640,  -7274],
                        [ -6719,  -7344],
                        [ -6759,  -7375],
                        [ -6763,  -7375],
                        [ -6733,  -7344],
                        [ -6672,  -7291],
                        [ -6585,  -7217],
                        [ -6472,  -7131],
                        [ -6338,  -7034],
                        [ -6186,  -6928],
                        [ -6021,  -6817],
                        [ -5846,  -6697],
                        [ -5664,  -6573],
                        [ -5479,  -6445],
                        [ -5293,  -6316],
                        [ -5110,  -6186],
                        [ -4933,  -6060],
                        [ -4764,  -5934],
                        [ -4605,  -5809],
                        [ -4459,  -5683],
                        [ -4327,  -5556],
                        [ -4212,  -5431],
                        [ -4115,  -5309],
                        [ -4041,  -5198],
                        [ -3990,  -5099],
                        [ -3966,  -5023],
                        [ -3969,  -4970],
                        [ -4000,  -4941],
                        [ -4058,  -4936],
                        [ -4144,  -4957],
                        [ -4257,  -5006],
                        [ -4393,  -5081],
                        [ -4554,  -5187],
                        [ -4738,  -5324],
                        [ -4941,  -5488],
                        [ -5161,  -5676],
                        [ -5398,  -5890],
                        [ -5634,  -6108],
                        [ -5869,  -6333],
                        [ -6075,  -6533],
                        [ -6254,  -6710],
                        [ -6393,  -6851],
                        [ -6492,  -6953],
                        [ -6548,  -7014],
                        [ -6560,  -7030],
                        [ -6582,  -7055],
                        [ -6609,  -7084],
                        [ -6653,  -7129],
                        [ -6712,  -7187],
                        [ -6794,  -7265],
                        [ -6897,  -7364],
                        [ -7020,  -7483],
                        [ -7164,  -7622],
                        [ -7328,  -7782],
                        [ -7511,  -7962],
                        [ -7711,  -8159],
                        [ -7927,  -8372],
                        [ -8154,  -8598],
                        [ -8391,  -8835],
                        [ -8624,  -9079],
                        [ -8854,  -9328],
                        [ -9073,  -9576],
                        [ -9280,  -9824],
                        [ -9473, -10064],
                        [ -9650, -10298],
                        [ -9817, -10519],
                        [ -9972, -10726],
                        [-10115, -10914],
                        [-10246, -11084],
                        [-10359, -11231],
                        [-10454, -11355],
                        [-10531, -11451],
                        [-10587, -11521],
                        [-10620, -11562],
                        [-10631, -11574],
                        [-10617, -11556],
                        [-10579, -11507],
                        [-10515, -11427],
                        [-10427, -11317],
                        [-10311, -11175],
                        [-10172, -11003],
                        [-10006, -10801],
                        [ -9815, -10570],
                        [ -9600, -10311],
                        [ -9360, -10025],
                        [ -9091,  -9709],
                        [ -8815,  -9385],
                        [ -8595,  -9119],
                        [ -8479,  -8957],
                        [ -8478,  -8912],
                        [ -8591,  -8981],
                        [ -8801,  -9149],
                        [ -9037,  -9345],
                        [ -9203,  -9475],
                        [ -9265,  -9505],
                        [ -9230,  -9440],
                        [ -9102,  -9286],
                        [ -8893,  -9050],
                        [ -8608,  -8739],
                        [ -8259,  -8363],
                        [ -7853,  -7928],
                        [ -7399,  -7447],
                        [ -6906,  -6927],
                        [ -6382,  -6375],
                        [ -5835,  -5801],
                        [ -5272,  -5211],
                        [ -4700,  -4613],
                        [ -4122,  -4012],
                        [ -3547,  -3413],
                        [ -2979,  -2823],
                        [ -2421,  -2247],
                        [ -1878,  -1689],
                        [ -1350,  -1152],
                        [  -843,   -639],
                        [  -355,   -150],
                        [   111,    314],
                        [   557,    753],
                        [   982,   1168],
                        [  1385,   1557],
                        [  1768,   1925],
                        [  2133,   2271],
                        [  2478,   2597],
                        [  2807,   2905],
                        [  3120,   3195],
                        [  3419,   3469],
                        [  3705,   3730],
                        [  3978,   3978],
                        [  4240,   4215],
                        [  4492,   4444],
                        [  4732,   4665],
                        [  4964,   4883],
                        [  5187,   5099],
                        [  5402,   5315],
                        [  5607,   5529],
                        [  5805,   5742],
                        [  5993,   5949],
                        [  6172,   6152],
                        [  6340,   6347],
                        [  6498,   6535],
                        [  6641,   6710],
                        [  6772,   6871],
                        [  6885,   7008],
                        [  6982,   7122],
                        [  7058,   7207],
                        [  7113,   7263],
                        [  7148,   7290],
                        [  7161,   7288],
                        [  7153,   7265],
                        [  7126,   7222],
                        [  7079,   7157],
                        [  7011,   7073],
                        [  6926,   6966],
                        [  6823,   6840],
                        [  6702,   6694],
                        [  6562,   6528],
                        [  6401,   6346],
                        [  6222,   6149],
                        [  6020,   5938],
                        [  5792,   5709],
                        [  5539,   5464],
                        [  5261,   5204],
                        [  4944,   4912],
                        [  4589,   4591],
                        [  4197,   4236],
                        [  3767,   3849],
                        [  3287,   3414],
                        [  2758,   2935],
                        [  2207,   2431],
                        [  1632,   1904],
                        [  1069,   1385],
                        [   518,    877],
                        [    -8,    390],
                        [  -508,    -73],
                        [  -967,   -501],
                        [ -1387,   -892],
                        [ -1758,  -1238],
                        [ -2080,  -1539],
                        [ -2346,  -1787],
                        [ -2556,  -1983],
                        [ -2709,  -2123],
                        [ -2803,  -2208],
                        [ -2845,  -2238],
                        [ -2832,  -2213],
                        [ -2773,  -2136],
                        [ -2668,  -2008],
                        [ -2523,  -1832],
                        [ -2337,  -1610],
                        [ -2112,  -1349],
                        [ -1850,  -1049],
                        [ -1549,   -717],
                        [ -1210,   -355],
                        [  -844,     28],
                        [  -453,    431],
                        [   -43,    846],
                        [   384,   1270],
                        [   818,   1697],
                        [  1258,   2121],
                        [  1695,   2538],
                        [  2127,   2945],
                        [  2546,   3332],
                        [  2949,   3699],
                        [  3330,   4040],
                        [  3686,   4351],
                        [  4011,   4628],
                        [  4304,   4868],
                        [  4557,   5068],
                        [  4773,   5226],
                        [  4943,   5340],
                        [  5062,   5402],
                        [  5162,   5446],
                        [  5324,   5555],
                        [  5598,   5779],
                        [  5992,   6125],
                        [  6507,   6596],
                        [  7131,   7178],
                        [  7790,   7802],
                        [  8360,   8340],
                        [  8790,   8744],
                        [  9086,   9022],
                        [  9257,   9176],
                        [  9303,   9210],
                        [  9238,   9130],
                        [  9068,   8945],
                        [  8806,   8663],
                        [  8460,   8295],
                        [  8041,   7853],
                        [  7560,   7344],
                        [  7027,   6782],
                        [  6454,   6176],
                        [  5848,   5536],
                        [  5221,   4871],
                        [  4583,   4193],
                        [  3942,   3509],
                        [  3308,   2832],
                        [  2685,   2165],
                        [  2082,   1520],
                        [  1506,    900],
                        [   958,    312],
                        [   445,   -241],
                        [   -32,   -757],
                        [  -468,  -1233],
                        [  -864,  -1667],
                        [ -1216,  -2059],
                        [ -1528,  -2408],
                        [ -1795,  -2715],
                        [ -2022,  -2982],
                        [ -2208,  -3208],
                        [ -2358,  -3395],
                        [ -2471,  -3545],
                        [ -2551,  -3659],
                        [ -2602,  -3738],
                        [ -2626,  -3788],
                        [ -2626,  -3809],
                        [ -2607,  -3810],
                        [ -2572,  -3794],
                        [ -2524,  -3769],
                        [ -2469,  -3739],
                        [ -2408,  -3707],
                        [ -2347,  -3677],
                        [ -2287,  -3651],
                        [ -2233,  -3630],
                        [ -2186,  -3616],
                        [ -2150,  -3613],
                        [ -2124,  -3614],
                        [ -2111,  -3622],
                        [ -2112,  -3634],
                        [ -2127,  -3651],
                        [ -2157,  -3673],
                        [ -2205,  -3700],
                        [ -2273,  -3742],
                        [ -2360,  -3796],
                        [ -2469,  -3871],
                        [ -2602,  -3966],
                        [ -2761,  -4079],
                        [ -2945,  -4208],
                        [ -3157,  -4354],
                        [ -3395,  -4515],
                        [ -3653,  -4689],
                        [ -3933,  -4878],
                        [ -4223,  -5081],
                        [ -4521,  -5293],
                        [ -4817,  -5512],
                        [ -5109,  -5736],
                        [ -5388,  -5959],
                        [ -5653,  -6177],
                        [ -5901,  -6387],
                        [ -6130,  -6588],
                        [ -6328,  -6767],
                        [ -6494,  -6922],
                        [ -6606,  -7029],
                        [ -6664,  -7087],
                        [ -6686,  -7116],
                        [ -6670,  -7109],
                        [ -6627,  -7078],
                        [ -6554,  -7020],
                        [ -6463,  -6945],
                        [ -6351,  -6852],
                        [ -6225,  -6746],
                        [ -6085,  -6627],
                        [ -5937,  -6502],
                        [ -5780,  -6368],
                        [ -5617,  -6230],
                        [ -5448,  -6087],
                        [ -5274,  -5943],
                        [ -5094,  -5795],
                        [ -4906,  -5645],
                        [ -4709,  -5493],
                        [ -4503,  -5338],
                        [ -4288,  -5181],
                        [ -4063,  -5018],
                        [ -3829,  -4852],
                        [ -3593,  -4681],
                        [ -3354,  -4505],
                        [ -3113,  -4323],
                        [ -2871,  -4133],
                        [ -2628,  -3936],
                        [ -2383,  -3731],
                        [ -2136,  -3517],
                        [ -1888,  -3293],
                        [ -1637,  -3060],
                        [ -1385,  -2818],
                        [ -1130,  -2564],
                        [  -873,  -2301],
                        [  -613,  -2026],
                        [  -350,  -1742],
                        [   -85,  -1446],
                        [   184,  -1142],
                        [   456,   -826],
                        [   730,   -499],
                        [  1008,   -167],
                        [  1290,    176],
                        [  1584,    531],
                        [  1837,    849],
                        [  1957,   1033],
                        [  1894,   1034],
                        [  1643,    847],
                        [  1198,    466],
                        [   562,   -111],
                        [  -183,   -798],
                        [  -890,  -1454],
                        [ -1497,  -2018],
                        [ -2009,  -2494],
                        [ -2426,  -2880],
                        [ -2745,  -3170],
                        [ -2967,  -3366],
                        [ -3099,  -3470],
                        [ -3144,  -3486],
                        [ -3107,  -3417],
                        [ -2992,  -3269],
                        [ -2805,  -3046],
                        [ -2551,  -2756],
                        [ -2236,  -2403],
                        [ -1866,  -1996],
                        [ -1448,  -1538],
                        [  -986,  -1038],
                        [  -491,   -502],
                        [    36,     63],
                        [   586,    652],
                        [  1155,   1256],
                        [  1739,   1872],
                        [  2332,   2495],
                        [  2931,   3122],
                        [  3531,   3748],
                        [  4129,   4371],
                        [  4723,   4989],
                        [  5309,   5597],
                        [  5883,   6196],
                        [  6445,   6781],
                        [  6990,   7352],
                        [  7518,   7905],
                        [  8028,   8439],
                        [  8515,   8950],
                        [  8981,   9437],
                        [  9423,   9893],
                        [  9839,  10318],
                        [ 10230,  10710],
                        [ 10594,  11070],
                        [ 10931,  11403],
                        [ 11239,  11709],
                        [ 11516,  11993],
                        [ 11766,  12253],
                        [ 11984,  12491],
                        [ 12173,  12706],
                        [ 12329,  12894],
                        [ 12454,  13059],
                        [ 12546,  13194],
                        [ 12604,  13300],
                        [ 12626,  13368],
                        [ 12612,  13400],
                        [ 12564,  13393],
                        [ 12478,  13349],
                        [ 12360,  13266],
                        [ 12209,  13147],
                        [ 12029,  13002],
                        [ 11822,  12831],
                        [ 11594,  12635],
                        [ 11347,  12416],
                        [ 11089,  12173],
                        [ 10823,  11908],
                        [ 10552,  11623],
                        [ 10277,  11318],
                        [  9995,  10999],
                        [  9706,  10667],
                        [  9403,  10325],
                        [  9085,   9973],
                        [  8756,   9616],
                        [  8413,   9254],
                        [  8071,   8903],
                        [  7731,   8560],
                        [  7402,   8236],
                        [  7085,   7930],
                        [  6758,   7621],
                        [  6427,   7312],
                        [  6074,   6985],
                        [  5703,   6642],
                        [  5329,   6298],
                        [  4951,   5951],
                        [  4584,   5613],
                        [  4227,   5285],
                        [  3892,   4977],
                        [  3579,   4689],
                        [  3298,   4431],
                        [  3047,   4202],
                        [  2834,   4009],
                        [  2655,   3850],
                        [  2517,   3729],
                        [  2416,   3647],
                        [  2352,   3604],
                        [  2325,   3598],
                        [  2329,   3628],
                        [  2365,   3692],
                        [  2428,   3786],
                        [  2515,   3910],
                        [  2624,   4057],
                        [  2751,   4227],
                        [  2899,   4412],
                        [  3062,   4610],
                        [  3236,   4816],
                        [  3417,   5026],
                        [  3601,   5236],
                        [  3785,   5440],
                        [  3963,   5633],
                        [  4134,   5814],
                        [  4291,   5976],
                        [  4433,   6118],
                        [  4555,   6234],
                        [  4654,   6322],
                        [  4727,   6379],
                        [  4774,   6403],
                        [  4792,   6393],
                        [  4779,   6346],
                        [  4733,   6260],
                        [  4657,   6142],
                        [  4544,   5982],
                        [  4392,   5782],
                        [  4264,   5605],
                        [  4261,   5551],
                        [  4423,   5663],
                        [  4759,   5948],
                        [  5281,   6421],
                        [  5998,   7089],
                        [  6824,   7870],
                        [  7608,   8613],
                        [  8284,   9256],
                        [  8861,   9806],
                        [  9339,  10260],
                        [  9712,  10614],
                        [  9986,  10866],
                        [ 10165,  11020],
                        [ 10256,  11080],
                        [ 10264,  11051],
                        [ 10194,  10939],
                        [ 10052,  10751],
                        [  9848,  10495],
                        [  9588,  10177],
                        [  9281,   9809],
                        [  8933,   9393],
                        [  8552,   8942],
                        [  8147,   8464],
                        [  7725,   7967],
                        [  7293,   7456],
                        [  6856,   6940],
                        [  6420,   6426],
                        [  5990,   5917],
                        [  5569,   5418],
                        [  5161,   4931],
                        [  4768,   4461],
                        [  4393,   4009],
                        [  4038,   3577],
                        [  3703,   3164],
                        [  3389,   2773],
                        [  3096,   2403],
                        [  2823,   2055],
                        [  2570,   1728],
                        [  2334,   1423],
                        [  2113,   1143],
                        [  1907,    887],
                        [  1713,    659],
                        [  1528,    455],
                        [  1351,    271],
                        [  1178,    105],
                        [  1008,    -59],
                        [   836,   -219],
                        [   663,   -385],
                        [   485,   -560],
                        [   301,   -743],
                        [   111,   -938],
                        [   -89,  -1144],
                        [  -297,  -1362],
                        [  -512,  -1587],
                        [  -735,  -1820],
                        [  -964,  -2057],
                        [ -1201,  -2301],
                        [ -1441,  -2546],
                        [ -1688,  -2793],
                        [ -1941,  -3045],
                        [ -2201,  -3303],
                        [ -2468,  -3568],
                        [ -2744,  -3840],
                        [ -3033,  -4114],
                        [ -3335,  -4388],
                        [ -3654,  -4659],
                        [ -3987,  -4924],
                        [ -4327,  -5181],
                        [ -4674,  -5428],
                        [ -5009,  -5665],
                        [ -5332,  -5887],
                        [ -5629,  -6092],
                        [ -5900,  -6281],
                        [ -6154,  -6463],
                        [ -6386,  -6634],
                        [ -6618,  -6817],
                        [ -6845,  -7008],
                        [ -7058,  -7196],
                        [ -7256,  -7379],
                        [ -7398,  -7516],
                        [ -7482,  -7605],
                        [ -7496,  -7631],
                        [ -7439,  -7594],
                        [ -7321,  -7500],
                        [ -7140,  -7350],
                        [ -6910,  -7153],
                        [ -6628,  -6908],
                        [ -6308,  -6625],
                        [ -5948,  -6303],
                        [ -5556,  -5954],
                        [ -5135,  -5575],
                        [ -4692,  -5178],
                        [ -4227,  -4761],
                        [ -3750,  -4333],
                        [ -3258,  -3893],
                        [ -2761,  -3447],
                        [ -2258,  -2997],
                        [ -1753,  -2546],
                        [ -1246,  -2096],
                        [  -739,  -1649],
                        [  -233,  -1206],
                        [   266,   -769],
                        [   756,   -338],
                        [  1236,     85],
                        [  1705,    498],
                        [  2159,    902],
                        [  2598,   1297],
                        [  3023,   1682],
                        [  3430,   2056],
                        [  3822,   2421],
                        [  4197,   2776],
                        [  4556,   3123],
                        [  4897,   3460],
                        [  5223,   3789],
                        [  5532,   4110],
                        [  5826,   4422],
                        [  6103,   4727],
                        [  6368,   5026],
                        [  6619,   5319],
                        [  6854,   5601],
                        [  7081,   5881],
                        [  7302,   6158],
                        [  7443,   6359],
                        [  7414,   6389],
                        [  7181,   6217],
                        [  6744,   5841],
                        [  6083,   5243],
                        [  5188,   4407],
                        [  4144,   3419],
                        [  3114,   2438],
                        [  2157,   1522],
                        [  1275,    672],
                        [   475,   -103],
                        [  -234,   -791],
                        [  -845,  -1385],
                        [ -1362,  -1881],
                        [ -1781,  -2277],
                        [ -2103,  -2572],
                        [ -2329,  -2768],
                        [ -2461,  -2867],
                        [ -2502,  -2871],
                        [ -2455,  -2785],
                        [ -2328,  -2615],
                        [ -2124,  -2364],
                        [ -1849,  -2042],
                        [ -1513,  -1655],
                        [ -1120,  -1209],
                        [  -678,   -713],
                        [  -193,   -175],
                        [   325,    400],
                        [   873,   1004],
                        [  1441,   1631],
                        [  2026,   2273],
                        [  2620,   2926],
                        [  3218,   3584],
                        [  3812,   4241],
                        [  4400,   4894],
                        [  4973,   5534],
                        [  5529,   6160],
                        [  6064,   6767],
                        [  6572,   7349],
                        [  7053,   7898],
                        [  7501,   8413],
                        [  7915,   8881],
                        [  8292,   9298],
                        [  8630,   9662],
                        [  8930,   9972],
                        [  9189,  10233],
                        [  9406,  10445],
                        [  9581,  10619],
                        [  9714,  10758],
                        [  9806,  10861],
                        [  9856,  10931],
                        [  9865,  10968],
                        [  9832,  10972],
                        [  9759,  10941],
                        [  9647,  10879],
                        [  9494,  10780],
                        [  9303,  10649],
                        [  9075,  10483],
                        [  8812,  10285],
                        [  8517,  10057],
                        [  8194,   9800],
                        [  7848,   9523],
                        [  7483,   9228],
                        [  7109,   8916],
                        [  6730,   8591],
                        [  6357,   8252],
                        [  5995,   7902],
                        [  5646,   7541],
                        [  5315,   7172],
                        [  4994,   6799],
                        [  4682,   6424],
                        [  4370,   6048],
                        [  4060,   5677],
                        [  3757,   5318],
                        [  3461,   4973],
                        [  3211,   4680],
                        [  3004,   4439],
                        [  2854,   4262],
                        [  2761,   4151],
                        [  2698,   4077],
                        [  2666,   4042],
                        [  2613,   3991],
                        [  2542,   3928],
                        [  2450,   3850],
                        [  2338,   3754],
                        [  2213,   3647],
                        [  2076,   3530],
                        [  1935,   3408],
                        [  1788,   3281],
                        [  1642,   3155],
                        [  1496,   3029],
                        [  1354,   2909],
                        [  1214,   2792],
                        [  1081,   2684],
                        [   952,   2581],
                        [   834,   2489],
                        [   725,   2403],
                        [   624,   2325],
                        [   530,   2252],
                        [   437,   2185],
                        [   345,   2120],
                        [   250,   2056],
                        [   150,   1991],
                        [    46,   1922],
                        [   -64,   1849],
                        [  -182,   1768],
                        [  -310,   1678],
                        [  -448,   1575],
                        [  -597,   1458],
                        [  -760,   1326],
                        [  -936,   1177],
                        [ -1129,   1006],
                        [ -1335,    817],
                        [ -1557,    608],
                        [ -1796,    376],
                        [ -2050,    123],
                        [ -2317,   -151],
                        [ -2600,   -445],
                        [ -2896,   -761],
                        [ -3204,  -1094],
                        [ -3517,  -1438],
                        [ -3845,  -1802],
                        [ -4177,  -2177],
                        [ -4439,  -2484],
                        [ -4545,  -2640],
                        [ -4472,  -2618],
                        [ -4214,  -2414],
                        [ -3742,  -1999],
                        [ -3034,  -1348],
                        [ -2169,   -539],
                        [ -1294,    284],
                        [  -465,   1068],
                        [   326,   1818],
                        [  1067,   2522],
                        [  1747,   3170],
                        [  2364,   3752],
                        [  2915,   4267],
                        [  3403,   4712],
                        [  3824,   5083],
                        [  4177,   5382],
                        [  4465,   5610],
                        [  4688,   5766],
                        [  4851,   5857],
                        [  4954,   5886],
                        [  5002,   5853],
                        [  4999,   5767],
                        [  4950,   5631],
                        [  4859,   5449],
                        [  4730,   5228],
                        [  4566,   4971],
                        [  4374,   4683],
                        [  4154,   4368],
                        [  3912,   4031],
                        [  3649,   3672],
                        [  3369,   3296],
                        [  3074,   2906],
                        [  2765,   2504],
                        [  2446,   2091],
                        [  2118,   1669],
                        [  1783,   1240],
                        [  1441,    806],
                        [  1092,    370],
                        [   739,    -69],
                        [   379,   -500],
                        [    15,   -921],
                        [  -355,  -1325],
                        [  -730,  -1714],
                        [ -1108,  -2085],
                        [ -1493,  -2441],
                        [ -1882,  -2795],
                        [ -2276,  -3147],
                        [ -2674,  -3508],
                        [ -3077,  -3876],
                        [ -3482,  -4253],
                        [ -3890,  -4638],
                        [ -4299,  -5029],
                        [ -4707,  -5427],
                        [ -5111,  -5827],
                        [ -5509,  -6229],
                        [ -5899,  -6631],
                        [ -6279,  -7030],
                        [ -6648,  -7420],
                        [ -7004,  -7801],
                        [ -7345,  -8172],
                        [ -7673,  -8532],
                        [ -7989,  -8880],
                        [ -8291,  -9215],
                        [ -8590,  -9532],
                        [ -8883,  -9830],
                        [ -9175, -10102],
                        [ -9464, -10347],
                        [ -9743, -10563],
                        [-10010, -10745],
                        [-10246, -10896],
                        [-10450, -11013],
                        [-10615, -11096],
                        [-10738, -11143],
                        [-10848, -11189],
                        [-10943, -11227],
                        [-11054, -11295],
                        [-11181, -11388],
                        [-11316, -11501],
                        [-11459, -11633],
                        [-11551, -11724],
                        [-11598, -11780],
                        [-11557, -11756],
                        [-11431, -11656],
                        [-11230, -11486],
                        [-10953, -11246],
                        [-10612, -10943],
                        [-10205, -10577],
                        [ -9744, -10160],
                        [ -9232,  -9691],
                        [ -8675,  -9181],
                        [ -8078,  -8633],
                        [ -7451,  -8055],
                        [ -6794,  -7451],
                        [ -6122,  -6830],
                        [ -5436,  -6193],
                        [ -4750,  -5549],
                        [ -4063,  -4900],
                        [ -3380,  -4254],
                        [ -2703,  -3610],
                        [ -2033,  -2976],
                        [ -1372,  -2352],
                        [  -722,  -1742],
                        [   -87,  -1149],
                        [   529,   -574],
                        [  1125,    -20],
                        [  1699,    512],
                        [  2249,   1022],
                        [  2773,   1510],
                        [  3270,   1972],
                        [  3742,   2412],
                        [  4184,   2828],
                        [  4600,   3221],
                        [  4986,   3590],
                        [  5347,   3939],
                        [  5679,   4265],
                        [  5986,   4570],
                        [  6266,   4856],
                        [  6523,   5123],
                        [  6755,   5370],
                        [  6961,   5596],
                        [  7149,   5809],
                        [  7314,   6004],
                        [  7384,   6105],
                        [  7298,   6053],
                        [  7045,   5836],
                        [  6623,   5449],
                        [  6002,   4866],
                        [  5156,   4055],
                        [  4156,   3088],
                        [  3139,   2098],
                        [  2149,   1129],
                        [  1190,    183],
                        [   275,   -726],
                        [  -580,  -1579],
                        [ -1366,  -2367],
                        [ -2080,  -3081],
                        [ -2716,  -3714],
                        [ -3270,  -4260],
                        [ -3739,  -4717],
                        [ -4122,  -5083],
                        [ -4418,  -5358],
                        [ -4631,  -5546],
                        [ -4761,  -5646],
                        [ -4813,  -5664],
                        [ -4791,  -5604],
                        [ -4701,  -5471],
                        [ -4549,  -5271],
                        [ -4341,  -5011],
                        [ -4084,  -4697],
                        [ -3785,  -4338],
                        [ -3452,  -3938],
                        [ -3088,  -3508],
                        [ -2703,  -3052],
                        [ -2303,  -2576],
                        [ -1895,  -2089],
                        [ -1484,  -1597],
                        [ -1077,  -1103],
                        [  -681,   -616],
                        [  -299,   -141],
                        [    63,    319],
                        [   403,    757],
                        [   715,   1164],
                        [   997,   1538],
                        [  1246,   1863],
                        [  1461,   2137],
                        [  1639,   2354],
                        [  1780,   2513],
                        [  1883,   2620],
                        [  1948,   2672],
                        [  1975,   2689],
                        [  1965,   2672],
                        [  1918,   2624],
                        [  1835,   2546],
                        [  1720,   2442],
                        [  1573,   2313],
                        [  1393,   2162],
                        [  1186,   1991],
                        [   950,   1801],
                        [   687,   1597],
                        [   403,   1377],
                        [    97,   1143],
                        [  -225,    895],
                        [  -560,    636],
                        [  -902,    371],
                        [ -1250,    103],
                        [ -1587,   -167],
                        [ -1913,   -435],
                        [ -2215,   -702],
                        [ -2490,   -966],
                        [ -2735,  -1227],
                        [ -2947,  -1484],
                        [ -3139,  -1736],
                        [ -3307,  -1982],
                        [ -3466,  -2217],
                        [ -3612,  -2440],
                        [ -3734,  -2637],
                        [ -3833,  -2805],
                        [ -3856,  -2893],
                        [ -3808,  -2904],
                        [ -3677,  -2824],
                        [ -3465,  -2655],
                        [ -3200,  -2426],
                        [ -2883,  -2137],
                        [ -2594,  -1867],
                        [ -2327,  -1613],
                        [ -2098,  -1390],
                        [ -1907,  -1200],
                        [ -1752,  -1042],
                        [ -1634,   -919],
                        [ -1550,   -827],
                        [ -1503,   -769],
                        [ -1489,   -742],
                        [ -1510,   -747],
                        [ -1562,   -778],
                        [ -1648,   -840],
                        [ -1761,   -928],
                        [ -1901,  -1042],
                        [ -2059,  -1177],
                        [ -2238,  -1338],
                        [ -2432,  -1520],
                        [ -2644,  -1723],
                        [ -2876,  -1945],
                        [ -3131,  -2187],
                        [ -3409,  -2448],
                        [ -3713,  -2728],
                        [ -4037,  -3023],
                        [ -4383,  -3336],
                        [ -4745,  -3663],
                        [ -5125,  -4005],
                        [ -5520,  -4360],
                        [ -5928,  -4728],
                        [ -6346,  -5107],
                        [ -6773,  -5496],
                        [ -7205,  -5892],
                        [ -7642,  -6295],
                        [ -8079,  -6703],
                        [ -8514,  -7114],
                        [ -8945,  -7525],
                        [ -9367,  -7934],
                        [ -9779,  -8338],
                        [-10179,  -8736],
                        [-10562,  -9122],
                        [-10920,  -9492],
                        [-11262,  -9850],
                        [-11570, -10182],
                        [-11785, -10426],
                        [-11860, -10537],
                        [-11794, -10511],
                        [-11576, -10336],
                        [-11172,  -9980],
                        [-10546,  -9403],
                        [ -9752,  -8658],
                        [ -8894,  -7849],
                        [ -8012,  -7012],
                        [ -7105,  -6146],
                        [ -6190,  -5269],
                        [ -5284,  -4396],
                        [ -4395,  -3542],
                        [ -3532,  -2713],
                        [ -2701,  -1922],
                        [ -1911,  -1176],
                        [ -1168,   -481],
                        [  -477,    157],
                        [   158,    735],
                        [   733,   1250],
                        [  1246,   1701],
                        [  1697,   2086],
                        [  2082,   2404],
                        [  2407,   2657],
                        [  2667,   2845],
                        [  2867,   2968],
                        [  3008,   3030],
                        [  3092,   3033],
                        [  3119,   2980],
                        [  3095,   2873],
                        [  3019,   2715],
                        [  2896,   2509],
                        [  2728,   2259],
                        [  2516,   1965],
                        [  2268,   1634],
                        [  1983,   1268],
                        [  1666,    869],
                        [  1319,    440],
                        [   946,    -11],
                        [   548,   -485],
                        [   130,   -965],
                        [  -308,  -1451],
                        [  -760,  -1931],
                        [ -1225,  -2400],
                        [ -1701,  -2857],
                        [ -2185,  -3297],
                        [ -2672,  -3733],
                        [ -3161,  -4161],
                        [ -3650,  -4592],
                        [ -4136,  -5025],
                        [ -4614,  -5454],
                        [ -5085,  -5882],
                        [ -5543,  -6305],
                        [ -5987,  -6723],
                        [ -6411,  -7135],
                        [ -6814,  -7538],
                        [ -7193,  -7930],
                        [ -7544,  -8309],
                        [ -7866,  -8666],
                        [ -8158,  -9002],
                        [ -8418,  -9310],
                        [ -8644,  -9590],
                        [ -8842,  -9840],
                        [ -9008, -10061],
                        [ -9154, -10248],
                        [ -9280, -10402],
                        [ -9388, -10516],
                        [ -9479, -10593],
                        [ -9550, -10627],
                        [ -9596, -10616],
                        [ -9604, -10563],
                        [ -9574, -10472],
                        [ -9503, -10342],
                        [ -9392, -10175],
                        [ -9284, -10019],
                        [ -9180,  -9869],
                        [ -9112,  -9766],
                        [ -9082,  -9707],
                        [ -9088,  -9692],
                        [ -9132,  -9725],
                        [ -9150,  -9739],
                        [ -9146,  -9739],
                        [ -9069,  -9674],
                        [ -8924,  -9548],
                        [ -8717,  -9363],
                        [ -8448,  -9121],
                        [ -8122,  -8824],
                        [ -7741,  -8474],
                        [ -7313,  -8079],
                        [ -6840,  -7638],
                        [ -6328,  -7161],
                        [ -5778,  -6650],
                        [ -5202,  -6113],
                        [ -4599,  -5552],
                        [ -3988,  -4976],
                        [ -3368,  -4385],
                        [ -2752,  -3789],
                        [ -2140,  -3188],
                        [ -1536,  -2590],
                        [  -941,  -1996],
                        [  -351,  -1411],
                        [   232,   -835],
                        [   806,   -275],
                        [  1369,    271],
                        [  1918,    796],
                        [  2451,   1303],
                        [  2966,   1790],
                        [  3462,   2254],
                        [  3937,   2696],
                        [  4392,   3115],
                        [  4825,   3512],
                        [  5234,   3887],
                        [  5620,   4240],
                        [  5984,   4570],
                        [  6325,   4880],
                        [  6643,   5168],
                        [  6937,   5435],
                        [  7209,   5683],
                        [  7460,   5912],
                        [  7688,   6120],
                        [  7891,   6307],
                        [  8075,   6480],
                        [  8229,   6627],
                        [  8312,   6706],
                        [  8307,   6702],
                        [  8218,   6615],
                        [  8040,   6441],
                        [  7737,   6143],
                        [  7267,   5680],
                        [  6661,   5081],
                        [  6001,   4425],
                        [  5312,   3737],
                        [  4599,   3021],
                        [  3876,   2293],
                        [  3163,   1571],
                        [  2467,    863],
                        [  1795,    183],
                        [  1158,   -462],
                        [   561,  -1060],
                        [     9,  -1609],
                        [  -494,  -2103],
                        [  -943,  -2540],
                        [ -1337,  -2918],
                        [ -1676,  -3235],
                        [ -1961,  -3494],
                        [ -2192,  -3694],
                        [ -2374,  -3839],
                        [ -2507,  -3930],
                        [ -2598,  -3972],
                        [ -2650,  -3967],
                        [ -2666,  -3922],
                        [ -2652,  -3841],
                        [ -2613,  -3730],
                        [ -2554,  -3593],
                        [ -2479,  -3436],
                        [ -2393,  -3264],
                        [ -2301,  -3082],
                        [ -2207,  -2895],
                        [ -2116,  -2706],
                        [ -2031,  -2521],
                        [ -1957,  -2344],
                        [ -1896,  -2177],
                        [ -1849,  -2028],
                        [ -1819,  -1900],
                        [ -1808,  -1807],
                        [ -1817,  -1749],
                        [ -1847,  -1731],
                        [ -1898,  -1755],
                        [ -1969,  -1817],
                        [ -2061,  -1918],
                        [ -2172,  -2040],
                        [ -2301,  -2183],
                        [ -2446,  -2340],
                        [ -2607,  -2510],
                        [ -2781,  -2688],
                        [ -2967,  -2872],
                        [ -3162,  -3057],
                        [ -3365,  -3239],
                        [ -3574,  -3415],
                        [ -3787,  -3582],
                        [ -4002,  -3741],
                        [ -4217,  -3891],
                        [ -4429,  -4036],
                        [ -4636,  -4172],
                        [ -4834,  -4300],
                        [ -5023,  -4418],
                        [ -5189,  -4522],
                        [ -5331,  -4611],
                        [ -5442,  -4687],
                        [ -5521,  -4750],
                        [ -5563,  -4800],
                        [ -5570,  -4839],
                        [ -5553,  -4869],
                        [ -5512,  -4887],
                        [ -5456,  -4893],
                        [ -5386,  -4886],
                        [ -5285,  -4847],
                        [ -5153,  -4777],
                        [ -4942,  -4625],
                        [ -4656,  -4393],
                        [ -4288,  -4074],
                        [ -3838,  -3668],
                        [ -3334,  -3200],
                        [ -2775,  -2670],
                        [ -2248,  -2166],
                        [ -1751,  -1684],
                        [ -1301,  -1243],
                        [  -899,   -845],
                        [  -549,   -496],
                        [  -256,   -198],
                        [   -17,     47],
                        [   163,    238],
                        [   287,    375],
                        [   350,    456],
                        [   356,    484],
                        [   303,    458],
                        [   203,    384],
                        [    53,    258],
                        [  -133,     87],
                        [  -358,   -129],
                        [  -613,   -384],
                        [  -899,   -678],
                        [ -1220,  -1006],
                        [ -1574,  -1366],
                        [ -1961,  -1753],
                        [ -2382,  -2165],
                        [ -2828,  -2596],
                        [ -3297,  -3045],
                        [ -3783,  -3506],
                        [ -4284,  -3978],
                        [ -4793,  -4455],
                        [ -5307,  -4934],
                        [ -5821,  -5410],
                        [ -6331,  -5882],
                        [ -6831,  -6344],
                        [ -7318,  -6793],
                        [ -7786,  -7226],
                        [ -8234,  -7641],
                        [ -8655,  -8032],
                        [ -9047,  -8395],
                        [ -9406,  -8728],
                        [ -9729,  -9029],
                        [-10010,  -9294],
                        [-10246,  -9519],
                        [-10438,  -9706],
                        [-10574,  -9843],
                        [-10636,  -9914],
                        [-10628,  -9918],
                        [-10557,  -9865],
                        [-10413,  -9744],
                        [-10164,  -9520],
                        [ -9761,  -9146],
                        [ -9208,  -8621],
                        [ -8552,  -7995],
                        [ -7815,  -7288],
                        [ -7004,  -6505],
                        [ -6138,  -5665],
                        [ -5233,  -4783],
                        [ -4304,  -3876],
                        [ -3362,  -2955],
                        [ -2420,  -2035],
                        [ -1489,  -1129],
                        [  -582,   -246],
                        [   294,    604],
                        [  1130,   1412],
                        [  1918,   2173],
                        [  2650,   2877],
                        [  3323,   3522],
                        [  3932,   4102],
                        [  4474,   4614],
                        [  4947,   5055],
                        [  5350,   5422],
                        [  5682,   5717],
                        [  5943,   5939],
                        [  6135,   6089],
                        [  6259,   6170],
                        [  6317,   6185],
                        [  6312,   6135],
                        [  6246,   6025],
                        [  6123,   5857],
                        [  5948,   5636],
                        [  5724,   5367],
                        [  5458,   5054],
                        [  5150,   4700],
                        [  4808,   4314],
                        [  4436,   3897],
                        [  4039,   3465],
                        [  3621,   3022],
                        [  3186,   2578],
                        [  2740,   2139],
                        [  2287,   1710],
                        [  1832,   1298],
                        [  1380,    899],
                        [   933,    514],
                        [   496,    139],
                        [    74,   -223],
                        [  -332,   -572],
                        [  -717,   -905],
                        [ -1077,  -1223],
                        [ -1412,  -1523],
                        [ -1717,  -1809],
                        [ -1990,  -2080],
                        [ -2228,  -2331],
                        [ -2430,  -2561],
                        [ -2594,  -2762],
                        [ -2719,  -2932],
                        [ -2803,  -3067],
                        [ -2846,  -3166],
                        [ -2854,  -3228],
                        [ -2824,  -3255],
                        [ -2767,  -3245],
                        [ -2681,  -3200],
                        [ -2573,  -3118],
                        [ -2444,  -3001],
                        [ -2294,  -2845],
                        [ -2121,  -2650],
                        [ -1919,  -2420],
                        [ -1689,  -2160],
                        [ -1436,  -1875],
                        [ -1159,  -1567],
                        [  -907,  -1282],
                        [  -677,  -1022],
                        [  -498,   -817],
                        [  -371,   -664],
                        [  -303,   -575],
                        [  -296,   -550],
                        [  -290,   -532],
                        [  -293,   -528],
                        [  -256,   -488],
                        [  -182,   -414],
                        [   -71,   -306],
                        [    76,   -166],
                        [   259,     11],
                        [   478,    223],
                        [   730,    466],
                        [  1016,    742],
                        [  1333,   1045],
                        [  1680,   1376],
                        [  2049,   1730],
                        [  2441,   2104],
                        [  2839,   2495],
                        [  3246,   2902],
                        [  3651,   3318],
                        [  4057,   3744],
                        [  4460,   4174],
                        [  4860,   4606],
                        [  5266,   5038],
                        [  5676,   5468],
                        [  6087,   5892],
                        [  6500,   6311],
                        [  6910,   6719],
                        [  7318,   7119],
                        [  7720,   7506],
                        [  8117,   7880],
                        [  8504,   8242],
                        [  8884,   8588],
                        [  9252,   8920],
                        [  9609,   9237],
                        [  9952,   9536],
                        [ 10281,   9819],
                        [ 10594,  10085],
                        [ 10891,  10333],
                        [ 11170,  10562],
                        [ 11434,  10772],
                        [ 11676,  10963],
                        [ 11897,  11134],
                        [ 12093,  11282],
                        [ 12265,  11409],
                        [ 12409,  11512],
                        [ 12535,  11603],
                        [ 12666,  11702],
                        [ 12810,  11817],
                        [ 12959,  11941],
                        [ 13080,  12040],
                        [ 13117,  12057],
                        [ 13039,  11961],
                        [ 12864,  11770],
                        [ 12604,  11496],
                        [ 12262,  11143],
                        [ 11854,  10725],
                        [ 11393,  10253],
                        [ 10888,   9737],
                        [ 10347,   9188],
                        [  9783,   8616],
                        [  9202,   8031],
                        [  8612,   7440],
                        [  8019,   6849],
                        [  7430,   6267],
                        [  6852,   5696],
                        [  6286,   5141],
                        [  5737,   4606],
                        [  5207,   4093],
                        [  4699,   3608],
                        [  4213,   3148],
                        [  3749,   2719],
                        [  3307,   2316],
                        [  2888,   1943],
                        [  2489,   1596],
                        [  2110,   1272],
                        [  1750,    972],
                        [  1408,    692],
                        [  1081,    431],
                        [   767,    187],
                        [   466,    -43],
                        [   175,   -261],
                        [  -108,   -469],
                        [  -381,   -666],
                        [  -648,   -856],
                        [  -909,  -1044],
                        [ -1164,  -1229],
                        [ -1415,  -1419],
                        [ -1659,  -1614],
                        [ -1899,  -1817],
                        [ -2134,  -2028],
                        [ -2362,  -2251],
                        [ -2585,  -2482],
                        [ -2800,  -2711],
                        [ -3007,  -2940],
                        [ -3205,  -3161],
                        [ -3391,  -3373],
                        [ -3565,  -3570],
                        [ -3726,  -3753],
                        [ -3872,  -3911],
                        [ -4003,  -4046],
                        [ -4116,  -4151],
                        [ -4211,  -4227],
                        [ -4289,  -4275],
                        [ -4349,  -4297],
                        [ -4392,  -4299],
                        [ -4416,  -4280],
                        [ -4422,  -4244],
                        [ -4409,  -4189],
                        [ -4373,  -4114],
                        [ -4314,  -4019],
                        [ -4228,  -3907],
                        [ -4119,  -3778],
                        [ -3980,  -3634],
                        [ -3816,  -3479],
                        [ -3634,  -3317],
                        [ -3433,  -3146],
                        [ -3220,  -2966],
                        [ -2997,  -2780],
                        [ -2746,  -2568],
                        [ -2472,  -2332],
                        [ -2139,  -2038],
                        [ -1750,  -1688],
                        [ -1302,  -1276],
                        [  -794,   -803],
                        [  -242,   -280],
                        [   353,    290],
                        [   919,    836],
                        [  1458,   1359],
                        [  1953,   1844],
                        [  2404,   2288],
                        [  2800,   2680],
                        [  3140,   3021],
                        [  3421,   3304],
                        [  3642,   3530],
                        [  3799,   3695],
                        [  3893,   3800],
                        [  3924,   3846],
                        [  3891,   3832],
                        [  3808,   3763],
                        [  3673,   3638],
                        [  3499,   3464],
                        [  3284,   3239],
                        [  3037,   2974],
                        [  2758,   2667],
                        [  2446,   2328],
                        [  2104,   1958],
                        [  1731,   1564],
                        [  1330,   1151],
                        [   912,    723],
                        [   477,    287],
                        [    33,   -153],
                        [  -415,   -593],
                        [  -862,  -1025],
                        [ -1302,  -1446],
                        [ -1731,  -1851],
                        [ -2143,  -2237],
                        [ -2533,  -2598],
                        [ -2897,  -2932],
                        [ -3231,  -3233],
                        [ -3532,  -3499],
                        [ -3795,  -3728],
                        [ -4019,  -3915],
                        [ -4198,  -4058],
                        [ -4333,  -4158],
                        [ -4418,  -4209],
                        [ -4453,  -4212],
                        [ -4434,  -4166],
                        [ -4367,  -4077],
                        [ -4292,  -3985],
                        [ -4247,  -3926],
                        [ -4243,  -3912],
                        [ -4273,  -3934],
                        [ -4313,  -3970],
                        [ -4301,  -3955],
                        [ -4177,  -3829],
                        [ -3933,  -3587],
                        [ -3584,  -3240],
                        [ -3134,  -2796],
                        [ -2602,  -2268],
                        [ -1998,  -1669],
                        [ -1338,  -1013],
                        [  -636,   -310],
                        [    95,    422],
                        [   842,   1172],
                        [  1594,   1929],
                        [  2340,   2682],
                        [  3070,   3421],
                        [  3772,   4136],
                        [  4443,   4821],
                        [  5072,   5466],
                        [  5653,   6065],
                        [  6182,   6611],
                        [  6655,   7100],
                        [  7070,   7528],
                        [  7423,   7893],
                        [  7714,   8193],
                        [  7944,   8431],
                        [  8113,   8604],
                        [  8222,   8717],
                        [  8274,   8771],
                        [  8271,   8769],
                        [  8217,   8716],
                        [  8115,   8613],
                        [  7971,   8467],
                        [  7789,   8283],
                        [  7572,   8062],
                        [  7326,   7813],
                        [  7057,   7538],
                        [  6768,   7249],
                        [  6466,   6948],
                        [  6156,   6644],
                        [  5842,   6341],
                        [  5529,   6048],
                        [  5223,   5770],
                        [  4925,   5510],
                        [  4643,   5271],
                        [  4377,   5051],
                        [  4132,   4853],
                        [  3910,   4678],
                        [  3712,   4526],
                        [  3542,   4395],
                        [  3399,   4284],
                        [  3286,   4189],
                        [  3203,   4112],
                        [  3151,   4054],
                        [  3131,   4015],
                        [  3145,   4002],
                        [  3194,   4015],
                        [  3274,   4059],
                        [  3389,   4136],
                        [  3533,   4239],
                        [  3706,   4368],
                        [  3903,   4523],
                        [  4125,   4701],
                        [  4364,   4900],
                        [  4617,   5117],
                        [  4879,   5354],
                        [  5150,   5611],
                        [  5428,   5881],
                        [  5710,   6161],
                        [  5990,   6443],
                        [  6268,   6728],
                        [  6509,   6979],
                        [  6713,   7197],
                        [  6867,   7366],
                        [  6967,   7486],
                        [  7001,   7537],
                        [  6966,   7521],
                        [  6900,   7473],
                        [  6799,   7387],
                        [  6701,   7303],
                        [  6601,   7216],
                        [  6508,   7135],
                        [  6420,   7057],
                        [  6347,   6993],
                        [  6286,   6940],
                        [  6242,   6905],
                        [  6217,   6885],
                        [  6213,   6884],
                        [  6229,   6901],
                        [  6264,   6939],
                        [  6319,   6995],
                        [  6383,   7071],
                        [  6459,   7165],
                        [  6543,   7278],
                        [  6636,   7406],
                        [  6738,   7550],
                        [  6851,   7707],
                        [  6981,   7877],
                        [  7130,   8058],
                        [  7292,   8247],
                        [  7472,   8445],
                        [  7664,   8647],
                        [  7868,   8853],
                        [  8082,   9060],
                        [  8305,   9268],
                        [  8532,   9475],
                        [  8764,   9678],
                        [  8998,   9876],
                        [  9232,  10068],
                        [  9461,  10251],
                        [  9686,  10424],
                        [  9903,  10584],
                        [ 10112,  10731],
                        [ 10307,  10861],
                        [ 10490,  10974],
                        [ 10654,  11066],
                        [ 10799,  11139],
                        [ 10918,  11188],
                        [ 11007,  11208],
                        [ 11085,  11222],
                        [ 11214,  11291],
                        [ 11437,  11457],
                        [ 11761,  11728],
                        [ 12180,  12098],
                        [ 12673,  12545],
                        [ 13166,  12995],
                        [ 13561,  13353],
                        [ 13830,  13587],
                        [ 13975,  13706],
                        [ 14000,  13711],
                        [ 13912,  13608],
                        [ 13720,  13404],
                        [ 13431,  13106],
                        [ 13054,  12721],
                        [ 12599,  12260],
                        [ 12076,  11730],
                        [ 11493,  11141],
                        [ 10857,  10500],
                        [ 10178,   9815],
                        [  9463,   9094],
                        [  8719,   8345],
                        [  7954,   7576],
                        [  7174,   6792],
                        [  6385,   6003],
                        [  5593,   5212],
                        [  4804,   4428],
                        [  4019,   3653],
                        [  3245,   2893],
                        [  2485,   2151],
                        [  1741,   1428],
                        [  1017,    727],
                        [   314,     50],
                        [  -366,   -603],
                        [ -1019,  -1229],
                        [ -1646,  -1829],
                        [ -2244,  -2399],
                        [ -2815,  -2941],
                        [ -3354,  -3454],
                        [ -3863,  -3937],
                        [ -4341,  -4388],
                        [ -4788,  -4810],
                        [ -5203,  -5202],
                        [ -5587,  -5563],
                        [ -5938,  -5897],
                        [ -6257,  -6202],
                        [ -6546,  -6485],
                        [ -6802,  -6745],
                        [ -7027,  -6980],
                        [ -7222,  -7193],
                        [ -7383,  -7379],
                        [ -7515,  -7541],
                        [ -7614,  -7672],
                        [ -7681,  -7774],
                        [ -7718,  -7838],
                        [ -7723,  -7866],
                        [ -7698,  -7855],
                        [ -7645,  -7807],
                        [ -7566,  -7728],
                        [ -7463,  -7616],
                        [ -7339,  -7484],
                        [ -7198,  -7332],
                        [ -7040,  -7163],
                        [ -6867,  -6979],
                        [ -6685,  -6781],
                        [ -6495,  -6571],
                        [ -6297,  -6349],
                        [ -6095,  -6118],
                        [ -5882,  -5879],
                        [ -5663,  -5638],
                        [ -5437,  -5397],
                        [ -5205,  -5156],
                        [ -4968,  -4916],
                        [ -4730,  -4679],
                        [ -4479,  -4435],
                        [ -4221,  -4186],
                        [ -3941,  -3920],
                        [ -3642,  -3638],
                        [ -3318,  -3333],
                        [ -2970,  -3005],
                        [ -2592,  -2646],
                        [ -2186,  -2260],
                        [ -1793,  -1884],
                        [ -1412,  -1519],
                        [ -1055,  -1178],
                        [  -724,   -860],
                        [  -428,   -576],
                        [  -168,   -326],
                        [    50,   -117],
                        [   228,     52],
                        [   359,    177],
                        [   446,    260],
                        [   488,    298],
                        [   487,    294],
                        [   450,    249],
                        [   379,    164],
                        [   280,     43],
                        [   156,   -111],
                        [    11,   -294],
                        [  -151,   -504],
                        [  -332,   -732],
                        [  -531,   -979],
                        [  -746,  -1236],
                        [  -973,  -1500],
                        [ -1206,  -1765],
                        [ -1442,  -2029],
                        [ -1676,  -2283],
                        [ -1905,  -2527],
                        [ -2124,  -2754],
                        [ -2329,  -2961],
                        [ -2515,  -3144],
                        [ -2680,  -3302],
                        [ -2821,  -3428],
                        [ -2934,  -3523],
                        [ -3018,  -3583],
                        [ -3069,  -3607],
                        [ -3088,  -3592],
                        [ -3073,  -3540],
                        [ -3021,  -3447],
                        [ -2933,  -3315],
                        [ -2808,  -3145],
                        [ -2645,  -2936],
                        [ -2438,  -2685],
                        [ -2227,  -2431],
                        [ -2098,  -2261],
                        [ -2097,  -2223],
                        [ -2236,  -2325],
                        [ -2515,  -2569],
                        [ -2927,  -2945],
                        [ -3391,  -3376],
                        [ -3789,  -3742],
                        [ -4078,  -4002],
                        [ -4265,  -4166],
                        [ -4355,  -4237],
                        [ -4353,  -4220],
                        [ -4268,  -4123],
                        [ -4110,  -3951],
                        [ -3889,  -3714],
                        [ -3616,  -3422],
                        [ -3301,  -3083],
                        [ -2953,  -2708],
                        [ -2582,  -2306],
                        [ -2195,  -1883],
                        [ -1801,  -1450],
                        [ -1408,  -1013],
                        [ -1022,   -579],
                        [  -650,   -158],
                        [  -298,    245],
                        [    31,    625],
                        [   332,    977],
                        [   605,   1297],
                        [   845,   1584],
                        [  1052,   1835],
                        [  1227,   2051],
                        [  1368,   2233],
                        [  1479,   2381],
                        [  1558,   2498],
                        [  1610,   2586],
                        [  1636,   2648],
                        [  1639,   2685],
                        [  1623,   2702],
                        [  1588,   2702],
                        [  1542,   2685],
                        [  1486,   2657],
                        [  1424,   2619],
                        [  1359,   2574],
                        [  1297,   2524],
                        [  1238,   2472],
                        [  1188,   2426],
                        [  1149,   2389],
                        [  1122,   2368],
                        [  1111,   2367],
                        [  1115,   2386],
                        [  1138,   2430],
                        [  1178,   2494],
                        [  1237,   2580],
                        [  1314,   2680],
                        [  1408,   2797],
                        [  1518,   2922],
                        [  1644,   3057],
                        [  1785,   3199],
                        [  1942,   3350],
                        [  2115,   3513],
                        [  2302,   3686],
                        [  2504,   3874],
                        [  2719,   4076],
                        [  2949,   4286],
                        [  3192,   4504],
                        [  3447,   4726],
                        [  3715,   4951],
                        [  3986,   5174],
                        [  4260,   5392],
                        [  4524,   5605],
                        [  4778,   5813],
                        [  5013,   6009],
                        [  5228,   6193],
                        [  5419,   6360],
                        [  5586,   6510],
                        [  5721,   6633],
                        [  5822,   6732],
                        [  5890,   6801],
                        [  5923,   6841],
                        [  5900,   6830],
                        [  5822,   6766],
                        [  5692,   6653],
                        [  5510,   6489],
                        [  5300,   6298],
                        [  5059,   6076],
                        [  4799,   5835],
                        [  4521,   5575],
                        [  4236,   5307],
                        [  3944,   5032],
                        [  3656,   4760],
                        [  3372,   4492],
                        [  3100,   4234],
                        [  2840,   3986],
                        [  2595,   3756],
                        [  2367,   3543],
                        [  2155,   3350],
                        [  1959,   3179],
                        [  1781,   3031],
                        [  1622,   2907],
                        [  1481,   2806],
                        [  1361,   2728],
                        [  1268,   2673],
                        [  1200,   2639],
                        [  1158,   2624],
                        [  1141,   2630],
                        [  1146,   2651],
                        [  1175,   2688],
                        [  1223,   2737],
                        [  1290,   2797],
                        [  1372,   2867],
                        [  1468,   2941],
                        [  1575,   3019],
                        [  1688,   3100],
                        [  1806,   3177],
                        [  1927,   3250],
                        [  2045,   3315],
                        [  2160,   3371],
                        [  2267,   3414],
                        [  2363,   3441],
                        [  2442,   3449],
                        [  2507,   3440],
                        [  2546,   3406],
                        [  2555,   3343],
                        [  2584,   3304],
                        [  2728,   3382],
                        [  3025,   3616],
                        [  3482,   4013],
                        [  4101,   4575],
                        [  4877,   5298],
                        [  5721,   6091],
                        [  6489,   6813],
                        [  7125,   7410],
                        [  7632,   7887],
                        [  8009,   8243],
                        [  8253,   8474],
                        [  8369,   8583],
                        [  8359,   8573],
                        [  8234,   8445],
                        [  7998,   8206],
                        [  7661,   7864],
                        [  7230,   7425],
                        [  6714,   6898],
                        [  6120,   6291],
                        [  5458,   5613],
                        [  4737,   4872],
                        [  3966,   4079],
                        [  3153,   3242],
                        [  2310,   2373],
                        [  1443,   1479],
                        [   561,    570],
                        [  -328,   -347],
                        [ -1218,  -1263],
                        [ -2102,  -2173],
                        [ -2975,  -3070],
                        [ -3829,  -3948],
                        [ -4661,  -4804],
                        [ -5465,  -5635],
                        [ -6237,  -6435],
                        [ -6974,  -7201],
                        [ -7672,  -7931],
                        [ -8328,  -8621],
                        [ -8941,  -9270],
                        [ -9509,  -9874],
                        [-10031, -10430],
                        [-10506, -10938],
                        [-10933, -11390],
                        [-11313, -11790],
                        [-11646, -12134],
                        [-11933, -12424],
                        [-12175, -12669],
                        [-12372, -12868],
                        [-12526, -13031],
                        [-12637, -13159],
                        [-12707, -13254],
                        [-12738, -13317],
                        [-12730, -13346],
                        [-12685, -13342],
                        [-12603, -13301],
                        [-12487, -13227],
                        [-12340, -13117],
                        [-12165, -12976],
                        [-11966, -12807],
                        [-11746, -12613],
                        [-11510, -12404],
                        [-11263, -12182],
                        [-11009, -11950],
                        [-10753, -11711],
                        [-10504, -11468],
                        [-10264, -11222],
                        [-10037, -10974],
                        [ -9824, -10726],
                        [ -9617, -10477],
                        [ -9419, -10232],
                        [ -9223,  -9992],
                        [ -9026,  -9757],
                        [ -8829,  -9530],
                        [ -8635,  -9310],
                        [ -8448,  -9102],
                        [ -8267,  -8908],
                        [ -8105,  -8739],
                        [ -7961,  -8594],
                        [ -7824,  -8463],
                        [ -7698,  -8347],
                        [ -7551,  -8214],
                        [ -7386,  -8066],
                        [ -7207,  -7905],
                        [ -7011,  -7729],
                        [ -6810,  -7550],
                        [ -6602,  -7363],
                        [ -6395,  -7180],
                        [ -6190,  -6998],
                        [ -5993,  -6825],
                        [ -5801,  -6658],
                        [ -5622,  -6505],
                        [ -5452,  -6362],
                        [ -5294,  -6234],
                        [ -5148,  -6117],
                        [ -5013,  -6017],
                        [ -4886,  -5926],
                        [ -4767,  -5850],
                        [ -4654,  -5783],
                        [ -4542,  -5726],
                        [ -4431,  -5675],
                        [ -4323,  -5627],
                        [ -4214,  -5583],
                        [ -4106,  -5536],
                        [ -3998,  -5486],
                        [ -3887,  -5430],
                        [ -3771,  -5365],
                        [ -3648,  -5288],
                        [ -3518,  -5198],
                        [ -3378,  -5093],
                        [ -3228,  -4972],
                        [ -3066,  -4830],
                        [ -2889,  -4669],
                        [ -2700,  -4488],
                        [ -2497,  -4287],
                        [ -2278,  -4063],
                        [ -2048,  -3817],
                        [ -1803,  -3551],
                        [ -1546,  -3265],
                        [ -1276,  -2959],
                        [  -994,  -2636],
                        [  -704,  -2300],
                        [  -401,  -1947],
                        [   -84,  -1578],
                        [   175,  -1267],
                        [   277,  -1110],
                        [   182,  -1149],
                        [  -116,  -1391],
                        [  -631,  -1848],
                        [ -1370,  -2529],
                        [ -2241,  -3339],
                        [ -3092,  -4132],
                        [ -3867,  -4852],
                        [ -4570,  -5508],
                        [ -5199,  -6094],
                        [ -5747,  -6606],
                        [ -6215,  -7043],
                        [ -6606,  -7404],
                        [ -6925,  -7692],
                        [ -7176,  -7908],
                        [ -7365,  -8056],
                        [ -7494,  -8141],
                        [ -7570,  -8167],
                        [ -7597,  -8139],
                        [ -7581,  -8063],
                        [ -7525,  -7943],
                        [ -7435,  -7785],
                        [ -7317,  -7597],
                        [ -7177,  -7382],
                        [ -7016,  -7145],
                        [ -6840,  -6892],
                        [ -6650,  -6628],
                        [ -6451,  -6353],
                        [ -6243,  -6072],
                        [ -6030,  -5787],
                        [ -5810,  -5498],
                        [ -5588,  -5208],
                        [ -5363,  -4914],
                        [ -5134,  -4618],
                        [ -4904,  -4322],
                        [ -4672,  -4022],
                        [ -4437,  -3721],
                        [ -4200,  -3418],
                        [ -3959,  -3115],
                        [ -3712,  -2811],
                        [ -3461,  -2512],
                        [ -3205,  -2217],
                        [ -2941,  -1931],
                        [ -2670,  -1653],
                        [ -2392,  -1380],
                        [ -2106,  -1112],
                        [ -1814,   -837],
                        [ -1512,   -556],
                        [ -1206,   -262],
                        [  -894,     45],
                        [  -579,    360],
                        [  -262,    685],
                        [    52,   1011],
                        [   365,   1339],
                        [   671,   1662],
                        [   971,   1982],
                        [  1263,   2291],
                        [  1547,   2591],
                        [  1823,   2882],
                        [  2090,   3163],
                        [  2349,   3436],
                        [  2598,   3699],
                        [  2845,   3951],
                        [  3088,   4189],
                        [  3330,   4411],
                        [  3572,   4617],
                        [  3804,   4799],
                        [  4027,   4958],
                        [  4224,   5092],
                        [  4396,   5200],
                        [  4534,   5281],
                        [  4635,   5334],
                        [  4705,   5363],
                        [  4743,   5367],
                        [  4772,   5371],
                        [  4790,   5371],
                        [  4806,   5378],
                        [  4821,   5392],
                        [  4809,   5383],
                        [  4772,   5355],
                        [  4677,   5273],
                        [  4526,   5140],
                        [  4331,   4962],
                        [  4088,   4739],
                        [  3811,   4483],
                        [  3502,   4194],
                        [  3172,   3885],
                        [  2822,   3556],
                        [  2463,   3218],
                        [  2095,   2872],
                        [  1730,   2529],
                        [  1367,   2187],
                        [  1014,   1857],
                        [   673,   1538],
                        [   349,   1237],
                        [    44,    953],
                        [  -242,    691],
                        [  -508,    451],
                        [  -754,    235],
                        [  -980,     41],
                        [ -1183,   -129],
                        [ -1363,   -279],
                        [ -1519,   -407],
                        [ -1655,   -515],
                        [ -1770,   -608],
                        [ -1865,   -685],
                        [ -1944,   -750],
                        [ -2008,   -804],
                        [ -2060,   -853],
                        [ -2103,   -898],
                        [ -2140,   -943],
                        [ -2173,   -989],
                        [ -2205,  -1041],
                        [ -2240,  -1100],
                        [ -2281,  -1172],
                        [ -2328,  -1256],
                        [ -2386,  -1356],
                        [ -2459,  -1476],
                        [ -2549,  -1615],
                        [ -2652,  -1773],
                        [ -2783,  -1958],
                        [ -2937,  -2168],
                        [ -3040,  -2327],
                        [ -3001,  -2342],
                        [ -2792,  -2185],
                        [ -2408,  -1853],
                        [ -1832,  -1327],
                        [ -1051,   -596],
                        [  -161,    248],
                        [   687,   1051],
                        [  1432,   1760],
                        [  2083,   2381],
                        [  2629,   2907],
                        [  3062,   3330],
                        [  3381,   3644],
                        [  3585,   3851],
                        [  3681,   3949],
                        [  3670,   3937],
                        [  3560,   3823],
                        [  3356,   3608],
                        [  3064,   3302],
                        [  2689,   2909],
                        [  2243,   2438],
                        [  1731,   1896],
                        [  1163,   1293],
                        [   548,    637],
                        [  -106,    -61],
                        [  -787,   -792],
                        [ -1489,  -1547],
                        [ -2203,  -2316],
                        [ -2920,  -3092],
                        [ -3635,  -3868],
                        [ -4341,  -4635],
                        [ -5030,  -5388],
                        [ -5698,  -6121],
                        [ -6339,  -6830],
                        [ -6948,  -7509],
                        [ -7521,  -8156],
                        [ -8053,  -8765],
                        [ -8543,  -9336],
                        [ -8989,  -9862],
                        [ -9389, -10344],
                        [ -9743, -10773],
                        [-10050, -11152],
                        [-10310, -11468],
                        [-10524, -11725],
                        [-10693, -11920],
                        [-10818, -12053],
                        [-10901, -12135],
                        [-10944, -12167],
                        [-10948, -12165],
                        [-10917, -12130],
                        [-10851, -12069],
                        [-10753, -11985],
                        [-10624, -11876],
                        [-10467, -11746],
                        [-10283, -11596],
                        [-10075, -11427],
                        [ -9846, -11240],
                        [ -9600, -11038],
                        [ -9341, -10822],
                        [ -9072, -10594],
                        [ -8800, -10363],
                        [ -8527, -10129],
                        [ -8262,  -9897],
                        [ -8008,  -9668],
                        [ -7776,  -9445],
                        [ -7568,  -9230],
                        [ -7386,  -9021],
                        [ -7231,  -8820],
                        [ -7092,  -8622],
                        [ -6970,  -8431],
                        [ -6849,  -8245],
                        [ -6731,  -8066],
                        [ -6612,  -7893],
                        [ -6494,  -7727],
                        [ -6398,  -7590],
                        [ -6323,  -7482],
                        [ -6296,  -7431],
                        [ -6315,  -7434],
                        [ -6368,  -7478],
                        [ -6457,  -7567],
                        [ -6528,  -7643],
                        [ -6583,  -7709],
                        [ -6593,  -7735],
                        [ -6558,  -7720],
                        [ -6486,  -7671],
                        [ -6373,  -7582],
                        [ -6226,  -7462],
                        [ -6043,  -7308],
                        [ -5831,  -7127],
                        [ -5586,  -6917],
                        [ -5317,  -6685],
                        [ -5020,  -6429],
                        [ -4704,  -6156],
                        [ -4367,  -5862],
                        [ -4018,  -5555],
                        [ -3654,  -5233],
                        [ -3280,  -4900],
                        [ -2894,  -4556],
                        [ -2496,  -4202],
                        [ -2084,  -3839],
                        [ -1662,  -3469],
                        [ -1229,  -3092],
                        [  -789,  -2707],
                        [  -343,  -2316],
                        [   108,  -1919],
                        [   563,  -1517],
                        [  1020,  -1111],
                        [  1476,   -700],
                        [  1932,   -284],
                        [  2386,    132],
                        [  2834,    553],
                        [  3278,    973],
                        [  3714,   1393],
                        [  4141,   1811],
                        [  4557,   2228],
                        [  4962,   2639],
                        [  5351,   3044],
                        [  5725,   3441],
                        [  6082,   3829],
                        [  6419,   4205],
                        [  6732,   4563],
                        [  7029,   4911],
                        [  7300,   5237],
                        [  7464,   5460],
                        [  7441,   5500],
                        [  7209,   5334],
                        [  6766,   4959],
                        [  6082,   4346],
                        [  5140,   3477],
                        [  4028,   2439],
                        [  2896,   1380],
                        [  1791,    346],
                        [   715,   -665],
                        [  -321,  -1644],
                        [ -1300,  -2573],
                        [ -2217,  -3447],
                        [ -3066,  -4255],
                        [ -3843,  -4996],
                        [ -4548,  -5659],
                        [ -5180,  -6246],
                        [ -5737,  -6753],
                        [ -6218,  -7180],
                        [ -6624,  -7529],
                        [ -6957,  -7799],
                        [ -7217,  -7994],
                        [ -7408,  -8115],
                        [ -7533,  -8167],
                        [ -7595,  -8153],
                        [ -7599,  -8076],
                        [ -7546,  -7941],
                        [ -7440,  -7753],
                        [ -7287,  -7516],
                        [ -7087,  -7232],
                        [ -6846,  -6907],
                        [ -6565,  -6544],
                        [ -6249,  -6145],
                        [ -5902,  -5714],
                        [ -5525,  -5254],
                        [ -5124,  -4769],
                        [ -4701,  -4262],
                        [ -4259,  -3734],
                        [ -3800,  -3192],
                        [ -3327,  -2638],
                        [ -2843,  -2078],
                        [ -2351,  -1521],
                        [ -1851,   -969],
                        [ -1347,   -435],
                        [  -841,     82],
                        [  -336,    579],
                        [   167,   1055],
                        [   665,   1521],
                        [  1156,   1974],
                        [  1637,   2425],
                        [  2106,   2869],
                        [  2558,   3305],
                        [  2992,   3733],
                        [  3404,   4149],
                        [  3794,   4552],
                        [  4154,   4936],
                        [  4488,   5302],
                        [  4794,   5642],
                        [  5071,   5956],
                        [  5320,   6243],
                        [  5541,   6503],
                        [  5738,   6737],
                        [  5909,   6944],
                        [  6066,   7125],
                        [  6209,   7280],
                        [  6343,   7408],
                        [  6468,   7507],
                        [  6580,   7575],
                        [  6678,   7614],
                        [  6745,   7619],
                        [  6784,   7591],
                        [  6785,   7534],
                        [  6751,   7447],
                        [  6695,   7344],
                        [  6616,   7226],
                        [  6563,   7140],
                        [  6533,   7086],
                        [  6538,   7076],
                        [  6581,   7111],
                        [  6634,   7161],
                        [  6699,   7230],
                        [  6713,   7253],
                        [  6681,   7235],
                        [  6601,   7169],
                        [  6472,   7057],
                        [  6305,   6907],
                        [  6099,   6719],
                        [  5863,   6503],
                        [  5598,   6259],
                        [  5311,   5995],
                        [  5003,   5712],
                        [  4685,   5420],
                        [  4357,   5119],
                        [  4029,   4817],
                        [  3703,   4512],
                        [  3387,   4213],
                        [  3081,   3918],
                        [  2784,   3633],
                        [  2498,   3356],
                        [  2217,   3092],
                        [  1944,   2837],
                        [  1678,   2595],
                        [  1419,   2364],
                        [  1168,   2142],
                        [   925,   1929],
                        [   689,   1723],
                        [   458,   1525],
                        [   232,   1329],
                        [    11,   1137],
                        [  -210,    943],
                        [  -428,    749],
                        [  -649,    549],
                        [  -871,    345],
                        [ -1098,    132],
                        [ -1330,    -91],
                        [ -1570,   -326],
                        [ -1815,   -570],
                        [ -2070,   -830],
                        [ -2335,  -1103],
                        [ -2609,  -1389],
                        [ -2889,  -1686],
                        [ -3187,  -2004],
                        [ -3486,  -2325],
                        [ -3716,  -2580],
                        [ -3812,  -2702],
                        [ -3764,  -2682],
                        [ -3566,  -2513],
                        [ -3186,  -2164],
                        [ -2596,  -1606],
                        [ -1873,   -915],
                        [ -1146,   -219],
                        [  -456,    444],
                        [   200,   1077],
                        [   808,   1670],
                        [  1353,   2208],
                        [  1831,   2684],
                        [  2239,   3095],
                        [  2576,   3434],
                        [  2838,   3698],
                        [  3031,   3885],
                        [  3154,   3998],
                        [  3209,   4037],
                        [  3199,   4007],
                        [  3129,   3911],
                        [  3004,   3754],
                        [  2829,   3541],
                        [  2611,   3279],
                        [  2356,   2974],
                        [  2071,   2632],
                        [  1762,   2260],
                        [  1436,   1865],
                        [  1098,   1455],
                        [   754,   1035],
                        [   410,    613],
                        [    70,    191],
                        [  -262,   -224],
                        [  -579,   -629],
                        [  -879,  -1020],
                        [ -1157,  -1392],
                        [ -1412,  -1744],
                        [ -1640,  -2070],
                        [ -1842,  -2370],
                        [ -2014,  -2641],
                        [ -2158,  -2876],
                        [ -2272,  -3076],
                        [ -2357,  -3230],
                        [ -2414,  -3337],
                        [ -2443,  -3395],
                        [ -2447,  -3404],
                        [ -2426,  -3375],
                        [ -2383,  -3307],
                        [ -2319,  -3218],
                        [ -2235,  -3109],
                        [ -2135,  -2991],
                        [ -2019,  -2863],
                        [ -1887,  -2730],
                        [ -1743,  -2594],
                        [ -1587,  -2459],
                        [ -1419,  -2325],
                        [ -1246,  -2189],
                        [ -1067,  -2055],
                        [  -886,  -1920],
                        [  -704,  -1786],
                        [  -529,  -1655],
                        [  -359,  -1529],
                        [  -206,  -1411],
                        [   -68,  -1302],
                        [    42,  -1203],
                        [   126,  -1112],
                        [   182,  -1031],
                        [   212,   -957],
                        [   228,   -886],
                        [   230,   -816],
                        [   237,   -744],
                        [   245,   -674],
                        [   259,   -605],
                        [   280,   -535],
                        [   269,   -505],
                        [   231,   -509],
                        [   132,   -583],
                        [   -24,   -722],
                        [  -229,   -918],
                        [  -483,  -1172],
                        [  -717,  -1413],
                        [  -935,  -1645],
                        [ -1088,  -1817],
                        [ -1177,  -1930],
                        [ -1207,  -1984],
                        [ -1172,  -1979],
                        [ -1078,  -1916],
                        [  -922,  -1794],
                        [  -709,  -1619],
                        [  -436,  -1388],
                        [  -111,  -1109],
                        [   266,   -782],
                        [   682,   -414],
                        [  1138,     -4],
                        [  1622,    438],
                        [  2131,    913],
                        [  2661,   1415],
                        [  3211,   1940],
                        [  3779,   2483],
                        [  4366,   3044],
                        [  4968,   3613],
                        [  5585,   4193],
                        [  6208,   4776],
                        [  6836,   5361],
                        [  7461,   5944],
                        [  8084,   6523],
                        [  8696,   7092],
                        [  9297,   7652],
                        [  9882,   8198],
                        [ 10446,   8727],
                        [ 10989,   9238],
                        [ 11506,   9729],
                        [ 11993,  10195],
                        [ 12449,  10636],
                        [ 12872,  11051],
                        [ 13261,  11435],
                        [ 13609,  11788],
                        [ 13917,  12107],
                        [ 14186,  12393],
                        [ 14408,  12641],
                        [ 14584,  12848],
                        [ 14721,  13023],
                        [ 14802,  13148],
                        [ 14766,  13162],
                        [ 14575,  13024],
                        [ 14226,  12733],
                        [ 13714,  12283],
                        [ 13004,  11637],
                        [ 12067,  10767],
                        [ 10963,   9732],
                        [  9804,   8642],
                        [  8622,   7528],
                        [  7425,   6393],
                        [  6232,   5255],
                        [  5061,   4135],
                        [  3925,   3042],
                        [  2834,   1990],
                        [  1800,    990],
                        [   828,     55],
                        [   -75,   -808],
                        [  -902,  -1595],
                        [ -1649,  -2299],
                        [ -2312,  -2918],
                        [ -2891,  -3448],
                        [ -3382,  -3890],
                        [ -3786,  -4243],
                        [ -4105,  -4506],
                        [ -4340,  -4681],
                        [ -4493,  -4771],
                        [ -4569,  -4779],
                        [ -4569,  -4710],
                        [ -4499,  -4567],
                        [ -4362,  -4357],
                        [ -4162,  -4082],
                        [ -3907,  -3750],
                        [ -3597,  -3364],
                        [ -3241,  -2930],
                        [ -2844,  -2453],
                        [ -2411,  -1939],
                        [ -1948,  -1393],
                        [ -1458,   -821],
                        [  -950,   -229],
                        [  -427,    375],
                        [   108,    987],
                        [   648,   1593],
                        [  1190,   2189],
                        [  1727,   2760],
                        [  2259,   3304],
                        [  2779,   3818],
                        [  3286,   4297],
                        [  3775,   4751],
                        [  4244,   5173],
                        [  4689,   5578],
                        [  5108,   5961],
                        [  5497,   6322],
                        [  5856,   6662],
                        [  6180,   6983],
                        [  6468,   7282],
                        [  6719,   7555],
                        [  6931,   7805],
                        [  7108,   8022],
                        [  7245,   8206],
                        [  7349,   8356],
                        [  7417,   8472],
                        [  7458,   8556],
                        [  7471,   8611],
                        [  7469,   8637],
                        [  7450,   8636],
                        [  7425,   8610],
                        [  7391,   8560],
                        [  7349,   8484],
                        [  7299,   8384],
                        [  7225,   8257],
                        [  7132,   8106],
                        [  7015,   7934],
                        [  6876,   7745],
                        [  6736,   7559],
                        [  6597,   7378],
                        [  6511,   7258],
                        [  6480,   7199],
                        [  6515,   7212],
                        [  6619,   7299],
                        [  6763,   7434],
                        [  6953,   7619],
                        [  7105,   7772],
                        [  7229,   7898],
                        [  7311,   7986],
                        [  7353,   8036],
                        [  7356,   8049],
                        [  7321,   8023],
                        [  7248,   7963],
                        [  7138,   7869],
                        [  6995,   7745],
                        [  6817,   7590],
                        [  6614,   7412],
                        [  6384,   7207],
                        [  6142,   6983],
                        [  5885,   6739],
                        [  5620,   6479],
                        [  5348,   6203],
                        [  5066,   5915],
                        [  4773,   5614],
                        [  4464,   5304],
                        [  4140,   4985],
                        [  3800,   4657],
                        [  3444,   4320],
                        [  3077,   3976],
                        [  2696,   3624],
                        [  2303,   3264],
                        [  1899,   2897],
                        [  1484,   2522],
                        [  1060,   2139],
                        [   627,   1749],
                        [   186,   1351],
                        [  -262,    944],
                        [  -718,    530],
                        [ -1179,    108],
                        [ -1646,   -320],
                        [ -2117,   -755],
                        [ -2589,  -1193],
                        [ -3060,  -1635],
                        [ -3530,  -2079],
                        [ -3993,  -2522],
                        [ -4448,  -2960],
                        [ -4900,  -3400],
                        [ -5328,  -3820],
                        [ -5693,  -4182],
                        [ -5972,  -4462],
                        [ -6169,  -4663],
                        [ -6271,  -4773],
                        [ -6240,  -4754],
                        [ -6035,  -4564],
                        [ -5690,  -4235],
                        [ -5281,  -3845],
                        [ -4833,  -3413],
                        [ -4344,  -2941],
                        [ -3835,  -2444],
                        [ -3316,  -1935],
                        [ -2797,  -1422],
                        [ -2286,   -913],
                        [ -1791,   -420],
                        [ -1317,     51],
                        [  -867,    493],
                        [  -444,    904],
                        [   -52,   1281],
                        [   306,   1621],
                        [   630,   1923],
                        [   921,   2187],
                        [  1178,   2413],
                        [  1403,   2602],
                        [  1599,   2754],
                        [  1767,   2871],
                        [  1909,   2958],
                        [  2029,   3014],
                        [  2128,   3046],
                        [  2210,   3056],
                        [  2276,   3046],
                        [  2329,   3021],
                        [  2372,   2983],
                        [  2406,   2933],
                        [  2434,   2875],
                        [  2459,   2811],
                        [  2481,   2744],
                        [  2504,   2674],
                        [  2528,   2605],
                        [  2552,   2537],
                        [  2578,   2478],
                        [  2607,   2426],
                        [  2637,   2394],
                        [  2670,   2378],
                        [  2704,   2386],
                        [  2741,   2416],
                        [  2777,   2464],
                        [  2814,   2529],
                        [  2850,   2598],
                        [  2886,   2672],
                        [  2921,   2740],
                        [  2953,   2802],
                        [  2986,   2851],
                        [  3016,   2887],
                        [  3045,   2909],
                        [  3073,   2915],
                        [  3099,   2912],
                        [  3124,   2898],
                        [  3147,   2881],
                        [  3167,   2861],
                        [  3183,   2837],
                        [  3196,   2811],
                        [  3196,   2780],
                        [  3187,   2745],
                        [  3161,   2709],
                        [  3119,   2669],
                        [  3062,   2628],
                        [  2991,   2588],
                        [  2917,   2555],
                        [  2843,   2533],
                        [  2782,   2520],
                        [  2732,   2518],
                        [  2693,   2524],
                        [  2670,   2538],
                        [  2614,   2515],
                        [  2531,   2459],
                        [  2391,   2340],
                        [  2197,   2160],
                        [  1951,   1922],
                        [  1652,   1623],
                        [  1370,   1336],
                        [  1101,   1055],
                        [   895,    834],
                        [   751,    671],
                        [   670,    569],
                        [   651,    527],
                        [   697,    547],
                        [   808,    630],
                        [   983,    772],
                        [  1220,    972],
                        [  1513,   1224],
                        [  1861,   1530],
                        [  2249,   1880],
                        [  2676,   2273],
                        [  3128,   2703],
                        [  3603,   3167],
                        [  4096,   3655],
                        [  4604,   4167],
                        [  5126,   4693],
                        [  5662,   5232],
                        [  6208,   5774],
                        [  6763,   6319],
                        [  7317,   6858],
                        [  7867,   7391],
                        [  8405,   7908],
                        [  8932,   8409],
                        [  9438,   8888],
                        [  9921,   9342],
                        [ 10376,   9768],
                        [ 10801,  10162],
                        [ 11190,  10524],
                        [ 11542,  10849],
                        [ 11853,  11135],
                        [ 12122,  11381],
                        [ 12348,  11586],
                        [ 12528,  11748],
                        [ 12660,  11867],
                        [ 12743,  11940],
                        [ 12777,  11969],
                        [ 12757,  11950],
                        [ 12686,  11887],
                        [ 12568,  11780],
                        [ 12391,  11622],
                        [ 12142,  11396],
                        [ 11826,  11108],
                        [ 11451,  10765],
                        [ 11012,  10362],
                        [ 10473,   9861],
                        [  9791,   9222],
                        [  8976,   8450],
                        [  8081,   7599],
                        [  7126,   6689],
                        [  6120,   5726],
                        [  5082,   4728],
                        [  4032,   3714],
                        [  2982,   2696],
                        [  1947,   1689],
                        [   939,    706],
                        [   -29,   -238],
                        [  -951,  -1136],
                        [ -1815,  -1978],
                        [ -2617,  -2757],
                        [ -3349,  -3467],
                        [ -4006,  -4103],
                        [ -4587,  -4662],
                        [ -5090,  -5142],
                        [ -5511,  -5538],
                        [ -5853,  -5851],
                        [ -6117,  -6082],
                        [ -6305,  -6233],
                        [ -6419,  -6307],
                        [ -6462,  -6307],
                        [ -6440,  -6240],
                        [ -6356,  -6108],
                        [ -6216,  -5919],
                        [ -6024,  -5676],
                        [ -5787,  -5386],
                        [ -5509,  -5055],
                        [ -5198,  -4689],
                        [ -4860,  -4293],
                        [ -4499,  -3875],
                        [ -4123,  -3439],
                        [ -3735,  -2994],
                        [ -3342,  -2545],
                        [ -2949,  -2104],
                        [ -2559,  -1675],
                        [ -2179,  -1272],
                        [ -1812,   -895],
                        [ -1461,   -553],
                        [ -1129,   -248],
                        [  -820,     25],
                        [  -534,    262],
                        [  -275,    474],
                        [   -44,    657],
                        [   158,    819],
                        [   329,    959],
                        [   468,   1081],
                        [   575,   1185],
                        [   651,   1269],
                        [   694,   1334],
                        [   707,   1374],
                        [   689,   1389],
                        [   644,   1376],
                        [   573,   1336],
                        [   483,   1273],
                        [   375,   1190],
                        [   258,   1091],
                        [   135,    977],
                        [    11,    850],
                        [  -111,    713],
                        [  -230,    566],
                        [  -345,    411],
                        [  -467,    245],
                        [  -592,     72],
                        [  -721,   -103],
                        [  -851,   -280],
                        [  -960,   -433],
                        [ -1048,   -562],
                        [ -1066,   -618],
                        [ -1017,   -605],
                        [  -891,   -509],
                        [  -687,   -331],
                        [  -423,    -89],
                        [   -99,    217],
                        [   206,    508],
                        [   496,    788],
                        [   759,   1042],
                        [   994,   1271],
                        [  1192,   1465],
                        [  1354,   1625],
                        [  1476,   1748],
                        [  1554,   1831],
                        [  1589,   1876],
                        [  1579,   1880],
                        [  1529,   1844],
                        [  1440,   1769],
                        [  1320,   1654],
                        [  1168,   1501],
                        [   990,   1311],
                        [   782,   1083],
                        [   545,    822],
                        [   275,    527],
                        [   -32,    203],
                        [  -378,   -153],
                        [  -758,   -535],
                        [ -1173,   -944],
                        [ -1619,  -1376],
                        [ -2094,  -1831],
                        [ -2594,  -2303],
                        [ -3120,  -2794],
                        [ -3664,  -3300],
                        [ -4227,  -3818],
                        [ -4802,  -4346],
                        [ -5389,  -4882],
                        [ -5982,  -5423],
                        [ -6580,  -5966],
                        [ -7178,  -6509],
                        [ -7776,  -7048],
                        [ -8366,  -7581],
                        [ -8945,  -8103],
                        [ -9509,  -8613],
                        [-10053,  -9106],
                        [-10571,  -9578],
                        [-11062, -10025],
                        [-11521, -10447],
                        [-11943, -10837],
                        [-12336, -11203],
                        [-12717, -11564],
                        [-13095, -11924],
                        [-13456, -12274],
                        [-13765, -12574],
                        [-13963, -12769],
                        [-14025, -12830],
                        [-13968, -12777],
                        [-13804, -12620],
                        [-13539, -12361],
                        [-13183, -12014],
                        [-12751, -11593],
                        [-12253, -11104],
                        [-11698, -10559],
                        [-11098,  -9969],
                        [-10464,  -9344],
                        [ -9804,  -8694],
                        [ -9124,  -8025],
                        [ -8434,  -7346],
                        [ -7739,  -6663],
                        [ -7047,  -5982],
                        [ -6360,  -5309],
                        [ -5687,  -4651],
                        [ -5029,  -4011],
                        [ -4390,  -3394],
                        [ -3772,  -2804],
                        [ -3179,  -2243],
                        [ -2612,  -1713],
                        [ -2073,  -1214],
                        [ -1562,   -747],
                        [ -1080,   -313],
                        [  -628,     90],
                        [  -206,    461],
                        [   185,    800],
                        [   546,   1107],
                        [   879,   1385],
                        [  1183,   1632],
                        [  1458,   1851],
                        [  1707,   2042],
                        [  1929,   2207],
                        [  2126,   2349],
                        [  2297,   2471],
                        [  2446,   2578],
                        [  2571,   2672],
                        [  2674,   2758],
                        [  2756,   2835],
                        [  2817,   2907],
                        [  2860,   2975],
                        [  2884,   3031],
                        [  2890,   3077],
                        [  2881,   3105],
                        [  2857,   3115],
                        [  2819,   3102],
                        [  2769,   3067],
                        [  2709,   3010],
                        [  2641,   2932],
                        [  2568,   2838],
                        [  2492,   2732],
                        [  2414,   2624],
                        [  2337,   2516],
                        [  2260,   2407],
                        [  2184,   2300],
                        [  2108,   2195],
                        [  2034,   2095],
                        [  1958,   1999],
                        [  1883,   1909],
                        [  1808,   1827],
                        [  1731,   1752],
                        [  1662,   1691],
                        [  1604,   1645],
                        [  1561,   1616],
                        [  1532,   1603],
                        [  1515,   1600],
                        [  1511,   1610],
                        [  1483,   1590],
                        [  1431,   1547],
                        [  1337,   1458],
                        [  1202,   1326],
                        [  1017,   1140],
                        [   783,    902],
                        [   554,    664],
                        [   324,    422],
                        [   137,    220],
                        [   -13,     55],
                        [  -119,    -67],
                        [  -184,   -149],
                        [  -199,   -184],
                        [  -170,   -175],
                        [   -92,   -120],
                        [    33,    -22],
                        [   199,    117],
                        [   405,    295],
                        [   637,    508],
                        [   895,    753],
                        [  1167,   1025],
                        [  1451,   1321],
                        [  1744,   1635],
                        [  2043,   1964],
                        [  2351,   2300],
                        [  2664,   2643],
                        [  2982,   2984],
                        [  3303,   3320],
                        [  3616,   3645],
                        [  3921,   3958],
                        [  4214,   4251],
                        [  4492,   4524],
                        [  4747,   4772],
                        [  4980,   4991],
                        [  5184,   5180],
                        [  5359,   5335],
                        [  5502,   5455],
                        [  5611,   5539],
                        [  5685,   5585],
                        [  5723,   5593],
                        [  5724,   5562],
                        [  5686,   5493],
                        [  5608,   5383],
                        [  5491,   5234],
                        [  5333,   5046],
                        [  5135,   4821],
                        [  4898,   4561],
                        [  4619,   4262],
                        [  4313,   3940],
                        [  4017,   3632],
                        [  3769,   3376],
                        [  3581,   3182],
                        [  3446,   3044],
                        [  3338,   2936],
                        [  3195,   2795],
                        [  2960,   2563],
                        [  2632,   2238],
                        [  2221,   1833],
                        [  1736,   1355],
                        [  1190,    817],
                        [   596,    231],
                        [   -37,   -392],
                        [  -692,  -1040],
                        [ -1359,  -1702],
                        [ -2026,  -2367],
                        [ -2683,  -3024],
                        [ -3322,  -3666],
                        [ -3933,  -4284],
                        [ -4513,  -4872],
                        [ -5054,  -5424],
                        [ -5552,  -5935],
                        [ -6004,  -6401],
                        [ -6406,  -6815],
                        [ -6757,  -7177],
                        [ -7057,  -7484],
                        [ -7306,  -7737],
                        [ -7505,  -7937],
                        [ -7656,  -8085],
                        [ -7762,  -8186],
                        [ -7825,  -8240],
                        [ -7848,  -8253],
                        [ -7834,  -8227],
                        [ -7789,  -8169],
                        [ -7716,  -8080],
                        [ -7620,  -7967],
                        [ -7505,  -7833],
                        [ -7375,  -7682],
                        [ -7235,  -7520],
                        [ -7088,  -7352],
                        [ -6940,  -7179],
                        [ -6792,  -7011],
                        [ -6650,  -6850],
                        [ -6514,  -6702],
                        [ -6389,  -6572],
                        [ -6275,  -6462],
                        [ -6175,  -6376],
                        [ -6089,  -6315],
                        [ -6019,  -6281],
                        [ -5964,  -6265],
                        [ -5925,  -6269],
                        [ -5901,  -6284],
                        [ -5892,  -6309],
                        [ -5898,  -6339],
                        [ -5917,  -6373],
                        [ -5951,  -6411],
                        [ -6004,  -6459],
                        [ -6072,  -6518],
                        [ -6152,  -6587],
                        [ -6243,  -6667],
                        [ -6342,  -6756],
                        [ -6445,  -6849],
                        [ -6550,  -6945],
                        [ -6651,  -7040],
                        [ -6748,  -7131],
                        [ -6834,  -7215],
                        [ -6906,  -7291],
                        [ -6960,  -7355],
                        [ -6996,  -7408],
                        [ -7018,  -7451],
                        [ -7022,  -7482],
                        [ -7010,  -7499],
                        [ -6979,  -7499],
                        [ -6917,  -7468],
                        [ -6825,  -7407],
                        [ -6676,  -7291],
                        [ -6473,  -7120],
                        [ -6209,  -6885],
                        [ -5883,  -6589],
                        [ -5504,  -6235],
                        [ -5070,  -5825],
                        [ -4641,  -5416],
                        [ -4214,  -5008],
                        [ -3807,  -4617],
                        [ -3417,  -4241],
                        [ -3060,  -3896],
                        [ -2736,  -3581],
                        [ -2454,  -3305],
                        [ -2218,  -3072],
                        [ -2031,  -2884],
                        [ -1896,  -2742],
                        [ -1805,  -2649],
                        [ -1763,  -2605],
                        [ -1763,  -2611],
                        [ -1805,  -2665],
                        [ -1887,  -2769],
                        [ -2010,  -2920],
                        [ -2174,  -3116],
                        [ -2381,  -3357],
                        [ -2636,  -3638],
                        [ -2937,  -3958],
                        [ -3278,  -4310],
                        [ -3659,  -4696],
                        [ -4074,  -5108],
                        [ -4526,  -5549],
                        [ -5004,  -6010],
                        [ -5508,  -6488],
                        [ -6028,  -6977],
                        [ -6563,  -7474],
                        [ -7106,  -7973],
                        [ -7655,  -8473],
                        [ -8201,  -8965],
                        [ -8743,  -9449],
                        [ -9272,  -9917],
                        [ -9788, -10367],
                        [-10283, -10793],
                        [-10753, -11194],
                        [-11189, -11562],
                        [-11590, -11897],
                        [-11950, -12193],
                        [-12274, -12456],
                        [-12544, -12669],
                        [-12786, -12859],
                        [-13056, -13082],
                        [-13395, -13379],
                        [-13809, -13756],
                        [-14291, -14207],
                        [-14818, -14705],
                        [-15314, -15176],
                        [-15686, -15527],
                        [-15912, -15734],
                        [-15997, -15806],
                        [-15945, -15745],
                        [-15763, -15561],
                        [-15463, -15263],
                        [-15053, -14860],
                        [-14544, -14359],
                        [-13950, -13774],
                        [-13284, -13114],
                        [-12555, -12391],
                        [-11775, -11613],
                        [-10956, -10793],
                        [-10105,  -9941],
                        [ -9235,  -9065],
                        [ -8352,  -8174],
                        [ -7467,  -7280],
                        [ -6587,  -6391],
                        [ -5719,  -5515],
                        [ -4869,  -4660],
                        [ -4044,  -3831],
                        [ -3248,  -3033],
                        [ -2485,  -2272],
                        [ -1760,  -1549],
                        [ -1075,   -869],
                        [  -431,   -231],
                        [   168,    362],
                        [   723,    911],
                        [  1233,   1413],
                        [  1696,   1870],
                        [  2114,   2280],
                        [  2489,   2646],
                        [  2820,   2966],
                        [  3109,   3246],
                        [  3360,   3485],
                        [  3572,   3686],
                        [  3749,   3851],
                        [  3893,   3984],
                        [  4005,   4089],
                        [  4089,   4167],
                        [  4146,   4228],
                        [  4180,   4273],
                        [  4192,   4305],
                        [  4184,   4326],
                        [  4160,   4330],
                        [  4121,   4321],
                        [  4069,   4293],
                        [  4006,   4249],
                        [  3938,   4190],
                        [  3866,   4119],
                        [  3794,   4041],
                        [  3725,   3959],
                        [  3664,   3883],
                        [  3610,   3816],
                        [  3567,   3756],
                        [  3536,   3707],
                        [  3520,   3669],
                        [  3520,   3644],
                        [  3535,   3632],
                        [  3567,   3633],
                        [  3608,   3647],
                        [  3660,   3673],
                        [  3722,   3712],
                        [  3794,   3768],
                        [  3876,   3837],
                        [  3965,   3917],
                        [  4058,   4004],
                        [  4155,   4098],
                        [  4236,   4177],
                        [  4300,   4243],
                        [  4340,   4287],
                        [  4356,   4307],
                        [  4327,   4284],
                        [  4256,   4217],
                        [  4162,   4128],
                        [  4044,   4015],
                        [  3928,   3903],
                        [  3812,   3790],
                        [  3702,   3685],
                        [  3595,   3584],
                        [  3502,   3495],
                        [  3418,   3417],
                        [  3350,   3352],
                        [  3296,   3301],
                        [  3254,   3265],
                        [  3224,   3241],
                        [  3200,   3230],
                        [  3180,   3231],
                        [  3159,   3240],
                        [  3137,   3258],
                        [  3113,   3282],
                        [  3083,   3309],
                        [  3056,   3336],
                        [  3028,   3364],
                        [  3001,   3386],
                        [  2971,   3402],
                        [  2938,   3409],
                        [  2898,   3405],
                        [  2851,   3387],
                        [  2796,   3353],
                        [  2728,   3302],
                        [  2648,   3232],
                        [  2554,   3141],
                        [  2445,   3031],
                        [  2320,   2897],
                        [  2179,   2742],
                        [  2022,   2564],
                        [  1851,   2365],
                        [  1662,   2144],
                        [  1455,   1902],
                        [  1232,   1639],
                        [   992,   1357],
                        [   734,   1055],
                        [   460,    739],
                        [   169,    405],
                        [  -141,     54],
                        [  -427,   -272],
                        [  -607,   -489],
                        [  -636,   -553],
                        [  -505,   -457],
                        [  -214,   -197],
                        [   224,    210],
                        [   725,    682],
                        [  1171,   1099],
                        [  1523,   1424],
                        [  1791,   1666],
                        [  1974,   1828],
                        [  2074,   1913],
                        [  2098,   1926],
                        [  2050,   1874],
                        [  1941,   1761],
                        [  1779,   1595],
                        [  1572,   1381],
                        [  1330,   1128],
                        [  1059,    841],
                        [   765,    527],
                        [   456,    193],
                        [   134,   -158],
                        [  -193,   -516],
                        [  -519,   -878],
                        [  -843,  -1237],
                        [ -1160,  -1590],
                        [ -1467,  -1932],
                        [ -1762,  -2262],
                        [ -2044,  -2576],
                        [ -2312,  -2875],
                        [ -2565,  -3157],
                        [ -2803,  -3422],
                        [ -3026,  -3673],
                        [ -3236,  -3907],
                        [ -3431,  -4128],
                        [ -3615,  -4336],
                        [ -3786,  -4530],
                        [ -3948,  -4713],
                        [ -4102,  -4887],
                        [ -4248,  -5052],
                        [ -4388,  -5209],
                        [ -4524,  -5360],
                        [ -4656,  -5503],
                        [ -4786,  -5641],
                        [ -4913,  -5772],
                        [ -5040,  -5896],
                        [ -5163,  -6020],
                        [ -5286,  -6142],
                        [ -5405,  -6269],
                        [ -5522,  -6403],
                        [ -5633,  -6538],
                        [ -5740,  -6675],
                        [ -5837,  -6804],
                        [ -5926,  -6926],
                        [ -6006,  -7034],
                        [ -6076,  -7130],
                        [ -6137,  -7210],
                        [ -6188,  -7275],
                        [ -6229,  -7330],
                        [ -6262,  -7375],
                        [ -6284,  -7411],
                        [ -6297,  -7436],
                        [ -6302,  -7450],
                        [ -6299,  -7451],
                        [ -6290,  -7438],
                        [ -6275,  -7413],
                        [ -6249,  -7373],
                        [ -6210,  -7318],
                        [ -6150,  -7245],
                        [ -6072,  -7157],
                        [ -5974,  -7054],
                        [ -5854,  -6935],
                        [ -5714,  -6800],
                        [ -5555,  -6649],
                        [ -5372,  -6479],
                        [ -5168,  -6290],
                        [ -4942,  -6083],
                        [ -4697,  -5861],
                        [ -4427,  -5612],
                        [ -4130,  -5339],
                        [ -3795,  -5028],
                        [ -3425,  -4679],
                        [ -3045,  -4320],
                        [ -2655,  -3949],
                        [ -2270,  -3581],
                        [ -1891,  -3216],
                        [ -1531,  -2869],
                        [ -1190,  -2540],
                        [  -881,  -2241],
                        [  -604,  -1970],
                        [  -366,  -1738],
                        [  -170,  -1545],
                        [   -15,  -1393],
                        [    99,  -1286],
                        [   171,  -1225],
                        [   201,  -1210],
                        [   191,  -1240],
                        [   144,  -1315],
                        [    54,  -1432],
                        [   -75,  -1592],
                        [  -245,  -1789],
                        [  -456,  -2022],
                        [  -700,  -2284],
                        [  -979,  -2575],
                        [ -1284,  -2885],
                        [ -1613,  -3215],
                        [ -1960,  -3556],
                        [ -2321,  -3904],
                        [ -2689,  -4254],
                        [ -3062,  -4601],
                        [ -3431,  -4939],
                        [ -3794,  -5264],
                        [ -4144,  -5570],
                        [ -4478,  -5853],
                        [ -4789,  -6109],
                        [ -5074,  -6333],
                        [ -5327,  -6523],
                        [ -5545,  -6673],
                        [ -5722,  -6781],
                        [ -5854,  -6845],
                        [ -5941,  -6863],
                        [ -5977,  -6831],
                        [ -5955,  -6745],
                        [ -5935,  -6663],
                        [ -6008,  -6677],
                        [ -6215,  -6827],
                        [ -6559,  -7118],
                        [ -7045,  -7556],
                        [ -7670,  -8135],
                        [ -8339,  -8759],
                        [ -8915,  -9293],
                        [ -9354,  -9691],
                        [ -9661,  -9963],
                        [ -9835, -10109],
                        [ -9879, -10132],
                        [ -9795, -10035],
                        [ -9592,  -9825],
                        [ -9275,  -9508],
                        [ -8860,  -9091],
                        [ -8355,  -8584],
                        [ -7772,  -7995],
                        [ -7124,  -7334],
                        [ -6418,  -6611],
                        [ -5665,  -5837],
                        [ -4876,  -5021],
                        [ -4059,  -4173],
                        [ -3226,  -3306],
                        [ -2387,  -2428],
                        [ -1548,  -1549],
                        [  -717,   -676],
                        [    98,    181],
                        [   892,   1017],
                        [  1658,   1827],
                        [  2394,   2605],
                        [  3095,   3348],
                        [  3756,   4051],
                        [  4378,   4715],
                        [  4956,   5336],
                        [  5491,   5913],
                        [  5981,   6446],
                        [  6428,   6934],
                        [  6831,   7378],
                        [  7191,   7777],
                        [  7512,   8135],
                        [  7796,   8450],
                        [  8043,   8725],
                        [  8257,   8958],
                        [  8439,   9151],
                        [  8595,   9306],
                        [  8724,   9427],
                        [  8830,   9525],
                        [  8916,   9601],
                        [  8984,   9669],
                        [  9037,   9728],
                        [  9073,   9778],
                        [  9099,   9821],
                        [  9115,   9854],
                        [  9123,   9880],
                        [  9127,   9899],
                        [  9128,   9913],
                        [  9134,   9927],
                        [  9145,   9943],
                        [  9163,   9966],
                        [  9189,   9999],
                        [  9229,  10041],
                        [  9284,  10092],
                        [  9361,  10155],
                        [  9458,  10228],
                        [  9575,  10311],
                        [  9713,  10406],
                        [  9859,  10506],
                        [ 10013,  10613],
                        [ 10165,  10723],
                        [ 10315,  10836],
                        [ 10458,  10948],
                        [ 10592,  11059],
                        [ 10715,  11165],
                        [ 10827,  11265],
                        [ 10934,  11368],
                        [ 11034,  11468],
                        [ 11128,  11569],
                        [ 11215,  11669],
                        [ 11268,  11737],
                        [ 11286,  11774],
                        [ 11256,  11764],
                        [ 11175,  11706],
                        [ 11056,  11608],
                        [ 10894,  11470],
                        [ 10700,  11301],
                        [ 10471,  11098],
                        [ 10216,  10870],
                        [  9932,  10617],
                        [  9631,  10346],
                        [  9309,  10055],
                        [  8972,   9752],
                        [  8621,   9435],
                        [  8259,   9110],
                        [  7883,   8776],
                        [  7498,   8437],
                        [  7103,   8093],
                        [  6699,   7746],
                        [  6287,   7396],
                        [  5874,   7045],
                        [  5460,   6693],
                        [  5049,   6342],
                        [  4639,   5991],
                        [  4235,   5639],
                        [  3834,   5289],
                        [  3440,   4938],
                        [  3053,   4587],
                        [  2671,   4236],
                        [  2298,   3887],
                        [  1931,   3538],
                        [  1574,   3190],
                        [  1225,   2843],
                        [   886,   2498],
                        [   558,   2155],
                        [   240,   1814],
                        [   -69,   1476],
                        [  -366,   1142],
                        [  -652,    813],
                        [  -930,    489],
                        [ -1199,    171],
                        [ -1454,   -137],
                        [ -1704,   -442],
                        [ -1944,   -739],
                        [ -2106,   -957],
                        [ -2091,   -999],
                        [ -1868,   -830],
                        [ -1429,   -447],
                        [  -765,    163],
                        [   127,    999],
                        [  1143,   1961],
                        [  2136,   2897],
                        [  3053,   3761],
                        [  3898,   4555],
                        [  4661,   5276],
                        [  5337,   5915],
                        [  5922,   6472],
                        [  6416,   6945],
                        [  6820,   7334],
                        [  7138,   7640],
                        [  7376,   7863],
                        [  7538,   8006],
                        [  7629,   8074],
                        [  7655,   8070],
                        [  7616,   7998],
                        [  7521,   7864],
                        [  7373,   7673],
                        [  7178,   7432],
                        [  6944,   7147],
                        [  6672,   6823],
                        [  6371,   6465],
                        [  6043,   6080],
                        [  5692,   5670],
                        [  5322,   5243],
                        [  4937,   4799],
                        [  4542,   4345],
                        [  4138,   3883],
                        [  3729,   3415],
                        [  3318,   2945],
                        [  2908,   2475],
                        [  2501,   2008],
                        [  2099,   1545],
                        [  1704,   1092],
                        [  1317,    648],
                        [   941,    217],
                        [   575,   -202],
                        [   223,   -596],
                        [  -115,   -969],
                        [  -437,  -1312],
                        [  -743,  -1624],
                        [ -1029,  -1908],
                        [ -1297,  -2162],
                        [ -1543,  -2399],
                        [ -1766,  -2616],
                        [ -1963,  -2819],
                        [ -2134,  -3005],
                        [ -2278,  -3168],
                        [ -2393,  -3309],
                        [ -2478,  -3426],
                        [ -2536,  -3517],
                        [ -2567,  -3580],
                        [ -2572,  -3616],
                        [ -2555,  -3631],
                        [ -2515,  -3624],
                        [ -2455,  -3596],
                        [ -2377,  -3548],
                        [ -2290,  -3482],
                        [ -2197,  -3397],
                        [ -2102,  -3297],
                        [ -2007,  -3183],
                        [ -1906,  -3053],
                        [ -1802,  -2910],
                        [ -1682,  -2754],
                        [ -1547,  -2585],
                        [ -1394,  -2402],
                        [ -1224,  -2208],
                        [ -1039,  -2004],
                        [  -841,  -1793],
                        [  -645,  -1592],
                        [  -453,  -1398],
                        [  -288,  -1237],
                        [  -150,  -1109],
                        [   -32,  -1003],
                        [    65,   -924],
                        [   176,   -829],
                        [   300,   -723],
                        [   444,   -597],
                        [   606,   -451],
                        [   777,   -295],
                        [   956,   -130],
                        [  1133,     33],
                        [  1311,    196],
                        [  1477,    348],
                        [  1633,    490],
                        [  1770,    613],
                        [  1891,    721],
                        [  1987,    804],
                        [  2061,    867],
                        [  2110,    904],
                        [  2135,    917],
                        [  2139,    904],
                        [  2122,    869],
                        [  2086,    812],
                        [  2031,    734],
                        [  1959,    638],
                        [  1871,    527],
                        [  1770,    404],
                        [  1659,    271],
                        [  1541,    136],
                        [  1419,     -1],
                        [  1297,   -133],
                        [  1178,   -258],
                        [  1067,   -369],
                        [   966,   -466],
                        [   881,   -540],
                        [   811,   -593],
                        [   763,   -618],
                        [   739,   -614],
                        [   741,   -578],
                        [   771,   -508],
                        [   833,   -401],
                        [   925,   -258],
                        [  1055,    -75],
                        [  1220,    145],
                        [  1418,    401],
                        [  1657,    698],
                        [  1931,   1030],
                        [  2157,   1315],
                        [  2247,   1462],
                        [  2169,   1441],
                        [  1920,   1249],
                        [  1478,    861],
                        [   831,    269],
                        [    80,   -427],
                        [  -626,  -1080],
                        [ -1242,  -1643],
                        [ -1775,  -2126],
                        [ -2215,  -2524],
                        [ -2556,  -2832],
                        [ -2797,  -3049],
                        [ -2941,  -3176],
                        [ -2990,  -3216],
                        [ -2952,  -3169],
                        [ -2831,  -3040],
                        [ -2638,  -2835],
                        [ -2379,  -2557],
                        [ -2061,  -2215],
                        [ -1690,  -1817],
                        [ -1275,  -1367],
                        [  -823,   -877],
                        [  -344,   -352],
                        [   158,    200],
                        [   675,    771],
                        [  1200,   1356],
                        [  1729,   1947],
                        [  2256,   2537],
                        [  2775,   3124],
                        [  3283,   3700],
                        [  3777,   4263],
                        [  4253,   4809],
                        [  4709,   5337],
                        [  5142,   5842],
                        [  5552,   6324],
                        [  5936,   6781],
                        [  6295,   7213],
                        [  6629,   7620],
                        [  6940,   8001],
                        [  7226,   8356],
                        [  7492,   8682],
                        [  7737,   8983],
                        [  7962,   9245],
                        [  8169,   9475],
                        [  8360,   9669],
                        [  8536,   9830],
                        [  8699,   9969],
                        [  8850,  10086],
                        [  8989,  10199],
                        [  9118,  10309],
                        [  9237,  10417],
                        [  9345,  10524],
                        [  9445,  10629],
                        [  9537,  10734],
                        [  9625,  10837],
                        [  9710,  10940],
                        [  9793,  11040],
                        [  9878,  11141],
                        [  9961,  11243],
                        [ 10047,  11347],
                        [ 10141,  11452],
                        [ 10243,  11557],
                        [ 10361,  11663],
                        [ 10493,  11771],
                        [ 10640,  11876],
                        [ 10798,  11978],
                        [ 10953,  12073],
                        [ 11102,  12160],
                        [ 11230,  12232],
                        [ 11337,  12288],
                        [ 11418,  12327],
                        [ 11473,  12348],
                        [ 11505,  12355],
                        [ 11513,  12347],
                        [ 11530,  12356],
                        [ 11551,  12378],
                        [ 11587,  12422],
                        [ 11634,  12487],
                        [ 11661,  12535],
                        [ 11669,  12571],
                        [ 11609,  12542],
                        [ 11481,  12448],
                        [ 11287,  12289],
                        [ 11025,  12064],
                        [ 10703,  11781],
                        [ 10320,  11440],
                        [  9884,  11050],
                        [  9395,  10610],
                        [  8866,  10132],
                        [  8296,   9614],
                        [  7697,   9069],
                        [  7069,   8495],
                        [  6425,   7902],
                        [  5766,   7291],
                        [  5095,   6669],
                        [  4417,   6039],
                        [  3733,   5406],
                        [  3044,   4773],
                        [  2360,   4145],
                        [  1679,   3522],
                        [  1008,   2911],
                        [   350,   2312],
                        [  -291,   1727],
                        [  -914,   1160],
                        [ -1515,    610],
                        [ -2093,     79],
                        [ -2646,   -432],
                        [ -3171,   -923],
                        [ -3669,  -1392],
                        [ -4138,  -1839],
                        [ -4578,  -2264],
                        [ -4986,  -2665],
                        [ -5365,  -3044],
                        [ -5713,  -3401],
                        [ -6030,  -3735],
                        [ -6316,  -4045],
                        [ -6573,  -4333],
                        [ -6802,  -4599],
                        [ -7003,  -4842],
                        [ -7171,  -5057],
                        [ -7322,  -5259],
                        [ -7442,  -5432],
                        [ -7449,  -5496],
                        [ -7268,  -5374],
                        [ -6885,  -5051],
                        [ -6294,  -4521],
                        [ -5472,  -3761],
                        [ -4405,  -2758],
                        [ -3191,  -1609],
                        [ -1977,   -461],
                        [  -808,    644],
                        [   319,   1706],
                        [  1382,   2714],
                        [  2369,   3652],
                        [  3271,   4514],
                        [  4083,   5295],
                        [  4799,   5987],
                        [  5416,   6585],
                        [  5940,   7087],
                        [  6368,   7492],
                        [  6703,   7800],
                        [  6947,   8012],
                        [  7102,   8132],
                        [  7173,   8162],
                        [  7164,   8107],
                        [  7081,   7973],
                        [  6929,   7766],
                        [  6715,   7491],
                        [  6445,   7157],
                        [  6125,   6767],
                        [  5761,   6330],
                        [  5358,   5852],
                        [  4922,   5341],
                        [  4461,   4802],
                        [  3980,   4240],
                        [  3482,   3663],
                        [  2977,   3075],
                        [  2468,   2481],
                        [  1959,   1888],
                        [  1456,   1299],
                        [   962,    721],
                        [   481,    156],
                        [    17,   -390],
                        [  -428,   -916],
                        [  -852,  -1406],
                        [ -1250,  -1860],
                        [ -1622,  -2266],
                        [ -1965,  -2624],
                        [ -2279,  -2935],
                        [ -2561,  -3196],
                        [ -2810,  -3421],
                        [ -3025,  -3612],
                        [ -3205,  -3777],
                        [ -3347,  -3916],
                        [ -3452,  -4030],
                        [ -3522,  -4119],
                        [ -3556,  -4181],
                        [ -3558,  -4219],
                        [ -3529,  -4227],
                        [ -3473,  -4212],
                        [ -3391,  -4173],
                        [ -3287,  -4112],
                        [ -3168,  -4033],
                        [ -3035,  -3937],
                        [ -2903,  -3829],
                        [ -2775,  -3709],
                        [ -2657,  -3582],
                        [ -2551,  -3452],
                        [ -2455,  -3315],
                        [ -2368,  -3177],
                        [ -2277,  -3035],
                        [ -2181,  -2889],
                        [ -2077,  -2742],
                        [ -1968,  -2594],
                        [ -1857,  -2451],
                        [ -1743,  -2313],
                        [ -1664,  -2217],
                        [ -1618,  -2160],
                        [ -1639,  -2177],
                        [ -1726,  -2267],
                        [ -1873,  -2421],
                        [ -2081,  -2641],
                        [ -2290,  -2864],
                        [ -2504,  -3095],
                        [ -2688,  -3296],
                        [ -2841,  -3466],
                        [ -2971,  -3613],
                        [ -3072,  -3734],
                        [ -3150,  -3833],
                        [ -3204,  -3910],
                        [ -3238,  -3969],
                        [ -3251,  -4011],
                        [ -3252,  -4039],
                        [ -3237,  -4052],
                        [ -3218,  -4056],
                        [ -3189,  -4048],
                        [ -3158,  -4032],
                        [ -3122,  -4006],
                        [ -3078,  -3973],
                        [ -3023,  -3931],
                        [ -2957,  -3881],
                        [ -2875,  -3820],
                        [ -2780,  -3751],
                        [ -2671,  -3669],
                        [ -2546,  -3575],
                        [ -2407,  -3468],
                        [ -2254,  -3346],
                        [ -2082,  -3207],
                        [ -1895,  -3049],
                        [ -1689,  -2871],
                        [ -1465,  -2672],
                        [ -1222,  -2451],
                        [  -960,  -2207],
                        [  -678,  -1939],
                        [  -377,  -1646],
                        [   -57,  -1330],
                        [   282,   -990],
                        [   639,   -626],
                        [  1010,   -241],
                        [  1398,    164],
                        [  1800,    590],
                        [  2212,   1029],
                        [  2632,   1480],
                        [  3065,   1948],
                        [  3493,   2413],
                        [  3837,   2798],
                        [  4036,   3040],
                        [  4077,   3125],
                        [  3953,   3047],
                        [  3627,   2768],
                        [  3075,   2265],
                        [  2381,   1621],
                        [  1670,    962],
                        [   973,    319],
                        [   293,   -314],
                        [  -361,   -921],
                        [  -970,  -1493],
                        [ -1531,  -2023],
                        [ -2038,  -2508],
                        [ -2486,  -2942],
                        [ -2875,  -3318],
                        [ -3205,  -3637],
                        [ -3478,  -3896],
                        [ -3694,  -4095],
                        [ -3856,  -4236],
                        [ -3965,  -4319],
                        [ -4024,  -4349],
                        [ -4037,  -4327],
                        [ -4006,  -4256],
                        [ -3938,  -4142],
                        [ -3835,  -3989],
                        [ -3703,  -3799],
                        [ -3543,  -3578],
                        [ -3361,  -3330],
                        [ -3157,  -3058],
                        [ -2938,  -2768],
                        [ -2704,  -2462],
                        [ -2459,  -2143],
                        [ -2206,  -1814],
                        [ -1947,  -1476],
                        [ -1684,  -1134],
                        [ -1418,   -788],
                        [ -1151,   -441],
                        [  -883,    -94],
                        [  -616,    251],
                        [  -349,    596],
                        [   -83,    931],
                        [   182,   1259],
                        [   447,   1567],
                        [   711,   1855],
                        [   973,   2119],
                        [  1236,   2361],
                        [  1495,   2585],
                        [  1753,   2793],
                        [  2007,   3001],
                        [  2257,   3210],
                        [  2499,   3424],
                        [  2736,   3642],
                        [  2962,   3863],
                        [  3180,   4089],
                        [  3388,   4310],
                        [  3587,   4530],
                        [  3776,   4741],
                        [  3954,   4944],
                        [  4120,   5137],
                        [  4275,   5319],
                        [  4427,   5488],
                        [  4574,   5645],
                        [  4724,   5788],
                        [  4873,   5917],
                        [  5022,   6030],
                        [  5168,   6122],
                        [  5293,   6191],
                        [  5398,   6235],
                        [  5463,   6247],
                        [  5489,   6224],
                        [  5475,   6169],
                        [  5417,   6080],
                        [  5333,   5973],
                        [  5221,   5846],
                        [  5131,   5750],
                        [  5059,   5682],
                        [  5019,   5652],
                        [  5008,   5660],
                        [  4997,   5672],
                        [  4986,   5692],
                        [  4905,   5642],
                        [  4756,   5529],
                        [  4535,   5345],
                        [  4240,   5090],
                        [  3876,   4768],
                        [  3445,   4382],
                        [  2954,   3940],
                        [  2403,   3441],
                        [  1804,   2897],
                        [  1159,   2308],
                        [   483,   1686],
                        [  -220,   1031],
                        [  -937,    356],
                        [ -1666,   -340],
                        [ -2402,  -1047],
                        [ -3140,  -1762],
                        [ -3876,  -2473],
                        [ -4611,  -3181],
                        [ -5337,  -3876],
                        [ -6055,  -4558],
                        [ -6754,  -5219],
                        [ -7434,  -5858],
                        [ -8088,  -6472],
                        [ -8716,  -7058],
                        [ -9311,  -7614],
                        [ -9874,  -8138],
                        [-10401,  -8630],
                        [-10891,  -9086],
                        [-11342,  -9509],
                        [-11754,  -9896],
                        [-12126, -10249],
                        [-12458, -10566],
                        [-12751, -10849],
                        [-13004, -11100],
                        [-13219, -11317],
                        [-13392, -11500],
                        [-13528, -11653],
                        [-13629, -11775],
                        [-13693, -11867],
                        [-13720, -11926],
                        [-13722, -11964],
                        [-13679, -11963],
                        [-13538, -11867],
                        [-13260, -11639],
                        [-12851, -11282],
                        [-12301, -10787],
                        [-11583, -10125],
                        [-10669,  -9270],
                        [ -9628,  -8288],
                        [ -8560,  -7282],
                        [ -7496,  -6281],
                        [ -6437,  -5283],
                        [ -5407,  -4309],
                        [ -4418,  -3371],
                        [ -3484,  -2481],
                        [ -2611,  -1645],
                        [ -1809,   -873],
                        [ -1086,   -173],
                        [  -439,    449],
                        [   128,    992],
                        [   613,   1452],
                        [  1018,   1827],
                        [  1342,   2120],
                        [  1588,   2332],
                        [  1759,   2464],
                        [  1860,   2520],
                        [  1895,   2506],
                        [  1868,   2424],
                        [  1786,   2280],
                        [  1655,   2082],
                        [  1480,   1835],
                        [  1264,   1545],
                        [  1018,   1220],
                        [   745,    865],
                        [   451,    488],
                        [   142,     92],
                        [  -176,   -315],
                        [  -497,   -729],
                        [  -817,  -1143],
                        [ -1133,  -1554],
                        [ -1438,  -1954],
                        [ -1730,  -2342],
                        [ -2005,  -2713],
                        [ -2262,  -3062],
                        [ -2497,  -3378],
                        [ -2710,  -3658],
                        [ -2897,  -3892],
                        [ -3060,  -4081],
                        [ -3196,  -4222],
                        [ -3305,  -4314],
                        [ -3387,  -4372],
                        [ -3442,  -4396],
                        [ -3469,  -4403],
                        [ -3469,  -4390],
                        [ -3444,  -4364],
                        [ -3393,  -4326],
                        [ -3319,  -4275],
                        [ -3224,  -4214],
                        [ -3112,  -4140],
                        [ -2985,  -4054],
                        [ -2846,  -3955],
                        [ -2698,  -3846],
                        [ -2549,  -3734],
                        [ -2400,  -3617],
                        [ -2269,  -3503],
                        [ -2153,  -3390],
                        [ -2061,  -3284],
                        [ -1994,  -3186],
                        [ -1948,  -3095],
                        [ -1926,  -3014],
                        [ -1909,  -2940],
                        [ -1896,  -2871],
                        [ -1887,  -2808],
                        [ -1882,  -2755],
                        [ -1883,  -2715],
                        [ -1892,  -2688],
                        [ -1955,  -2721],
                        [ -2068,  -2810],
                        [ -2265,  -2991],
                        [ -2543,  -3258],
                        [ -2898,  -3607],
                        [ -3330,  -4038],
                        [ -3766,  -4477],
                        [ -4211,  -4928],
                        [ -4614,  -5338],
                        [ -4976,  -5709],
                        [ -5295,  -6039],
                        [ -5569,  -6328],
                        [ -5793,  -6571],
                        [ -5967,  -6767],
                        [ -6093,  -6919],
                        [ -6169,  -7024],
                        [ -6202,  -7087],
                        [ -6190,  -7105],
                        [ -6146,  -7082],
                        [ -6067,  -7017],
                        [ -5957,  -6914],
                        [ -5817,  -6772],
                        [ -5643,  -6598],
                        [ -5436,  -6387],
                        [ -5191,  -6146],
                        [ -4908,  -5874],
                        [ -4592,  -5575],
                        [ -4244,  -5250],
                        [ -3867,  -4901],
                        [ -3463,  -4529],
                        [ -3036,  -4138],
                        [ -2588,  -3728],
                        [ -2122,  -3301],
                        [ -1640,  -2859],
                        [ -1147,  -2405],
                        [  -643,  -1940],
                        [  -132,  -1467],
                        [   385,   -988],
                        [   903,   -505],
                        [  1419,    -20],
                        [  1932,    465],
                        [  2436,    946],
                        [  2928,   1420],
                        [  3407,   1886],
                        [  3868,   2339],
                        [  4308,   2777],
                        [  4725,   3196],
                        [  5120,   3599],
                        [  5478,   3967],
                        [  5761,   4268],
                        [  5958,   4485],
                        [  6068,   4620],
                        [  6083,   4664],
                        [  5973,   4585],
                        [  5708,   4353],
                        [  5321,   4003],
                        [  4873,   3595],
                        [  4380,   3142],
                        [  3848,   2649],
                        [  3288,   2127],
                        [  2715,   1589],
                        [  2139,   1042],
                        [  1566,    494],
                        [  1005,    -47],
                        [   464,   -573],
                        [   -54,  -1078],
                        [  -544,  -1556],
                        [ -1005,  -2004],
                        [ -1431,  -2415],
                        [ -1821,  -2789],
                        [ -2173,  -3122],
                        [ -2485,  -3414],
                        [ -2759,  -3662],
                        [ -2993,  -3867],
                        [ -3187,  -4026],
                        [ -3344,  -4142],
                        [ -3463,  -4216],
                        [ -3546,  -4249],
                        [ -3594,  -4245],
                        [ -3608,  -4203],
                        [ -3590,  -4128],
                        [ -3542,  -4020],
                        [ -3466,  -3883],
                        [ -3365,  -3719],
                        [ -3241,  -3529],
                        [ -3096,  -3317],
                        [ -2933,  -3086],
                        [ -2754,  -2838],
                        [ -2560,  -2576],
                        [ -2355,  -2303],
                        [ -2140,  -2025],
                        [ -1918,  -1745],
                        [ -1689,  -1477],
                        [ -1457,  -1220],
                        [ -1223,   -984],
                        [  -989,   -768],
                        [  -758,   -571],
                        [  -531,   -397],
                        [  -314,   -228],
                        [  -104,    -67],
                        [    92,     93],
                        [   274,    251],
                        [   439,    406],
                        [   587,    559],
                        [   714,    699],
                        [   821,    827],
                        [   906,    936],
                        [   969,   1025],
                        [  1011,   1093],
                        [  1029,   1138],
                        [  1035,   1165],
                        [  1028,   1170],
                        [  1012,   1155],
                        [   986,   1118],
                        [   953,   1060],
                        [   913,    982],
                        [   853,    881],
                        [   772,    754],
                        [   657,    599],
                        [   511,    417],
                        [   336,    211],
                        [   130,    -19],
                        [   -81,   -248],
                        [  -299,   -476],
                        [  -469,   -650],
                        [  -594,   -773],
                        [  -661,   -831],
                        [  -670,   -826],
                        [  -645,   -782],
                        [  -583,   -696],
                        [  -562,   -650],
                        [  -579,   -638],
                        [  -640,   -670],
                        [  -748,   -745],
                        [  -904,   -865],
                        [ -1104,  -1027],
                        [ -1349,  -1229],
                        [ -1635,  -1468],
                        [ -1953,  -1740],
                        [ -2305,  -2043],
                        [ -2674,  -2372],
                        [ -3060,  -2723],
                        [ -3450,  -3089],
                        [ -3843,  -3471],
                        [ -4236,  -3859],
                        [ -4627,  -4253],
                        [ -5020,  -4646],
                        [ -5412,  -5037],
                        [ -5802,  -5419],
                        [ -6189,  -5791],
                        [ -6567,  -6149],
                        [ -6932,  -6491],
                        [ -7282,  -6814],
                        [ -7616,  -7117],
                        [ -7928,  -7397],
                        [ -8219,  -7655],
                        [ -8486,  -7887],
                        [ -8730,  -8095],
                        [ -8947,  -8278],
                        [ -9141,  -8435],
                        [ -9308,  -8568],
                        [ -9449,  -8675],
                        [ -9565,  -8760],
                        [ -9654,  -8821],
                        [ -9718,  -8860],
                        [ -9754,  -8876],
                        [ -9765,  -8872],
                        [ -9752,  -8848],
                        [ -9713,  -8804],
                        [ -9651,  -8742],
                        [ -9569,  -8664],
                        [ -9459,  -8562],
                        [ -9313,  -8429],
                        [ -9133,  -8267],
                        [ -8926,  -8082],
                        [ -8686,  -7867],
                        [ -8391,  -7600],
                        [ -8010,  -7252],
                        [ -7557,  -6832],
                        [ -7064,  -6374],
                        [ -6541,  -5887],
                        [ -5992,  -5376],
                        [ -5432,  -4851],
                        [ -4868,  -4323],
                        [ -4308,  -3794],
                        [ -3759,  -3274],
                        [ -3230,  -2770],
                        [ -2725,  -2286],
                        [ -2247,  -1826],
                        [ -1800,  -1394],
                        [ -1384,   -994],
                        [ -1003,   -628],
                        [  -656,   -297],
                        [  -344,     -2],
                        [   -66,    257],
                        [   179,    478],
                        [   391,    662],
                        [   574,    813],
                        [   729,    930],
                        [   858,   1016],
                        [   965,   1076],
                        [  1052,   1111],
                        [  1121,   1126],
                        [  1177,   1123],
                        [  1220,   1106],
                        [  1254,   1077],
                        [  1282,   1038],
                        [  1307,    995],
                        [  1330,    947],
                        [  1355,    900],
                        [  1384,    854],
                        [  1418,    812],
                        [  1457,    776],
                        [  1503,    749],
                        [  1556,    739],
                        [  1618,    746],
                        [  1687,    778],
                        [  1764,    834],
                        [  1848,    917],
                        [  1939,   1027],
                        [  2037,   1154],
                        [  2141,   1297],
                        [  2249,   1437],
                        [  2362,   1578],
                        [  2479,   1710],
                        [  2598,   1833],
                        [  2720,   1948],
                        [  2842,   2054],
                        [  2963,   2156],
                        [  3082,   2254],
                        [  3196,   2349],
                        [  3305,   2438],
                        [  3403,   2520],
                        [  3486,   2593],
                        [  3548,   2653],
                        [  3588,   2701],
                        [  3602,   2734],
                        [  3589,   2754],
                        [  3551,   2759],
                        [  3486,   2750],
                        [  3413,   2731],
                        [  3331,   2703],
                        [  3242,   2666],
                        [  3145,   2618],
                        [  3038,   2556],
                        [  2921,   2481],
                        [  2749,   2347],
                        [  2526,   2156],
                        [  2230,   1888],
                        [  1862,   1543],
                        [  1421,   1120],
                        [   908,    622],
                        [   389,    114],
                        [  -137,   -405],
                        [  -622,   -886],
                        [ -1067,  -1328],
                        [ -1463,  -1727],
                        [ -1811,  -2080],
                        [ -2101,  -2381],
                        [ -2334,  -2628],
                        [ -2507,  -2822],
                        [ -2621,  -2959],
                        [ -2683,  -3042],
                        [ -2690,  -3070],
                        [ -2655,  -3045],
                        [ -2577,  -2967],
                        [ -2459,  -2841],
                        [ -2303,  -2668],
                        [ -2104,  -2452],
                        [ -1866,  -2194],
                        [ -1583,  -1900],
                        [ -1256,  -1571],
                        [  -895,  -1214],
                        [  -499,   -829],
                        [   -76,   -423],
                        [   374,      4],
                        [   841,    444],
                        [  1325,    895],
                        [  1819,   1353],
                        [  2321,   1814],
                        [  2823,   2275],
                        [  3327,   2733],
                        [  3825,   3184],
                        [  4315,   3625],
                        [  4793,   4054],
                        [  5256,   4468],
                        [  5699,   4863],
                        [  6120,   5238],
                        [  6513,   5590],
                        [  6877,   5917],
                        [  7210,   6217],
                        [  7509,   6488],
                        [  7773,   6728],
                        [  8001,   6937],
                        [  8188,   7111],
                        [  8343,   7256],
                        [  8473,   7383],
                        [  8582,   7495],
                        [  8668,   7586],
                        [  8710,   7638],
                        [  8681,   7621],
                        [  8570,   7527],
                        [  8394,   7368],
                        [  8157,   7150],
                        [  7865,   6880],
                        [  7528,   6565],
                        [  7155,   6214],
                        [  6752,   5833],
                        [  6329,   5429],
                        [  5891,   5011],
                        [  5449,   4583],
                        [  5006,   4153],
                        [  4570,   3725],
                        [  4144,   3305],
                        [  3734,   2900],
                        [  3342,   2509],
                        [  2972,   2141],
                        [  2627,   1798],
                        [  2309,   1484],
                        [  2020,   1202],
                        [  1761,    953],
                        [  1532,    738],
                        [  1335,    557],
                        [  1168,    411],
                        [  1032,    298],
                        [   926,    217],
                        [   848,    167],
                        [   798,    147],
                        [   773,    154],
                        [   772,    188],
                        [   791,    244],
                        [   830,    323],
                        [   885,    418],
                        [   953,    530],
                        [  1033,    654],
                        [  1121,    790],
                        [  1216,    929],
                        [  1314,   1069],
                        [  1415,   1202],
                        [  1515,   1324],
                        [  1612,   1430],
                        [  1705,   1518],
                        [  1792,   1583],
                        [  1870,   1625],
                        [  1937,   1657],
                        [  1992,   1675],
                        [  2035,   1691],
                        [  2061,   1701],
                        [  2069,   1704],
                        [  2060,   1701],
                        [  2029,   1685],
                        [  1977,   1654],
                        [  1904,   1603],
                        [  1809,   1532],
                        [  1694,   1441],
                        [  1560,   1330],
                        [  1412,   1203],
                        [  1251,   1059],
                        [  1081,    899],
                        [   901,    726],
                        [   719,    541],
                        [   534,    345],
                        [   340,    136],
                        [   140,    -84],
                        [   -73,   -314],
                        [  -297,   -556],
                        [  -527,   -802],
                        [  -766,  -1054],
                        [  -986,  -1285],
                        [ -1189,  -1494],
                        [ -1333,  -1645],
                        [ -1424,  -1736],
                        [ -1445,  -1754],
                        [ -1397,  -1701],
                        [ -1292,  -1590],
                        [ -1129,  -1417],
                        [  -977,  -1252],
                        [  -828,  -1090],
                        [  -696,   -943],
                        [  -579,   -808],
                        [  -488,   -696],
                        [  -418,   -603],
                        [  -375,   -533],
                        [  -358,   -485],
                        [  -363,   -461],
                        [  -391,   -459],
                        [  -431,   -479],
                        [  -483,   -519],
                        [  -541,   -577],
                        [  -606,   -652],
                        [  -678,   -742],
                        [  -755,   -844],
                        [  -846,   -957],
                        [  -950,  -1079],
                        [ -1065,  -1207],
                        [ -1194,  -1339],
                        [ -1328,  -1473],
                        [ -1469,  -1609],
                        [ -1614,  -1742],
                        [ -1761,  -1874],
                        [ -1908,  -2000],
                        [ -2054,  -2121],
                        [ -2196,  -2234],
                        [ -2336,  -2342],
                        [ -2470,  -2439],
                        [ -2599,  -2528],
                        [ -2722,  -2607],
                        [ -2838,  -2678],
                        [ -2945,  -2739],
                        [ -3044,  -2790],
                        [ -3131,  -2832],
                        [ -3207,  -2865],
                        [ -3270,  -2888],
                        [ -3322,  -2902],
                        [ -3361,  -2907],
                        [ -3387,  -2903],
                        [ -3398,  -2889],
                        [ -3400,  -2870],
                        [ -3409,  -2862],
                        [ -3439,  -2879],
                        [ -3491,  -2924],
                        [ -3564,  -2994],
                        [ -3645,  -3074],
                        [ -3703,  -3135],
                        [ -3716,  -3153],
                        [ -3685,  -3128],
                        [ -3612,  -3065],
                        [ -3500,  -2964],
                        [ -3353,  -2830],
                        [ -3176,  -2669],
                        [ -2972,  -2482],
                        [ -2745,  -2276],
                        [ -2501,  -2051],
                        [ -2244,  -1812],
                        [ -1978,  -1561],
                        [ -1706,  -1301],
                        [ -1432,  -1034],
                        [ -1155,   -763],
                        [  -878,   -489],
                        [  -603,   -215],
                        [  -331,     55],
                        [   -63,    321],
                        [   201,    579],
                        [   458,    830],
                        [   711,   1073],
                        [   958,   1306],
                        [  1198,   1531],
                        [  1433,   1748],
                        [  1663,   1957],
                        [  1887,   2158],
                        [  2106,   2352],
                        [  2320,   2539],
                        [  2529,   2719],
                        [  2733,   2893],
                        [  2933,   3061],
                        [  3131,   3224],
                        [  3325,   3381],
                        [  3515,   3534],
                        [  3701,   3681],
                        [  3884,   3825],
                        [  4061,   3967],
                        [  4233,   4110],
                        [  4399,   4256],
                        [  4557,   4404],
                        [  4708,   4558],
                        [  4852,   4718],
                        [  4985,   4877],
                        [  5106,   5036],
                        [  5215,   5180],
                        [  5312,   5310],
                        [  5397,   5419],
                        [  5471,   5510],
                        [  5532,   5583],
                        [  5583,   5636],
                        [  5622,   5679],
                        [  5651,   5711],
                        [  5668,   5732],
                        [  5674,   5744],
                        [  5665,   5743],
                        [  5644,   5730],
                        [  5607,   5705],
                        [  5556,   5666],
                        [  5487,   5615],
                        [  5402,   5551],
                        [  5297,   5475],
                        [  5172,   5385],
                        [  5039,   5289],
                        [  4895,   5184],
                        [  4742,   5072],
                        [  4582,   4951],
                        [  4412,   4821],
                        [  4232,   4681],
                        [  4015,   4500],
                        [  3763,   4285],
                        [  3467,   4023],
                        [  3130,   3716],
                        [  2740,   3354],
                        [  2299,   2937],
                        [  1850,   2511],
                        [  1392,   2072],
                        [   959,   1656],
                        [   551,   1261],
                        [   179,    898],
                        [  -159,    566],
                        [  -453,    274],
                        [  -701,     21],
                        [  -903,   -187],
                        [ -1057,   -351],
                        [ -1168,   -469],
                        [ -1237,   -541],
                        [ -1271,   -570],
                        [ -1268,   -554],
                        [ -1233,   -497],
                        [ -1166,   -400],
                        [ -1064,   -267],
                        [  -927,    -98],
                        [  -753,     99],
                        [  -542,    326],
                        [  -304,    574],
                        [   -38,    844],
                        [   249,   1129],
                        [   557,   1428],
                        [   878,   1734],
                        [  1210,   2046],
                        [  1547,   2358],
                        [  1889,   2669],
                        [  2230,   2974],
                        [  2567,   3270],
                        [  2897,   3554],
                        [  3219,   3825],
                        [  3528,   4080],
                        [  3822,   4316],
                        [  4095,   4532],
                        [  4349,   4728],
                        [  4578,   4901],
                        [  4781,   5050],
                        [  4956,   5174],
                        [  5106,   5274],
                        [  5225,   5348],
                        [  5315,   5395],
                        [  5384,   5426],
                        [  5453,   5462],
                        [  5538,   5518],
                        [  5640,   5596],
                        [  5761,   5695],
                        [  5890,   5807],
                        [  6004,   5905],
                        [  6071,   5959],
                        [  6088,   5965],
                        [  6058,   5926],
                        [  5985,   5845],
                        [  5872,   5728],
                        [  5723,   5579],
                        [  5543,   5402],
                        [  5337,   5202],
                        [  5109,   4982],
                        [  4867,   4747],
                        [  4616,   4500],
                        [  4360,   4245],
                        [  4105,   3983],
                        [  3851,   3720],
                        [  3603,   3457],
                        [  3363,   3200],
                        [  3134,   2951],
                        [  2916,   2713],
                        [  2713,   2490],
                        [  2524,   2281],
                        [  2351,   2089],
                        [  2194,   1914],
                        [  2053,   1757],
                        [  1926,   1616],
                        [  1816,   1492],
                        [  1719,   1384],
                        [  1635,   1290],
                        [  1562,   1211],
                        [  1501,   1143],
                        [  1447,   1088],
                        [  1402,   1042],
                        [  1360,   1003],
                        [  1322,    969],
                        [  1285,    941],
                        [  1248,    916],
                        [  1209,    890],
                        [  1168,    862],
                        [  1121,    829],
                        [  1070,    789],
                        [  1013,    739],
                        [   949,    676],
                        [   878,    596],
                        [   797,    500],
                        [   710,    394],
                        [   616,    277],
                        [   513,    157],
                        [   400,     31],
                        [   276,    -98],
                        [   142,   -228],
                        [    -5,   -367],
                        [  -164,   -515],
                        [  -334,   -675],
                        [  -516,   -847],
                        [  -707,  -1029],
                        [  -908,  -1219],
                        [ -1116,  -1414],
                        [ -1333,  -1614],
                        [ -1555,  -1817],
                        [ -1780,  -2022],
                        [ -2000,  -2225],
                        [ -2215,  -2425],
                        [ -2420,  -2620],
                        [ -2615,  -2810],
                        [ -2801,  -2992],
                        [ -2975,  -3168],
                        [ -3137,  -3332],
                        [ -3286,  -3485],
                        [ -3408,  -3614],
                        [ -3504,  -3719],
                        [ -3563,  -3788],
                        [ -3586,  -3820],
                        [ -3562,  -3807],
                        [ -3493,  -3748],
                        [ -3375,  -3640],
                        [ -3209,  -3482],
                        [ -3025,  -3307],
                        [ -2823,  -3113],
                        [ -2613,  -2909],
                        [ -2394,  -2695],
                        [ -2177,  -2481],
                        [ -1961,  -2267],
                        [ -1753,  -2058],
                        [ -1551,  -1855],
                        [ -1359,  -1663],
                        [ -1177,  -1481],
                        [ -1002,  -1314],
                        [  -832,  -1159],
                        [  -670,  -1021],
                        [  -514,   -899],
                        [  -369,   -792],
                        [  -234,   -702],
                        [  -119,   -626],
                        [   -23,   -568],
                        [    53,   -523],
                        [   107,   -494],
                        [   144,   -478],
                        [   162,   -475],
                        [   163,   -483],
                        [   145,   -502],
                        [   115,   -531],
                        [    69,   -567],
                        [    11,   -609],
                        [   -59,   -658],
                        [  -140,   -709],
                        [  -231,   -765],
                        [  -329,   -822],
                        [  -436,   -881],
                        [  -544,   -940],
                        [  -657,   -999],
                        [  -769,  -1055],
                        [  -879,  -1110],
                        [  -986,  -1161],
                        [ -1089,  -1208],
                        [ -1185,  -1251],
                        [ -1275,  -1289],
                        [ -1354,  -1319],
                        [ -1436,  -1354],
                        [ -1541,  -1416],
                        [ -1682,  -1518],
                        [ -1857,  -1657],
                        [ -2067,  -1835],
                        [ -2308,  -2045],
                        [ -2550,  -2260],
                        [ -2761,  -2446],
                        [ -2932,  -2594],
                        [ -3066,  -2706],
                        [ -3161,  -2784],
                        [ -3218,  -2826],
                        [ -3237,  -2836],
                        [ -3219,  -2815],
                        [ -3166,  -2766],
                        [ -3083,  -2689],
                        [ -2971,  -2588],
                        [ -2838,  -2462],
                        [ -2685,  -2312],
                        [ -2516,  -2143],
                        [ -2334,  -1954],
                        [ -2139,  -1749],
                        [ -1933,  -1528],
                        [ -1721,  -1299],
                        [ -1502,  -1061],
                        [ -1281,   -820],
                        [ -1058,   -575],
                        [  -834,   -332],
                        [  -613,    -89],
                        [  -392,    153],
                        [  -177,    389],
                        [    34,    620],
                        [   240,    845],
                        [   439,   1062],
                        [   631,   1271],
                        [   813,   1470],
                        [   988,   1659],
                        [  1153,   1838],
                        [  1309,   2006],
                        [  1454,   2161],
                        [  1591,   2305],
                        [  1716,   2437],
                        [  1831,   2555],
                        [  1933,   2660],
                        [  2024,   2753],
                        [  2101,   2831],
                        [  2167,   2897],
                        [  2219,   2953],
                        [  2257,   3001],
                        [  2280,   3040],
                        [  2287,   3073],
                        [  2279,   3092],
                        [  2256,   3098],
                        [  2221,   3088],
                        [  2172,   3064],
                        [  2113,   3027],
                        [  2046,   2977],
                        [  1972,   2923],
                        [  1892,   2864],
                        [  1805,   2802],
                        [  1716,   2736],
                        [  1625,   2666],
                        [  1535,   2594],
                        [  1448,   2519],
                        [  1364,   2442],
                        [  1281,   2363],
                        [  1199,   2282],
                        [  1109,   2195],
                        [  1012,   2106],
                        [   909,   2016],
                        [   800,   1923],
                        [   686,   1830],
                        [   567,   1736],
                        [   443,   1638],
                        [   315,   1541],
                        [   180,   1437],
                        [    40,   1330],
                        [  -106,   1219],
                        [  -256,   1103],
                        [  -423,    969],
                        [  -608,    816],
                        [  -801,    652],
                        [ -1005,    475],
                        [ -1206,    300],
                        [ -1405,    124],
                        [ -1594,    -44],
                        [ -1775,   -206],
                        [ -1939,   -355],
                        [ -2087,   -492],
                        [ -2217,   -613],
                        [ -2329,   -717],
                        [ -2425,   -803],
                        [ -2504,   -870],
                        [ -2569,   -919],
                        [ -2621,   -947],
                        [ -2660,   -959],
                        [ -2686,   -951],
                        [ -2696,   -928],
                        [ -2691,   -888],
                        [ -2667,   -835],
                        [ -2623,   -769],
                        [ -2564,   -693],
                        [ -2492,   -606],
                        [ -2407,   -514],
                        [ -2309,   -414],
                        [ -2204,   -311],
                        [ -2091,   -206],
                        [ -1971,   -102],
                        [ -1848,      0],
                        [ -1722,     98],
                        [ -1593,    190],
                        [ -1467,    275],
                        [ -1340,    353],
                        [ -1217,    421],
                        [ -1099,    479],
                        [  -989,    527],
                        [  -886,    566],
                        [  -792,    593],
                        [  -710,    609],
                        [  -639,    613],
                        [  -578,    609],
                        [  -530,    592],
                        [  -494,    564],
                        [  -457,    540],
                        [  -395,    542],
                        [  -301,    580],
                        [  -173,    653],
                        [   -10,    765],
                        [   189,    913],
                        [   398,   1074],
                        [   588,   1217],
                        [   752,   1333],
                        [   890,   1424],
                        [  1003,   1493],
                        [  1089,   1539],
                        [  1148,   1564],
                        [  1181,   1571],
                        [  1191,   1562],
                        [  1178,   1536],
                        [  1149,   1496],
                        [  1106,   1441],
                        [  1053,   1372],
                        [   992,   1292],
                        [   925,   1199],
                        [   853,   1097],
                        [   778,    986],
                        [   700,    869],
                        [   622,    749],
                        [   544,    626],
                        [   466,    502],
                        [   390,    378],
                        [   314,    254],
                        [   240,    130],
                        [   166,      8],
                        [    93,   -113],
                        [    21,   -233],
                        [   -51,   -351],
                        [  -124,   -468],
                        [  -196,   -584],
                        [  -270,   -700],
                        [  -345,   -815],
                        [  -424,   -930],
                        [  -505,  -1046],
                        [  -591,  -1161],
                        [  -680,  -1277],
                        [  -774,  -1393],
                        [  -873,  -1508],
                        [  -975,  -1621],
                        [ -1082,  -1731],
                        [ -1192,  -1840],
                        [ -1307,  -1947],
                        [ -1422,  -2058],
                        [ -1540,  -2172],
                        [ -1656,  -2290],
                        [ -1772,  -2411],
                        [ -1887,  -2533],
                        [ -2002,  -2656],
                        [ -2117,  -2777],
                        [ -2233,  -2897],
                        [ -2351,  -3018],
                        [ -2471,  -3140],
                        [ -2593,  -3265],
                        [ -2715,  -3395],
                        [ -2841,  -3523],
                        [ -2969,  -3651],
                        [ -3105,  -3779],
                        [ -3247,  -3906],
                        [ -3393,  -4028],
                        [ -3543,  -4145],
                        [ -3686,  -4254],
                        [ -3822,  -4354],
                        [ -3940,  -4441],
                        [ -4039,  -4517],
                        [ -4119,  -4578],
                        [ -4177,  -4626],
                        [ -4216,  -4660],
                        [ -4233,  -4678],
                        [ -4232,  -4682],
                        [ -4210,  -4673],
                        [ -4175,  -4654],
                        [ -4128,  -4626],
                        [ -4063,  -4583],
                        [ -3980,  -4526],
                        [ -3868,  -4438],
                        [ -3726,  -4323],
                        [ -3560,  -4182],
                        [ -3371,  -4019],
                        [ -3164,  -3838],
                        [ -2940,  -3640],
                        [ -2706,  -3433],
                        [ -2464,  -3215],
                        [ -2218,  -2995],
                        [ -1970,  -2771],
                        [ -1723,  -2550],
                        [ -1479,  -2330],
                        [ -1237,  -2118],
                        [ -1000,  -1913],
                        [  -769,  -1718],
                        [  -544,  -1534],
                        [  -328,  -1363],
                        [  -121,  -1204],
                        [    70,  -1060],
                        [   245,   -930],
                        [   401,   -814],
                        [   540,   -713],
                        [   660,   -628],
                        [   761,   -557],
                        [   843,   -501],
                        [   908,   -457],
                        [   955,   -425],
                        [   984,   -404],
                        [   997,   -392],
                        [   995,   -389],
                        [   977,   -393],
                        [   945,   -404],
                        [   903,   -419],
                        [   848,   -438],
                        [   787,   -460],
                        [   717,   -483],
                        [   645,   -508],
                        [   568,   -533],
                        [   491,   -557],
                        [   413,   -580],
                        [   336,   -602],
                        [   263,   -620],
                        [   196,   -634],
                        [   119,   -657],
                        [    18,   -709],
                        [  -115,   -792],
                        [  -276,   -908],
                        [  -470,  -1059],
                        [  -695,  -1242],
                        [  -930,  -1437],
                        [ -1146,  -1614],
                        [ -1338,  -1769],
                        [ -1505,  -1899],
                        [ -1645,  -2006],
                        [ -1756,  -2089],
                        [ -1837,  -2148],
                        [ -1887,  -2186],
                        [ -1908,  -2202],
                        [ -1901,  -2197],
                        [ -1868,  -2172],
                        [ -1816,  -2126],
                        [ -1745,  -2060],
                        [ -1662,  -1974],
                        [ -1565,  -1870],
                        [ -1458,  -1749],
                        [ -1341,  -1612],
                        [ -1218,  -1464],
                        [ -1090,  -1306],
                        [  -959,  -1140],
                        [  -826,   -969],
                        [  -693,   -794],
                        [  -562,   -617],
                        [  -433,   -440],
                        [  -308,   -263],
                        [  -188,    -90],
                        [   -72,     78],
                        [    37,    241],
                        [   138,    397],
                        [   232,    546],
                        [   318,    687],
                        [   394,    817],
                        [   462,    939],
                        [   521,   1050],
                        [   570,   1150],
                        [   611,   1237],
                        [   641,   1311],
                        [   662,   1369],
                        [   674,   1411],
                        [   675,   1432],
                        [   667,   1434],
                        [   648,   1420],
                        [   619,   1390],
                        [   578,   1352],
                        [   526,   1306],
                        [   462,   1255],
                        [   387,   1199],
                        [   305,   1139],
                        [   215,   1074],
                        [   121,   1006],
                        [    26,    934],
                        [   -70,    866],
                        [  -166,    800],
                        [  -258,    738],
                        [  -346,    678],
                        [  -422,    625],
                        [  -483,    577],
                        [  -527,    535],
                        [  -553,    498],
                        [  -565,    466],
                        [  -564,    437],
                        [  -565,    410],
                        [  -565,    384],
                        [  -572,    358],
                        [  -585,    332],
                        [  -605,    307],
                        [  -629,    282],
                        [  -657,    259],
                        [  -689,    238],
                        [  -715,    228],
                        [  -735,    229],
                        [  -744,    243],
                        [  -744,    270],
                        [  -747,    294],
                        [  -750,    319],
                        [  -768,    328],
                        [  -800,    324],
                        [  -843,    309],
                        [  -898,    280],
                        [  -961,    244],
                        [ -1034,    197],
                        [ -1111,    146],
                        [ -1193,     90],
                        [ -1276,     32],
                        [ -1361,    -28],
                        [ -1445,    -89],
                        [ -1529,   -149],
                        [ -1611,   -207],
                        [ -1692,   -264],
                        [ -1774,   -318],
                        [ -1855,   -368],
                        [ -1935,   -414],
                        [ -2012,   -457],
                        [ -2083,   -497],
                        [ -2149,   -533],
                        [ -2209,   -565],
                        [ -2264,   -594],
                        [ -2312,   -619],
                        [ -2352,   -642],
                        [ -2386,   -662],
                        [ -2413,   -680],
                        [ -2433,   -696],
                        [ -2446,   -711],
                        [ -2451,   -726],
                        [ -2451,   -742],
                        [ -2444,   -758],
                        [ -2430,   -774],
                        [ -2412,   -792],
                        [ -2387,   -812],
                        [ -2360,   -832],
                        [ -2327,   -853],
                        [ -2293,   -875],
                        [ -2255,   -898],
                        [ -2215,   -921],
                        [ -2173,   -944],
                        [ -2130,   -969],
                        [ -2087,   -993],
                        [ -2028,  -1003],
                        [ -1943,   -986],
                        [ -1827,   -938],
                        [ -1681,   -860],
                        [ -1501,   -746],
                        [ -1286,   -597],
                        [ -1053,   -431],
                        [  -826,   -270],
                        [  -609,   -119],
                        [  -402,     22],
                        [  -210,    151],
                        [   -32,    268],
                        [   126,    375],
                        [   265,    470],
                        [   385,    553],
                        [   484,    626],
                        [   567,    687],
                        [   634,    735],
                        [   689,    769],
                        [   734,    789],
                        [   769,    794],
                        [   794,    784],
                        [   809,    760],
                        [   817,    722],
                        [   817,    672],
                        [   810,    610],
                        [   796,    538],
                        [   776,    455],
                        [   749,    363],
                        [   717,    263],
                        [   678,    156],
                        [   635,     41],
                        [   584,    -78],
                        [   528,   -203],
                        [   467,   -332],
                        [   402,   -466],
                        [   332,   -603],
                        [   258,   -743],
                        [   180,   -884],
                        [    98,  -1027],
                        [    14,  -1168],
                        [   -75,  -1311],
                        [  -165,  -1447],
                        [  -257,  -1579],
                        [  -349,  -1698],
                        [  -442,  -1805],
                        [  -533,  -1896],
                        [  -623,  -1972],
                        [  -709,  -2038],
                        [  -789,  -2093],
                        [  -862,  -2146],
                        [  -928,  -2197],
                        [  -986,  -2248],
                        [ -1036,  -2300],
                        [ -1081,  -2347],
                        [ -1120,  -2392],
                        [ -1156,  -2435],
                        [ -1187,  -2476],
                        [ -1214,  -2515],
                        [ -1238,  -2552],
                        [ -1265,  -2588],
                        [ -1294,  -2623],
                        [ -1336,  -2656],
                        [ -1389,  -2689],
                        [ -1450,  -2719],
                        [ -1520,  -2745],
                        [ -1587,  -2763],
                        [ -1650,  -2776],
                        [ -1696,  -2776],
                        [ -1725,  -2767],
                        [ -1735,  -2748],
                        [ -1726,  -2719],
                        [ -1699,  -2679],
                        [ -1654,  -2629],
                        [ -1601,  -2579],
                        [ -1538,  -2528],
                        [ -1478,  -2485],
                        [ -1420,  -2450],
                        [ -1363,  -2420],
                        [ -1308,  -2395],
                        [ -1240,  -2359],
                        [ -1157,  -2310],
                        [ -1055,  -2243],
                        [  -933,  -2158],
                        [  -795,  -2060],
                        [  -641,  -1946],
                        [  -475,  -1823],
                        [  -299,  -1690],
                        [  -117,  -1551],
                        [    72,  -1406],
                        [   261,  -1260],
                        [   450,  -1113],
                        [   635,   -967],
                        [   816,   -822],
                        [   992,   -682],
                        [  1164,   -546],
                        [  1332,   -417],
                        [  1496,   -294],
                        [  1653,   -180],
                        [  1805,    -72],
                        [  1946,     26],
                        [  2078,    115],
                        [  2199,    197],
                        [  2310,    269],
                        [  2409,    332],
                        [  2497,    388],
                        [  2572,    435],
                        [  2637,    475],
                        [  2689,    509],
                        [  2731,    538],
                        [  2763,    562],
                        [  2784,    583],
                        [  2796,    600],
                        [  2799,    616],
                        [  2796,    630],
                        [  2785,    643],
                        [  2770,    655],
                        [  2750,    668],
                        [  2727,    681],
                        [  2701,    696],
                        [  2674,    711],
                        [  2646,    728],
                        [  2619,    747],
                        [  2581,    757],
                        [  2524,    748],
                        [  2446,    721],
                        [  2349,    673],
                        [  2227,    600],
                        [  2082,    505],
                        [  1925,    397],
                        [  1773,    296],
                        [  1630,    205],
                        [  1497,    124],
                        [  1376,     54],
                        [  1271,     -7],
                        [  1181,    -55],
                        [  1108,    -95],
                        [  1055,   -124],
                        [  1016,   -145],
                        [   995,   -157],
                        [   985,   -158],
                        [   985,   -149],
                        [   991,   -129],
                        [  1003,    -99],
                        [  1019,    -59],
                        [  1039,     -8],
                        [  1062,     51],
                        [  1086,    118],
                        [  1109,    192],
                        [  1132,    271],
                        [  1153,    354],
                        [  1172,    441],
                        [  1187,    529],
                        [  1200,    618],
                        [  1210,    706],
                        [  1216,    793],
                        [  1216,    877],
                        [  1213,    958],
                        [  1205,   1035],
                        [  1192,   1109],
                        [  1173,   1178],
                        [  1150,   1242],
                        [  1121,   1300],
                        [  1088,   1352],
                        [  1050,   1395],
                        [  1007,   1431],
                        [   960,   1451],
                        [   908,   1457],
                        [   853,   1442],
                        [   794,   1406],
                        [   730,   1353],
                        [   661,   1280],
                        [   587,   1201],
                        [   505,   1114],
                        [   420,   1033],
                        [   329,    956],
                        [   236,    883],
                        [   142,    816],
                        [    50,    752],
                        [   -41,    691],
                        [  -128,    637],
                        [  -210,    589],
                        [  -283,    549],
                        [  -345,    516],
                        [  -388,    492],
                        [  -409,    479],
                        [  -404,    476],
                        [  -375,    482],
                        [  -328,    495],
                        [  -265,    514],
                        [  -201,    535],
                        [  -135,    557],
                        [   -76,    579],
                        [   -25,    603],
                        [    18,    625],
                        [    53,    647],
                        [    83,    670],
                        [   106,    696],
                        [   139,    737],
                        [   178,    791],
                        [   228,    859],
                        [   288,    943],
                        [   349,   1029],
                        [   413,   1120],
                        [   460,   1197],
                        [   492,   1259],
                        [   506,   1307],
                        [   502,   1337],
                        [   482,   1354],
                        [   444,   1357],
                        [   394,   1348],
                        [   330,   1325],
                        [   256,   1294],
                        [   173,   1250],
                        [    87,   1200],
                        [    -2,   1142],
                        [   -93,   1078],
                        [  -184,   1008],
                        [  -282,    934],
                        [  -384,    857],
                        [  -491,    778],
                        [  -603,    696],
                        [  -717,    615],
                        [  -833,    533],
                        [  -947,    453],
                        [ -1060,    373],
                        [ -1169,    296],
                        [ -1276,    220],
                        [ -1375,    149],
                        [ -1469,     80],
                        [ -1555,     15],
                        [ -1634,    -47],
                        [ -1705,   -105],
                        [ -1766,   -159],
                        [ -1818,   -210],
                        [ -1861,   -258],
                        [ -1894,   -302],
                        [ -1917,   -344],
                        [ -1930,   -381],
                        [ -1934,   -415],
                        [ -1929,   -445],
                        [ -1914,   -472],
                        [ -1893,   -495],
                        [ -1862,   -514],
                        [ -1827,   -531],
                        [ -1782,   -542],
                        [ -1723,   -541],
                        [ -1645,   -524],
                        [ -1546,   -488],
                        [ -1428,   -434],
                        [ -1289,   -359],
                        [ -1125,   -260],
                        [  -947,   -150],
                        [  -768,    -38],
                        [  -592,     69],
                        [  -418,    174],
                        [  -251,    274],
                        [   -92,    367],
                        [    54,    456],
                        [   188,    537],
                        [   305,    613],
                        [   407,    682],
                        [   495,    743],
                        [   567,    795],
                        [   630,    837],
                        [   683,    868],
                        [   725,    886],
                        [   757,    894],
                        [   781,    886],
                        [   795,    865],
                        [   802,    832],
                        [   801,    786],
                        [   793,    727],
                        [   778,    657],
                        [   757,    577],
                        [   730,    487],
                        [   697,    389],
                        [   659,    284],
                        [   617,    173],
                        [   570,     57],
                        [   520,    -63],
                        [   467,   -186],
                        [   414,   -311],
                        [   359,   -439],
                        [   304,   -566],
                        [   249,   -691],
                        [   195,   -813],
                        [   141,   -932],
                        [    89,  -1042],
                        [    40,  -1142],
                        [    -7,  -1224],
                        [   -50,  -1285],
                        [   -87,  -1323],
                        [  -119,  -1336],
                        [  -144,  -1330],
                        [  -160,  -1307],
                        [  -167,  -1280],
                        [  -164,  -1249],
                        [  -153,  -1220],
                        [  -132,  -1194],
                        [  -104,  -1166],
                        [   -70,  -1137],
                        [   -31,  -1104],
                        [    14,  -1069],
                        [    60,  -1034],
                        [   109,   -997],
                        [   150,   -961],
                        [   184,   -928],
                        [   201,   -897],
                        [   201,   -869],
                        [   187,   -843],
                        [   157,   -820],
                        [   126,   -794],
                        [    92,   -767],
                        [    69,   -735],
                        [    58,   -699],
                        [    58,   -659],
                        [    70,   -615],
                        [    93,   -569],
                        [   128,   -519],
                        [   164,   -478],
                        [   202,   -443],
                        [   230,   -423],
                        [   250,   -418],
                        [   262,   -426],
                        [   264,   -447],
                        [   271,   -465],
                        [   284,   -481],
                        [   310,   -487],
                        [   349,   -481],
                        [   403,   -466],
                        [   470,   -441],
                        [   548,   -409],
                        [   636,   -368],
                        [   732,   -321],
                        [   834,   -268],
                        [   937,   -211],
                        [  1039,   -149],
                        [  1137,    -85],
                        [  1229,    -19],
                        [  1319,     49],
                        [  1407,    118],
                        [  1499,    186],
                        [  1594,    254],
                        [  1692,    321],
                        [  1793,    386],
                        [  1894,    449],
                        [  1995,    510],
                        [  2094,    569],
                        [  2191,    624],
                        [  2286,    678],
                        [  2377,    728],
                        [  2463,    776],
                        [  2545,    821],
                        [  2622,    863],
                        [  2694,    904],
                        [  2761,    942],
                        [  2823,    979],
                        [  2878,   1015],
                        [  2927,   1050],
                        [  2970,   1085],
                        [  3006,   1118],
                        [  3038,   1152],
                        [  3063,   1186],
                        [  3083,   1220],
                        [  3099,   1252],
                        [  3109,   1285],
                        [  3115,   1318],
                        [  3116,   1349],
                        [  3106,   1373],
                        [  3085,   1389],
                        [  3051,   1395],
                        [  3004,   1391],
                        [  2942,   1374],
                        [  2862,   1341],
                        [  2771,   1298],
                        [  2678,   1255],
                        [  2581,   1211],
                        [  2484,   1168],
                        [  2387,   1125],
                        [  2293,   1083],
                        [  2204,   1042],
                        [  2121,   1003],
                        [  2043,    964],
                        [  1974,    925],
                        [  1913,    886],
                        [  1854,    849],
                        [  1800,    813],
                        [  1747,    780],
                        [  1695,    749],
                        [  1644,    723],
                        [  1593,    702],
                        [  1541,    687],
                        [  1489,    677],
                        [  1436,    673],
                        [  1381,    674],
                        [  1324,    679],
                        [  1267,    689],
                        [  1207,    701],
                        [  1146,    717],
                        [  1085,    735],
                        [  1021,    754],
                        [   957,    774],
                        [   891,    796],
                        [   824,    818],
                        [   755,    841],
                        [   685,    864],
                        [   613,    886],
                        [   540,    907],
                        [   468,    927],
                        [   395,    943],
                        [   321,    956],
                        [   248,    957],
                        [   175,    947],
                        [   102,    918],
                        [    31,    870],
                        [   -42,    804],
                        [  -115,    720],
                        [  -189,    631],
                        [  -263,    537],
                        [  -340,    453],
                        [  -417,    380],
                        [  -493,    316],
                        [  -568,    260],
                        [  -639,    210],
                        [  -709,    164],
                        [  -773,    124],
                        [  -832,     90],
                        [  -879,     63],
                        [  -917,     44],
                        [  -932,     36],
                        [  -926,     37],
                        [  -896,     47],
                        [  -843,     67],
                        [  -774,     93],
                        [  -687,    126],
                        [  -602,    159],
                        [  -516,    194],
                        [  -436,    229],
                        [  -363,    263],
                        [  -299,    297],
                        [  -243,    329],
                        [  -192,    364],
                        [  -146,    401],
                        [   -97,    449],
                        [   -44,    507],
                        [    16,    577],
                        [    82,    658],
                        [   150,    743],
                        [   220,    834],
                        [   275,    912],
                        [   318,    981],
                        [   344,   1037],
                        [   352,   1081],
                        [   344,   1112],
                        [   319,   1131],
                        [   281,   1139],
                        [   228,   1135],
                        [   169,   1121],
                        [   103,   1099],
                        [    37,   1067],
                        [   -28,   1027],
                        [   -92,    981],
                        [  -154,    927],
                        [  -222,    870],
                        [  -294,    808],
                        [  -375,    743],
                        [  -464,    676],
                        [  -558,    607],
                        [  -657,    537],
                        [  -756,    468],
                        [  -859,    398],
                        [  -960,    331],
                        [ -1060,    266],
                        [ -1156,    202],
                        [ -1250,    142],
                        [ -1339,     85],
                        [ -1423,     32],
                        [ -1502,    -18],
                        [ -1574,    -63],
                        [ -1639,   -105],
                        [ -1696,   -143],
                        [ -1744,   -177],
                        [ -1783,   -207],
                        [ -1814,   -235],
                        [ -1835,   -258],
                        [ -1848,   -280],
                        [ -1853,   -297],
                        [ -1850,   -311],
                        [ -1840,   -323],
                        [ -1822,   -332],
                        [ -1797,   -337],
                        [ -1763,   -339],
                        [ -1718,   -334],
                        [ -1666,   -323],
                        [ -1606,   -308],
                        [ -1535,   -284],
                        [ -1453,   -251],
                        [ -1363,   -212],
                        [ -1270,   -172],
                        [ -1177,   -133],
                        [ -1083,    -94],
                        [  -992,    -58],
                        [  -905,    -24],
                        [  -825,      7],
                        [  -752,     35],
                        [  -687,     60],
                        [  -634,     82],
                        [  -588,    102],
                        [  -555,    119],
                        [  -527,    131],
                        [  -507,    140],
                        [  -493,    141],
                        [  -485,    137],
                        [  -483,    126],
                        [  -485,    106],
                        [  -492,     78],
                        [  -503,     41],
                        [  -517,     -3],
                        [  -534,    -54],
                        [  -553,   -112],
                        [  -574,   -176],
                        [  -596,   -244],
                        [  -620,   -316],
                        [  -644,   -390],
                        [  -669,   -466],
                        [  -691,   -544],
                        [  -713,   -622],
                        [  -732,   -700],
                        [  -748,   -776],
                        [  -761,   -850],
                        [  -769,   -921],
                        [  -774,   -987],
                        [  -775,  -1048],
                        [  -772,  -1099],
                        [  -764,  -1138],
                        [  -751,  -1159],
                        [  -732,  -1159],
                        [  -708,  -1134],
                        [  -678,  -1086],
                        [  -642,  -1020],
                        [  -598,   -934],
                        [  -548,   -847],
                        [  -490,   -760],
                        [  -426,   -678],
                        [  -355,   -601],
                        [  -280,   -526],
                        [  -200,   -451],
                        [  -117,   -375],
                        [   -31,   -297],
                        [    53,   -220],
                        [   136,   -145],
                        [   206,    -76],
                        [   266,    -11],
                        [   308,     46],
                        [   332,     96],
                        [   338,    140],
                        [   326,    176],
                        [   307,    209],
                        [   281,    239],
                        [   259,    267],
                        [   239,    293],
                        [   223,    317],
                        [   212,    338],
                        [   206,    358],
                        [   203,    375],
                        [   197,    380],
                        [   189,    376],
                        [   174,    359],
                        [   150,    328],
                        [   116,    284],
                        [    74,    228],
                        [    33,    170],
                        [    -6,    110],
                        [   -35,     56],
                        [   -54,      7],
                        [   -63,    -36],
                        [   -60,    -73],
                        [   -47,   -103],
                        [   -23,   -128],
                        [     7,   -145],
                        [    45,   -158],
                        [    80,   -163],
                        [   112,   -163],
                        [   140,   -158],
                        [   163,   -148],
                        [   187,   -133],
                        [   210,   -114],
                        [   241,    -90],
                        [   283,    -63],
                        [   333,    -33],
                        [   392,      0],
                        [   459,     36],
                        [   532,     74],
                        [   609,    114],
                        [   692,    156],
                        [   778,    198],
                        [   867,    242],
                        [   957,    287],
                        [  1050,    331],
                        [  1142,    375],
                        [  1235,    418],
                        [  1327,    462],
                        [  1417,    504],
                        [  1504,    545],
                        [  1587,    587],
                        [  1664,    627],
                        [  1736,    667],
                        [  1802,    706],
                        [  1862,    743],
                        [  1916,    779],
                        [  1962,    814],
                        [  2002,    846],
                        [  2035,    876],
                        [  2060,    904],
                        [  2075,    928],
                        [  2083,    948],
                        [  2082,    965],
                        [  2074,    977],
                        [  2055,    984],
                        [  2025,    982],
                        [  1983,    973],
                        [  1935,    960],
                        [  1879,    942],
                        [  1817,    919],
                        [  1749,    894],
                        [  1679,    865],
                        [  1605,    833],
                        [  1529,    798],
                        [  1452,    761],
                        [  1376,    719],
                        [  1302,    675],
                        [  1228,    628],
                        [  1155,    577],
                        [  1082,    524],
                        [  1009,    470],
                        [   935,    418],
                        [   862,    366],
                        [   788,    320],
                        [   714,    277],
                        [   640,    239],
                        [   566,    206],
                        [   492,    178],
                        [   418,    154],
                        [   345,    136],
                        [   272,    121],
                        [   201,    111],
                        [   129,    104],
                        [    59,    102],
                        [    -9,    103],
                        [   -77,    107],
                        [  -144,    115],
                        [  -210,    126],
                        [  -275,    139],
                        [  -340,    154],
                        [  -403,    169],
                        [  -463,    184],
                        [  -522,    198],
                        [  -579,    204],
                        [  -635,    202],
                        [  -687,    185],
                        [  -739,    153],
                        [  -787,    106],
                        [  -835,     44],
                        [  -882,    -21],
                        [  -927,    -90],
                        [  -973,   -149],
                        [ -1017,   -197],
                        [ -1062,   -238],
                        [ -1106,   -271],
                        [ -1149,   -304],
                        [ -1190,   -334],
                        [ -1230,   -364],
                        [ -1268,   -392],
                        [ -1296,   -414],
                        [ -1317,   -432],
                        [ -1324,   -444],
                        [ -1318,   -449],
                        [ -1295,   -449],
                        [ -1257,   -440],
                        [ -1207,   -428],
                        [ -1146,   -412],
                        [ -1086,   -395],
                        [ -1024,   -376],
                        [  -966,   -357],
                        [  -912,   -338],
                        [  -862,   -319],
                        [  -817,   -301],
                        [  -776,   -280],
                        [  -738,   -256],
                        [  -697,   -226],
                        [  -655,   -188],
                        [  -607,   -142],
                        [  -556,    -89],
                        [  -502,    -32],
                        [  -446,     29],
                        [  -399,     86],
                        [  -358,    137],
                        [  -330,    183],
                        [  -312,    223],
                        [  -305,    255],
                        [  -309,    281],
                        [  -323,    301],
                        [  -345,    314],
                        [  -366,    322],
                        [  -389,    323],
                        [  -405,    320],
                        [  -417,    313],
                        [  -423,    301],
                        [  -423,    285],
                        [  -427,    267],
                        [  -435,    245],
                        [  -451,    222],
                        [  -476,    197],
                        [  -509,    171],
                        [  -546,    144],
                        [  -589,    116],
                        [  -636,     89],
                        [  -686,     62],
                        [  -739,     34],
                        [  -794,      9],
                        [  -850,    -15],
                        [  -908,    -39],
                        [  -965,    -60],
                        [ -1024,    -80],
                        [ -1081,    -99],
                        [ -1137,   -115],
                        [ -1190,   -131],
                        [ -1240,   -145],
                        [ -1285,   -158],
                        [ -1327,   -171],
                        [ -1364,   -184],
                        [ -1397,   -197],
                        [ -1425,   -210],
                        [ -1450,   -223],
                        [ -1469,   -236],
                        [ -1485,   -249],
                        [ -1497,   -262],
                        [ -1505,   -278],
                        [ -1510,   -294],
                        [ -1514,   -314],
                        [ -1515,   -334],
                        [ -1514,   -355],
                        [ -1509,   -375],
                        [ -1501,   -393],
                        [ -1490,   -410],
                        [ -1477,   -428],
                        [ -1463,   -445],
                        [ -1448,   -463],
                        [ -1433,   -482],
                        [ -1419,   -501],
                        [ -1407,   -520],
                        [ -1396,   -540],
                        [ -1388,   -560],
                        [ -1382,   -578],
                        [ -1380,   -594],
                        [ -1382,   -608],
                        [ -1387,   -619],
                        [ -1393,   -630],
                        [ -1402,   -639],
                        [ -1411,   -651],
                        [ -1421,   -662],
                        [ -1431,   -676],
                        [ -1441,   -692],
                        [ -1450,   -710],
                        [ -1458,   -730],
                        [ -1465,   -750],
                        [ -1470,   -771],
                        [ -1472,   -792],
                        [ -1472,   -814],
                        [ -1469,   -834],
                        [ -1463,   -855],
                        [ -1452,   -873],
                        [ -1439,   -891],
                        [ -1420,   -905],
                        [ -1397,   -918],
                        [ -1368,   -927],
                        [ -1336,   -934],
                        [ -1299,   -937],
                        [ -1259,   -934],
                        [ -1214,   -925],
                        [ -1167,   -908],
                        [ -1116,   -876],
                        [ -1061,   -830],
                        [ -1004,   -769],
                        [  -945,   -692],
                        [  -885,   -604],
                        [  -821,   -505],
                        [  -756,   -410],
                        [  -690,   -318],
                        [  -620,   -232],
                        [  -548,   -154],
                        [  -475,    -78],
                        [  -399,     -4],
                        [  -323,     72],
                        [  -248,    150],
                        [  -176,    224],
                        [  -106,    296],
                        [   -44,    362],
                        [    11,    423],
                        [    55,    478],
                        [    89,    524],
                        [   111,    563],
                        [   120,    594],
                        [   124,    620],
                        [   119,    640],
                        [   112,    656],
                        [   102,    666],
                        [    92,    674],
                        [    79,    675],
                        [    65,    674],
                        [    50,    667],
                        [    32,    652],
                        [     9,    631],
                        [   -20,    600],
                        [   -55,    560],
                        [   -98,    511],
                        [  -146,    454],
                        [  -195,    396],
                        [  -245,    335],
                        [  -289,    276],
                        [  -328,    219],
                        [  -359,    167],
                        [  -382,    117],
                        [  -397,     72],
                        [  -405,     31],
                        [  -409,     -4],
                        [  -410,    -36],
                        [  -415,    -62],
                        [  -425,    -82],
                        [  -440,    -97],
                        [  -459,   -106],
                        [  -479,   -112],
                        [  -501,   -112],
                        [  -509,   -108],
                        [  -509,   -100],
                        [  -499,    -88],
                        [  -479,    -72],
                        [  -450,    -52],
                        [  -412,    -29],
                        [  -366,     -3],
                        [  -314,     24],
                        [  -256,     54],
                        [  -192,     86],
                        [  -123,    119],
                        [   -49,    152],
                        [    28,    184],
                        [   109,    218],
                        [   191,    249],
                        [   274,    280],
                        [   355,    310],
                        [   435,    340],
                        [   509,    366],
                        [   582,    393],
                        [   648,    418],
                        [   710,    440],
                        [   766,    462],
                        [   817,    480],
                        [   860,    496],
                        [   898,    509],
                        [   928,    521],
                        [   951,    531],
                        [   970,    540],
                        [   983,    548],
                        [   992,    555],
                        [   995,    560],
                        [   992,    561],
                        [   982,    557],
                        [   966,    550],
                        [   945,    539],
                        [   919,    523],
                        [   887,    505],
                        [   852,    484],
                        [   813,    461],
                        [   770,    436],
                        [   724,    408],
                        [   677,    377],
                        [   628,    345],
                        [   581,    307],
                        [   536,    267],
                        [   492,    222],
                        [   451,    175],
                        [   410,    127],
                        [   372,     78],
                        [   336,     32],
                        [   301,    -13],
                        [   268,    -54],
                        [   237,    -93],
                        [   208,   -129],
                        [   180,   -162],
                        [   154,   -190],
                        [   128,   -215],
                        [   103,   -236],
                        [    80,   -254],
                        [    58,   -267],
                        [    36,   -278],
                        [    14,   -286],
                        [    -8,   -290],
                        [   -30,   -292],
                        [   -53,   -291],
                        [   -75,   -287],
                        [   -97,   -282],
                        [  -119,   -277],
                        [  -140,   -271],
                        [  -162,   -271],
                        [  -182,   -274],
                        [  -202,   -283],
                        [  -222,   -299],
                        [  -240,   -320],
                        [  -257,   -345],
                        [  -273,   -371],
                        [  -288,   -394],
                        [  -305,   -410],
                        [  -322,   -419],
                        [  -342,   -424],
                        [  -364,   -427],
                        [  -388,   -432],
                        [  -414,   -441],
                        [  -442,   -453],
                        [  -470,   -470],
                        [  -497,   -485],
                        [  -523,   -501],
                        [  -548,   -518],
                        [  -570,   -533],
                        [  -587,   -545],
                        [  -599,   -556],
                        [  -606,   -565],
                        [  -609,   -571],
                        [  -609,   -578],
                        [  -607,   -583],
                        [  -603,   -587],
                        [  -597,   -592],
                        [  -592,   -594],
                        [  -583,   -596],
                        [  -574,   -596],
                        [  -562,   -594],
                        [  -546,   -587],
                        [  -525,   -576],
                        [  -499,   -561],
                        [  -466,   -540],
                        [  -430,   -515],
                        [  -388,   -486],
                        [  -345,   -457],
                        [  -303,   -427],
                        [  -264,   -399],
                        [  -228,   -372],
                        [  -197,   -347],
                        [  -167,   -323],
                        [  -141,   -301],
                        [  -117,   -280],
                        [   -87,   -262],
                        [   -51,   -246],
                        [    -8,   -232],
                        [    43,   -219],
                        [   102,   -208],
                        [   167,   -199],
                        [   229,   -192],
                        [   288,   -185],
                        [   339,   -181],
                        [   382,   -178],
                        [   417,   -176],
                        [   444,   -175],
                        [   464,   -176],
                        [   476,   -176],
                        [   481,   -179],
                        [   479,   -182],
                        [   470,   -186],
                        [   453,   -192],
                        [   430,   -197],
                        [   400,   -203],
                        [   363,   -210],
                        [   322,   -217],
                        [   276,   -223],
                        [   227,   -231],
                        [   176,   -238],
                        [   124,   -247],
                        [    71,   -257],
                        [    17,   -267],
                        [   -37,   -280],
                        [   -90,   -293],
                        [  -143,   -306],
                        [  -195,   -322],
                        [  -245,   -338],
                        [  -294,   -355],
                        [  -341,   -375],
                        [  -388,   -397],
                        [  -434,   -423],
                        [  -479,   -450],
                        [  -524,   -479],
                        [  -567,   -509],
                        [  -608,   -538],
                        [  -647,   -566],
                        [  -683,   -592],
                        [  -717,   -618],
                        [  -750,   -643],
                        [  -779,   -666],
                        [  -804,   -688],
                        [  -826,   -710],
                        [  -843,   -730],
                        [  -856,   -749],
                        [  -867,   -765],
                        [  -878,   -776],
                        [  -887,   -782],
                        [  -898,   -783],
                        [  -908,   -779],
                        [  -918,   -770],
                        [  -927,   -757],
                        [  -935,   -741],
                        [  -942,   -723],
                        [  -947,   -703],
                        [  -951,   -680],
                        [  -952,   -656],
                        [  -951,   -630],
                        [  -948,   -602],
                        [  -941,   -574],
                        [  -931,   -544],
                        [  -918,   -514],
                        [  -902,   -483],
                        [  -882,   -449],
                        [  -858,   -415],
                        [  -831,   -381],
                        [  -800,   -345],
                        [  -765,   -309],
                        [  -728,   -273],
                        [  -689,   -236],
                        [  -648,   -197],
                        [  -605,   -156],
                        [  -561,   -113],
                        [  -516,    -66],
                        [  -471,    -15],
                        [  -427,     36],
                        [  -385,     89],
                        [  -345,    141],
                        [  -308,    190],
                        [  -271,    232],
                        [  -236,    267],
                        [  -199,    297],
                        [  -162,    318],
                        [  -124,    339],
                        [   -84,    360],
                        [   -44,    384],
                        [    -3,    412],
                        [    37,    440],
                        [    76,    466],
                        [   116,    494],
                        [   155,    521],
                        [   193,    546],
                        [   230,    568],
                        [   262,    587],
                        [   290,    601],
                        [   314,    613],
                        [   333,    622],
                        [   349,    626],
                        [   361,    629],
                        [   371,    629],
                        [   376,    626],
                        [   379,    620],
                        [   379,    613],
                        [   376,    601],
                        [   370,    587],
                        [   360,    569],
                        [   345,    547],
                        [   328,    522],
                        [   306,    493],
                        [   282,    463],
                        [   256,    431],
                        [   231,    400],
                        [   207,    368],
                        [   186,    338],
                        [   169,    310],
                        [   154,    284],
                        [   141,    259],
                        [   128,    238],
                        [   113,    219],
                        [    91,    202],
                        [    63,    189],
                        [    28,    179],
                        [   -12,    171],
                        [   -56,    166],
                        [  -103,    163],
                        [  -142,    163],
                        [  -176,    166],
                        [  -202,    171],
                        [  -223,    177],
                        [  -236,    186],
                        [  -243,    197],
                        [  -244,    208],
                        [  -239,    220],
                        [  -227,    234],
                        [  -209,    249],
                        [  -184,    263],
                        [  -154,    279],
                        [  -119,    293],
                        [   -78,    306],
                        [   -34,    319],
                        [    12,    329],
                        [    61,    339],
                        [   110,    347],
                        [   158,    353],
                        [   206,    358],
                        [   251,    360],
                        [   295,    362],
                        [   337,    362],
                        [   377,    359],
                        [   414,    356],
                        [   447,    350],
                        [   476,    342],
                        [   502,    334],
                        [   525,    325],
                        [   544,    315],
                        [   561,    305],
                        [   576,    294],
                        [   589,    282],
                        [   600,    267],
                        [   608,    251],
                        [   614,    232],
                        [   620,    212],
                        [   624,    191],
                        [   625,    170],
                        [   623,    147],
                        [   618,    125],
                        [   608,    104],
                        [   597,     82],
                        [   583,     61],
                        [   571,     37],
                        [   561,     12],
                        [   553,    -16],
                        [   550,    -47],
                        [   549,    -80],
                        [   552,   -115],
                        [   557,   -150],
                        [   565,   -185],
                        [   574,   -220],
                        [   586,   -255],
                        [   598,   -288],
                        [   613,   -319],
                        [   627,   -349],
                        [   641,   -376],
                        [   655,   -400],
                        [   668,   -422],
                        [   680,   -441],
                        [   690,   -459],
                        [   698,   -475],
                        [   704,   -488],
                        [   708,   -499],
                        [   709,   -506],
                        [   709,   -512],
                        [   707,   -516],
                        [   703,   -519],
                        [   696,   -522],
                        [   689,   -526],
                        [   680,   -530],
                        [   671,   -533],
                        [   663,   -535],
                        [   656,   -532],
                        [   650,   -526],
                        [   644,   -515],
                        [   639,   -499],
                        [   633,   -476],
                        [   624,   -449],
                        [   612,   -420],
                        [   596,   -391],
                        [   577,   -367],
                        [   554,   -349],
                        [   529,   -336],
                        [   501,   -327],
                        [   470,   -324],
                        [   436,   -326],
                        [   397,   -331],
                        [   356,   -340],
                        [   314,   -352],
                        [   271,   -364],
                        [   232,   -375],
                        [   194,   -388],
                        [   160,   -400],
                        [   131,   -411],
                        [   105,   -423],
                        [    83,   -433],
                        [    67,   -443],
                        [    54,   -453],
                        [    47,   -460],
                        [    45,   -466],
                        [    47,   -470],
                        [    54,   -474],
                        [    65,   -474],
                        [    82,   -471],
                        [   105,   -466],
                        [   134,   -457],
                        [   167,   -447],
                        [   203,   -434],
                        [   242,   -420],
                        [   283,   -404],
                        [   323,   -388],
                        [   366,   -370],
                        [   410,   -352],
                        [   457,   -333],
                        [   509,   -314],
                        [   566,   -297],
                        [   629,   -278],
                        [   699,   -260],
                        [   774,   -242],
                        [   855,   -225],
                        [   934,   -210],
                        [  1010,   -195],
                        [  1081,   -180],
                        [  1144,   -168],
                        [  1202,   -157],
                        [  1253,   -146],
                        [  1296,   -137],
                        [  1332,   -130],
                        [  1359,   -124],
                        [  1377,   -121],
                        [  1387,   -120],
                        [  1387,   -120],
                        [  1378,   -123],
                        [  1361,   -127],
                        [  1335,   -132],
                        [  1301,   -140],
                        [  1260,   -148],
                        [  1214,   -156],
                        [  1164,   -167],
                        [  1108,   -179],
                        [  1051,   -192],
                        [   989,   -206],
                        [   926,   -221],
                        [   860,   -238],
                        [   795,   -256],
                        [   728,   -274],
                        [   663,   -293],
                        [   598,   -312],
                        [   535,   -332],
                        [   475,   -352],
                        [   417,   -372],
                        [   362,   -392],
                        [   309,   -411],
                        [   258,   -430],
                        [   209,   -447],
                        [   162,   -462],
                        [   116,   -476],
                        [    72,   -488],
                        [    33,   -499],
                        [    -6,   -508],
                        [   -37,   -517],
                        [   -61,   -523],
                        [   -80,   -530],
                        [   -90,   -535],
                        [   -98,   -539],
                        [  -101,   -539],
                        [  -104,   -535],
                        [  -107,   -527],
                        [  -111,   -512],
                        [  -115,   -492],
                        [  -120,   -465],
                        [  -125,   -434],
                        [  -130,   -398],
                        [  -136,   -358],
                        [  -141,   -315],
                        [  -146,   -268],
                        [  -150,   -220],
                        [  -154,   -171],
                        [  -155,   -119],
                        [  -155,    -69],
                        [  -154,    -17],
                        [  -150,     35],
                        [  -145,     88],
                        [  -137,    140],
                        [  -127,    190],
                        [  -116,    240],
                        [  -104,    287],
                        [   -91,    332],
                        [   -77,    375],
                        [   -63,    416],
                        [   -48,    457],
                        [   -33,    496],
                        [   -20,    531],
                        [    -8,    563],
                        [     1,    588],
                        [     6,    606],
                        [     7,    615],
                        [     5,    615],
                        [     1,    607],
                        [    -5,    592],
                        [    -9,    570],
                        [   -11,    541],
                        [   -11,    514],
                        [    -9,    485],
                        [    -4,    462],
                        [     3,    440],
                        [    13,    421],
                        [    27,    405],
                        [    46,    394],
                        [    71,    387],
                        [    99,    383],
                        [   132,    380],
                        [   167,    377],
                        [   202,    375],
                        [   235,    372],
                        [   267,    368],
                        [   297,    365],
                        [   324,    360],
                        [   349,    356],
                        [   371,    351],
                        [   391,    345],
                        [   407,    341],
                        [   422,    337],
                        [   434,    333],
                        [   444,    329],
                        [   454,    327],
                        [   461,    324],
                        [   464,    321],
                        [   463,    318],
                        [   460,    314],
                        [   453,    309],
                        [   443,    305],
                        [   432,    301],
                        [   420,    298],
                        [   406,    296],
                        [   391,    293],
                        [   372,    293],
                        [   350,    293],
                        [   323,    293],
                        [   292,    294],
                        [   256,    297],
                        [   215,    300],
                        [   170,    303],
                        [   121,    307],
                        [    74,    312],
                        [    28,    318],
                        [   -16,    323],
                        [   -59,    329],
                        [   -99,    336],
                        [  -136,    341],
                        [  -169,    347],
                        [  -199,    353],
                        [  -223,    358],
                        [  -244,    364],
                        [  -259,    369],
                        [  -269,    374],
                        [  -274,    379],
                        [  -275,    382],
                        [  -270,    384],
                        [  -262,    384],
                        [  -250,    383],
                        [  -236,    380],
                        [  -220,    375],
                        [  -202,    370],
                        [  -182,    363],
                        [  -160,    354],
                        [  -137,    345],
                        [  -114,    333],
                        [   -90,    320],
                        [   -67,    306],
                        [   -44,    292],
                        [   -22,    275],
                        [    -2,    257],
                        [    16,    238],
                        [    33,    219],
                        [    50,    197],
                        [    66,    176],
                        [    82,    152],
                        [   100,    129],
                        [   119,    105],
                        [   137,     81],
                        [   158,     57],
                        [   176,     33],
                        [   192,     11],
                        [   203,    -10],
                        [   210,    -28],
                        [   213,    -43],
                        [   212,    -56],
                        [   211,    -68],
                        [   210,    -80],
                        [   214,    -93],
                        [   220,   -107],
                        [   230,   -124],
                        [   241,   -145],
                        [   257,   -166],
                        [   275,   -189],
                        [   294,   -215],
                        [   315,   -241],
                        [   338,   -268],
                        [   362,   -294],
                        [   384,   -319],
                        [   408,   -342],
                        [   429,   -365],
                        [   449,   -386],
                        [   468,   -406],
                        [   484,   -427],
                        [   499,   -444],
                        [   511,   -460],
                        [   522,   -474],
                        [   530,   -485],
                        [   536,   -494],
                        [   541,   -501],
                        [   545,   -507],
                        [   547,   -512],
                        [   548,   -515],
                        [   549,   -517],
                        [   552,   -513],
                        [   556,   -505],
                        [   563,   -489],
                        [   573,   -466],
                        [   584,   -437],
                        [   598,   -403],
                        [   610,   -365],
                        [   622,   -323],
                        [   630,   -280],
                        [   635,   -236],
                        [   637,   -197],
                        [   636,   -163],
                        [   632,   -132],
                        [   626,   -106],
                        [   613,    -88],
                        [   596,    -75],
                        [   574,    -68],
                        [   546,    -67],
                        [   514,    -69],
                        [   480,    -74],
                        [   447,    -79],
                        [   415,    -84],
                        [   385,    -89],
                        [   358,    -93],
                        [   335,    -98],
                        [   314,   -102],
                        [   297,   -104],
                        [   286,   -107],
                        [   277,   -109],
                        [   271,   -111],
                        [   268,   -112],
                        [   267,   -114],
                        [   267,   -115],
                        [   271,   -115],
                        [   278,   -113],
                        [   288,   -111],
                        [   303,   -106],
                        [   322,    -99],
                        [   344,    -92],
                        [   369,    -84],
                        [   396,    -74],
                        [   425,    -63],
                        [   455,    -52],
                        [   488,    -41],
                        [   521,    -29],
                        [   556,    -17],
                        [   592,     -7],
                        [   631,      5],
                        [   671,     16],
                        [   713,     27],
                        [   756,     36],
                        [   797,     45],
                        [   837,     52],
                        [   874,     59],
                        [   908,     64],
                        [   938,     68],
                        [   964,     72],
                        [   986,     73],
                        [  1003,     72],
                        [  1014,     71],
                        [  1019,     66],
                        [  1017,     60],
                        [  1010,     52],
                        [   996,     42],
                        [   977,     31],
                        [   951,     19],
                        [   921,      6],
                        [   887,     -9],
                        [   849,    -24],
                        [   808,    -39],
                        [   764,    -54],
                        [   717,    -70],
                        [   670,    -85],
                        [   620,   -102],
                        [   570,   -117],
                        [   518,   -132],
                        [   468,   -146],
                        [   419,   -159],
                        [   373,   -171],
                        [   328,   -181],
                        [   286,   -189],
                        [   247,   -196],
                        [   210,   -200],
                        [   176,   -202],
                        [   142,   -202],
                        [   110,   -198],
                        [    80,   -193],
                        [    50,   -184],
                        [    23,   -175],
                        [    -2,   -163],
                        [   -20,   -150],
                        [   -32,   -135],
                        [   -37,   -121],
                        [   -36,   -108],
                        [   -29,    -95],
                        [   -17,    -83],
                        [    -7,    -68],
                        [     5,    -51],
                        [    13,    -30],
                        [    20,     -5],
                        [    24,     26],
                        [    25,     61],
                        [    25,    100],
                        [    23,    144],
                        [    18,    190],
                        [    12,    239],
                        [     5,    288],
                        [    -4,    339],
                        [   -13,    388],
                        [   -22,    437],
                        [   -31,    485],
                        [   -39,    533],
                        [   -47,    579],
                        [   -55,    624],
                        [   -63,    666],
                        [   -72,    705],
                        [   -80,    740],
                        [   -88,    772],
                        [   -97,    800],
                        [  -106,    824],
                        [  -115,    845],
                        [  -125,    862],
                        [  -137,    874],
                        [  -152,    880],
                        [  -171,    877],
                        [  -193,    865],
                        [  -219,    846],
                        [  -249,    820],
                        [  -280,    789],
                        [  -313,    752],
                        [  -342,    713],
                        [  -371,    670],
                        [  -395,    626],
                        [  -416,    584],
                        [  -434,    544],
                        [  -448,    504],
                        [  -457,    470],
                        [  -462,    440],
                        [  -459,    416],
                        [  -449,    398],
                        [  -432,    385],
                        [  -410,    376],
                        [  -384,    369],
                        [  -355,    362],
                        [  -327,    356],
                        [  -297,    350],
                        [  -269,    345],
                        [  -241,    340],
                        [  -215,    336],
                        [  -189,    332],
                        [  -167,    329],
                        [  -146,    327],
                        [  -126,    326],
                        [  -106,    327],
                        [   -86,    329],
                        [   -67,    332],
                        [   -49,    337],
                        [   -33,    342],
                        [   -20,    348],
                        [   -11,    353],
                        [    -7,    358],
                        [    -7,    364],
                        [   -11,    369],
                        [   -18,    374],
                        [   -28,    378],
                        [   -42,    383],
                        [   -58,    387],
                        [   -76,    391],
                        [   -97,    394],
                        [  -119,    398],
                        [  -145,    401],
                        [  -172,    402],
                        [  -205,    404],
                        [  -241,    405],
                        [  -279,    405],
                        [  -319,    404],
                        [  -360,    402],
                        [  -401,    400],
                        [  -442,    397],
                        [  -483,    392],
                        [  -522,    387],
                        [  -559,    381],
                        [  -594,    375],
                        [  -626,    367],
                        [  -655,    361],
                        [  -680,    353],
                        [  -701,    345],
                        [  -718,    338],
                        [  -731,    330],
                        [  -741,    320],
                        [  -747,    310],
                        [  -749,    300],
                        [  -748,    289],
                        [  -745,    277],
                        [  -738,    266],
                        [  -729,    253],
                        [  -717,    241],
                        [  -703,    228],
                        [  -687,    214],
                        [  -670,    200],
                        [  -652,    186],
                        [  -633,    172],
                        [  -615,    158],
                        [  -597,    142],
                        [  -579,    128],
                        [  -561,    112],
                        [  -543,     97],
                        [  -524,     81],
                        [  -505,     66],
                        [  -483,     50],
                        [  -462,     34],
                        [  -439,     19],
                        [  -419,      5],
                        [  -401,     -9],
                        [  -388,    -19],
                        [  -381,    -26],
                        [  -379,    -30],
                        [  -382,    -29],
                        [  -387,    -26],
                        [  -394,    -20],
                        [  -398,    -14],
                        [  -400,     -8],
                        [  -400,     -5],
                        [  -397,     -5],
                        [  -392,     -8],
                        [  -385,    -15],
                        [  -375,    -24],
                        [  -364,    -37],
                        [  -351,    -50],
                        [  -337,    -66],
                        [  -323,    -80],
                        [  -308,    -96],
                        [  -293,   -112],
                        [  -280,   -128],
                        [  -267,   -145],
                        [  -254,   -163],
                        [  -242,   -180],
                        [  -231,   -196],
                        [  -220,   -210],
                        [  -210,   -223],
                        [  -199,   -235],
                        [  -189,   -245],
                        [  -180,   -253],
                        [  -170,   -260],
                        [  -159,   -265],
                        [  -148,   -267],
                        [  -132,   -264],
                        [  -115,   -256],
                        [   -93,   -243],
                        [   -66,   -223],
                        [   -37,   -202],
                        [    -7,   -179],
                        [    24,   -153],
                        [    55,   -125],
                        [    84,    -98],
                        [   111,    -68],
                        [   135,    -41],
                        [   158,    -13],
                        [   176,     11],
                        [   192,     33],
                        [   202,     49],
                        [   207,     59],
                        [   207,     65],
                        [   201,     66],
                        [   191,     64],
                        [   177,     61],
                        [   163,     60],
                        [   149,     61],
                        [   134,     63],
                        [   119,     65],
                        [   106,     68],
                        [    94,     73],
                        [    84,     80],
                        [    75,     88],
                        [    66,     96],
                        [    58,    104],
                        [    49,    113],
                        [    38,    121],
                        [    28,    130],
                        [    16,    139],
                        [     6,    148],
                        [    -3,    158],
                        [    -9,    167],
                        [   -12,    177],
                        [   -13,    187],
                        [   -11,    197],
                        [    -7,    206],
                        [    -2,    216],
                        [     4,    224],
                        [    11,    232],
                        [    17,    239],
                        [    21,    245],
                        [    26,    250],
                        [    30,    254],
                        [    36,    258],
                        [    43,    259],
                        [    52,    260],
                        [    63,    259],
                        [    73,    258],
                        [    85,    254],
                        [    96,    249],
                        [   106,    244],
                        [   115,    237],
                        [   124,    230],
                        [   130,    221],
                        [   134,    211],
                        [   136,    199],
                        [   136,    187],
                        [   132,    173],
                        [   127,    158],
                        [   118,    142],
                        [   106,    125],
                        [    92,    108],
                        [    76,     92],
                        [    57,     76],
                        [    37,     60],
                        [    15,     45],
                        [    -9,     31],
                        [   -33,     18],
                        [   -59,      6],
                        [   -85,     -4],
                        [  -111,    -12],
                        [  -136,    -19],
                        [  -160,    -24],
                        [  -184,    -26],
                        [  -205,    -26],
                        [  -224,    -24],
                        [  -242,    -20],
                        [  -258,    -12],
                        [  -271,     -2],
                        [  -285,     11],
                        [  -297,     25],
                        [  -310,     43],
                        [  -320,     63],
                        [  -329,     84],
                        [  -336,    107],
                        [  -338,    131],
                        [  -336,    154],
                        [  -327,    176],
                        [  -312,    196],
                        [  -293,    212],
                        [  -268,    226],
                        [  -244,    238],
                        [  -219,    248],
                        [  -197,    260],
                        [  -177,    273],
                        [  -160,    289],
                        [  -145,    309],
                        [  -134,    332],
                        [  -125,    357],
                        [  -120,    383],
                        [  -117,    411],
                        [  -117,    439],
                        [  -119,    466],
                        [  -122,    493],
                        [  -127,    518],
                        [  -132,    544],
                        [  -138,    568],
                        [  -146,    591],
                        [  -155,    611],
                        [  -166,    630],
                        [  -178,    645],
                        [  -190,    657],
                        [  -204,    665],
                        [  -219,    670],
                        [  -234,    673],
                        [  -250,    672],
                        [  -268,    668],
                        [  -288,    658],
                        [  -311,    644],
                        [  -337,    625],
                        [  -367,    599],
                        [  -400,    570],
                        [  -436,    539],
                        [  -474,    505],
                        [  -512,    471],
                        [  -548,    436],
                        [  -582,    400],
                        [  -614,    362],
                        [  -643,    326],
                        [  -669,    291],
                        [  -691,    258],
                        [  -709,    230],
                        [  -721,    208],
                        [  -727,    193],
                        [  -727,    183],
                        [  -722,    179],
                        [  -711,    179],
                        [  -697,    179],
                        [  -680,    181],
                        [  -662,    183],
                        [  -644,    184],
                        [  -624,    184],
                        [  -604,    186],
                        [  -584,    187],
                        [  -564,    189],
                        [  -544,    189],
                        [  -526,    190],
                        [  -505,    192],
                        [  -485,    193],
                        [  -462,    193],
                        [  -440,    195],
                        [  -417,    196],
                        [  -394,    197],
                        [  -375,    197],
                        [  -358,    196],
                        [  -346,    195],
                        [  -337,    193],
                        [  -332,    191],
                        [  -330,    188],
                        [  -331,    184],
                        [  -335,    180],
                        [  -340,    176],
                        [  -345,    170],
                        [  -350,    163],
                        [  -356,    157],
                        [  -364,    150],
                        [  -373,    141],
                        [  -387,    132],
                        [  -403,    122],
                        [  -422,    111],
                        [  -444,    100],
                        [  -467,     88],
                        [  -492,     76],
                        [  -517,     63],
                        [  -543,     49],
                        [  -568,     35],
                        [  -592,     21],
                        [  -617,      7],
                        [  -639,     -7],
                        [  -661,    -21],
                        [  -680,    -34],
                        [  -697,    -46],
                        [  -711,    -58],
                        [  -722,    -68],
                        [  -730,    -78],
                        [  -735,    -88],
                        [  -737,    -97],
                        [  -736,   -106],
                        [  -732,   -115],
                        [  -726,   -123],
                        [  -717,   -130],
                        [  -706,   -138],
                        [  -692,   -145],
                        [  -678,   -152],
                        [  -660,   -158],
                        [  -642,   -165],
                        [  -623,   -171],
                        [  -605,   -177],
                        [  -585,   -183],
                        [  -566,   -189],
                        [  -548,   -196],
                        [  -529,   -202],
                        [  -510,   -209],
                        [  -492,   -215],
                        [  -473,   -223],
                        [  -455,   -231],
                        [  -437,   -239],
                        [  -422,   -246],
                        [  -410,   -254],
                        [  -402,   -258],
                        [  -399,   -261],
                        [  -401,   -260],
                        [  -410,   -255],
                        [  -422,   -246],
                        [  -437,   -233],
                        [  -452,   -219],
                        [  -466,   -205],
                        [  -479,   -192],
                        [  -491,   -183],
                        [  -500,   -176],
                        [  -508,   -173],
                        [  -514,   -174],
                        [  -518,   -177],
                        [  -520,   -183],
                        [  -521,   -191],
                        [  -520,   -201],
                        [  -518,   -211],
                        [  -515,   -223],
                        [  -512,   -236],
                        [  -507,   -251],
                        [  -501,   -267],
                        [  -494,   -283],
                        [  -485,   -298],
                        [  -475,   -314],
                        [  -464,   -327],
                        [  -452,   -340],
                        [  -438,   -350],
                        [  -423,   -360],
                        [  -406,   -368],
                        [  -388,   -374],
                        [  -366,   -376],
                        [  -343,   -375],
                        [  -314,   -370],
                        [  -283,   -362],
                        [  -248,   -351],
                        [  -210,   -340],
                        [  -168,   -327],
                        [  -126,   -314],
                        [   -84,   -299],
                        [   -42,   -282],
                        [    -1,   -264],
                        [    39,   -245],
                        [    77,   -225],
                        [   113,   -208],
                        [   145,   -193],
                        [   175,   -183],
                        [   198,   -177],
                        [   219,   -175],
                        [   234,   -176],
                        [   246,   -180],
                        [   255,   -184],
                        [   262,   -186],
                        [   268,   -185],
                        [   273,   -184],
                        [   275,   -182],
                        [   277,   -178],
                        [   277,   -172],
                        [   275,   -167],
                        [   273,   -159],
                        [   269,   -150],
                        [   262,   -141],
                        [   251,   -132],
                        [   237,   -123],
                        [   221,   -112],
                        [   202,   -102],
                        [   181,    -93],
                        [   161,    -83],
                        [   141,    -73],
                        [   124,    -64],
                        [   108,    -56],
                        [    93,    -49],
                        [    80,    -42],
                        [    67,    -36],
                        [    54,    -31],
                        [    41,    -28],
                        [    28,    -24],
                        [    11,    -24],
                        [    -5,    -24],
                        [   -21,    -24],
                        [   -37,    -26],
                        [   -50,    -29],
                        [   -60,    -34],
                        [   -67,    -39],
                        [   -73,    -45],
                        [   -78,    -51],
                        [   -80,    -59],
                        [   -82,    -66],
                        [   -82,    -74],
                        [   -82,    -82],
                        [   -80,    -91],
                        [   -79,   -100],
                        [   -76,   -109],
                        [   -72,   -119],
                        [   -69,   -128],
                        [   -66,   -139],
                        [   -63,   -149],
                        [   -62,   -160],
                        [   -61,   -170],
                        [   -61,   -180],
                        [   -62,   -189],
                        [   -63,   -196],
                        [   -66,   -202],
                        [   -69,   -208],
                        [   -72,   -211],
                        [   -76,   -214],
                        [   -80,   -214],
                        [   -85,   -213],
                        [   -90,   -210],
                        [   -94,   -205],
                        [   -99,   -199],
                        [  -102,   -191],
                        [  -105,   -181],
                        [  -106,   -169],
                        [  -107,   -156],
                        [  -107,   -141],
                        [  -106,   -124],
                        [  -104,   -105],
                        [  -101,    -85],
                        [   -98,    -64],
                        [   -93,    -41],
                        [   -87,    -19],
                        [   -78,      2],
                        [   -67,     24],
                        [   -51,     42],
                        [   -33,     58],
                        [    -9,     68],
                        [    18,     74],
                        [    46,     75],
                        [    73,     72],
                        [   101,     69],
                        [   127,     63],
                        [   151,     60],
                        [   173,     58],
                        [   193,     57],
                        [   211,     58],
                        [   226,     59],
                        [   238,     61],
                        [   249,     63],
                        [   256,     67],
                        [   262,     69],
                        [   267,     72],
                        [   269,     75],
                        [   270,     77],
                        [   269,     80],
                        [   266,     82],
                        [   261,     84],
                        [   254,     84],
                        [   246,     83],
                        [   236,     80],
                        [   226,     75],
                        [   215,     68],
                        [   202,     61],
                        [   188,     51],
                        [   172,     39],
                        [   154,     24],
                        [   135,      8],
                        [   114,    -10],
                        [    89,    -28],
                        [    64,    -46],
                        [    37,    -63],
                        [    10,    -78],
                        [   -18,    -94],
                        [   -46,   -111],
                        [   -72,   -128],
                        [   -98,   -145],
                        [  -121,   -159],
                        [  -142,   -171],
                        [  -162,   -180],
                        [  -177,   -183],
                        [  -189,   -180],
                        [  -198,   -172],
                        [  -204,   -161],
                        [  -207,   -145],
                        [  -209,   -131],
                        [  -210,   -116],
                        [  -210,   -102],
                        [  -208,    -89],
                        [  -206,    -76],
                        [  -202,    -64],
                        [  -197,    -54],
                        [  -192,    -46],
                        [  -185,    -39],
                        [  -177,    -33],
                        [  -167,    -28],
                        [  -154,    -24],
                        [  -138,    -23],
                        [  -119,    -22],
                        [  -101,    -24],
                        [   -80,    -27],
                        [   -61,    -31],
                        [   -44,    -37],
                        [   -29,    -43],
                        [   -17,    -51],
                        [    -7,    -61],
                        [     0,    -72],
                        [     7,    -83],
                        [    11,    -96],
                        [    15,   -111],
                        [    20,   -124],
                        [    26,   -139],
                        [    32,   -155],
                        [    36,   -171],
                        [    40,   -188],
                        [    40,   -205],
                        [    38,   -222],
                        [    34,   -239],
                        [    28,   -257],
                        [    20,   -274],
                        [    11,   -291],
                        [     2,   -309],
                        [    -9,   -325],
                        [   -20,   -342],
                        [   -31,   -358],
                        [   -44,   -373],
                        [   -57,   -388],
                        [   -70,   -401],
                        [   -82,   -414],
                        [   -93,   -424],
                        [  -103,   -433],
                        [  -111,   -440],
                        [  -115,   -446],
                        [  -119,   -451],
                        [  -121,   -453],
                        [  -121,   -457],
                        [  -119,   -458],
                        [  -115,   -459],
                        [  -109,   -459],
                        [  -102,   -458],
                        [   -93,   -457],
                        [   -82,   -455],
                        [   -71,   -453],
                        [   -58,   -451],
                        [   -44,   -448],
                        [   -30,   -445],
                        [   -15,   -443],
                        [    -1,   -440],
                        [    13,   -437],
                        [    26,   -436],
                        [    38,   -434],
                        [    49,   -433],
                        [    59,   -433],
                        [    68,   -434],
                        [    76,   -436],
                        [    82,   -437],
                        [    86,   -439],
                        [    88,   -440],
                        [    87,   -440],
                        [    82,   -436],
                        [    75,   -431],
                        [    64,   -421],
                        [    50,   -407],
                        [    36,   -392],
                        [    20,   -374],
                        [     5,   -358],
                        [   -11,   -341],
                        [   -27,   -328],
                        [   -42,   -318],
                        [   -55,   -309],
                        [   -67,   -303],
                        [   -79,   -300],
                        [   -89,   -298],
                        [   -98,   -298],
                        [  -104,   -299],
                        [  -111,   -302],
                        [  -115,   -306],
                        [  -116,   -311],
                        [  -117,   -319],
                        [  -115,   -326],
                        [  -112,   -335],
                        [  -106,   -342],
                        [  -100,   -350],
                        [   -92,   -357],
                        [   -81,   -361],
                        [   -69,   -364],
                        [   -55,   -366],
                        [   -40,   -366],
                        [   -23,   -363],
                        [    -3,   -358],
                        [    18,   -352],
                        [    41,   -345],
                        [    67,   -336],
                        [    94,   -328],
                        [   124,   -319],
                        [   156,   -310],
                        [   189,   -301],
                        [   223,   -288],
                        [   257,   -275],
                        [   290,   -261],
                        [   323,   -246],
                        [   355,   -232],
                        [   384,   -222],
                        [   412,   -215],
                        [   437,   -210],
                        [   459,   -210],
                        [   480,   -212],
                        [   499,   -215],
                        [   515,   -220],
                        [   531,   -223],
                        [   546,   -225],
                        [   558,   -227],
                        [   568,   -228],
                        [   575,   -228],
                        [   580,   -227],
                        [   582,   -225],
                        [   581,   -223],
                        [   577,   -219],
                        [   569,   -215],
                        [   556,   -211],
                        [   538,   -207],
                        [   517,   -202],
                        [   492,   -197],
                        [   466,   -193],
                        [   438,   -187],
                        [   411,   -182],
                        [   384,   -177],
                        [   359,   -172],
                        [   334,   -167],
                        [   310,   -163],
                        [   288,   -159],
                        [   265,   -156],
                        [   242,   -153],
                        [   219,   -150],
                        [   194,   -148],
                        [   170,   -147],
                        [   146,   -145],
                        [   126,   -145],
                        [   107,   -145],
                        [    91,   -144],
                        [    79,   -144],
                        [    67,   -144],
                        [    59,   -144],
                        [    54,   -144],
                        [    50,   -143],
                        [    48,   -143],
                        [    50,   -141],
                        [    53,   -140],
                        [    59,   -138],
                        [    67,   -135],
                        [    77,   -132],
                        [    89,   -129],
                        [   102,   -127],
                        [   115,   -123],
                        [   128,   -119],
                        [   140,   -116],
                        [   152,   -112],
                        [   164,   -108],
                        [   176,   -102],
                        [   186,    -97],
                        [   196,    -89],
                        [   206,    -82],
                        [   215,    -73],
                        [   222,    -64],
                        [   229,    -54],
                        [   235,    -44],
                        [   240,    -33],
                        [   244,    -21],
                        [   247,     -9],
                        [   249,      3],
                        [   251,     16],
                        [   254,     29],
                        [   257,     43],
                        [   260,     56],
                        [   265,     71],
                        [   269,     84],
                        [   275,     98],
                        [   280,    112],
                        [   286,    125],
                        [   293,    138],
                        [   301,    149],
                        [   310,    158],
                        [   319,    163],
                        [   329,    165],
                        [   341,    163],
                        [   355,    155],
                        [   370,    143],
                        [   385,    128],
                        [   401,    111],
                        [   416,     93],
                        [   431,     76],
                        [   445,     59],
                        [   459,     42],
                        [   471,     26],
                        [   483,     11],
                        [   493,     -2],
                        [   502,    -16],
                        [   510,    -28],
                        [   518,    -40],
                        [   522,    -50],
                        [   527,    -60],
                        [   529,    -67],
                        [   531,    -74],
                        [   531,    -79],
                        [   531,    -84],
                        [   529,    -88],
                        [   527,    -92],
                        [   523,    -97],
                        [   519,   -102],
                        [   514,   -106],
                        [   509,   -111],
                        [   503,   -117],
                        [   496,   -123],
                        [   489,   -127],
                        [   480,   -131],
                        [   470,   -133],
                        [   458,   -133],
                        [   444,   -132],
                        [   429,   -131],
                        [   413,   -128],
                        [   395,   -126],
                        [   376,   -124],
                        [   357,   -122],
                        [   339,   -119],
                        [   320,   -114],
                        [   302,   -106],
                        [   286,    -96],
                        [   270,    -82],
                        [   254,    -67],
                        [   239,    -48],
                        [   223,    -28],
                        [   208,     -7],
                        [   192,     11],
                        [   176,     30],
                        [   161,     47],
                        [   147,     63],
                        [   135,     77],
                        [   124,     90],
                        [   115,    102],
                        [   108,    111],
                        [   103,    117],
                        [   102,    123],
                        [   104,    126],
                        [   110,    127],
                        [   119,    126],
                        [   129,    124],
                        [   143,    119],
                        [   155,    113],
                        [   168,    106],
                        [   180,     96],
                        [   192,     85],
                        [   203,     74],
                        [   213,     61],
                        [   223,     47],
                        [   232,     33],
                        [   242,     18],
                        [   253,      3],
                        [   264,    -13],
                        [   275,    -28],
                        [   286,    -44],
                        [   296,    -59],
                        [   305,    -74],
                        [   310,    -89],
                        [   315,   -102],
                        [   319,   -116],
                        [   322,   -129],
                        [   323,   -141],
                        [   323,   -154],
                        [   323,   -164],
                        [   319,   -175],
                        [   315,   -184],
                        [   309,   -192],
                        [   301,   -198],
                        [   292,   -205],
                        [   282,   -210],
                        [   272,   -213],
                        [   262,   -215],
                        [   254,   -215],
                        [   245,   -215],
                        [   239,   -213],
                        [   232,   -210],
                        [   227,   -206],
                        [   222,   -202],
                        [   218,   -197],
                        [   215,   -192],
                        [   213,   -186],
                        [   212,   -180],
                        [   211,   -174],
                        [   212,   -167],
                        [   214,   -162],
                        [   217,   -155],
                        [   221,   -149],
                        [   226,   -143],
                        [   231,   -137],
                        [   235,   -132],
                        [   237,   -127],
                        [   240,   -122],
                        [   240,   -119],
                        [   239,   -116],
                        [   237,   -115],
                        [   233,   -115],
                        [   229,   -114],
                        [   224,   -115],
                        [   219,   -115],
                        [   212,   -115],
                        [   205,   -114],
                        [   197,   -111],
                        [   187,   -106],
                        [   176,    -98],
                        [   163,    -87],
                        [   149,    -74],
                        [   133,    -60],
                        [   118,    -45],
                        [   102,    -31],
                        [    85,    -18],
                        [    71,     -6],
                        [    55,      5],
                        [    41,     15],
                        [    28,     23],
                        [    16,     30],
                        [     7,     36],
                        [    -2,     40],
                        [   -10,     44],
                        [   -15,     46],
                        [   -18,     48],
                        [   -20,     48],
                        [   -21,     47],
                        [   -21,     46],
                        [   -20,     45],
                        [   -16,     45],
                        [   -13,     46],
                        [    -8,     48],
                        [    -2,     51],
                        [     4,     55],
                        [    11,     61],
                        [    19,     67],
                        [    27,     73],
                        [    36,     79],
                        [    46,     84],
                        [    57,     88],
                        [    71,     92],
                        [    85,     96],
                        [   102,    100],
                        [   119,    106],
                        [   137,    112],
                        [   155,    119],
                        [   173,    126],
                        [   190,    132],
                        [   206,    137],
                        [   222,    141],
                        [   236,    143],
                        [   250,    142],
                        [   264,    140],
                        [   277,    137],
                        [   290,    132],
                        [   303,    127],
                        [   315,    122],
                        [   326,    116],
                        [   335,    111],
                        [   340,    104],
                        [   344,     99],
                        [   345,     93],
                        [   342,     88],
                        [   336,     82],
                        [   327,     77],
                        [   314,     72],
                        [   298,     68],
                        [   279,     64],
                        [   256,     61],
                        [   232,     57],
                        [   206,     54],
                        [   180,     51],
                        [   154,     50],
                        [   128,     48],
                        [   102,     46],
                        [    78,     46],
                        [    54,     45],
                        [    30,     45],
                        [     6,     44],
                        [   -17,     45],
                        [   -41,     46],
                        [   -63,     46],
                        [   -85,     48],
                        [  -104,     50],
                        [  -121,     52],
                        [  -136,     54],
                        [  -149,     58],
                        [  -159,     61],
                        [  -168,     65],
                        [  -175,     70],
                        [  -179,     75],
                        [  -181,     80],
                        [  -180,     87],
                        [  -176,     93],
                        [  -168,    101],
                        [  -158,    109],
                        [  -146,    117],
                        [  -132,    125],
                        [  -117,    134],
                        [  -102,    143],
                        [   -86,    152],
                        [   -72,    162],
                        [   -56,    170],
                        [   -41,    179],
                        [   -26,    189],
                        [   -12,    197],
                        [     2,    206],
                        [    14,    215],
                        [    25,    224],
                        [    36,    233],
                        [    45,    242],
                        [    52,    250],
                        [    58,    258],
                        [    62,    265],
                        [    63,    271],
                        [    64,    278],
                        [    64,    284],
                        [    63,    288],
                        [    63,    293],
                        [    63,    297],
                        [    63,    301],
                        [    64,    303],
                        [    66,    306],
                        [    69,    308],
                        [    72,    310],
                        [    75,    311],
                        [    77,    311],
                        [    80,    310],
                        [    82,    307],
                        [    85,    301],
                        [    87,    293],
                        [    92,    282],
                        [    97,    267],
                        [   104,    250],
                        [   113,    230],
                        [   121,    209],
                        [   132,    187],
                        [   141,    165],
                        [   153,    144],
                        [   163,    124],
                        [   175,    106],
                        [   184,     89],
                        [   195,     73],
                        [   203,     59],
                        [   211,     46],
                        [   218,     36],
                        [   223,     28],
                        [   229,     22],
                        [   234,     18],
                        [   238,     15],
                        [   242,     16],
                        [   245,     17],
                        [   249,     19],
                        [   252,     21],
                        [   254,     24],
                        [   257,     26],
                        [   258,     28],
                        [   261,     32],
                        [   263,     35],
                        [   266,     40],
                        [   267,     46],
                        [   267,     54],
                        [   266,     63],
                        [   262,     74],
                        [   258,     85],
                        [   250,     95],
                        [   241,    106],
                        [   232,    115],
                        [   219,    123],
                        [   208,    132],
                        [   196,    140],
                        [   183,    148],
                        [   170,    155],
                        [   157,    164],
                        [   143,    173],
                        [   127,    182],
                        [   110,    192],
                        [    92,    202],
                        [    72,    211],
                        [    52,    220],
                        [    32,    229],
                        [    14,    237],
                        [    -3,    244],
                        [   -19,    249],
                        [   -32,    255],
                        [   -43,    259],
                        [   -53,    262],
                        [   -59,    263],
                        [   -64,    263],
                        [   -66,    262],
                        [   -65,    261],
                        [   -62,    258],
                        [   -56,    254],
                        [   -50,    249],
                        [   -41,    243],
                        [   -33,    236],
                        [   -24,    228],
                        [   -14,    220],
                        [    -4,    212],
                        [     7,    203],
                        [    19,    194],
                        [    30,    185],
                        [    43,    176],
                        [    57,    167],
                        [    71,    158],
                        [    84,    150],
                        [    98,    142],
                        [   110,    134],
                        [   121,    128],
                        [   132,    121],
                        [   141,    115],
                        [   150,    110],
                        [   158,    105],
                        [   165,    100],
                        [   171,     96],
                        [   174,     93],
                        [   174,     90],
                        [   172,     88],
                        [   167,     86],
                        [   162,     85],
                        [   153,     84],
                        [   145,     83],
                        [   137,     83],
                        [   128,     83],
                        [   119,     84],
                        [   110,     85],
                        [   101,     85],
                        [    92,     87],
                        [    83,     88],
                        [    75,     89],
                        [    67,     91],
                        [    59,     93],
                        [    52,     94],
                        [    46,     96],
                        [    40,     98],
                        [    37,     99],
                        [    35,    100],
                        [    33,    102],
                        [    34,    103],
                        [    35,    104],
                        [    36,    106],
                        [    36,    106],
                        [    35,    107],
                        [    33,    108],
                        [    28,    107],
                        [    24,    107],
                        [    18,    106],
                        [    12,    104],
                        [     5,    102],
                        [    -1,    102],
                        [    -7,    100],
                        [   -14,     99],
                        [   -19,     99],
                        [   -25,    101],
                        [   -33,    105],
                        [   -41,    111],
                        [   -50,    121],
                        [   -60,    132],
                        [   -72,    145],
                        [   -84,    159],
                        [   -97,    174],
                        [  -110,    188],
                        [  -124,    202],
                        [  -136,    214],
                        [  -148,    225],
                        [  -158,    235],
                        [  -168,    245],
                        [  -176,    253],
                        [  -183,    260],
                        [  -189,    266],
                        [  -193,    270],
                        [  -197,    272],
                        [  -202,    274],
                        [  -206,    274],
                        [  -209,    273],
                        [  -212,    273],
                        [  -215,    273],
                        [  -219,    274],
                        [  -221,    275],
                        [  -225,    277],
                        [  -229,    279],
                        [  -233,    280],
                        [  -238,    280],
                        [  -242,    280],
                        [  -246,    280],
                        [  -249,    278],
                        [  -249,    275],
                        [  -249,    272],
                        [  -249,    268],
                        [  -246,    266],
                        [  -243,    264],
                        [  -240,    262],
                        [  -236,    261],
                        [  -232,    259],
                        [  -229,    258],
                        [  -226,    257],
                        [  -223,    255],
                        [  -218,    252],
                        [  -213,    248],
                        [  -206,    243],
                        [  -199,    236],
                        [  -191,    229],
                        [  -181,    221],
                        [  -174,    212],
                        [  -167,    203],
                        [  -161,    193],
                        [  -158,    183],
                        [  -155,    172],
                        [  -154,    162],
                        [  -156,    151],
                        [  -158,    141],
                        [  -163,    132],
                        [  -168,    122],
                        [  -176,    113],
                        [  -186,    104],
                        [  -197,     97],
                        [  -210,     89],
                        [  -223,     83],
                        [  -236,     77],
                        [  -251,     72],
                        [  -265,     67],
                        [  -280,     64],
                        [  -294,     61],
                        [  -309,     59],
                        [  -323,     57],
                        [  -337,     56],
                        [  -352,     56],
                        [  -365,     57],
                        [  -379,     58],
                        [  -390,     59],
                        [  -401,     62],
                        [  -411,     65],
                        [  -420,     68],
                        [  -427,     72],
                        [  -433,     77],
                        [  -438,     82],
                        [  -441,     88],
                        [  -442,     94],
                        [  -440,    101],
                        [  -437,    108],
                        [  -430,    115],
                        [  -421,    123],
                        [  -410,    131],
                        [  -397,    140],
                        [  -384,    149],
                        [  -371,    158],
                        [  -357,    167],
                        [  -343,    176],
                        [  -329,    185],
                        [  -315,    194],
                        [  -301,    202],
                        [  -288,    210],
                        [  -275,    218],
                        [  -264,    224],
                        [  -253,    231],
                        [  -243,    236],
                        [  -235,    241],
                        [  -228,    245],
                        [  -223,    247],
                        [  -221,    249],
                        [  -221,    249],
                        [  -222,    249],
                        [  -224,    246],
                        [  -228,    243],
                        [  -230,    240],
                        [  -232,    235],
                        [  -234,    229],
                        [  -235,    223],
                        [  -235,    216],
                        [  -234,    209],
                        [  -232,    202],
                        [  -231,    194],
                        [  -229,    185],
                        [  -228,    177],
                        [  -228,    167],
                        [  -227,    158],
                        [  -226,    146],
                        [  -224,    133],
                        [  -222,    119],
                        [  -217,    102],
                        [  -211,     82],
                        [  -204,     62],
                        [  -195,     41],
                        [  -185,     20],
                        [  -175,     -1],
                        [  -163,    -20],
                        [  -152,    -37],
                        [  -141,    -52],
                        [  -130,    -65],
                        [  -121,    -77],
                        [  -113,    -87],
                        [  -105,    -94],
                        [   -98,   -100],
                        [   -91,   -103],
                        [   -84,   -104],
                        [   -77,   -102],
                        [   -69,    -98],
                        [   -62,    -92],
                        [   -54,    -85],
                        [   -46,    -79],
                        [   -38,    -72],
                        [   -30,    -65],
                        [   -22,    -59],
                        [   -12,    -50],
                        [    -3,    -43],
                        [     7,    -34],
                        [    15,    -24],
                        [    24,    -15],
                        [    30,     -4],
                        [    36,      7],
                        [    39,     18],
                        [    41,     28],
                        [    41,     37],
                        [    41,     46],
                        [    39,     53],
                        [    36,     59],
                        [    33,     64],
                        [    28,     67],
                        [    24,     69],
                        [    20,     70],
                        [    13,     71],
                        [     4,     72],
                        [    -6,     73],
                        [   -18,     74],
                        [   -33,     76],
                        [   -47,     77],
                        [   -63,     78],
                        [   -76,     80],
                        [   -89,     80],
                        [  -101,     81],
                        [  -111,     82],
                        [  -121,     82],
                        [  -130,     82],
                        [  -137,     81],
                        [  -144,     80],
                        [  -149,     79],
                        [  -152,     77],
                        [  -153,     75],
                        [  -152,     72],
                        [  -150,     70],
                        [  -145,     67],
                        [  -140,     63],
                        [  -133,     60],
                        [  -125,     57],
                        [  -116,     53],
                        [  -106,     50],
                        [   -96,     46],
                        [   -85,     43],
                        [   -73,     40],
                        [   -61,     37],
                        [   -47,     35],
                        [   -34,     33],
                        [   -21,     31],
                        [    -9,     29],
                        [     4,     28],
                        [    15,     27],
                        [    28,     26],
                        [    38,     26],
                        [    49,     26],
                        [    58,     27],
                        [    64,     27],
                        [    70,     27],
                        [    72,     28],
                        [    73,     28],
                        [    72,     28],
                        [    68,     28],
                        [    63,     28],
                        [    57,     28],
                        [    50,     27],
                        [    43,     24],
                        [    35,     22],
                        [    27,     20],
                        [    18,     17],
                        [     9,     14],
                        [     0,     11],
                        [    -8,      7],
                        [   -17,      5],
                        [   -26,      2],
                        [   -34,     -1],
                        [   -41,     -4],
                        [   -47,     -7],
                        [   -51,     -9],
                        [   -54,    -11],
                        [   -54,    -13],
                        [   -54,    -15],
                        [   -53,    -15],
                        [   -51,    -15],
                        [   -50,    -15],
                        [   -49,    -14],
                        [   -48,    -12],
                        [   -49,    -11],
                        [   -50,    -10],
                        [   -53,     -8],
                        [   -55,     -7],
                        [   -59,     -4],
                        [   -61,     -2],
                        [   -63,     -1],
                        [   -65,      2],
                        [   -66,      4],
                        [   -67,      7],
                        [   -68,     11],
                        [   -71,     17],
                        [   -73,     25],
                        [   -78,     36],
                        [   -84,     49],
                        [   -89,     62],
                        [   -97,     76],
                        [  -104,     91],
                        [  -112,    105],
                        [  -119,    117],
                        [  -127,    128],
                        [  -133,    139],
                        [  -138,    150],
                        [  -142,    158],
                        [  -145,    166],
                        [  -147,    172],
                        [  -149,    177],
                        [  -152,    180],
                        [  -154,    180],
                        [  -158,    180],
                        [  -162,    178],
                        [  -167,    176],
                        [  -171,    173],
                        [  -177,    171],
                        [  -183,    168],
                        [  -191,    166],
                        [  -199,    163],
                        [  -207,    159],
                        [  -217,    155],
                        [  -228,    150],
                        [  -236,    145],
                        [  -245,    139],
                        [  -254,    133],
                        [  -261,    127],
                        [  -267,    119],
                        [  -272,    113],
                        [  -277,    106],
                        [  -282,    101],
                        [  -286,     95],
                        [  -290,     91],
                        [  -294,     88],
                        [  -297,     85],
                        [  -301,     82],
                        [  -302,     80],
                        [  -303,     76],
                        [  -301,     72],
                        [  -298,     66],
                        [  -293,     59],
                        [  -287,     53],
                        [  -280,     46],
                        [  -274,     37],
                        [  -267,     29],
                        [  -262,     21],
                        [  -258,     12],
                        [  -252,      3],
                        [  -248,     -6],
                        [  -243,    -15],
                        [  -239,    -23],
                        [  -235,    -30],
                        [  -232,    -37],
                        [  -229,    -45],
                        [  -228,    -51],
                        [  -228,    -57],
                        [  -229,    -62],
                        [  -231,    -67],
                        [  -233,    -71],
                        [  -236,    -75],
                        [  -240,    -77],
                        [  -243,    -80],
                        [  -247,    -81],
                        [  -251,    -83],
                        [  -255,    -84],
                        [  -259,    -84],
                        [  -263,    -84],
                        [  -267,    -84],
                        [  -271,    -83],
                        [  -275,    -81],
                        [  -278,    -80],
                        [  -281,    -78],
                        [  -284,    -76],
                        [  -286,    -75],
                        [  -287,    -72],
                        [  -288,    -70],
                        [  -287,    -67],
                        [  -284,    -65],
                        [  -280,    -63],
                        [  -275,    -60],
                        [  -268,    -57],
                        [  -259,    -54],
                        [  -250,    -51],
                        [  -241,    -47],
                        [  -231,    -43],
                        [  -220,    -38],
                        [  -210,    -33],
                        [  -199,    -28],
                        [  -189,    -23],
                        [  -179,    -18],
                        [  -169,    -14],
                        [  -159,    -11],
                        [  -150,     -7],
                        [  -142,     -6],
                        [  -135,     -4],
                        [  -129,     -3],
                        [  -124,     -3],
                        [  -121,     -5],
                        [  -120,     -7],
                        [  -121,    -10],
                        [  -123,    -14],
                        [  -127,    -20],
                        [  -131,    -26],
                        [  -135,    -33],
                        [  -139,    -41],
                        [  -142,    -51],
                        [  -145,    -61],
                        [  -146,    -71],
                        [  -147,    -81],
                        [  -148,    -92],
                        [  -147,   -102],
                        [  -147,   -113],
                        [  -147,   -123],
                        [  -147,   -132],
                        [  -147,   -141],
                        [  -147,   -150],
                        [  -147,   -158],
                        [  -145,   -168],
                        [  -142,   -180],
                        [  -138,   -192],
                        [  -132,   -205],
                        [  -126,   -219],
                        [  -119,   -234],
                        [  -110,   -248],
                        [  -101,   -260],
                        [   -91,   -270],
                        [   -82,   -279],
                        [   -74,   -285],
                        [   -66,   -292],
                        [   -60,   -296],
                        [   -54,   -300],
                        [   -50,   -301],
                        [   -44,   -301],
                        [   -38,   -299],
                        [   -32,   -295],
                        [   -25,   -288],
                        [   -18,   -280],
                        [   -11,   -271],
                        [    -2,   -262],
                        [     6,   -254],
                        [    15,   -245],
                        [    24,   -236],
                        [    35,   -228],
                        [    46,   -219],
                        [    57,   -210],
                        [    68,   -202],
                        [    78,   -193],
                        [    88,   -185],
                        [    97,   -177],
                        [   104,   -170],
                        [   111,   -163],
                        [   117,   -158],
                        [   122,   -153],
                        [   126,   -149],
                        [   130,   -145],
                        [   132,   -145],
                        [   135,   -146],
                        [   138,   -149],
                        [   141,   -151],
                        [   141,   -154],
                        [   141,   -158],
                        [   138,   -160],
                        [   133,   -163],
                        [   128,   -165],
                        [   120,   -167],
                        [   111,   -168],
                        [   103,   -169],
                        [    96,   -170],
                        [    89,   -170],
                        [    81,   -171],
                        [    75,   -171],
                        [    67,   -170],
                        [    60,   -170],
                        [    54,   -169],
                        [    48,   -168],
                        [    42,   -167],
                        [    38,   -167],
                        [    36,   -166],
                        [    34,   -165],
                        [    34,   -164],
                        [    35,   -163],
                        [    37,   -162],
                        [    40,   -160],
                        [    45,   -158],
                        [    50,   -157],
                        [    55,   -154],
                        [    61,   -153],
                        [    67,   -150],
                        [    74,   -148],
                        [    81,   -145],
                        [    89,   -142],
                        [    97,   -139],
                        [   105,   -137],
                        [   112,   -133],
                        [   120,   -130],
                        [   128,   -126],
                        [   133,   -123],
                        [   140,   -119],
                        [   145,   -115],
                        [   150,   -112],
                        [   154,   -108],
                        [   156,   -105],
                        [   156,   -102],
                        [   155,    -99],
                        [   154,    -98],
                        [   150,    -96],
                        [   146,    -96],
                        [   142,    -96],
                        [   137,    -98],
                        [   131,   -101],
                        [   124,   -104],
                        [   117,   -108],
                        [   110,   -112],
                        [   102,   -117],
                        [    95,   -121],
                        [    89,   -125],
                        [    81,   -129],
                        [    75,   -132],
                        [    69,   -136],
                        [    64,   -139],
                        [    60,   -141],
                        [    59,   -143],
                        [    58,   -145],
                        [    59,   -145],
                        [    60,   -144],
                        [    63,   -142],
                        [    65,   -140],
                        [    68,   -136],
                        [    71,   -131],
                        [    73,   -126],
                        [    75,   -120],
                        [    76,   -114],
                        [    76,   -107],
                        [    77,   -100],
                        [    78,    -93],
                        [    79,    -85],
                        [    80,    -79],
                        [    83,    -72],
                        [    85,    -66],
                        [    87,    -59],
                        [    88,    -52],
                        [    89,    -43],
                        [    89,    -33],
                        [    88,    -20],
                        [    85,     -7],
                        [    82,      7],
                        [    78,     20],
                        [    73,     33],
                        [    69,     43],
                        [    66,     53],
                        [    63,     62],
                        [    60,     70],
                        [    59,     77],
                        [    59,     84],
                        [    57,     89],
                        [    57,     93],
                        [    55,     96],
                        [    53,     95],
                        [    50,     93],
                        [    46,     89],
                        [    41,     85],
                        [    37,     79],
                        [    30,     73],
                        [    24,     67],
                        [    15,     61],
                        [     7,     54],
                        [    -3,     47],
                        [   -14,     41],
                        [   -24,     34],
                        [   -35,     28],
                        [   -46,     20],
                        [   -55,     13],
                        [   -65,      7],
                        [   -74,     -1],
                        [   -83,     -7],
                        [   -91,    -14],
                        [   -98,    -19],
                        [  -105,    -24],
                        [  -112,    -27],
                        [  -119,    -29],
                        [  -125,    -31],
                        [  -132,    -32],
                        [  -137,    -33],
                        [  -140,    -33],
                        [  -141,    -36],
                        [  -142,    -37],
                        [  -140,    -40],
                        [  -137,    -43],
                        [  -132,    -46],
                        [  -127,    -50],
                        [  -122,    -54],
                        [  -115,    -58],
                        [  -109,    -62],
                        [  -101,    -65],
                        [   -93,    -70],
                        [   -84,    -74],
                        [   -74,    -77],
                        [   -64,    -81],
                        [   -55,    -85],
                        [   -46,    -88],
                        [   -37,    -90],
                        [   -28,    -93],
                        [   -21,    -95],
                        [   -15,    -97],
                        [    -9,    -98],
                        [    -3,   -100],
                        [     1,   -102],
                        [     5,   -102],
                        [     9,   -102],
                        [    12,   -102],
                        [    15,   -103],
                        [    17,   -103],
                        [    20,   -103],
                        [    20,   -103],
                        [    22,   -103],
                        [    23,   -102],
                        [    24,   -102],
                        [    24,   -102],
                        [    24,   -102],
                        [    24,   -102],
                        [    24,   -102],
                        [    25,   -102],
                        [    25,   -103],
                        [    26,   -103],
                        [    27,   -104],
                        [    28,   -105],
                        [    31,   -105],
                        [    34,   -105],
                        [    37,   -105],
                        [    40,   -104],
                        [    44,   -102],
                        [    47,   -100],
                        [    51,    -97],
                        [    56,    -93],
                        [    59,    -89],
                        [    64,    -85],
                        [    68,    -82],
                        [    72,    -79],
                        [    76,    -76],
                        [    79,    -74],
                        [    82,    -72],
                        [    85,    -71],
                        [    86,    -71],
                        [    87,    -71],
                        [    86,    -72],
                        [    85,    -73],
                        [    82,    -76],
                        [    78,    -80],
                        [    74,    -84],
                        [    70,    -89],
                        [    66,    -96],
                        [    62,   -103],
                        [    59,   -111],
                        [    55,   -119],
                        [    53,   -128],
                        [    50,   -137],
                        [    49,   -145],
                        [    47,   -154],
                        [    46,   -161],
                        [    44,   -168],
                        [    41,   -174],
                        [    40,   -180],
                        [    38,   -184],
                        [    37,   -190],
                        [    37,   -197],
                        [    37,   -203],
                        [    39,   -211],
                        [    41,   -219],
                        [    45,   -228],
                        [    49,   -236],
                        [    54,   -241],
                        [    59,   -246],
                        [    62,   -250],
                        [    66,   -253],
                        [    68,   -254],
                        [    70,   -256],
                        [    72,   -256],
                        [    72,   -256],
                        [    74,   -255],
                        [    76,   -252],
                        [    77,   -247],
                        [    80,   -240],
                        [    83,   -232],
                        [    86,   -223],
                        [    91,   -213],
                        [    95,   -204],
                        [   100,   -194],
                        [   106,   -185],
                        [   112,   -176],
                        [   119,   -167],
                        [   127,   -159],
                        [   135,   -151],
                        [   142,   -145],
                        [   150,   -138],
                        [   157,   -132],
                        [   164,   -128],
                        [   171,   -123],
                        [   176,   -119],
                        [   181,   -116],
                        [   186,   -114],
                        [   191,   -113],
                        [   196,   -114],
                        [   201,   -116],
                        [   206,   -119],
                        [   210,   -123],
                        [   214,   -127],
                        [   218,   -130],
                        [   220,   -133],
                        [   221,   -137],
                        [   221,   -139],
                        [   220,   -141],
                        [   218,   -143],
                        [   215,   -145],
                        [   212,   -145],
                        [   208,   -145],
                        [   203,   -145],
                        [   197,   -145],
                        [   192,   -144],
                        [   185,   -143],
                        [   178,   -141],
                        [   171,   -139],
                        [   163,   -137],
                        [   157,   -134],
                        [   150,   -132],
                        [   144,   -129],
                        [   138,   -126],
                        [   133,   -122],
                        [   129,   -119],
                        [   126,   -115],
                        [   124,   -111],
                        [   121,   -106],
                        [   119,   -102],
                        [   118,    -98],
                        [   117,    -93],
                        [   116,    -89],
                        [   116,    -85],
                        [   116,    -80],
                        [   117,    -76],
                        [   117,    -72],
                        [   118,    -67],
                        [   118,    -63],
                        [   119,    -58],
                        [   119,    -53],
                        [   119,    -49],
                        [   119,    -45],
                        [   119,    -41],
                        [   119,    -37],
                        [   119,    -33],
                        [   119,    -28],
                        [   118,    -26],
                        [   116,    -23],
                        [   115,    -20],
                        [   111,    -20],
                        [   109,    -20],
                        [   106,    -22],
                        [   102,    -24],
                        [    98,    -28],
                        [    94,    -32],
                        [    90,    -36],
                        [    86,    -41],
                        [    83,    -45],
                        [    79,    -49],
                        [    75,    -52],
                        [    72,    -55],
                        [    68,    -59],
                        [    66,    -61],
                        [    64,    -63],
                        [    63,    -64],
                        [    63,    -64],
                        [    63,    -63],
                        [    63,    -62],
                        [    65,    -59],
                        [    67,    -55],
                        [    70,    -50],
                        [    73,    -44],
                        [    76,    -37],
                        [    79,    -28],
                        [    81,    -20],
                        [    84,    -12],
                        [    86,     -2],
                        [    89,      7],
                        [    93,     16],
                        [    96,     25],
                        [   100,     33],
                        [   104,     42],
                        [   108,     50],
                        [   112,     59],
                        [   115,     67],
                        [   119,     77],
                        [   120,     88],
                        [   121,     98],
                        [   121,    110],
                        [   122,    120],
                        [   121,    130],
                        [   120,    138],
                        [   119,    145],
                        [   119,    151],
                        [   119,    157],
                        [   120,    163],
                        [   122,    167],
                        [   124,    171],
                        [   124,    174],
                        [   125,    176],
                        [   125,    175],
                        [   124,    172],
                        [   123,    167],
                        [   120,    162],
                        [   117,    154],
                        [   114,    147],
                        [   110,    139],
                        [   104,    131],
                        [    98,    123],
                        [    92,    115],
                        [    85,    106],
                        [    76,     99],
                        [    69,     92],
                        [    60,     84],
                        [    52,     77],
                        [    44,     71],
                        [    35,     64],
                        [    28,     59],
                        [    20,     54],
                        [    13,     49],
                        [     7,     46],
                        [     0,     44],
                        [    -7,     43],
                        [   -13,     43],
                        [   -20,     43],
                        [   -26,     45],
                        [   -33,     46],
                        [   -37,     46],
                        [   -41,     47],
                        [   -45,     47],
                        [   -46,     48],
                        [   -46,     49],
                        [   -46,     50],
                        [   -44,     50],
                        [   -41,     50],
                        [   -37,     50],
                        [   -32,     50],
                        [   -26,     49],
                        [   -19,     49],
                        [   -11,     49],
                        [    -2,     48],
                        [     7,     48],
                        [    15,     48],
                        [    24,     48],
                        [    33,     48],
                        [    41,     48],
                        [    49,     47],
                        [    56,     47],
                        [    63,     47],
                        [    70,     47],
                        [    76,     46],
                        [    82,     46],
                        [    87,     46],
                        [    91,     46],
                        [    95,     46],
                        [    98,     46],
                        [   101,     45],
                        [   103,     45],
                        [   106,     44],
                        [   107,     43],
                        [   110,     41],
                        [   111,     41],
                        [   113,     39],
                        [   114,     37],
                        [   114,     35],
                        [   114,     33],
                        [   114,     30],
                        [   113,     28],
                        [   113,     25],
                        [   112,     23],
                        [   112,     20],
                        [   112,     19],
                        [   112,     17],
                        [   112,     17],
                        [   112,     18],
                        [   112,     20],
                        [   112,     21],
                        [   112,     24],
                        [   112,     26],
                        [   112,     28],
                        [   112,     31],
                        [   112,     33],
                        [   112,     35],
                        [   112,     37],
                        [   112,     38],
                        [   112,     39],
                        [   111,     40],
                        [   111,     40],
                        [   111,     40],
                        [   109,     38],
                        [   106,     37],
                        [   105,     33],
                        [   102,     30],
                        [   100,     25],
                        [    98,     20],
                        [    94,     14],
                        [    91,      8],
                        [    89,      2],
                        [    85,     -6],
                        [    83,    -12],
                        [    80,    -20],
                        [    76,    -25],
                        [    72,    -31],
                        [    68,    -37],
                        [    65,    -41],
                        [    60,    -46],
                        [    57,    -49],
                        [    53,    -53],
                        [    50,    -58],
                        [    46,    -63],
                        [    45,    -67],
                        [    42,    -72],
                        [    41,    -76],
                        [    40,    -80],
                        [    39,    -82],
                        [    37,    -84],
                        [    36,    -85],
                        [    33,    -85],
                        [    30,    -86],
                        [    27,    -87],
                        [    23,    -88],
                        [    19,    -88],
                        [    15,    -87],
                        [    11,    -85],
                        [     9,    -80],
                        [     6,    -76],
                        [     4,    -69],
                        [     2,    -63],
                        [     2,    -55],
                        [     1,    -49],
                        [     2,    -41],
                        [     2,    -34],
                        [     4,    -27],
                        [     7,    -20],
                        [    10,    -15],
                        [    13,     -9],
                        [    17,     -4],
                        [    22,      1],
                        [    27,      5],
                        [    31,      8],
                        [    35,     11],
                        [    39,     13],
                        [    43,     15],
                        [    47,     15],
                        [    51,     15],
                        [    55,     13],
                        [    60,     11],
                        [    65,      8],
                        [    71,      5],
                        [    76,      2],
                        [    80,     -1],
                        [    85,     -4],
                        [    89,     -7],
                        [    91,     -9],
                        [    93,    -11],
                        [    94,    -13],
                        [    94,    -14],
                        [    93,    -15],
                        [    91,    -16],
                        [    89,    -16],
                        [    85,    -16],
                        [    80,    -16],
                        [    74,    -15],
                        [    67,    -15],
                        [    62,    -14],
                        [    55,    -13],
                        [    49,    -11],
                        [    42,    -10],
                        [    35,     -7],
                        [    28,     -5],
                        [    22,     -2],
                        [    16,      0],
                        [    10,      2],
                        [     5,      6],
                        [     0,      8],
                        [    -4,     11],
                        [    -8,     15],
                        [   -12,     18],
                        [   -15,     21],
                        [   -19,     24],
                        [   -22,     27],
                        [   -25,     30],
                        [   -28,     33],
                        [   -32,     37],
                        [   -35,     40],
                        [   -37,     43],
                        [   -40,     46],
                        [   -43,     50],
                        [   -45,     53],
                        [   -47,     56],
                        [   -49,     59],
                        [   -50,     63],
                        [   -52,     66],
                        [   -54,     68],
                        [   -55,     70],
                        [   -57,     72],
                        [   -59,     72],
                        [   -61,     72],
                        [   -62,     71],
                        [   -64,     69],
                        [   -65,     67],
                        [   -67,     65],
                        [   -68,     63],
                        [   -69,     60],
                        [   -71,     58],
                        [   -72,     55],
                        [   -73,     54],
                        [   -75,     52],
                        [   -76,     51],
                        [   -76,     50],
                        [   -78,     50],
                        [   -79,     49],
                        [   -79,     50],
                        [   -79,     51],
                        [   -79,     54],
                        [   -78,     57],
                        [   -76,     61],
                        [   -75,     65],
                        [   -72,     71],
                        [   -70,     77],
                        [   -67,     84],
                        [   -64,     90],
                        [   -61,     98],
                        [   -58,    104],
                        [   -54,    111],
                        [   -50,    118],
                        [   -46,    124],
                        [   -41,    129],
                        [   -36,    135],
                        [   -32,    140],
                        [   -27,    144],
                        [   -23,    149],
                        [   -19,    154],
                        [   -15,    158],
                        [   -12,    163],
                        [   -10,    168],
                        [    -7,    171],
                        [    -5,    175],
                        [    -3,    176],
                        [     0,    179],
                        [     2,    180],
                        [     7,    182],
                        [    10,    184],
                        [    14,    184],
                        [    18,    185],
                        [    21,    185],
                        [    24,    184],
                        [    27,    181],
                        [    29,    178],
                        [    32,    173],
                        [    33,    167],
                        [    33,    161],
                        [    33,    155],
                        [    33,    148],
                        [    32,    140],
                        [    29,    132],
                        [    27,    124],
                        [    23,    117],
                        [    18,    110],
                        [    13,    103],
                        [     7,     97],
                        [     2,     90],
                        [    -4,     85],
                        [   -10,     79],
                        [   -15,     74],
                        [   -20,     71],
                        [   -24,     67],
                        [   -29,     66],
                        [   -34,     65],
                        [   -40,     64],
                        [   -46,     64],
                        [   -51,     65],
                        [   -58,     66],
                        [   -63,     67],
                        [   -68,     68],
                        [   -72,     70],
                        [   -76,     72],
                        [   -79,     73],
                        [   -80,     75],
                        [   -80,     76],
                        [   -80,     78],
                        [   -79,     80],
                        [   -76,     81],
                        [   -72,     83],
                        [   -67,     85],
                        [   -63,     86],
                        [   -57,     87],
                        [   -51,     89],
                        [   -46,     89],
                        [   -40,     90],
                        [   -33,     91],
                        [   -27,     92],
                        [   -20,     91],
                        [   -13,     92],
                        [    -7,     92],
                        [    -2,     91],
                        [     4,     92],
                        [     9,     91],
                        [    12,     90],
                        [    16,     89],
                        [    19,     89],
                        [    22,     88],
                        [    24,     86],
                        [    27,     85],
                        [    30,     83],
                        [    33,     81],
                        [    35,     80],
                        [    37,     77],
                        [    40,     75],
                        [    41,     72],
                        [    43,     70],
                        [    44,     67],
                        [    45,     64],
                        [    45,     61],
                        [    45,     58],
                        [    45,     55],
                        [    45,     52],
                        [    46,     50],
                        [    46,     48],
                        [    46,     47],
                        [    46,     46],
                        [    45,     46],
                        [    44,     46],
                        [    43,     46],
                        [    42,     48],
                        [    42,     49],
                        [    41,     50],
                        [    41,     51],
                        [    42,     54],
                        [    41,     54],
                        [    42,     56],
                        [    42,     58],
                        [    43,     59],
                        [    44,     60],
                        [    46,     60],
                        [    46,     61],
                        [    47,     61],
                        [    47,     61],
                        [    47,     60],
                        [    46,     59],
                        [    46,     57],
                        [    45,     55],
                        [    43,     53],
                        [    41,     50],
                        [    39,     46],
                        [    36,     43],
                        [    33,     39],
                        [    30,     37],
                        [    26,     33],
                        [    22,     30],
                        [    18,     28],
                        [    14,     26],
                        [     9,     24],
                        [     5,     23],
                        [     0,     21],
                        [    -4,     20],
                        [    -8,     17],
                        [   -12,     15],
                        [   -15,     13],
                        [   -20,     11],
                        [   -24,      8],
                        [   -27,      7],
                        [   -31,      4],
                        [   -36,      2],
                        [   -40,     -1],
                        [   -46,     -3],
                        [   -52,     -7],
                        [   -58,    -10],
                        [   -64,    -12],
                        [   -70,    -14],
                        [   -75,    -15],
                        [   -80,    -15],
                        [   -85,    -15],
                        [   -89,    -14],
                        [   -93,    -12],
                        [   -97,    -10],
                        [  -100,     -7],
                        [  -102,     -4],
                        [  -102,     -1],
                        [  -103,      2],
                        [  -102,      6],
                        [  -102,     10],
                        [   -98,     13],
                        [   -96,     16],
                        [   -93,     20],
                        [   -89,     23],
                        [   -86,     25],
                        [   -83,     28],
                        [   -80,     30],
                        [   -77,     31],
                        [   -74,     33],
                        [   -71,     33],
                        [   -67,     33],
                        [   -63,     33],
                        [   -59,     32],
                        [   -54,     31],
                        [   -49,     30],
                        [   -45,     29],
                        [   -40,     28],
                        [   -36,     28],
                        [   -33,     27],
                        [   -31,     25],
                        [   -30,     25],
                        [   -30,     24],
                        [   -30,     24],
                        [   -32,     24],
                        [   -34,     23],
                        [   -37,     23],
                        [   -40,     23],
                        [   -44,     23],
                        [   -47,     24],
                        [   -50,     24],
                        [   -54,     24],
                        [   -59,     25],
                        [   -63,     26],
                        [   -68,     27],
                        [   -74,     28],
                        [   -79,     29],
                        [   -84,     30],
                        [   -88,     32],
                        [   -91,     33],
                        [   -94,     33],
                        [   -98,     35],
                        [  -101,     36],
                        [  -103,     37],
                        [  -106,     38],
                        [  -108,     39],
                        [  -111,     39],
                        [  -115,     41],
                        [  -118,     41],
                        [  -121,     42],
                        [  -124,     44],
                        [  -128,     45],
                        [  -130,     46],
                        [  -132,     46],
                        [  -133,     48],
                        [  -134,     49],
                        [  -136,     50],
                        [  -137,     50],
                        [  -138,     51],
                        [  -140,     52],
                        [  -140,     52],
                        [  -141,     51],
                        [  -141,     51],
                        [  -141,     50],
                        [  -140,     49],
                        [  -140,     47],
                        [  -139,     46],
                        [  -138,     44],
                        [  -138,     42],
                        [  -138,     40],
                        [  -137,     38],
                        [  -137,     37],
                        [  -137,     35],
                        [  -137,     33],
                        [  -138,     32],
                        [  -138,     30],
                        [  -139,     29],
                        [  -140,     28],
                        [  -141,     28],
                        [  -140,     28],
                        [  -140,     28],
                        [  -139,     28],
                        [  -137,     28],
                        [  -137,     30],
                        [  -134,     31],
                        [  -132,     33],
                        [  -128,     35],
                        [  -125,     37],
                        [  -121,     40],
                        [  -118,     42],
                        [  -113,     44],
                        [  -109,     46],
                        [  -104,     47],
                        [  -100,     48],
                        [   -95,     49],
                        [   -90,     50],
                        [   -85,     50],
                        [   -80,     50],
                        [   -76,     50],
                        [   -72,     51],
                        [   -68,     52],
                        [   -64,     53],
                        [   -60,     54],
                        [   -57,     54],
                        [   -53,     55],
                        [   -49,     57],
                        [   -45,     59],
                        [   -41,     60],
                        [   -36,     62],
                        [   -31,     63],
                        [   -26,     64],
                        [   -21,     65],
                        [   -16,     65],
                        [   -11,     65],
                        [    -7,     64],
                        [    -3,     62],
                        [     1,     59],
                        [     4,     56],
                        [     7,     53],
                        [     9,     49],
                        [    11,     44],
                        [    11,     39],
                        [    11,     34],
                        [    10,     29],
                        [     7,     24],
                        [     6,     20],
                        [     3,     15],
                        [     1,     10],
                        [    -2,      6],
                        [    -4,      2],
                        [    -5,     -2],
                        [    -7,     -5],
                        [    -9,     -7],
                        [   -10,     -9],
                        [   -11,    -11],
                        [   -14,    -11],
                        [   -16,    -12],
                        [   -19,    -12],
                        [   -22,    -12],
                        [   -24,    -11],
                        [   -27,    -11],
                        [   -29,    -10],
                        [   -30,     -9],
                        [   -31,     -7],
                        [   -31,     -7],
                        [   -30,     -5],
                        [   -28,     -3],
                        [   -26,     -2],
                        [   -23,     -1],
                        [   -20,      1],
                        [   -17,      2],
                        [   -14,      3],
                        [   -11,      4],
                        [    -7,      5],
                        [    -4,      6],
                        [    -1,      7],
                        [     3,      7],
                        [     7,      7],
                        [    11,      7],
                        [    16,      7],
                        [    20,      6],
                        [    23,      6],
                        [    25,      5],
                        [    28,      4],
                        [    29,      4],
                        [    32,      3],
                        [    33,      2],
                        [    35,      2],
                        [    37,      1],
                        [    38,      0],
                        [    41,     -2],
                        [    43,     -2],
                        [    46,     -3],
                        [    47,     -5],
                        [    50,     -6],
                        [    51,     -7],
                        [    53,     -8],
                        [    54,    -10],
                        [    54,    -11],
                        [    55,    -13],
                        [    56,    -14],
                        [    58,    -15],
                        [    58,    -15],
                        [    59,    -16],
                        [    59,    -17],
                        [    59,    -16],
                        [    59,    -17],
                        [    57,    -16],
                        [    57,    -15],
                        [    56,    -15],
                        [    56,    -14],
                        [    56,    -12],
                        [    56,    -11],
                        [    56,    -10],
                        [    57,     -8],
                        [    58,     -7],
                        [    59,     -5],
                        [    59,     -3],
                        [    61,     -1],
                        [    63,      2],
                        [    64,      3],
                        [    67,      6],
                        [    67,      7],
                        [    69,      9],
                        [    70,     11],
                        [    70,     12],
                        [    70,     14],
                        [    69,     14],
                        [    67,     15],
                        [    67,     15],
                        [    64,     15],
                        [    62,     15],
                        [    59,     14],
                        [    55,     14],
                        [    52,     14],
                        [    49,     13],
                        [    46,     13],
                        [    41,     13],
                        [    37,     14],
                        [    33,     14],
                        [    29,     14],
                        [    25,     13],
                        [    21,     11],
                        [    17,     10],
                        [    13,      7],
                        [     9,      5],
                        [     5,      2],
                        [     2,     -2],
                        [    -2,     -6],
                        [    -7,    -10],
                        [   -11,    -15],
                        [   -15,    -20],
                        [   -20,    -24],
                        [   -25,    -28],
                        [   -30,    -33],
                        [   -35,    -37],
                        [   -41,    -41],
                        [   -46,    -45],
                        [   -50,    -47],
                        [   -54,    -49],
                        [   -59,    -50],
                        [   -62,    -51],
                        [   -65,    -51],
                        [   -67,    -50],
                        [   -68,    -50],
                        [   -68,    -48],
                        [   -68,    -46],
                        [   -67,    -44],
                        [   -65,    -41],
                        [   -63,    -39],
                        [   -62,    -36],
                        [   -60,    -33],
                        [   -59,    -31],
                        [   -58,    -28],
                        [   -56,    -25],
                        [   -55,    -22],
                        [   -54,    -20],
                        [   -53,    -17],
                        [   -51,    -15],
                        [   -49,    -14],
                        [   -47,    -12],
                        [   -44,    -11],
                        [   -41,    -10],
                        [   -39,     -9],
                        [   -37,     -8],
                        [   -36,     -7],
                        [   -35,     -7],
                        [   -34,     -6],
                        [   -34,     -6],
                        [   -35,     -5],
                        [   -36,     -5],
                        [   -37,     -4],
                        [   -39,     -4],
                        [   -41,     -4],
                        [   -42,     -4],
                        [   -43,     -3],
                        [   -44,     -3],
                        [   -46,     -2],
                        [   -47,     -2],
                        [   -50,     -2],
                        [   -52,     -1],
                        [   -54,     -1],
                        [   -57,      0],
                        [   -59,      0],
                        [   -62,      1],
                        [   -63,      1],
                        [   -64,      1],
                        [   -64,      2],
                        [   -65,      2],
                        [   -67,      2],
                        [   -67,      2],
                        [   -69,      2],
                        [   -70,      1],
                        [   -72,      1],
                        [   -74,      1],
                        [   -76,      0],
                        [   -77,      0],
                        [   -80,     -1],
                        [   -81,     -1],
                        [   -83,     -2],
                        [   -84,     -2],
                        [   -85,     -2],
                        [   -87,     -2],
                        [   -88,     -3],
                        [   -89,     -4],
                        [   -89,     -4],
                        [   -90,     -5],
                        [   -90,     -5],
                        [   -90,     -6],
                        [   -89,     -6],
                        [   -89,     -7],
                        [   -87,     -7],
                        [   -86,     -7],
                        [   -86,     -8],
                        [   -85,     -9],
                        [   -85,    -10],
                        [   -85,    -11],
                        [   -85,    -11],
                        [   -85,    -13],
                        [   -85,    -14],
                        [   -85,    -15],
                        [   -85,    -17],
                        [   -86,    -19],
                        [   -88,    -20],
                        [   -88,    -22],
                        [   -89,    -24],
                        [   -89,    -26],
                        [   -89,    -28],
                        [   -88,    -31],
                        [   -87,    -33],
                        [   -85,    -36],
                        [   -83,    -37],
                        [   -81,    -39],
                        [   -78,    -41],
                        [   -75,    -42],
                        [   -72,    -44],
                        [   -68,    -46],
                        [   -64,    -46],
                        [   -60,    -48],
                        [   -57,    -50],
                        [   -53,    -53],
                        [   -49,    -55],
                        [   -45,    -57],
                        [   -41,    -59],
                        [   -36,    -60],
                        [   -32,    -61],
                        [   -28,    -62],
                        [   -24,    -62],
                        [   -20,    -61],
                        [   -15,    -60],
                        [   -12,    -59],
                        [    -9,    -57],
                        [    -5,    -54],
                        [    -1,    -51],
                        [     3,    -49],
                        [     7,    -46],
                        [    12,    -43],
                        [    16,    -40],
                        [    21,    -37],
                        [    26,    -35],
                        [    31,    -33],
                        [    35,    -30],
                        [    39,    -28],
                        [    43,    -28],
                        [    47,    -27],
                        [    50,    -27],
                        [    52,    -27],
                        [    54,    -28],
                        [    54,    -29],
                        [    54,    -31],
                        [    54,    -33],
                        [    54,    -34],
                        [    53,    -36],
                        [    53,    -38],
                        [    52,    -41],
                        [    52,    -43],
                        [    51,    -46],
                        [    52,    -47],
                        [    52,    -50],
                        [    53,    -51],
                        [    54,    -52],
                        [    53,    -54],
                        [    53,    -54],
                        [    52,    -55],
                        [    51,    -56],
                        [    50,    -56],
                        [    50,    -56],
                        [    50,    -57],
                        [    50,    -56],
                        [    50,    -56],
                        [    50,    -56],
                        [    50,    -55],
                        [    52,    -54],
                        [    54,    -54],
                        [    55,    -53],
                        [    57,    -53],
                        [    59,    -52],
                        [    59,    -51],
                        [    59,    -51],
                        [    60,    -50],
                        [    61,    -50],
                        [    61,    -50],
                        [    63,    -50],
                        [    64,    -50],
                        [    66,    -50],
                        [    67,    -50],
                        [    67,    -50],
                        [    68,    -51],
                        [    69,    -51],
                        [    69,    -51],
                        [    69,    -51],
                        [    68,    -52],
                        [    68,    -52],
                        [    68,    -52],
                        [    68,    -52],
                        [    69,    -52],
                        [    70,    -51],
                        [    71,    -51],
                        [    72,    -50],
                        [    73,    -50],
                        [    75,    -50],
                        [    76,    -49],
                        [    76,    -48],
                        [    78,    -47],
                        [    79,    -46],
                        [    80,    -45],
                        [    81,    -44],
                        [    82,    -42],
                        [    84,    -41],
                        [    85,    -41],
                        [    85,    -40],
                        [    85,    -39],
                        [    85,    -38],
                        [    85,    -37],
                        [    85,    -37],
                        [    85,    -36],
                        [    85,    -35],
                        [    85,    -34],
                        [    87,    -33],
                        [    87,    -32],
                        [    88,    -30],
                        [    89,    -29],
                        [    90,    -28],
                        [    92,    -25],
                        [    93,    -24],
                        [    96,    -21],
                        [    98,    -18],
                        [    99,    -15],
                        [   101,    -12],
                        [   102,     -9],
                        [   103,     -6],
                        [   104,     -2],
                        [   105,      2],
                        [   105,      6],
                        [   103,      9],
                        [   102,     12],
                        [   101,     15],
                        [    98,     16],
                        [    97,     19],
                        [    94,     21],
                        [    92,     23],
                        [    89,     25],
                        [    87,     27],
                        [    84,     28],
                        [    80,     30],
                        [    77,     32],
                        [    74,     33],
                        [    70,     33],
                        [    67,     33],
                        [    63,     32],
                        [    59,     30],
                        [    55,     28],
                        [    52,     24],
                        [    49,     22],
                        [    46,     18],
                        [    41,     14],
                        [    38,     10],
                        [    35,      6],
                        [    30,      1],
                        [    26,     -4],
                        [    21,     -8],
                        [    17,    -13],
                        [    12,    -17],
                        [     7,    -22],
                        [     3,    -26],
                        [    -1,    -30],
                        [    -5,    -33],
                        [    -8,    -36],
                        [   -11,    -37],
                        [   -13,    -38],
                        [   -15,    -39],
                        [   -16,    -39],
                        [   -17,    -39],
                        [   -17,    -38],
                        [   -17,    -37],
                        [   -17,    -35],
                        [   -17,    -33],
                        [   -17,    -31],
                        [   -17,    -29],
                        [   -17,    -27],
                        [   -18,    -24],
                        [   -18,    -21],
                        [   -19,    -19],
                        [   -20,    -15],
                        [   -20,    -13],
                        [   -20,    -11],
                        [   -20,     -8],
                        [   -20,     -7],
                        [   -19,     -5],
                        [   -19,     -2],
                        [   -18,     -1],
                        [   -19,      0],
                        [   -19,      2],
                        [   -20,      2],
                        [   -20,      3],
                        [   -21,      4],
                        [   -22,      5],
                        [   -23,      5],
                        [   -24,      6],
                        [   -24,      6],
                        [   -24,      6],
                        [   -24,      7],
                        [   -24,      7],
                        [   -23,      7],
                        [   -23,      7],
                        [   -24,      7],
                        [   -24,      7],
                        [   -25,      8],
                        [   -25,      8],
                        [   -26,      8],
                        [   -26,      9],
                        [   -27,      9],
                        [   -27,      9],
                        [   -27,      9],
                        [   -26,      8],
                        [   -25,      9],
                        [   -26,      8],
                        [   -26,      8],
                        [   -27,      7],
                        [   -28,      7],
                        [   -28,      7],
                        [   -29,      6],
                        [   -31,      5],
                        [   -33,      4],
                        [   -34,      2],
                        [   -35,      2],
                        [   -37,      1],
                        [   -38,     -1],
                        [   -40,     -2],
                        [   -41,     -2],
                        [   -43,     -3],
                        [   -44,     -4],
                        [   -45,     -5],
                        [   -46,     -6],
                        [   -46,     -5],
                        [   -46,     -4],
                        [   -46,     -4],
                        [   -46,     -3],
                        [   -46,     -2],
                        [   -46,     -1],
                        [   -46,     -1],
                        [   -47,     -1],
                        [   -48,     -1],
                        [   -48,     -1],
                        [   -48,      0],
                        [   -49,     -1],
                        [   -50,     -2],
                        [   -50,     -2],
                        [   -51,     -4],
                        [   -52,     -6],
                        [   -54,     -8],
                        [   -54,    -11],
                        [   -54,    -15],
                        [   -54,    -19],
                        [   -54,    -24],
                        [   -54,    -28],
                        [   -53,    -33],
                        [   -51,    -37],
                        [   -50,    -41],
                        [   -48,    -46],
                        [   -46,    -50],
                        [   -44,    -53],
                        [   -41,    -57],
                        [   -39,    -60],
                        [   -37,    -64],
                        [   -34,    -68],
                        [   -31,    -72],
                        [   -28,    -75],
                        [   -25,    -78],
                        [   -22,    -81],
                        [   -19,    -83],
                        [   -15,    -85],
                        [   -12,    -85],
                        [    -9,    -85],
                        [    -7,    -85],
                        [    -3,    -84],
                        [    -1,    -82],
                        [     2,    -80],
                        [     5,    -79],
                        [     7,    -76],
                        [    10,    -73],
                        [    13,    -70],
                        [    16,    -67],
                        [    19,    -63],
                        [    23,    -59],
                        [    26,    -55],
                        [    29,    -51],
                        [    33,    -47],
                        [    36,    -43],
                        [    38,    -40],
                        [    41,    -37],
                        [    42,    -33],
                        [    44,    -30],
                        [    45,    -28],
                        [    46,    -27],
                        [    46,    -25],
                        [    46,    -24],
                        [    46,    -24],
                        [    46,    -24],
                        [    46,    -24],
                        [    46,    -24],
                        [    46,    -24],
                        [    47,    -24],
                        [    48,    -25],
                        [    48,    -26],
                        [    50,    -27],
                        [    50,    -28],
                        [    51,    -28],
                        [    51,    -29],
                        [    52,    -30],
                        [    52,    -30],
                        [    52,    -31],
                        [    52,    -31],
                        [    52,    -32],
                        [    52,    -32],
                        [    53,    -32],
                        [    54,    -32],
                        [    54,    -32],
                        [    55,    -31],
                        [    55,    -32],
                        [    56,    -31],
                        [    57,    -31],
                        [    57,    -31],
                        [    56,    -30],
                        [    54,    -29],
                        [    53,    -29],
                        [    52,    -29],
                        [    50,    -28],
                        [    50,    -28],
                        [    49,    -28],
                        [    49,    -28],
                        [    48,    -28],
                        [    47,    -28],
                        [    47,    -28],
                        [    46,    -28],
                        [    45,    -28],
                        [    44,    -27],
                        [    42,    -26],
                        [    41,    -26],
                        [    40,    -25],
                        [    39,    -24],
                        [    38,    -24],
                        [    37,    -22],
                        [    37,    -20],
                        [    37,    -20],
                        [    38,    -18],
                        [    39,    -16],
                        [    39,    -14],
                        [    40,    -12],
                        [    41,    -10],
                        [    42,     -7],
                        [    43,     -6],
                        [    44,     -3],
                        [    45,     -2],
                        [    46,      0],
                        [    47,      2],
                        [    48,      2],
                        [    49,      2],
                        [    49,      3],
                        [    50,      2],
                        [    50,      2],
                        [    51,      2],
                        [    52,      1],
                        [    53,      0],
                        [    54,      0],
                        [    56,     -1],
                        [    58,     -1],
                        [    59,     -1],
                        [    60,     -2],
                        [    62,     -1],
                        [    63,     -1],
                        [    65,      0],
                        [    66,      2],
                        [    67,      3],
                        [    69,      6],
                        [    71,      9],
                        [    72,     12],
                        [    72,     16],
                        [    72,     20],
                        [    72,     24],
                        [    72,     28],
                        [    72,     33],
                        [    72,     36],
                        [    71,     39],
                        [    69,     42],
                        [    67,     46],
                        [    67,     48],
                        [    65,     52],
                        [    63,     54],
                        [    62,     57],
                        [    60,     59],
                        [    58,     62],
                        [    55,     63],
                        [    53,     65],
                        [    50,     66],
                        [    47,     65],
                        [    44,     65],
                        [    41,     63],
                        [    38,     63],
                        [    36,     62],
                        [    33,     60],
                        [    30,     58],
                        [    28,     55],
                        [    25,     53],
                        [    22,     50],
                        [    19,     47],
                        [    15,     45],
                        [    11,     41],
                        [     8,     37],
                        [     4,     33],
                        [     1,     28],
                        [    -2,     25],
                        [    -5,     21],
                        [    -8,     18],
                        [   -11,     15],
                        [   -13,     12],
                        [   -15,     11],
                        [   -18,      9],
                        [   -20,      7],
                        [   -20,      7],
                        [   -21,      7],
                        [   -23,      7],
                        [   -24,      7],
                        [   -24,      7],
                        [   -26,      8],
                        [   -28,      9],
                        [   -29,     10],
                        [   -31,     11],
                        [   -32,     13],
                        [   -33,     15],
                        [   -35,     16],
                        [   -36,     18],
                        [   -37,     19],
                        [   -37,     20],
                        [   -38,     21],
                        [   -39,     23],
                        [   -40,     24],
                        [   -41,     25],
                        [   -41,     26],
                        [   -41,     27],
                        [   -42,     27],
                        [   -43,     28],
                        [   -43,     28],
                        [   -43,     29],
                        [   -43,     29],
                        [   -42,     29],
                        [   -41,     29],
                        [   -40,     30],
                        [   -38,     30],
                        [   -37,     30],
                        [   -36,     30],
                        [   -34,     31],
                        [   -33,     31],
                        [   -33,     32],
                        [   -32,     32],
                        [   -31,     33],
                        [   -30,     33],
                        [   -29,     33],
                        [   -28,     33],
                        [   -26,     33],
                        [   -24,     33],
                        [   -23,     33],
                        [   -22,     33],
                        [   -20,     33],
                        [   -20,     32],
                        [   -20,     31],
                        [   -19,     31],
                        [   -19,     29],
                        [   -18,     28],
                        [   -18,     28],
                        [   -19,     26],
                        [   -19,     24],
                        [   -20,     23],
                        [   -20,     21],
                        [   -21,     20],
                        [   -22,     18],
                        [   -23,     16],
                        [   -24,     15],
                        [   -24,     15],
                        [   -25,     14],
                        [   -26,     14],
                        [   -27,     14],
                        [   -27,     15],
                        [   -28,     16],
                        [   -28,     18],
                        [   -30,     19],
                        [   -31,     20],
                        [   -33,     20],
                        [   -33,     21],
                        [   -35,     22],
                        [   -36,     23],
                        [   -37,     23],
                        [   -38,     23],
                        [   -39,     22],
                        [   -40,     21],
                        [   -41,     20],
                        [   -42,     18],
                        [   -43,     15],
                        [   -44,     11],
                        [   -45,      8],
                        [   -46,      3],
                        [   -46,     -2],
                        [   -46,     -7],
                        [   -46,    -11],
                        [   -46,    -16],
                        [   -45,    -21],
                        [   -44,    -25],
                        [   -44,    -30],
                        [   -44,    -34],
                        [   -43,    -39],
                        [   -43,    -43],
                        [   -42,    -46],
                        [   -41,    -50],
                        [   -41,    -54],
                        [   -40,    -58],
                        [   -38,    -60],
                        [   -37,    -63],
                        [   -36,    -64],
                        [   -34,    -65],
                        [   -33,    -66],
                        [   -30,    -66],
                        [   -28,    -66],
                        [   -28,    -66],
                        [   -26,    -65],
                        [   -25,    -64],
                        [   -24,    -63],
                        [   -22,    -61],
                        [   -20,    -59],
                        [   -18,    -57],
                        [   -16,    -54],
                        [   -15,    -51],
                        [   -12,    -47],
                        [   -10,    -43],
                        [    -7,    -39],
                        [    -6,    -34],
                        [    -3,    -30],
                        [    -2,    -27],
                        [     0,    -23],
                        [     2,    -20],
                        [     4,    -16],
                        [     6,    -14],
                        [     7,    -11],
                        [     9,     -9],
                        [    10,     -7],
                        [    11,     -6],
                        [    12,     -5],
                        [    13,     -4],
                        [    15,     -3],
                        [    15,     -2],
                        [    17,     -2],
                        [    18,     -2],
                        [    20,     -2],
                        [    21,     -2],
                        [    22,     -2],
                        [    23,     -2],
                        [    24,     -3],
                        [    24,     -3],
                        [    24,     -4],
                        [    25,     -4],
                        [    25,     -5],
                        [    26,     -5],
                        [    26,     -5],
                        [    26,     -5],
                        [    27,     -5],
                        [    26,     -5],
                        [    25,     -5],
                        [    25,     -5],
                        [    24,     -4],
                        [    23,     -4],
                        [    20,     -4],
                        [    19,     -3],
                        [    16,     -3],
                        [    14,     -2],
                        [    12,     -2],
                        [    10,     -2],
                        [     8,     -2],
                        [     7,     -2],
                        [     5,     -2],
                        [     4,     -1],
                        [     2,     -1],
                        [     1,     -1],
                        [    -2,     -1],
                        [    -3,      0],
                        [    -5,      0],
                        [    -7,      1],
                        [    -9,      2],
                        [   -11,      2],
                        [   -12,      3],
                        [   -13,      4],
                        [   -15,      6],
                        [   -15,      7],
                        [   -16,      8],
                        [   -16,     10],
                        [   -16,     11],
                        [   -16,     13],
                        [   -16,     15],
                        [   -15,     17],
                        [   -15,     19],
                        [   -14,     20],
                        [   -13,     23],
                        [   -12,     24],
                        [   -11,     24],
                        [   -10,     24],
                        [    -9,     24],
                        [    -7,     24],
                        [    -6,     22],
                        [    -4,     21],
                        [    -2,     20],
                        [    -1,     18],
                        [     2,     16],
                        [     3,     15],
                        [     5,     13],
                        [     7,     11],
                        [     9,     10],
                        [    11,      8],
                        [    11,      7],
                        [    13,      7],
                        [    15,      6],
                        [    16,      6],
                        [    17,      7],
                        [    19,      7],
                        [    20,     10],
                        [    21,     12],
                        [    22,     15],
                        [    23,     18],
                        [    23,     22],
                        [    23,     26],
                        [    24,     29],
                        [    24,     33],
                        [    24,     37],
                        [    24,     40],
                        [    24,     43],
                        [    24,     46],
                        [    24,     50],
                        [    24,     53],
                        [    24,     56],
                        [    24,     59],
                        [    24,     62],
                        [    23,     64],
                        [    22,     66],
                        [    20,     67],
                        [    20,     68],
                        [    18,     69],
                        [    16,     70],
                        [    15,     70],
                        [    15,     71],
                        [    13,     71],
                        [    12,     71],
                        [    11,     70],
                        [    10,     69],
                        [     8,     68],
                        [     7,     67],
                        [     5,     65],
                        [     3,     63],
                        [     2,     60],
                        [    -1,     57],
                        [    -2,     54],
                        [    -4,     50],
                        [    -7,     47],
                        [    -8,     44],
                        [   -10,     41],
                        [   -12,     38],
                        [   -14,     36],
                        [   -16,     33],
                        [   -18,     31],
                        [   -20,     29],
                        [   -22,     28],
                        [   -23,     27],
                        [   -24,     26],
                        [   -26,     25],
                        [   -28,     24],
                        [   -29,     24],
                        [   -31,     24],
                        [   -33,     24],
                        [   -34,     24],
                        [   -36,     24],
                        [   -37,     24],
                        [   -38,     24],
                        [   -40,     24],
                        [   -41,     25],
                        [   -41,     25],
                        [   -42,     26],
                        [   -43,     26],
                        [   -43,     27],
                        [   -44,     27],
                        [   -45,     27],
                        [   -45,     28],
                        [   -44,     28],
                        [   -44,     28],
                        [   -43,     28],
                        [   -42,     28],
                        [   -41,     28],
                        [   -39,     28],
                        [   -37,     28],
                        [   -36,     28],
                        [   -34,     28],
                        [   -32,     28],
                        [   -30,     28],
                        [   -28,     28],
                        [   -27,     28],
                        [   -25,     28],
                        [   -24,     29],
                        [   -22,     29],
                        [   -20,     29],
                        [   -19,     30],
                        [   -17,     30],
                        [   -15,     30],
                        [   -12,     30],
                        [   -11,     29],
                        [    -9,     29],
                        [    -7,     29],
                        [    -5,     28],
                        [    -3,     28],
                        [    -2,     27],
                        [    -1,     26],
                        [     1,     24],
                        [     2,     24],
                        [     2,     22],
                        [     2,     20],
                        [     2,     19],
                        [     2,     17],
                        [     2,     15],
                        [     3,     14],
                        [     2,     12],
                        [     2,     11],
                        [     2,     11],
                        [     1,     11],
                        [     0,     11],
                        [    -2,     11],
                        [    -2,     12],
                        [    -3,     13],
                        [    -5,     14],
                        [    -6,     15],
                        [    -8,     16],
                        [    -9,     17],
                        [   -11,     18],
                        [   -11,     19],
                        [   -12,     20],
                        [   -13,     20],
                        [   -14,     20],
                        [   -15,     20],
                        [   -17,     19],
                        [   -18,     18],
                        [   -19,     15],
                        [   -20,     14],
                        [   -20,     11],
                        [   -21,      7],
                        [   -22,      3],
                        [   -23,      0],
                        [   -24,     -5],
                        [   -24,     -9],
                        [   -25,    -12],
                        [   -26,    -16],
                        [   -26,    -20],
                        [   -28,    -24],
                        [   -28,    -28],
                        [   -29,    -31],
                        [   -29,    -35],
                        [   -30,    -38],
                        [   -31,    -42],
                        [   -31,    -45],
                        [   -32,    -47],
                        [   -32,    -50],
                        [   -31,    -52],
                        [   -31,    -54],
                        [   -30,    -55],
                        [   -30,    -57],
                        [   -29,    -58],
                        [   -29,    -59],
                        [   -28,    -59],
                        [   -28,    -59],
                        [   -28,    -59],
                        [   -28,    -59],
                        [   -27,    -59],
                        [   -26,    -58],
                        [   -25,    -56],
                        [   -24,    -54],
                        [   -24,    -52],
                        [   -22,    -50],
                        [   -21,    -46],
                        [   -20,    -42],
                        [   -19,    -39],
                        [   -17,    -36],
                        [   -15,    -33],
                        [   -14,    -30],
                        [   -11,    -27],
                        [    -9,    -24],
                        [    -7,    -22],
                        [    -6,    -20],
                        [    -4,    -18],
                        [    -2,    -16],
                        [    -2,    -15],
                        [    -1,    -13],
                        [     1,    -11],
                        [     2,    -11],
                        [     3,    -10],
                        [     5,     -9],
                        [     5,     -9],
                        [     7,     -8],
                        [     8,     -8],
                        [     9,     -7],
                        [    10,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    12,     -8],
                        [    11,     -8],
                        [    11,     -8],
                        [    10,     -8],
                        [     9,     -8],
                        [     7,     -7],
                        [     6,     -7],
                        [     4,     -7],
                        [     2,     -7],
                        [     0,     -7],
                        [    -2,     -7],
                        [    -3,     -7],
                        [    -5,     -6],
                        [    -7,     -6],
                        [    -7,     -5],
                        [    -9,     -5],
                        [   -10,     -5],
                        [   -11,     -4],
                        [   -12,     -5],
                        [   -14,     -4],
                        [   -15,     -4],
                        [   -16,     -4],
                        [   -17,     -3],
                        [   -19,     -3],
                        [   -20,     -2],
                        [   -21,     -2],
                        [   -22,     -1],
                        [   -24,     -1],
                        [   -24,      0],
                        [   -25,      1],
                        [   -26,      2],
                        [   -26,      3],
                        [   -27,      4],
                        [   -28,      6],
                        [   -28,      7],
                        [   -27,      8],
                        [   -27,      9],
                        [   -26,     11],
                        [   -26,     11],
                        [   -25,     11],
                        [   -24,     11],
                        [   -24,     11],
                        [   -22,     11],
                        [   -21,      9],
                        [   -20,      7],
                        [   -19,      7],
                        [   -17,      5],
                        [   -16,      3],
                        [   -15,      2],
                        [   -13,     -1],
                        [   -11,     -2],
                        [   -11,     -4],
                        [   -10,     -6],
                        [    -9,     -7],
                        [    -8,     -8],
                        [    -7,     -9],
                        [    -7,    -10],
                        [    -6,    -11],
                        [    -4,    -10],
                        [    -3,     -9],
                        [    -2,     -8],
                        [    -2,     -6],
                        [    -1,     -4],
                        [     0,     -2],
                        [     1,      0],
                        [     2,      2],
                        [     2,      5],
                        [     3,      7],
                        [     5,     10],
                        [     6,     12],
                        [     7,     15],
                        [     8,     17],
                        [     9,     20],
                        [    11,     23],
                        [    11,     25],
                        [    12,     28],
                        [    12,     30],
                        [    13,     32],
                        [    13,     34],
                        [    14,     37],
                        [    14,     38],
                        [    14,     40],
                        [    15,     41],
                        [    15,     42],
                        [    15,     44],
                        [    15,     46],
                        [    15,     46],
                        [    15,     46],
                        [    15,     46],
                        [    15,     46],
                        [    15,     46],
                        [    15,     45],
                        [    15,     44],
                        [    14,     42],
                        [    13,     40],
                        [    13,     38],
                        [    11,     36],
                        [    11,     33],
                        [     9,     31],
                        [     7,     29],
                        [     6,     27],
                        [     3,     24],
                        [     2,     23],
                        [     0,     21],
                        [    -2,     20],
                        [    -3,     18],
                        [    -5,     16],
                        [    -6,     15],
                        [    -7,     15],
                        [    -8,     14],
                        [    -9,     13],
                        [   -11,     12],
                        [   -11,     11],
                        [   -12,     11],
                        [   -14,     11],
                        [   -15,     11],
                        [   -15,     11],
                        [   -16,     11],
                        [   -16,     11],
                        [   -17,     11],
                        [   -18,     11],
                        [   -18,     11],
                        [   -17,     11],
                        [   -17,     11],
                        [   -16,     11],
                        [   -15,     11],
                        [   -15,     11],
                        [   -14,     11],
                        [   -12,     11],
                        [   -11,     10],
                        [    -9,     10],
                        [    -7,     10],
                        [    -6,     10],
                        [    -5,     10],
                        [    -3,      9],
                        [    -2,      9],
                        [     0,      9],
                        [     2,      8],
                        [     3,      8],
                        [     4,      8],
                        [     5,      8],
                        [     7,      8],
                        [     7,      8],
                        [     9,      7],
                        [    11,      7],
                        [    12,      7],
                        [    14,      7],
                        [    15,      7],
                        [    16,      6],
                        [    18,      5],
                        [    20,      5],
                        [    21,      4],
                        [    23,      3],
                        [    24,      2],
                        [    25,      2],
                        [    26,      1],
                        [    27,     -1],
                        [    28,     -2],
                        [    28,     -3],
                        [    28,     -5],
                        [    28,     -7],
                        [    28,     -7],
                        [    28,     -7],
                        [    28,     -8],
                        [    28,     -8],
                        [    28,     -8],
                        [    27,     -7],
                        [    26,     -7],
                        [    25,     -6],
                        [    24,     -5],
                        [    23,     -5],
                        [    22,     -4],
                        [    21,     -3],
                        [    20,     -2],
                        [    20,     -2],
                        [    19,     -1],
                        [    19,      0],
                        [    18,      1],
                        [    17,      1],
                        [    16,      1],
                        [    15,      0],
                        [    15,     -1],
                        [    14,     -2],
                        [    13,     -3],
                        [    12,     -5],
                        [    11,     -7],
                        [    10,     -8],
                        [     9,    -11],
                        [     7,    -13],
                        [     7,    -15],
                        [     6,    -17],
                        [     4,    -20],
                        [     2,    -22],
                        [     2,    -24],
                        [     0,    -26],
                        [    -1,    -28],
                        [    -2,    -31],
                        [    -3,    -33],
                        [    -4,    -35],
                        [    -5,    -37],
                        [    -6,    -40],
                        [    -7,    -41],
                        [    -7,    -43],
                        [    -8,    -45],
                        [    -8,    -46],
                        [    -9,    -48],
                        [   -10,    -50],
                        [   -11,    -50],
                        [   -11,    -52],
                        [   -12,    -53],
                        [   -13,    -54],
                        [   -14,    -54],
                        [   -15,    -54],
                        [   -15,    -53],
                        [   -15,    -52],
                        [   -15,    -51],
                        [   -15,    -50],
                        [   -15,    -48],
                        [   -15,    -46],
                        [   -14,    -44],
                        [   -13,    -41],
                        [   -12,    -40],
                        [   -11,    -37],
                        [   -10,    -35],
                        [    -8,    -33],
                        [    -7,    -31],
                        [    -6,    -29],
                        [    -5,    -28],
                        [    -4,    -26],
                        [    -3,    -24],
                        [    -2,    -23],
                        [    -2,    -21],
                        [    -1,    -20],
                        [     0,    -19],
                        [     1,    -18],
                        [     2,    -18],
                        [     2,    -17],
                        [     2,    -16],
                        [     3,    -15],
                        [     3,    -15],
                        [     3,    -15],
                        [     4,    -15],
                        [     4,    -15],
                        [     4,    -14],
                        [     4,    -15],
                        [     4,    -14],
                        [     3,    -14],
                        [     2,    -14],
                        [     2,    -14],
                        [     1,    -14],
                        [     0,    -13],
                        [    -1,    -13],
                        [    -2,    -13],
                        [    -2,    -13],
                        [    -4,    -13],
                        [    -5,    -12],
                        [    -5,    -11],
                        [    -6,    -11],
                        [    -7,    -11],
                        [    -7,    -11],
                        [    -8,    -11],
                        [    -9,    -11],
                        [    -9,    -10],
                        [   -10,    -10],
                        [   -10,    -10],
                        [   -11,    -10],
                        [   -11,     -9],
                        [   -11,     -9],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -12,     -7],
                        [   -13,     -7],
                        [   -14,     -7],
                        [   -15,     -6],
                        [   -15,     -6],
                        [   -16,     -5],
                        [   -17,     -4],
                        [   -17,     -3],
                        [   -18,     -3],
                        [   -19,     -2],
                        [   -19,     -2],
                        [   -20,     -1],
                        [   -20,      0],
                        [   -20,      1],
                        [   -20,      2],
                        [   -20,      2],
                        [   -20,      2],
                        [   -19,      2],
                        [   -19,      1],
                        [   -18,      0],
                        [   -17,     -1],
                        [   -16,     -2],
                        [   -16,     -3],
                        [   -15,     -4],
                        [   -15,     -6],
                        [   -14,     -7],
                        [   -14,     -8],
                        [   -13,    -10],
                        [   -13,    -11],
                        [   -13,    -12],
                        [   -13,    -13],
                        [   -13,    -15],
                        [   -12,    -15],
                        [   -12,    -15],
                        [   -11,    -15],
                        [   -11,    -15],
                        [   -11,    -15],
                        [   -10,    -15],
                        [    -8,    -14],
                        [    -8,    -13],
                        [    -7,    -12],
                        [    -6,    -11],
                        [    -5,    -10],
                        [    -3,     -9],
                        [    -2,     -8],
                        [    -2,     -7],
                        [     0,     -6],
                        [     1,     -4],
                        [     2,     -2],
                        [     3,      0],
                        [     5,      2],
                        [     6,      3],
                        [     7,      5],
                        [     8,      7],
                        [     9,      9],
                        [    10,     11],
                        [    11,     13],
                        [    12,     15],
                        [    13,     17],
                        [    14,     19],
                        [    15,     20],
                        [    16,     23],
                        [    18,     24],
                        [    19,     25],
                        [    20,     26],
                        [    20,     26],
                        [    22,     28],
                        [    22,     27],
                        [    23,     27],
                        [    23,     27],
                        [    23,     27],
                        [    24,     26],
                        [    23,     25],
                        [    22,     24],
                        [    21,     24],
                        [    20,     22],
                        [    20,     21],
                        [    18,     20],
                        [    16,     19],
                        [    15,     18],
                        [    14,     17],
                        [    13,     15],
                        [    12,     15],
                        [    11,     14],
                        [    11,     13],
                        [    11,     11],
                        [    10,     11],
                        [    10,     10],
                        [     9,      9],
                        [     8,      8],
                        [     7,      8],
                        [     7,      7],
                        [     7,      7],
                        [     7,      7],
                        [     7,      7],
                        [     6,      6],
                        [     7,      6],
                        [     7,      6],
                        [     7,      6],
                        [     8,      5],
                        [     8,      5],
                        [     9,      4],
                        [    10,      4],
                        [    11,      4],
                        [    12,      3],
                        [    13,      3],
                        [    15,      3],
                        [    15,      2],
                        [    15,      2],
                        [    16,      2],
                        [    17,      2],
                        [    18,      2],
                        [    20,      1],
                        [    20,      1],
                        [    20,      0],
                        [    21,      0],
                        [    22,      0],
                        [    22,     -1],
                        [    23,     -1],
                        [    24,     -2],
                        [    24,     -2],
                        [    24,     -2],
                        [    25,     -2],
                        [    25,     -2],
                        [    26,     -3],
                        [    27,     -3],
                        [    28,     -4],
                        [    29,     -4],
                        [    30,     -5],
                        [    31,     -5],
                        [    32,     -6],
                        [    33,     -6],
                        [    33,     -7],
                        [    34,     -7],
                        [    35,     -7],
                        [    35,     -8],
                        [    36,     -9],
                        [    36,    -10],
                        [    36,    -10],
                        [    36,    -10],
                        [    35,    -10],
                        [    35,    -10],
                        [    34,    -10],
                        [    34,     -9],
                        [    33,     -8],
                        [    33,     -8],
                        [    33,     -7],
                        [    33,     -7],
                        [    32,     -6],
                        [    31,     -4],
                        [    31,     -3],
                        [    31,     -2],
                        [    30,     -2],
                        [    30,     -1],
                        [    30,     -1],
                        [    30,      0],
                        [    29,      0],
                        [    28,      0],
                        [    28,      1],
                        [    28,      1],
                        [    27,      0],
                        [    26,      0],
                        [    25,     -1],
                        [    24,     -1],
                        [    23,     -2],
                        [    22,     -2],
                        [    20,     -2],
                        [    20,     -2],
                        [    19,     -3],
                        [    17,     -4],
                        [    16,     -5],
                        [    15,     -6],
                        [    14,     -7],
                        [    13,     -8],
                        [    12,     -9],
                        [    11,    -11],
                        [    10,    -11],
                        [     8,    -13],
                        [     7,    -15],
                        [     7,    -16],
                        [     5,    -18],
                        [     4,    -19],
                        [     2,    -20],
                        [     2,    -21],
                        [     0,    -23],
                        [    -2,    -24],
                        [    -2,    -24],
                        [    -4,    -25],
                        [    -5,    -26],
                        [    -6,    -26],
                        [    -7,    -27],
                        [    -8,    -27],
                        [    -9,    -26],
                        [   -10,    -26],
                        [   -10,    -26],
                        [   -10,    -25],
                        [   -10,    -24],
                        [   -10,    -24],
                        [    -9,    -23],
                        [    -8,    -22],
                        [    -7,    -21],
                        [    -7,    -20],
                        [    -6,    -19],
                        [    -5,    -18],
                        [    -5,    -17],
                        [    -4,    -16],
                        [    -3,    -15],
                        [    -3,    -14],
                        [    -3,    -13],
                        [    -3,    -12],
                        [    -3,    -11],
                        [    -2,    -11],
                        [    -2,    -11],
                        [    -2,    -10],
                        [    -2,     -9],
                        [    -2,     -9],
                        [    -2,     -8],
                        [    -2,     -8],
                        [    -2,     -7],
                        [    -1,     -7],
                        [    -1,     -7],
                        [    -2,     -7],
                        [    -2,     -7],
                        [    -2,     -7],
                        [    -2,     -7],
                        [    -3,     -7],
                        [    -3,     -7],
                        [    -3,     -6],
                        [    -3,     -6],
                        [    -4,     -6],
                        [    -4,     -5],
                        [    -4,     -5],
                        [    -4,     -5],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -4,     -3],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -3,     -1],
                        [    -3,      0],
                        [    -3,      0],
                        [    -4,      1],
                        [    -4,      1],
                        [    -4,      2],
                        [    -5,      2],
                        [    -6,      2],
                        [    -7,      2],
                        [    -7,      3],
                        [    -8,      3],
                        [    -9,      3],
                        [   -10,      3],
                        [   -11,      4],
                        [   -11,      4],
                        [   -12,      4],
                        [   -12,      5],
                        [   -13,      5],
                        [   -13,      5],
                        [   -14,      5],
                        [   -15,      5],
                        [   -15,      5],
                        [   -15,      4],
                        [   -15,      4],
                        [   -15,      3],
                        [   -15,      3],
                        [   -15,      2],
                        [   -15,      2],
                        [   -15,      1],
                        [   -16,      0],
                        [   -16,     -1],
                        [   -16,     -2],
                        [   -17,     -2],
                        [   -17,     -4],
                        [   -18,     -5],
                        [   -18,     -6],
                        [   -18,     -7],
                        [   -19,     -7],
                        [   -18,     -8],
                        [   -18,     -8],
                        [   -17,     -9],
                        [   -16,     -9],
                        [   -15,     -9],
                        [   -15,    -10],
                        [   -15,    -10],
                        [   -14,    -11],
                        [   -13,    -11],
                        [   -12,    -11],
                        [   -11,    -10],
                        [   -11,    -10],
                        [   -10,    -10],
                        [    -9,     -9],
                        [    -8,     -9],
                        [    -7,     -7],
                        [    -6,     -7],
                        [    -4,     -6],
                        [    -3,     -4],
                        [    -2,     -3],
                        [    -1,     -2],
                        [     0,      0],
                        [     2,      2],
                        [     2,      2],
                        [     4,      4],
                        [     6,      6],
                        [     7,      7],
                        [     8,      8],
                        [    10,     10],
                        [    11,     11],
                        [    12,     11],
                        [    13,     12],
                        [    14,     13],
                        [    15,     14],
                        [    16,     15],
                        [    16,     15],
                        [    17,     15],
                        [    17,     15],
                        [    17,     15],
                        [    16,     15],
                        [    16,     15],
                        [    15,     15],
                        [    15,     14],
                        [    15,     14],
                        [    15,     13],
                        [    14,     12],
                        [    14,     11],
                        [    13,     11],
                        [    13,     11],
                        [    13,     10],
                        [    13,      9],
                        [    13,      9],
                        [    13,      8],
                        [    12,      7],
                        [    12,      7],
                        [    12,      7],
                        [    13,      6],
                        [    13,      6],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    13,      4],
                        [    14,      4],
                        [    14,      4],
                        [    15,      4],
                        [    15,      4],
                        [    15,      4],
                        [    15,      3],
                        [    15,      3],
                        [    16,      3],
                        [    16,      3],
                        [    16,      3],
                        [    16,      3],
                        [    16,      2],
                        [    17,      2],
                        [    17,      2],
                        [    17,      2],
                        [    17,      2],
                        [    17,      2],
                        [    17,      2],
                        [    16,      1],
                        [    16,      1],
                        [    16,      1],
                        [    16,      1],
                        [    17,      0],
                        [    16,      0],
                        [    16,     -1],
                        [    16,     -2],
                        [    15,     -2],
                        [    16,     -2],
                        [    16,     -2],
                        [    16,     -2],
                        [    16,     -3],
                        [    17,     -2],
                        [    18,     -3],
                        [    19,     -3],
                        [    19,     -3],
                        [    20,     -3],
                        [    20,     -3],
                        [    20,     -3],
                        [    20,     -3],
                        [    21,     -3],
                        [    21,     -4],
                        [    21,     -4],
                        [    22,     -5],
                        [    22,     -5],
                        [    22,     -5],
                        [    22,     -6],
                        [    22,     -5],
                        [    22,     -5],
                        [    22,     -5],
                        [    22,     -5],
                        [    23,     -5],
                        [    23,     -4],
                        [    23,     -4],
                        [    23,     -3],
                        [    24,     -2],
                        [    24,     -2],
                        [    24,     -1],
                        [    25,      0],
                        [    24,      1],
                        [    25,      2],
                        [    24,      2],
                        [    24,      3],
                        [    24,      3],
                        [    24,      4],
                        [    24,      5],
                        [    24,      6],
                        [    23,      7],
                        [    22,      7],
                        [    21,      7],
                        [    21,      8],
                        [    20,      9],
                        [    20,      9],
                        [    20,     10],
                        [    19,     10],
                        [    18,     10],
                        [    18,     10],
                        [    17,      9],
                        [    15,      9],
                        [    15,      8],
                        [    14,      7],
                        [    13,      7],
                        [    11,      6],
                        [    10,      5],
                        [     9,      4],
                        [     7,      2],
                        [     6,      2],
                        [     4,      1],
                        [     3,      0],
                        [     2,     -1],
                        [     0,     -2],
                        [    -2,     -3],
                        [    -3,     -4],
                        [    -5,     -5],
                        [    -6,     -5],
                        [    -7,     -7],
                        [    -8,     -7],
                        [    -8,     -7],
                        [    -9,     -7],
                        [   -10,     -7],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -8],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -6],
                        [   -11,     -5],
                        [   -11,     -5],
                        [   -11,     -4],
                        [   -11,     -4],
                        [   -11,     -3],
                        [   -11,     -2],
                        [   -11,     -2],
                        [   -11,     -2],
                        [   -11,     -2],
                        [   -11,     -2],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,      0],
                        [   -11,      0],
                        [   -11,      0],
                        [   -11,      0],
                        [   -10,      0],
                        [   -10,      0],
                        [   -10,      1],
                        [    -9,      0],
                        [    -9,      1],
                        [    -8,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      2],
                        [    -6,      2],
                        [    -6,      2],
                        [    -6,      2],
                        [    -5,      2],
                        [    -4,      2],
                        [    -4,      2],
                        [    -4,      3],
                        [    -4,      3],
                        [    -3,      4],
                        [    -3,      4],
                        [    -3,      5],
                        [    -3,      5],
                        [    -2,      5],
                        [    -2,      5],
                        [    -3,      5],
                        [    -3,      6],
                        [    -3,      6],
                        [    -4,      6],
                        [    -5,      6],
                        [    -6,      5],
                        [    -7,      5],
                        [    -8,      5],
                        [    -9,      4],
                        [   -10,      3],
                        [   -11,      3],
                        [   -11,      2],
                        [   -11,      2],
                        [   -12,      2],
                        [   -13,      2],
                        [   -15,      2],
                        [   -15,      2],
                        [   -16,      2],
                        [   -16,      2],
                        [   -18,      2],
                        [   -19,      2],
                        [   -19,      2],
                        [   -20,      2],
                        [   -20,      1],
                        [   -21,      1],
                        [   -22,      0],
                        [   -23,      0],
                        [   -24,      0],
                        [   -24,     -1],
                        [   -25,     -2],
                        [   -26,     -2],
                        [   -26,     -3],
                        [   -26,     -4],
                        [   -27,     -5],
                        [   -27,     -6],
                        [   -27,     -7],
                        [   -26,     -7],
                        [   -26,     -8],
                        [   -26,     -9],
                        [   -26,    -10],
                        [   -26,    -11],
                        [   -26,    -11],
                        [   -26,    -11],
                        [   -25,    -12],
                        [   -24,    -12],
                        [   -24,    -12],
                        [   -24,    -13],
                        [   -24,    -12],
                        [   -23,    -12],
                        [   -23,    -12],
                        [   -22,    -12],
                        [   -21,    -11],
                        [   -20,    -11],
                        [   -19,    -11],
                        [   -18,    -10],
                        [   -17,     -8],
                        [   -16,     -7],
                        [   -15,     -7],
                        [   -14,     -6],
                        [   -12,     -5],
                        [   -11,     -4],
                        [   -10,     -3],
                        [    -9,     -2],
                        [    -7,     -2],
                        [    -7,     -1],
                        [    -6,      0],
                        [    -4,      1],
                        [    -3,      1],
                        [    -2,      2],
                        [    -2,      2],
                        [    -1,      2],
                        [    -1,      3],
                        [     0,      3],
                        [     1,      4],
                        [     1,      4],
                        [     1,      4],
                        [     2,      4],
                        [     2,      4],
                        [     2,      4],
                        [     2,      4],
                        [     3,      4],
                        [     3,      4],
                        [     3,      3],
                        [     4,      3],
                        [     5,      2],
                        [     5,      2],
                        [     6,      2],
                        [     6,      2],
                        [     6,      2],
                        [     7,      2],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      0],
                        [     8,      1],
                        [     8,      1],
                        [     8,      1],
                        [     8,      1],
                        [     9,      1],
                        [     9,      1],
                        [     9,      1],
                        [     9,      1],
                        [     9,      1],
                        [     9,      2],
                        [     8,      2],
                        [     8,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     6,      2],
                        [     6,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      1],
                        [     4,      0],
                        [     4,      0],
                        [     3,      0],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -2],
                        [     1,     -3],
                        [     1,     -3],
                        [     2,     -3],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     5,     -3],
                        [     5,     -3],
                        [     6,     -3],
                        [     6,     -3],
                        [     7,     -3],
                        [     7,     -3],
                        [     7,     -3],
                        [     8,     -3],
                        [     9,     -2],
                        [     9,     -2],
                        [    10,     -2],
                        [    11,     -2],
                        [    11,     -1],
                        [    11,      0],
                        [    12,      0],
                        [    12,      1],
                        [    13,      2],
                        [    13,      3],
                        [    13,      4],
                        [    14,      5],
                        [    14,      6],
                        [    14,      7],
                        [    14,      8],
                        [    14,      9],
                        [    14,     10],
                        [    13,     11],
                        [    13,     11],
                        [    13,     12],
                        [    14,     13],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    12,     15],
                        [    12,     15],
                        [    11,     14],
                        [    11,     14],
                        [    10,     13],
                        [     9,     13],
                        [     8,     12],
                        [     7,     11],
                        [     7,     11],
                        [     5,     11],
                        [     4,     10],
                        [     3,      9],
                        [     2,      8],
                        [     1,      7],
                        [     0,      7],
                        [    -2,      6],
                        [    -2,      5],
                        [    -3,      4],
                        [    -4,      3],
                        [    -5,      2],
                        [    -6,      2],
                        [    -7,      2],
                        [    -7,      1],
                        [    -8,      0],
                        [    -8,      0],
                        [    -9,     -1],
                        [    -9,     -1],
                        [   -10,     -1],
                        [   -10,     -1],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,     -1],
                        [   -11,      0],
                        [   -12,      1],
                        [   -12,      1],
                        [   -12,      1],
                        [   -12,      2],
                        [   -12,      2],
                        [   -12,      2],
                        [   -11,      3],
                        [   -11,      3],
                        [   -12,      4],
                        [   -12,      4],
                        [   -11,      5],
                        [   -11,      5],
                        [   -11,      5],
                        [   -11,      5],
                        [   -11,      6],
                        [   -11,      6],
                        [   -11,      6],
                        [   -11,      6],
                        [   -10,      6],
                        [    -9,      6],
                        [    -9,      6],
                        [    -8,      6],
                        [    -7,      5],
                        [    -7,      6],
                        [    -7,      6],
                        [    -7,      5],
                        [    -6,      5],
                        [    -6,      5],
                        [    -5,      5],
                        [    -5,      5],
                        [    -5,      5],
                        [    -4,      5],
                        [    -4,      6],
                        [    -5,      6],
                        [    -5,      6],
                        [    -4,      7],
                        [    -4,      7],
                        [    -4,      7],
                        [    -4,      7],
                        [    -4,      7],
                        [    -4,      7],
                        [    -5,      7],
                        [    -5,      7],
                        [    -6,      7],
                        [    -7,      7],
                        [    -7,      7],
                        [    -7,      6],
                        [    -8,      5],
                        [    -9,      5],
                        [    -9,      4],
                        [   -10,      3],
                        [   -11,      2],
                        [   -11,      2],
                        [   -11,      3],
                        [   -12,      3],
                        [   -13,      3],
                        [   -14,      3],
                        [   -15,      2],
                        [   -15,      2],
                        [   -16,      2],
                        [   -17,      3],
                        [   -18,      3],
                        [   -18,      3],
                        [   -19,      3],
                        [   -20,      3],
                        [   -20,      3],
                        [   -21,      2],
                        [   -22,      2],
                        [   -22,      2],
                        [   -23,      2],
                        [   -23,      1],
                        [   -23,      0],
                        [   -24,     -1],
                        [   -24,     -2],
                        [   -24,     -2],
                        [   -24,     -2],
                        [   -24,     -3],
                        [   -24,     -4],
                        [   -24,     -6],
                        [   -24,     -6],
                        [   -24,     -7],
                        [   -24,     -7],
                        [   -24,     -7],
                        [   -24,     -8],
                        [   -24,     -8],
                        [   -24,     -9],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -24,    -10],
                        [   -23,     -9],
                        [   -22,     -9],
                        [   -22,     -9],
                        [   -21,     -9],
                        [   -20,     -8],
                        [   -20,     -7],
                        [   -19,     -7],
                        [   -18,     -7],
                        [   -17,     -6],
                        [   -16,     -6],
                        [   -15,     -5],
                        [   -15,     -5],
                        [   -14,     -4],
                        [   -13,     -3],
                        [   -12,     -2],
                        [   -11,     -2],
                        [   -10,     -2],
                        [    -9,     -1],
                        [    -8,      0],
                        [    -8,      0],
                        [    -7,      1],
                        [    -6,      2],
                        [    -5,      2],
                        [    -5,      2],
                        [    -4,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -1,      2],
                        [     0,      3],
                        [     1,      3],
                        [     1,      3],
                        [     2,      3],
                        [     2,      2],
                        [     2,      3],
                        [     3,      2],
                        [     3,      2],
                        [     4,      2],
                        [     4,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     6,      2],
                        [     6,      2],
                        [     6,      2],
                        [     7,      3],
                        [     6,      2],
                        [     6,      2],
                        [     6,      3],
                        [     6,      3],
                        [     5,      3],
                        [     5,      3],
                        [     5,      4],
                        [     4,      4],
                        [     4,      4],
                        [     3,      4],
                        [     3,      5],
                        [     2,      4],
                        [     2,      4],
                        [     2,      4],
                        [     1,      4],
                        [     1,      4],
                        [     0,      3],
                        [     0,      3],
                        [     0,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -3,     -1],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     2,      0],
                        [     3,      0],
                        [     4,      1],
                        [     4,      1],
                        [     5,      1],
                        [     6,      1],
                        [     6,      2],
                        [     7,      2],
                        [     7,      2],
                        [     8,      3],
                        [     9,      4],
                        [     9,      5],
                        [     9,      5],
                        [    10,      7],
                        [    10,      7],
                        [    11,      9],
                        [    11,     10],
                        [    11,     10],
                        [    11,     11],
                        [    11,     11],
                        [    11,     11],
                        [    12,     12],
                        [    12,     13],
                        [    13,     13],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     14],
                        [    13,     13],
                        [    13,     13],
                        [    12,     12],
                        [    11,     12],
                        [    11,     11],
                        [    11,     11],
                        [    10,     11],
                        [    10,     11],
                        [     9,     10],
                        [     8,      9],
                        [     7,      8],
                        [     7,      8],
                        [     7,      7],
                        [     6,      7],
                        [     5,      6],
                        [     5,      6],
                        [     4,      5],
                        [     4,      5],
                        [     3,      4],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     0,      3],
                        [     0,      3],
                        [     0,      3],
                        [     0,      3],
                        [     0,      4],
                        [     0,      4],
                        [    -1,      5],
                        [    -1,      5],
                        [    -1,      6],
                        [    -1,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      8],
                        [     0,      9],
                        [     0,      9],
                        [     0,      9],
                        [     1,      9],
                        [     1,      9],
                        [     1,      8],
                        [     1,      9],
                        [     1,      8],
                        [     2,      8],
                        [     2,      8],
                        [     2,      7],
                        [     2,      7],
                        [     2,      7],
                        [     2,      7],
                        [     2,      6],
                        [     2,      6],
                        [     2,      5],
                        [     2,      5],
                        [     2,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      5],
                        [     1,      6],
                        [     0,      6],
                        [     0,      6],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [     0,      7],
                        [    -1,      7],
                        [    -1,      6],
                        [    -1,      6],
                        [    -2,      6],
                        [    -2,      5],
                        [    -2,      5],
                        [    -2,      4],
                        [    -2,      4],
                        [    -2,      4],
                        [    -2,      4],
                        [    -2,      4],
                        [    -2,      4],
                        [    -3,      4],
                        [    -3,      4],
                        [    -4,      4],
                        [    -4,      5],
                        [    -5,      5],
                        [    -5,      5],
                        [    -6,      5],
                        [    -7,      5],
                        [    -7,      4],
                        [    -7,      4],
                        [    -7,      4],
                        [    -8,      4],
                        [    -8,      4],
                        [    -8,      3],
                        [    -8,      2],
                        [    -9,      2],
                        [    -9,      2],
                        [   -10,      1],
                        [   -10,      0],
                        [   -10,     -1],
                        [   -10,     -2],
                        [   -11,     -2],
                        [   -11,     -3],
                        [   -11,     -3],
                        [   -11,     -4],
                        [   -11,     -5],
                        [   -11,     -5],
                        [   -12,     -6],
                        [   -12,     -7],
                        [   -13,     -7],
                        [   -13,     -7],
                        [   -13,     -7],
                        [   -13,     -7],
                        [   -14,     -8],
                        [   -13,     -8],
                        [   -13,     -8],
                        [   -13,     -8],
                        [   -13,     -8],
                        [   -13,     -8],
                        [   -12,     -7],
                        [   -12,     -8],
                        [   -12,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -11,     -7],
                        [   -10,     -7],
                        [    -9,     -6],
                        [    -9,     -6],
                        [    -8,     -5],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -3],
                        [    -6,     -3],
                        [    -5,     -2],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     3,      2],
                        [     3,      2],
                        [     4,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      1],
                        [     5,      1],
                        [     6,      1],
                        [     6,      1],
                        [     6,      1],
                        [     6,      1],
                        [     6,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      0],
                        [     6,      0],
                        [     7,      0],
                        [     7,      0],
                        [     6,      0],
                        [     6,      0],
                        [     6,      0],
                        [     6,      0],
                        [     5,      0],
                        [     5,      1],
                        [     5,      1],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -3],
                        [     1,     -3],
                        [     1,     -3],
                        [     0,     -4],
                        [     0,     -4],
                        [     0,     -4],
                        [     0,     -5],
                        [    -1,     -5],
                        [    -1,     -4],
                        [    -1,     -4],
                        [    -1,     -3],
                        [    -1,     -3],
                        [    -2,     -3],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     3,     -1],
                        [     3,     -1],
                        [     4,      0],
                        [     4,      0],
                        [     5,      1],
                        [     5,      1],
                        [     6,      2],
                        [     6,      2],
                        [     7,      2],
                        [     7,      3],
                        [     7,      4],
                        [     8,      4],
                        [     8,      4],
                        [     9,      4],
                        [     9,      5],
                        [    10,      5],
                        [    10,      6],
                        [    10,      6],
                        [    11,      6],
                        [    11,      6],
                        [    11,      6],
                        [    11,      6],
                        [    12,      6],
                        [    12,      6],
                        [    12,      6],
                        [    12,      6],
                        [    13,      6],
                        [    13,      6],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    13,      5],
                        [    12,      4],
                        [    12,      4],
                        [    11,      3],
                        [    11,      3],
                        [    11,      3],
                        [    11,      3],
                        [    11,      2],
                        [    11,      2],
                        [    11,      2],
                        [    11,      2],
                        [    10,      2],
                        [    10,      2],
                        [    10,      2],
                        [    10,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      2],
                        [     9,      3],
                        [     8,      3],
                        [     8,      3],
                        [     8,      4],
                        [     8,      4],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     8,      5],
                        [     7,      5],
                        [     7,      4],
                        [     7,      4],
                        [     7,      4],
                        [     7,      3],
                        [     7,      2],
                        [     7,      2],
                        [     6,      2],
                        [     6,      1],
                        [     5,      1],
                        [     5,      0],
                        [     4,     -1],
                        [     4,     -1],
                        [     3,     -2],
                        [     3,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      0],
                        [     3,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,     -1],
                        [     1,     -2],
                        [     0,     -2],
                        [    -1,     -3],
                        [    -1,     -3],
                        [    -1,     -4],
                        [    -2,     -4],
                        [    -2,     -5],
                        [    -2,     -6],
                        [    -2,     -6],
                        [    -2,     -6],
                        [    -3,     -7],
                        [    -3,     -7],
                        [    -3,     -7],
                        [    -4,     -7],
                        [    -5,     -8],
                        [    -5,     -8],
                        [    -6,     -8],
                        [    -6,     -9],
                        [    -7,     -9],
                        [    -7,     -9],
                        [    -7,     -9],
                        [    -7,    -10],
                        [    -7,    -10],
                        [    -7,     -9],
                        [    -7,    -10],
                        [    -7,    -10],
                        [    -7,     -9],
                        [    -7,     -9],
                        [    -7,     -9],
                        [    -6,     -8],
                        [    -6,     -8],
                        [    -6,     -8],
                        [    -5,     -7],
                        [    -5,     -7],
                        [    -4,     -7],
                        [    -4,     -7],
                        [    -3,     -6],
                        [    -3,     -6],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -4],
                        [    -1,     -4],
                        [    -1,     -3],
                        [    -1,     -3],
                        [    -1,     -3],
                        [     0,     -3],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -4],
                        [     2,     -4],
                        [     1,     -5],
                        [     1,     -5],
                        [     1,     -6],
                        [     0,     -6],
                        [     0,     -6],
                        [     1,     -5],
                        [     0,     -5],
                        [     0,     -5],
                        [     0,     -5],
                        [     0,     -4],
                        [     0,     -4],
                        [     0,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     0,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     1,     -4],
                        [     0,     -4],
                        [     0,     -5],
                        [     0,     -5],
                        [     0,     -5],
                        [     0,     -6],
                        [     0,     -6],
                        [    -1,     -6],
                        [    -1,     -6],
                        [    -1,     -6],
                        [    -1,     -6],
                        [    -1,     -6],
                        [    -1,     -5],
                        [    -2,     -5],
                        [    -2,     -6],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -3,     -5],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -3,     -3],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -3,     -3],
                        [    -3,     -4],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -2,     -4],
                        [    -2,     -4],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -1,     -3],
                        [    -1,     -3],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -3],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     3,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     5,     -2],
                        [     6,     -2],
                        [     6,     -2],
                        [     6,     -1],
                        [     6,     -1],
                        [     7,     -1],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      0],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      1],
                        [     7,      2],
                        [     7,      1],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     7,      2],
                        [     6,      2],
                        [     6,      2],
                        [     6,      2],
                        [     5,      1],
                        [     5,      1],
                        [     5,      1],
                        [     4,      0],
                        [     4,      0],
                        [     3,     -1],
                        [     3,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -2],
                        [     0,     -2],
                        [     0,     -3],
                        [    -1,     -3],
                        [    -2,     -4],
                        [    -2,     -4],
                        [    -2,     -4],
                        [    -2,     -4],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -5,     -4],
                        [    -5,     -4],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -5,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -3],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -3],
                        [     1,     -3],
                        [     1,     -4],
                        [     1,     -4],
                        [     0,     -4],
                        [     0,     -4],
                        [     0,     -4],
                        [    -1,     -5],
                        [    -1,     -5],
                        [    -1,     -5],
                        [    -1,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -2,     -5],
                        [    -3,     -6],
                        [    -3,     -6],
                        [    -4,     -6],
                        [    -4,     -6],
                        [    -4,     -6],
                        [    -4,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -6,     -7],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -5,     -6],
                        [    -4,     -5],
                        [    -4,     -5],
                        [    -4,     -5],
                        [    -4,     -4],
                        [    -4,     -4],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -3,     -4],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -3],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -5,     -2],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -6,     -3],
                        [    -6,     -4],
                        [    -6,     -4],
                        [    -6,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -7,     -4],
                        [    -6,     -3],
                        [    -6,     -3],
                        [    -6,     -3],
                        [    -5,     -3],
                        [    -5,     -3],
                        [    -4,     -3],
                        [    -4,     -3],
                        [    -4,     -3],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -4,      0],
                        [    -4,      0],
                        [    -4,      1],
                        [    -4,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,     -1],
                        [    -6,     -1],
                        [    -5,     -1],
                        [    -6,     -1],
                        [    -5,     -1],
                        [    -5,     -1],
                        [    -5,     -1],
                        [    -5,     -1],
                        [    -5,     -2],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     3,      3],
                        [     3,      3],
                        [     3,      3],
                        [     3,      4],
                        [     3,      4],
                        [     4,      4],
                        [     4,      5],
                        [     4,      5],
                        [     4,      5],
                        [     4,      5],
                        [     5,      5],
                        [     5,      5],
                        [     5,      5],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      4],
                        [     5,      3],
                        [     5,      3],
                        [     5,      3],
                        [     5,      3],
                        [     5,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     3,      2],
                        [     3,      2],
                        [     3,      2],
                        [     3,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     1,      1],
                        [     1,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -3,      0],
                        [    -4,      0],
                        [    -4,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -6,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -6,      2],
                        [    -6,      2],
                        [    -6,      2],
                        [    -6,      2],
                        [    -5,      2],
                        [    -5,      2],
                        [    -5,      1],
                        [    -4,      1],
                        [    -4,      1],
                        [    -3,      1],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -4,      1],
                        [    -4,      2],
                        [    -4,      1],
                        [    -4,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -6,      1],
                        [    -6,      1],
                        [    -6,      1],
                        [    -6,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      1],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      0],
                        [    -7,      1],
                        [    -6,      0],
                        [    -6,      0],
                        [    -5,      0],
                        [    -5,      0],
                        [    -4,      1],
                        [    -4,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -2,      2],
                        [    -2,      1],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     2,      3],
                        [     1,      3],
                        [     1,      3],
                        [     1,      3],
                        [     1,      3],
                        [     0,      3],
                        [     0,      3],
                        [     0,      3],
                        [     0,      3],
                        [    -1,      3],
                        [    -1,      3],
                        [    -1,      3],
                        [    -1,      3],
                        [    -2,      2],
                        [    -2,      3],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      3],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [     0,      2],
                        [     1,      3],
                        [     1,      3],
                        [     1,      3],
                        [     2,      4],
                        [     1,      3],
                        [     2,      4],
                        [     2,      4],
                        [     2,      4],
                        [     2,      5],
                        [     2,      5],
                        [     2,      5],
                        [     2,      5],
                        [     2,      5],
                        [     3,      6],
                        [     3,      6],
                        [     3,      6],
                        [     3,      6],
                        [     3,      6],
                        [     3,      6],
                        [     4,      6],
                        [     4,      6],
                        [     5,      6],
                        [     5,      6],
                        [     5,      6],
                        [     5,      6],
                        [     5,      6],
                        [     5,      5],
                        [     5,      5],
                        [     5,      5],
                        [     5,      5],
                        [     5,      4],
                        [     4,      4],
                        [     4,      4],
                        [     4,      3],
                        [     4,      3],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      1],
                        [     5,      2],
                        [     4,      2],
                        [     4,      1],
                        [     4,      2],
                        [     4,      2],
                        [     4,      1],
                        [     3,      1],
                        [     3,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -3,      2],
                        [    -3,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     3,     -1],
                        [     3,     -1],
                        [     3,     -1],
                        [     4,     -1],
                        [     4,     -1],
                        [     4,     -1],
                        [     4,     -1],
                        [     4,     -1],
                        [     5,     -1],
                        [     5,     -1],
                        [     5,      0],
                        [     6,      0],
                        [     6,      0],
                        [     6,      0],
                        [     6,      0],
                        [     5,      1],
                        [     5,      1],
                        [     5,      1],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     5,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     4,      2],
                        [     3,      2],
                        [     3,      2],
                        [     3,      2],
                        [     3,      2],
                        [     2,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -2,      0],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -3,      1],
                        [    -4,      1],
                        [    -4,      1],
                        [    -4,      1],
                        [    -4,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      1],
                        [    -5,      0],
                        [    -4,      0],
                        [    -4,      0],
                        [    -4,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     3,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      2],
                        [    -1,      1],
                        [    -1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     0,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     2,     -2],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -3],
                        [    -2,     -3],
                        [    -1,     -3],
                        [    -1,     -3],
                        [    -1,     -3],
                        [     0,     -3],
                        [     0,     -3],
                        [     0,     -3],
                        [     1,     -3],
                        [     1,     -3],
                        [     1,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     2,     -3],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     3,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     4,     -2],
                        [     5,     -2],
                        [     5,     -2],
                        [     5,     -1],
                        [     5,     -1],
                        [     5,     -1],
                        [     5,     -1],
                        [     4,     -1],
                        [     4,      0],
                        [     4,      0],
                        [     4,      0],
                        [     4,      0],
                        [     4,      0],
                        [     4,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     3,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -1],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -1],
                        [    -4,     -1],
                        [    -5,     -1],
                        [    -4,     -1],
                        [    -5,     -2],
                        [    -5,     -2],
                        [    -5,     -2],
                        [    -5,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -4,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -3,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [    -1,     -2],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     0,     -2],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     0,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -2],
                        [     2,     -2],
                        [     2,     -2],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,      0],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -3,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      2],
                        [     1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -1,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      2],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -2,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     2,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      2],
                        [     1,      2],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      2],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -2],
                        [     1,     -1],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     1,      0],
                        [     1,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      0],
                        [     2,      1],
                        [     2,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -2,     -2],
                        [    -2,     -2],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -2],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,      0],
                        [     2,      0],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     2,     -1],
                        [     1,     -2],
                        [     1,     -2],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -2],
                        [     0,     -1],
                        [     0,     -2],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -1,     -1],
                        [    -1,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,     -1],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -2,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -2,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      2],
                        [     1,      2],
                        [     0,      2],
                        [     1,      2],
                        [     1,      2],
                        [     1,      2],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      2],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [    -1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     1,      1],
                        [     1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     1,      0],
                        [     0,     -1],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     1,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     1,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,     -1],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,     -1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      0],
                        [    -1,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      0],
                        [     0,      1],
                        [     0,      1],
                        [    -1,      1],
                        [     0,      1],
                        [     0,      1],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [     0,      0],
                        [    -1,      0],
                        [     0,      0]],
                        dtype = numpy.int16)
))

sounds.append(Sound(
    name = "DynamicLoad_BSPNostromo_Ripley.023",
    rate = 41000,
    data = numpy.array([[  1.03759766e-03,   3.87573242e-03],
                        [ -4.45556641e-03,  -2.65502930e-03],
                        [ -1.17797852e-02,  -1.11694336e-02],
                        [ -2.07824707e-02,  -2.13928223e-02],
                        [ -2.81677246e-02,  -2.99072266e-02],
                        [ -3.20129395e-02,  -3.47595215e-02],
                        [ -3.56445312e-02,  -3.91540527e-02],
                        [ -4.17480469e-02,  -4.56848145e-02],
                        [ -4.60510254e-02,  -5.01708984e-02],
                        [ -4.28466797e-02,  -4.67834473e-02],
                        [ -3.34777832e-02,  -3.69262695e-02],
                        [ -2.31933594e-02,  -2.58789062e-02],
                        [ -1.35803223e-02,  -1.52893066e-02],
                        [ -5.67626953e-03,  -6.28662109e-03],
                        [ -3.60107422e-03,  -3.05175781e-03],
                        [ -6.59179688e-03,  -4.97436523e-03],
                        [ -6.50024414e-03,  -3.93676758e-03],
                        [ -9.15527344e-05,   3.20434570e-03],
                        [  5.15747070e-03,   8.91113281e-03],
                        [  2.89916992e-03,   6.77490234e-03],
                        [ -3.50952148e-03,   1.52587891e-04],
                        [ -7.96508789e-03,  -4.82177734e-03],
                        [ -8.94165039e-03,  -6.59179688e-03],
                        [ -7.35473633e-03,  -5.98144531e-03],
                        [ -3.57055664e-03,  -3.32641602e-03],
                        [  3.05175781e-05,  -9.15527344e-04],
                        [  7.32421875e-04,  -1.34277344e-03],
                        [  1.25122070e-03,  -1.80053711e-03],
                        [  7.29370117e-03,   3.47900391e-03],
                        [  1.84936523e-02,   1.41601562e-02],
                        [  2.78015137e-02,   2.32849121e-02],
                        [  3.07922363e-02,   2.64282227e-02],
                        [  2.97546387e-02,   2.58483887e-02],
                        [  2.86254883e-02,   2.54516602e-02],
                        [  2.97241211e-02,   2.75268555e-02],
                        [  3.42102051e-02,   3.30810547e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  5.07812500e-02,   5.19104004e-02],
                        [  6.39648438e-02,   6.60705566e-02],
                        [  8.36791992e-02,   8.65478516e-02],
                        [  1.07177734e-01,   1.10595703e-01],
                        [  1.27197266e-01,   1.30828857e-01],
                        [  1.33666992e-01,   1.37207031e-01],
                        [  1.10443115e-01,   1.13647461e-01],
                        [  4.14733887e-02,   4.40368652e-02],
                        [ -7.10144043e-02,  -6.93359375e-02],
                        [ -1.97753906e-01,  -1.97021484e-01],
                        [ -2.97363281e-01,  -2.97668457e-01],
                        [ -3.40850830e-01,  -3.42132568e-01],
                        [ -3.25317383e-01,  -3.27484131e-01],
                        [ -2.73895264e-01,  -2.76733398e-01],
                        [ -2.20245361e-01,  -2.23541260e-01],
                        [ -1.82617188e-01,  -1.86126709e-01],
                        [ -1.53472900e-01,  -1.56860352e-01],
                        [ -1.15692139e-01,  -1.18743896e-01],
                        [ -6.19812012e-02,  -6.43920898e-02],
                        [ -1.52587891e-04,  -1.83105469e-03],
                        [  5.31005859e-02,   5.23376465e-02],
                        [  8.41369629e-02,   8.43200684e-02],
                        [  9.06982422e-02,   9.17358398e-02],
                        [  8.30993652e-02,   8.49609375e-02],
                        [  7.65380859e-02,   7.90405273e-02],
                        [  7.71789551e-02,   8.00781250e-02],
                        [  7.95593262e-02,   8.26110840e-02],
                        [  7.82775879e-02,   8.12988281e-02],
                        [  7.56225586e-02,   7.83691406e-02],
                        [  7.48901367e-02,   7.71484375e-02],
                        [  7.27233887e-02,   7.43408203e-02],
                        [  6.51245117e-02,   6.60400391e-02],
                        [  5.55114746e-02,   5.56335449e-02],
                        [  4.92248535e-02,   4.86450195e-02],
                        [  4.60510254e-02,   4.48303223e-02],
                        [  4.21752930e-02,   4.04052734e-02],
                        [  3.65295410e-02,   3.44543457e-02],
                        [  3.16772461e-02,   2.94189453e-02],
                        [  2.88085938e-02,   2.65808105e-02],
                        [  2.76489258e-02,   2.56347656e-02],
                        [  2.85339355e-02,   2.68859863e-02],
                        [  3.08227539e-02,   2.96020508e-02],
                        [  3.46069336e-02,   3.39050293e-02],
                        [  4.19006348e-02,   4.17480469e-02],
                        [  5.04150391e-02,   5.07507324e-02],
                        [  5.11779785e-02,   5.19714355e-02],
                        [  3.68957520e-02,   3.80249023e-02],
                        [  1.07116699e-02,   1.20544434e-02],
                        [ -1.40380859e-02,  -1.25732422e-02],
                        [ -2.40478516e-02,  -2.26440430e-02],
                        [ -1.68151855e-02,  -1.55639648e-02],
                        [ -3.38745117e-03,  -2.38037109e-03],
                        [  3.35693359e-04,   1.03759766e-03],
                        [ -1.00708008e-02,  -9.70458984e-03],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.54821777e-02,  -2.57873535e-02],
                        [ -1.63879395e-02,  -1.69982910e-02],
                        [ -4.45556641e-03,  -5.24902344e-03],
                        [  3.14331055e-03,   2.19726562e-03],
                        [  4.08935547e-03,   3.08227539e-03],
                        [  1.25122070e-03,   3.05175781e-04],
                        [  2.92968750e-03,   2.07519531e-03],
                        [  1.31835938e-02,   1.24511719e-02],
                        [  2.47802734e-02,   2.42309570e-02],
                        [  2.92663574e-02,   2.89306641e-02],
                        [  2.80456543e-02,   2.79235840e-02],
                        [  2.86560059e-02,   2.86865234e-02],
                        [  3.38745117e-02,   3.40576172e-02],
                        [  3.91845703e-02,   3.94592285e-02],
                        [  3.96423340e-02,   3.99780273e-02],
                        [  3.42102051e-02,   3.45764160e-02],
                        [  2.55432129e-02,   2.58789062e-02],
                        [  1.82189941e-02,   1.85241699e-02],
                        [  1.48620605e-02,   1.51062012e-02],
                        [  1.38549805e-02,   1.40380859e-02],
                        [  1.14746094e-02,   1.15356445e-02],
                        [  6.43920898e-03,   6.46972656e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.89208984e-03,   1.80053711e-03],
                        [  3.87573242e-03,   3.78417969e-03],
                        [  5.37109375e-03,   5.27954102e-03],
                        [  3.47900391e-03,   3.38745117e-03],
                        [ -1.80053711e-03,  -1.86157227e-03],
                        [ -7.56835938e-03,  -7.59887695e-03],
                        [ -1.26953125e-02,  -1.27563477e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.51672363e-02,  -1.51367188e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.50646973e-02,  -3.50341797e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.23583984e-02,  -4.23278809e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  5.73730469e-03,   5.70678711e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  4.30297852e-03,   4.33349609e-03],
                        [  8.33129883e-03,   8.30078125e-03],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  2.29797363e-02,   2.30102539e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  1.02600098e-01,   1.02600098e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -1.04278564e-01,  -1.04248047e-01],
                        [ -2.21374512e-01,  -2.21374512e-01],
                        [ -3.14880371e-01,  -3.14880371e-01],
                        [ -3.60565186e-01,  -3.60565186e-01],
                        [ -3.54003906e-01,  -3.54003906e-01],
                        [ -3.09997559e-01,  -3.09997559e-01],
                        [ -2.50946045e-01,  -2.50946045e-01],
                        [ -1.96014404e-01,  -1.96014404e-01],
                        [ -1.51123047e-01,  -1.51123047e-01],
                        [ -1.05255127e-01,  -1.05255127e-01],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  8.33129883e-02,   8.33129883e-02],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  1.15692139e-01,   1.15692139e-01],
                        [  1.01959229e-01,   1.01959229e-01],
                        [  8.96301270e-02,   8.96606445e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  6.61926270e-02,   6.61926270e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  7.61718750e-02,   7.61718750e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  5.73730469e-03,   5.70678711e-03],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.42297363e-02,  -5.41992188e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  5.21545410e-02,   5.21545410e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -1.82159424e-01,  -1.82159424e-01],
                        [ -2.80853271e-01,  -2.80853271e-01],
                        [ -3.31787109e-01,  -3.31787109e-01],
                        [ -3.22570801e-01,  -3.22570801e-01],
                        [ -2.73498535e-01,  -2.73498535e-01],
                        [ -2.19238281e-01,  -2.19238281e-01],
                        [ -1.79962158e-01,  -1.79962158e-01],
                        [ -1.52526855e-01,  -1.52526855e-01],
                        [ -1.22711182e-01,  -1.22711182e-01],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  8.53881836e-02,   8.53881836e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [  7.93457031e-04,   7.93457031e-04],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  1.43554688e-01,   1.43554688e-01],
                        [  1.40380859e-01,   1.40380859e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  4.71191406e-02,   4.71191406e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -1.49353027e-01,  -1.49353027e-01],
                        [ -2.51647949e-01,  -2.51647949e-01],
                        [ -3.16040039e-01,  -3.16040039e-01],
                        [ -3.26110840e-01,  -3.26110840e-01],
                        [ -2.94403076e-01,  -2.94403076e-01],
                        [ -2.50305176e-01,  -2.50305176e-01],
                        [ -2.15454102e-01,  -2.15454102e-01],
                        [ -1.89514160e-01,  -1.89514160e-01],
                        [ -1.56463623e-01,  -1.56463623e-01],
                        [ -1.03118896e-01,  -1.03118896e-01],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.01379395e-01,   1.01379395e-01],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  6.45446777e-02,   6.45446777e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  1.14257812e-01,   1.14257812e-01],
                        [  1.25000000e-01,   1.25000000e-01],
                        [  1.22039795e-01,   1.22039795e-01],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -1.70928955e-01,  -1.70928955e-01],
                        [ -2.70568848e-01,  -2.70568848e-01],
                        [ -3.30474854e-01,  -3.30474854e-01],
                        [ -3.33892822e-01,  -3.33892822e-01],
                        [ -2.92236328e-01,  -2.92236328e-01],
                        [ -2.41027832e-01,  -2.41027832e-01],
                        [ -2.07672119e-01,  -2.07672119e-01],
                        [ -1.86157227e-01,  -1.86157227e-01],
                        [ -1.52221680e-01,  -1.52221680e-01],
                        [ -9.53674316e-02,  -9.53674316e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -2.62359619e-01,  -2.62359619e-01],
                        [ -3.21411133e-01,  -3.21411133e-01],
                        [ -3.32916260e-01,  -3.32916260e-01],
                        [ -3.02001953e-01,  -3.02001953e-01],
                        [ -2.50976562e-01,  -2.50976562e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.75811768e-01,  -1.75811768e-01],
                        [ -1.46911621e-01,  -1.46911621e-01],
                        [ -1.01623535e-01,  -1.01623535e-01],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.37573242e-01,   1.37573242e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.24847412e-01,   1.24847412e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  3.53393555e-02,   3.53393555e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  3.46679688e-02,   3.46679688e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [  1.70898438e-03,   1.67846680e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  5.30090332e-02,   5.29785156e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.28326416e-01,   1.28326416e-01],
                        [  1.11816406e-01,   1.11816406e-01],
                        [  6.55517578e-02,   6.55517578e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -1.31866455e-01,  -1.31866455e-01],
                        [ -2.40905762e-01,  -2.40905762e-01],
                        [ -3.11401367e-01,  -3.11370850e-01],
                        [ -3.24096680e-01,  -3.24096680e-01],
                        [ -2.86224365e-01,  -2.86224365e-01],
                        [ -2.29705811e-01,  -2.29705811e-01],
                        [ -1.90917969e-01,  -1.90917969e-01],
                        [ -1.80236816e-01,  -1.80236816e-01],
                        [ -1.74407959e-01,  -1.74407959e-01],
                        [ -1.45355225e-01,  -1.45324707e-01],
                        [ -9.04846191e-02,  -9.04846191e-02],
                        [ -2.71606445e-02,  -2.71911621e-02],
                        [  3.12194824e-02,   3.11889648e-02],
                        [  7.98950195e-02,   7.99255371e-02],
                        [  1.13372803e-01,   1.13403320e-01],
                        [  1.26190186e-01,   1.26220703e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.12548828e-01,   1.12548828e-01],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  8.34655762e-02,   8.34960938e-02],
                        [  7.34558105e-02,   7.34863281e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  6.02416992e-02,   6.02111816e-02],
                        [  4.72717285e-02,   4.72412109e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  6.15234375e-02,   6.14929199e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  1.92260742e-02,   1.92565918e-02],
                        [ -6.34765625e-03,  -6.31713867e-03],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.74658203e-02,  -2.74963379e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.22570801e-02,  -3.22875977e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  3.18298340e-02,   3.18603516e-02],
                        [  4.16564941e-02,   4.16870117e-02],
                        [  4.38232422e-02,   4.37927246e-02],
                        [  4.25415039e-02,   4.25109863e-02],
                        [  4.08020020e-02,   4.07714844e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  3.54003906e-02,   3.54309082e-02],
                        [  3.40881348e-02,   3.41186523e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.94592285e-02,   3.94287109e-02],
                        [  3.68347168e-02,   3.68041992e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.23999023e-02,   2.24304199e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.48718262e-02,   2.48413086e-02],
                        [  2.50854492e-02,   2.50549316e-02],
                        [  2.37731934e-02,   2.37426758e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.24609375e-02,   2.24914551e-02],
                        [  1.91650391e-02,   1.91955566e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  4.45556641e-03,   4.42504883e-03],
                        [ -2.62451172e-03,  -2.65502930e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.76086426e-02,  -1.75781250e-02],
                        [ -2.53906250e-02,  -2.53601074e-02],
                        [ -3.25622559e-02,  -3.25317383e-02],
                        [ -3.79333496e-02,  -3.79638672e-02],
                        [ -4.06494141e-02,  -4.07104492e-02],
                        [ -4.02526855e-02,  -4.02832031e-02],
                        [ -3.59497070e-02,  -3.59191895e-02],
                        [ -2.98156738e-02,  -2.97851562e-02],
                        [ -2.65808105e-02,  -2.65502930e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -1.95922852e-02,  -1.96228027e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -1.66625977e-02,  -1.66320801e-02],
                        [ -1.32751465e-02,  -1.32446289e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -6.59179688e-03,  -6.62231445e-03],
                        [ -7.96508789e-03,  -8.02612305e-03],
                        [ -9.67407227e-03,  -9.70458984e-03],
                        [ -1.18103027e-02,  -1.17797852e-02],
                        [ -1.67541504e-02,  -1.66931152e-02],
                        [ -2.29797363e-02,  -2.29492188e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.55639648e-02,  -1.56250000e-02],
                        [ -7.93457031e-04,  -8.23974609e-04],
                        [  1.37329102e-02,   1.37634277e-02],
                        [  2.34069824e-02,   2.34375000e-02],
                        [  2.52685547e-02,   2.52990723e-02],
                        [  1.85241699e-02,   1.85546875e-02],
                        [  7.84301758e-03,   7.78198242e-03],
                        [  8.23974609e-04,   7.62939453e-04],
                        [ -1.83105469e-04,  -2.13623047e-04],
                        [  2.74658203e-04,   3.35693359e-04],
                        [  5.79833984e-04,   6.40869141e-04],
                        [  4.88281250e-03,   4.91333008e-03],
                        [  1.42822266e-02,   1.42517090e-02],
                        [  2.39562988e-02,   2.38952637e-02],
                        [  3.02734375e-02,   3.02124023e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  4.29687500e-02,   4.30297852e-02],
                        [  5.64880371e-02,   5.65490723e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  9.52148438e-02,   9.51538086e-02],
                        [  1.12884521e-01,   1.12823486e-01],
                        [  1.18499756e-01,   1.18499756e-01],
                        [  1.01684570e-01,   1.01715088e-01],
                        [  5.60607910e-02,   5.61523438e-02],
                        [ -2.04467773e-02,  -2.04162598e-02],
                        [ -1.24298096e-01,  -1.24359131e-01],
                        [ -2.35778809e-01,  -2.35870361e-01],
                        [ -3.17291260e-01,  -3.17352295e-01],
                        [ -3.38500977e-01,  -3.38470459e-01],
                        [ -3.04046631e-01,  -3.03955078e-01],
                        [ -2.47558594e-01,  -2.47497559e-01],
                        [ -1.99829102e-01,  -1.99829102e-01],
                        [ -1.68884277e-01,  -1.68975830e-01],
                        [ -1.45996094e-01,  -1.46057129e-01],
                        [ -1.19415283e-01,  -1.19445801e-01],
                        [ -8.18481445e-02,  -8.17871094e-02],
                        [ -3.32031250e-02,  -3.31115723e-02],
                        [  1.97753906e-02,   1.98059082e-02],
                        [  6.83898926e-02,   6.83593750e-02],
                        [  1.06201172e-01,   1.06140137e-01],
                        [  1.29089355e-01,   1.29058838e-01],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.31866455e-01,   1.31958008e-01],
                        [  1.23992920e-01,   1.24084473e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.03302002e-01,   1.03210449e-01],
                        [  8.41064453e-02,   8.40454102e-02],
                        [  6.39343262e-02,   6.39038086e-02],
                        [  5.05981445e-02,   5.06896973e-02],
                        [  4.68444824e-02,   4.69360352e-02],
                        [  5.05371094e-02,   5.05676270e-02],
                        [  5.79528809e-02,   5.78918457e-02],
                        [  6.41479492e-02,   6.40258789e-02],
                        [  6.38122559e-02,   6.37512207e-02],
                        [  5.53894043e-02,   5.54199219e-02],
                        [  4.22668457e-02,   4.23889160e-02],
                        [  2.81372070e-02,   2.81982422e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -2.50244141e-03,  -2.59399414e-03],
                        [ -1.66625977e-02,  -1.67541504e-02],
                        [ -2.37121582e-02,  -2.37426758e-02],
                        [ -2.16064453e-02,  -2.15148926e-02],
                        [ -1.53198242e-02,  -1.51977539e-02],
                        [ -1.15356445e-02,  -1.15051270e-02],
                        [ -1.18713379e-02,  -1.19323730e-02],
                        [ -1.35192871e-02,  -1.36413574e-02],
                        [ -1.40991211e-02,  -1.41601562e-02],
                        [ -1.33972168e-02,  -1.33666992e-02],
                        [ -1.11694336e-02,  -1.10778809e-02],
                        [ -5.95092773e-03,  -5.88989258e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  1.18713379e-02,   1.17797852e-02],
                        [  1.90124512e-02,   1.89208984e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.88085938e-02,   2.89001465e-02],
                        [  3.24096680e-02,   3.25012207e-02],
                        [  3.55224609e-02,   3.55529785e-02],
                        [  4.02526855e-02,   4.01916504e-02],
                        [  4.54711914e-02,   4.53491211e-02],
                        [  4.68139648e-02,   4.67529297e-02],
                        [  4.32434082e-02,   4.33044434e-02],
                        [  3.78112793e-02,   3.79333496e-02],
                        [  3.27148438e-02,   3.27758789e-02],
                        [  2.78625488e-02,   2.78320312e-02],
                        [  2.47192383e-02,   2.45971680e-02],
                        [  2.61535645e-02,   2.60620117e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  3.17993164e-02,   3.18908691e-02],
                        [  2.84118652e-02,   2.85339355e-02],
                        [  2.30712891e-02,   2.31018066e-02],
                        [  1.84936523e-02,   1.84020996e-02],
                        [  1.66320801e-02,   1.65100098e-02],
                        [  1.83105469e-02,   1.82495117e-02],
                        [  2.05993652e-02,   2.06604004e-02],
                        [  1.87072754e-02,   1.88293457e-02],
                        [  1.14746094e-02,   1.15661621e-02],
                        [  2.47192383e-03,   2.41088867e-03],
                        [ -5.40161133e-03,  -5.55419922e-03],
                        [ -1.26953125e-02,  -1.28173828e-02],
                        [ -1.98364258e-02,  -1.98059082e-02],
                        [ -2.50854492e-02,  -2.49328613e-02],
                        [ -2.75268555e-02,  -2.74047852e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -3.15551758e-02,  -3.16467285e-02],
                        [ -3.45764160e-02,  -3.47290039e-02],
                        [ -3.48510742e-02,  -3.49121094e-02],
                        [ -3.06091309e-02,  -3.05175781e-02],
                        [ -2.38647461e-02,  -2.37121582e-02],
                        [ -1.83410645e-02,  -1.82495117e-02],
                        [ -1.62048340e-02,  -1.62658691e-02],
                        [ -1.70288086e-02,  -1.71508789e-02],
                        [ -1.82800293e-02,  -1.84020996e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.58386230e-02,  -1.56860352e-02],
                        [ -1.44653320e-02,  -1.43127441e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.22680664e-02,  -1.24206543e-02],
                        [ -1.28479004e-02,  -1.30004883e-02],
                        [ -1.36108398e-02,  -1.36718750e-02],
                        [ -1.06811523e-02,  -1.05895996e-02],
                        [ -4.60815430e-03,  -4.42504883e-03],
                        [  4.57763672e-04,   5.49316406e-04],
                        [  3.50952148e-03,   3.41796875e-03],
                        [  5.88989258e-03,   5.73730469e-03],
                        [  7.44628906e-03,   7.32421875e-03],
                        [  7.81250000e-03,   7.87353516e-03],
                        [  8.63647461e-03,   8.78906250e-03],
                        [  1.06811523e-02,   1.08337402e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.19934082e-02,   1.18713379e-02],
                        [  9.94873047e-03,   9.79614258e-03],
                        [  6.56127930e-03,   6.50024414e-03],
                        [  4.15039062e-03,   4.27246094e-03],
                        [  7.53784180e-03,   7.72094727e-03],
                        [  1.87072754e-02,   1.87683105e-02],
                        [  3.37524414e-02,   3.36608887e-02],
                        [  4.78820801e-02,   4.76989746e-02],
                        [  6.21337891e-02,   6.20117188e-02],
                        [  8.18786621e-02,   8.19091797e-02],
                        [  1.06964111e-01,   1.07147217e-01],
                        [  1.28295898e-01,   1.28448486e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.19140625e-01,   1.18988037e-01],
                        [  7.42492676e-02,   7.40966797e-02],
                        [ -6.01196289e-03,  -6.07299805e-03],
                        [ -1.16760254e-01,  -1.16638184e-01],
                        [ -2.32940674e-01,  -2.32757568e-01],
                        [ -3.16528320e-01,  -3.16436768e-01],
                        [ -3.38958740e-01,  -3.39080811e-01],
                        [ -3.03222656e-01,  -3.03436279e-01],
                        [ -2.43041992e-01,  -2.43133545e-01],
                        [ -1.95770264e-01,  -1.95709229e-01],
                        [ -1.74133301e-01,  -1.73919678e-01],
                        [ -1.62689209e-01,  -1.62506104e-01],
                        [ -1.39434814e-01,  -1.39465332e-01],
                        [ -9.78698730e-02,  -9.80529785e-02],
                        [ -4.64782715e-02,  -4.66613770e-02],
                        [  6.50024414e-03,   6.46972656e-03],
                        [  5.80749512e-02,   5.82275391e-02],
                        [  1.03240967e-01,   1.03454590e-01],
                        [  1.33880615e-01,   1.33941650e-01],
                        [  1.45965576e-01,   1.45874023e-01],
                        [  1.43249512e-01,   1.43035889e-01],
                        [  1.32812500e-01,   1.32690430e-01],
                        [  1.20391846e-01,   1.20483398e-01],
                        [  1.08154297e-01,   1.08367920e-01],
                        [  9.44824219e-02,   9.46350098e-02],
                        [  7.83081055e-02,   7.82775879e-02],
                        [  6.39038086e-02,   6.36901855e-02],
                        [  5.69458008e-02,   5.67321777e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  6.24694824e-02,   6.26525879e-02],
                        [  6.24389648e-02,   6.26525879e-02],
                        [  5.27648926e-02,   5.28259277e-02],
                        [  3.54003906e-02,   3.52478027e-02],
                        [  1.52587891e-02,   1.50146484e-02],
                        [ -6.07299805e-03,  -6.19506836e-03],
                        [ -2.59399414e-02,  -2.58178711e-02],
                        [ -3.64685059e-02,  -3.62548828e-02],
                        [ -3.22265625e-02,  -3.20434570e-02],
                        [ -1.80358887e-02,  -1.80664062e-02],
                        [ -4.39453125e-03,  -4.63867188e-03],
                        [  2.10571289e-03,   1.89208984e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -4.02832031e-03,  -3.81469727e-03],
                        [ -1.10778809e-02,  -1.08337402e-02],
                        [ -1.68151855e-02,  -1.67541504e-02],
                        [ -1.71813965e-02,  -1.73339844e-02],
                        [ -9.70458984e-03,  -9.97924805e-03],
                        [  3.20434570e-03,   3.08227539e-03],
                        [  1.66931152e-02,   1.68151855e-02],
                        [  2.68859863e-02,   2.71301270e-02],
                        [  3.15246582e-02,   3.16772461e-02],
                        [  3.04565430e-02,   3.03955078e-02],
                        [  2.75878906e-02,   2.73742676e-02],
                        [  2.82287598e-02,   2.80456543e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  3.46679688e-02,   3.48815918e-02],
                        [  3.15551758e-02,   3.17993164e-02],
                        [  2.75268555e-02,   2.75573730e-02],
                        [  2.71911621e-02,   2.70080566e-02],
                        [  2.97851562e-02,   2.95104980e-02],
                        [  3.12805176e-02,   3.11889648e-02],
                        [  2.93273926e-02,   2.94799805e-02],
                        [  2.57568359e-02,   2.60314941e-02],
                        [  2.44445801e-02,   2.46276855e-02],
                        [  2.67333984e-02,   2.66418457e-02],
                        [  2.94494629e-02,   2.91748047e-02],
                        [  2.79846191e-02,   2.77709961e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  1.53198242e-02,   1.55639648e-02],
                        [  1.19628906e-02,   1.22070312e-02],
                        [  8.48388672e-03,   8.54492188e-03],
                        [  2.62451172e-03,   2.41088867e-03],
                        [ -2.41088867e-03,  -2.68554688e-03],
                        [ -4.18090820e-03,  -4.30297852e-03],
                        [ -6.22558594e-03,  -6.07299805e-03],
                        [ -1.22985840e-02,  -1.19934082e-02],
                        [ -2.08435059e-02,  -2.06909180e-02],
                        [ -2.83813477e-02,  -2.84729004e-02],
                        [ -3.35388184e-02,  -3.38134766e-02],
                        [ -3.58581543e-02,  -3.60717773e-02],
                        [ -3.45153809e-02,  -3.44543457e-02],
                        [ -3.03649902e-02,  -3.00903320e-02],
                        [ -2.59399414e-02,  -2.56958008e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.13317871e-02,  -2.15454102e-02],
                        [ -2.13928223e-02,  -2.16674805e-02],
                        [ -2.31628418e-02,  -2.32543945e-02],
                        [ -2.54821777e-02,  -2.52990723e-02],
                        [ -2.64892578e-02,  -2.61840820e-02],
                        [ -2.59704590e-02,  -2.58178711e-02],
                        [ -2.55126953e-02,  -2.56652832e-02],
                        [ -2.57263184e-02,  -2.60314941e-02],
                        [ -2.48718262e-02,  -2.50854492e-02],
                        [ -2.21862793e-02,  -2.21252441e-02],
                        [ -1.88293457e-02,  -1.85546875e-02],
                        [ -1.47094727e-02,  -1.44653320e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.03759766e-03,  -1.28173828e-03],
                        [  4.33349609e-03,   4.05883789e-03],
                        [  4.15039062e-03,   4.08935547e-03],
                        [ -1.37329102e-03,  -1.19018555e-03],
                        [ -6.50024414e-03,  -6.19506836e-03],
                        [ -5.88989258e-03,  -5.73730469e-03],
                        [ -1.77001953e-03,  -1.92260742e-03],
                        [  0.00000000e+00,  -3.35693359e-04],
                        [  9.15527344e-05,  -1.22070312e-04],
                        [  3.50952148e-03,   3.60107422e-03],
                        [  8.81958008e-03,   9.12475586e-03],
                        [  9.85717773e-03,   1.01013184e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  9.42993164e-03,   9.15527344e-03],
                        [  1.59301758e-02,   1.56250000e-02],
                        [  2.23693848e-02,   2.23083496e-02],
                        [  2.74047852e-02,   2.76489258e-02],
                        [  3.48205566e-02,   3.51562500e-02],
                        [  4.98352051e-02,   4.99572754e-02],
                        [  7.61413574e-02,   7.59887695e-02],
                        [  1.10168457e-01,   1.09832764e-01],
                        [  1.38122559e-01,   1.37908936e-01],
                        [  1.44531250e-01,   1.44622803e-01],
                        [  1.21307373e-01,   1.21643066e-01],
                        [  6.50939941e-02,   6.53686523e-02],
                        [ -2.51464844e-02,  -2.52075195e-02],
                        [ -1.39465332e-01,  -1.39770508e-01],
                        [ -2.49847412e-01,  -2.50152588e-01],
                        [ -3.20678711e-01,  -3.20739746e-01],
                        [ -3.31817627e-01,  -3.31542969e-01],
                        [ -2.92510986e-01,  -2.92175293e-01],
                        [ -2.34436035e-01,  -2.34313965e-01],
                        [ -1.90216064e-01,  -1.90399170e-01],
                        [ -1.71051025e-01,  -1.71386719e-01],
                        [ -1.60583496e-01,  -1.60797119e-01],
                        [ -1.36505127e-01,  -1.36383057e-01],
                        [ -9.49707031e-02,  -9.46044922e-02],
                        [ -4.61730957e-02,  -4.58984375e-02],
                        [  4.24194336e-03,   4.18090820e-03],
                        [  5.52978516e-02,   5.49926758e-02],
                        [  9.93957520e-02,   9.90905762e-02],
                        [  1.25244141e-01,   1.25213623e-01],
                        [  1.31195068e-01,   1.31469727e-01],
                        [  1.25762939e-01,   1.26129150e-01],
                        [  1.18286133e-01,   1.18377686e-01],
                        [  1.13159180e-01,   1.12945557e-01],
                        [  1.07299805e-01,   1.06933594e-01],
                        [  9.44824219e-02,   9.42993164e-02],
                        [  7.86743164e-02,   7.87963867e-02],
                        [  7.29370117e-02,   7.33032227e-02],
                        [  7.97729492e-02,   8.00170898e-02],
                        [  8.58154297e-02,   8.57238770e-02],
                        [  7.93457031e-02,   7.89794922e-02],
                        [  6.12182617e-02,   6.09130859e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  1.14135742e-02,   1.17187500e-02],
                        [ -1.30615234e-02,  -1.26953125e-02],
                        [ -2.99377441e-02,  -2.98461914e-02],
                        [ -3.45458984e-02,  -3.47900391e-02],
                        [ -2.78625488e-02,  -2.82592773e-02],
                        [ -1.69982910e-02,  -1.71508789e-02],
                        [ -1.02539062e-02,  -1.00708008e-02],
                        [ -9.88769531e-03,  -9.52148438e-03],
                        [ -9.88769531e-03,  -9.64355469e-03],
                        [ -3.72314453e-03,  -3.81469727e-03],
                        [  5.82885742e-03,   5.46264648e-03],
                        [  8.27026367e-03,   7.93457031e-03],
                        [  1.22070312e-04,   1.52587891e-04],
                        [ -7.47680664e-03,  -7.14111328e-03],
                        [ -3.38745117e-03,  -3.05175781e-03],
                        [  8.54492188e-03,   8.60595703e-03],
                        [  1.73950195e-02,   1.71203613e-02],
                        [  2.05993652e-02,   2.02026367e-02],
                        [  2.29492188e-02,   2.27661133e-02],
                        [  2.65808105e-02,   2.67944336e-02],
                        [  3.01208496e-02,   3.05175781e-02],
                        [  3.20434570e-02,   3.22875977e-02],
                        [  3.09143066e-02,   3.07922363e-02],
                        [  2.71301270e-02,   2.67333984e-02],
                        [  2.38647461e-02,   2.35595703e-02],
                        [  2.39257812e-02,   2.39562988e-02],
                        [  2.80151367e-02,   2.83813477e-02],
                        [  3.56750488e-02,   3.60412598e-02],
                        [  4.37622070e-02,   4.38232422e-02],
                        [  4.75158691e-02,   4.72106934e-02],
                        [  4.55932617e-02,   4.51965332e-02],
                        [  4.04968262e-02,   4.03442383e-02],
                        [  3.39660645e-02,   3.41796875e-02],
                        [  2.47802734e-02,   2.51770020e-02],
                        [  1.33972168e-02,   1.36413574e-02],
                        [  4.88281250e-03,   4.73022461e-03],
                        [  2.59399414e-03,   2.16674805e-03],
                        [  2.47192383e-03,   2.13623047e-03],
                        [ -3.66210938e-04,  -2.74658203e-04],
                        [ -4.05883789e-03,  -3.69262695e-03],
                        [ -5.46264648e-03,  -5.09643555e-03],
                        [ -6.31713867e-03,  -6.25610352e-03],
                        [ -8.45336914e-03,  -8.78906250e-03],
                        [ -1.06811523e-02,  -1.11083984e-02],
                        [ -1.40380859e-02,  -1.41906738e-02],
                        [ -2.14233398e-02,  -2.11486816e-02],
                        [ -2.96630859e-02,  -2.92358398e-02],
                        [ -3.22875977e-02,  -3.20739746e-02],
                        [ -2.92053223e-02,  -2.93579102e-02],
                        [ -2.46276855e-02,  -2.50549316e-02],
                        [ -2.06298828e-02,  -2.09350586e-02],
                        [ -2.01416016e-02,  -2.00500488e-02],
                        [ -2.73437500e-02,  -2.69165039e-02],
                        [ -3.83605957e-02,  -3.79943848e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.05578613e-02,  -4.08935547e-02],
                        [ -3.39355469e-02,  -3.43322754e-02],
                        [ -2.56042480e-02,  -2.57263184e-02],
                        [ -1.66015625e-02,  -1.63269043e-02],
                        [ -1.00402832e-02,  -9.58251953e-03],
                        [ -6.22558594e-03,  -6.01196289e-03],
                        [ -1.86157227e-03,  -2.07519531e-03],
                        [  2.53295898e-03,   2.07519531e-03],
                        [  2.41088867e-03,   2.13623047e-03],
                        [ -2.01416016e-03,  -1.89208984e-03],
                        [ -5.24902344e-03,  -4.82177734e-03],
                        [ -6.04248047e-03,  -5.67626953e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -1.17797852e-02,  -1.21765137e-02],
                        [ -1.55029297e-02,  -1.59301758e-02],
                        [ -1.65405273e-02,  -1.66320801e-02],
                        [ -1.27563477e-02,  -1.24206543e-02],
                        [ -4.94384766e-03,  -4.51660156e-03],
                        [  2.28881836e-03,   2.47192383e-03],
                        [  7.44628906e-03,   7.20214844e-03],
                        [  1.43127441e-02,   1.38549805e-02],
                        [  2.29492188e-02,   2.26440430e-02],
                        [  2.65808105e-02,   2.67333984e-02],
                        [  2.25830078e-02,   2.30407715e-02],
                        [  1.67541504e-02,   1.70898438e-02],
                        [  1.51977539e-02,   1.51367188e-02],
                        [  2.04162598e-02,   2.00195312e-02],
                        [  3.53393555e-02,   3.49121094e-02],
                        [  6.15234375e-02,   6.14318848e-02],
                        [  9.42382812e-02,   9.46044922e-02],
                        [  1.23138428e-01,   1.23596191e-01],
                        [  1.37725830e-01,   1.37908936e-01],
                        [  1.31622314e-01,   1.31347656e-01],
                        [  1.00891113e-01,   1.00433350e-01],
                        [  4.11682129e-02,   4.08935547e-02],
                        [ -4.93774414e-02,  -4.92248535e-02],
                        [ -1.60095215e-01,  -1.59637451e-01],
                        [ -2.62847900e-01,  -2.62481689e-01],
                        [ -3.23760986e-01,  -3.23852539e-01],
                        [ -3.25988770e-01,  -3.26446533e-01],
                        [ -2.82440186e-01,  -2.82867432e-01],
                        [ -2.27172852e-01,  -2.27203369e-01],
                        [ -1.89941406e-01,  -1.89575195e-01],
                        [ -1.74804688e-01,  -1.74346924e-01],
                        [ -1.64733887e-01,  -1.64581299e-01],
                        [ -1.42913818e-01,  -1.43218994e-01],
                        [ -1.04522705e-01,  -1.05010986e-01],
                        [ -5.40466309e-02,  -5.43212891e-02],
                        [  1.64794922e-03,   1.83105469e-03],
                        [  5.78613281e-02,   5.83496094e-02],
                        [  1.08703613e-01,   1.09039307e-01],
                        [  1.42700195e-01,   1.42608643e-01],
                        [  1.52038574e-01,   1.51580811e-01],
                        [  1.44348145e-01,   1.43951416e-01],
                        [  1.34674072e-01,   1.34643555e-01],
                        [  1.26373291e-01,   1.26800537e-01],
                        [  1.13037109e-01,   1.13494873e-01],
                        [  9.55200195e-02,   9.56115723e-02],
                        [  8.27636719e-02,   8.24279785e-02],
                        [  7.90100098e-02,   7.85217285e-02],
                        [  8.07800293e-02,   8.05358887e-02],
                        [  8.14514160e-02,   8.16650391e-02],
                        [  7.27539062e-02,   7.32421875e-02],
                        [  4.90112305e-02,   4.93469238e-02],
                        [  1.35498047e-02,   1.33972168e-02],
                        [ -2.23388672e-02,  -2.28271484e-02],
                        [ -4.56542969e-02,  -4.60510254e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -3.07617188e-02,  -3.03344727e-02],
                        [ -7.47680664e-03,  -6.98852539e-03],
                        [  6.77490234e-03,   6.86645508e-03],
                        [  9.09423828e-03,   8.72802734e-03],
                        [  8.17871094e-03,   7.65991211e-03],
                        [  9.36889648e-03,   9.18579102e-03],
                        [  8.81958008e-03,   9.09423828e-03],
                        [  3.72314453e-03,   4.24194336e-03],
                        [ -1.80053711e-03,  -1.46484375e-03],
                        [ -2.50244141e-03,  -2.65502930e-03],
                        [  3.47900391e-03,   2.96020508e-03],
                        [  1.43432617e-02,   1.39465332e-02],
                        [  2.41699219e-02,   2.42309570e-02],
                        [  2.73437500e-02,   2.77709961e-02],
                        [  2.46887207e-02,   2.51464844e-02],
                        [  2.16979980e-02,   2.17895508e-02],
                        [  2.11791992e-02,   2.07824707e-02],
                        [  2.16369629e-02,   2.11181641e-02],
                        [  2.13928223e-02,   2.12097168e-02],
                        [  2.17895508e-02,   2.20642090e-02],
                        [  2.57873535e-02,   2.63061523e-02],
                        [  3.42712402e-02,   3.45764160e-02],
                        [  4.37011719e-02,   4.35180664e-02],
                        [  4.86755371e-02,   4.81567383e-02],
                        [  4.67834473e-02,   4.63867188e-02],
                        [  4.04968262e-02,   4.05883789e-02],
                        [  3.48205566e-02,   3.53088379e-02],
                        [  3.30200195e-02,   3.34777832e-02],
                        [  3.40576172e-02,   3.41186523e-02],
                        [  3.36914062e-02,   3.32946777e-02],
                        [  2.88085938e-02,   2.82897949e-02],
                        [  2.04467773e-02,   2.02941895e-02],
                        [  1.25122070e-02,   1.28173828e-02],
                        [  8.17871094e-03,   8.72802734e-03],
                        [  7.72094727e-03,   7.99560547e-03],
                        [  7.78198242e-03,   7.56835938e-03],
                        [  3.84521484e-03,   3.32641602e-03],
                        [ -4.94384766e-03,  -5.34057617e-03],
                        [ -1.49230957e-02,  -1.48315430e-02],
                        [ -2.33154297e-02,  -2.28271484e-02],
                        [ -3.00598145e-02,  -2.96020508e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.32336426e-02,  -3.36914062e-02],
                        [ -3.03039551e-02,  -3.08227539e-02],
                        [ -2.80151367e-02,  -2.81677246e-02],
                        [ -2.73742676e-02,  -2.70385742e-02],
                        [ -2.82897949e-02,  -2.77404785e-02],
                        [ -2.96630859e-02,  -2.93884277e-02],
                        [ -2.95715332e-02,  -2.98156738e-02],
                        [ -2.83508301e-02,  -2.89001465e-02],
                        [ -2.87475586e-02,  -2.90832520e-02],
                        [ -3.03955078e-02,  -3.02734375e-02],
                        [ -2.86865234e-02,  -2.81677246e-02],
                        [ -2.20031738e-02,  -2.15454102e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.23291016e-02,  -1.27868652e-02],
                        [ -1.33972168e-02,  -1.39160156e-02],
                        [ -1.66015625e-02,  -1.67236328e-02],
                        [ -1.85241699e-02,  -1.81579590e-02],
                        [ -1.58691406e-02,  -1.53503418e-02],
                        [ -1.03759766e-02,  -1.01318359e-02],
                        [ -6.37817383e-03,  -6.65283203e-03],
                        [ -4.82177734e-03,  -5.40161133e-03],
                        [ -4.85229492e-03,  -5.21850586e-03],
                        [ -7.23266602e-03,  -7.04956055e-03],
                        [ -1.08642578e-02,  -1.03454590e-02],
                        [ -1.11083984e-02,  -1.06811523e-02],
                        [ -6.83593750e-03,  -6.86645508e-03],
                        [ -2.68554688e-03,  -3.17382812e-03],
                        [ -1.25122070e-03,  -1.77001953e-03],
                        [ -9.15527344e-05,  -1.83105469e-04],
                        [  2.22778320e-03,   2.65502930e-03],
                        [  4.85229492e-03,   5.40161133e-03],
                        [  6.50024414e-03,   6.71386719e-03],
                        [  6.07299805e-03,   5.76782227e-03],
                        [  4.27246094e-03,   3.72314453e-03],
                        [  5.76782227e-03,   5.43212891e-03],
                        [  1.56860352e-02,   1.58691406e-02],
                        [  3.42712402e-02,   3.48510742e-02],
                        [  5.72814941e-02,   5.76782227e-02],
                        [  8.02001953e-02,   8.01086426e-02],
                        [  1.00402832e-01,   9.98840332e-02],
                        [  1.16027832e-01,   1.15539551e-01],
                        [  1.24938965e-01,   1.24877930e-01],
                        [  1.21887207e-01,   1.22344971e-01],
                        [  9.61303711e-02,   9.66796875e-02],
                        [  3.73229980e-02,   3.75061035e-02],
                        [ -5.32226562e-02,  -5.35583496e-02],
                        [ -1.59240723e-01,  -1.59820557e-01],
                        [ -2.55249023e-01,  -2.55554199e-01],
                        [ -3.14117432e-01,  -3.13873291e-01],
                        [ -3.19061279e-01,  -3.18511963e-01],
                        [ -2.79144287e-01,  -2.78747559e-01],
                        [ -2.27081299e-01,  -2.27172852e-01],
                        [ -1.90795898e-01,  -1.91345215e-01],
                        [ -1.71325684e-01,  -1.71813965e-01],
                        [ -1.53442383e-01,  -1.53442383e-01],
                        [ -1.27868652e-01,  -1.27380371e-01],
                        [ -9.52453613e-02,  -9.47265625e-02],
                        [ -5.71594238e-02,  -5.70068359e-02],
                        [ -1.17187500e-02,  -1.20849609e-02],
                        [  4.15954590e-02,   4.09851074e-02],
                        [  9.54589844e-02,   9.51538086e-02],
                        [  1.36566162e-01,   1.36871338e-01],
                        [  1.56341553e-01,   1.56921387e-01],
                        [  1.57684326e-01,   1.58050537e-01],
                        [  1.49871826e-01,   1.49749756e-01],
                        [  1.39923096e-01,   1.39373779e-01],
                        [  1.29943848e-01,   1.29455566e-01],
                        [  1.19140625e-01,   1.19171143e-01],
                        [  1.07025146e-01,   1.07513428e-01],
                        [  9.53369141e-02,   9.58862305e-02],
                        [  8.51745605e-02,   8.52966309e-02],
                        [  7.28454590e-02,   7.24487305e-02],
                        [  5.31005859e-02,   5.25207520e-02],
                        [  2.45971680e-02,   2.43225098e-02],
                        [ -9.46044922e-03,  -9.15527344e-03],
                        [ -4.15649414e-02,  -4.09851074e-02],
                        [ -6.17675781e-02,  -6.14013672e-02],
                        [ -6.38732910e-02,  -6.40563965e-02],
                        [ -4.94079590e-02,  -4.99572754e-02],
                        [ -2.50854492e-02,  -2.55737305e-02],
                        [ -1.67846680e-03,  -1.64794922e-03],
                        [  1.05895996e-02,   1.11083984e-02],
                        [  1.09863281e-02,   1.15051270e-02],
                        [  7.44628906e-03,   7.50732422e-03],
                        [  5.27954102e-03,   4.85229492e-03],
                        [  3.93676758e-03,   3.35693359e-03],
                        [  3.84521484e-03,   3.63159180e-03],
                        [  8.54492188e-03,   8.88061523e-03],
                        [  1.90734863e-02,   1.96838379e-02],
                        [  3.22265625e-02,   3.25622559e-02],
                        [  4.31518555e-02,   4.29382324e-02],
                        [  4.66613770e-02,   4.60815430e-02],
                        [  4.04357910e-02,   3.99780273e-02],
                        [  2.95410156e-02,   2.96020508e-02],
                        [  2.20336914e-02,   2.25830078e-02],
                        [  1.98669434e-02,   2.03857422e-02],
                        [  1.98669434e-02,   1.99279785e-02],
                        [  2.03857422e-02,   1.99279785e-02],
                        [  2.13012695e-02,   2.07214355e-02],
                        [  2.21557617e-02,   2.19726562e-02],
                        [  2.39868164e-02,   2.43225098e-02],
                        [  2.87475586e-02,   2.93579102e-02],
                        [  3.56140137e-02,   3.59497070e-02],
                        [  4.13513184e-02,   4.11071777e-02],
                        [  4.40368652e-02,   4.34570312e-02],
                        [  4.27551270e-02,   4.23278809e-02],
                        [  3.72314453e-02,   3.73535156e-02],
                        [  3.09448242e-02,   3.14941406e-02],
                        [  2.89001465e-02,   2.94189453e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  3.20739746e-02,   3.15856934e-02],
                        [  2.91748047e-02,   2.86254883e-02],
                        [  2.48107910e-02,   2.46582031e-02],
                        [  2.03247070e-02,   2.07214355e-02],
                        [  1.20239258e-02,   1.26342773e-02],
                        [ -2.71606445e-03,  -2.44140625e-03],
                        [ -1.93176270e-02,  -1.95922852e-02],
                        [ -3.07922363e-02,  -3.14025879e-02],
                        [ -3.46069336e-02,  -3.50036621e-02],
                        [ -3.30200195e-02,  -3.28674316e-02],
                        [ -2.95104980e-02,  -2.89306641e-02],
                        [ -2.57873535e-02,  -2.52990723e-02],
                        [ -2.16979980e-02,  -2.17285156e-02],
                        [ -1.76086426e-02,  -1.80969238e-02],
                        [ -1.49536133e-02,  -1.55029297e-02],
                        [ -1.53503418e-02,  -1.54724121e-02],
                        [ -1.92565918e-02,  -1.88598633e-02],
                        [ -2.49633789e-02,  -2.43530273e-02],
                        [ -2.85339355e-02,  -2.82592773e-02],
                        [ -2.61840820e-02,  -2.65197754e-02],
                        [ -1.86462402e-02,  -1.92565918e-02],
                        [ -1.19323730e-02,  -1.22680664e-02],
                        [ -1.11694336e-02,  -1.09863281e-02],
                        [ -1.52893066e-02,  -1.47399902e-02],
                        [ -1.97753906e-02,  -1.92871094e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.62048340e-02,  -1.67541504e-02],
                        [ -9.03320312e-03,  -9.58251953e-03],
                        [ -4.24194336e-03,  -4.30297852e-03],
                        [ -1.77001953e-03,  -1.34277344e-03],
                        [  2.59399414e-03,   3.17382812e-03],
                        [  7.17163086e-03,   7.41577148e-03],
                        [  5.15747070e-03,   4.82177734e-03],
                        [ -3.23486328e-03,  -3.87573242e-03],
                        [ -1.11389160e-02,  -1.15051270e-02],
                        [ -1.55029297e-02,  -1.52587891e-02],
                        [ -1.63879395e-02,  -1.57775879e-02],
                        [ -1.22985840e-02,  -1.18713379e-02],
                        [ -5.31005859e-03,  -5.37109375e-03],
                        [  3.35693359e-04,  -2.13623047e-04],
                        [  5.92041016e-03,   5.37109375e-03],
                        [  1.34277344e-02,   1.33972168e-02],
                        [  1.77917480e-02,   1.83105469e-02],
                        [  1.65405273e-02,   1.71203613e-02],
                        [  1.69677734e-02,   1.71508789e-02],
                        [  2.45056152e-02,   2.41394043e-02],
                        [  3.50036621e-02,   3.43933105e-02],
                        [  4.54711914e-02,   4.51354980e-02],
                        [  6.02722168e-02,   6.05163574e-02],
                        [  8.26721191e-02,   8.32824707e-02],
                        [  1.08306885e-01,   1.08703613e-01],
                        [  1.28173828e-01,   1.28051758e-01],
                        [  1.30645752e-01,   1.30096436e-01],
                        [  1.03210449e-01,   1.02691650e-01],
                        [  3.98254395e-02,   3.97949219e-02],
                        [ -5.37109375e-02,  -5.32226562e-02],
                        [ -1.61254883e-01,  -1.60644531e-01],
                        [ -2.58666992e-01,  -2.58514404e-01],
                        [ -3.17535400e-01,  -3.17932129e-01],
                        [ -3.18725586e-01,  -3.19366455e-01],
                        [ -2.71118164e-01,  -2.71423340e-01],
                        [ -2.09899902e-01,  -2.09594727e-01],
                        [ -1.68212891e-01,  -1.67572021e-01],
                        [ -1.51947021e-01,  -1.51519775e-01],
                        [ -1.45935059e-01,  -1.46087646e-01],
                        [ -1.36199951e-01,  -1.36779785e-01],
                        [ -1.18804932e-01,  -1.19323730e-01],
                        [ -9.26818848e-02,  -9.26818848e-02],
                        [ -5.34362793e-02,  -5.29174805e-02],
                        [  2.86865234e-03,   3.44848633e-03],
                        [  7.08923340e-02,   7.10144043e-02],
                        [  1.33941650e-01,   1.33544922e-01],
                        [  1.74011230e-01,   1.73400879e-01],
                        [  1.84295654e-01,   1.84020996e-01],
                        [  1.72027588e-01,   1.72332764e-01],
                        [  1.51306152e-01,   1.51947021e-01],
                        [  1.34765625e-01,   1.35162354e-01],
                        [  1.26586914e-01,   1.26403809e-01],
                        [  1.20513916e-01,   1.19934082e-01],
                        [  1.07910156e-01,   1.07421875e-01],
                        [  8.68835449e-02,   8.69445801e-02],
                        [  5.99670410e-02,   6.05163574e-02],
                        [  2.73437500e-02,   2.78930664e-02],
                        [ -1.08032227e-02,  -1.07421875e-02],
                        [ -4.72106934e-02,  -4.76684570e-02],
                        [ -6.92443848e-02,  -6.98547363e-02],
                        [ -7.00683594e-02,  -7.03125000e-02],
                        [ -5.42907715e-02,  -5.39245605e-02],
                        [ -3.14025879e-02,  -3.07922363e-02],
                        [ -9.15527344e-03,  -8.81958008e-03],
                        [  6.46972656e-03,   6.25610352e-03],
                        [  1.19934082e-02,   1.13830566e-02],
                        [  9.58251953e-03,   9.12475586e-03],
                        [  5.24902344e-03,   5.31005859e-03],
                        [  1.95312500e-03,   2.50244141e-03],
                        [ -3.05175781e-05,   5.18798828e-04],
                        [  2.89916992e-03,   2.96020508e-03],
                        [  1.52282715e-02,   1.47399902e-02],
                        [  3.33557129e-02,   3.27453613e-02],
                        [  4.81872559e-02,   4.79736328e-02],
                        [  5.44433594e-02,   5.48095703e-02],
                        [  5.09033203e-02,   5.15441895e-02],
                        [  3.94287109e-02,   3.97644043e-02],
                        [  2.76184082e-02,   2.73437500e-02],
                        [  2.27355957e-02,   2.21252441e-02],
                        [  2.22778320e-02,   2.18505859e-02],
                        [  1.99279785e-02,   2.00500488e-02],
                        [  1.65710449e-02,   1.71203613e-02],
                        [  1.53808594e-02,   1.59301758e-02],
                        [  1.53503418e-02,   1.54113770e-02],
                        [  1.77307129e-02,   1.72119141e-02],
                        [  2.76184082e-02,   2.70080566e-02],
                        [  4.20227051e-02,   4.19006348e-02],
                        [  5.02319336e-02,   5.06286621e-02],
                        [  4.85534668e-02,   4.91638184e-02],
                        [  4.24499512e-02,   4.27856445e-02],
                        [  3.59191895e-02,   3.56445312e-02],
                        [  3.03039551e-02,   2.96630859e-02],
                        [  2.79846191e-02,   2.75573730e-02],
                        [  2.84118652e-02,   2.85949707e-02],
                        [  2.72827148e-02,   2.78625488e-02],
                        [  2.40173340e-02,   2.45056152e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.77917480e-02,   1.72729492e-02],
                        [  7.69042969e-03,   7.11059570e-03],
                        [ -6.40869141e-03,  -6.53076172e-03],
                        [ -1.86767578e-02,  -1.82189941e-02],
                        [ -2.79235840e-02,  -2.73132324e-02],
                        [ -3.39355469e-02,  -3.36914062e-02],
                        [ -3.38745117e-02,  -3.41796875e-02],
                        [ -2.85644531e-02,  -2.91748047e-02],
                        [ -2.43835449e-02,  -2.47802734e-02],
                        [ -2.44750977e-02,  -2.42919922e-02],
                        [ -2.46276855e-02,  -2.40173340e-02],
                        [ -2.20336914e-02,  -2.15454102e-02],
                        [ -2.06604004e-02,  -2.06909180e-02],
                        [ -2.31628418e-02,  -2.37121582e-02],
                        [ -2.67944336e-02,  -2.73437500e-02],
                        [ -3.04870605e-02,  -3.05786133e-02],
                        [ -3.53698730e-02,  -3.49121094e-02],
                        [ -3.69567871e-02,  -3.63464355e-02],
                        [ -3.02429199e-02,  -2.99987793e-02],
                        [ -2.01416016e-02,  -2.04772949e-02],
                        [ -1.46484375e-02,  -1.52893066e-02],
                        [ -1.28784180e-02,  -1.32446289e-02],
                        [ -1.01013184e-02,  -9.88769531e-03],
                        [ -7.41577148e-03,  -6.80541992e-03],
                        [ -7.53784180e-03,  -7.08007812e-03],
                        [ -9.30786133e-03,  -9.36889648e-03],
                        [ -1.06201172e-02,  -1.11694336e-02],
                        [ -9.82666016e-03,  -1.03759766e-02],
                        [ -6.16455078e-03,  -6.22558594e-03],
                        [ -4.05883789e-03,  -3.57055664e-03],
                        [ -8.69750977e-03,  -8.11767578e-03],
                        [ -1.49536133e-02,  -1.47705078e-02],
                        [ -1.28173828e-02,  -1.31835938e-02],
                        [ -3.78417969e-03,  -4.39453125e-03],
                        [  1.06811523e-03,   7.32421875e-04],
                        [ -1.43432617e-03,  -1.19018555e-03],
                        [ -2.89916992e-03,  -2.25830078e-03],
                        [  2.74658203e-03,   3.17382812e-03],
                        [  1.09863281e-02,   1.08642578e-02],
                        [  1.34887695e-02,   1.29089355e-02],
                        [  8.45336914e-03,   7.93457031e-03],
                        [  3.57055664e-03,   3.50952148e-03],
                        [  7.62939453e-03,   8.11767578e-03],
                        [  2.05993652e-02,   2.12097168e-02],
                        [  3.66821289e-02,   3.68347168e-02],
                        [  5.55114746e-02,   5.50842285e-02],
                        [  8.09326172e-02,   8.03222656e-02],
                        [  1.10748291e-01,   1.10473633e-01],
                        [  1.33880615e-01,   1.34124756e-01],
                        [  1.36688232e-01,   1.37329102e-01],
                        [  1.09283447e-01,   1.09741211e-01],
                        [  4.78515625e-02,   4.76989746e-02],
                        [ -4.44946289e-02,  -4.51049805e-02],
                        [ -1.54418945e-01,  -1.54907227e-01],
                        [ -2.55584717e-01,  -2.55584717e-01],
                        [ -3.16497803e-01,  -3.15979004e-01],
                        [ -3.19824219e-01,  -3.19244385e-01],
                        [ -2.76245117e-01,  -2.76092529e-01],
                        [ -2.17468262e-01,  -2.17926025e-01],
                        [ -1.73889160e-01,  -1.74499512e-01],
                        [ -1.55517578e-01,  -1.55792236e-01],
                        [ -1.51092529e-01,  -1.50756836e-01],
                        [ -1.42883301e-01,  -1.42272949e-01],
                        [ -1.22711182e-01,  -1.22314453e-01],
                        [ -9.16442871e-02,  -9.17968750e-02],
                        [ -4.94995117e-02,  -5.01098633e-02],
                        [  6.43920898e-03,   5.95092773e-03],
                        [  7.25708008e-02,   7.26013184e-02],
                        [  1.34216309e-01,   1.34765625e-01],
                        [  1.74591064e-01,   1.75140381e-01],
                        [  1.87774658e-01,   1.87866211e-01],
                        [  1.82067871e-01,   1.81610107e-01],
                        [  1.69555664e-01,   1.68945312e-01],
                        [  1.55914307e-01,   1.55670166e-01],
                        [  1.39831543e-01,   1.40197754e-01],
                        [  1.19201660e-01,   1.19842529e-01],
                        [  9.41162109e-02,   9.44824219e-02],
                        [  6.50634766e-02,   6.48498535e-02],
                        [  3.17993164e-02,   3.11889648e-02],
                        [ -4.54711914e-03,  -5.03540039e-03],
                        [ -3.88793945e-02,  -3.87878418e-02],
                        [ -6.20117188e-02,  -6.14624023e-02],
                        [ -6.51550293e-02,  -6.46057129e-02],
                        [ -4.87976074e-02,  -4.87365723e-02],
                        [ -2.59704590e-02,  -2.64587402e-02],
                        [ -1.07727051e-02,  -1.13830566e-02],
                        [ -4.48608398e-03,  -4.69970703e-03],
                        [  1.00708008e-03,   1.37329102e-03],
                        [  8.05664062e-03,   8.69750977e-03],
                        [  1.11083984e-02,   1.14440918e-02],
                        [  9.18579102e-03,   8.91113281e-03],
                        [  8.57543945e-03,   7.93457031e-03],
                        [  1.25732422e-02,   1.21459961e-02],
                        [  1.92260742e-02,   1.93481445e-02],
                        [  2.71911621e-02,   2.77404785e-02],
                        [  3.63464355e-02,   3.68957520e-02],
                        [  4.44641113e-02,   4.44946289e-02],
                        [  4.74243164e-02,   4.69055176e-02],
                        [  4.25415039e-02,   4.19616699e-02],
                        [  3.21655273e-02,   3.20129395e-02],
                        [  2.22778320e-02,   2.26745605e-02],
                        [  1.60522461e-02,   1.66931152e-02],
                        [  1.17187500e-02,   1.20239258e-02],
                        [  8.20922852e-03,   7.90405273e-03],
                        [  8.81958008e-03,   8.17871094e-03],
                        [  1.53808594e-02,   1.49536133e-02],
                        [  2.44140625e-02,   2.45666504e-02],
                        [  3.25927734e-02,   3.31726074e-02],
                        [  3.94897461e-02,   4.00085449e-02],
                        [  4.39758301e-02,   4.40063477e-02],
                        [  4.40368652e-02,   4.35180664e-02],
                        [  4.07714844e-02,   4.01916504e-02],
                        [  3.77807617e-02,   3.76892090e-02],
                        [  3.72009277e-02,   3.76281738e-02],
                        [  3.84216309e-02,   3.90014648e-02],
                        [  3.91845703e-02,   3.94592285e-02],
                        [  3.69873047e-02,   3.67126465e-02],
                        [  3.03039551e-02,   2.96630859e-02],
                        [  1.99890137e-02,   1.95617676e-02],
                        [  8.94165039e-03,   9.15527344e-03],
                        [  1.83105469e-04,   7.93457031e-04],
                        [ -4.79125977e-03,  -4.30297852e-03],
                        [ -7.23266602e-03,  -7.29370117e-03],
                        [ -1.03759766e-02,  -1.09252930e-02],
                        [ -1.48620605e-02,  -1.54418945e-02],
                        [ -1.79138184e-02,  -1.80358887e-02],
                        [ -1.93786621e-02,  -1.89208984e-02],
                        [ -2.27355957e-02,  -2.21252441e-02],
                        [ -2.89001465e-02,  -2.86865234e-02],
                        [ -3.45153809e-02,  -3.48510742e-02],
                        [ -3.73840332e-02,  -3.80249023e-02],
                        [ -3.79333496e-02,  -3.82995605e-02],
                        [ -3.44543457e-02,  -3.42712402e-02],
                        [ -2.56652832e-02,  -2.50549316e-02],
                        [ -1.81884766e-02,  -1.77001953e-02],
                        [ -2.10876465e-02,  -2.11791992e-02],
                        [ -3.16467285e-02,  -3.22265625e-02],
                        [ -3.80859375e-02,  -3.86352539e-02],
                        [ -3.58886719e-02,  -3.59497070e-02],
                        [ -3.00598145e-02,  -2.96020508e-02],
                        [ -2.41699219e-02,  -2.35595703e-02],
                        [ -1.76391602e-02,  -1.74255371e-02],
                        [ -1.17492676e-02,  -1.21154785e-02],
                        [ -1.02844238e-02,  -1.09252930e-02],
                        [ -1.38549805e-02,  -1.41601562e-02],
                        [ -1.74255371e-02,  -1.71508789e-02],
                        [ -1.53503418e-02,  -1.47399902e-02],
                        [ -7.47680664e-03,  -7.01904297e-03],
                        [  3.35693359e-04,   2.44140625e-04],
                        [  2.22778320e-03,   1.64794922e-03],
                        [ -1.25122070e-03,  -1.77001953e-03],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [ -6.19506836e-03,  -5.67626953e-03],
                        [ -8.05664062e-03,  -7.44628906e-03],
                        [ -1.19018555e-02,  -1.17187500e-02],
                        [ -1.37023926e-02,  -1.41296387e-02],
                        [ -1.00097656e-02,  -1.06506348e-02],
                        [ -3.57055664e-03,  -3.84521484e-03],
                        [  1.34277344e-03,   1.64794922e-03],
                        [  4.15039062e-03,   4.76074219e-03],
                        [  6.10351562e-03,   6.53076172e-03],
                        [  9.09423828e-03,   8.94165039e-03],
                        [  1.57775879e-02,   1.51672363e-02],
                        [  2.65197754e-02,   2.60009766e-02],
                        [  3.99475098e-02,   3.99780273e-02],
                        [  5.80139160e-02,   5.85327148e-02],
                        [  8.45642090e-02,   8.51440430e-02],
                        [  1.16760254e-01,   1.16912842e-01],
                        [  1.42089844e-01,   1.41662598e-01],
                        [  1.45050049e-01,   1.44439697e-01],
                        [  1.15814209e-01,   1.15570068e-01],
                        [  5.21850586e-02,   5.24902344e-02],
                        [ -4.20837402e-02,  -4.14428711e-02],
                        [ -1.54296875e-01,  -1.53900146e-01],
                        [ -2.58636475e-01,  -2.58819580e-01],
                        [ -3.22570801e-01,  -3.23181152e-01],
                        [ -3.26812744e-01,  -3.27301025e-01],
                        [ -2.81280518e-01,  -2.81219482e-01],
                        [ -2.18231201e-01,  -2.17681885e-01],
                        [ -1.68640137e-01,  -1.68090820e-01],
                        [ -1.43981934e-01,  -1.43890381e-01],
                        [ -1.35467529e-01,  -1.35925293e-01],
                        [ -1.27716064e-01,  -1.28326416e-01],
                        [ -1.12579346e-01,  -1.12823486e-01],
                        [ -8.89282227e-02,  -8.85620117e-02],
                        [ -5.43518066e-02,  -5.37109375e-02],
                        [ -4.91333008e-03,  -4.54711914e-03],
                        [  5.74035645e-02,   5.71899414e-02],
                        [  1.21337891e-01,   1.20697021e-01],
                        [  1.71295166e-01,   1.70837402e-01],
                        [  1.95983887e-01,   1.96044922e-01],
                        [  1.95129395e-01,   1.95678711e-01],
                        [  1.79870605e-01,   1.80419922e-01],
                        [  1.62261963e-01,   1.62322998e-01],
                        [  1.43859863e-01,   1.43341064e-01],
                        [  1.17553711e-01,   1.16943359e-01],
                        [  7.95288086e-02,   7.93457031e-02],
                        [  3.37219238e-02,   3.41186523e-02],
                        [ -1.19018555e-02,  -1.12915039e-02],
                        [ -4.69665527e-02,  -4.66308594e-02],
                        [ -6.10046387e-02,  -6.12182617e-02],
                        [ -5.24291992e-02,  -5.30700684e-02],
                        [ -3.41796875e-02,  -3.46374512e-02],
                        [ -2.15148926e-02,  -2.13928223e-02],
                        [ -1.61437988e-02,  -1.55639648e-02],
                        [ -1.04064941e-02,  -9.88769531e-03],
                        [ -2.04467773e-03,  -2.01416016e-03],
                        [  5.61523438e-03,   5.12695312e-03],
                        [  1.16882324e-02,   1.10778809e-02],
                        [  1.70593262e-02,   1.68762207e-02],
                        [  2.10876465e-02,   2.14843750e-02],
                        [  2.38647461e-02,   2.45056152e-02],
                        [  2.76489258e-02,   2.79541016e-02],
                        [  3.31726074e-02,   3.28674316e-02],
                        [  3.86047363e-02,   3.79943848e-02],
                        [  4.32739258e-02,   4.28466797e-02],
                        [  4.68750000e-02,   4.70275879e-02],
                        [  4.58984375e-02,   4.65087891e-02],
                        [  3.72619629e-02,   3.77807617e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  1.69677734e-02,   1.64184570e-02],
                        [  1.42517090e-02,   1.36718750e-02],
                        [  1.30615234e-02,   1.29394531e-02],
                        [  1.23291016e-02,   1.27563477e-02],
                        [  1.45874023e-02,   1.51977539e-02],
                        [  1.97448730e-02,   2.00500488e-02],
                        [  2.51464844e-02,   2.48413086e-02],
                        [  3.09143066e-02,   3.02734375e-02],
                        [  3.87573242e-02,   3.83605957e-02],
                        [  4.65393066e-02,   4.67224121e-02],
                        [  4.98046875e-02,   5.03845215e-02],
                        [  4.72412109e-02,   4.77294922e-02],
                        [  4.23278809e-02,   4.22973633e-02],
                        [  3.98559570e-02,   3.93066406e-02],
                        [  4.03747559e-02,   3.97949219e-02],
                        [  3.81469727e-02,   3.80554199e-02],
                        [  2.78015137e-02,   2.82897949e-02],
                        [  1.33056641e-02,   1.39160156e-02],
                        [  4.66918945e-03,   4.88281250e-03],
                        [  5.03540039e-03,   4.69970703e-03],
                        [  7.75146484e-03,   7.14111328e-03],
                        [  6.62231445e-03,   6.22558594e-03],
                        [  2.07519531e-03,   2.28881836e-03],
                        [ -2.59399414e-03,  -1.95312500e-03],
                        [ -5.31005859e-03,  -4.82177734e-03],
                        [ -6.83593750e-03,  -6.92749023e-03],
                        [ -1.16882324e-02,  -1.22375488e-02],
                        [ -2.38342285e-02,  -2.43835449e-02],
                        [ -3.92761230e-02,  -3.93676758e-02],
                        [ -4.69360352e-02,  -4.64477539e-02],
                        [ -4.05883789e-02,  -3.99475098e-02],
                        [ -2.65502930e-02,  -2.63366699e-02],
                        [ -1.61743164e-02,  -1.65710449e-02],
                        [ -1.52587891e-02,  -1.58996582e-02],
                        [ -2.20336914e-02,  -2.23388672e-02],
                        [ -2.98767090e-02,  -2.96325684e-02],
                        [ -3.20129395e-02,  -3.14025879e-02],
                        [ -2.69470215e-02,  -2.64587402e-02],
                        [ -1.95312500e-02,  -1.96533203e-02],
                        [ -1.66931152e-02,  -1.73034668e-02],
                        [ -2.19421387e-02,  -2.24609375e-02],
                        [ -2.99682617e-02,  -2.99987793e-02],
                        [ -2.93884277e-02,  -2.89001465e-02],
                        [ -1.66015625e-02,  -1.60217285e-02],
                        [ -1.92260742e-03,  -1.73950195e-03],
                        [  4.42504883e-03,   3.99780273e-03],
                        [  3.60107422e-03,   2.96020508e-03],
                        [  5.79833984e-04,   3.05175781e-04],
                        [ -4.05883789e-03,  -3.75366211e-03],
                        [ -9.33837891e-03,  -8.72802734e-03],
                        [ -1.17797852e-02,  -1.13525391e-02],
                        [ -1.16271973e-02,  -1.17797852e-02],
                        [ -1.27868652e-02,  -1.33972168e-02],
                        [ -1.51367188e-02,  -1.56555176e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -5.58471680e-03,  -5.06591797e-03],
                        [  6.53076172e-03,   7.11059570e-03],
                        [  1.51062012e-02,   1.52282715e-02],
                        [  1.39160156e-02,   1.34582520e-02],
                        [  4.24194336e-03,   3.60107422e-03],
                        [ -4.97436523e-03,  -5.21850586e-03],
                        [ -4.60815430e-03,  -4.30297852e-03],
                        [  6.65283203e-03,   7.26318359e-03],
                        [  2.40783691e-02,   2.44750977e-02],
                        [  4.49218750e-02,   4.47387695e-02],
                        [  7.01904297e-02,   6.95800781e-02],
                        [  9.92126465e-02,   9.87243652e-02],
                        [  1.25854492e-01,   1.25915527e-01],
                        [  1.40808105e-01,   1.41357422e-01],
                        [  1.35711670e-01,   1.36291504e-01],
                        [  1.04949951e-01,   1.05072021e-01],
                        [  4.52575684e-02,   4.47998047e-02],
                        [ -4.21752930e-02,  -4.27856445e-02],
                        [ -1.46911621e-01,  -1.47155762e-01],
                        [ -2.45941162e-01,  -2.45574951e-01],
                        [ -3.08380127e-01,  -3.07769775e-01],
                        [ -3.13537598e-01,  -3.13201904e-01],
                        [ -2.69348145e-01,  -2.69561768e-01],
                        [ -2.08862305e-01,  -2.09472656e-01],
                        [ -1.65252686e-01,  -1.65740967e-01],
                        [ -1.49291992e-01,  -1.49200439e-01],
                        [ -1.47766113e-01,  -1.47186279e-01],
                        [ -1.41235352e-01,  -1.40686035e-01],
                        [ -1.21856689e-01,  -1.21795654e-01],
                        [ -9.28649902e-02,  -9.33532715e-02],
                        [ -5.60607910e-02,  -5.66711426e-02],
                        [ -7.35473633e-03,  -7.56835938e-03],
                        [  5.42602539e-02,   5.46264648e-02],
                        [  1.19812012e-01,   1.20422363e-01],
                        [  1.73675537e-01,   1.74011230e-01],
                        [  2.02850342e-01,   2.02606201e-01],
                        [  2.04986572e-01,   2.04376221e-01],
                        [  1.89483643e-01,   1.89025879e-01],
                        [  1.66656494e-01,   1.66778564e-01],
                        [  1.37298584e-01,   1.37878418e-01],
                        [  9.65576172e-02,   9.70764160e-02],
                        [  4.50744629e-02,   4.51049805e-02],
                        [ -7.23266602e-03,  -7.72094727e-03],
                        [ -4.62036133e-02,  -4.68139648e-02],
                        [ -6.17675781e-02,  -6.19506836e-02],
                        [ -5.40466309e-02,  -5.36499023e-02],
                        [ -3.33251953e-02,  -3.27148438e-02],
                        [ -1.36108398e-02,  -1.33056641e-02],
                        [ -3.05175781e-03,  -3.32641602e-03],
                        [ -1.22070312e-04,  -7.32421875e-04],
                        [  6.71386719e-04,   2.44140625e-04],
                        [  2.31933594e-03,   2.47192383e-03],
                        [  5.70678711e-03,   6.31713867e-03],
                        [  1.08032227e-02,   1.12915039e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.77001953e-02,   1.71813965e-02],
                        [  2.14843750e-02,   2.08740234e-02],
                        [  3.16467285e-02,   3.14941406e-02],
                        [  4.66003418e-02,   4.70581055e-02],
                        [  5.93872070e-02,   6.00280762e-02],
                        [  6.53076172e-02,   6.55517578e-02],
                        [  6.25610352e-02,   6.22558594e-02],
                        [  5.09338379e-02,   5.03234863e-02],
                        [  3.51562500e-02,   3.47290039e-02],
                        [  2.26745605e-02,   2.28271484e-02],
                        [  1.46484375e-02,   1.52587891e-02],
                        [  7.04956055e-03,   7.53784180e-03],
                        [  1.19018555e-03,   1.12915039e-03],
                        [  3.93676758e-03,   3.38745117e-03],
                        [  1.61743164e-02,   1.55944824e-02],
                        [  2.92968750e-02,   2.91748047e-02],
                        [  3.57666016e-02,   3.62243652e-02],
                        [  3.75976562e-02,   3.82080078e-02],
                        [  4.05578613e-02,   4.08020020e-02],
                        [  4.40368652e-02,   4.37011719e-02],
                        [  4.25720215e-02,   4.19311523e-02],
                        [  3.66210938e-02,   3.62548828e-02],
                        [  3.44543457e-02,   3.46679688e-02],
                        [  3.98864746e-02,   4.05273438e-02],
                        [  4.57763672e-02,   4.62646484e-02],
                        [  4.35485840e-02,   4.34570312e-02],
                        [  3.28063965e-02,   3.22570801e-02],
                        [  1.91650391e-02,   1.86157227e-02],
                        [  7.53784180e-03,   7.44628906e-03],
                        [ -2.74658203e-04,   1.83105469e-04],
                        [ -4.51660156e-03,  -3.90625000e-03],
                        [ -6.31713867e-03,  -6.10351562e-03],
                        [ -8.08715820e-03,  -8.45336914e-03],
                        [ -1.20544434e-02,  -1.26647949e-02],
                        [ -1.71508789e-02,  -1.74560547e-02],
                        [ -2.07519531e-02,  -2.05383301e-02],
                        [ -2.33154297e-02,  -2.27050781e-02],
                        [ -2.74353027e-02,  -2.69775391e-02],
                        [ -3.25622559e-02,  -3.26843262e-02],
                        [ -3.48815918e-02,  -3.54919434e-02],
                        [ -3.26232910e-02,  -3.31420898e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -1.82495117e-02,  -1.77612305e-02],
                        [ -9.03320312e-03,  -8.45336914e-03],
                        [ -5.58471680e-03,  -5.40161133e-03],
                        [ -1.09863281e-02,  -1.13830566e-02],
                        [ -1.95312500e-02,  -2.01416016e-02],
                        [ -2.34985352e-02,  -2.38037109e-02],
                        [ -2.23388672e-02,  -2.20642090e-02],
                        [ -2.10876465e-02,  -2.04467773e-02],
                        [ -2.12707520e-02,  -2.08740234e-02],
                        [ -1.87072754e-02,  -1.88293457e-02],
                        [ -1.14135742e-02,  -1.19934082e-02],
                        [ -4.73022461e-03,  -5.24902344e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.26953125e-02,  -1.21765137e-02],
                        [ -2.10876465e-02,  -2.05078125e-02],
                        [ -2.34069824e-02,  -2.32849121e-02],
                        [ -1.82189941e-02,  -1.86157227e-02],
                        [ -9.15527344e-03,  -9.76562500e-03],
                        [ -9.76562500e-04,  -1.25122070e-03],
                        [  3.66210938e-03,   3.96728516e-03],
                        [  5.21850586e-03,   5.85937500e-03],
                        [  5.52368164e-03,   5.88989258e-03],
                        [  4.33349609e-03,   4.11987305e-03],
                        [ -7.32421875e-04,  -1.31225586e-03],
                        [ -8.85009766e-03,  -9.33837891e-03],
                        [ -1.42517090e-02,  -1.42211914e-02],
                        [ -1.33972168e-02,  -1.28784180e-02],
                        [ -8.42285156e-03,  -7.84301758e-03],
                        [  3.35693359e-04,   4.27246094e-04],
                        [  1.45874023e-02,   1.41296387e-02],
                        [  2.99987793e-02,   2.94189453e-02],
                        [  4.04968262e-02,   4.02526855e-02],
                        [  4.87060547e-02,   4.90417480e-02],
                        [  6.17675781e-02,   6.24084473e-02],
                        [  8.12377930e-02,   8.16040039e-02],
                        [  1.03637695e-01,   1.03424072e-01],
                        [  1.24359131e-01,   1.23748779e-01],
                        [  1.34338379e-01,   1.33880615e-01],
                        [  1.17919922e-01,   1.18011475e-01],
                        [  6.18286133e-02,   6.23779297e-02],
                        [ -3.24401855e-02,  -3.19213867e-02],
                        [ -1.45050049e-01,  -1.44989014e-01],
                        [ -2.44476318e-01,  -2.44934082e-01],
                        [ -3.00903320e-01,  -3.01513672e-01],
                        [ -3.01635742e-01,  -3.01818848e-01],
                        [ -2.58575439e-01,  -2.58209229e-01],
                        [ -2.02178955e-01,  -2.01538086e-01],
                        [ -1.62322998e-01,  -1.61987305e-01],
                        [ -1.48223877e-01,  -1.48468018e-01],
                        [ -1.46118164e-01,  -1.46728516e-01],
                        [ -1.38763428e-01,  -1.39190674e-01],
                        [ -1.21978760e-01,  -1.21856689e-01],
                        [ -9.96704102e-02,  -9.91210938e-02],
                        [ -7.06787109e-02,  -7.01293945e-02],
                        [ -2.71301270e-02,  -2.70996094e-02],
                        [  3.57360840e-02,   3.52172852e-02],
                        [  1.10839844e-01,   1.10260010e-01],
                        [  1.79290771e-01,   1.79138184e-01],
                        [  2.20092773e-01,   2.20489502e-01],
                        [  2.24304199e-01,   2.24884033e-01],
                        [  2.00500488e-01,   2.00805664e-01],
                        [  1.64306641e-01,   1.64031982e-01],
                        [  1.23107910e-01,   1.22497559e-01],
                        [  7.47070312e-02,   7.42797852e-02],
                        [  2.05688477e-02,   2.07519531e-02],
                        [ -2.58483887e-02,  -2.52990723e-02],
                        [ -4.94689941e-02,  -4.89807129e-02],
                        [ -4.81567383e-02,  -4.81262207e-02],
                        [ -3.29895020e-02,  -3.34777832e-02],
                        [ -1.72119141e-02,  -1.77917480e-02],
                        [ -8.14819336e-03,  -8.27026367e-03],
                        [ -4.85229492e-03,  -4.42504883e-03],
                        [ -2.25830078e-03,  -1.67846680e-03],
                        [  1.22070312e-03,   1.46484375e-03],
                        [  3.17382812e-03,   2.86865234e-03],
                        [  3.20434570e-03,   2.59399414e-03],
                        [  4.82177734e-03,   4.42504883e-03],
                        [  1.13525391e-02,   1.15356445e-02],
                        [  2.30407715e-02,   2.36206055e-02],
                        [  3.86047363e-02,   3.90930176e-02],
                        [  5.63354492e-02,   5.62744141e-02],
                        [  7.22656250e-02,   7.17468262e-02],
                        [  8.15429688e-02,   8.09936523e-02],
                        [  8.14819336e-02,   8.13598633e-02],
                        [  7.18383789e-02,   7.22656250e-02],
                        [  5.50231934e-02,   5.56335449e-02],
                        [  3.61633301e-02,   3.64074707e-02],
                        [  1.91040039e-02,   1.87683105e-02],
                        [  4.97436523e-03,   4.36401367e-03],
                        [ -3.17382812e-03,  -3.50952148e-03],
                        [ -2.74658203e-04,  -6.10351562e-05],
                        [  1.22375488e-02,   1.28173828e-02],
                        [  2.54211426e-02,   2.58789062e-02],
                        [  3.31115723e-02,   3.30200195e-02],
                        [  3.64379883e-02,   3.59191895e-02],
                        [  3.74450684e-02,   3.69262695e-02],
                        [  3.71704102e-02,   3.71093750e-02],
                        [  3.83300781e-02,   3.87878418e-02],
                        [  4.16259766e-02,   4.22058105e-02],
                        [  4.34265137e-02,   4.36096191e-02],
                        [  4.22058105e-02,   4.18701172e-02],
                        [  4.11071777e-02,   4.05273438e-02],
                        [  4.16870117e-02,   4.13513184e-02],
                        [  4.02832031e-02,   4.05273438e-02],
                        [  3.31420898e-02,   3.37219238e-02],
                        [  2.16674805e-02,   2.20947266e-02],
                        [  9.97924805e-03,   9.88769531e-03],
                        [ -2.44140625e-04,  -7.93457031e-04],
                        [ -9.12475586e-03,  -9.61303711e-03],
                        [ -1.59301758e-02,  -1.59606934e-02],
                        [ -2.09655762e-02,  -2.04772949e-02],
                        [ -2.57873535e-02,  -2.52075195e-02],
                        [ -3.01208496e-02,  -2.99377441e-02],
                        [ -3.12500000e-02,  -3.16162109e-02],
                        [ -2.87780762e-02,  -2.93884277e-02],
                        [ -2.56958008e-02,  -2.59704590e-02],
                        [ -2.34985352e-02,  -2.32543945e-02],
                        [ -2.14538574e-02,  -2.08740234e-02],
                        [ -1.96838379e-02,  -1.92565918e-02],
                        [ -1.88293457e-02,  -1.89819336e-02],
                        [ -1.87683105e-02,  -1.93481445e-02],
                        [ -1.92565918e-02,  -1.97448730e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.81274414e-02,  -1.76391602e-02],
                        [ -1.55029297e-02,  -1.49536133e-02],
                        [ -1.35803223e-02,  -1.34582520e-02],
                        [ -1.32751465e-02,  -1.37023926e-02],
                        [ -1.44958496e-02,  -1.50756836e-02],
                        [ -1.66931152e-02,  -1.69677734e-02],
                        [ -1.93481445e-02,  -1.90734863e-02],
                        [ -2.29187012e-02,  -2.23388672e-02],
                        [ -2.77709961e-02,  -2.74047852e-02],
                        [ -3.16772461e-02,  -3.18603516e-02],
                        [ -3.10668945e-02,  -3.16162109e-02],
                        [ -2.50854492e-02,  -2.55737305e-02],
                        [ -1.69982910e-02,  -1.69677734e-02],
                        [ -1.11999512e-02,  -1.06811523e-02],
                        [ -9.39941406e-03,  -8.85009766e-03],
                        [ -1.00402832e-02,  -9.94873047e-03],
                        [ -1.12915039e-02,  -1.17187500e-02],
                        [ -1.30004883e-02,  -1.35498047e-02],
                        [ -1.40991211e-02,  -1.43432617e-02],
                        [ -1.26647949e-02,  -1.23596191e-02],
                        [ -9.70458984e-03,  -9.12475586e-03],
                        [ -7.75146484e-03,  -7.41577148e-03],
                        [ -5.31005859e-03,  -5.52368164e-03],
                        [ -1.22070312e-04,  -7.01904297e-04],
                        [  5.00488281e-03,   4.57763672e-03],
                        [  6.86645508e-03,   6.95800781e-03],
                        [  8.14819336e-03,   8.66699219e-03],
                        [  1.36413574e-02,   1.41601562e-02],
                        [  2.52075195e-02,   2.52685547e-02],
                        [  4.29077148e-02,   4.24804688e-02],
                        [  6.69860840e-02,   6.64367676e-02],
                        [  9.46655273e-02,   9.44824219e-02],
                        [  1.19323730e-01,   1.19659424e-01],
                        [  1.34063721e-01,   1.34643555e-01],
                        [  1.32202148e-01,   1.32507324e-01],
                        [  1.05834961e-01,   1.05621338e-01],
                        [  5.03845215e-02,   4.98352051e-02],
                        [ -3.04870605e-02,  -3.08837891e-02],
                        [ -1.26068115e-01,  -1.25976562e-01],
                        [ -2.18231201e-01,  -2.17712402e-01],
                        [ -2.80059814e-01,  -2.79571533e-01],
                        [ -2.88909912e-01,  -2.88879395e-01],
                        [ -2.48931885e-01,  -2.49389648e-01],
                        [ -1.93084717e-01,  -1.93603516e-01],
                        [ -1.54998779e-01,  -1.55151367e-01],
                        [ -1.43218994e-01,  -1.42883301e-01],
                        [ -1.44775391e-01,  -1.44226074e-01],
                        [ -1.43920898e-01,  -1.43615723e-01],
                        [ -1.32873535e-01,  -1.33148193e-01],
                        [ -1.11480713e-01,  -1.12060547e-01],
                        [ -8.10241699e-02,  -8.13903809e-02],
                        [ -3.86047363e-02,  -3.84826660e-02],
                        [  2.05078125e-02,   2.09960938e-02],
                        [  9.34753418e-02,   9.39331055e-02],
                        [  1.66046143e-01,   1.66046143e-01],
                        [  2.20031738e-01,   2.19543457e-01],
                        [  2.42462158e-01,   2.41943359e-01],
                        [  2.27905273e-01,   2.27813721e-01],
                        [  1.78314209e-01,   1.78710938e-01],
                        [  1.05316162e-01,   1.05865479e-01],
                        [  2.93579102e-02,   2.96325684e-02],
                        [ -2.77404785e-02,  -2.80151367e-02],
                        [ -5.37414551e-02,  -5.43212891e-02],
                        [ -5.21545410e-02,  -5.25207520e-02],
                        [ -3.61633301e-02,  -3.60107422e-02],
                        [ -1.72424316e-02,  -1.66931152e-02],
                        [ -1.52587891e-03,  -1.09863281e-03],
                        [  7.26318359e-03,   7.23266602e-03],
                        [  8.60595703e-03,   8.14819336e-03],
                        [  5.82885742e-03,   5.31005859e-03],
                        [  2.83813477e-03,   2.71606445e-03],
                        [  1.89208984e-03,   2.28881836e-03],
                        [  4.24194336e-03,   4.79125977e-03],
                        [  1.10778809e-02,   1.12609863e-02],
                        [  2.27050781e-02,   2.23999023e-02],
                        [  3.79638672e-02,   3.74145508e-02],
                        [  5.57556152e-02,   5.54504395e-02],
                        [  7.47680664e-02,   7.49511719e-02],
                        [  8.99658203e-02,   9.04846191e-02],
                        [  9.45434570e-02,   9.49707031e-02],
                        [  8.75549316e-02,   8.74938965e-02],
                        [  7.37915039e-02,   7.33032227e-02],
                        [  5.77392578e-02,   5.72509766e-02],
                        [  4.19006348e-02,   4.18395996e-02],
                        [  2.85034180e-02,   2.89001465e-02],
                        [  1.83715820e-02,   1.89208984e-02],
                        [  1.13220215e-02,   1.15356445e-02],
                        [  8.60595703e-03,   8.30078125e-03],
                        [  1.10473633e-02,   1.04980469e-02],
                        [  1.47705078e-02,   1.44653320e-02],
                        [  1.62963867e-02,   1.65100098e-02],
                        [  1.95617676e-02,   2.00805664e-02],
                        [  2.79846191e-02,   2.83508301e-02],
                        [  3.59497070e-02,   3.58581543e-02],
                        [  3.79028320e-02,   3.74145508e-02],
                        [  3.78417969e-02,   3.73535156e-02],
                        [  4.05578613e-02,   4.05273438e-02],
                        [  4.29077148e-02,   4.33349609e-02],
                        [  4.08325195e-02,   4.13513184e-02],
                        [  3.67126465e-02,   3.68652344e-02],
                        [  3.31420898e-02,   3.28063965e-02],
                        [  2.82287598e-02,   2.77099609e-02],
                        [  2.17285156e-02,   2.14538574e-02],
                        [  1.70593262e-02,   1.72729492e-02],
                        [  1.48010254e-02,   1.53198242e-02],
                        [  1.08947754e-02,   1.12609863e-02],
                        [  2.83813477e-03,   2.71606445e-03],
                        [ -7.59887695e-03,  -8.08715820e-03],
                        [ -1.75170898e-02,  -1.79443359e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.84118652e-02,  -2.79846191e-02],
                        [ -2.69775391e-02,  -2.64892578e-02],
                        [ -2.16979980e-02,  -2.15759277e-02],
                        [ -1.50756836e-02,  -1.54418945e-02],
                        [ -1.20544434e-02,  -1.25732422e-02],
                        [ -1.63574219e-02,  -1.65710449e-02],
                        [ -2.55432129e-02,  -2.52990723e-02],
                        [ -3.22875977e-02,  -3.17687988e-02],
                        [ -3.17687988e-02,  -3.14331055e-02],
                        [ -2.56347656e-02,  -2.57568359e-02],
                        [ -1.94091797e-02,  -1.98974609e-02],
                        [ -1.73645020e-02,  -1.77612305e-02],
                        [ -1.97143555e-02,  -1.96533203e-02],
                        [ -2.31628418e-02,  -2.27355957e-02],
                        [ -2.43530273e-02,  -2.38952637e-02],
                        [ -2.32543945e-02,  -2.31628418e-02],
                        [ -2.20031738e-02,  -2.23693848e-02],
                        [ -2.09045410e-02,  -2.13928223e-02],
                        [ -1.87988281e-02,  -1.90124512e-02],
                        [ -1.62048340e-02,  -1.59301758e-02],
                        [ -1.53503418e-02,  -1.48620605e-02],
                        [ -1.73645020e-02,  -1.70593262e-02],
                        [ -2.08435059e-02,  -2.09960938e-02],
                        [ -2.40478516e-02,  -2.45361328e-02],
                        [ -2.59704590e-02,  -2.63366699e-02],
                        [ -2.53601074e-02,  -2.53295898e-02],
                        [ -2.08129883e-02,  -2.03857422e-02],
                        [ -1.17797852e-02,  -1.13220215e-02],
                        [ -6.40869141e-04,  -5.79833984e-04],
                        [  5.52368164e-03,   5.12695312e-03],
                        [  1.06811523e-03,   6.10351562e-04],
                        [ -9.12475586e-03,  -9.30786133e-03],
                        [ -1.33972168e-02,  -1.30920410e-02],
                        [ -7.47680664e-03,  -6.98852539e-03],
                        [  2.28881836e-03,   2.56347656e-03],
                        [  1.08032227e-02,   1.06201172e-02],
                        [  1.96228027e-02,   1.91345215e-02],
                        [  2.98461914e-02,   2.95104980e-02],
                        [  4.03137207e-02,   4.04052734e-02],
                        [  5.26733398e-02,   5.31005859e-02],
                        [  7.08618164e-02,   7.12890625e-02],
                        [  9.37805176e-02,   9.38110352e-02],
                        [  1.13830566e-01,   1.13433838e-01],
                        [  1.25213623e-01,   1.24755859e-01],
                        [  1.25793457e-01,   1.25640869e-01],
                        [  1.08764648e-01,   1.09069824e-01],
                        [  6.27441406e-02,   6.32324219e-02],
                        [ -1.66931152e-02,  -1.64794922e-02],
                        [ -1.19537354e-01,  -1.19720459e-01],
                        [ -2.20947266e-01,  -2.21405029e-01],
                        [ -2.87597656e-01,  -2.87933350e-01],
                        [ -2.95654297e-01,  -2.95562744e-01],
                        [ -2.52166748e-01,  -2.51708984e-01],
                        [ -1.93145752e-01,  -1.92749023e-01],
                        [ -1.52099609e-01,  -1.52099609e-01],
                        [ -1.34948730e-01,  -1.35345459e-01],
                        [ -1.29302979e-01,  -1.29730225e-01],
                        [ -1.24938965e-01,  -1.25061035e-01],
                        [ -1.19049072e-01,  -1.18743896e-01],
                        [ -1.10504150e-01,  -1.10046387e-01],
                        [ -9.31396484e-02,  -9.29260254e-02],
                        [ -5.51452637e-02,  -5.53588867e-02],
                        [  9.46044922e-03,   9.00268555e-03],
                        [  9.07592773e-02,   9.04846191e-02],
                        [  1.68518066e-01,   1.68640137e-01],
                        [  2.22808838e-01,   2.23236084e-01],
                        [  2.38830566e-01,   2.39196777e-01],
                        [  2.10235596e-01,   2.10205078e-01],
                        [  1.45202637e-01,   1.44805908e-01],
                        [  6.59790039e-02,   6.55822754e-02],
                        [ -2.25830078e-03,  -2.31933594e-03],
                        [ -4.21142578e-02,  -4.17785645e-02],
                        [ -4.92858887e-02,  -4.88586426e-02],
                        [ -3.36303711e-02,  -3.34472656e-02],
                        [ -1.13830566e-02,  -1.16271973e-02],
                        [  6.80541992e-03,   6.34765625e-03],
                        [  1.93481445e-02,   1.91040039e-02],
                        [  2.71606445e-02,   2.73132324e-02],
                        [  2.78930664e-02,   2.83508301e-02],
                        [  1.98059082e-02,   2.01416016e-02],
                        [  8.30078125e-03,   8.23974609e-03],
                        [  1.15966797e-03,   7.62939453e-04],
                        [ -2.44140625e-04,  -6.40869141e-04],
                        [  2.22778320e-03,   2.19726562e-03],
                        [  1.10778809e-02,   1.14135742e-02],
                        [  2.96630859e-02,   3.01208496e-02],
                        [  5.52062988e-02,   5.53588867e-02],
                        [  7.97119141e-02,   7.94372559e-02],
                        [  9.57641602e-02,   9.53369141e-02],
                        [  9.95178223e-02,   9.92736816e-02],
                        [  9.15527344e-02,   9.17358398e-02],
                        [  7.63244629e-02,   7.67517090e-02],
                        [  5.90515137e-02,   5.93566895e-02],
                        [  4.24499512e-02,   4.23583984e-02],
                        [  2.71606445e-02,   2.67639160e-02],
                        [  1.46789551e-02,   1.42822266e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  1.07421875e-02,   1.11083984e-02],
                        [  1.81884766e-02,   1.86157227e-02],
                        [  2.57568359e-02,   2.58789062e-02],
                        [  3.04870605e-02,   3.02429199e-02],
                        [  3.23486328e-02,   3.19213867e-02],
                        [  3.25927734e-02,   3.23791504e-02],
                        [  3.32031250e-02,   3.34167480e-02],
                        [  3.56140137e-02,   3.60412598e-02],
                        [  3.83300781e-02,   3.86047363e-02],
                        [  3.90319824e-02,   3.89404297e-02],
                        [  3.83605957e-02,   3.79943848e-02],
                        [  3.82385254e-02,   3.78723145e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  3.77807617e-02,   3.81164551e-02],
                        [  3.45458984e-02,   3.49426270e-02],
                        [  2.70690918e-02,   2.71606445e-02],
                        [  1.64489746e-02,   1.61743164e-02],
                        [  6.16455078e-03,   5.73730469e-03],
                        [ -2.71606445e-03,  -2.89916992e-03],
                        [ -1.18103027e-02,  -1.16271973e-02],
                        [ -2.04772949e-02,  -2.00805664e-02],
                        [ -2.42919922e-02,  -2.40478516e-02],
                        [ -2.16064453e-02,  -2.17285156e-02],
                        [ -1.65100098e-02,  -1.69067383e-02],
                        [ -1.26342773e-02,  -1.29699707e-02],
                        [ -1.01623535e-02,  -1.01318359e-02],
                        [ -9.73510742e-03,  -9.39941406e-03],
                        [ -1.39465332e-02,  -1.35803223e-02],
                        [ -2.23693848e-02,  -2.23083496e-02],
                        [ -2.99072266e-02,  -3.01818848e-02],
                        [ -3.27453613e-02,  -3.31420898e-02],
                        [ -3.21044922e-02,  -3.22570801e-02],
                        [ -2.94494629e-02,  -2.92358398e-02],
                        [ -2.54516602e-02,  -2.50549316e-02],
                        [ -2.26135254e-02,  -2.23999023e-02],
                        [ -2.18505859e-02,  -2.19726562e-02],
                        [ -1.99279785e-02,  -2.02941895e-02],
                        [ -1.62048340e-02,  -1.64794922e-02],
                        [ -1.51367188e-02,  -1.50756836e-02],
                        [ -1.70898438e-02,  -1.67541504e-02],
                        [ -1.57470703e-02,  -1.54113770e-02],
                        [ -9.70458984e-03,  -9.64355469e-03],
                        [ -7.08007812e-03,  -7.35473633e-03],
                        [ -1.31835938e-02,  -1.35498047e-02],
                        [ -2.40783691e-02,  -2.42004395e-02],
                        [ -3.29589844e-02,  -3.27453613e-02],
                        [ -3.55834961e-02,  -3.51867676e-02],
                        [ -3.04565430e-02,  -3.02429199e-02],
                        [ -1.97448730e-02,  -1.98974609e-02],
                        [ -9.39941406e-03,  -9.76562500e-03],
                        [ -5.79833984e-03,  -6.07299805e-03],
                        [ -9.67407227e-03,  -9.61303711e-03],
                        [ -1.51672363e-02,  -1.48620605e-02],
                        [ -1.65710449e-02,  -1.62658691e-02],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [ -4.82177734e-03,  -5.09643555e-03],
                        [  2.71606445e-03,   2.38037109e-03],
                        [  9.00268555e-03,   8.91113281e-03],
                        [  1.60827637e-02,   1.63269043e-02],
                        [  2.63061523e-02,   2.66723633e-02],
                        [  3.87573242e-02,   3.89404297e-02],
                        [  4.93164062e-02,   4.91638184e-02],
                        [  5.64880371e-02,   5.61218262e-02],
                        [  6.52465820e-02,   6.50024414e-02],
                        [  8.03222656e-02,   8.03833008e-02],
                        [  9.93041992e-02,   9.96398926e-02],
                        [  1.14105225e-01,   1.14379883e-01],
                        [  1.14440918e-01,   1.14410400e-01],
                        [  9.03320312e-02,   9.00268555e-02],
                        [  3.43322754e-02,   3.40270996e-02],
                        [ -5.32531738e-02,  -5.33447266e-02],
                        [ -1.57836914e-01,  -1.57592773e-01],
                        [ -2.50976562e-01,  -2.50640869e-01],
                        [ -3.01666260e-01,  -3.01513672e-01],
                        [ -2.93182373e-01,  -2.93365479e-01],
                        [ -2.38708496e-01,  -2.39044189e-01],
                        [ -1.76086426e-01,  -1.76300049e-01],
                        [ -1.36962891e-01,  -1.36871338e-01],
                        [ -1.23809814e-01,  -1.23504639e-01],
                        [ -1.20697021e-01,  -1.20422363e-01],
                        [ -1.15844727e-01,  -1.15844727e-01],
                        [ -1.07574463e-01,  -1.07849121e-01],
                        [ -9.66186523e-02,  -9.69238281e-02],
                        [ -8.00781250e-02,  -8.01391602e-02],
                        [ -5.04760742e-02,  -5.02319336e-02],
                        [  5.18798828e-04,   8.54492188e-04],
                        [  7.36999512e-02,   7.38220215e-02],
                        [  1.54022217e-01,   1.53869629e-01],
                        [  2.13775635e-01,   2.13439941e-01],
                        [  2.27722168e-01,   2.27508545e-01],
                        [  1.88385010e-01,   1.88507080e-01],
                        [  1.11511230e-01,   1.11816406e-01],
                        [  2.99682617e-02,   3.02124023e-02],
                        [ -2.41699219e-02,  -2.42004395e-02],
                        [ -3.96423340e-02,  -3.99169922e-02],
                        [ -2.90527344e-02,  -2.93273926e-02],
                        [ -1.33056641e-02,  -1.33361816e-02],
                        [ -4.39453125e-03,  -4.15039062e-03],
                        [  1.83105469e-04,   4.88281250e-04],
                        [  8.17871094e-03,   8.30078125e-03],
                        [  1.85852051e-02,   1.84020996e-02],
                        [  2.05078125e-02,   2.02026367e-02],
                        [  8.63647461e-03,   8.45336914e-03],
                        [ -7.23266602e-03,  -7.14111328e-03],
                        [ -1.31225586e-02,  -1.28173828e-02],
                        [ -4.15039062e-03,  -3.93676758e-03],
                        [  1.66015625e-02,   1.65710449e-02],
                        [  4.32434082e-02,   4.29687500e-02],
                        [  6.77185059e-02,   6.74743652e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  9.06372070e-02,   9.08813477e-02],
                        [  8.80126953e-02,   8.83178711e-02],
                        [  7.73010254e-02,   7.73620605e-02],
                        [  6.42395020e-02,   6.40563965e-02],
                        [  5.56335449e-02,   5.53283691e-02],
                        [  5.07507324e-02,   5.05981445e-02],
                        [  4.37011719e-02,   4.38232422e-02],
                        [  3.36608887e-02,   3.39355469e-02],
                        [  2.57568359e-02,   2.59399414e-02],
                        [  2.24609375e-02,   2.23999023e-02],
                        [  2.09960938e-02,   2.07519531e-02],
                        [  1.90124512e-02,   1.87683105e-02],
                        [  1.79748535e-02,   1.80053711e-02],
                        [  2.13012695e-02,   2.15148926e-02],
                        [  2.96020508e-02,   2.98461914e-02],
                        [  3.82995605e-02,   3.83605957e-02],
                        [  4.04968262e-02,   4.03137207e-02],
                        [  3.45764160e-02,   3.43017578e-02],
                        [  2.61535645e-02,   2.60314941e-02],
                        [  2.15759277e-02,   2.16979980e-02],
                        [  2.30407715e-02,   2.33154297e-02],
                        [  2.87780762e-02,   2.89611816e-02],
                        [  3.28063965e-02,   3.27453613e-02],
                        [  2.98461914e-02,   2.96020508e-02],
                        [  2.20947266e-02,   2.18811035e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.10168457e-02,   1.12304688e-02],
                        [  6.34765625e-03,   6.59179688e-03],
                        [  6.10351562e-05,   9.15527344e-05],
                        [ -7.11059570e-03,  -7.29370117e-03],
                        [ -1.36718750e-02,  -1.39465332e-02],
                        [ -1.80358887e-02,  -1.81274414e-02],
                        [ -1.95312500e-02,  -1.94091797e-02],
                        [ -2.04772949e-02,  -2.02331543e-02],
                        [ -2.33154297e-02,  -2.31628418e-02],
                        [ -2.70385742e-02,  -2.70996094e-02],
                        [ -3.03039551e-02,  -3.05480957e-02],
                        [ -3.45764160e-02,  -3.47900391e-02],
                        [ -3.87878418e-02,  -3.87573242e-02],
                        [ -3.74755859e-02,  -3.72619629e-02],
                        [ -2.95104980e-02,  -2.92968750e-02],
                        [ -2.13012695e-02,  -2.12707520e-02],
                        [ -1.84936523e-02,  -1.86767578e-02],
                        [ -2.02636719e-02,  -2.05078125e-02],
                        [ -2.45361328e-02,  -2.46276855e-02],
                        [ -3.10668945e-02,  -3.09143066e-02],
                        [ -3.71093750e-02,  -3.68652344e-02],
                        [ -3.77502441e-02,  -3.76281738e-02],
                        [ -3.24707031e-02,  -3.25622559e-02],
                        [ -2.49938965e-02,  -2.52075195e-02],
                        [ -1.81884766e-02,  -1.83715820e-02],
                        [ -1.27868652e-02,  -1.27563477e-02],
                        [ -8.75854492e-03,  -8.54492188e-03],
                        [ -6.89697266e-03,  -6.68334961e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.33361816e-02,  -1.35192871e-02],
                        [ -1.88293457e-02,  -1.90429688e-02],
                        [ -2.39562988e-02,  -2.40173340e-02],
                        [ -2.87170410e-02,  -2.85644531e-02],
                        [ -3.18908691e-02,  -3.16772461e-02],
                        [ -3.16467285e-02,  -3.15551758e-02],
                        [ -2.70996094e-02,  -2.71911621e-02],
                        [ -1.89208984e-02,  -1.91345215e-02],
                        [ -9.91821289e-03,  -1.00708008e-02],
                        [ -3.32641602e-03,  -3.26538086e-03],
                        [ -2.74658203e-04,  -6.10351562e-05],
                        [  6.10351562e-05,   2.44140625e-04],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -6.40869141e-04,  -8.23974609e-04],
                        [  6.34765625e-03,   6.16455078e-03],
                        [  2.08129883e-02,   2.07519531e-02],
                        [  3.76586914e-02,   3.78112793e-02],
                        [  5.23071289e-02,   5.25207520e-02],
                        [  6.58569336e-02,   6.59484863e-02],
                        [  8.30688477e-02,   8.29772949e-02],
                        [  1.05438232e-01,   1.05255127e-01],
                        [  1.25946045e-01,   1.25823975e-01],
                        [  1.31896973e-01,   1.31958008e-01],
                        [  1.11816406e-01,   1.11999512e-01],
                        [  5.82275391e-02,   5.83801270e-02],
                        [ -2.87475586e-02,  -2.87780762e-02],
                        [ -1.35833740e-01,  -1.36016846e-01],
                        [ -2.36175537e-01,  -2.36358643e-01],
                        [ -2.96783447e-01,  -2.96844482e-01],
                        [ -2.95928955e-01,  -2.95776367e-01],
                        [ -2.42614746e-01,  -2.42431641e-01],
                        [ -1.75262451e-01,  -1.75201416e-01],
                        [ -1.30615234e-01,  -1.30737305e-01],
                        [ -1.15356445e-01,  -1.15539551e-01],
                        [ -1.12121582e-01,  -1.12243652e-01],
                        [ -1.06170654e-01,  -1.06109619e-01],
                        [ -9.62219238e-02,  -9.60388184e-02],
                        [ -8.59680176e-02,  -8.58459473e-02],
                        [ -7.47985840e-02,  -7.48291016e-02],
                        [ -5.52368164e-02,  -5.53894043e-02],
                        [ -1.73339844e-02,  -1.74865723e-02],
                        [  4.16870117e-02,   4.16564941e-02],
                        [  1.10290527e-01,   1.10412598e-01],
                        [  1.64794922e-01,   1.64978027e-01],
                        [  1.81793213e-01,   1.81854248e-01],
                        [  1.53137207e-01,   1.53045654e-01],
                        [  9.23156738e-02,   9.21325684e-02],
                        [  2.85034180e-02,   2.84118652e-02],
                        [ -9.73510742e-03,  -9.67407227e-03],
                        [ -1.52587891e-02,  -1.51062012e-02],
                        [ -5.49316406e-03,  -5.37109375e-03],
                        [  7.93457031e-04,   7.62939453e-04],
                        [  4.08935547e-03,   3.93676758e-03],
                        [  1.48620605e-02,   1.47399902e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.51660156e-02,   4.53186035e-02],
                        [  4.28466797e-02,   4.30297852e-02],
                        [  2.76489258e-02,   2.76794434e-02],
                        [  9.24682617e-03,   9.12475586e-03],
                        [ -4.88281250e-04,  -6.71386719e-04],
                        [  5.58471680e-03,   5.49316406e-03],
                        [  2.55126953e-02,   2.55737305e-02],
                        [  5.18493652e-02,   5.20019531e-02],
                        [  7.77893066e-02,   7.78808594e-02],
                        [  9.70458984e-02,   9.70153809e-02],
                        [  1.01562500e-01,   1.01409912e-01],
                        [  8.82263184e-02,   8.81042480e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  5.48095703e-02,   5.49316406e-02],
                        [  5.34057617e-02,   5.35278320e-02],
                        [  5.24902344e-02,   5.25207520e-02],
                        [  4.46777344e-02,   4.45861816e-02],
                        [  3.43322754e-02,   3.41796875e-02],
                        [  2.72216797e-02,   2.71606445e-02],
                        [  2.25830078e-02,   2.26440430e-02],
                        [  1.87072754e-02,   1.88598633e-02],
                        [  1.69067383e-02,   1.69982910e-02],
                        [  1.62963867e-02,   1.62658691e-02],
                        [  1.42211914e-02,   1.40991211e-02],
                        [  1.27563477e-02,   1.26342773e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  2.38952637e-02,   2.40173340e-02],
                        [  2.94494629e-02,   2.95715332e-02],
                        [  3.15551758e-02,   3.15856934e-02],
                        [  3.32031250e-02,   3.30810547e-02],
                        [  3.61633301e-02,   3.60412598e-02],
                        [  3.92456055e-02,   3.91845703e-02],
                        [  3.91540527e-02,   3.92150879e-02],
                        [  3.28369141e-02,   3.29895020e-02],
                        [  2.13012695e-02,   2.13928223e-02],
                        [  1.00402832e-02,   1.00097656e-02],
                        [  2.86865234e-03,   2.74658203e-03],
                        [ -1.64794922e-03,  -1.73950195e-03],
                        [ -4.24194336e-03,  -4.21142578e-03],
                        [ -2.62451172e-03,  -2.50244141e-03],
                        [  1.03759766e-03,   1.15966797e-03],
                        [ -3.05175781e-05,   0.00000000e+00],
                        [ -7.14111328e-03,  -7.23266602e-03],
                        [ -1.42517090e-02,  -1.43737793e-02],
                        [ -1.74865723e-02,  -1.75476074e-02],
                        [ -1.99279785e-02,  -1.98669434e-02],
                        [ -2.46276855e-02,  -2.45056152e-02],
                        [ -2.81372070e-02,  -2.80761719e-02],
                        [ -2.69165039e-02,  -2.69470215e-02],
                        [ -2.45971680e-02,  -2.46887207e-02],
                        [ -2.59399414e-02,  -2.60314941e-02],
                        [ -2.90527344e-02,  -2.90222168e-02],
                        [ -3.03039551e-02,  -3.01818848e-02],
                        [ -3.21350098e-02,  -3.20434570e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.82177734e-02,  -4.83093262e-02],
                        [ -4.92553711e-02,  -4.93469238e-02],
                        [ -4.22058105e-02,  -4.22668457e-02],
                        [ -3.55224609e-02,  -3.54614258e-02],
                        [ -3.20129395e-02,  -3.18908691e-02],
                        [ -2.67639160e-02,  -2.67028809e-02],
                        [ -1.79443359e-02,  -1.80053711e-02],
                        [ -1.04980469e-02,  -1.06201172e-02],
                        [ -8.14819336e-03,  -8.20922852e-03],
                        [ -8.30078125e-03,  -8.27026367e-03],
                        [ -9.24682617e-03,  -9.15527344e-03],
                        [ -1.37023926e-02,  -1.36108398e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -2.53601074e-02,  -2.54211426e-02],
                        [ -2.18200684e-02,  -2.19116211e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.11083984e-02,  -1.10473633e-02],
                        [ -1.08032227e-02,  -1.07116699e-02],
                        [ -1.02233887e-02,  -1.01928711e-02],
                        [ -8.39233398e-03,  -8.42285156e-03],
                        [ -5.31005859e-03,  -5.40161133e-03],
                        [ -1.83105469e-04,  -2.44140625e-04],
                        [  6.71386719e-03,   6.74438477e-03],
                        [  1.36718750e-02,   1.37634277e-02],
                        [  1.85241699e-02,   1.85852051e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.64892578e-02,   2.63977051e-02],
                        [  4.00390625e-02,   3.99475098e-02],
                        [  6.17065430e-02,   6.16760254e-02],
                        [  8.67919922e-02,   8.68530273e-02],
                        [  1.11389160e-01,   1.11480713e-01],
                        [  1.30798340e-01,   1.30828857e-01],
                        [  1.34521484e-01,   1.34490967e-01],
                        [  1.11022949e-01,   1.10961914e-01],
                        [  5.62133789e-02,   5.61523438e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -1.28845215e-01,  -1.28753662e-01],
                        [ -2.27020264e-01,  -2.26959229e-01],
                        [ -2.88909912e-01,  -2.88909912e-01],
                        [ -2.92449951e-01,  -2.92510986e-01],
                        [ -2.46704102e-01,  -2.46765137e-01],
                        [ -1.87530518e-01,  -1.87561035e-01],
                        [ -1.46636963e-01,  -1.46606445e-01],
                        [ -1.28387451e-01,  -1.28295898e-01],
                        [ -1.18865967e-01,  -1.18835449e-01],
                        [ -1.07849121e-01,  -1.07879639e-01],
                        [ -9.43603516e-02,  -9.44519043e-02],
                        [ -7.90405273e-02,  -7.90710449e-02],
                        [ -6.11572266e-02,  -6.11267090e-02],
                        [ -4.00695801e-02,  -4.00085449e-02],
                        [ -1.29394531e-02,  -1.29089355e-02],
                        [  2.36816406e-02,   2.36511230e-02],
                        [  6.60705566e-02,   6.60095215e-02],
                        [  1.00738525e-01,   1.00708008e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.01196289e-01,   1.01257324e-01],
                        [  7.20520020e-02,   7.21130371e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  1.66015625e-02,   1.65710449e-02],
                        [  1.16882324e-02,   1.16271973e-02],
                        [  2.11486816e-02,   2.11181641e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  3.24096680e-02,   3.24707031e-02],
                        [  3.01513672e-02,   3.02124023e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  3.76892090e-02,   3.76281738e-02],
                        [  3.16467285e-02,   3.15856934e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  5.21850586e-03,   5.24902344e-03],
                        [  1.01013184e-02,   1.01623535e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  4.82482910e-02,   4.81872559e-02],
                        [  6.83593750e-02,   6.83288574e-02],
                        [  8.70056152e-02,   8.69750977e-02],
                        [  1.00006104e-01,   1.00036621e-01],
                        [  1.01684570e-01,   1.01745605e-01],
                        [  9.12780762e-02,   9.13085938e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  6.50024414e-02,   6.49719238e-02],
                        [  6.10656738e-02,   6.10351562e-02],
                        [  5.69458008e-02,   5.69763184e-02],
                        [  4.63867188e-02,   4.64172363e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  1.73950195e-02,   1.74255371e-02],
                        [  1.04064941e-02,   1.03759766e-02],
                        [  1.07116699e-02,   1.06811523e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.88293457e-02,   1.88598633e-02],
                        [  1.86157227e-02,   1.86462402e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  2.30407715e-02,   2.30102539e-02],
                        [  2.91442871e-02,   2.91137695e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.52478027e-02,   3.52783203e-02],
                        [  3.35083008e-02,   3.35388184e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.49023438e-02,   2.48718262e-02],
                        [  2.14233398e-02,   2.13928223e-02],
                        [  1.69982910e-02,   1.69677734e-02],
                        [  1.14135742e-02,   1.14440918e-02],
                        [  6.25610352e-03,   6.28662109e-03],
                        [  2.19726562e-03,   2.22778320e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -6.40869141e-03,  -6.43920898e-03],
                        [ -9.12475586e-03,  -9.15527344e-03],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -4.30297852e-03,  -4.27246094e-03],
                        [ -4.05883789e-03,  -4.02832031e-03],
                        [ -1.03149414e-02,  -1.02844238e-02],
                        [ -2.00195312e-02,  -2.00500488e-02],
                        [ -2.59704590e-02,  -2.60009766e-02],
                        [ -2.56958008e-02,  -2.57263184e-02],
                        [ -2.38647461e-02,  -2.38342285e-02],
                        [ -2.46887207e-02,  -2.46582031e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -4.01611328e-02,  -4.01916504e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.29687500e-02,  -4.29382324e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.07824707e-02,  -2.08129883e-02],
                        [ -1.26647949e-02,  -1.26953125e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.66625977e-02,  -1.66320801e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -2.96020508e-03,  -2.99072266e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [ -1.15966797e-03,  -1.12915039e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  4.97436523e-03,   4.94384766e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  8.28552246e-02,   8.28247070e-02],
                        [  1.03118896e-01,   1.03118896e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.13555908e-01,   1.13555908e-01],
                        [  8.69750977e-02,   8.70056152e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -1.39404297e-01,  -1.39404297e-01],
                        [ -2.31811523e-01,  -2.31811523e-01],
                        [ -2.83721924e-01,  -2.83691406e-01],
                        [ -2.79052734e-01,  -2.79052734e-01],
                        [ -2.30987549e-01,  -2.30987549e-01],
                        [ -1.71905518e-01,  -1.71905518e-01],
                        [ -1.30767822e-01,  -1.30798340e-01],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -8.78906250e-02,  -8.78906250e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -5.34973145e-02,  -5.35278320e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  6.62231445e-02,   6.62231445e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  4.29077148e-02,   4.29382324e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  1.19171143e-01,   1.19171143e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -1.38366699e-01,  -1.38366699e-01],
                        [ -2.26348877e-01,  -2.26348877e-01],
                        [ -2.78289795e-01,  -2.78289795e-01],
                        [ -2.79357910e-01,  -2.79357910e-01],
                        [ -2.35321045e-01,  -2.35321045e-01],
                        [ -1.75415039e-01,  -1.75415039e-01],
                        [ -1.32537842e-01,  -1.32537842e-01],
                        [ -1.12854004e-01,  -1.12854004e-01],
                        [ -9.70153809e-02,  -9.70153809e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  9.95788574e-02,   9.95788574e-02],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  7.06787109e-02,   7.06787109e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  1.32568359e-01,   1.32568359e-01],
                        [  1.25671387e-01,   1.25671387e-01],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -2.15026855e-01,  -2.15026855e-01],
                        [ -2.74902344e-01,  -2.74902344e-01],
                        [ -2.78228760e-01,  -2.78228760e-01],
                        [ -2.28942871e-01,  -2.28942871e-01],
                        [ -1.61834717e-01,  -1.61834717e-01],
                        [ -1.11083984e-01,  -1.11083984e-01],
                        [ -8.55712891e-02,  -8.55712891e-02],
                        [ -7.31201172e-02,  -7.31201172e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -8.19702148e-02,  -8.19702148e-02],
                        [ -1.02172852e-01,  -1.02172852e-01],
                        [ -1.09497070e-01,  -1.09497070e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  1.04553223e-01,   1.04553223e-01],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  1.23870850e-01,   1.23870850e-01],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  4.68444824e-02,   4.68444824e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -1.28875732e-01,  -1.28875732e-01],
                        [ -2.07489014e-01,  -2.07489014e-01],
                        [ -2.53997803e-01,  -2.53997803e-01],
                        [ -2.56011963e-01,  -2.56011963e-01],
                        [ -2.15972900e-01,  -2.15972900e-01],
                        [ -1.57379150e-01,  -1.57379150e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -8.63037109e-02,  -8.63037109e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -1.44256592e-01,  -1.44256592e-01],
                        [ -1.52038574e-01,  -1.52038574e-01],
                        [ -1.27136230e-01,  -1.27136230e-01],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  1.14959717e-01,   1.14959717e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  8.38623047e-02,   8.38623047e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  6.86950684e-02,   6.86950684e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  6.79321289e-02,   6.79321289e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  1.07879639e-01,   1.07879639e-01],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  1.32934570e-01,   1.32934570e-01],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  6.04858398e-02,   6.04858398e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.08520508e-01,  -1.08520508e-01],
                        [ -1.95190430e-01,  -1.95190430e-01],
                        [ -2.54699707e-01,  -2.54699707e-01],
                        [ -2.70172119e-01,  -2.70172119e-01],
                        [ -2.40936279e-01,  -2.40936279e-01],
                        [ -1.86676025e-01,  -1.86676025e-01],
                        [ -1.33270264e-01,  -1.33270264e-01],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -1.40380859e-01,  -1.40380859e-01],
                        [ -1.62292480e-01,  -1.62292480e-01],
                        [ -1.58203125e-01,  -1.58203125e-01],
                        [ -1.23077393e-01,  -1.23077393e-01],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  1.25488281e-01,   1.25488281e-01],
                        [  1.33819580e-01,   1.33819580e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.19104004e-02,   5.19104004e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.80139160e-02,   5.80139160e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  1.35070801e-01,   1.35070801e-01],
                        [  1.40563965e-01,   1.40563965e-01],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  6.63452148e-02,   6.63452148e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.11663818e-01,  -1.11663818e-01],
                        [ -2.06176758e-01,  -2.06176758e-01],
                        [ -2.69622803e-01,  -2.69622803e-01],
                        [ -2.81066895e-01,  -2.81066895e-01],
                        [ -2.40814209e-01,  -2.40814209e-01],
                        [ -1.73126221e-01,  -1.73126221e-01],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -7.19299316e-02,  -7.19299316e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -1.07849121e-01,  -1.07849121e-01],
                        [ -1.60583496e-01,  -1.60583496e-01],
                        [ -1.95983887e-01,  -1.95983887e-01],
                        [ -1.99310303e-01,  -1.99310303e-01],
                        [ -1.71844482e-01,  -1.71844482e-01],
                        [ -1.23504639e-01,  -1.23504639e-01],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  7.41271973e-02,   7.41271973e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  1.26403809e-01,   1.26403809e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.23321533e-01,   1.23321533e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  1.11999512e-01,   1.11999512e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  1.48803711e-01,   1.48803711e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -8.48388672e-02,  -8.48388672e-02],
                        [ -1.87408447e-01,  -1.87408447e-01],
                        [ -2.63214111e-01,  -2.63214111e-01],
                        [ -2.84454346e-01,  -2.84454346e-01],
                        [ -2.46582031e-01,  -2.46582031e-01],
                        [ -1.73034668e-01,  -1.73034668e-01],
                        [ -9.97009277e-02,  -9.97009277e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -8.57238770e-02,  -8.57238770e-02],
                        [ -1.34277344e-01,  -1.34277344e-01],
                        [ -1.82678223e-01,  -1.82678223e-01],
                        [ -2.12463379e-01,  -2.12463379e-01],
                        [ -2.09503174e-01,  -2.09503174e-01],
                        [ -1.74743652e-01,  -1.74743652e-01],
                        [ -1.25305176e-01,  -1.25305176e-01],
                        [ -7.82775879e-02,  -7.82775879e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  1.14776611e-01,   1.14776611e-01],
                        [  1.42150879e-01,   1.42150879e-01],
                        [  1.39343262e-01,   1.39343262e-01],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  8.63342285e-02,   8.63342285e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.46209717e-01,   1.46209717e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  7.27233887e-02,   7.27233887e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.51397705e-01,   1.51397705e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.41998291e-01,   1.41998291e-01],
                        [  9.38415527e-02,   9.38415527e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [ -8.72802734e-02,  -8.72802734e-02],
                        [ -1.91711426e-01,  -1.91711426e-01],
                        [ -2.64556885e-01,  -2.64556885e-01],
                        [ -2.79083252e-01,  -2.79083252e-01],
                        [ -2.34710693e-01,  -2.34710693e-01],
                        [ -1.59576416e-01,  -1.59576416e-01],
                        [ -9.14916992e-02,  -9.14916992e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -7.22656250e-02,  -7.22656250e-02],
                        [ -1.13494873e-01,  -1.13494873e-01],
                        [ -1.63146973e-01,  -1.63146973e-01],
                        [ -2.04223633e-01,  -2.04223633e-01],
                        [ -2.21008301e-01,  -2.21008301e-01],
                        [ -2.08038330e-01,  -2.08038330e-01],
                        [ -1.72119141e-01,  -1.72119141e-01],
                        [ -1.26281738e-01,  -1.26281738e-01],
                        [ -8.09020996e-02,  -8.09020996e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.53533936e-01,   1.53533936e-01],
                        [  1.42517090e-01,   1.42517090e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  9.73205566e-02,   9.73205566e-02],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  9.56115723e-02,   9.56115723e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  1.35589600e-01,   1.35589600e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.42333984e-01,   1.42333984e-01],
                        [  1.46209717e-01,   1.46209717e-01],
                        [  1.24755859e-01,   1.24755859e-01],
                        [  7.49816895e-02,   7.49816895e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -1.84539795e-01,  -1.84539795e-01],
                        [ -2.49481201e-01,  -2.49481201e-01],
                        [ -2.62176514e-01,  -2.62176514e-01],
                        [ -2.19696045e-01,  -2.19696045e-01],
                        [ -1.51000977e-01,  -1.51000977e-01],
                        [ -9.61608887e-02,  -9.61608887e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.76367188e-02,  -7.76367188e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -1.09283447e-01,  -1.09283447e-01],
                        [ -1.38336182e-01,  -1.38336182e-01],
                        [ -1.71783447e-01,  -1.71783447e-01],
                        [ -1.92718506e-01,  -1.92718506e-01],
                        [ -1.89636230e-01,  -1.89636230e-01],
                        [ -1.68243408e-01,  -1.68243408e-01],
                        [ -1.42059326e-01,  -1.42059326e-01],
                        [ -1.17156982e-01,  -1.17156982e-01],
                        [ -9.03625488e-02,  -9.03625488e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  1.22558594e-01,   1.22558594e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.45904541e-01,   1.45904541e-01],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.13220215e-01,   1.13220215e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.40167236e-01,   1.40167236e-01],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  7.06787109e-02,   7.06787109e-02],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.58386230e-01,   1.58386230e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  7.20520020e-02,   7.20520020e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -1.88323975e-01,  -1.88323975e-01],
                        [ -2.44506836e-01,  -2.44506836e-01],
                        [ -2.47100830e-01,  -2.47100830e-01],
                        [ -2.00164795e-01,  -2.00164795e-01],
                        [ -1.33483887e-01,  -1.33483887e-01],
                        [ -8.29467773e-02,  -8.29467773e-02],
                        [ -6.85729980e-02,  -6.85729980e-02],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -1.23992920e-01,  -1.23992920e-01],
                        [ -1.62048340e-01,  -1.62048340e-01],
                        [ -1.89056396e-01,  -1.89056396e-01],
                        [ -1.94976807e-01,  -1.94976807e-01],
                        [ -1.77429199e-01,  -1.77429199e-01],
                        [ -1.46881104e-01,  -1.46881104e-01],
                        [ -1.19812012e-01,  -1.19812012e-01],
                        [ -1.04614258e-01,  -1.04614258e-01],
                        [ -9.61303711e-02,  -9.61303711e-02],
                        [ -8.37402344e-02,  -8.37402344e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.50238037e-01,   1.50238037e-01],
                        [  1.60552979e-01,   1.60552979e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  1.03302002e-01,   1.03302002e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  1.15905762e-01,   1.15905762e-01],
                        [  1.39495850e-01,   1.39495850e-01],
                        [  1.57867432e-01,   1.57867432e-01],
                        [  1.61254883e-01,   1.61254883e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [ -3.05175781e-05,   0.00000000e+00],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.32324219e-02,  -6.32324219e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.02526855e-02,  -4.02832031e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.43432617e-01,   1.43432617e-01],
                        [  1.48773193e-01,   1.48742676e-01],
                        [  1.28967285e-01,   1.28967285e-01],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  3.20434570e-03,   3.20434570e-03],
                        [ -8.85925293e-02,  -8.85925293e-02],
                        [ -1.76513672e-01,  -1.76513672e-01],
                        [ -2.34893799e-01,  -2.34893799e-01],
                        [ -2.42858887e-01,  -2.42858887e-01],
                        [ -2.01812744e-01,  -2.01812744e-01],
                        [ -1.40686035e-01,  -1.40686035e-01],
                        [ -9.76257324e-02,  -9.76257324e-02],
                        [ -9.30175781e-02,  -9.30175781e-02],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -1.55181885e-01,  -1.55181885e-01],
                        [ -1.81732178e-01,  -1.81732178e-01],
                        [ -1.91223145e-01,  -1.91223145e-01],
                        [ -1.82250977e-01,  -1.82250977e-01],
                        [ -1.58660889e-01,  -1.58660889e-01],
                        [ -1.29608154e-01,  -1.29608154e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -9.08508301e-02,  -9.08508301e-02],
                        [ -8.53576660e-02,  -8.53576660e-02],
                        [ -8.16345215e-02,  -8.16345215e-02],
                        [ -7.14416504e-02,  -7.14416504e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.68029785e-01,   1.68029785e-01],
                        [  1.58325195e-01,   1.58325195e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.16912842e-01,   1.16912842e-01],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.06292725e-01,   1.06292725e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.37512207e-01,   1.37512207e-01],
                        [  1.53717041e-01,   1.53717041e-01],
                        [  1.64001465e-01,   1.64001465e-01],
                        [  1.64855957e-01,   1.64855957e-01],
                        [  1.55456543e-01,   1.55456543e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.11511230e-01,   1.11480713e-01],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.68554688e-02,   2.68249512e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.95410156e-02,  -2.95715332e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -3.08227539e-02,  -3.07922363e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  1.10717773e-01,   1.10717773e-01],
                        [  1.34185791e-01,   1.34185791e-01],
                        [  1.49383545e-01,   1.49383545e-01],
                        [  1.49047852e-01,   1.49047852e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  7.52868652e-02,   7.52868652e-02],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -1.69342041e-01,  -1.69342041e-01],
                        [ -2.18109131e-01,  -2.18109131e-01],
                        [ -2.19512939e-01,  -2.19512939e-01],
                        [ -1.79840088e-01,  -1.79840088e-01],
                        [ -1.30737305e-01,  -1.30737305e-01],
                        [ -1.07727051e-01,  -1.07727051e-01],
                        [ -1.22558594e-01,  -1.22558594e-01],
                        [ -1.59484863e-01,  -1.59484863e-01],
                        [ -1.92779541e-01,  -1.92779541e-01],
                        [ -2.04559326e-01,  -2.04589844e-01],
                        [ -1.92108154e-01,  -1.92108154e-01],
                        [ -1.64916992e-01,  -1.64916992e-01],
                        [ -1.36077881e-01,  -1.36077881e-01],
                        [ -1.14471436e-01,  -1.14471436e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -9.46044922e-02,  -9.46044922e-02],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  9.27429199e-02,   9.27429199e-02],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.66320801e-01,   1.66320801e-01],
                        [  1.64550781e-01,   1.64550781e-01],
                        [  1.47247314e-01,   1.47247314e-01],
                        [  1.27471924e-01,   1.27471924e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.14959717e-01,   1.14990234e-01],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  1.57196045e-01,   1.57196045e-01],
                        [  1.68731689e-01,   1.68731689e-01],
                        [  1.73004150e-01,   1.73004150e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.44561768e-01,   1.44561768e-01],
                        [  1.24847412e-01,   1.24847412e-01],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -9.15527344e-04,  -8.85009766e-04],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -5.41381836e-02,  -5.41076660e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -4.36706543e-02,  -4.37011719e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.04162598e-02,  -2.03857422e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.89208984e-03,  -1.92260742e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  1.09191895e-01,   1.09191895e-01],
                        [  1.34460449e-01,   1.34429932e-01],
                        [  1.51702881e-01,   1.51702881e-01],
                        [  1.50054932e-01,   1.50085449e-01],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  7.03735352e-02,   7.03735352e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.00891113e-01,  -1.00891113e-01],
                        [ -1.77581787e-01,  -1.77581787e-01],
                        [ -2.18536377e-01,  -2.18536377e-01],
                        [ -2.15484619e-01,  -2.15484619e-01],
                        [ -1.79962158e-01,  -1.79962158e-01],
                        [ -1.43493652e-01,  -1.43493652e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -1.71600342e-01,  -1.71600342e-01],
                        [ -2.17132568e-01,  -2.17132568e-01],
                        [ -2.42370605e-01,  -2.42370605e-01],
                        [ -2.33276367e-01,  -2.33276367e-01],
                        [ -1.99798584e-01,  -1.99798584e-01],
                        [ -1.60522461e-01,  -1.60522461e-01],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -1.02935791e-01,  -1.02905273e-01],
                        [ -8.20617676e-02,  -8.20617676e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.49169922e-01,   1.49169922e-01],
                        [  1.64672852e-01,   1.64672852e-01],
                        [  1.57073975e-01,   1.57073975e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.18988037e-01,   1.18988037e-01],
                        [  1.15814209e-01,   1.15814209e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  1.57196045e-01,   1.57196045e-01],
                        [  1.79473877e-01,   1.79473877e-01],
                        [  1.89056396e-01,   1.89056396e-01],
                        [  1.86981201e-01,   1.86981201e-01],
                        [  1.76269531e-01,   1.76269531e-01],
                        [  1.56005859e-01,   1.56005859e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  6.89086914e-02,   6.88781738e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  7.78198242e-03,   7.75146484e-03],
                        [  4.08935547e-03,   4.05883789e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.25427246e-02,   1.25732422e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  1.76696777e-02,   1.77001953e-02],
                        [  5.82885742e-03,   5.82885742e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -6.69250488e-02,  -6.69555664e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.27148438e-02,   3.27453613e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  1.01959229e-01,   1.01959229e-01],
                        [  1.30798340e-01,   1.30798340e-01],
                        [  1.53442383e-01,   1.53442383e-01],
                        [  1.57745361e-01,   1.57745361e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -1.34246826e-01,  -1.34246826e-01],
                        [ -2.01080322e-01,  -2.01080322e-01],
                        [ -2.30682373e-01,  -2.30712891e-01],
                        [ -2.24670410e-01,  -2.24670410e-01],
                        [ -2.08770752e-01,  -2.08770752e-01],
                        [ -2.07031250e-01,  -2.07061768e-01],
                        [ -2.18750000e-01,  -2.18750000e-01],
                        [ -2.25494385e-01,  -2.25463867e-01],
                        [ -2.13623047e-01,  -2.13623047e-01],
                        [ -1.84478760e-01,  -1.84478760e-01],
                        [ -1.50238037e-01,  -1.50238037e-01],
                        [ -1.24633789e-01,  -1.24633789e-01],
                        [ -1.12365723e-01,  -1.12365723e-01],
                        [ -1.04370117e-01,  -1.04370117e-01],
                        [ -8.86840820e-02,  -8.86535645e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -1.83410645e-02,  -1.83105469e-02],
                        [  4.48608398e-03,   4.51660156e-03],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.56341553e-01,   1.56341553e-01],
                        [  1.51000977e-01,   1.51031494e-01],
                        [  1.46789551e-01,   1.46820068e-01],
                        [  1.53900146e-01,   1.53869629e-01],
                        [  1.74377441e-01,   1.74346924e-01],
                        [  1.98883057e-01,   1.98883057e-01],
                        [  2.12615967e-01,   2.12615967e-01],
                        [  2.08038330e-01,   2.08038330e-01],
                        [  1.89300537e-01,   1.89300537e-01],
                        [  1.64642334e-01,   1.64672852e-01],
                        [  1.39709473e-01,   1.39709473e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  5.08117676e-02,   5.07812500e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.71301270e-02,   2.70996094e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.19421387e-02,   2.19726562e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  3.03649902e-02,   3.03955078e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -2.30712891e-02,  -2.30407715e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.82482910e-02,  -4.82788086e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -6.39648438e-02,  -6.39648438e-02],
                        [ -6.79626465e-02,  -6.79931641e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -5.76782227e-02,  -5.76477051e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -5.15747070e-02,  -5.15441895e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.27258301e-02,   1.26953125e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.65405273e-02,   1.65710449e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  1.03546143e-01,   1.03546143e-01],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.61437988e-01,   1.61437988e-01],
                        [  1.71051025e-01,   1.71051025e-01],
                        [  1.58843994e-01,   1.58843994e-01],
                        [  1.19140625e-01,   1.19140625e-01],
                        [  4.87976074e-02,   4.87976074e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -1.40625000e-01,  -1.40594482e-01],
                        [ -2.17315674e-01,  -2.17315674e-01],
                        [ -2.61322021e-01,  -2.61322021e-01],
                        [ -2.73468018e-01,  -2.73437500e-01],
                        [ -2.65472412e-01,  -2.65472412e-01],
                        [ -2.51312256e-01,  -2.51312256e-01],
                        [ -2.37548828e-01,  -2.37548828e-01],
                        [ -2.19940186e-01,  -2.19940186e-01],
                        [ -1.91528320e-01,  -1.91528320e-01],
                        [ -1.55731201e-01,  -1.55731201e-01],
                        [ -1.26129150e-01,  -1.26129150e-01],
                        [ -1.09985352e-01,  -1.09985352e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -8.13293457e-02,  -8.12988281e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  9.41772461e-02,   9.41772461e-02],
                        [  1.26831055e-01,   1.26800537e-01],
                        [  1.52587891e-01,   1.52618408e-01],
                        [  1.67053223e-01,   1.67053223e-01],
                        [  1.70898438e-01,   1.70867920e-01],
                        [  1.72363281e-01,   1.72393799e-01],
                        [  1.78985596e-01,   1.78985596e-01],
                        [  1.89483643e-01,   1.89483643e-01],
                        [  1.96166992e-01,   1.96166992e-01],
                        [  1.93908691e-01,   1.93939209e-01],
                        [  1.84387207e-01,   1.84356689e-01],
                        [  1.70104980e-01,   1.70104980e-01],
                        [  1.50482178e-01,   1.50512695e-01],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.02111816e-01,   1.02111816e-01],
                        [  7.94067383e-02,   7.94372559e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.35192871e-02,   1.34887695e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.23083496e-02,   2.22778320e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  1.30310059e-02,   1.30615234e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.00500488e-02,  -2.00805664e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -7.27844238e-02,  -7.27844238e-02],
                        [ -7.62634277e-02,  -7.62634277e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.81457520e-02,  -6.81152344e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -6.37512207e-02,  -6.37207031e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  1.06811523e-03,   1.03759766e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.52893066e-02,  -1.52587891e-02],
                        [ -1.93176270e-02,  -1.93481445e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.47192383e-03,  -2.44140625e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  5.13305664e-02,   5.13000488e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  7.69348145e-02,   7.69653320e-02],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  1.32751465e-01,   1.32751465e-01],
                        [  1.64642334e-01,   1.64642334e-01],
                        [  1.88629150e-01,   1.88629150e-01],
                        [  1.93267822e-01,   1.93267822e-01],
                        [  1.63909912e-01,   1.63909912e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [ -1.17797852e-02,  -1.18103027e-02],
                        [ -1.29516602e-01,  -1.29516602e-01],
                        [ -2.36022949e-01,  -2.36022949e-01],
                        [ -3.08288574e-01,  -3.08288574e-01],
                        [ -3.32244873e-01,  -3.32244873e-01],
                        [ -3.13598633e-01,  -3.13598633e-01],
                        [ -2.74658203e-01,  -2.74658203e-01],
                        [ -2.35595703e-01,  -2.35595703e-01],
                        [ -2.01599121e-01,  -2.01599121e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.41815186e-01,  -1.41815186e-01],
                        [ -1.22558594e-01,  -1.22558594e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -1.00982666e-01,  -1.00982666e-01],
                        [ -8.42590332e-02,  -8.42590332e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  2.34069824e-02,   2.34375000e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  1.41662598e-01,   1.41662598e-01],
                        [  1.74652100e-01,   1.74652100e-01],
                        [  1.92352295e-01,   1.92321777e-01],
                        [  2.00836182e-01,   2.00836182e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  2.15332031e-01,   2.15301514e-01],
                        [  2.15423584e-01,   2.15423584e-01],
                        [  2.02453613e-01,   2.02453613e-01],
                        [  1.81091309e-01,   1.81091309e-01],
                        [  1.61743164e-01,   1.61743164e-01],
                        [  1.47888184e-01,   1.47888184e-01],
                        [  1.34948730e-01,   1.34948730e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  6.21032715e-02,   6.21337891e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.92260742e-03,   1.95312500e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  7.56835938e-03,   7.53784180e-03],
                        [  1.22375488e-02,   1.22680664e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  2.46887207e-02,   2.46582031e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.09252930e-02,  -1.09558105e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.64282227e-02,  -2.64587402e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -7.45849609e-02,  -7.45849609e-02],
                        [ -8.19396973e-02,  -8.19396973e-02],
                        [ -8.68835449e-02,  -8.68835449e-02],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.77307129e-02,  -1.77612305e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.70135498e-01,   1.70135498e-01],
                        [  2.01599121e-01,   2.01599121e-01],
                        [  2.04711914e-01,   2.04711914e-01],
                        [  1.71447754e-01,   1.71478271e-01],
                        [  1.00250244e-01,   1.00250244e-01],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -1.39739990e-01,  -1.39739990e-01],
                        [ -2.71087646e-01,  -2.71087646e-01],
                        [ -3.63952637e-01,  -3.63952637e-01],
                        [ -3.90106201e-01,  -3.90106201e-01],
                        [ -3.52691650e-01,  -3.52691650e-01],
                        [ -2.84820557e-01,  -2.84790039e-01],
                        [ -2.21527100e-01,  -2.21527100e-01],
                        [ -1.78039551e-01,  -1.78039551e-01],
                        [ -1.51977539e-01,  -1.51977539e-01],
                        [ -1.34887695e-01,  -1.34887695e-01],
                        [ -1.19110107e-01,  -1.19110107e-01],
                        [ -1.02172852e-01,  -1.02172852e-01],
                        [ -8.82263184e-02,  -8.82568359e-02],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [  1.56555176e-02,   1.56250000e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  1.20300293e-01,   1.20330811e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  2.17834473e-01,   2.17834473e-01],
                        [  2.45758057e-01,   2.45788574e-01],
                        [  2.55218506e-01,   2.55218506e-01],
                        [  2.48870850e-01,   2.48840332e-01],
                        [  2.33978271e-01,   2.34008789e-01],
                        [  2.14874268e-01,   2.14874268e-01],
                        [  1.91467285e-01,   1.91467285e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.45507812e-01,   1.45507812e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.16271973e-01,   1.16271973e-01],
                        [  9.75036621e-02,   9.75341797e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  6.18286133e-02,   6.17980957e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  3.17687988e-02,   3.17993164e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  1.23291016e-02,   1.23596191e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.84936523e-02,   1.85241699e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.07519531e-03,   2.07519531e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.43432617e-02,  -1.43737793e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -5.84716797e-02,  -5.84411621e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -5.32531738e-02,  -5.32836914e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.32324219e-02,  -6.32629395e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -7.89489746e-02,  -7.89489746e-02],
                        [ -7.57141113e-02,  -7.57446289e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -3.63769531e-02,  -3.63464355e-02],
                        [ -2.49328613e-02,  -2.49023438e-02],
                        [ -1.82495117e-02,  -1.82800293e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.40991211e-02,  -1.40686035e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.72119141e-02,  -1.72424316e-02],
                        [ -2.24914551e-02,  -2.24609375e-02],
                        [ -2.55737305e-02,  -2.55432129e-02],
                        [ -2.19116211e-02,  -2.19421387e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -9.18579102e-03,  -9.15527344e-03],
                        [ -4.36401367e-03,  -4.39453125e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  1.25823975e-01,   1.25854492e-01],
                        [  1.60705566e-01,   1.60675049e-01],
                        [  1.90979004e-01,   1.90979004e-01],
                        [  1.99188232e-01,   1.99188232e-01],
                        [  1.70166016e-01,   1.70166016e-01],
                        [  9.65576172e-02,   9.65270996e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.65985107e-01,  -1.65954590e-01],
                        [ -3.05633545e-01,  -3.05664062e-01],
                        [ -3.95324707e-01,  -3.95355225e-01],
                        [ -4.09362793e-01,  -4.09332275e-01],
                        [ -3.57788086e-01,  -3.57788086e-01],
                        [ -2.76397705e-01,  -2.76397705e-01],
                        [ -2.03094482e-01,  -2.03094482e-01],
                        [ -1.58294678e-01,  -1.58294678e-01],
                        [ -1.37268066e-01,  -1.37298584e-01],
                        [ -1.21124268e-01,  -1.21124268e-01],
                        [ -9.87854004e-02,  -9.87854004e-02],
                        [ -7.56835938e-02,  -7.57141113e-02],
                        [ -6.19506836e-02,  -6.19812012e-02],
                        [ -5.79223633e-02,  -5.78918457e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  8.45336914e-03,   8.48388672e-03],
                        [  9.24682617e-03,   9.21630859e-03],
                        [ -7.93457031e-03,  -7.96508789e-03],
                        [ -3.16467285e-02,  -3.16162109e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  1.06872559e-01,   1.06903076e-01],
                        [  1.81457520e-01,   1.81457520e-01],
                        [  2.43591309e-01,   2.43560791e-01],
                        [  2.74078369e-01,   2.74078369e-01],
                        [  2.71148682e-01,   2.71148682e-01],
                        [  2.52136230e-01,   2.52136230e-01],
                        [  2.34527588e-01,   2.34527588e-01],
                        [  2.20275879e-01,   2.20275879e-01],
                        [  2.03155518e-01,   2.03155518e-01],
                        [  1.81640625e-01,   1.81640625e-01],
                        [  1.58111572e-01,   1.58111572e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  8.94775391e-02,   8.94775391e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -1.41601562e-02,  -1.41296387e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -8.34655762e-02,  -8.34655762e-02],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -8.64562988e-02,  -8.64257812e-02],
                        [ -8.14819336e-02,  -8.14819336e-02],
                        [ -7.37609863e-02,  -7.37915039e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.68859863e-02,  -2.69165039e-02],
                        [ -2.17590332e-02,  -2.17285156e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  3.87878418e-02,   3.87573242e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.50787354e-01,   1.50787354e-01],
                        [  1.80267334e-01,   1.80267334e-01],
                        [  1.93420410e-01,   1.93420410e-01],
                        [  1.78771973e-01,   1.78802490e-01],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  2.44750977e-02,   2.44445801e-02],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -2.50976562e-01,  -2.50976562e-01],
                        [ -3.66302490e-01,  -3.66302490e-01],
                        [ -4.14215088e-01,  -4.14245605e-01],
                        [ -3.82781982e-01,  -3.82781982e-01],
                        [ -3.04229736e-01,  -3.04229736e-01],
                        [ -2.28637695e-01,  -2.28668213e-01],
                        [ -1.83135986e-01,  -1.83135986e-01],
                        [ -1.60644531e-01,  -1.60644531e-01],
                        [ -1.40808105e-01,  -1.40808105e-01],
                        [ -1.13800049e-01,  -1.13800049e-01],
                        [ -8.68835449e-02,  -8.68835449e-02],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.92260742e-03,  -1.95312500e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.72515869e-01,   1.72515869e-01],
                        [  2.34893799e-01,   2.34893799e-01],
                        [  2.73132324e-01,   2.73162842e-01],
                        [  2.78259277e-01,   2.78259277e-01],
                        [  2.57751465e-01,   2.57751465e-01],
                        [  2.29248047e-01,   2.29248047e-01],
                        [  2.06298828e-01,   2.06298828e-01],
                        [  1.90155029e-01,   1.90124512e-01],
                        [  1.73980713e-01,   1.73980713e-01],
                        [  1.54388428e-01,   1.54388428e-01],
                        [  1.35314941e-01,   1.35314941e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  8.34655762e-02,   8.34350586e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  8.72802734e-03,   8.69750977e-03],
                        [  6.40869141e-03,   6.43920898e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  3.50952148e-03,   3.54003906e-03],
                        [  1.77001953e-03,   1.73950195e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.64794922e-03,  -1.61743164e-03],
                        [ -2.13623047e-03,  -2.10571289e-03],
                        [ -3.41796875e-03,  -3.44848633e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.59094238e-02,  -2.59399414e-02],
                        [ -3.89709473e-02,  -3.89404297e-02],
                        [ -4.73937988e-02,  -4.74243164e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.27856445e-02,  -4.27551270e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.41186523e-02,  -3.41491699e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.58374023e-02,  -4.58068848e-02],
                        [ -5.48095703e-02,  -5.48400879e-02],
                        [ -5.89294434e-02,  -5.89599609e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -6.19812012e-02,  -6.20117188e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.64062500e-02,  -6.64367676e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -5.98144531e-02,  -5.97839355e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -4.54406738e-02,  -4.54406738e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -8.75854492e-03,  -8.72802734e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  1.65710449e-02,   1.66015625e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  7.15026855e-02,   7.15332031e-02],
                        [  8.62731934e-02,   8.62426758e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.54022217e-01,   1.53991699e-01],
                        [  1.77215576e-01,   1.77185059e-01],
                        [  1.78863525e-01,   1.78863525e-01],
                        [  1.46881104e-01,   1.46881104e-01],
                        [  7.77282715e-02,   7.77282715e-02],
                        [ -2.75268555e-02,  -2.74963379e-02],
                        [ -1.58477783e-01,  -1.58477783e-01],
                        [ -2.85736084e-01,  -2.85766602e-01],
                        [ -3.69903564e-01,  -3.69873047e-01],
                        [ -3.86749268e-01,  -3.86749268e-01],
                        [ -3.43811035e-01,  -3.43841553e-01],
                        [ -2.73681641e-01,  -2.73681641e-01],
                        [ -2.11334229e-01,  -2.11334229e-01],
                        [ -1.72210693e-01,  -1.72241211e-01],
                        [ -1.49139404e-01,  -1.49139404e-01],
                        [ -1.27990723e-01,  -1.27990723e-01],
                        [ -1.04675293e-01,  -1.04705811e-01],
                        [ -8.62426758e-02,  -8.62426758e-02],
                        [ -7.66296387e-02,  -7.66296387e-02],
                        [ -6.69250488e-02,  -6.69555664e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -2.09960938e-02,  -2.09655762e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  9.88769531e-03,   9.91821289e-03],
                        [  1.00708008e-03,   1.03759766e-03],
                        [ -1.27868652e-02,  -1.28173828e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -3.93371582e-02,  -3.93066406e-02],
                        [ -4.84924316e-02,  -4.85229492e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  4.10766602e-02,   4.10461426e-02],
                        [  1.17736816e-01,   1.17736816e-01],
                        [  1.98455811e-01,   1.98455811e-01],
                        [  2.65563965e-01,   2.65563965e-01],
                        [  3.03833008e-01,   3.03833008e-01],
                        [  3.04473877e-01,   3.04473877e-01],
                        [  2.73040771e-01,   2.73040771e-01],
                        [  2.30957031e-01,   2.30926514e-01],
                        [  1.99035645e-01,   1.99035645e-01],
                        [  1.80267334e-01,   1.80267334e-01],
                        [  1.65313721e-01,   1.65313721e-01],
                        [  1.49108887e-01,   1.49078369e-01],
                        [  1.32995605e-01,   1.32995605e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  9.88769531e-02,   9.88464355e-02],
                        [  7.73620605e-02,   7.73925781e-02],
                        [  5.31005859e-02,   5.31311035e-02],
                        [  2.90222168e-02,   2.89916992e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  3.96728516e-03,   3.99780273e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.80053711e-02,   1.80358887e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  3.58276367e-02,   3.58581543e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  9.33837891e-03,   9.30786133e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -2.74658203e-03,  -2.77709961e-03],
                        [ -1.38854980e-02,  -1.38549805e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -1.29089355e-02,  -1.29394531e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.62048340e-02,  -1.61743164e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -4.15954590e-02,  -4.15649414e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -6.59179688e-02,  -6.58874512e-02],
                        [ -7.22656250e-02,  -7.22656250e-02],
                        [ -7.54089355e-02,  -7.54089355e-02],
                        [ -7.40966797e-02,  -7.41271973e-02],
                        [ -6.84814453e-02,  -6.84509277e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.16455078e-02,  -6.16760254e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.43823242e-02,  -5.44128418e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.25000000e-02,  -6.24694824e-02],
                        [ -6.83898926e-02,  -6.84204102e-02],
                        [ -6.79626465e-02,  -6.79931641e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -3.77502441e-02,  -3.77807617e-02],
                        [ -2.63366699e-02,  -2.63061523e-02],
                        [ -1.96228027e-02,  -1.95922852e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -9.30786133e-03,  -9.27734375e-03],
                        [ -4.24194336e-03,  -4.27246094e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  2.87780762e-02,   2.87475586e-02],
                        [  3.85742188e-02,   3.85437012e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  4.94995117e-02,   4.94689941e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.35314941e-01,   1.35314941e-01],
                        [  1.62963867e-01,   1.62963867e-01],
                        [  1.83441162e-01,   1.83441162e-01],
                        [  1.81213379e-01,   1.81213379e-01],
                        [  1.43371582e-01,   1.43371582e-01],
                        [  6.46057129e-02,   6.46057129e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -1.86065674e-01,  -1.86065674e-01],
                        [ -3.07983398e-01,  -3.07983398e-01],
                        [ -3.81317139e-01,  -3.81317139e-01],
                        [ -3.87512207e-01,  -3.87512207e-01],
                        [ -3.37768555e-01,  -3.37768555e-01],
                        [ -2.66143799e-01,  -2.66143799e-01],
                        [ -2.05291748e-01,  -2.05291748e-01],
                        [ -1.67083740e-01,  -1.67083740e-01],
                        [ -1.44348145e-01,  -1.44317627e-01],
                        [ -1.24908447e-01,  -1.24908447e-01],
                        [ -1.02691650e-01,  -1.02722168e-01],
                        [ -8.05969238e-02,  -8.05969238e-02],
                        [ -6.34460449e-02,  -6.34155273e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -2.67944336e-02,  -2.68249512e-02],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -7.10144043e-02,  -7.09838867e-02],
                        [ -8.02001953e-02,  -8.02001953e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  1.92443848e-01,   1.92443848e-01],
                        [  2.73590088e-01,   2.73620605e-01],
                        [  3.24493408e-01,   3.24493408e-01],
                        [  3.32794189e-01,   3.32794189e-01],
                        [  3.04443359e-01,   3.04473877e-01],
                        [  2.58514404e-01,   2.58514404e-01],
                        [  2.13043213e-01,   2.13043213e-01],
                        [  1.75506592e-01,   1.75506592e-01],
                        [  1.45843506e-01,   1.45843506e-01],
                        [  1.24267578e-01,   1.24237061e-01],
                        [  1.11328125e-01,   1.11358643e-01],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  7.65991211e-02,   7.66296387e-02],
                        [  5.32226562e-02,   5.31921387e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.62048340e-02,  -1.61743164e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -7.73010254e-02,  -7.73010254e-02],
                        [ -7.78198242e-02,  -7.77893066e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -7.46459961e-02,  -7.46459961e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -7.28759766e-02,  -7.28759766e-02],
                        [ -6.82373047e-02,  -6.82067871e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -3.58276367e-02,  -3.57971191e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -2.74658203e-02,  -2.74963379e-02],
                        [ -2.33459473e-02,  -2.33154297e-02],
                        [ -1.28784180e-02,  -1.28479004e-02],
                        [ -6.40869141e-04,  -6.71386719e-04],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  4.84313965e-02,   4.84619141e-02],
                        [  6.10046387e-02,   6.09741211e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  1.17736816e-01,   1.17706299e-01],
                        [  1.47399902e-01,   1.47399902e-01],
                        [  1.72637939e-01,   1.72637939e-01],
                        [  1.76513672e-01,   1.76483154e-01],
                        [  1.48498535e-01,   1.48498535e-01],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -9.89685059e-02,  -9.89685059e-02],
                        [ -2.04376221e-01,  -2.04376221e-01],
                        [ -2.97943115e-01,  -2.97943115e-01],
                        [ -3.59405518e-01,  -3.59405518e-01],
                        [ -3.72436523e-01,  -3.72436523e-01],
                        [ -3.37066650e-01,  -3.37066650e-01],
                        [ -2.72460938e-01,  -2.72460938e-01],
                        [ -2.05383301e-01,  -2.05383301e-01],
                        [ -1.53717041e-01,  -1.53686523e-01],
                        [ -1.17828369e-01,  -1.17797852e-01],
                        [ -8.84704590e-02,  -8.85009766e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -4.84008789e-02,  -4.83703613e-02],
                        [ -4.47387695e-02,  -4.47692871e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -3.08837891e-02,  -3.08532715e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [  7.01904297e-04,   6.71386719e-04],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -5.95092773e-02,  -5.95397949e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -6.60095215e-02,  -6.59790039e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  1.84234619e-01,   1.84234619e-01],
                        [  2.58789062e-01,   2.58789062e-01],
                        [  3.03192139e-01,   3.03192139e-01],
                        [  3.08441162e-01,   3.08441162e-01],
                        [  2.82623291e-01,   2.82623291e-01],
                        [  2.44079590e-01,   2.44079590e-01],
                        [  2.07244873e-01,   2.07244873e-01],
                        [  1.76635742e-01,   1.76605225e-01],
                        [  1.50970459e-01,   1.50970459e-01],
                        [  1.29028320e-01,   1.29028320e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  8.87145996e-02,   8.87451172e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  6.19506836e-03,   6.22558594e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  8.30078125e-03,   8.33129883e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.32238770e-02,  -2.32543945e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.23999023e-02,  -2.23693848e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.37121582e-02,  -2.37426758e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -6.09130859e-02,  -6.09436035e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -7.25097656e-02,  -7.25402832e-02],
                        [ -6.36596680e-02,  -6.36291504e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.59497070e-02,  -3.59191895e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.10778809e-02,  -1.10473633e-02],
                        [ -2.25830078e-03,  -2.28881836e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.89819336e-02,   1.90124512e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  1.03515625e-01,   1.03546143e-01],
                        [  1.25213623e-01,   1.25244141e-01],
                        [  1.44561768e-01,   1.44531250e-01],
                        [  1.57562256e-01,   1.57531738e-01],
                        [  1.56097412e-01,   1.56127930e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -1.46118164e-01,  -1.46118164e-01],
                        [ -2.34069824e-01,  -2.34069824e-01],
                        [ -3.08898926e-01,  -3.08898926e-01],
                        [ -3.52630615e-01,  -3.52661133e-01],
                        [ -3.51226807e-01,  -3.51226807e-01],
                        [ -3.07067871e-01,  -3.07067871e-01],
                        [ -2.41577148e-01,  -2.41577148e-01],
                        [ -1.81945801e-01,  -1.81945801e-01],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.19812012e-01,  -1.19812012e-01],
                        [ -9.86328125e-02,  -9.86328125e-02],
                        [ -7.53479004e-02,  -7.53479004e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -4.75463867e-02,  -4.75769043e-02],
                        [ -3.67431641e-02,  -3.67736816e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -5.47790527e-02,  -5.47485352e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -8.14819336e-03,  -8.11767578e-03],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  1.12304688e-01,   1.12274170e-01],
                        [  1.92504883e-01,   1.92535400e-01],
                        [  2.62023926e-01,   2.62054443e-01],
                        [  3.01696777e-01,   3.01696777e-01],
                        [  3.07281494e-01,   3.07281494e-01],
                        [  2.85705566e-01,   2.85736084e-01],
                        [  2.47680664e-01,   2.47680664e-01],
                        [  2.05352783e-01,   2.05322266e-01],
                        [  1.69189453e-01,   1.69189453e-01],
                        [  1.43402100e-01,   1.43402100e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  9.89379883e-02,   9.89685059e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.88586426e-02,   4.88891602e-02],
                        [  5.74035645e-02,   5.73730469e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -2.53295898e-03,  -2.50244141e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -2.07519531e-03,  -2.10571289e-03],
                        [ -5.06591797e-03,  -5.03540039e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.55639648e-03,  -1.58691406e-03],
                        [  1.12915039e-03,   1.15966797e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -6.85729980e-02,  -6.85729980e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -6.72607422e-02,  -6.72912598e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  8.90808105e-02,   8.90502930e-02],
                        [  1.12792969e-01,   1.12792969e-01],
                        [  1.33209229e-01,   1.33239746e-01],
                        [  1.46331787e-01,   1.46301270e-01],
                        [  1.48162842e-01,   1.48162842e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [ -1.87072754e-02,  -1.86767578e-02],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -1.57562256e-01,  -1.57562256e-01],
                        [ -2.28118896e-01,  -2.28118896e-01],
                        [ -2.93853760e-01,  -2.93853760e-01],
                        [ -3.37463379e-01,  -3.37463379e-01],
                        [ -3.38195801e-01,  -3.38195801e-01],
                        [ -2.93548584e-01,  -2.93548584e-01],
                        [ -2.27935791e-01,  -2.27935791e-01],
                        [ -1.73339844e-01,  -1.73339844e-01],
                        [ -1.41357422e-01,  -1.41357422e-01],
                        [ -1.19537354e-01,  -1.19537354e-01],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.51464844e-02,  -2.51159668e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  7.98339844e-02,   7.98034668e-02],
                        [  1.43859863e-01,   1.43829346e-01],
                        [  2.09747314e-01,   2.09747314e-01],
                        [  2.61566162e-01,   2.61596680e-01],
                        [  2.88543701e-01,   2.88543701e-01],
                        [  2.87200928e-01,   2.87200928e-01],
                        [  2.62298584e-01,   2.62298584e-01],
                        [  2.26898193e-01,   2.26898193e-01],
                        [  1.94793701e-01,   1.94793701e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.48986816e-01,   1.48986816e-01],
                        [  1.26586914e-01,   1.26556396e-01],
                        [  1.04156494e-01,   1.04187012e-01],
                        [  8.52661133e-02,   8.52966309e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  3.64685059e-02,   3.64990234e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.02941895e-02,   2.02636719e-02],
                        [  1.66015625e-02,   1.66320801e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  2.33154297e-02,   2.33459473e-02],
                        [  3.53698730e-02,   3.53393555e-02],
                        [  4.34570312e-02,   4.34265137e-02],
                        [  4.44946289e-02,   4.45251465e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  2.88085938e-02,   2.87780762e-02],
                        [  2.14843750e-02,   2.15148926e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -4.97436523e-03,  -5.00488281e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  7.29370117e-03,   7.32421875e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -4.92858887e-02,  -4.92553711e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.14831543e-02,  -5.14526367e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -5.87463379e-02,  -5.87768555e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -6.55212402e-02,  -6.55212402e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  7.11059570e-03,   7.14111328e-03],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  1.18835449e-01,   1.18865967e-01],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.14959717e-01,   1.14929199e-01],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  6.31408691e-02,   6.31713867e-02],
                        [  1.90124512e-02,   1.89819336e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -1.28631592e-01,  -1.28662109e-01],
                        [ -1.86523438e-01,  -1.86492920e-01],
                        [ -2.60467529e-01,  -2.60467529e-01],
                        [ -3.13995361e-01,  -3.14025879e-01],
                        [ -3.14453125e-01,  -3.14453125e-01],
                        [ -2.63885498e-01,  -2.63885498e-01],
                        [ -1.94488525e-01,  -1.94488525e-01],
                        [ -1.40747070e-01,  -1.40747070e-01],
                        [ -1.15570068e-01,  -1.15570068e-01],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -8.87145996e-02,  -8.87451172e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -3.22570801e-02,  -3.22265625e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -6.10351562e-05,  -3.05175781e-05],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -2.35290527e-02,  -2.35595703e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.88085938e-02,  -2.87780762e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -6.40869141e-04,  -6.71386719e-04],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  1.55792236e-01,   1.55792236e-01],
                        [  1.99737549e-01,   1.99768066e-01],
                        [  2.37579346e-01,   2.37579346e-01],
                        [  2.64495850e-01,   2.64495850e-01],
                        [  2.71759033e-01,   2.71789551e-01],
                        [  2.56011963e-01,   2.56011963e-01],
                        [  2.27294922e-01,   2.27264404e-01],
                        [  1.98059082e-01,   1.98059082e-01],
                        [  1.69830322e-01,   1.69860840e-01],
                        [  1.40197754e-01,   1.40167236e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  9.14916992e-02,   9.15222168e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  6.11572266e-02,   6.11267090e-02],
                        [  4.94995117e-02,   4.95300293e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  3.55529785e-02,   3.55224609e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  7.47680664e-03,   7.44628906e-03],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  2.50854492e-02,   2.51159668e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  2.18811035e-02,   2.18505859e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  7.62939453e-04,   7.93457031e-04],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.23791504e-02,  -3.24096680e-02],
                        [ -3.43933105e-02,  -3.43627930e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.84619141e-02,  -4.84924316e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.99975586e-02,  -6.00280762e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -6.41174316e-02,  -6.40869141e-02],
                        [ -6.31408691e-02,  -6.31713867e-02],
                        [ -6.06994629e-02,  -6.07299805e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -5.76782227e-02,  -5.76477051e-02],
                        [ -5.64880371e-02,  -5.65185547e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -6.00891113e-02,  -6.00585938e-02],
                        [ -5.92041016e-02,  -5.92041016e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.02929688e-02,  -5.02624512e-02],
                        [ -4.24499512e-02,  -4.24194336e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.44348145e-02,  -1.44653320e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  4.30297852e-03,   4.33349609e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  1.05407715e-01,   1.05438232e-01],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -1.01562500e-01,  -1.01562500e-01],
                        [ -1.79779053e-01,  -1.79779053e-01],
                        [ -2.64099121e-01,  -2.64099121e-01],
                        [ -3.16223145e-01,  -3.16223145e-01],
                        [ -3.09967041e-01,  -3.09967041e-01],
                        [ -2.54364014e-01,  -2.54333496e-01],
                        [ -1.86096191e-01,  -1.86126709e-01],
                        [ -1.37054443e-01,  -1.37054443e-01],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -9.49707031e-02,  -9.49707031e-02],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  7.59887695e-03,   7.62939453e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  7.34863281e-02,   7.35168457e-02],
                        [  1.06536865e-01,   1.06536865e-01],
                        [  1.43218994e-01,   1.43218994e-01],
                        [  1.80999756e-01,   1.81030273e-01],
                        [  2.17559814e-01,   2.17559814e-01],
                        [  2.51342773e-01,   2.51342773e-01],
                        [  2.73651123e-01,   2.73681641e-01],
                        [  2.70751953e-01,   2.70751953e-01],
                        [  2.40966797e-01,   2.40936279e-01],
                        [  1.99523926e-01,   1.99554443e-01],
                        [  1.62292480e-01,   1.62322998e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.09680176e-01,   1.09680176e-01],
                        [  8.86840820e-02,   8.87145996e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  5.70983887e-02,   5.70678711e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  3.45764160e-02,   3.46069336e-02],
                        [  2.64282227e-02,   2.63977051e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  1.99279785e-02,   1.99584961e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  3.88793945e-02,   3.89099121e-02],
                        [  4.42810059e-02,   4.43115234e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  4.37011719e-02,   4.37316895e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -3.93676758e-03,  -3.96728516e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -7.30590820e-02,  -7.30590820e-02],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -7.28759766e-02,  -7.28759766e-02],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -5.69763184e-02,  -5.70068359e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -2.34985352e-03,  -2.31933594e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  3.23486328e-03,   3.20434570e-03],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  9.90295410e-02,   9.89990234e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  1.00677490e-01,   1.00708008e-01],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -1.75811768e-01,  -1.75781250e-01],
                        [ -2.61047363e-01,  -2.61047363e-01],
                        [ -3.05816650e-01,  -3.05816650e-01],
                        [ -2.94097900e-01,  -2.94067383e-01],
                        [ -2.40509033e-01,  -2.40509033e-01],
                        [ -1.77764893e-01,  -1.77795410e-01],
                        [ -1.33728027e-01,  -1.33728027e-01],
                        [ -1.13006592e-01,  -1.13006592e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -2.06298828e-02,  -2.06604004e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  1.26037598e-02,   1.25732422e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  1.52587891e-02,   1.52282715e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  3.99780273e-03,   4.02832031e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  6.21337891e-02,   6.21032715e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  1.01287842e-01,   1.01318359e-01],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  1.45538330e-01,   1.45538330e-01],
                        [  1.81365967e-01,   1.81365967e-01],
                        [  2.20336914e-01,   2.20336914e-01],
                        [  2.49023438e-01,   2.48992920e-01],
                        [  2.55432129e-01,   2.55432129e-01],
                        [  2.39471436e-01,   2.39471436e-01],
                        [  2.11517334e-01,   2.11517334e-01],
                        [  1.80603027e-01,   1.80603027e-01],
                        [  1.50238037e-01,   1.50238037e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  8.70666504e-02,   8.70666504e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.09753418e-02,   3.10058594e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.34069824e-02,   2.33764648e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  3.28979492e-02,   3.29284668e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.40380859e-02,   1.40075684e-02],
                        [  5.31005859e-03,   5.27954102e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -1.08642578e-02,  -1.08947754e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.52783203e-02,  -3.53088379e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.32434082e-02,  -4.32128906e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.29174805e-02,  -5.29479980e-02],
                        [ -5.35583496e-02,  -5.35278320e-02],
                        [ -5.23681641e-02,  -5.23376465e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -7.46154785e-02,  -7.46154785e-02],
                        [ -7.73010254e-02,  -7.72705078e-02],
                        [ -7.72399902e-02,  -7.72399902e-02],
                        [ -7.37304688e-02,  -7.37609863e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -2.27050781e-02,  -2.27355957e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.81164551e-02,   3.80859375e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -8.00476074e-02,  -8.00170898e-02],
                        [ -4.82177734e-02,  -4.82482910e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -1.61712646e-01,  -1.61712646e-01],
                        [ -2.48413086e-01,  -2.48413086e-01],
                        [ -2.99255371e-01,  -2.99255371e-01],
                        [ -2.94464111e-01,  -2.94464111e-01],
                        [ -2.42340088e-01,  -2.42340088e-01],
                        [ -1.73583984e-01,  -1.73614502e-01],
                        [ -1.16607666e-01,  -1.16638184e-01],
                        [ -8.16955566e-02,  -8.16650391e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -5.08728027e-02,  -5.09033203e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.52783203e-02,  -3.53088379e-02],
                        [ -3.95812988e-02,  -3.96118164e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  1.54418945e-02,   1.54113770e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  7.23266602e-02,   7.22961426e-02],
                        [  8.77685547e-02,   8.77990723e-02],
                        [  9.24682617e-02,   9.24987793e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  1.00799561e-01,   1.00830078e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.68365479e-01,   1.68365479e-01],
                        [  2.09899902e-01,   2.09930420e-01],
                        [  2.34130859e-01,   2.34130859e-01],
                        [  2.31719971e-01,   2.31689453e-01],
                        [  2.08374023e-01,   2.08374023e-01],
                        [  1.77398682e-01,   1.77429199e-01],
                        [  1.51000977e-01,   1.50970459e-01],
                        [  1.34368896e-01,   1.34368896e-01],
                        [  1.22192383e-01,   1.22222900e-01],
                        [  1.05255127e-01,   1.05255127e-01],
                        [  8.37402344e-02,   8.37097168e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  5.52673340e-02,   5.52673340e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  3.90930176e-02,   3.91235352e-02],
                        [  3.11584473e-02,   3.11279297e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  1.46484375e-02,   1.46179199e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  1.52282715e-02,   1.51977539e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.73034668e-02,   1.72729492e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  7.72094727e-03,   7.75146484e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [ -6.53076172e-03,  -6.56127930e-03],
                        [ -1.10778809e-02,  -1.10473633e-02],
                        [ -1.29699707e-02,  -1.29394531e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.15051270e-02,  -1.14746094e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -5.42602539e-02,  -5.42297363e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -5.74035645e-02,  -5.74340820e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.95703125e-02,  -5.96008301e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.19201660e-02,  -6.18896484e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  7.61413574e-02,   7.61413574e-02],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -9.28955078e-02,  -9.28955078e-02],
                        [ -9.91516113e-02,  -9.91516113e-02],
                        [ -6.76879883e-02,  -6.77185059e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  3.10974121e-02,   3.10668945e-02],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -5.92956543e-02,  -5.92651367e-02],
                        [ -1.38000488e-01,  -1.38000488e-01],
                        [ -2.16247559e-01,  -2.16247559e-01],
                        [ -2.68157959e-01,  -2.68157959e-01],
                        [ -2.73712158e-01,  -2.73712158e-01],
                        [ -2.36206055e-01,  -2.36206055e-01],
                        [ -1.81304932e-01,  -1.81304932e-01],
                        [ -1.34674072e-01,  -1.34643555e-01],
                        [ -1.03820801e-01,  -1.03820801e-01],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.62451172e-03,  -2.59399414e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.93786621e-02,   1.93481445e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.86560059e-02,   2.86865234e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  9.39025879e-02,   9.39331055e-02],
                        [  1.04125977e-01,   1.04125977e-01],
                        [  1.04095459e-01,   1.04064941e-01],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  1.49627686e-01,   1.49627686e-01],
                        [  1.93664551e-01,   1.93695068e-01],
                        [  2.27844238e-01,   2.27844238e-01],
                        [  2.38403320e-01,   2.38403320e-01],
                        [  2.25677490e-01,   2.25677490e-01],
                        [  1.98242188e-01,   1.98242188e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.39190674e-01,   1.39190674e-01],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  6.40258789e-02,   6.40563965e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  6.79016113e-02,   6.78710938e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  4.92248535e-02,   4.91943359e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  7.62939453e-04,   7.32421875e-04],
                        [  1.89208984e-03,   1.92260742e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.64794922e-02,   1.65100098e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -9.67407227e-03,  -9.64355469e-03],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -4.40368652e-02,  -4.40673828e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.75769043e-02,  -4.76074219e-02],
                        [ -5.16052246e-02,  -5.15747070e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -6.21948242e-02,  -6.22253418e-02],
                        [ -6.51855469e-02,  -6.51550293e-02],
                        [ -6.57043457e-02,  -6.56738281e-02],
                        [ -6.49414062e-02,  -6.49719238e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -6.83288574e-02,  -6.82983398e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -5.53894043e-02,  -5.53588867e-02],
                        [ -5.12695312e-02,  -5.13000488e-02],
                        [ -4.52575684e-02,  -4.52880859e-02],
                        [ -3.67431641e-02,  -3.67126465e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -7.38525391e-03,  -7.35473633e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  6.68334961e-03,   6.71386719e-03],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  7.67517090e-02,   7.67822266e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  8.38317871e-02,   8.38623047e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  6.13403320e-03,   6.10351562e-03],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -8.36181641e-02,  -8.36181641e-02],
                        [ -9.09423828e-02,  -9.09423828e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  2.31018066e-02,   2.31323242e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -1.99707031e-01,  -1.99676514e-01],
                        [ -2.71820068e-01,  -2.71850586e-01],
                        [ -2.99407959e-01,  -2.99407959e-01],
                        [ -2.71240234e-01,  -2.71240234e-01],
                        [ -2.06451416e-01,  -2.06451416e-01],
                        [ -1.39434814e-01,  -1.39434814e-01],
                        [ -9.53979492e-02,  -9.53979492e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -6.97937012e-02,  -6.97937012e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -4.08935547e-02,  -4.08630371e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.99072266e-02,  -2.99377441e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  2.16674805e-03,   2.19726562e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.35192871e-02,   1.34887695e-02],
                        [  1.91040039e-02,   1.91345215e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  6.74743652e-02,   6.74743652e-02],
                        [  8.53881836e-02,   8.54187012e-02],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  8.77685547e-02,   8.77380371e-02],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  1.51428223e-01,   1.51428223e-01],
                        [  1.99279785e-01,   1.99279785e-01],
                        [  2.35290527e-01,   2.35290527e-01],
                        [  2.44049072e-01,   2.44049072e-01],
                        [  2.26074219e-01,   2.26074219e-01],
                        [  1.94793701e-01,   1.94793701e-01],
                        [  1.63543701e-01,   1.63574219e-01],
                        [  1.39099121e-01,   1.39099121e-01],
                        [  1.20971680e-01,   1.20941162e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  8.19702148e-02,   8.19702148e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.59802246e-02,   3.60107422e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.10571289e-02,   2.10266113e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.43432617e-02,   1.43737793e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.84729004e-02,   2.85034180e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -3.31115723e-02,  -3.31420898e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.84826660e-02,  -3.84521484e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.31115723e-02,  -3.31420898e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -4.49829102e-02,  -4.49523926e-02],
                        [ -5.18798828e-02,  -5.19104004e-02],
                        [ -5.67016602e-02,  -5.67321777e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.07812500e-02,  -5.08117676e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.61730957e-02,  -4.62036133e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -6.79626465e-02,  -6.79321289e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -1.87377930e-02,  -1.87683105e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  3.02429199e-02,   3.02124023e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -1.14685059e-01,  -1.14685059e-01],
                        [ -1.12731934e-01,  -1.12731934e-01],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -1.65740967e-01,  -1.65740967e-01],
                        [ -2.29156494e-01,  -2.29156494e-01],
                        [ -2.54180908e-01,  -2.54180908e-01],
                        [ -2.33337402e-01,  -2.33337402e-01],
                        [ -1.84356689e-01,  -1.84356689e-01],
                        [ -1.36138916e-01,  -1.36138916e-01],
                        [ -1.05438232e-01,  -1.05407715e-01],
                        [ -8.86230469e-02,  -8.86230469e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  3.28979492e-02,   3.28674316e-02],
                        [  5.63659668e-02,   5.63659668e-02],
                        [  8.41674805e-02,   8.41979980e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  9.12780762e-02,   9.13085938e-02],
                        [  8.08715820e-02,   8.08715820e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  1.02325439e-01,   1.02355957e-01],
                        [  1.37390137e-01,   1.37390137e-01],
                        [  1.77551270e-01,   1.77551270e-01],
                        [  2.08770752e-01,   2.08770752e-01],
                        [  2.20520020e-01,   2.20520020e-01],
                        [  2.11242676e-01,   2.11242676e-01],
                        [  1.87377930e-01,   1.87377930e-01],
                        [  1.58630371e-01,   1.58630371e-01],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.15875244e-01,   1.15844727e-01],
                        [  9.95483398e-02,   9.95788574e-02],
                        [  7.89489746e-02,   7.89794922e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.44750977e-02,   2.44445801e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  6.56127930e-03,   6.59179688e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -4.02832031e-02,  -4.03137207e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.97949219e-02,  -3.97644043e-02],
                        [ -3.95812988e-02,  -3.96118164e-02],
                        [ -3.84216309e-02,  -3.84521484e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -5.20019531e-02,  -5.20324707e-02],
                        [ -5.42602539e-02,  -5.42297363e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.86547852e-02,  -5.86853027e-02],
                        [ -5.95703125e-02,  -5.95397949e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -6.14318848e-02,  -6.14624023e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.15844727e-02,  -6.16149902e-02],
                        [ -6.39953613e-02,  -6.40258789e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  1.66625977e-02,   1.66931152e-02],
                        [  3.24401855e-02,   3.24096680e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -9.79003906e-02,  -9.78698730e-02],
                        [ -1.20208740e-01,  -1.20208740e-01],
                        [ -1.05010986e-01,  -1.05010986e-01],
                        [ -5.93261719e-02,  -5.92956543e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  3.79943848e-02,   3.80249023e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -1.35955811e-01,  -1.35925293e-01],
                        [ -2.16064453e-01,  -2.16064453e-01],
                        [ -2.64099121e-01,  -2.64099121e-01],
                        [ -2.59552002e-01,  -2.59521484e-01],
                        [ -2.10571289e-01,  -2.10540771e-01],
                        [ -1.45843506e-01,  -1.45874023e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [  7.01904297e-03,   7.04956055e-03],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.41510010e-01,   1.41510010e-01],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.04095459e-01,   1.04064941e-01],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  5.78002930e-02,   5.78308105e-02],
                        [  6.51245117e-02,   6.50939941e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  1.45782471e-01,   1.45812988e-01],
                        [  1.89422607e-01,   1.89422607e-01],
                        [  2.17651367e-01,   2.17620850e-01],
                        [  2.22595215e-01,   2.22595215e-01],
                        [  2.02819824e-01,   2.02850342e-01],
                        [  1.69342041e-01,   1.69311523e-01],
                        [  1.38519287e-01,   1.38488770e-01],
                        [  1.15539551e-01,   1.15570068e-01],
                        [  9.55200195e-02,   9.55200195e-02],
                        [  7.95593262e-02,   7.95288086e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  8.05358887e-02,   8.05664062e-02],
                        [  8.55712891e-02,   8.55407715e-02],
                        [  8.06884766e-02,   8.06579590e-02],
                        [  6.44836426e-02,   6.45141602e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  2.22778320e-02,   2.22473145e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  4.05883789e-03,   4.08935547e-03],
                        [  5.49316406e-03,   5.46264648e-03],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.08032227e-02,   1.08337402e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  1.91955566e-02,   1.91650391e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.15966797e-02,   1.15661621e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -2.89916992e-03,  -2.86865234e-03],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -2.16369629e-02,  -2.16674805e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -4.02832031e-02,  -4.03137207e-02],
                        [ -4.13818359e-02,  -4.13513184e-02],
                        [ -4.09851074e-02,  -4.09545898e-02],
                        [ -4.41284180e-02,  -4.41589355e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -5.83190918e-02,  -5.82885742e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -4.92553711e-02,  -4.92248535e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.65087891e-02,  -4.65393066e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.44030762e-02,  -4.43725586e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [  2.19116211e-02,   2.18811035e-02],
                        [  4.84313965e-02,   4.84008789e-02],
                        [  7.40661621e-02,   7.40966797e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  1.04339600e-01,   1.04339600e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  7.91015625e-02,   7.91015625e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [ -4.22973633e-02,  -4.23278809e-02],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -1.43890381e-01,  -1.43890381e-01],
                        [ -1.36199951e-01,  -1.36199951e-01],
                        [ -8.85925293e-02,  -8.85925293e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [  3.14331055e-02,   3.14025879e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [ -3.93676758e-03,  -3.96728516e-03],
                        [ -8.70056152e-02,  -8.70056152e-02],
                        [ -1.83166504e-01,  -1.83166504e-01],
                        [ -2.61871338e-01,  -2.61871338e-01],
                        [ -2.92053223e-01,  -2.92053223e-01],
                        [ -2.63183594e-01,  -2.63183594e-01],
                        [ -1.95739746e-01,  -1.95739746e-01],
                        [ -1.27655029e-01,  -1.27685547e-01],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -6.57043457e-02,  -6.57043457e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.99987793e-02,  -3.00292969e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.17187500e-01,   1.17187500e-01],
                        [  1.26098633e-01,   1.26068115e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  7.95593262e-02,   7.95593262e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  7.72705078e-02,   7.72705078e-02],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.90856934e-01,   1.90856934e-01],
                        [  2.23571777e-01,   2.23571777e-01],
                        [  2.34344482e-01,   2.34313965e-01],
                        [  2.20672607e-01,   2.20672607e-01],
                        [  1.88415527e-01,   1.88446045e-01],
                        [  1.52648926e-01,   1.52648926e-01],
                        [  1.27319336e-01,   1.27319336e-01],
                        [  1.12396240e-01,   1.12426758e-01],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  5.11779785e-02,   5.12084961e-02],
                        [  5.04455566e-02,   5.04150391e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  4.76684570e-02,   4.76989746e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.07421875e-02,   1.07116699e-02],
                        [  4.76074219e-03,   4.79125977e-03],
                        [  3.81469727e-03,   3.84521484e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.62353516e-02,   1.62658691e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [ -4.45556641e-03,  -4.42504883e-03],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -6.26525879e-02,  -6.26220703e-02],
                        [ -6.32019043e-02,  -6.31713867e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -5.56030273e-02,  -5.56335449e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  6.29577637e-02,   6.29882812e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  7.56530762e-02,   7.56530762e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -8.58764648e-02,  -8.58764648e-02],
                        [ -1.32476807e-01,  -1.32476807e-01],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.09985352e-01,  -1.09985352e-01],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  6.97937012e-02,   6.97937012e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -1.35162354e-01,  -1.35162354e-01],
                        [ -2.25189209e-01,  -2.25189209e-01],
                        [ -2.77954102e-01,  -2.77954102e-01],
                        [ -2.73376465e-01,  -2.73376465e-01],
                        [ -2.20764160e-01,  -2.20764160e-01],
                        [ -1.51947021e-01,  -1.51947021e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  3.77197266e-02,   3.76892090e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  3.32336426e-02,   3.32641602e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.26556396e-01,   1.26556396e-01],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  6.90002441e-02,   6.89697266e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  1.33026123e-01,   1.32995605e-01],
                        [  1.72180176e-01,   1.72180176e-01],
                        [  2.06878662e-01,   2.06878662e-01],
                        [  2.25067139e-01,   2.25067139e-01],
                        [  2.19451904e-01,   2.19451904e-01],
                        [  1.92047119e-01,   1.92077637e-01],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  1.21673584e-01,   1.21643066e-01],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.97448730e-02,   1.97143555e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.89501953e-02,  -4.89196777e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -4.85229492e-02,  -4.84924316e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.24804688e-02,  -4.24499512e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -4.14733887e-02,  -4.15039062e-02],
                        [ -4.51354980e-02,  -4.51049805e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -6.80541992e-02,  -6.80847168e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -7.44628906e-02,  -7.44323730e-02],
                        [ -7.53479004e-02,  -7.53479004e-02],
                        [ -7.36389160e-02,  -7.36694336e-02],
                        [ -6.59484863e-02,  -6.59179688e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -4.82177734e-02,  -4.82482910e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -6.09436035e-02,  -6.09741211e-02],
                        [ -6.91528320e-02,  -6.91833496e-02],
                        [ -7.05566406e-02,  -7.05261230e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -6.08520508e-02,  -6.08825684e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [  5.21850586e-03,   5.21850586e-03],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  3.64685059e-02,   3.64379883e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  5.28259277e-02,   5.27954102e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -1.30981445e-01,  -1.30981445e-01],
                        [ -1.62963867e-01,  -1.62963867e-01],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -9.63439941e-02,  -9.63439941e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -1.32171631e-01,  -1.32171631e-01],
                        [ -2.17315674e-01,  -2.17315674e-01],
                        [ -2.65472412e-01,  -2.65472412e-01],
                        [ -2.57232666e-01,  -2.57232666e-01],
                        [ -2.02056885e-01,  -2.02087402e-01],
                        [ -1.34826660e-01,  -1.34826660e-01],
                        [ -8.80126953e-02,  -8.80126953e-02],
                        [ -6.83288574e-02,  -6.83288574e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -3.86657715e-02,  -3.86352539e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [  7.32421875e-04,   7.01904297e-04],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  3.96728516e-02,   3.97033691e-02],
                        [  4.88586426e-02,   4.88281250e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  3.87573242e-02,   3.87878418e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  3.17993164e-02,   3.17687988e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  1.18621826e-01,   1.18591309e-01],
                        [  1.39617920e-01,   1.39617920e-01],
                        [  1.35345459e-01,   1.35375977e-01],
                        [  1.11053467e-01,   1.11022949e-01],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  6.04858398e-02,   6.04553223e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  1.15905762e-01,   1.15905762e-01],
                        [  1.62872314e-01,   1.62872314e-01],
                        [  2.05932617e-01,   2.05932617e-01],
                        [  2.28240967e-01,   2.28240967e-01],
                        [  2.21984863e-01,   2.21984863e-01],
                        [  1.92901611e-01,   1.92901611e-01],
                        [  1.54663086e-01,   1.54693604e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  9.63745117e-02,   9.63439941e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  6.54296875e-02,   6.53991699e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  5.31005859e-02,   5.30700684e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [ -2.74658203e-03,  -2.71606445e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  8.75854492e-03,   8.78906250e-03],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.78320312e-02,  -2.78015137e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.73327637e-02,  -4.73022461e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -5.43212891e-02,  -5.43518066e-02],
                        [ -6.18286133e-02,  -6.17980957e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -6.16455078e-02,  -6.16760254e-02],
                        [ -6.59790039e-02,  -6.59484863e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.70166016e-02,  -6.70471191e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -2.45361328e-02,  -2.45056152e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.89001465e-02,   2.88696289e-02],
                        [  4.86450195e-02,   4.86145020e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  7.15332031e-02,   7.15026855e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -1.22528076e-01,  -1.22528076e-01],
                        [ -1.53442383e-01,  -1.53411865e-01],
                        [ -1.43341064e-01,  -1.43341064e-01],
                        [ -1.03240967e-01,  -1.03271484e-01],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -1.05895996e-02,  -1.05590820e-02],
                        [  2.05078125e-02,   2.04772949e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  5.63964844e-02,   5.63964844e-02],
                        [  5.00183105e-02,   4.99877930e-02],
                        [  1.23291016e-02,   1.22985840e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -1.47430420e-01,  -1.47399902e-01],
                        [ -2.20916748e-01,  -2.20947266e-01],
                        [ -2.50457764e-01,  -2.50488281e-01],
                        [ -2.31445312e-01,  -2.31414795e-01],
                        [ -1.82464600e-01,  -1.82464600e-01],
                        [ -1.27990723e-01,  -1.27990723e-01],
                        [ -8.60290527e-02,  -8.59985352e-02],
                        [ -6.38427734e-02,  -6.38122559e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.74548340e-02,  -4.74243164e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.42919922e-02,   2.42614746e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  3.06091309e-02,   3.06396484e-02],
                        [  2.54516602e-02,   2.54211426e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.47399902e-01,   1.47369385e-01],
                        [  1.47583008e-01,   1.47552490e-01],
                        [  1.27960205e-01,   1.27929688e-01],
                        [  9.70764160e-02,   9.70458984e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  6.26831055e-02,   6.27136230e-02],
                        [  9.53063965e-02,   9.53674316e-02],
                        [  1.39984131e-01,   1.40045166e-01],
                        [  1.81854248e-01,   1.81884766e-01],
                        [  2.06787109e-01,   2.06817627e-01],
                        [  2.08801270e-01,   2.08862305e-01],
                        [  1.91558838e-01,   1.91619873e-01],
                        [  1.65191650e-01,   1.65222168e-01],
                        [  1.41662598e-01,   1.41632080e-01],
                        [  1.25976562e-01,   1.25915527e-01],
                        [  1.11602783e-01,   1.11541748e-01],
                        [  9.21936035e-02,   9.21020508e-02],
                        [  7.28454590e-02,   7.27539062e-02],
                        [  6.13708496e-02,   6.12792969e-02],
                        [  5.61828613e-02,   5.60913086e-02],
                        [  5.09948730e-02,   5.09033203e-02],
                        [  4.43420410e-02,   4.42810059e-02],
                        [  3.82995605e-02,   3.83300781e-02],
                        [  3.29895020e-02,   3.30505371e-02],
                        [  2.63977051e-02,   2.64587402e-02],
                        [  1.83410645e-02,   1.84936523e-02],
                        [  1.34582520e-02,   1.36108398e-02],
                        [  1.63269043e-02,   1.64489746e-02],
                        [  2.23693848e-02,   2.25524902e-02],
                        [  2.18811035e-02,   2.20336914e-02],
                        [  1.43127441e-02,   1.43432617e-02],
                        [  6.16455078e-03,   6.13403320e-03],
                        [ -2.47192383e-03,  -2.53295898e-03],
                        [ -1.53503418e-02,  -1.54724121e-02],
                        [ -2.87170410e-02,  -2.88696289e-02],
                        [ -3.49426270e-02,  -3.50952148e-02],
                        [ -3.34167480e-02,  -3.36303711e-02],
                        [ -3.03039551e-02,  -3.05175781e-02],
                        [ -2.96325684e-02,  -2.97546387e-02],
                        [ -3.07312012e-02,  -3.07922363e-02],
                        [ -3.28063965e-02,  -3.27758789e-02],
                        [ -3.62548828e-02,  -3.61633301e-02],
                        [ -4.03747559e-02,  -4.02221680e-02],
                        [ -4.47082520e-02,  -4.45251465e-02],
                        [ -5.16967773e-02,  -5.14831543e-02],
                        [ -6.23168945e-02,  -6.20117188e-02],
                        [ -6.97326660e-02,  -6.94580078e-02],
                        [ -6.73828125e-02,  -6.71997070e-02],
                        [ -6.08520508e-02,  -6.07604980e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -6.51245117e-02,  -6.52160645e-02],
                        [ -6.81762695e-02,  -6.83288574e-02],
                        [ -6.62231445e-02,  -6.64672852e-02],
                        [ -6.10046387e-02,  -6.13098145e-02],
                        [ -5.47790527e-02,  -5.51147461e-02],
                        [ -5.00183105e-02,  -5.03234863e-02],
                        [ -4.90722656e-02,  -4.93164062e-02],
                        [ -5.24597168e-02,  -5.26123047e-02],
                        [ -5.91430664e-02,  -5.91735840e-02],
                        [ -6.76879883e-02,  -6.76574707e-02],
                        [ -7.44628906e-02,  -7.43103027e-02],
                        [ -7.38525391e-02,  -7.35778809e-02],
                        [ -6.31713867e-02,  -6.27746582e-02],
                        [ -4.55017090e-02,  -4.51049805e-02],
                        [ -2.83508301e-02,  -2.79541016e-02],
                        [ -1.84631348e-02,  -1.81579590e-02],
                        [ -1.65405273e-02,  -1.63574219e-02],
                        [ -1.80664062e-02,  -1.79443359e-02],
                        [ -1.83715820e-02,  -1.83410645e-02],
                        [ -1.45568848e-02,  -1.47094727e-02],
                        [ -5.15747070e-03,  -5.43212891e-03],
                        [  1.11083984e-02,   1.07116699e-02],
                        [  3.45764160e-02,   3.41491699e-02],
                        [  6.07299805e-02,   6.03332520e-02],
                        [  7.97424316e-02,   7.94067383e-02],
                        [  8.33740234e-02,   8.30993652e-02],
                        [  6.77795410e-02,   6.75354004e-02],
                        [  2.88696289e-02,   2.87475586e-02],
                        [ -3.45153809e-02,  -3.44543457e-02],
                        [ -1.07513428e-01,  -1.07299805e-01],
                        [ -1.60400391e-01,  -1.60064697e-01],
                        [ -1.70806885e-01,  -1.70410156e-01],
                        [ -1.39556885e-01,  -1.39190674e-01],
                        [ -8.41064453e-02,  -8.37402344e-02],
                        [ -2.44445801e-02,  -2.40783691e-02],
                        [  2.52685547e-02,   2.55737305e-02],
                        [  5.88378906e-02,   5.90515137e-02],
                        [  7.49206543e-02,   7.49816895e-02],
                        [  7.08312988e-02,   7.07092285e-02],
                        [  3.90319824e-02,   3.88488770e-02],
                        [ -2.62756348e-02,  -2.65197754e-02],
                        [ -1.15905762e-01,  -1.16180420e-01],
                        [ -2.03277588e-01,  -2.03582764e-01],
                        [ -2.58605957e-01,  -2.58941650e-01],
                        [ -2.64678955e-01,  -2.65014648e-01],
                        [ -2.24578857e-01,  -2.24822998e-01],
                        [ -1.60858154e-01,  -1.60949707e-01],
                        [ -1.03607178e-01,  -1.03637695e-01],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -6.06994629e-02,  -6.06689453e-02],
                        [ -5.70068359e-02,  -5.69458008e-02],
                        [ -5.18188477e-02,  -5.16967773e-02],
                        [ -4.73327637e-02,  -4.70886230e-02],
                        [ -4.53186035e-02,  -4.51049805e-02],
                        [ -3.80249023e-02,  -3.78723145e-02],
                        [ -1.60522461e-02,  -1.59606934e-02],
                        [  1.61437988e-02,   1.62963867e-02],
                        [  4.30908203e-02,   4.32128906e-02],
                        [  5.45349121e-02,   5.46875000e-02],
                        [  5.20324707e-02,   5.21850586e-02],
                        [  4.29687500e-02,   4.30297852e-02],
                        [  3.35388184e-02,   3.35083008e-02],
                        [  2.60314941e-02,   2.60620117e-02],
                        [  2.35290527e-02,   2.35900879e-02],
                        [  3.37524414e-02,   3.37524414e-02],
                        [  6.17675781e-02,   6.16455078e-02],
                        [  1.00219727e-01,   1.00006104e-01],
                        [  1.32751465e-01,   1.32476807e-01],
                        [  1.45660400e-01,   1.45385742e-01],
                        [  1.34399414e-01,   1.34185791e-01],
                        [  1.05804443e-01,   1.05560303e-01],
                        [  7.61108398e-02,   7.57751465e-02],
                        [  5.92041016e-02,   5.88989258e-02],
                        [  5.70068359e-02,   5.68237305e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  8.85314941e-02,   8.86535645e-02],
                        [  1.25549316e-01,   1.25762939e-01],
                        [  1.70715332e-01,   1.70989990e-01],
                        [  2.09014893e-01,   2.09350586e-01],
                        [  2.26104736e-01,   2.26593018e-01],
                        [  2.17010498e-01,   2.17590332e-01],
                        [  1.87591553e-01,   1.88201904e-01],
                        [  1.50421143e-01,   1.50878906e-01],
                        [  1.17187500e-01,   1.17462158e-01],
                        [  9.32006836e-02,   9.32922363e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  6.94274902e-02,   6.93054199e-02],
                        [  6.38427734e-02,   6.35681152e-02],
                        [  5.96008301e-02,   5.90820312e-02],
                        [  5.74340820e-02,   5.67321777e-02],
                        [  5.67932129e-02,   5.60607910e-02],
                        [  5.33752441e-02,   5.27343750e-02],
                        [  4.42504883e-02,   4.37316895e-02],
                        [  3.34777832e-02,   3.30505371e-02],
                        [  2.61535645e-02,   2.58178711e-02],
                        [  2.04467773e-02,   2.02636719e-02],
                        [  1.30004883e-02,   1.30615234e-02],
                        [  7.14111328e-03,   7.50732422e-03],
                        [  6.43920898e-03,   7.01904297e-03],
                        [  6.13403320e-03,   6.77490234e-03],
                        [ -1.22070312e-04,   5.18798828e-04],
                        [ -9.55200195e-03,  -8.91113281e-03],
                        [ -1.48620605e-02,  -1.41906738e-02],
                        [ -1.58996582e-02,  -1.52282715e-02],
                        [ -1.82495117e-02,  -1.77307129e-02],
                        [ -2.45971680e-02,  -2.43530273e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -4.31213379e-02,  -4.33044434e-02],
                        [ -4.86450195e-02,  -4.88891602e-02],
                        [ -4.73327637e-02,  -4.76989746e-02],
                        [ -4.17175293e-02,  -4.22363281e-02],
                        [ -3.90014648e-02,  -3.97033691e-02],
                        [ -4.30297852e-02,  -4.37927246e-02],
                        [ -4.88891602e-02,  -4.95910645e-02],
                        [ -5.08117676e-02,  -5.13305664e-02],
                        [ -5.04760742e-02,  -5.08422852e-02],
                        [ -5.21240234e-02,  -5.24291992e-02],
                        [ -5.47790527e-02,  -5.50537109e-02],
                        [ -5.58471680e-02,  -5.59692383e-02],
                        [ -5.70678711e-02,  -5.69458008e-02],
                        [ -6.18896484e-02,  -6.15234375e-02],
                        [ -6.98547363e-02,  -6.93054199e-02],
                        [ -7.65991211e-02,  -7.60192871e-02],
                        [ -7.68432617e-02,  -7.62939453e-02],
                        [ -6.89392090e-02,  -6.83593750e-02],
                        [ -5.91735840e-02,  -5.84411621e-02],
                        [ -5.56640625e-02,  -5.49316406e-02],
                        [ -5.87158203e-02,  -5.81359863e-02],
                        [ -6.29882812e-02,  -6.26525879e-02],
                        [ -6.45446777e-02,  -6.44531250e-02],
                        [ -6.15539551e-02,  -6.16455078e-02],
                        [ -5.50537109e-02,  -5.52062988e-02],
                        [ -4.95910645e-02,  -4.98657227e-02],
                        [ -4.73632812e-02,  -4.79431152e-02],
                        [ -4.41894531e-02,  -4.50439453e-02],
                        [ -3.51257324e-02,  -3.60412598e-02],
                        [ -2.11791992e-02,  -2.20642090e-02],
                        [ -7.23266602e-03,  -7.93457031e-03],
                        [  3.99780273e-03,   3.44848633e-03],
                        [  1.34887695e-02,   1.30004883e-02],
                        [  2.46887207e-02,   2.42919922e-02],
                        [  3.98254395e-02,   3.97033691e-02],
                        [  5.66406250e-02,   5.68847656e-02],
                        [  6.96105957e-02,   7.02209473e-02],
                        [  7.30895996e-02,   7.38525391e-02],
                        [  6.18286133e-02,   6.26220703e-02],
                        [  3.15551758e-02,   3.23486328e-02],
                        [ -1.92260742e-02,  -1.83715820e-02],
                        [ -8.41064453e-02,  -8.31909180e-02],
                        [ -1.44226074e-01,  -1.43402100e-01],
                        [ -1.74621582e-01,  -1.74072266e-01],
                        [ -1.60034180e-01,  -1.59881592e-01],
                        [ -1.07391357e-01,  -1.07543945e-01],
                        [ -4.26025391e-02,  -4.28466797e-02],
                        [  9.30786133e-03,   8.94165039e-03],
                        [  4.15649414e-02,   4.10156250e-02],
                        [  6.19201660e-02,   6.11572266e-02],
                        [  7.52868652e-02,   7.43713379e-02],
                        [  7.28759766e-02,   7.18994141e-02],
                        [  3.74755859e-02,   3.67431641e-02],
                        [ -3.85742188e-02,  -3.90625000e-02],
                        [ -1.38610840e-01,  -1.38977051e-01],
                        [ -2.26470947e-01,  -2.26837158e-01],
                        [ -2.70812988e-01,  -2.71057129e-01],
                        [ -2.62969971e-01,  -2.63000488e-01],
                        [ -2.15454102e-01,  -2.15148926e-01],
                        [ -1.52709961e-01,  -1.52160645e-01],
                        [ -1.01165771e-01,  -1.00555420e-01],
                        [ -7.35168457e-02,  -7.29980469e-02],
                        [ -6.25000000e-02,  -6.19812012e-02],
                        [ -5.48095703e-02,  -5.41076660e-02],
                        [ -4.53186035e-02,  -4.44641113e-02],
                        [ -3.61328125e-02,  -3.52783203e-02],
                        [ -2.88696289e-02,  -2.81982422e-02],
                        [ -2.16979980e-02,  -2.13012695e-02],
                        [ -1.03454590e-02,  -1.01013184e-02],
                        [  7.96508789e-03,   8.14819336e-03],
                        [  2.98156738e-02,   2.99377441e-02],
                        [  4.74853516e-02,   4.73022461e-02],
                        [  5.51147461e-02,   5.45349121e-02],
                        [  5.11779785e-02,   5.02319336e-02],
                        [  3.86047363e-02,   3.74450684e-02],
                        [  2.63671875e-02,   2.52380371e-02],
                        [  2.54516602e-02,   2.43530273e-02],
                        [  4.13513184e-02,   4.01611328e-02],
                        [  7.18078613e-02,   7.05871582e-02],
                        [  1.07055664e-01,   1.06048584e-01],
                        [  1.32324219e-01,   1.31774902e-01],
                        [  1.37268066e-01,   1.37329102e-01],
                        [  1.23779297e-01,   1.24359131e-01],
                        [  1.02111816e-01,   1.03057861e-01],
                        [  8.13293457e-02,   8.25195312e-02],
                        [  6.46057129e-02,   6.61621094e-02],
                        [  5.30090332e-02,   5.49316406e-02],
                        [  5.02929688e-02,   5.24291992e-02],
                        [  6.39343262e-02,   6.58874512e-02],
                        [  9.82971191e-02,   9.97619629e-02],
                        [  1.47430420e-01,   1.48254395e-01],
                        [  1.96472168e-01,   1.96685791e-01],
                        [  2.29064941e-01,   2.28790283e-01],
                        [  2.34375000e-01,   2.33551025e-01],
                        [  2.13531494e-01,   2.11975098e-01],
                        [  1.79290771e-01,   1.77093506e-01],
                        [  1.45568848e-01,   1.42974854e-01],
                        [  1.18408203e-01,   1.15875244e-01],
                        [  9.65881348e-02,   9.44213867e-02],
                        [  7.65075684e-02,   7.48291016e-02],
                        [  5.75561523e-02,   5.63354492e-02],
                        [  4.34570312e-02,   4.28466797e-02],
                        [  3.94287109e-02,   3.96118164e-02],
                        [  4.64782715e-02,   4.76074219e-02],
                        [  5.69458008e-02,   5.89599609e-02],
                        [  5.86853027e-02,   6.11877441e-02],
                        [  4.62951660e-02,   4.88586426e-02],
                        [  2.56042480e-02,   2.80456543e-02],
                        [  6.86645508e-03,   9.12475586e-03],
                        [ -3.32641602e-03,  -1.40380859e-03],
                        [ -4.18090820e-03,  -2.80761719e-03],
                        [  7.62939453e-04,   1.28173828e-03],
                        [  6.56127930e-03,   6.01196289e-03],
                        [  1.11999512e-02,   9.73510742e-03],
                        [  1.56555176e-02,   1.37023926e-02],
                        [  1.86767578e-02,   1.65405273e-02],
                        [  1.67236328e-02,   1.44653320e-02],
                        [  7.32421875e-03,   4.97436523e-03],
                        [ -9.61303711e-03,  -1.18103027e-02],
                        [ -2.90222168e-02,  -3.07312012e-02],
                        [ -4.26330566e-02,  -4.35180664e-02],
                        [ -4.92553711e-02,  -4.91638184e-02],
                        [ -5.42907715e-02,  -5.34362793e-02],
                        [ -5.85632324e-02,  -5.73425293e-02],
                        [ -5.94482422e-02,  -5.78918457e-02],
                        [ -5.87463379e-02,  -5.69152832e-02],
                        [ -5.91735840e-02,  -5.70983887e-02],
                        [ -5.84411621e-02,  -5.64270020e-02],
                        [ -5.52978516e-02,  -5.37109375e-02],
                        [ -5.25512695e-02,  -5.17883301e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -5.27648926e-02,  -5.31616211e-02],
                        [ -5.49011230e-02,  -5.56335449e-02],
                        [ -5.69458008e-02,  -5.79833984e-02],
                        [ -5.60913086e-02,  -5.74951172e-02],
                        [ -5.20019531e-02,  -5.37109375e-02],
                        [ -4.78820801e-02,  -4.94689941e-02],
                        [ -4.81262207e-02,  -4.92248535e-02],
                        [ -5.35888672e-02,  -5.40466309e-02],
                        [ -5.94177246e-02,  -5.93872070e-02],
                        [ -6.10656738e-02,  -6.07604980e-02],
                        [ -5.99975586e-02,  -5.94787598e-02],
                        [ -5.96313477e-02,  -5.88073730e-02],
                        [ -5.96923828e-02,  -5.84411621e-02],
                        [ -5.76782227e-02,  -5.62438965e-02],
                        [ -5.34362793e-02,  -5.22766113e-02],
                        [ -4.83093262e-02,  -4.76684570e-02],
                        [ -4.18090820e-02,  -4.16870117e-02],
                        [ -3.18908691e-02,  -3.20739746e-02],
                        [ -1.79748535e-02,  -1.82800293e-02],
                        [ -3.50952148e-03,  -4.05883789e-03],
                        [  6.98852539e-03,   6.07299805e-03],
                        [  1.58996582e-02,   1.46179199e-02],
                        [  3.07006836e-02,   2.93884277e-02],
                        [  5.21545410e-02,   5.12084961e-02],
                        [  7.13806152e-02,   7.09228516e-02],
                        [  7.95288086e-02,   7.94677734e-02],
                        [  7.32116699e-02,   7.33032227e-02],
                        [  4.87365723e-02,   4.89807129e-02],
                        [  9.76562500e-04,   1.55639648e-03],
                        [ -6.62536621e-02,  -6.52160645e-02],
                        [ -1.33605957e-01,  -1.32263184e-01],
                        [ -1.76208496e-01,  -1.74926758e-01],
                        [ -1.77490234e-01,  -1.76605225e-01],
                        [ -1.37817383e-01,  -1.37298584e-01],
                        [ -7.55310059e-02,  -7.51953125e-02],
                        [ -1.51672363e-02,  -1.48925781e-02],
                        [  2.85644531e-02,   2.86560059e-02],
                        [  5.47485352e-02,   5.43518066e-02],
                        [  6.79016113e-02,   6.70166016e-02],
                        [  6.86035156e-02,   6.74133301e-02],
                        [  5.09643555e-02,   4.98962402e-02],
                        [  8.36181641e-03,   7.56835938e-03],
                        [ -5.96313477e-02,  -6.03027344e-02],
                        [ -1.41296387e-01,  -1.42089844e-01],
                        [ -2.12036133e-01,  -2.12860107e-01],
                        [ -2.44842529e-01,  -2.45422363e-01],
                        [ -2.27386475e-01,  -2.27447510e-01],
                        [ -1.73400879e-01,  -1.72973633e-01],
                        [ -1.15661621e-01,  -1.15081787e-01],
                        [ -8.09020996e-02,  -8.04138184e-02],
                        [ -7.08312988e-02,  -7.03735352e-02],
                        [ -7.01599121e-02,  -6.94580078e-02],
                        [ -6.59179688e-02,  -6.48803711e-02],
                        [ -5.58471680e-02,  -5.46264648e-02],
                        [ -4.32128906e-02,  -4.21752930e-02],
                        [ -3.08837891e-02,  -3.02124023e-02],
                        [ -1.97448730e-02,  -1.93481445e-02],
                        [ -8.42285156e-03,  -8.02612305e-03],
                        [  5.79833984e-03,   6.25610352e-03],
                        [  2.27966309e-02,   2.30407715e-02],
                        [  3.86657715e-02,   3.83911133e-02],
                        [  4.89807129e-02,   4.81262207e-02],
                        [  5.16052246e-02,   5.04760742e-02],
                        [  4.82788086e-02,   4.71496582e-02],
                        [  4.41589355e-02,   4.30603027e-02],
                        [  4.58068848e-02,   4.45861816e-02],
                        [  5.87768555e-02,   5.72204590e-02],
                        [  8.27636719e-02,   8.11157227e-02],
                        [  1.08123779e-01,   1.06842041e-01],
                        [  1.22253418e-01,   1.21643066e-01],
                        [  1.21765137e-01,   1.21734619e-01],
                        [  1.12731934e-01,   1.13098145e-01],
                        [  1.00952148e-01,   1.01531982e-01],
                        [  8.87145996e-02,   8.96911621e-02],
                        [  7.80944824e-02,   7.97424316e-02],
                        [  6.97326660e-02,   7.20214844e-02],
                        [  6.32019043e-02,   6.57653809e-02],
                        [  6.34460449e-02,   6.57348633e-02],
                        [  7.86743164e-02,   8.04748535e-02],
                        [  1.10534668e-01,   1.11938477e-01],
                        [  1.51641846e-01,   1.52740479e-01],
                        [  1.91406250e-01,   1.92077637e-01],
                        [  2.18414307e-01,   2.18261719e-01],
                        [  2.22137451e-01,   2.20886230e-01],
                        [  2.00317383e-01,   1.98059082e-01],
                        [  1.61956787e-01,   1.59210205e-01],
                        [  1.20880127e-01,   1.18072510e-01],
                        [  8.89282227e-02,   8.61206055e-02],
                        [  7.14721680e-02,   6.86035156e-02],
                        [  6.51245117e-02,   6.23168945e-02],
                        [  6.28356934e-02,   6.05163574e-02],
                        [  6.16149902e-02,   6.03027344e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  5.88989258e-02,   6.00280762e-02],
                        [  4.84008789e-02,   5.02624512e-02],
                        [  3.03649902e-02,   3.27453613e-02],
                        [  1.30004883e-02,   1.60522461e-02],
                        [  2.80761719e-03,   6.53076172e-03],
                        [ -8.85009766e-04,   3.20434570e-03],
                        [ -7.93457031e-04,   3.02124023e-03],
                        [  6.40869141e-04,   3.57055664e-03],
                        [  1.03759766e-03,   2.83813477e-03],
                        [  5.49316406e-04,   1.34277344e-03],
                        [  1.37329102e-03,   1.34277344e-03],
                        [  3.23486328e-03,   2.22778320e-03],
                        [  1.67846680e-03,  -5.79833984e-04],
                        [ -6.37817383e-03,  -9.91821289e-03],
                        [ -1.75170898e-02,  -2.18505859e-02],
                        [ -2.63671875e-02,  -3.07922363e-02],
                        [ -3.16162109e-02,  -3.55834961e-02],
                        [ -3.45153809e-02,  -3.79028320e-02],
                        [ -3.68652344e-02,  -3.97338867e-02],
                        [ -4.06188965e-02,  -4.27551270e-02],
                        [ -4.57763672e-02,  -4.66918945e-02],
                        [ -5.09643555e-02,  -5.02624512e-02],
                        [ -5.54199219e-02,  -5.31311035e-02],
                        [ -5.82275391e-02,  -5.49011230e-02],
                        [ -5.92346191e-02,  -5.53894043e-02],
                        [ -5.93872070e-02,  -5.53588867e-02],
                        [ -5.96313477e-02,  -5.54504395e-02],
                        [ -6.03637695e-02,  -5.61523438e-02],
                        [ -6.03332520e-02,  -5.65795898e-02],
                        [ -5.71594238e-02,  -5.45043945e-02],
                        [ -5.12695312e-02,  -5.02014160e-02],
                        [ -4.67834473e-02,  -4.71801758e-02],
                        [ -4.71496582e-02,  -4.86145020e-02],
                        [ -5.16967773e-02,  -5.38940430e-02],
                        [ -5.64880371e-02,  -5.94482422e-02],
                        [ -5.71594238e-02,  -6.09436035e-02],
                        [ -5.17883301e-02,  -5.61218262e-02],
                        [ -4.28771973e-02,  -4.71191406e-02],
                        [ -3.58581543e-02,  -3.92761230e-02],
                        [ -3.34472656e-02,  -3.56750488e-02],
                        [ -3.48815918e-02,  -3.61022949e-02],
                        [ -3.93066406e-02,  -3.97644043e-02],
                        [ -4.40368652e-02,  -4.37316895e-02],
                        [ -4.36096191e-02,  -4.22668457e-02],
                        [ -3.64685059e-02,  -3.39660645e-02],
                        [ -2.69165039e-02,  -2.36206055e-02],
                        [ -1.77612305e-02,  -1.43737793e-02],
                        [ -6.68334961e-03,  -3.75366211e-03],
                        [  9.46044922e-03,   1.18103027e-02],
                        [  2.99377441e-02,   3.19213867e-02],
                        [  4.99877930e-02,   5.16662598e-02],
                        [  6.41784668e-02,   6.52465820e-02],
                        [  6.83898926e-02,   6.84204102e-02],
                        [  5.64575195e-02,   5.54504395e-02],
                        [  1.98669434e-02,   1.82800293e-02],
                        [ -4.16870117e-02,  -4.33349609e-02],
                        [ -1.10137939e-01,  -1.11572266e-01],
                        [ -1.56036377e-01,  -1.57409668e-01],
                        [ -1.60736084e-01,  -1.62292480e-01],
                        [ -1.30401611e-01,  -1.32049561e-01],
                        [ -8.66394043e-02,  -8.78906250e-02],
                        [ -4.67224121e-02,  -4.73022461e-02],
                        [ -1.49841309e-02,  -1.50146484e-02],
                        [  1.28784180e-02,   1.29394531e-02],
                        [  4.19616699e-02,   4.17785645e-02],
                        [  7.11669922e-02,   7.07702637e-02],
                        [  8.96606445e-02,   8.94775391e-02],
                        [  8.05969238e-02,   8.08105469e-02],
                        [  3.29895020e-02,   3.33862305e-02],
                        [ -4.78515625e-02,  -4.76379395e-02],
                        [ -1.40197754e-01,  -1.40258789e-01],
                        [ -2.13256836e-01,  -2.13226318e-01],
                        [ -2.40509033e-01,  -2.39929199e-01],
                        [ -2.16705322e-01,  -2.15393066e-01],
                        [ -1.62109375e-01,  -1.60430908e-01],
                        [ -1.08123779e-01,  -1.06506348e-01],
                        [ -7.74230957e-02,  -7.59582520e-02],
                        [ -7.04040527e-02,  -6.89086914e-02],
                        [ -6.93359375e-02,  -6.75964355e-02],
                        [ -5.99060059e-02,  -5.81970215e-02],
                        [ -4.32434082e-02,  -4.22058105e-02],
                        [ -2.63366699e-02,  -2.64282227e-02],
                        [ -1.17492676e-02,  -1.28784180e-02],
                        [  1.98364258e-03,   1.83105469e-04],
                        [  1.60827637e-02,   1.39160156e-02],
                        [  3.02124023e-02,   2.76184082e-02],
                        [  4.22668457e-02,   3.90930176e-02],
                        [  4.73632812e-02,   4.36096191e-02],
                        [  4.10156250e-02,   3.73535156e-02],
                        [  2.59704590e-02,   2.31628418e-02],
                        [  1.06811523e-02,   9.15527344e-03],
                        [  3.84521484e-03,   3.47900391e-03],
                        [  1.31835938e-02,   1.37329102e-02],
                        [  4.17175293e-02,   4.31213379e-02],
                        [  8.15734863e-02,   8.41369629e-02],
                        [  1.17492676e-01,   1.21429443e-01],
                        [  1.38000488e-01,   1.42883301e-01],
                        [  1.40808105e-01,   1.45843506e-01],
                        [  1.28753662e-01,   1.33148193e-01],
                        [  1.06262207e-01,   1.09710693e-01],
                        [  8.14514160e-02,   8.40759277e-02],
                        [  6.27136230e-02,   6.44531250e-02],
                        [  5.11779785e-02,   5.16662598e-02],
                        [  4.39758301e-02,   4.26940918e-02],
                        [  4.39758301e-02,   4.08325195e-02],
                        [  6.11572266e-02,   5.66101074e-02],
                        [  1.00585938e-01,   9.54895020e-02],
                        [  1.51397705e-01,   1.46331787e-01],
                        [  1.93023682e-01,   1.88140869e-01],
                        [  2.10510254e-01,   2.05810547e-01],
                        [  2.00531006e-01,   1.96411133e-01],
                        [  1.71691895e-01,   1.68884277e-01],
                        [  1.40869141e-01,   1.40045166e-01],
                        [  1.19720459e-01,   1.20880127e-01],
                        [  1.05224609e-01,   1.07910156e-01],
                        [  9.04541016e-02,   9.40551758e-02],
                        [  7.62634277e-02,   8.05969238e-02],
                        [  6.68640137e-02,   7.19299316e-02],
                        [  6.08825684e-02,   6.65893555e-02],
                        [  5.37109375e-02,   5.93261719e-02],
                        [  4.37316895e-02,   4.83398438e-02],
                        [  3.21655273e-02,   3.51257324e-02],
                        [  2.01721191e-02,   2.15148926e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  7.62939453e-03,   6.53076172e-03],
                        [  9.91821289e-03,   7.53784180e-03],
                        [  1.06506348e-02,   6.77490234e-03],
                        [  5.79833984e-03,   6.40869141e-04],
                        [ -1.92260742e-03,  -7.44628906e-03],
                        [ -8.02612305e-03,  -1.30615234e-02],
                        [ -1.08947754e-02,  -1.50451660e-02],
                        [ -1.10168457e-02,  -1.43127441e-02],
                        [ -9.42993164e-03,  -1.19628906e-02],
                        [ -8.85009766e-03,  -1.04064941e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.42004395e-02,  -2.23693848e-02],
                        [ -3.75671387e-02,  -3.43017578e-02],
                        [ -4.80957031e-02,  -4.41284180e-02],
                        [ -5.32531738e-02,  -4.92248535e-02],
                        [ -5.52978516e-02,  -5.13305664e-02],
                        [ -5.70983887e-02,  -5.30395508e-02],
                        [ -5.85021973e-02,  -5.45349121e-02],
                        [ -5.98754883e-02,  -5.66711426e-02],
                        [ -6.29272461e-02,  -6.10961914e-02],
                        [ -6.55822754e-02,  -6.53381348e-02],
                        [ -6.39038086e-02,  -6.48803711e-02],
                        [ -5.78918457e-02,  -5.95397949e-02],
                        [ -5.07507324e-02,  -5.27954102e-02],
                        [ -4.50744629e-02,  -4.77600098e-02],
                        [ -4.16564941e-02,  -4.51354980e-02],
                        [ -4.04663086e-02,  -4.43420410e-02],
                        [ -4.20227051e-02,  -4.55017090e-02],
                        [ -4.59594727e-02,  -4.84619141e-02],
                        [ -5.11474609e-02,  -5.26733398e-02],
                        [ -5.80444336e-02,  -5.89294434e-02],
                        [ -6.69555664e-02,  -6.75048828e-02],
                        [ -7.45849609e-02,  -7.45849609e-02],
                        [ -7.54394531e-02,  -7.44628906e-02],
                        [ -6.65588379e-02,  -6.45446777e-02],
                        [ -5.13610840e-02,  -4.87976074e-02],
                        [ -3.82080078e-02,  -3.57666016e-02],
                        [ -3.40270996e-02,  -3.20739746e-02],
                        [ -3.88488770e-02,  -3.71398926e-02],
                        [ -4.46777344e-02,  -4.28771973e-02],
                        [ -4.17175293e-02,  -3.98559570e-02],
                        [ -2.75268555e-02,  -2.61535645e-02],
                        [ -6.62231445e-03,  -6.16455078e-03],
                        [  1.69372559e-02,   1.65100098e-02],
                        [  4.12902832e-02,   4.04968262e-02],
                        [  6.40563965e-02,   6.33544922e-02],
                        [  8.05969238e-02,   7.99255371e-02],
                        [  8.26416016e-02,   8.15734863e-02],
                        [  6.04858398e-02,   5.87768555e-02],
                        [  9.67407227e-03,   7.59887695e-03],
                        [ -6.27441406e-02,  -6.45141602e-02],
                        [ -1.37603760e-01,  -1.38763428e-01],
                        [ -1.90368652e-01,  -1.91162109e-01],
                        [ -2.01232910e-01,  -2.02087402e-01],
                        [ -1.67327881e-01,  -1.68334961e-01],
                        [ -1.08764648e-01,  -1.09497070e-01],
                        [ -5.50537109e-02,  -5.49621582e-02],
                        [ -2.14233398e-02,  -2.04162598e-02],
                        [ -1.70898438e-03,  -2.44140625e-04],
                        [  1.84326172e-02,   1.98059082e-02],
                        [  4.49218750e-02,   4.61425781e-02],
                        [  6.94274902e-02,   7.08923340e-02],
                        [  7.77587891e-02,   7.97119141e-02],
                        [  6.06689453e-02,   6.28051758e-02],
                        [  1.50451660e-02,   1.67236328e-02],
                        [ -5.60913086e-02,  -5.53588867e-02],
                        [ -1.38458252e-01,  -1.38610840e-01],
                        [ -2.05902100e-01,  -2.06420898e-01],
                        [ -2.32879639e-01,  -2.33489990e-01],
                        [ -2.13134766e-01,  -2.14080811e-01],
                        [ -1.66290283e-01,  -1.67999268e-01],
                        [ -1.21337891e-01,  -1.23779297e-01],
                        [ -9.30480957e-02,  -9.56420898e-02],
                        [ -7.69348145e-02,  -7.89489746e-02],
                        [ -6.25610352e-02,  -6.36596680e-02],
                        [ -4.56848145e-02,  -4.61425781e-02],
                        [ -2.88391113e-02,  -2.90222168e-02],
                        [ -1.45874023e-02,  -1.44348145e-02],
                        [ -2.65502930e-03,  -1.77001953e-03],
                        [  7.29370117e-03,   9.18579102e-03],
                        [  1.58996582e-02,   1.85546875e-02],
                        [  2.49633789e-02,   2.75573730e-02],
                        [  3.33557129e-02,   3.52478027e-02],
                        [  3.66821289e-02,   3.77502441e-02],
                        [  3.32641602e-02,   3.38745117e-02],
                        [  2.63671875e-02,   2.67028809e-02],
                        [  2.01416016e-02,   1.98669434e-02],
                        [  1.91345215e-02,   1.77917480e-02],
                        [  3.03039551e-02,   2.78320312e-02],
                        [  5.73730469e-02,   5.44128418e-02],
                        [  9.38110352e-02,   9.11865234e-02],
                        [  1.27014160e-01,   1.25213623e-01],
                        [  1.47216797e-01,   1.46118164e-01],
                        [  1.49444580e-01,   1.48803711e-01],
                        [  1.33697510e-01,   1.33605957e-01],
                        [  1.05407715e-01,   1.06384277e-01],
                        [  7.32116699e-02,   7.55920410e-02],
                        [  4.68750000e-02,   5.03845215e-02],
                        [  3.34167480e-02,   3.71704102e-02],
                        [  3.14941406e-02,   3.46374512e-02],
                        [  3.67736816e-02,   3.90625000e-02],
                        [  5.30700684e-02,   5.46875000e-02],
                        [  8.78295898e-02,   8.88061523e-02],
                        [  1.37084961e-01,   1.36932373e-01],
                        [  1.84265137e-01,   1.82434082e-01],
                        [  2.13195801e-01,   2.09625244e-01],
                        [  2.15942383e-01,   2.11242676e-01],
                        [  1.92871094e-01,   1.88049316e-01],
                        [  1.54357910e-01,   1.50054932e-01],
                        [  1.17279053e-01,   1.13677979e-01],
                        [  9.33532715e-02,   9.03625488e-02],
                        [  8.28247070e-02,   8.08715820e-02],
                        [  7.86743164e-02,   7.84606934e-02],
                        [  7.28759766e-02,   7.49206543e-02],
                        [  6.27136230e-02,   6.68945312e-02],
                        [  5.07812500e-02,   5.61828613e-02],
                        [  3.91845703e-02,   4.49218750e-02],
                        [  2.92053223e-02,   3.47900391e-02],
                        [  2.24609375e-02,   2.78625488e-02],
                        [  1.78527832e-02,   2.27355957e-02],
                        [  1.25732422e-02,   1.61437988e-02],
                        [  7.23266602e-03,   8.60595703e-03],
                        [  3.84521484e-03,   2.59399414e-03],
                        [  1.06811523e-03,  -2.47192383e-03],
                        [ -3.05175781e-03,  -8.05664062e-03],
                        [ -6.86645508e-03,  -1.26342773e-02],
                        [ -8.36181641e-03,  -1.47399902e-02],
                        [ -9.52148438e-03,  -1.63269043e-02],
                        [ -1.18103027e-02,  -1.84326172e-02],
                        [ -1.23291016e-02,  -1.76391602e-02],
                        [ -9.79614258e-03,  -1.28173828e-02],
                        [ -9.64355469e-03,  -1.01013184e-02],
                        [ -1.69982910e-02,  -1.52893066e-02],
                        [ -2.93884277e-02,  -2.61230469e-02],
                        [ -4.12597656e-02,  -3.66821289e-02],
                        [ -5.13916016e-02,  -4.54406738e-02],
                        [ -6.08825684e-02,  -5.38635254e-02],
                        [ -6.84509277e-02,  -6.11877441e-02],
                        [ -7.17468262e-02,  -6.55212402e-02],
                        [ -7.10144043e-02,  -6.66503906e-02],
                        [ -6.77185059e-02,  -6.53381348e-02],
                        [ -6.29272461e-02,  -6.21643066e-02],
                        [ -5.74951172e-02,  -5.81665039e-02],
                        [ -5.20324707e-02,  -5.43823242e-02],
                        [ -4.78820801e-02,  -5.20935059e-02],
                        [ -4.73022461e-02,  -5.30395508e-02],
                        [ -5.03234863e-02,  -5.65795898e-02],
                        [ -5.33752441e-02,  -5.90515137e-02],
                        [ -5.41992188e-02,  -5.88378906e-02],
                        [ -5.37719727e-02,  -5.74035645e-02],
                        [ -5.29785156e-02,  -5.57861328e-02],
                        [ -5.29785156e-02,  -5.47485352e-02],
                        [ -5.59997559e-02,  -5.61523438e-02],
                        [ -5.99975586e-02,  -5.82580566e-02],
                        [ -5.79528809e-02,  -5.47180176e-02],
                        [ -4.67529297e-02,  -4.29687500e-02],
                        [ -3.28369141e-02,  -2.91442871e-02],
                        [ -2.50244141e-02,  -2.15148926e-02],
                        [ -2.49328613e-02,  -2.13623047e-02],
                        [ -2.65502930e-02,  -2.28881836e-02],
                        [ -2.32543945e-02,  -2.01110840e-02],
                        [ -1.25427246e-02,  -1.05895996e-02],
                        [  4.51660156e-03,   5.06591797e-03],
                        [  2.50549316e-02,   2.46887207e-02],
                        [  4.49829102e-02,   4.43115234e-02],
                        [  5.91430664e-02,   5.83496094e-02],
                        [  6.24084473e-02,   6.10656738e-02],
                        [  4.95910645e-02,   4.73632812e-02],
                        [  1.67846680e-02,   1.38549805e-02],
                        [ -3.50646973e-02,  -3.79943848e-02],
                        [ -9.79919434e-02,  -1.00372314e-01],
                        [ -1.55792236e-01,  -1.57684326e-01],
                        [ -1.85913086e-01,  -1.87774658e-01],
                        [ -1.74163818e-01,  -1.76239014e-01],
                        [ -1.31072998e-01,  -1.33026123e-01],
                        [ -8.32214355e-02,  -8.43200684e-02],
                        [ -4.73937988e-02,  -4.73022461e-02],
                        [ -2.17590332e-02,  -2.08129883e-02],
                        [  1.64794922e-03,   2.89916992e-03],
                        [  2.72827148e-02,   2.86865234e-02],
                        [  5.52978516e-02,   5.71594238e-02],
                        [  7.91320801e-02,   8.19091797e-02],
                        [  8.53576660e-02,   8.89282227e-02],
                        [  6.28967285e-02,   6.65283203e-02],
                        [  1.16577148e-02,   1.45874023e-02],
                        [ -5.94787598e-02,  -5.74340820e-02],
                        [ -1.36199951e-01,  -1.34765625e-01],
                        [ -1.98577881e-01,  -1.97479248e-01],
                        [ -2.25433350e-01,  -2.24914551e-01],
                        [ -2.08862305e-01,  -2.09533691e-01],
                        [ -1.64398193e-01,  -1.66595459e-01],
                        [ -1.19232178e-01,  -1.22589111e-01],
                        [ -8.78906250e-02,  -9.16137695e-02],
                        [ -6.56433105e-02,  -6.91223145e-02],
                        [ -4.36096191e-02,  -4.68750000e-02],
                        [ -2.13928223e-02,  -2.46887207e-02],
                        [ -4.24194336e-03,  -7.50732422e-03],
                        [  4.94384766e-03,   2.38037109e-03],
                        [  8.75854492e-03,   7.65991211e-03],
                        [  1.17187500e-02,   1.22680664e-02],
                        [  1.54113770e-02,   1.70898438e-02],
                        [  1.87988281e-02,   2.09655762e-02],
                        [  2.06909180e-02,   2.31933594e-02],
                        [  2.02941895e-02,   2.34069824e-02],
                        [  1.90734863e-02,   2.29492188e-02],
                        [  2.12707520e-02,   2.55126953e-02],
                        [  2.86865234e-02,   3.24096680e-02],
                        [  3.86352539e-02,   4.11987305e-02],
                        [  5.13610840e-02,   5.27648926e-02],
                        [  7.27844238e-02,   7.35168457e-02],
                        [  1.04858398e-01,   1.05163574e-01],
                        [  1.37145996e-01,   1.36779785e-01],
                        [  1.53533936e-01,   1.51947021e-01],
                        [  1.47460938e-01,   1.44622803e-01],
                        [  1.27563477e-01,   1.24023438e-01],
                        [  1.06842041e-01,   1.03424072e-01],
                        [  9.03015137e-02,   8.73413086e-02],
                        [  7.47985840e-02,   7.20825195e-02],
                        [  5.77087402e-02,   5.48706055e-02],
                        [  4.26940918e-02,   3.99169922e-02],
                        [  3.68347168e-02,   3.47900391e-02],
                        [  4.36401367e-02,   4.29382324e-02],
                        [  6.21948242e-02,   6.27746582e-02],
                        [  9.15832520e-02,   9.29260254e-02],
                        [  1.30523682e-01,   1.32141113e-01],
                        [  1.70104980e-01,   1.72088623e-01],
                        [  1.94030762e-01,   1.96777344e-01],
                        [  1.90795898e-01,   1.94519043e-01],
                        [  1.64672852e-01,   1.68792725e-01],
                        [  1.32171631e-01,   1.35894775e-01],
                        [  1.08886719e-01,   1.11663818e-01],
                        [  9.72595215e-02,   9.92126465e-02],
                        [  8.73413086e-02,   8.88366699e-02],
                        [  7.11975098e-02,   7.22656250e-02],
                        [  5.32531738e-02,   5.33142090e-02],
                        [  4.21142578e-02,   4.06188965e-02],
                        [  3.79028320e-02,   3.48815918e-02],
                        [  3.45458984e-02,   3.06701660e-02],
                        [  2.95410156e-02,   2.55737305e-02],
                        [  2.52380371e-02,   2.14843750e-02],
                        [  2.26745605e-02,   1.88903809e-02],
                        [  1.91955566e-02,   1.53198242e-02],
                        [  1.23901367e-02,   8.88061523e-03],
                        [  3.23486328e-03,   1.00708008e-03],
                        [ -4.82177734e-03,  -5.21850586e-03],
                        [ -9.82666016e-03,  -8.60595703e-03],
                        [ -1.23596191e-02,  -1.01623535e-02],
                        [ -1.36108398e-02,  -1.08642578e-02],
                        [ -1.52587891e-02,  -1.19018555e-02],
                        [ -1.93786621e-02,  -1.51367188e-02],
                        [ -2.52380371e-02,  -2.03552246e-02],
                        [ -3.08532715e-02,  -2.61535645e-02],
                        [ -3.59191895e-02,  -3.23486328e-02],
                        [ -4.01611328e-02,  -3.81164551e-02],
                        [ -4.22668457e-02,  -4.14733887e-02],
                        [ -4.32739258e-02,  -4.32434082e-02],
                        [ -4.44946289e-02,  -4.52575684e-02],
                        [ -4.40673828e-02,  -4.59899902e-02],
                        [ -4.18090820e-02,  -4.51354980e-02],
                        [ -4.21447754e-02,  -4.64172363e-02],
                        [ -4.76074219e-02,  -5.18493652e-02],
                        [ -5.59387207e-02,  -5.94177246e-02],
                        [ -6.42089844e-02,  -6.68334961e-02],
                        [ -7.07702637e-02,  -7.28759766e-02],
                        [ -7.47985840e-02,  -7.65686035e-02],
                        [ -7.65686035e-02,  -7.75756836e-02],
                        [ -7.57751465e-02,  -7.55004883e-02],
                        [ -7.05566406e-02,  -6.88781738e-02],
                        [ -6.02416992e-02,  -5.77697754e-02],
                        [ -4.89196777e-02,  -4.64782715e-02],
                        [ -4.20532227e-02,  -3.99780273e-02],
                        [ -4.07104492e-02,  -3.87268066e-02],
                        [ -4.17480469e-02,  -3.95202637e-02],
                        [ -4.25109863e-02,  -4.01611328e-02],
                        [ -4.16564941e-02,  -3.97949219e-02],
                        [ -3.84216309e-02,  -3.75671387e-02],
                        [ -3.37829590e-02,  -3.38134766e-02],
                        [ -2.99682617e-02,  -3.02124023e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.04162598e-02,  -2.03247070e-02],
                        [ -9.18579102e-03,  -9.55200195e-03],
                        [  5.09643555e-03,   3.96728516e-03],
                        [  2.01110840e-02,   1.85241699e-02],
                        [  3.55224609e-02,   3.41186523e-02],
                        [  4.99572754e-02,   4.89501953e-02],
                        [  5.75866699e-02,   5.65795898e-02],
                        [  4.79736328e-02,   4.63867188e-02],
                        [  1.08947754e-02,   8.66699219e-03],
                        [ -5.30090332e-02,  -5.52673340e-02],
                        [ -1.26373291e-01,  -1.27990723e-01],
                        [ -1.83227539e-01,  -1.83990479e-01],
                        [ -2.04101562e-01,  -2.04376221e-01],
                        [ -1.86828613e-01,  -1.86950684e-01],
                        [ -1.44714355e-01,  -1.44500732e-01],
                        [ -9.56420898e-02,  -9.44519043e-02],
                        [ -5.41687012e-02,  -5.16052246e-02],
                        [ -2.76489258e-02,  -2.40173340e-02],
                        [ -1.13220215e-02,  -7.47680664e-03],
                        [  8.23974609e-03,   1.16577148e-02],
                        [  3.82690430e-02,   4.11682129e-02],
                        [  7.17468262e-02,   7.43713379e-02],
                        [  9.55200195e-02,   9.77783203e-02],
                        [  1.00097656e-01,   1.01348877e-01],
                        [  8.08715820e-02,   8.02917480e-02],
                        [  3.54309082e-02,   3.28979492e-02],
                        [ -3.54309082e-02,  -3.93981934e-02],
                        [ -1.21307373e-01,  -1.25823975e-01],
                        [ -1.96441650e-01,  -2.01049805e-01],
                        [ -2.31811523e-01,  -2.36572266e-01],
                        [ -2.18963623e-01,  -2.23785400e-01],
                        [ -1.75323486e-01,  -1.79687500e-01],
                        [ -1.26159668e-01,  -1.29028320e-01],
                        [ -8.88671875e-02,  -8.94775391e-02],
                        [ -6.89086914e-02,  -6.72302246e-02],
                        [ -5.89599609e-02,  -5.56640625e-02],
                        [ -4.68750000e-02,  -4.26025391e-02],
                        [ -2.94494629e-02,  -2.43835449e-02],
                        [ -1.26953125e-02,  -6.80541992e-03],
                        [ -4.57763672e-04,   5.95092773e-03],
                        [  9.39941406e-03,   1.52587891e-02],
                        [  1.88903809e-02,   2.30712891e-02],
                        [  2.69775391e-02,   2.87780762e-02],
                        [  3.28063965e-02,   3.24401855e-02],
                        [  3.82690430e-02,   3.62548828e-02],
                        [  4.41284180e-02,   4.07409668e-02],
                        [  4.79125977e-02,   4.30297852e-02],
                        [  4.80041504e-02,   4.16870117e-02],
                        [  4.80651855e-02,   4.10461426e-02],
                        [  5.54504395e-02,   4.89501953e-02],
                        [  7.35168457e-02,   6.86950684e-02],
                        [  9.64660645e-02,   9.37194824e-02],
                        [  1.14135742e-01,   1.13220215e-01],
                        [  1.20849609e-01,   1.21551514e-01],
                        [  1.17462158e-01,   1.19842529e-01],
                        [  1.08856201e-01,   1.13220215e-01],
                        [  1.01318359e-01,   1.07421875e-01],
                        [  9.77783203e-02,   1.04644775e-01],
                        [  9.41162109e-02,   1.00433350e-01],
                        [  8.31909180e-02,   8.80126953e-02],
                        [  6.37512207e-02,   6.69555664e-02],
                        [  4.39147949e-02,   4.56848145e-02],
                        [  3.43933105e-02,   3.46374512e-02],
                        [  4.08630371e-02,   3.91540527e-02],
                        [  6.31103516e-02,   5.92041016e-02],
                        [  9.75036621e-02,   9.18273926e-02],
                        [  1.38427734e-01,   1.32202148e-01],
                        [  1.76147461e-01,   1.70532227e-01],
                        [  1.95159912e-01,   1.90704346e-01],
                        [  1.85211182e-01,   1.81884766e-01],
                        [  1.55090332e-01,   1.52893066e-01],
                        [  1.24420166e-01,   1.23748779e-01],
                        [  1.02081299e-01,   1.03546143e-01],
                        [  8.50219727e-02,   8.87145996e-02],
                        [  7.18383789e-02,   7.70263672e-02],
                        [  6.49719238e-02,   7.04650879e-02],
                        [  6.28662109e-02,   6.77795410e-02],
                        [  5.95092773e-02,   6.35986328e-02],
                        [  5.05981445e-02,   5.39550781e-02],
                        [  3.68347168e-02,   3.92150879e-02],
                        [  2.21862793e-02,   2.29187012e-02],
                        [  1.02844238e-02,   8.81958008e-03],
                        [  2.28881836e-03,  -1.22070312e-03],
                        [ -1.31225586e-03,  -5.92041016e-03],
                        [  9.15527344e-05,  -4.60815430e-03],
                        [  3.81469727e-03,  -4.57763672e-04],
                        [  5.09643555e-03,   1.22070312e-03],
                        [  3.11279297e-03,  -3.35693359e-04],
                        [  3.05175781e-05,  -2.41088867e-03],
                        [ -4.05883789e-03,  -4.76074219e-03],
                        [ -9.88769531e-03,  -8.48388672e-03],
                        [ -1.47399902e-02,  -1.16577148e-02],
                        [ -1.58081055e-02,  -1.20544434e-02],
                        [ -1.70288086e-02,  -1.32751465e-02],
                        [ -2.55432129e-02,  -2.19421387e-02],
                        [ -4.01306152e-02,  -3.65295410e-02],
                        [ -5.13000488e-02,  -4.79431152e-02],
                        [ -5.45959473e-02,  -5.22460938e-02],
                        [ -5.49011230e-02,  -5.42602539e-02],
                        [ -5.71899414e-02,  -5.83496094e-02],
                        [ -6.13403320e-02,  -6.35986328e-02],
                        [ -6.43920898e-02,  -6.69555664e-02],
                        [ -6.38122559e-02,  -6.63452148e-02],
                        [ -5.92346191e-02,  -6.19201660e-02],
                        [ -5.27343750e-02,  -5.56640625e-02],
                        [ -4.83093262e-02,  -5.10253906e-02],
                        [ -4.87060547e-02,  -5.04150391e-02],
                        [ -5.18493652e-02,  -5.21240234e-02],
                        [ -5.24597168e-02,  -5.15747070e-02],
                        [ -4.81262207e-02,  -4.68444824e-02],
                        [ -4.22973633e-02,  -4.11071777e-02],
                        [ -4.08630371e-02,  -3.97338867e-02],
                        [ -4.52270508e-02,  -4.37622070e-02],
                        [ -4.92553711e-02,  -4.75463867e-02],
                        [ -4.72717285e-02,  -4.58374023e-02],
                        [ -4.17175293e-02,  -4.12292480e-02],
                        [ -3.76892090e-02,  -3.82080078e-02],
                        [ -3.47900391e-02,  -3.57360840e-02],
                        [ -3.00292969e-02,  -3.06091309e-02],
                        [ -2.31628418e-02,  -2.32238770e-02],
                        [ -1.44958496e-02,  -1.44042969e-02],
                        [ -1.83105469e-03,  -1.92260742e-03],
                        [  1.53503418e-02,   1.52587891e-02],
                        [  3.38745117e-02,   3.43933105e-02],
                        [  5.07202148e-02,   5.20935059e-02],
                        [  6.15844727e-02,   6.34460449e-02],
                        [  5.58166504e-02,   5.72814941e-02],
                        [  2.10571289e-02,   2.15454102e-02],
                        [ -4.35180664e-02,  -4.38842773e-02],
                        [ -1.20941162e-01,  -1.21734619e-01],
                        [ -1.82922363e-01,  -1.83990479e-01],
                        [ -2.05902100e-01,  -2.07550049e-01],
                        [ -1.86798096e-01,  -1.89453125e-01],
                        [ -1.44744873e-01,  -1.48254395e-01],
                        [ -1.04766846e-01,  -1.08245850e-01],
                        [ -7.76672363e-02,  -8.01391602e-02],
                        [ -5.56030273e-02,  -5.67321777e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [  7.26318359e-03,   8.08715820e-03],
                        [  3.72619629e-02,   3.89709473e-02],
                        [  5.71594238e-02,   6.02416992e-02],
                        [  7.34863281e-02,   7.80334473e-02],
                        [  9.32617188e-02,   9.86328125e-02],
                        [  1.07910156e-01,   1.12976074e-01],
                        [  9.61914062e-02,   1.00006104e-01],
                        [  4.39453125e-02,   4.62951660e-02],
                        [ -4.17480469e-02,  -4.06494141e-02],
                        [ -1.34979248e-01,  -1.35101318e-01],
                        [ -2.03826904e-01,  -2.05627441e-01],
                        [ -2.26165771e-01,  -2.30072021e-01],
                        [ -2.01110840e-01,  -2.06878662e-01],
                        [ -1.50238037e-01,  -1.56860352e-01],
                        [ -1.04614258e-01,  -1.10839844e-01],
                        [ -8.27941895e-02,  -8.79211426e-02],
                        [ -7.81555176e-02,  -8.20312500e-02],
                        [ -7.01293945e-02,  -7.27844238e-02],
                        [ -5.01403809e-02,  -5.11474609e-02],
                        [ -3.00292969e-02,  -2.86865234e-02],
                        [ -2.22167969e-02,  -1.82189941e-02],
                        [ -2.23999023e-02,  -1.63269043e-02],
                        [ -1.86462402e-02,  -1.16577148e-02],
                        [ -6.25610352e-03,   5.49316406e-04],
                        [  1.21765137e-02,   1.83105469e-02],
                        [  3.17993164e-02,   3.71398926e-02],
                        [  4.66918945e-02,   5.09033203e-02],
                        [  5.27038574e-02,   5.49926758e-02],
                        [  5.16357422e-02,   5.11779785e-02],
                        [  5.09948730e-02,   4.76989746e-02],
                        [  5.80444336e-02,   5.26733398e-02],
                        [  7.47375488e-02,   6.83898926e-02],
                        [  9.79919434e-02,   9.14306641e-02],
                        [  1.20391846e-01,   1.13861084e-01],
                        [  1.32263184e-01,   1.26007080e-01],
                        [  1.29211426e-01,   1.23901367e-01],
                        [  1.16516113e-01,   1.13189697e-01],
                        [  1.02661133e-01,   1.02081299e-01],
                        [  9.12780762e-02,   9.33227539e-02],
                        [  8.14819336e-02,   8.53576660e-02],
                        [  7.20825195e-02,   7.69348145e-02],
                        [  6.24084473e-02,   6.79016113e-02],
                        [  5.20324707e-02,   5.81359863e-02],
                        [  4.20532227e-02,   4.83703613e-02],
                        [  3.61633301e-02,   4.17480469e-02],
                        [  3.94287109e-02,   4.31823730e-02],
                        [  5.54809570e-02,   5.68847656e-02],
                        [  8.34655762e-02,   8.28552246e-02],
                        [  1.17889404e-01,   1.15966797e-01],
                        [  1.52557373e-01,   1.49688721e-01],
                        [  1.80236816e-01,   1.76361084e-01],
                        [  1.89056396e-01,   1.84143066e-01],
                        [  1.71173096e-01,   1.65802002e-01],
                        [  1.36199951e-01,   1.31408691e-01],
                        [  1.03942871e-01,   1.00616455e-01],
                        [  8.42895508e-02,   8.25805664e-02],
                        [  7.40966797e-02,   7.35473633e-02],
                        [  6.92443848e-02,   6.93969727e-02],
                        [  6.80847168e-02,   6.90307617e-02],
                        [  6.60400391e-02,   6.81152344e-02],
                        [  5.65185547e-02,   5.97229004e-02],
                        [  3.85742188e-02,   4.22363281e-02],
                        [  1.89819336e-02,   2.21557617e-02],
                        [  5.24902344e-03,   7.44628906e-03],
                        [ -2.53295898e-03,  -1.09863281e-03],
                        [ -9.85717773e-03,  -8.69750977e-03],
                        [ -1.87988281e-02,  -1.77612305e-02],
                        [ -2.52990723e-02,  -2.48413086e-02],
                        [ -2.55737305e-02,  -2.60925293e-02],
                        [ -1.96228027e-02,  -2.10266113e-02],
                        [ -1.00402832e-02,  -1.15966797e-02],
                        [ -6.10351562e-05,  -1.19018555e-03],
                        [  6.95800781e-03,   6.31713867e-03],
                        [  7.87353516e-03,   7.14111328e-03],
                        [  1.22070312e-03,   3.05175781e-05],
                        [ -1.03759766e-02,  -1.18408203e-02],
                        [ -2.26135254e-02,  -2.38037109e-02],
                        [ -3.37829590e-02,  -3.43322754e-02],
                        [ -4.35485840e-02,  -4.37011719e-02],
                        [ -5.11779785e-02,  -5.16052246e-02],
                        [ -5.76477051e-02,  -5.85021973e-02],
                        [ -6.45751953e-02,  -6.54296875e-02],
                        [ -7.04345703e-02,  -7.05871582e-02],
                        [ -7.11059570e-02,  -7.03430176e-02],
                        [ -6.61315918e-02,  -6.48498535e-02],
                        [ -6.05163574e-02,  -5.92956543e-02],
                        [ -5.81970215e-02,  -5.71289062e-02],
                        [ -5.68542480e-02,  -5.55114746e-02],
                        [ -5.27954102e-02,  -5.08117676e-02],
                        [ -4.70581055e-02,  -4.46777344e-02],
                        [ -4.34570312e-02,  -4.14733887e-02],
                        [ -4.37927246e-02,  -4.28466797e-02],
                        [ -4.63256836e-02,  -4.64172363e-02],
                        [ -4.76684570e-02,  -4.83093262e-02],
                        [ -4.60205078e-02,  -4.68139648e-02],
                        [ -4.29077148e-02,  -4.40979004e-02],
                        [ -4.07409668e-02,  -4.27551270e-02],
                        [ -3.89404297e-02,  -4.18701172e-02],
                        [ -3.40881348e-02,  -3.72924805e-02],
                        [ -2.41394043e-02,  -2.67028809e-02],
                        [ -1.10778809e-02,  -1.26037598e-02],
                        [  1.89208984e-03,   1.22070312e-03],
                        [  1.37329102e-02,   1.34887695e-02],
                        [  2.44750977e-02,   2.46276855e-02],
                        [  3.29589844e-02,   3.39050293e-02],
                        [  3.84826660e-02,   4.06188965e-02],
                        [  4.10766602e-02,   4.41284180e-02],
                        [  3.61633301e-02,   3.93066406e-02],
                        [  1.25732422e-02,   1.50146484e-02],
                        [ -3.69262695e-02,  -3.52783203e-02],
                        [ -1.02355957e-01,  -1.01196289e-01],
                        [ -1.59790039e-01,  -1.58813477e-01],
                        [ -1.88568115e-01,  -1.88049316e-01],
                        [ -1.84234619e-01,  -1.84722900e-01],
                        [ -1.56158447e-01,  -1.57836914e-01],
                        [ -1.18957520e-01,  -1.21276855e-01],
                        [ -8.59985352e-02,  -8.81347656e-02],
                        [ -6.26220703e-02,  -6.41174316e-02],
                        [ -4.40368652e-02,  -4.50744629e-02],
                        [ -2.41699219e-02,  -2.52380371e-02],
                        [ -2.25830078e-03,  -3.41796875e-03],
                        [  2.20336914e-02,   2.13012695e-02],
                        [  5.05371094e-02,   5.06896973e-02],
                        [  7.99560547e-02,   8.08715820e-02],
                        [  1.01745605e-01,   1.02691650e-01],
                        [  1.08489990e-01,   1.08856201e-01],
                        [  9.39025879e-02,   9.36889648e-02],
                        [  4.94995117e-02,   4.91943359e-02],
                        [ -2.74963379e-02,  -2.74353027e-02],
                        [ -1.20513916e-01,  -1.20208740e-01],
                        [ -1.96807861e-01,  -1.96746826e-01],
                        [ -2.28790283e-01,  -2.29125977e-01],
                        [ -2.11425781e-01,  -2.11730957e-01],
                        [ -1.62963867e-01,  -1.62475586e-01],
                        [ -1.12396240e-01,  -1.10809326e-01],
                        [ -8.01391602e-02,  -7.78503418e-02],
                        [ -6.57348633e-02,  -6.35070801e-02],
                        [ -5.68542480e-02,  -5.49926758e-02],
                        [ -4.79125977e-02,  -4.62646484e-02],
                        [ -4.25720215e-02,  -4.08935547e-02],
                        [ -3.94592285e-02,  -3.80249023e-02],
                        [ -2.83203125e-02,  -2.78930664e-02],
                        [ -5.34057617e-03,  -6.65283203e-03],
                        [  2.00195312e-02,   1.70593262e-02],
                        [  3.77807617e-02,   3.38745117e-02],
                        [  4.63562012e-02,   4.22058105e-02],
                        [  4.75769043e-02,   4.34265137e-02],
                        [  4.25109863e-02,   3.82690430e-02],
                        [  3.49121094e-02,   3.07312012e-02],
                        [  3.27148438e-02,   2.93579102e-02],
                        [  4.24499512e-02,   4.10156250e-02],
                        [  6.39343262e-02,   6.49108887e-02],
                        [  9.18884277e-02,   9.49707031e-02],
                        [  1.19628906e-01,   1.24084473e-01],
                        [  1.38580322e-01,   1.43859863e-01],
                        [  1.40563965e-01,   1.46606445e-01],
                        [  1.25122070e-01,   1.31805420e-01],
                        [  1.02325439e-01,   1.08978271e-01],
                        [  8.49304199e-02,   9.03930664e-02],
                        [  7.82470703e-02,   8.13903809e-02],
                        [  7.78808594e-02,   7.83386230e-02],
                        [  7.55920410e-02,   7.37304688e-02],
                        [  6.56433105e-02,   6.20422363e-02],
                        [  4.85229492e-02,   4.33959961e-02],
                        [  3.17687988e-02,   2.50244141e-02],
                        [  2.49633789e-02,   1.69677734e-02],
                        [  3.29589844e-02,   2.47802734e-02],
                        [  5.52978516e-02,   4.83398438e-02],
                        [  9.03015137e-02,   8.55712891e-02],
                        [  1.34033203e-01,   1.31713867e-01],
                        [  1.73431396e-01,   1.73187256e-01],
                        [  1.89178467e-01,   1.90826416e-01],
                        [  1.73370361e-01,   1.77154541e-01],
                        [  1.38397217e-01,   1.44378662e-01],
                        [  1.03607178e-01,   1.11236572e-01],
                        [  7.94372559e-02,   8.74633789e-02],
                        [  6.57348633e-02,   7.28149414e-02],
                        [  5.88684082e-02,   6.43310547e-02],
                        [  5.62438965e-02,   6.00585938e-02],
                        [  5.52978516e-02,   5.75866699e-02],
                        [  5.23071289e-02,   5.28564453e-02],
                        [  4.45861816e-02,   4.28466797e-02],
                        [  3.27453613e-02,   2.86865234e-02],
                        [  2.01721191e-02,   1.45263672e-02],
                        [  9.42993164e-03,   3.35693359e-03],
                        [  1.22070312e-04,  -5.43212891e-03],
                        [ -7.78198242e-03,  -1.25427246e-02],
                        [ -1.17187500e-02,  -1.58386230e-02],
                        [ -1.17187500e-02,  -1.51062012e-02],
                        [ -1.26953125e-02,  -1.47399902e-02],
                        [ -1.80358887e-02,  -1.82189941e-02],
                        [ -2.51770020e-02,  -2.35290527e-02],
                        [ -2.95410156e-02,  -2.68249512e-02],
                        [ -2.97546387e-02,  -2.69165039e-02],
                        [ -2.75268555e-02,  -2.49023438e-02],
                        [ -2.35290527e-02,  -2.09045410e-02],
                        [ -1.84631348e-02,  -1.55944824e-02],
                        [ -1.62658691e-02,  -1.34277344e-02],
                        [ -2.10876465e-02,  -1.89208984e-02],
                        [ -3.27453613e-02,  -3.16467285e-02],
                        [ -4.81262207e-02,  -4.77905273e-02],
                        [ -6.23779297e-02,  -6.20727539e-02],
                        [ -7.02514648e-02,  -6.95190430e-02],
                        [ -7.09533691e-02,  -7.00378418e-02],
                        [ -6.86645508e-02,  -6.81457520e-02],
                        [ -6.68945312e-02,  -6.70776367e-02],
                        [ -6.62231445e-02,  -6.68334961e-02],
                        [ -6.60705566e-02,  -6.66809082e-02],
                        [ -6.53381348e-02,  -6.59179688e-02],
                        [ -6.21337891e-02,  -6.32934570e-02],
                        [ -5.57556152e-02,  -5.81054688e-02],
                        [ -4.83703613e-02,  -5.19104004e-02],
                        [ -4.22058105e-02,  -4.62036133e-02],
                        [ -3.67736816e-02,  -4.04968262e-02],
                        [ -3.11279297e-02,  -3.42407227e-02],
                        [ -2.62756348e-02,  -2.89306641e-02],
                        [ -2.45056152e-02,  -2.67333984e-02],
                        [ -2.67639160e-02,  -2.80456543e-02],
                        [ -3.00598145e-02,  -2.95104980e-02],
                        [ -2.92053223e-02,  -2.63977051e-02],
                        [ -2.24304199e-02,  -1.76696777e-02],
                        [ -1.25122070e-02,  -6.77490234e-03],
                        [ -2.19726562e-03,   3.81469727e-03],
                        [  9.64355469e-03,   1.56555176e-02],
                        [  2.58789062e-02,   3.18298340e-02],
                        [  4.57153320e-02,   5.10864258e-02],
                        [  6.04248047e-02,   6.41479492e-02],
                        [  5.50842285e-02,   5.61828613e-02],
                        [  1.83715820e-02,   1.65710449e-02],
                        [ -4.56237793e-02,  -4.98046875e-02],
                        [ -1.17462158e-01,  -1.23199463e-01],
                        [ -1.74987793e-01,  -1.81793213e-01],
                        [ -2.02301025e-01,  -2.09960938e-01],
                        [ -1.93389893e-01,  -2.01538086e-01],
                        [ -1.57775879e-01,  -1.65405273e-01],
                        [ -1.16607666e-01,  -1.22375488e-01],
                        [ -8.55102539e-02,  -8.83789062e-02],
                        [ -6.50634766e-02,  -6.49414062e-02],
                        [ -4.94079590e-02,  -4.68444824e-02],
                        [ -3.54309082e-02,  -3.10058594e-02],
                        [ -1.95312500e-02,  -1.33361816e-02],
                        [  6.83593750e-03,   1.46179199e-02],
                        [  4.64172363e-02,   5.51452637e-02],
                        [  8.74938965e-02,   9.58251953e-02],
                        [  1.16882324e-01,   1.23382568e-01],
                        [  1.31988525e-01,   1.35894775e-01],
                        [  1.29638672e-01,   1.30981445e-01],
                        [  9.66491699e-02,   9.57946777e-02],
                        [  2.33459473e-02,   2.04772949e-02],
                        [ -7.89489746e-02,  -8.39538574e-02],
                        [ -1.78833008e-01,  -1.85760498e-01],
                        [ -2.40814209e-01,  -2.48779297e-01],
                        [ -2.44537354e-01,  -2.52075195e-01],
                        [ -1.98486328e-01,  -2.04345703e-01],
                        [ -1.36718750e-01,  -1.40502930e-01],
                        [ -9.19189453e-02,  -9.37194824e-02],
                        [ -6.96411133e-02,  -6.96716309e-02],
                        [ -5.48400879e-02,  -5.28869629e-02],
                        [ -3.75061035e-02,  -3.33251953e-02],
                        [ -2.21862793e-02,  -1.61743164e-02],
                        [ -1.58691406e-02,  -9.15527344e-03],
                        [ -1.56860352e-02,  -9.64355469e-03],
                        [ -1.29394531e-02,  -8.39233398e-03],
                        [ -3.72314453e-03,  -7.93457031e-04],
                        [  1.04370117e-02,   1.19018555e-02],
                        [  2.68554688e-02,   2.67333984e-02],
                        [  4.10156250e-02,   3.89404297e-02],
                        [  4.77905273e-02,   4.36096191e-02],
                        [  4.71801758e-02,   4.15649414e-02],
                        [  4.61730957e-02,   4.03442383e-02],
                        [  5.19714355e-02,   4.70581055e-02],
                        [  6.55212402e-02,   6.20117188e-02],
                        [  8.36181641e-02,   8.14208984e-02],
                        [  1.03179932e-01,   1.02233887e-01],
                        [  1.19628906e-01,   1.20361328e-01],
                        [  1.27502441e-01,   1.30310059e-01],
                        [  1.26007080e-01,   1.30767822e-01],
                        [  1.19628906e-01,   1.25427246e-01],
                        [  1.12762451e-01,   1.18347168e-01],
                        [  1.06964111e-01,   1.11541748e-01],
                        [  9.99450684e-02,   1.03302002e-01],
                        [  8.68225098e-02,   8.91113281e-02],
                        [  6.70166016e-02,   6.79626465e-02],
                        [  4.76074219e-02,   4.66003418e-02],
                        [  3.68041992e-02,   3.35388184e-02],
                        [  3.53088379e-02,   3.01818848e-02],
                        [  3.82995605e-02,   3.24096680e-02],
                        [  4.48608398e-02,   3.92761230e-02],
                        [  5.95703125e-02,   5.47485352e-02],
                        [  8.53576660e-02,   8.12988281e-02],
                        [  1.18835449e-01,   1.15661621e-01],
                        [  1.50299072e-01,   1.48559570e-01],
                        [  1.67877197e-01,   1.68304443e-01],
                        [  1.65832520e-01,   1.68609619e-01],
                        [  1.48559570e-01,   1.53015137e-01],
                        [  1.26373291e-01,   1.31500244e-01],
                        [  1.07543945e-01,   1.12640381e-01],
                        [  9.26818848e-02,   9.76257324e-02],
                        [  7.80029297e-02,   8.27941895e-02],
                        [  6.19812012e-02,   6.62231445e-02],
                        [  4.51049805e-02,   4.79736328e-02],
                        [  2.81982422e-02,   2.90222168e-02],
                        [  1.46179199e-02,   1.33666992e-02],
                        [  7.53784180e-03,   4.91333008e-03],
                        [  5.06591797e-03,   1.83105469e-03],
                        [  2.80761719e-03,  -8.54492188e-04],
                        [ -1.52587891e-04,  -4.36401367e-03],
                        [ -1.15966797e-03,  -5.85937500e-03],
                        [  9.15527344e-05,  -4.51660156e-03],
                        [ -4.27246094e-04,  -3.99780273e-03],
                        [ -4.42504883e-03,  -6.46972656e-03],
                        [ -9.36889648e-03,  -1.00402832e-02],
                        [ -1.41296387e-02,  -1.40380859e-02],
                        [ -1.96228027e-02,  -1.90429688e-02],
                        [ -2.38952637e-02,  -2.26135254e-02],
                        [ -2.45971680e-02,  -2.22473145e-02],
                        [ -2.45971680e-02,  -2.12707520e-02],
                        [ -2.94799805e-02,  -2.59094238e-02],
                        [ -3.94592285e-02,  -3.64074707e-02],
                        [ -4.91943359e-02,  -4.68139648e-02],
                        [ -5.71594238e-02,  -5.50842285e-02],
                        [ -6.61621094e-02,  -6.40258789e-02],
                        [ -7.37915039e-02,  -7.17773438e-02],
                        [ -7.35778809e-02,  -7.22961426e-02],
                        [ -6.54296875e-02,  -6.52770996e-02],
                        [ -5.58471680e-02,  -5.66711426e-02],
                        [ -5.04760742e-02,  -5.16357422e-02],
                        [ -4.95910645e-02,  -5.07202148e-02],
                        [ -4.90112305e-02,  -5.03845215e-02],
                        [ -4.54406738e-02,  -4.76074219e-02],
                        [ -4.15039062e-02,  -4.45556641e-02],
                        [ -4.35485840e-02,  -4.69665527e-02],
                        [ -5.33142090e-02,  -5.63964844e-02],
                        [ -6.36596680e-02,  -6.60705566e-02],
                        [ -6.50634766e-02,  -6.70776367e-02],
                        [ -5.58166504e-02,  -5.77392578e-02],
                        [ -4.19921875e-02,  -4.36706543e-02],
                        [ -2.98461914e-02,  -3.06091309e-02],
                        [ -2.09350586e-02,  -2.02026367e-02],
                        [ -1.35192871e-02,  -1.13525391e-02],
                        [ -6.71386719e-03,  -3.72314453e-03],
                        [ -1.15966797e-03,   2.10571289e-03],
                        [  5.06591797e-03,   8.54492188e-03],
                        [  1.66320801e-02,   2.05993652e-02],
                        [  3.47290039e-02,   3.92150879e-02],
                        [  5.21545410e-02,   5.64880371e-02],
                        [  5.49621582e-02,   5.81970215e-02],
                        [  3.10058594e-02,   3.26232910e-02],
                        [ -2.21862793e-02,  -2.20336914e-02],
                        [ -9.48181152e-02,  -9.56726074e-02],
                        [ -1.66320801e-01,  -1.67999268e-01],
                        [ -2.11975098e-01,  -2.14813232e-01],
                        [ -2.15637207e-01,  -2.19879150e-01],
                        [ -1.80603027e-01,  -1.85974121e-01],
                        [ -1.30371094e-01,  -1.35986328e-01],
                        [ -9.19799805e-02,  -9.68627930e-02],
                        [ -7.31201172e-02,  -7.69348145e-02],
                        [ -6.17980957e-02,  -6.46972656e-02],
                        [ -4.67224121e-02,  -4.88586426e-02],
                        [ -2.73132324e-02,  -2.83203125e-02],
                        [ -6.40869141e-03,  -5.73730469e-03],
                        [  1.46789551e-02,   1.73034668e-02],
                        [  3.71093750e-02,   4.12597656e-02],
                        [  6.48803711e-02,   6.96716309e-02],
                        [  9.97924805e-02,   1.04583740e-01],
                        [  1.32904053e-01,   1.37542725e-01],
                        [  1.43890381e-01,   1.48590088e-01],
                        [  1.14715576e-01,   1.19232178e-01],
                        [  4.31823730e-02,   4.67834473e-02],
                        [ -5.62744141e-02,  -5.43518066e-02],
                        [ -1.57196045e-01,  -1.57165527e-01],
                        [ -2.27539062e-01,  -2.28912354e-01],
                        [ -2.45971680e-01,  -2.48107910e-01],
                        [ -2.16491699e-01,  -2.19268799e-01],
                        [ -1.63360596e-01,  -1.66992188e-01],
                        [ -1.13067627e-01,  -1.17675781e-01],
                        [ -7.99865723e-02,  -8.51135254e-02],
                        [ -6.13098145e-02,  -6.60400391e-02],
                        [ -4.58679199e-02,  -4.95300293e-02],
                        [ -2.93579102e-02,  -3.18908691e-02],
                        [ -1.72729492e-02,  -1.90429688e-02],
                        [ -1.24511719e-02,  -1.36718750e-02],
                        [ -8.97216797e-03,  -9.27734375e-03],
                        [ -1.03759766e-03,   9.15527344e-05],
                        [  1.04675293e-02,   1.30920410e-02],
                        [  2.23388672e-02,   2.59094238e-02],
                        [  3.03344727e-02,   3.40881348e-02],
                        [  2.89001465e-02,   3.24707031e-02],
                        [  1.88293457e-02,   2.23693848e-02],
                        [  1.18408203e-02,   1.56250000e-02],
                        [  2.18505859e-02,   2.56042480e-02],
                        [  5.27038574e-02,   5.57250977e-02],
                        [  9.49401855e-02,   9.66186523e-02],
                        [  1.32995605e-01,   1.33300781e-01],
                        [  1.54388428e-01,   1.53778076e-01],
                        [  1.54510498e-01,   1.53411865e-01],
                        [  1.38366699e-01,   1.36688232e-01],
                        [  1.18377686e-01,   1.15661621e-01],
                        [  1.05377197e-01,   1.01562500e-01],
                        [  1.01165771e-01,   9.67407227e-02],
                        [  9.92431641e-02,   9.50622559e-02],
                        [  9.25598145e-02,   8.91113281e-02],
                        [  8.04748535e-02,   7.76672363e-02],
                        [  6.70776367e-02,   6.46667480e-02],
                        [  5.38330078e-02,   5.18798828e-02],
                        [  3.82080078e-02,   3.72314453e-02],
                        [  2.02026367e-02,   2.07824707e-02],
                        [  7.17163086e-03,   9.30786133e-03],
                        [  1.06811523e-02,   1.37634277e-02],
                        [  3.73229980e-02,   4.07409668e-02],
                        [  8.28247070e-02,   8.63342285e-02],
                        [  1.33636475e-01,   1.37451172e-01],
                        [  1.72058105e-01,   1.76239014e-01],
                        [  1.83715820e-01,   1.87805176e-01],
                        [  1.67755127e-01,   1.70928955e-01],
                        [  1.38397217e-01,   1.40075684e-01],
                        [  1.12701416e-01,   1.12976074e-01],
                        [  9.68627930e-02,   9.62829590e-02],
                        [  8.59375000e-02,   8.47473145e-02],
                        [  7.49511719e-02,   7.29370117e-02],
                        [  6.33850098e-02,   6.02722168e-02],
                        [  4.96520996e-02,   4.55322266e-02],
                        [  3.21960449e-02,   2.77709961e-02],
                        [  1.47094727e-02,   1.08032227e-02],
                        [  1.95312500e-03,  -1.06811523e-03],
                        [ -5.43212891e-03,  -7.75146484e-03],
                        [ -8.78906250e-03,  -1.06811523e-02],
                        [ -8.78906250e-03,  -1.01013184e-02],
                        [ -5.82885742e-03,  -6.04248047e-03],
                        [ -2.01416016e-03,  -7.62939453e-04],
                        [ -2.19726562e-03,   2.74658203e-04],
                        [ -8.57543945e-03,  -5.58471680e-03],
                        [ -1.61132812e-02,  -1.31835938e-02],
                        [ -1.84020996e-02,  -1.55639648e-02],
                        [ -1.64184570e-02,  -1.33666992e-02],
                        [ -1.71813965e-02,  -1.38854980e-02],
                        [ -2.52990723e-02,  -2.22778320e-02],
                        [ -3.76586914e-02,  -3.55834961e-02],
                        [ -4.66003418e-02,  -4.57153320e-02],
                        [ -4.77905273e-02,  -4.78210449e-02],
                        [ -4.51965332e-02,  -4.56237793e-02],
                        [ -4.63562012e-02,  -4.70581055e-02],
                        [ -5.16357422e-02,  -5.29785156e-02],
                        [ -5.39245605e-02,  -5.62438965e-02],
                        [ -5.07507324e-02,  -5.38635254e-02],
                        [ -4.72717285e-02,  -5.05676270e-02],
                        [ -4.70886230e-02,  -4.99877930e-02],
                        [ -4.89196777e-02,  -5.13305664e-02],
                        [ -5.13610840e-02,  -5.35888672e-02],
                        [ -5.52673340e-02,  -5.74951172e-02],
                        [ -6.19506836e-02,  -6.38427734e-02],
                        [ -6.97021484e-02,  -7.06176758e-02],
                        [ -7.37609863e-02,  -7.33337402e-02],
                        [ -7.10754395e-02,  -6.95190430e-02],
                        [ -6.30493164e-02,  -6.09436035e-02],
                        [ -5.27954102e-02,  -5.04150391e-02],
                        [ -4.22058105e-02,  -3.93676758e-02],
                        [ -3.10974121e-02,  -2.75268555e-02],
                        [ -1.89514160e-02,  -1.48010254e-02],
                        [ -7.08007812e-03,  -3.05175781e-03],
                        [  2.92968750e-03,   6.01196289e-03],
                        [  1.22375488e-02,   1.40991211e-02],
                        [  2.34069824e-02,   2.42614746e-02],
                        [  3.69262695e-02,   3.70483398e-02],
                        [  4.99267578e-02,   4.91333008e-02],
                        [  5.52368164e-02,   5.30700684e-02],
                        [  4.20532227e-02,   3.83605957e-02],
                        [  2.89916992e-03,  -1.89208984e-03],
                        [ -5.87158203e-02,  -6.37817383e-02],
                        [ -1.29760742e-01,  -1.34338379e-01],
                        [ -1.91284180e-01,  -1.95159912e-01],
                        [ -2.21099854e-01,  -2.24365234e-01],
                        [ -2.07916260e-01,  -2.10418701e-01],
                        [ -1.66381836e-01,  -1.67510986e-01],
                        [ -1.24786377e-01,  -1.23992920e-01],
                        [ -9.79919434e-02,  -9.51843262e-02],
                        [ -8.16650391e-02,  -7.74230957e-02],
                        [ -6.62231445e-02,  -6.13403320e-02],
                        [ -4.60815430e-02,  -4.10766602e-02],
                        [ -2.11486816e-02,  -1.61437988e-02],
                        [  3.99780273e-03,   8.94165039e-03],
                        [  2.56958008e-02,   2.99987793e-02],
                        [  4.79431152e-02,   5.07202148e-02],
                        [  7.76062012e-02,   7.82470703e-02],
                        [  1.11175537e-01,   1.09741211e-01],
                        [  1.34674072e-01,   1.31744385e-01],
                        [  1.35986328e-01,   1.32141113e-01],
                        [  1.08306885e-01,   1.03729248e-01],
                        [  4.66003418e-02,   4.13513184e-02],
                        [ -4.49218750e-02,  -5.05371094e-02],
                        [ -1.44042969e-01,  -1.49139404e-01],
                        [ -2.18017578e-01,  -2.21649170e-01],
                        [ -2.42431641e-01,  -2.44110107e-01],
                        [ -2.16339111e-01,  -2.16186523e-01],
                        [ -1.62902832e-01,  -1.61407471e-01],
                        [ -1.12335205e-01,  -1.09741211e-01],
                        [ -8.02612305e-02,  -7.65380859e-02],
                        [ -6.25305176e-02,  -5.77087402e-02],
                        [ -4.81872559e-02,  -4.27856445e-02],
                        [ -3.19213867e-02,  -2.70080566e-02],
                        [ -1.59606934e-02,  -1.23596191e-02],
                        [ -5.12695312e-03,  -3.11279297e-03],
                        [ -1.22070312e-03,  -5.49316406e-04],
                        [  3.66210938e-04,  -6.10351562e-05],
                        [  6.28662109e-03,   4.69970703e-03],
                        [  1.71508789e-02,   1.42211914e-02],
                        [  2.73132324e-02,   2.31628418e-02],
                        [  3.28063965e-02,   2.81982422e-02],
                        [  3.49426270e-02,   3.08532715e-02],
                        [  3.79333496e-02,   3.49731445e-02],
                        [  4.66918945e-02,   4.48608398e-02],
                        [  6.44531250e-02,   6.34765625e-02],
                        [  8.87756348e-02,   8.87145996e-02],
                        [  1.12518311e-01,   1.13616943e-01],
                        [  1.29364014e-01,   1.31805420e-01],
                        [  1.36047363e-01,   1.39495850e-01],
                        [  1.31500244e-01,   1.35162354e-01],
                        [  1.20300293e-01,   1.23382568e-01],
                        [  1.13098145e-01,   1.15295410e-01],
                        [  1.14318848e-01,   1.15783691e-01],
                        [  1.14501953e-01,   1.15386963e-01],
                        [  1.03576660e-01,   1.03668213e-01],
                        [  8.47778320e-02,   8.37097168e-02],
                        [  6.64367676e-02,   6.42089844e-02],
                        [  4.86755371e-02,   4.58068848e-02],
                        [  2.87170410e-02,   2.59704590e-02],
                        [  1.07727051e-02,   8.66699219e-03],
                        [  2.10571289e-03,   7.01904297e-04],
                        [  6.25610352e-03,   5.21850586e-03],
                        [  2.44445801e-02,   2.38342285e-02],
                        [  5.67321777e-02,   5.69152832e-02],
                        [  9.86328125e-02,   9.98535156e-02],
                        [  1.40258789e-01,   1.42364502e-01],
                        [  1.68762207e-01,   1.71051025e-01],
                        [  1.73675537e-01,   1.75537109e-01],
                        [  1.55761719e-01,   1.57012939e-01],
                        [  1.27746582e-01,   1.28540039e-01],
                        [  1.02539062e-01,   1.03118896e-01],
                        [  8.37402344e-02,   8.39538574e-02],
                        [  6.92749023e-02,   6.86950684e-02],
                        [  5.76171875e-02,   5.61523438e-02],
                        [  4.74243164e-02,   4.55017090e-02],
                        [  3.61938477e-02,   3.45153809e-02],
                        [  2.47497559e-02,   2.36816406e-02],
                        [  1.74255371e-02,   1.69067383e-02],
                        [  1.48620605e-02,   1.45874023e-02],
                        [  1.17187500e-02,   1.16271973e-02],
                        [  4.05883789e-03,   4.39453125e-03],
                        [ -6.22558594e-03,  -5.12695312e-03],
                        [ -1.47399902e-02,  -1.30615234e-02],
                        [ -2.02331543e-02,  -1.85852051e-02],
                        [ -2.45971680e-02,  -2.35290527e-02],
                        [ -2.82592773e-02,  -2.78930664e-02],
                        [ -2.76794434e-02,  -2.77709961e-02],
                        [ -1.98974609e-02,  -2.01721191e-02],
                        [ -9.09423828e-03,  -9.58251953e-03],
                        [ -4.57763672e-03,  -5.61523438e-03],
                        [ -1.06811523e-02,  -1.23291016e-02],
                        [ -2.18505859e-02,  -2.36816406e-02],
                        [ -3.03649902e-02,  -3.17382812e-02],
                        [ -3.42712402e-02,  -3.48205566e-02],
                        [ -3.63159180e-02,  -3.61328125e-02],
                        [ -4.09240723e-02,  -4.03747559e-02],
                        [ -5.19714355e-02,  -5.12084961e-02],
                        [ -6.75048828e-02,  -6.63757324e-02],
                        [ -7.86437988e-02,  -7.69348145e-02],
                        [ -7.90100098e-02,  -7.68737793e-02],
                        [ -7.17468262e-02,  -6.98242188e-02],
                        [ -6.44226074e-02,  -6.33239746e-02],
                        [ -6.02416992e-02,  -6.00891113e-02],
                        [ -5.80139160e-02,  -5.85632324e-02],
                        [ -5.55419922e-02,  -5.64575195e-02],
                        [ -4.99877930e-02,  -5.12695312e-02],
                        [ -4.03442383e-02,  -4.22058105e-02],
                        [ -3.20434570e-02,  -3.44848633e-02],
                        [ -3.20739746e-02,  -3.46374512e-02],
                        [ -3.85742188e-02,  -4.05273438e-02],
                        [ -4.19616699e-02,  -4.28466797e-02],
                        [ -3.57971191e-02,  -3.57055664e-02],
                        [ -2.11486816e-02,  -2.03857422e-02],
                        [ -2.19726562e-03,  -9.46044922e-04],
                        [  1.72729492e-02,   1.91345215e-02],
                        [  3.44543457e-02,   3.70483398e-02],
                        [  4.82177734e-02,   5.13305664e-02],
                        [  5.95397949e-02,   6.24694824e-02],
                        [  6.57348633e-02,   6.78100586e-02],
                        [  5.43212891e-02,   5.52368164e-02],
                        [  1.04064941e-02,   1.03454590e-02],
                        [ -6.55517578e-02,  -6.63452148e-02],
                        [ -1.51397705e-01,  -1.52954102e-01],
                        [ -2.16705322e-01,  -2.19146729e-01],
                        [ -2.41333008e-01,  -2.44689941e-01],
                        [ -2.23693848e-01,  -2.27416992e-01],
                        [ -1.77612305e-01,  -1.80969238e-01],
                        [ -1.25366211e-01,  -1.27746582e-01],
                        [ -8.65783691e-02,  -8.78601074e-02],
                        [ -6.67724609e-02,  -6.71081543e-02],
                        [ -5.67321777e-02,  -5.62133789e-02],
                        [ -4.58068848e-02,  -4.41894531e-02],
                        [ -3.23791504e-02,  -2.95410156e-02],
                        [ -1.80969238e-02,  -1.42517090e-02],
                        [  2.92968750e-03,   7.11059570e-03],
                        [  3.80554199e-02,   4.18090820e-02],
                        [  8.27331543e-02,   8.56323242e-02],
                        [  1.24572754e-01,   1.26525879e-01],
                        [  1.54235840e-01,   1.55364990e-01],
                        [  1.62170410e-01,   1.62292480e-01],
                        [  1.33880615e-01,   1.32629395e-01],
                        [  6.21948242e-02,   5.94787598e-02],
                        [ -4.04968262e-02,  -4.43115234e-02],
                        [ -1.45843506e-01,  -1.50024414e-01],
                        [ -2.22076416e-01,  -2.25982666e-01],
                        [ -2.47009277e-01,  -2.50366211e-01],
                        [ -2.19543457e-01,  -2.22351074e-01],
                        [ -1.62567139e-01,  -1.64703369e-01],
                        [ -1.07879639e-01,  -1.08947754e-01],
                        [ -7.31811523e-02,  -7.26928711e-02],
                        [ -5.42297363e-02,  -5.22155762e-02],
                        [ -3.88183594e-02,  -3.57360840e-02],
                        [ -2.35900879e-02,  -2.00805664e-02],
                        [ -1.53198242e-02,  -1.17492676e-02],
                        [ -1.68151855e-02,  -1.32751465e-02],
                        [ -1.90429688e-02,  -1.56250000e-02],
                        [ -1.09558105e-02,  -7.96508789e-03],
                        [  8.75854492e-03,   1.07421875e-02],
                        [  3.20129395e-02,   3.25317383e-02],
                        [  4.79125977e-02,   4.71191406e-02],
                        [  5.06896973e-02,   4.90112305e-02],
                        [  4.52575684e-02,   4.30297852e-02],
                        [  4.04663086e-02,   3.78112793e-02],
                        [  3.93066406e-02,   3.62548828e-02],
                        [  4.30603027e-02,   3.96728516e-02],
                        [  5.80749512e-02,   5.48400879e-02],
                        [  8.79211426e-02,   8.54492188e-02],
                        [  1.23474121e-01,   1.22070312e-01],
                        [  1.49139404e-01,   1.48620605e-01],
                        [  1.56311035e-01,   1.56372070e-01],
                        [  1.46820068e-01,   1.47399902e-01],
                        [  1.28112793e-01,   1.29333496e-01],
                        [  1.08734131e-01,   1.10717773e-01],
                        [  9.40551758e-02,   9.66186523e-02],
                        [  8.36486816e-02,   8.63037109e-02],
                        [  7.56835938e-02,   7.79418945e-02],
                        [  7.09838867e-02,   7.27539062e-02],
                        [  6.86035156e-02,   7.00988770e-02],
                        [  6.27746582e-02,   6.40869141e-02],
                        [  4.97436523e-02,   5.06896973e-02],
                        [  3.28369141e-02,   3.31115723e-02],
                        [  1.80664062e-02,   1.75170898e-02],
                        [  1.12304688e-02,   1.00708008e-02],
                        [  2.00195312e-02,   1.86767578e-02],
                        [  4.98962402e-02,   4.85534668e-02],
                        [  9.46350098e-02,   9.32006836e-02],
                        [  1.37298584e-01,   1.35559082e-01],
                        [  1.61590576e-01,   1.59637451e-01],
                        [  1.61010742e-01,   1.59179688e-01],
                        [  1.41693115e-01,   1.40319824e-01],
                        [  1.18560791e-01,   1.17767334e-01],
                        [  1.02630615e-01,   1.02203369e-01],
                        [  9.18579102e-02,   9.16137695e-02],
                        [  7.86437988e-02,   7.86132812e-02],
                        [  6.09741211e-02,   6.14624023e-02],
                        [  4.13818359e-02,   4.25720215e-02],
                        [  2.20642090e-02,   2.38037109e-02],
                        [  6.86645508e-03,   8.72802734e-03],
                        [  9.76562500e-04,   2.71606445e-03],
                        [  3.90625000e-03,   5.52368164e-03],
                        [  8.14819336e-03,   9.79614258e-03],
                        [  7.56835938e-03,   9.21630859e-03],
                        [  1.64794922e-03,   3.02124023e-03],
                        [ -7.41577148e-03,  -6.71386719e-03],
                        [ -1.66320801e-02,  -1.67541504e-02],
                        [ -2.19726562e-02,  -2.27050781e-02],
                        [ -2.06604004e-02,  -2.16674805e-02],
                        [ -1.42211914e-02,  -1.54724121e-02],
                        [ -8.60595703e-03,  -1.02233887e-02],
                        [ -9.55200195e-03,  -1.16271973e-02],
                        [ -1.67846680e-02,  -1.91040039e-02],
                        [ -2.56042480e-02,  -2.77709961e-02],
                        [ -3.43322754e-02,  -3.59802246e-02],
                        [ -4.52270508e-02,  -4.62341309e-02],
                        [ -5.72204590e-02,  -5.78308105e-02],
                        [ -6.57958984e-02,  -6.61010742e-02],
                        [ -6.97021484e-02,  -6.95495605e-02],
                        [ -7.04040527e-02,  -6.95495605e-02],
                        [ -6.61926270e-02,  -6.46057129e-02],
                        [ -5.67016602e-02,  -5.46264648e-02],
                        [ -4.90417480e-02,  -4.69360352e-02],
                        [ -4.98352051e-02,  -4.79431152e-02],
                        [ -5.59997559e-02,  -5.42907715e-02],
                        [ -6.03027344e-02,  -5.86242676e-02],
                        [ -5.95703125e-02,  -5.80444336e-02],
                        [ -5.45959473e-02,  -5.35583496e-02],
                        [ -4.80957031e-02,  -4.77905273e-02],
                        [ -4.37316895e-02,  -4.41894531e-02],
                        [ -4.23278809e-02,  -4.32739258e-02],
                        [ -3.93371582e-02,  -4.04968262e-02],
                        [ -3.05175781e-02,  -3.18298340e-02],
                        [ -1.73034668e-02,  -1.89208984e-02],
                        [ -3.57055664e-03,  -5.52368164e-03],
                        [  9.00268555e-03,   6.92749023e-03],
                        [  2.00195312e-02,   1.82495117e-02],
                        [  2.98156738e-02,   2.85644531e-02],
                        [  4.01611328e-02,   3.93981934e-02],
                        [  5.04455566e-02,   4.99572754e-02],
                        [  5.22460938e-02,   5.19714355e-02],
                        [  3.21655273e-02,   3.22875977e-02],
                        [ -1.69677734e-02,  -1.62048340e-02],
                        [ -8.82568359e-02,  -8.69140625e-02],
                        [ -1.64306641e-01,  -1.62658691e-01],
                        [ -2.23754883e-01,  -2.22106934e-01],
                        [ -2.46490479e-01,  -2.44934082e-01],
                        [ -2.25097656e-01,  -2.23541260e-01],
                        [ -1.75903320e-01,  -1.74285889e-01],
                        [ -1.28234863e-01,  -1.26678467e-01],
                        [ -9.76562500e-02,  -9.65576172e-02],
                        [ -7.67211914e-02,  -7.62634277e-02],
                        [ -5.38635254e-02,  -5.39855957e-02],
                        [ -3.08837891e-02,  -3.14025879e-02],
                        [ -1.48010254e-02,  -1.55334473e-02],
                        [ -3.05175781e-03,  -4.08935547e-03],
                        [  1.31530762e-02,   1.16577148e-02],
                        [  3.76281738e-02,   3.57055664e-02],
                        [  6.88171387e-02,   6.67419434e-02],
                        [  1.02996826e-01,   1.01135254e-01],
                        [  1.32476807e-01,   1.31011963e-01],
                        [  1.44866943e-01,   1.43768311e-01],
                        [  1.29302979e-01,   1.28448486e-01],
                        [  8.20617676e-02,   8.15429688e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [ -9.08203125e-02,  -9.00573730e-02],
                        [ -1.81762695e-01,  -1.80389404e-01],
                        [ -2.34924316e-01,  -2.33154297e-01],
                        [ -2.33398438e-01,  -2.31597900e-01],
                        [ -1.90521240e-01,  -1.88751221e-01],
                        [ -1.38000488e-01,  -1.36169434e-01],
                        [ -9.94262695e-02,  -9.76257324e-02],
                        [ -7.54699707e-02,  -7.39135742e-02],
                        [ -5.39855957e-02,  -5.29785156e-02],
                        [ -3.02429199e-02,  -2.99987793e-02],
                        [ -1.13220215e-02,  -1.16882324e-02],
                        [ -3.69262695e-03,  -4.45556641e-03],
                        [ -3.84521484e-03,  -4.91333008e-03],
                        [ -1.70898438e-03,  -3.08227539e-03],
                        [  8.57543945e-03,   6.83593750e-03],
                        [  2.31628418e-02,   2.11791992e-02],
                        [  3.39660645e-02,   3.20739746e-02],
                        [  3.65600586e-02,   3.50646973e-02],
                        [  3.32946777e-02,   3.23181152e-02],
                        [  3.08837891e-02,   3.03039551e-02],
                        [  3.57360840e-02,   3.54614258e-02],
                        [  5.01098633e-02,   5.01403809e-02],
                        [  7.04956055e-02,   7.10754395e-02],
                        [  9.20410156e-02,   9.31396484e-02],
                        [  1.13067627e-01,   1.14501953e-01],
                        [  1.30676270e-01,   1.32171631e-01],
                        [  1.36566162e-01,   1.37878418e-01],
                        [  1.28204346e-01,   1.29333496e-01],
                        [  1.17034912e-01,   1.18103027e-01],
                        [  1.13311768e-01,   1.14318848e-01],
                        [  1.13128662e-01,   1.13861084e-01],
                        [  1.09619141e-01,   1.09863281e-01],
                        [  1.03942871e-01,   1.03698730e-01],
                        [  9.81140137e-02,   9.75952148e-02],
                        [  8.88366699e-02,   8.82263184e-02],
                        [  7.38220215e-02,   7.31811523e-02],
                        [  5.56030273e-02,   5.48706055e-02],
                        [  3.63769531e-02,   3.54309082e-02],
                        [  1.72729492e-02,   1.62048340e-02],
                        [  3.50952148e-03,   2.59399414e-03],
                        [  4.33349609e-03,   3.69262695e-03],
                        [  2.62756348e-02,   2.58483887e-02],
                        [  6.71997070e-02,   6.68640137e-02],
                        [  1.14349365e-01,   1.14044189e-01],
                        [  1.50146484e-01,   1.49932861e-01],
                        [  1.62994385e-01,   1.63024902e-01],
                        [  1.52923584e-01,   1.53289795e-01],
                        [  1.29364014e-01,   1.29943848e-01],
                        [  1.05468750e-01,   1.06079102e-01],
                        [  9.03015137e-02,   9.08813477e-02],
                        [  8.19702148e-02,   8.26721191e-02],
                        [  7.16247559e-02,   7.24792480e-02],
                        [  5.56030273e-02,   5.66101074e-02],
                        [  4.01306152e-02,   4.10461426e-02],
                        [  3.10668945e-02,   3.17077637e-02],
                        [  2.52990723e-02,   2.56347656e-02],
                        [  1.62658691e-02,   1.64184570e-02],
                        [  2.96020508e-03,   2.99072266e-03],
                        [ -9.76562500e-03,  -9.94873047e-03],
                        [ -1.71813965e-02,  -1.77307129e-02],
                        [ -1.74865723e-02,  -1.84020996e-02],
                        [ -1.14135742e-02,  -1.26037598e-02],
                        [ -2.59399414e-03,  -3.81469727e-03],
                        [  2.28881836e-03,   1.19018555e-03],
                        [ -2.25830078e-03,  -3.17382812e-03],
                        [ -1.42517090e-02,  -1.50756836e-02],
                        [ -2.65502930e-02,  -2.72216797e-02],
                        [ -3.50341797e-02,  -3.53393555e-02],
                        [ -3.97033691e-02,  -3.95202637e-02],
                        [ -4.07104492e-02,  -4.00085449e-02],
                        [ -3.99169922e-02,  -3.88793945e-02],
                        [ -4.33044434e-02,  -4.21447754e-02],
                        [ -5.35278320e-02,  -5.23376465e-02],
                        [ -6.30493164e-02,  -6.18286133e-02],
                        [ -6.34460449e-02,  -6.22253418e-02],
                        [ -5.80444336e-02,  -5.69763184e-02],
                        [ -5.64880371e-02,  -5.58471680e-02],
                        [ -5.99060059e-02,  -5.97839355e-02],
                        [ -6.08825684e-02,  -6.12792969e-02],
                        [ -5.65185547e-02,  -5.72509766e-02],
                        [ -5.10864258e-02,  -5.20019531e-02],
                        [ -4.77905273e-02,  -4.88586426e-02],
                        [ -4.61730957e-02,  -4.74243164e-02],
                        [ -4.60510254e-02,  -4.73632812e-02],
                        [ -4.67224121e-02,  -4.78515625e-02],
                        [ -4.50134277e-02,  -4.57153320e-02],
                        [ -3.93981934e-02,  -3.96118164e-02],
                        [ -3.22265625e-02,  -3.20129395e-02],
                        [ -2.48718262e-02,  -2.43835449e-02],
                        [ -1.59912109e-02,  -1.52587891e-02],
                        [ -4.66918945e-03,  -3.69262695e-03],
                        [  9.49096680e-03,   1.06506348e-02],
                        [  2.72216797e-02,   2.84118652e-02],
                        [  4.47692871e-02,   4.57458496e-02],
                        [  5.19104004e-02,   5.24597168e-02],
                        [  3.96728516e-02,   3.97949219e-02],
                        [  4.88281250e-03,   4.69970703e-03],
                        [ -5.31616211e-02,  -5.35888672e-02],
                        [ -1.28936768e-01,  -1.29638672e-01],
                        [ -2.01385498e-01,  -2.02331543e-01],
                        [ -2.40661621e-01,  -2.41760254e-01],
                        [ -2.31781006e-01,  -2.32879639e-01],
                        [ -1.87530518e-01,  -1.88323975e-01],
                        [ -1.35681152e-01,  -1.36077881e-01],
                        [ -9.69238281e-02,  -9.69543457e-02],
                        [ -7.51953125e-02,  -7.49206543e-02],
                        [ -6.39953613e-02,  -6.34765625e-02],
                        [ -5.62438965e-02,  -5.54504395e-02],
                        [ -4.84924316e-02,  -4.73937988e-02],
                        [ -3.91540527e-02,  -3.79638672e-02],
                        [ -2.55737305e-02,  -2.45056152e-02],
                        [ -3.66210938e-03,  -2.92968750e-03],
                        [  2.91748047e-02,   2.95104980e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  1.12792969e-01,   1.12487793e-01],
                        [  1.44134521e-01,   1.43493652e-01],
                        [  1.56707764e-01,   1.55731201e-01],
                        [  1.44226074e-01,   1.42974854e-01],
                        [  9.79919434e-02,   9.67102051e-02],
                        [  1.45568848e-02,   1.34277344e-02],
                        [ -9.09118652e-02,  -9.17053223e-02],
                        [ -1.85272217e-01,  -1.85729980e-01],
                        [ -2.36785889e-01,  -2.36907959e-01],
                        [ -2.33581543e-01,  -2.33367920e-01],
                        [ -1.87622070e-01,  -1.87011719e-01],
                        [ -1.26617432e-01,  -1.25610352e-01],
                        [ -7.91320801e-02,  -7.78503418e-02],
                        [ -5.72814941e-02,  -5.59692383e-02],
                        [ -5.09948730e-02,  -4.98352051e-02],
                        [ -4.34265137e-02,  -4.25109863e-02],
                        [ -2.92053223e-02,  -2.85339355e-02],
                        [ -1.39160156e-02,  -1.35498047e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  5.24902344e-03,   4.85229492e-03],
                        [  1.33361816e-02,   1.25427246e-02],
                        [  2.34985352e-02,   2.24304199e-02],
                        [  3.33862305e-02,   3.22570801e-02],
                        [  3.68347168e-02,   3.57666016e-02],
                        [  3.07922363e-02,   2.98767090e-02],
                        [  2.18200684e-02,   2.10571289e-02],
                        [  1.99890137e-02,   1.94396973e-02],
                        [  2.90527344e-02,   2.88391113e-02],
                        [  4.84924316e-02,   4.86145020e-02],
                        [  7.73315430e-02,   7.78198242e-02],
                        [  1.08764648e-01,   1.09466553e-01],
                        [  1.28753662e-01,   1.29516602e-01],
                        [  1.29547119e-01,   1.30279541e-01],
                        [  1.19628906e-01,   1.20391846e-01],
                        [  1.14379883e-01,   1.15081787e-01],
                        [  1.18865967e-01,   1.19445801e-01],
                        [  1.25274658e-01,   1.25610352e-01],
                        [  1.24877930e-01,   1.24938965e-01],
                        [  1.16821289e-01,   1.16668701e-01],
                        [  1.04919434e-01,   1.04644775e-01],
                        [  9.17663574e-02,   9.14611816e-02],
                        [  7.68432617e-02,   7.64770508e-02],
                        [  5.75561523e-02,   5.71289062e-02],
                        [  3.28063965e-02,   3.23791504e-02],
                        [  6.80541992e-03,   6.43920898e-03],
                        [ -1.15051270e-02,  -1.17797852e-02],
                        [ -1.40075684e-02,  -1.41296387e-02],
                        [  2.92968750e-03,   2.86865234e-03],
                        [  3.94897461e-02,   3.94287109e-02],
                        [  9.12170410e-02,   9.11560059e-02],
                        [  1.43188477e-01,   1.43188477e-01],
                        [  1.73492432e-01,   1.73553467e-01],
                        [  1.70288086e-01,   1.70379639e-01],
                        [  1.42913818e-01,   1.42974854e-01],
                        [  1.11328125e-01,   1.11358643e-01],
                        [  8.77990723e-02,   8.78295898e-02],
                        [  7.27539062e-02,   7.28759766e-02],
                        [  6.27136230e-02,   6.28967285e-02],
                        [  5.43823242e-02,   5.46569824e-02],
                        [  4.47387695e-02,   4.49829102e-02],
                        [  3.36303711e-02,   3.38745117e-02],
                        [  2.46582031e-02,   2.49023438e-02],
                        [  1.89819336e-02,   1.92260742e-02],
                        [  1.30615234e-02,   1.32751465e-02],
                        [  5.09643555e-03,   5.21850586e-03],
                        [ -2.01416016e-03,  -2.04467773e-03],
                        [ -5.58471680e-03,  -5.76782227e-03],
                        [ -6.43920898e-03,  -6.71386719e-03],
                        [ -6.89697266e-03,  -7.23266602e-03],
                        [ -9.33837891e-03,  -9.73510742e-03],
                        [ -1.55944824e-02,  -1.60522461e-02],
                        [ -2.46582031e-02,  -2.51159668e-02],
                        [ -3.17993164e-02,  -3.22265625e-02],
                        [ -3.31115723e-02,  -3.34167480e-02],
                        [ -2.89611816e-02,  -2.90832520e-02],
                        [ -2.21862793e-02,  -2.21252441e-02],
                        [ -1.69372559e-02,  -1.67846680e-02],
                        [ -1.86157227e-02,  -1.83410645e-02],
                        [ -2.87780762e-02,  -2.83813477e-02],
                        [ -4.29382324e-02,  -4.24499512e-02],
                        [ -5.64270020e-02,  -5.58776855e-02],
                        [ -6.82067871e-02,  -6.76879883e-02],
                        [ -7.60803223e-02,  -7.56835938e-02],
                        [ -7.54089355e-02,  -7.51342773e-02],
                        [ -6.62536621e-02,  -6.61621094e-02],
                        [ -5.57556152e-02,  -5.57861328e-02],
                        [ -4.87365723e-02,  -4.88891602e-02],
                        [ -4.19921875e-02,  -4.22973633e-02],
                        [ -3.17687988e-02,  -3.21960449e-02],
                        [ -2.20031738e-02,  -2.24914551e-02],
                        [ -1.91345215e-02,  -1.95922852e-02],
                        [ -2.25219727e-02,  -2.29187012e-02],
                        [ -2.67639160e-02,  -2.70690918e-02],
                        [ -2.99072266e-02,  -3.01208496e-02],
                        [ -3.21960449e-02,  -3.23181152e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -1.39465332e-02,  -1.37939453e-02],
                        [  1.07116699e-02,   1.10168457e-02],
                        [  3.66210938e-02,   3.69567871e-02],
                        [  5.68542480e-02,   5.72204590e-02],
                        [  6.49719238e-02,   6.52770996e-02],
                        [  5.13305664e-02,   5.15747070e-02],
                        [  1.04064941e-02,   1.06201172e-02],
                        [ -5.19714355e-02,  -5.18188477e-02],
                        [ -1.22467041e-01,  -1.22406006e-01],
                        [ -1.85638428e-01,  -1.85699463e-01],
                        [ -2.23999023e-01,  -2.24151611e-01],
                        [ -2.22534180e-01,  -2.22717285e-01],
                        [ -1.82250977e-01,  -1.82464600e-01],
                        [ -1.25885010e-01,  -1.26068115e-01],
                        [ -8.10546875e-02,  -8.12377930e-02],
                        [ -5.87768555e-02,  -5.89294434e-02],
                        [ -5.17272949e-02,  -5.18493652e-02],
                        [ -4.92553711e-02,  -4.93164062e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.48303223e-02,  -4.47998047e-02],
                        [ -3.76892090e-02,  -3.76281738e-02],
                        [ -1.77917480e-02,  -1.77612305e-02],
                        [  1.77917480e-02,   1.78527832e-02],
                        [  6.19812012e-02,   6.20727539e-02],
                        [  1.02996826e-01,   1.03088379e-01],
                        [  1.31896973e-01,   1.31958008e-01],
                        [  1.43280029e-01,   1.43310547e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  9.62524414e-02,   9.62219238e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [ -5.27038574e-02,  -5.26733398e-02],
                        [ -1.42547607e-01,  -1.42547607e-01],
                        [ -2.07916260e-01,  -2.07946777e-01],
                        [ -2.24487305e-01,  -2.24487305e-01],
                        [ -1.91406250e-01,  -1.91406250e-01],
                        [ -1.33361816e-01,  -1.33331299e-01],
                        [ -8.25805664e-02,  -8.25500488e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -4.55017090e-02,  -4.55322266e-02],
                        [ -3.60412598e-02,  -3.60717773e-02],
                        [ -2.28576660e-02,  -2.28881836e-02],
                        [ -1.15966797e-02,  -1.16271973e-02],
                        [ -4.60815430e-03,  -4.63867188e-03],
                        [  1.61743164e-03,   1.55639648e-03],
                        [  9.79614258e-03,   9.73510742e-03],
                        [  1.99890137e-02,   1.99279785e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.66210938e-02,   3.66516113e-02],
                        [  3.11584473e-02,   3.11889648e-02],
                        [  2.49023438e-02,   2.49328613e-02],
                        [  2.02331543e-02,   2.02941895e-02],
                        [  2.24914551e-02,   2.25219727e-02],
                        [  4.12902832e-02,   4.13513184e-02],
                        [  7.83386230e-02,   7.83996582e-02],
                        [  1.18988037e-01,   1.19018555e-01],
                        [  1.43646240e-01,   1.43646240e-01],
                        [  1.45812988e-01,   1.45812988e-01],
                        [  1.36718750e-01,   1.36718750e-01],
                        [  1.31744385e-01,   1.31713867e-01],
                        [  1.31988525e-01,   1.31958008e-01],
                        [  1.26037598e-01,   1.26007080e-01],
                        [  1.10168457e-01,   1.10107422e-01],
                        [  9.46655273e-02,   9.46350098e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  5.49011230e-02,   5.48706055e-02],
                        [  3.14331055e-02,   3.14025879e-02],
                        [  1.26953125e-02,   1.27258301e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  5.84411621e-02,   5.84411621e-02],
                        [  9.77478027e-02,   9.77783203e-02],
                        [  1.34460449e-01,   1.34460449e-01],
                        [  1.55548096e-01,   1.55548096e-01],
                        [  1.52374268e-01,   1.52374268e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [  3.04565430e-02,   3.04260254e-02],
                        [  2.44140625e-02,   2.43835449e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  3.59191895e-02,   3.59497070e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  1.69982910e-02,   1.69677734e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -2.32543945e-02,  -2.32238770e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.36206055e-02,  -2.35900879e-02],
                        [ -1.90124512e-02,  -1.90429688e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.42211914e-02,  -1.41906738e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -6.83288574e-02,  -6.83288574e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.34765625e-02,  -6.35070801e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -5.57250977e-02,  -5.57556152e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -3.28063965e-02,  -3.27758789e-02],
                        [ -2.29187012e-02,  -2.29492188e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.07617188e-02,   3.07922363e-02],
                        [  3.80554199e-02,   3.80859375e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -1.04217529e-01,  -1.04248047e-01],
                        [ -1.69281006e-01,  -1.69281006e-01],
                        [ -2.13562012e-01,  -2.13531494e-01],
                        [ -2.20153809e-01,  -2.20153809e-01],
                        [ -1.87866211e-01,  -1.87866211e-01],
                        [ -1.35223389e-01,  -1.35223389e-01],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -6.93359375e-02,  -6.93664551e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.80847168e-02,  -6.80541992e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -5.63659668e-02,  -5.63964844e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  8.41369629e-02,   8.41674805e-02],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  1.34155273e-01,   1.34124756e-01],
                        [  1.31835938e-01,   1.31835938e-01],
                        [  1.02844238e-01,   1.02874756e-01],
                        [  4.74853516e-02,   4.74548340e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -1.18133545e-01,  -1.18103027e-01],
                        [ -1.92077637e-01,  -1.92108154e-01],
                        [ -2.22930908e-01,  -2.22961426e-01],
                        [ -2.00347900e-01,  -2.00317383e-01],
                        [ -1.44500732e-01,  -1.44470215e-01],
                        [ -9.03015137e-02,  -9.03015137e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  4.28771973e-02,   4.28466797e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  2.88391113e-02,   2.88696289e-02],
                        [  1.41906738e-02,   1.41601562e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  3.28369141e-02,   3.28369141e-02],
                        [  6.51245117e-02,   6.50939941e-02],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  1.42883301e-01,   1.42913818e-01],
                        [  1.60766602e-01,   1.60766602e-01],
                        [  1.56585693e-01,   1.56585693e-01],
                        [  1.41632080e-01,   1.41662598e-01],
                        [  1.27838135e-01,   1.27868652e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.09222412e-01,   1.09252930e-01],
                        [  1.00952148e-01,   1.00982666e-01],
                        [  9.17358398e-02,   9.17053223e-02],
                        [  7.99865723e-02,   7.99865723e-02],
                        [  6.65588379e-02,   6.65893555e-02],
                        [  5.34362793e-02,   5.34362793e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  4.05883789e-03,   4.02832031e-03],
                        [  1.72424316e-02,   1.72729492e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.41113281e-01,   1.41113281e-01],
                        [  1.19659424e-01,   1.19659424e-01],
                        [  8.90808105e-02,   8.90808105e-02],
                        [  6.38122559e-02,   6.38427734e-02],
                        [  5.17578125e-02,   5.17272949e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  3.92761230e-02,   3.93066406e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -8.08715820e-03,  -8.05664062e-03],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.32238770e-02,  -2.31933594e-02],
                        [ -2.46582031e-02,  -2.46887207e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -6.03027344e-02,  -6.03332520e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -6.05468750e-02,  -6.05773926e-02],
                        [ -5.02929688e-02,  -5.02624512e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.35998535e-02,  -3.35693359e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  5.68847656e-02,   5.69152832e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -1.15295410e-01,  -1.15295410e-01],
                        [ -1.82220459e-01,  -1.82220459e-01],
                        [ -2.23236084e-01,  -2.23236084e-01],
                        [ -2.22900391e-01,  -2.22869873e-01],
                        [ -1.86248779e-01,  -1.86248779e-01],
                        [ -1.36779785e-01,  -1.36810303e-01],
                        [ -9.94873047e-02,  -9.94567871e-02],
                        [ -8.34045410e-02,  -8.33740234e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -7.45544434e-02,  -7.45849609e-02],
                        [ -6.18591309e-02,  -6.18286133e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -2.47497559e-02,  -2.47802734e-02],
                        [ -5.46264648e-03,  -5.43212891e-03],
                        [  1.67236328e-02,   1.67541504e-02],
                        [  4.51660156e-02,   4.51354980e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  1.13677979e-01,   1.13708496e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  1.40441895e-01,   1.40411377e-01],
                        [  1.15356445e-01,   1.15386963e-01],
                        [  6.11267090e-02,   6.11267090e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.83410645e-01,  -1.83380127e-01],
                        [ -2.25616455e-01,  -2.25616455e-01],
                        [ -2.18292236e-01,  -2.18292236e-01],
                        [ -1.73553467e-01,  -1.73553467e-01],
                        [ -1.19506836e-01,  -1.19506836e-01],
                        [ -7.76977539e-02,  -7.76977539e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [ -1.40380859e-03,  -1.43432617e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  9.46044922e-03,   9.42993164e-03],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.45202637e-01,   1.45202637e-01],
                        [  1.54632568e-01,   1.54632568e-01],
                        [  1.52404785e-01,   1.52404785e-01],
                        [  1.41357422e-01,   1.41357422e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.15386963e-01,   1.15356445e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  9.32312012e-02,   9.32312012e-02],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  1.19934082e-02,   1.19628906e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.39465332e-01,   1.39465332e-01],
                        [  1.45233154e-01,   1.45233154e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.36499023e-02,   5.36193848e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.04980469e-02,  -1.05285645e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.25219727e-02,  -2.25524902e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.26538086e-02,  -3.26232910e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -5.52368164e-03,  -5.55419922e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -5.61218262e-02,  -5.61218262e-02],
                        [ -1.25152588e-01,  -1.25122070e-01],
                        [ -1.90887451e-01,  -1.90887451e-01],
                        [ -2.31964111e-01,  -2.31964111e-01],
                        [ -2.33551025e-01,  -2.33551025e-01],
                        [ -1.98364258e-01,  -1.98364258e-01],
                        [ -1.47369385e-01,  -1.47369385e-01],
                        [ -1.05804443e-01,  -1.05804443e-01],
                        [ -8.39233398e-02,  -8.39233398e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -2.83813477e-02,  -2.84118652e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.15966797e-03,  -1.12915039e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  8.83789062e-02,   8.84094238e-02],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.29425049e-01,   1.29394531e-01],
                        [  1.34979248e-01,   1.35009766e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  7.19909668e-02,   7.19909668e-02],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -1.06872559e-01,  -1.06872559e-01],
                        [ -1.90490723e-01,  -1.90490723e-01],
                        [ -2.30255127e-01,  -2.30255127e-01],
                        [ -2.13531494e-01,  -2.13531494e-01],
                        [ -1.57531738e-01,  -1.57531738e-01],
                        [ -9.93041992e-02,  -9.93041992e-02],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  1.34613037e-01,   1.34613037e-01],
                        [  1.68548584e-01,   1.68548584e-01],
                        [  1.81701660e-01,   1.81701660e-01],
                        [  1.76391602e-01,   1.76391602e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.08032227e-01,   1.08032227e-01],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  4.38232422e-02,   4.38537598e-02],
                        [  2.63671875e-02,   2.63366699e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  8.66394043e-02,   8.66088867e-02],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.60430908e-01,   1.60461426e-01],
                        [  1.61621094e-01,   1.61621094e-01],
                        [  1.36901855e-01,   1.36871338e-01],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  7.88879395e-02,   7.88879395e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  2.69775391e-02,   2.69470215e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -4.37622070e-02,  -4.37927246e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -7.09838867e-02,  -7.09838867e-02],
                        [ -7.30285645e-02,  -7.30285645e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -4.29687500e-02,  -4.29992676e-02],
                        [ -1.20941162e-01,  -1.20941162e-01],
                        [ -1.96746826e-01,  -1.96746826e-01],
                        [ -2.45361328e-01,  -2.45391846e-01],
                        [ -2.49206543e-01,  -2.49206543e-01],
                        [ -2.13562012e-01,  -2.13531494e-01],
                        [ -1.62506104e-01,  -1.62536621e-01],
                        [ -1.18652344e-01,  -1.18652344e-01],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -7.10754395e-02,  -7.10449219e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.31561279e-01,   1.31561279e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  7.88574219e-02,   7.88574219e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -1.02966309e-01,  -1.02996826e-01],
                        [ -1.92047119e-01,  -1.92047119e-01],
                        [ -2.35748291e-01,  -2.35717773e-01],
                        [ -2.24761963e-01,  -2.24761963e-01],
                        [ -1.73370361e-01,  -1.73400879e-01],
                        [ -1.09619141e-01,  -1.09619141e-01],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [  6.65283203e-03,   6.68334961e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  7.11059570e-03,   7.08007812e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  2.77709961e-03,   2.74658203e-03],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.21862793e-02,   2.21557617e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  7.20214844e-03,   7.17163086e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  1.10931396e-01,   1.10931396e-01],
                        [  1.46179199e-01,   1.46179199e-01],
                        [  1.67144775e-01,   1.67144775e-01],
                        [  1.68273926e-01,   1.68273926e-01],
                        [  1.55059814e-01,   1.55059814e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  1.16516113e-01,   1.16516113e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.11572266e-01,   1.11602783e-01],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  8.07800293e-02,   8.07495117e-02],
                        [  5.82885742e-02,   5.83190918e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  1.46148682e-01,   1.46148682e-01],
                        [  1.74621582e-01,   1.74621582e-01],
                        [  1.70928955e-01,   1.70928955e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.60205078e-02,  -4.60510254e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -3.10668945e-02,  -3.10363770e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -6.67724609e-02,  -6.68029785e-02],
                        [ -7.14416504e-02,  -7.14416504e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.77709961e-03,  -2.74658203e-03],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -1.19201660e-01,  -1.19201660e-01],
                        [ -1.83685303e-01,  -1.83685303e-01],
                        [ -2.18627930e-01,  -2.18627930e-01],
                        [ -2.12127686e-01,  -2.12127686e-01],
                        [ -1.75140381e-01,  -1.75140381e-01],
                        [ -1.33697510e-01,  -1.33697510e-01],
                        [ -1.06811523e-01,  -1.06811523e-01],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -9.08508301e-02,  -9.08508301e-02],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -7.76672363e-02,  -7.76672363e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  4.87365723e-02,   4.87060547e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.44653320e-01,   1.44653320e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [ -9.09118652e-02,  -9.09118652e-02],
                        [ -1.73217773e-01,  -1.73217773e-01],
                        [ -2.15850830e-01,  -2.15850830e-01],
                        [ -2.10876465e-01,  -2.10876465e-01],
                        [ -1.68609619e-01,  -1.68609619e-01],
                        [ -1.12701416e-01,  -1.12701416e-01],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -4.15344238e-02,  -4.15039062e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -1.13830566e-02,  -1.13525391e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.61834717e-01,   1.61834717e-01],
                        [  1.53533936e-01,   1.53533936e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  1.24755859e-01,   1.24755859e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.23199463e-01,   1.23199463e-01],
                        [  1.17431641e-01,   1.17431641e-01],
                        [  1.01043701e-01,   1.01043701e-01],
                        [  7.44628906e-02,   7.44628906e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  1.02233887e-01,   1.02203369e-01],
                        [  1.39373779e-01,   1.39343262e-01],
                        [  1.47155762e-01,   1.47155762e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  6.04858398e-02,   6.04553223e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  3.27758789e-02,   3.28063965e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -5.85327148e-02,  -5.85021973e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -4.62646484e-02,  -4.62341309e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  5.21545410e-02,   5.21545410e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -1.33026123e-01,  -1.33026123e-01],
                        [ -2.07519531e-01,  -2.07489014e-01],
                        [ -2.48809814e-01,  -2.48809814e-01],
                        [ -2.44750977e-01,  -2.44750977e-01],
                        [ -2.06268311e-01,  -2.06268311e-01],
                        [ -1.57684326e-01,  -1.57684326e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -9.97314453e-02,  -9.97619629e-02],
                        [ -8.73107910e-02,  -8.73107910e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.03454590e-02,  -1.03149414e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  1.65100098e-02,   1.64794922e-02],
                        [  3.96728516e-02,   3.97033691e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  9.92126465e-02,   9.92126465e-02],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.32934570e-01,   1.32965088e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -1.53076172e-01,  -1.53076172e-01],
                        [ -2.10906982e-01,  -2.10906982e-01],
                        [ -2.17071533e-01,  -2.17041016e-01],
                        [ -1.78955078e-01,  -1.78955078e-01],
                        [ -1.21734619e-01,  -1.21765137e-01],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.62658691e-01,   1.62658691e-01],
                        [  1.80664062e-01,   1.80664062e-01],
                        [  1.81701660e-01,   1.81701660e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.51458740e-01,   1.51458740e-01],
                        [  1.38153076e-01,   1.38153076e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  8.45947266e-02,   8.45947266e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  1.12579346e-01,   1.12579346e-01],
                        [  1.42517090e-01,   1.42517090e-01],
                        [  1.46118164e-01,   1.46118164e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -6.73522949e-02,  -6.73522949e-02],
                        [ -6.90307617e-02,  -6.90307617e-02],
                        [ -6.40869141e-02,  -6.40869141e-02],
                        [ -5.48706055e-02,  -5.48400879e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -4.07104492e-02,  -4.07409668e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  5.06896973e-02,   5.06896973e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -2.16705322e-01,  -2.16705322e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -2.19024658e-01,  -2.19024658e-01],
                        [ -1.72973633e-01,  -1.72973633e-01],
                        [ -1.28143311e-01,  -1.28143311e-01],
                        [ -1.01287842e-01,  -1.01287842e-01],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -7.90100098e-02,  -7.90100098e-02],
                        [ -6.41479492e-02,  -6.41479492e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.39129639e-01,   1.39129639e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -1.99462891e-01,  -1.99462891e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -2.17437744e-01,  -2.17437744e-01],
                        [ -1.58172607e-01,  -1.58172607e-01],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.50360107e-01,   1.50360107e-01],
                        [  1.62506104e-01,   1.62506104e-01],
                        [  1.61621094e-01,   1.61621094e-01],
                        [  1.57012939e-01,   1.57012939e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  6.37817383e-03,   6.40869141e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.85632324e-02,  -5.85632324e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  5.75256348e-02,   5.75561523e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -7.86132812e-02,  -7.86132812e-02],
                        [ -1.49261475e-01,  -1.49261475e-01],
                        [ -2.04467773e-01,  -2.04467773e-01],
                        [ -2.27081299e-01,  -2.27081299e-01],
                        [ -2.12158203e-01,  -2.12158203e-01],
                        [ -1.74926758e-01,  -1.74926758e-01],
                        [ -1.40136719e-01,  -1.40136719e-01],
                        [ -1.20635986e-01,  -1.20635986e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -7.36694336e-02,  -7.36694336e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  1.42456055e-01,   1.42456055e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -1.77337646e-01,  -1.77337646e-01],
                        [ -2.28729248e-01,  -2.28729248e-01],
                        [ -2.17376709e-01,  -2.17376709e-01],
                        [ -1.63635254e-01,  -1.63635254e-01],
                        [ -1.06506348e-01,  -1.06506348e-01],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  3.96118164e-02,   3.96423340e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  6.99462891e-02,   6.99462891e-02],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.54113770e-01,   1.54113770e-01],
                        [  1.72637939e-01,   1.72637939e-01],
                        [  1.69891357e-01,   1.69891357e-01],
                        [  1.55822754e-01,   1.55822754e-01],
                        [  1.43646240e-01,   1.43646240e-01],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.38305664e-01,   1.38305664e-01],
                        [  1.32415771e-01,   1.32415771e-01],
                        [  1.17889404e-01,   1.17889404e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.30737305e-01,   1.30737305e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.14624023e-01,   1.14624023e-01],
                        [  9.11254883e-02,   9.11254883e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -1.87347412e-01,  -1.87347412e-01],
                        [ -2.32727051e-01,  -2.32727051e-01],
                        [ -2.33123779e-01,  -2.33123779e-01],
                        [ -1.98669434e-01,  -1.98669434e-01],
                        [ -1.55303955e-01,  -1.55303955e-01],
                        [ -1.24359131e-01,  -1.24359131e-01],
                        [ -1.08337402e-01,  -1.08337402e-01],
                        [ -9.68017578e-02,  -9.68017578e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  8.89587402e-02,   8.89587402e-02],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  1.34124756e-01,   1.34124756e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.30859375e-01,   1.30859375e-01],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [ -9.24987793e-02,  -9.24987793e-02],
                        [ -1.84509277e-01,  -1.84509277e-01],
                        [ -2.29888916e-01,  -2.29888916e-01],
                        [ -2.17498779e-01,  -2.17498779e-01],
                        [ -1.64855957e-01,  -1.64855957e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  1.34948730e-01,   1.34948730e-01],
                        [  1.73675537e-01,   1.73675537e-01],
                        [  1.91040039e-01,   1.91040039e-01],
                        [  1.86218262e-01,   1.86218262e-01],
                        [  1.68670654e-01,   1.68670654e-01],
                        [  1.50939941e-01,   1.50939941e-01],
                        [  1.38427734e-01,   1.38427734e-01],
                        [  1.26953125e-01,   1.26953125e-01],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  9.03015137e-02,   9.03015137e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  5.11474609e-02,   5.11474609e-02],
                        [  9.27429199e-02,   9.27429199e-02],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.13739014e-01,   1.13739014e-01],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -9.54589844e-02,  -9.54589844e-02],
                        [ -1.76818848e-01,  -1.76818848e-01],
                        [ -2.35443115e-01,  -2.35443115e-01],
                        [ -2.50885010e-01,  -2.50885010e-01],
                        [ -2.24090576e-01,  -2.24090576e-01],
                        [ -1.75842285e-01,  -1.75842285e-01],
                        [ -1.32385254e-01,  -1.32385254e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  6.64672852e-02,   6.64672852e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.98822021e-01,  -1.98822021e-01],
                        [ -2.28576660e-01,  -2.28576660e-01],
                        [ -1.99829102e-01,  -1.99829102e-01],
                        [ -1.39068604e-01,  -1.39068604e-01],
                        [ -7.96203613e-02,  -7.96203613e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.78558350e-01,   1.78558350e-01],
                        [  1.90826416e-01,   1.90826416e-01],
                        [  1.79626465e-01,   1.79626465e-01],
                        [  1.56372070e-01,   1.56372070e-01],
                        [  1.35711670e-01,   1.35711670e-01],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.23474121e-01,   1.23474121e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  1.12304688e-02,   1.12304688e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -1.30798340e-01,  -1.30798340e-01],
                        [ -2.04986572e-01,  -2.04986572e-01],
                        [ -2.49359131e-01,  -2.49359131e-01],
                        [ -2.47070312e-01,  -2.47070312e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.55364990e-01,  -1.55364990e-01],
                        [ -1.21459961e-01,  -1.21459961e-01],
                        [ -1.05285645e-01,  -1.05285645e-01],
                        [ -9.17968750e-02,  -9.17968750e-02],
                        [ -7.44018555e-02,  -7.44018555e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  3.82080078e-02,   3.82080078e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -1.56829834e-01,  -1.56829834e-01],
                        [ -2.20184326e-01,  -2.20184326e-01],
                        [ -2.28363037e-01,  -2.28363037e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -1.26373291e-01,  -1.26373291e-01],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  1.31225586e-01,   1.31225586e-01],
                        [  1.67846680e-01,   1.67846680e-01],
                        [  1.89849854e-01,   1.89849854e-01],
                        [  1.90338135e-01,   1.90338135e-01],
                        [  1.73614502e-01,   1.73614502e-01],
                        [  1.52709961e-01,   1.52709961e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.21002197e-01,   1.21002197e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.28906250e-01,   1.28906250e-01],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  8.72802734e-02,   8.72802734e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  6.90917969e-02,   6.90917969e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -7.80944824e-02,  -7.80944824e-02],
                        [ -1.63970947e-01,  -1.63970947e-01],
                        [ -2.31445312e-01,  -2.31445312e-01],
                        [ -2.54943848e-01,  -2.54943848e-01],
                        [ -2.31262207e-01,  -2.31262207e-01],
                        [ -1.82312012e-01,  -1.82312012e-01],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -1.01226807e-01,  -1.01226807e-01],
                        [ -8.69445801e-02,  -8.69445801e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  1.23077393e-01,   1.23077393e-01],
                        [  1.35711670e-01,   1.35711670e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  4.40979004e-02,   4.40979004e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -1.33422852e-01,  -1.33422852e-01],
                        [ -2.01538086e-01,  -2.01538086e-01],
                        [ -2.17102051e-01,  -2.17102051e-01],
                        [ -1.81213379e-01,  -1.81213379e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  1.27929688e-01,   1.27929688e-01],
                        [  1.72882080e-01,   1.72882080e-01],
                        [  1.97540283e-01,   1.97540283e-01],
                        [  1.94885254e-01,   1.94885254e-01],
                        [  1.74804688e-01,   1.74804688e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.34552002e-01,   1.34552002e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  1.03302002e-01,   1.03302002e-01],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -1.33178711e-01,  -1.33178711e-01],
                        [ -2.08038330e-01,  -2.08038330e-01],
                        [ -2.54425049e-01,  -2.54425049e-01],
                        [ -2.56500244e-01,  -2.56500244e-01],
                        [ -2.18200684e-01,  -2.18200684e-01],
                        [ -1.66931152e-01,  -1.66931152e-01],
                        [ -1.32507324e-01,  -1.32507324e-01],
                        [ -1.20849609e-01,  -1.20849609e-01],
                        [ -1.15081787e-01,  -1.15081787e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -7.90100098e-02,  -7.90100098e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -1.31683350e-01,  -1.31683350e-01],
                        [ -1.90979004e-01,  -1.90979004e-01],
                        [ -2.00775146e-01,  -2.00775146e-01],
                        [ -1.64947510e-01,  -1.64947510e-01],
                        [ -1.12670898e-01,  -1.12670898e-01],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  1.41174316e-01,   1.41174316e-01],
                        [  1.78405762e-01,   1.78405762e-01],
                        [  1.92749023e-01,   1.92749023e-01],
                        [  1.81793213e-01,   1.81793213e-01],
                        [  1.59027100e-01,   1.59027100e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.17248535e-01,   1.17248535e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  1.01806641e-01,   1.01806641e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  8.64868164e-02,   8.64868164e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -1.16210938e-01,  -1.16210938e-01],
                        [ -1.89300537e-01,  -1.89300537e-01],
                        [ -2.43255615e-01,  -2.43255615e-01],
                        [ -2.56561279e-01,  -2.56561279e-01],
                        [ -2.24884033e-01,  -2.24884033e-01],
                        [ -1.68914795e-01,  -1.68914795e-01],
                        [ -1.19384766e-01,  -1.19384766e-01],
                        [ -9.34143066e-02,  -9.34143066e-02],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -8.12377930e-02,  -8.12377930e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -6.87866211e-02,  -6.87866211e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  1.35803223e-01,   1.35803223e-01],
                        [  1.45965576e-01,   1.45965576e-01],
                        [  1.37390137e-01,   1.37390137e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  3.96118164e-02,   3.96118164e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -1.37847900e-01,  -1.37847900e-01],
                        [ -2.01965332e-01,  -2.01965332e-01],
                        [ -2.16003418e-01,  -2.16003418e-01],
                        [ -1.80694580e-01,  -1.80694580e-01],
                        [ -1.21826172e-01,  -1.21826172e-01],
                        [ -7.03430176e-02,  -7.03430176e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.72943115e-01,   1.72943115e-01],
                        [  1.86462402e-01,   1.86462402e-01],
                        [  1.79077148e-01,   1.79077148e-01],
                        [  1.60949707e-01,   1.60949707e-01],
                        [  1.44592285e-01,   1.44592285e-01],
                        [  1.36108398e-01,   1.36108398e-01],
                        [  1.32141113e-01,   1.32141113e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  8.37402344e-02,   8.37402344e-02],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.27166748e-01,   1.27166748e-01],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -7.54089355e-02,  -7.54089355e-02],
                        [ -1.57165527e-01,  -1.57165527e-01],
                        [ -2.27905273e-01,  -2.27905273e-01],
                        [ -2.64556885e-01,  -2.64556885e-01],
                        [ -2.56469727e-01,  -2.56469727e-01],
                        [ -2.11914062e-01,  -2.11914062e-01],
                        [ -1.55639648e-01,  -1.55639648e-01],
                        [ -1.15081787e-01,  -1.15081787e-01],
                        [ -1.00067139e-01,  -1.00067139e-01],
                        [ -9.70764160e-02,  -9.70764160e-02],
                        [ -8.79821777e-02,  -8.79821777e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -1.40991211e-01,  -1.40991211e-01],
                        [ -2.04284668e-01,  -2.04284668e-01],
                        [ -2.13439941e-01,  -2.13439941e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.36401367e-02,   4.36401367e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  8.23364258e-02,   8.23364258e-02],
                        [  1.28234863e-01,   1.28234863e-01],
                        [  1.66412354e-01,   1.66412354e-01],
                        [  1.83441162e-01,   1.83441162e-01],
                        [  1.78680420e-01,   1.78680420e-01],
                        [  1.64123535e-01,   1.64123535e-01],
                        [  1.50848389e-01,   1.50848389e-01],
                        [  1.41143799e-01,   1.41143799e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.18316650e-01,   1.18316650e-01],
                        [  1.03118896e-01,   1.03118896e-01],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  1.06536865e-01,   1.06536865e-01],
                        [  1.28326416e-01,   1.28326416e-01],
                        [  1.25305176e-01,   1.25305176e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -1.39038086e-01,  -1.39038086e-01],
                        [ -2.16766357e-01,  -2.16766357e-01],
                        [ -2.55950928e-01,  -2.55950928e-01],
                        [ -2.48596191e-01,  -2.48596191e-01],
                        [ -2.08404541e-01,  -2.08404541e-01],
                        [ -1.59362793e-01,  -1.59362793e-01],
                        [ -1.22528076e-01,  -1.22528076e-01],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -6.96411133e-02,  -6.96411133e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  7.09228516e-02,   7.09228516e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -9.32006836e-02,  -9.32006836e-02],
                        [ -1.68823242e-01,  -1.68823242e-01],
                        [ -2.06176758e-01,  -2.06176758e-01],
                        [ -1.95922852e-01,  -1.95922852e-01],
                        [ -1.50726318e-01,  -1.50726318e-01],
                        [ -9.55200195e-02,  -9.55200195e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.69006348e-01,   1.69006348e-01],
                        [  1.84326172e-01,   1.84326172e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  1.70349121e-01,   1.70349121e-01],
                        [  1.56890869e-01,   1.56890869e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  7.68737793e-02,   7.68737793e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -1.18072510e-01,  -1.18072510e-01],
                        [ -2.02819824e-01,  -2.02819824e-01],
                        [ -2.64770508e-01,  -2.64770508e-01],
                        [ -2.79205322e-01,  -2.79205322e-01],
                        [ -2.42492676e-01,  -2.42492676e-01],
                        [ -1.80419922e-01,  -1.80419922e-01],
                        [ -1.28479004e-01,  -1.28479004e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -8.43811035e-02,  -8.43811035e-02],
                        [ -7.52868652e-02,  -7.52868652e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  8.57238770e-02,   8.57238770e-02],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -1.62841797e-01,  -1.62841797e-01],
                        [ -2.01965332e-01,  -2.01965332e-01],
                        [ -1.86676025e-01,  -1.86676025e-01],
                        [ -1.33331299e-01,  -1.33331299e-01],
                        [ -7.80029297e-02,  -7.80029297e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  1.40289307e-01,   1.40289307e-01],
                        [  1.66564941e-01,   1.66564941e-01],
                        [  1.72790527e-01,   1.72790527e-01],
                        [  1.63940430e-01,   1.63940430e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.38854980e-01,   1.38854980e-01],
                        [  1.35375977e-01,   1.35375977e-01],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  1.15692139e-01,   1.15692139e-01],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  6.73522949e-02,   6.73522949e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -1.57623291e-01,  -1.57623291e-01],
                        [ -2.34619141e-01,  -2.34619141e-01],
                        [ -2.74932861e-01,  -2.74932861e-01],
                        [ -2.68768311e-01,  -2.68768311e-01],
                        [ -2.26165771e-01,  -2.26165771e-01],
                        [ -1.71508789e-01,  -1.71508789e-01],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -1.09741211e-01,  -1.09741211e-01],
                        [ -9.79309082e-02,  -9.79309082e-02],
                        [ -8.07495117e-02,  -8.07495117e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.10229492e-01,   1.10229492e-01],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -1.49139404e-01,  -1.49139404e-01],
                        [ -1.98120117e-01,  -1.98120117e-01],
                        [ -1.95465088e-01,  -1.95465088e-01],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.57470703e-01,   1.57470703e-01],
                        [  1.80267334e-01,   1.80267334e-01],
                        [  1.81488037e-01,   1.81488037e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  1.48193359e-01,   1.48193359e-01],
                        [  1.36352539e-01,   1.36352539e-01],
                        [  1.29638672e-01,   1.29638672e-01],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.14898682e-01,   1.14898682e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  9.03930664e-02,   9.03930664e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -1.49353027e-01,  -1.49353027e-01],
                        [ -2.24090576e-01,  -2.24090576e-01],
                        [ -2.64068604e-01,  -2.64068604e-01],
                        [ -2.52349854e-01,  -2.52349854e-01],
                        [ -2.02178955e-01,  -2.02178955e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -9.95483398e-02,  -9.95483398e-02],
                        [ -8.97827148e-02,  -8.97827148e-02],
                        [ -7.46154785e-02,  -7.46154785e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  6.74743652e-02,   6.74743652e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -1.01074219e-01,  -1.01074219e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -1.99432373e-01,  -1.99432373e-01],
                        [ -1.76879883e-01,  -1.76879883e-01],
                        [ -1.26312256e-01,  -1.26312256e-01],
                        [ -7.81860352e-02,  -7.81860352e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.48712158e-01,   1.48712158e-01],
                        [  1.78619385e-01,   1.78619385e-01],
                        [  1.84326172e-01,   1.84326172e-01],
                        [  1.71783447e-01,   1.71783447e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.48162842e-01,   1.48162842e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  9.03930664e-02,   9.03930664e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -1.49810791e-01,  -1.49810791e-01],
                        [ -2.18872070e-01,  -2.18872070e-01],
                        [ -2.59246826e-01,  -2.59246826e-01],
                        [ -2.55645752e-01,  -2.55645752e-01],
                        [ -2.14508057e-01,  -2.14508057e-01],
                        [ -1.64794922e-01,  -1.64794922e-01],
                        [ -1.32659912e-01,  -1.32659912e-01],
                        [ -1.19262695e-01,  -1.19262695e-01],
                        [ -1.09741211e-01,  -1.09741211e-01],
                        [ -9.63439941e-02,  -9.63439941e-02],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  1.06414795e-01,   1.06414795e-01],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  7.62023926e-02,   7.62023926e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -1.06292725e-01,  -1.06292725e-01],
                        [ -1.88690186e-01,  -1.88690186e-01],
                        [ -2.17071533e-01,  -2.17071533e-01],
                        [ -1.87072754e-01,  -1.87072754e-01],
                        [ -1.28540039e-01,  -1.28540039e-01],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  1.43188477e-01,   1.43188477e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.66748047e-01,   1.66748047e-01],
                        [  1.53015137e-01,   1.53015137e-01],
                        [  1.40319824e-01,   1.40319824e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.37512207e-01,   1.37512207e-01],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  1.29272461e-01,   1.29272461e-01],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  9.96093750e-02,   9.96093750e-02],
                        [  1.34613037e-01,   1.34613037e-01],
                        [  1.32049561e-01,   1.32049561e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  7.08312988e-02,   7.08312988e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  2.07519531e-03,   2.07519531e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  4.94384766e-03,   4.94384766e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -1.59088135e-01,  -1.59088135e-01],
                        [ -2.23022461e-01,  -2.23022461e-01],
                        [ -2.52746582e-01,  -2.52746582e-01],
                        [ -2.37060547e-01,  -2.37060547e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.37207031e-01,  -1.37207031e-01],
                        [ -1.09008789e-01,  -1.09008789e-01],
                        [ -1.05468750e-01,  -1.05468750e-01],
                        [ -1.09893799e-01,  -1.09893799e-01],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -9.69543457e-02,  -9.69543457e-02],
                        [ -8.00781250e-02,  -8.00781250e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  9.98229980e-02,   9.98229980e-02],
                        [  1.11358643e-01,   1.11358643e-01],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -1.00769043e-01,  -1.00769043e-01],
                        [ -1.58935547e-01,  -1.58935547e-01],
                        [ -1.75201416e-01,  -1.75201416e-01],
                        [ -1.50085449e-01,  -1.50085449e-01],
                        [ -1.06414795e-01,  -1.06414795e-01],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.51702881e-01,   1.51702881e-01],
                        [  1.67083740e-01,   1.67083740e-01],
                        [  1.63513184e-01,   1.63513184e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.33331299e-01,   1.33331299e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.13281250e-01,   1.13281250e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.13800049e-01,   1.13800049e-01],
                        [  9.69238281e-02,   9.69238281e-02],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -1.38244629e-01,  -1.38244629e-01],
                        [ -2.23236084e-01,  -2.23236084e-01],
                        [ -2.77648926e-01,  -2.77648926e-01],
                        [ -2.82379150e-01,  -2.82379150e-01],
                        [ -2.43957520e-01,  -2.43957520e-01],
                        [ -1.89788818e-01,  -1.89788818e-01],
                        [ -1.44836426e-01,  -1.44836426e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -9.09729004e-02,  -9.09729004e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -1.25732422e-01,  -1.25732422e-01],
                        [ -1.77062988e-01,  -1.77062988e-01],
                        [ -1.77398682e-01,  -1.77398682e-01],
                        [ -1.37542725e-01,  -1.37542725e-01],
                        [ -8.91723633e-02,  -8.91723633e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  1.61468506e-01,   1.61468506e-01],
                        [  1.86462402e-01,   1.86462402e-01],
                        [  1.92291260e-01,   1.92291260e-01],
                        [  1.78253174e-01,   1.78253174e-01],
                        [  1.51947021e-01,   1.51947021e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -1.86523438e-01,  -1.86523438e-01],
                        [ -2.51007080e-01,  -2.51007080e-01],
                        [ -2.71728516e-01,  -2.71728516e-01],
                        [ -2.46643066e-01,  -2.46643066e-01],
                        [ -1.97631836e-01,  -1.97631836e-01],
                        [ -1.52160645e-01,  -1.52160645e-01],
                        [ -1.23565674e-01,  -1.23565674e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -9.30480957e-02,  -9.30480957e-02],
                        [ -7.82775879e-02,  -7.82775879e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  8.43505859e-02,   8.43505859e-02],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -9.68627930e-02,  -9.68627930e-02],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.73095703e-01,  -1.73095703e-01],
                        [ -1.53717041e-01,  -1.53717041e-01],
                        [ -1.12426758e-01,  -1.12426758e-01],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.67480469e-01,   1.67480469e-01],
                        [  1.67846680e-01,   1.67846680e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  9.39025879e-02,   9.39025879e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -1.35559082e-01,  -1.35559082e-01],
                        [ -2.13562012e-01,  -2.13562012e-01],
                        [ -2.64617920e-01,  -2.64617920e-01],
                        [ -2.71697998e-01,  -2.71697998e-01],
                        [ -2.37945557e-01,  -2.37945557e-01],
                        [ -1.83959961e-01,  -1.83959961e-01],
                        [ -1.33605957e-01,  -1.33605957e-01],
                        [ -1.01806641e-01,  -1.01806641e-01],
                        [ -8.94470215e-02,  -8.94470215e-02],
                        [ -8.63952637e-02,  -8.63952637e-02],
                        [ -8.16040039e-02,  -8.16040039e-02],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  6.80541992e-02,   6.80541992e-02],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.46972656e-01,   1.46972656e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.20941162e-01,   1.20941162e-01],
                        [  4.97741699e-02,   4.97741699e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -1.41540527e-01,  -1.41540527e-01],
                        [ -1.91375732e-01,  -1.91375732e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.43615723e-01,  -1.43615723e-01],
                        [ -9.12170410e-02,  -9.12170410e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.75872803e-01,   1.75872803e-01],
                        [  2.04040527e-01,   2.04040527e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  1.70410156e-01,   1.70410156e-01],
                        [  1.29577637e-01,   1.29577637e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  8.19396973e-02,   8.19396973e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  9.22241211e-02,   9.22241211e-02],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.10961914e-01,   1.10961914e-01],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  5.19104004e-02,   5.19104004e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -1.36871338e-01,  -1.36871338e-01],
                        [ -2.14599609e-01,  -2.14599609e-01],
                        [ -2.64038086e-01,  -2.64038086e-01],
                        [ -2.67059326e-01,  -2.67059326e-01],
                        [ -2.31353760e-01,  -2.31353760e-01],
                        [ -1.84570312e-01,  -1.84570312e-01],
                        [ -1.48834229e-01,  -1.48834229e-01],
                        [ -1.26129150e-01,  -1.26129150e-01],
                        [ -1.08520508e-01,  -1.08520508e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -7.93762207e-02,  -7.93762207e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  6.63452148e-02,   6.63452148e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  8.71276855e-02,   8.71276855e-02],
                        [  1.05926514e-01,   1.05926514e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -1.51916504e-01,  -1.51916504e-01],
                        [ -1.79168701e-01,  -1.79168701e-01],
                        [ -1.60949707e-01,  -1.60949707e-01],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.68365479e-01,   1.68365479e-01],
                        [  1.97814941e-01,   1.97814941e-01],
                        [  2.00469971e-01,   2.00469971e-01],
                        [  1.80725098e-01,   1.80725098e-01],
                        [  1.49963379e-01,   1.49963379e-01],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  6.13098145e-02,   6.13098145e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  6.30493164e-02,   6.30493164e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -8.83789062e-02,  -8.83789062e-02],
                        [ -1.58447266e-01,  -1.58447266e-01],
                        [ -2.16735840e-01,  -2.16735840e-01],
                        [ -2.42034912e-01,  -2.42034912e-01],
                        [ -2.31781006e-01,  -2.31781006e-01],
                        [ -2.01110840e-01,  -2.01110840e-01],
                        [ -1.68029785e-01,  -1.68029785e-01],
                        [ -1.41418457e-01,  -1.41418457e-01],
                        [ -1.19964600e-01,  -1.19964600e-01],
                        [ -9.93041992e-02,  -9.93041992e-02],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -6.32324219e-02,  -6.32324219e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  8.80432129e-02,   8.80432129e-02],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [ -7.19299316e-02,  -7.19299316e-02],
                        [ -1.52465820e-01,  -1.52465820e-01],
                        [ -1.93695068e-01,  -1.93695068e-01],
                        [ -1.85363770e-01,  -1.85363770e-01],
                        [ -1.43310547e-01,  -1.43310547e-01],
                        [ -9.51843262e-02,  -9.51843262e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.52496338e-01,   1.52496338e-01],
                        [  1.77825928e-01,   1.77825928e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  1.50482178e-01,   1.50482178e-01],
                        [  1.20910645e-01,   1.20910645e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  1.09497070e-01,   1.09497070e-01],
                        [  1.18225098e-01,   1.18225098e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  8.77990723e-02,   8.77990723e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  6.13708496e-02,   6.13708496e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -7.28454590e-02,  -7.28454590e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  1.08734131e-01,   1.08734131e-01],
                        [  1.17401123e-01,   1.17401123e-01],
                        [  1.02966309e-01,   1.02966309e-01],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  5.32531738e-02,   5.32531738e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -1.95678711e-01,  -1.95678711e-01],
                        [ -2.52014160e-01,  -2.52014160e-01],
                        [ -2.68341064e-01,  -2.68341064e-01],
                        [ -2.47711182e-01,  -2.47711182e-01],
                        [ -2.07275391e-01,  -2.07275391e-01],
                        [ -1.64306641e-01,  -1.64306641e-01],
                        [ -1.28417969e-01,  -1.28417969e-01],
                        [ -1.02752686e-01,  -1.02783203e-01],
                        [ -8.80432129e-02,  -8.80432129e-02],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -7.99865723e-02,  -7.99865723e-02],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  5.20019531e-02,   5.19714355e-02],
                        [  6.67114258e-02,   6.67114258e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.27471924e-01,   1.27471924e-01],
                        [  1.34674072e-01,   1.34674072e-01],
                        [  1.21032715e-01,   1.21032715e-01],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -1.57012939e-01,  -1.57043457e-01],
                        [ -1.94824219e-01,  -1.94824219e-01],
                        [ -1.83624268e-01,  -1.83654785e-01],
                        [ -1.38702393e-01,  -1.38702393e-01],
                        [ -8.94775391e-02,  -8.94775391e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.32836914e-02,  -5.33142090e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -2.74353027e-02,  -2.74658203e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  1.34460449e-01,   1.34460449e-01],
                        [  1.71386719e-01,   1.71356201e-01],
                        [  1.81365967e-01,   1.81335449e-01],
                        [  1.68975830e-01,   1.68975830e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.10351562e-01,   1.10351562e-01],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  1.06414795e-01,   1.06414795e-01],
                        [  1.08856201e-01,   1.08825684e-01],
                        [  1.03607178e-01,   1.03576660e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  7.64770508e-02,   7.64770508e-02],
                        [  5.87463379e-02,   5.87158203e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  3.57360840e-02,   3.57055664e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.05895996e-02,   1.05590820e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.69677734e-02,  -1.69982910e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -5.29785156e-02,  -5.30090332e-02],
                        [ -5.05676270e-02,  -5.05981445e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.24450684e-01,   1.24450684e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.17187500e-02,   1.16882324e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  9.97924805e-03,   9.94873047e-03],
                        [  7.50732422e-03,   7.47680664e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -1.25122070e-03,  -1.28173828e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -1.38244629e-02,  -1.38549805e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -4.52880859e-02,  -4.53186035e-02],
                        [ -4.57458496e-02,  -4.57763672e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  5.96618652e-02,   5.96923828e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -1.55914307e-01,  -1.55914307e-01],
                        [ -2.27996826e-01,  -2.27996826e-01],
                        [ -2.65991211e-01,  -2.65991211e-01],
                        [ -2.61840820e-01,  -2.61840820e-01],
                        [ -2.25799561e-01,  -2.25799561e-01],
                        [ -1.79931641e-01,  -1.79931641e-01],
                        [ -1.43432617e-01,  -1.43432617e-01],
                        [ -1.21704102e-01,  -1.21704102e-01],
                        [ -1.08367920e-01,  -1.08337402e-01],
                        [ -9.45434570e-02,  -9.45129395e-02],
                        [ -7.57141113e-02,  -7.57141113e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  1.53503418e-02,   1.53808594e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  4.17175293e-02,   4.17480469e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  9.10339355e-02,   9.10644531e-02],
                        [  1.07910156e-01,   1.07940674e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.03912354e-01,   1.03942871e-01],
                        [  4.19006348e-02,   4.19311523e-02],
                        [ -4.73022461e-02,  -4.72717285e-02],
                        [ -1.29791260e-01,  -1.29760742e-01],
                        [ -1.73156738e-01,  -1.73156738e-01],
                        [ -1.70898438e-01,  -1.70867920e-01],
                        [ -1.41815186e-01,  -1.41815186e-01],
                        [ -1.11480713e-01,  -1.11450195e-01],
                        [ -9.33837891e-02,  -9.33532715e-02],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.96203613e-02,  -7.95898438e-02],
                        [ -7.27539062e-02,  -7.27233887e-02],
                        [ -6.37512207e-02,  -6.37207031e-02],
                        [ -4.80041504e-02,  -4.79736328e-02],
                        [ -1.77612305e-02,  -1.77307129e-02],
                        [  2.98156738e-02,   2.98461914e-02],
                        [  8.73413086e-02,   8.73718262e-02],
                        [  1.41235352e-01,   1.41265869e-01],
                        [  1.77886963e-01,   1.77886963e-01],
                        [  1.89208984e-01,   1.89239502e-01],
                        [  1.77429199e-01,   1.77459717e-01],
                        [  1.54083252e-01,   1.54113770e-01],
                        [  1.31683350e-01,   1.31713867e-01],
                        [  1.15814209e-01,   1.15814209e-01],
                        [  1.04217529e-01,   1.04248047e-01],
                        [  9.36584473e-02,   9.36889648e-02],
                        [  8.46862793e-02,   8.47167969e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  7.34252930e-02,   7.34558105e-02],
                        [  6.93054199e-02,   6.93359375e-02],
                        [  6.59484863e-02,   6.59790039e-02],
                        [  6.27441406e-02,   6.27746582e-02],
                        [  6.02416992e-02,   6.02722168e-02],
                        [  5.85327148e-02,   5.85632324e-02],
                        [  5.44128418e-02,   5.44433594e-02],
                        [  4.53796387e-02,   4.54101562e-02],
                        [  3.52783203e-02,   3.53088379e-02],
                        [  3.08837891e-02,   3.09143066e-02],
                        [  3.26538086e-02,   3.26843262e-02],
                        [  3.23791504e-02,   3.24096680e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [ -5.18798828e-04,  -4.88281250e-04],
                        [ -2.72521973e-02,  -2.72216797e-02],
                        [ -4.79736328e-02,  -4.79431152e-02],
                        [ -5.21240234e-02,  -5.20935059e-02],
                        [ -3.64379883e-02,  -3.64074707e-02],
                        [ -6.28662109e-03,  -6.25610352e-03],
                        [  3.17382812e-02,   3.17687988e-02],
                        [  7.20825195e-02,   7.21130371e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.11267090e-01,   1.11297607e-01],
                        [  8.95080566e-02,   8.95385742e-02],
                        [  5.20629883e-02,   5.20935059e-02],
                        [  2.14233398e-02,   2.14538574e-02],
                        [  1.04980469e-02,   1.05285645e-02],
                        [  1.53198242e-02,   1.53503418e-02],
                        [  2.31933594e-02,   2.32238770e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.55029297e-02,   1.55334473e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -1.57775879e-02,  -1.57470703e-02],
                        [ -3.27148438e-02,  -3.26843262e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.35485840e-02,  -4.35180664e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.00903320e-02,  -3.00598145e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.26843262e-02,  -3.26538086e-02],
                        [ -3.83911133e-02,  -3.83605957e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  6.37817383e-02,   6.37817383e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -1.17187500e-01,  -1.17187500e-01],
                        [ -1.94763184e-01,  -1.94763184e-01],
                        [ -2.51464844e-01,  -2.51464844e-01],
                        [ -2.67913818e-01,  -2.67913818e-01],
                        [ -2.44689941e-01,  -2.44720459e-01],
                        [ -2.02117920e-01,  -2.02117920e-01],
                        [ -1.63635254e-01,  -1.63665771e-01],
                        [ -1.39282227e-01,  -1.39312744e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -1.07421875e-01,  -1.07452393e-01],
                        [ -8.79821777e-02,  -8.80126953e-02],
                        [ -6.76574707e-02,  -6.76879883e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -3.37219238e-02,  -3.37524414e-02],
                        [ -1.87377930e-02,  -1.87683105e-02],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  1.74865723e-02,   1.74560547e-02],
                        [  2.53601074e-02,   2.53295898e-02],
                        [  3.12194824e-02,   3.11889648e-02],
                        [  3.72314453e-02,   3.72009277e-02],
                        [  4.53796387e-02,   4.53491211e-02],
                        [  5.47790527e-02,   5.47180176e-02],
                        [  6.26831055e-02,   6.26220703e-02],
                        [  7.00988770e-02,   7.00683594e-02],
                        [  8.38012695e-02,   8.37707520e-02],
                        [  1.06536865e-01,   1.06506348e-01],
                        [  1.26464844e-01,   1.26434326e-01],
                        [  1.22955322e-01,   1.22894287e-01],
                        [  8.36181641e-02,   8.35571289e-02],
                        [  1.19628906e-02,   1.19018555e-02],
                        [ -7.53784180e-02,  -7.54089355e-02],
                        [ -1.50756836e-01,  -1.50817871e-01],
                        [ -1.85577393e-01,  -1.85638428e-01],
                        [ -1.71875000e-01,  -1.71905518e-01],
                        [ -1.31134033e-01,  -1.31195068e-01],
                        [ -9.50317383e-02,  -9.50622559e-02],
                        [ -7.84606934e-02,  -7.85217285e-02],
                        [ -7.46459961e-02,  -7.47070312e-02],
                        [ -6.95495605e-02,  -6.95800781e-02],
                        [ -5.53894043e-02,  -5.54504395e-02],
                        [ -3.19213867e-02,  -3.19519043e-02],
                        [ -6.40869141e-04,  -7.01904297e-04],
                        [  3.75061035e-02,   3.74450684e-02],
                        [  8.00781250e-02,   8.00476074e-02],
                        [  1.21246338e-01,   1.21185303e-01],
                        [  1.52526855e-01,   1.52465820e-01],
                        [  1.64794922e-01,   1.64733887e-01],
                        [  1.54937744e-01,   1.54876709e-01],
                        [  1.32568359e-01,   1.32507324e-01],
                        [  1.15081787e-01,   1.15020752e-01],
                        [  1.11816406e-01,   1.11785889e-01],
                        [  1.16149902e-01,   1.16088867e-01],
                        [  1.14959717e-01,   1.14868164e-01],
                        [  1.02600098e-01,   1.02539062e-01],
                        [  8.47778320e-02,   8.47167969e-02],
                        [  7.03125000e-02,   7.02209473e-02],
                        [  6.20422363e-02,   6.19812012e-02],
                        [  5.77697754e-02,   5.77087402e-02],
                        [  5.46875000e-02,   5.46264648e-02],
                        [  5.01403809e-02,   5.00793457e-02],
                        [  4.43115234e-02,   4.42504883e-02],
                        [  4.23583984e-02,   4.22973633e-02],
                        [  4.73937988e-02,   4.73327637e-02],
                        [  5.48095703e-02,   5.47180176e-02],
                        [  5.67626953e-02,   5.67016602e-02],
                        [  5.00488281e-02,   4.99877930e-02],
                        [  3.82690430e-02,   3.82080078e-02],
                        [  2.54516602e-02,   2.53906250e-02],
                        [  9.76562500e-03,   9.70458984e-03],
                        [ -1.09558105e-02,  -1.10168457e-02],
                        [ -3.07312012e-02,  -3.07922363e-02],
                        [ -3.92456055e-02,  -3.93066406e-02],
                        [ -3.19519043e-02,  -3.20129395e-02],
                        [ -1.26647949e-02,  -1.27258301e-02],
                        [  1.35498047e-02,   1.34887695e-02],
                        [  4.39147949e-02,   4.38537598e-02],
                        [  7.29980469e-02,   7.29370117e-02],
                        [  9.08203125e-02,   9.07592773e-02],
                        [  9.08203125e-02,   9.07592773e-02],
                        [  7.55004883e-02,   7.54699707e-02],
                        [  5.36804199e-02,   5.36193848e-02],
                        [  3.59191895e-02,   3.58886719e-02],
                        [  2.85339355e-02,   2.85034180e-02],
                        [  2.71911621e-02,   2.71301270e-02],
                        [  2.18505859e-02,   2.18200684e-02],
                        [  1.00097656e-02,   9.94873047e-03],
                        [  5.49316406e-04,   5.18798828e-04],
                        [  3.05175781e-03,   2.99072266e-03],
                        [  1.45874023e-02,   1.45568848e-02],
                        [  2.17285156e-02,   2.16979980e-02],
                        [  1.60217285e-02,   1.59912109e-02],
                        [  1.89208984e-03,   1.86157227e-03],
                        [ -1.17187500e-02,  -1.17492676e-02],
                        [ -2.02026367e-02,  -2.02331543e-02],
                        [ -2.33459473e-02,  -2.33764648e-02],
                        [ -2.42919922e-02,  -2.43225098e-02],
                        [ -2.91137695e-02,  -2.91442871e-02],
                        [ -4.02832031e-02,  -4.03137207e-02],
                        [ -5.03234863e-02,  -5.03540039e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -3.58886719e-02,  -3.59191895e-02],
                        [ -2.31933594e-02,  -2.32238770e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.84936523e-02,  -1.85241699e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.84118652e-02,  -2.84423828e-02],
                        [ -3.33251953e-02,  -3.33557129e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -2.31933594e-02,  -2.32238770e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [  8.05664062e-03,   8.02612305e-03],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  7.39440918e-02,   7.39440918e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -9.44824219e-02,  -9.44519043e-02],
                        [ -1.85394287e-01,  -1.85394287e-01],
                        [ -2.56927490e-01,  -2.56896973e-01],
                        [ -2.86834717e-01,  -2.86834717e-01],
                        [ -2.67456055e-01,  -2.67425537e-01],
                        [ -2.14508057e-01,  -2.14477539e-01],
                        [ -1.60827637e-01,  -1.60797119e-01],
                        [ -1.29760742e-01,  -1.29730225e-01],
                        [ -1.16699219e-01,  -1.16668701e-01],
                        [ -1.03271484e-01,  -1.03240967e-01],
                        [ -8.36486816e-02,  -8.36181641e-02],
                        [ -6.69555664e-02,  -6.69250488e-02],
                        [ -5.86242676e-02,  -5.85937500e-02],
                        [ -5.28259277e-02,  -5.27648926e-02],
                        [ -4.18395996e-02,  -4.17785645e-02],
                        [ -2.28271484e-02,  -2.27661133e-02],
                        [  9.76562500e-04,   1.03759766e-03],
                        [  2.10571289e-02,   2.11181641e-02],
                        [  3.14941406e-02,   3.15246582e-02],
                        [  3.51867676e-02,   3.52478027e-02],
                        [  3.82385254e-02,   3.82995605e-02],
                        [  4.16259766e-02,   4.16870117e-02],
                        [  4.42199707e-02,   4.42810059e-02],
                        [  4.99877930e-02,   5.00488281e-02],
                        [  6.46362305e-02,   6.46972656e-02],
                        [  8.66699219e-02,   8.67309570e-02],
                        [  1.08245850e-01,   1.08337402e-01],
                        [  1.22406006e-01,   1.22467041e-01],
                        [  1.22589111e-01,   1.22680664e-01],
                        [  1.00189209e-01,   1.00250244e-01],
                        [  4.93164062e-02,   4.93774414e-02],
                        [ -2.46887207e-02,  -2.45971680e-02],
                        [ -1.03332520e-01,  -1.03240967e-01],
                        [ -1.61651611e-01,  -1.61560059e-01],
                        [ -1.81915283e-01,  -1.81823730e-01],
                        [ -1.65802002e-01,  -1.65740967e-01],
                        [ -1.32629395e-01,  -1.32568359e-01],
                        [ -1.04492188e-01,  -1.04400635e-01],
                        [ -9.10339355e-02,  -9.09729004e-02],
                        [ -8.46862793e-02,  -8.45947266e-02],
                        [ -7.14111328e-02,  -7.13195801e-02],
                        [ -4.44335938e-02,  -4.43420410e-02],
                        [ -4.24194336e-03,  -4.15039062e-03],
                        [  4.65087891e-02,   4.66003418e-02],
                        [  1.00646973e-01,   1.00738525e-01],
                        [  1.43188477e-01,   1.43280029e-01],
                        [  1.60308838e-01,   1.60400391e-01],
                        [  1.53930664e-01,   1.54022217e-01],
                        [  1.39434814e-01,   1.39526367e-01],
                        [  1.27502441e-01,   1.27593994e-01],
                        [  1.18225098e-01,   1.18316650e-01],
                        [  1.09893799e-01,   1.09985352e-01],
                        [  1.02416992e-01,   1.02508545e-01],
                        [  9.42077637e-02,   9.43298340e-02],
                        [  8.36181641e-02,   8.37402344e-02],
                        [  7.33032227e-02,   7.33947754e-02],
                        [  6.83288574e-02,   6.84204102e-02],
                        [  6.92443848e-02,   6.93359375e-02],
                        [  7.18078613e-02,   7.19299316e-02],
                        [  7.22045898e-02,   7.23266602e-02],
                        [  6.79016113e-02,   6.80236816e-02],
                        [  5.68237305e-02,   5.69152832e-02],
                        [  4.19616699e-02,   4.20837402e-02],
                        [  3.31115723e-02,   3.32336426e-02],
                        [  3.51257324e-02,   3.52172852e-02],
                        [  3.98864746e-02,   3.99780273e-02],
                        [  3.74450684e-02,   3.75671387e-02],
                        [  2.73132324e-02,   2.74353027e-02],
                        [  1.38549805e-02,   1.39465332e-02],
                        [ -6.10351562e-04,  -5.18798828e-04],
                        [ -1.50451660e-02,  -1.49230957e-02],
                        [ -2.73132324e-02,  -2.72216797e-02],
                        [ -3.43017578e-02,  -3.42102051e-02],
                        [ -3.16772461e-02,  -3.15856934e-02],
                        [ -1.44042969e-02,  -1.43127441e-02],
                        [  1.74560547e-02,   1.75476074e-02],
                        [  5.42907715e-02,   5.43823242e-02],
                        [  8.22143555e-02,   8.23059082e-02],
                        [  9.17358398e-02,   9.18273926e-02],
                        [  8.09936523e-02,   8.10546875e-02],
                        [  5.66406250e-02,   5.67321777e-02],
                        [  3.28369141e-02,   3.28979492e-02],
                        [  2.19726562e-02,   2.20642090e-02],
                        [  2.51770020e-02,   2.52685547e-02],
                        [  3.39050293e-02,   3.39660645e-02],
                        [  3.91235352e-02,   3.91845703e-02],
                        [  3.66210938e-02,   3.66821289e-02],
                        [  2.78015137e-02,   2.78625488e-02],
                        [  1.76391602e-02,   1.77307129e-02],
                        [  9.76562500e-03,   9.82666016e-03],
                        [  3.72314453e-03,   3.78417969e-03],
                        [ -3.05175781e-03,  -2.99072266e-03],
                        [ -1.19934082e-02,  -1.19323730e-02],
                        [ -2.15454102e-02,  -2.14843750e-02],
                        [ -2.91137695e-02,  -2.90527344e-02],
                        [ -3.32946777e-02,  -3.32336426e-02],
                        [ -3.41186523e-02,  -3.40881348e-02],
                        [ -3.22265625e-02,  -3.21655273e-02],
                        [ -2.84729004e-02,  -2.84118652e-02],
                        [ -2.52075195e-02,  -2.51464844e-02],
                        [ -2.57873535e-02,  -2.57263184e-02],
                        [ -3.06396484e-02,  -3.05786133e-02],
                        [ -3.71093750e-02,  -3.70483398e-02],
                        [ -4.39453125e-02,  -4.39147949e-02],
                        [ -4.97131348e-02,  -4.96826172e-02],
                        [ -4.88586426e-02,  -4.88281250e-02],
                        [ -3.66516113e-02,  -3.66210938e-02],
                        [ -1.69067383e-02,  -1.68762207e-02],
                        [  1.83105469e-04,   2.13623047e-04],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.32751465e-02,   1.33056641e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -1.19384766e-01,  -1.19384766e-01],
                        [ -2.13104248e-01,  -2.13104248e-01],
                        [ -2.81311035e-01,  -2.81341553e-01],
                        [ -2.97912598e-01,  -2.97943115e-01],
                        [ -2.61413574e-01,  -2.61444092e-01],
                        [ -1.97845459e-01,  -1.97875977e-01],
                        [ -1.42517090e-01,  -1.42547607e-01],
                        [ -1.15173340e-01,  -1.15203857e-01],
                        [ -1.10260010e-01,  -1.10290527e-01],
                        [ -1.07543945e-01,  -1.07604980e-01],
                        [ -9.32922363e-02,  -9.33227539e-02],
                        [ -7.14111328e-02,  -7.14721680e-02],
                        [ -5.30700684e-02,  -5.31311035e-02],
                        [ -4.11376953e-02,  -4.11987305e-02],
                        [ -3.03039551e-02,  -3.03649902e-02],
                        [ -1.69982910e-02,  -1.70593262e-02],
                        [ -2.38037109e-03,  -2.44140625e-03],
                        [  1.08642578e-02,   1.07727051e-02],
                        [  2.15454102e-02,   2.14538574e-02],
                        [  2.99682617e-02,   2.99072266e-02],
                        [  3.60412598e-02,   3.59802246e-02],
                        [  3.84826660e-02,   3.84216309e-02],
                        [  3.86047363e-02,   3.85131836e-02],
                        [  4.25415039e-02,   4.24499512e-02],
                        [  5.63964844e-02,   5.63049316e-02],
                        [  8.02001953e-02,   8.01086426e-02],
                        [  1.07910156e-01,   1.07849121e-01],
                        [  1.31439209e-01,   1.31347656e-01],
                        [  1.40960693e-01,   1.40869141e-01],
                        [  1.23016357e-01,   1.22924805e-01],
                        [  6.72912598e-02,   6.71997070e-02],
                        [ -1.95007324e-02,  -1.95922852e-02],
                        [ -1.11328125e-01,  -1.11450195e-01],
                        [ -1.76818848e-01,  -1.76940918e-01],
                        [ -1.97113037e-01,  -1.97204590e-01],
                        [ -1.75598145e-01,  -1.75720215e-01],
                        [ -1.35375977e-01,  -1.35498047e-01],
                        [ -1.04034424e-01,  -1.04125977e-01],
                        [ -9.25292969e-02,  -9.26513672e-02],
                        [ -8.82873535e-02,  -8.84094238e-02],
                        [ -7.10449219e-02,  -7.11364746e-02],
                        [ -3.12500000e-02,  -3.13720703e-02],
                        [  2.55737305e-02,   2.54516602e-02],
                        [  8.45336914e-02,   8.44116211e-02],
                        [  1.30126953e-01,   1.30004883e-01],
                        [  1.53717041e-01,   1.53564453e-01],
                        [  1.56372070e-01,   1.56219482e-01],
                        [  1.46575928e-01,   1.46453857e-01],
                        [  1.34338379e-01,   1.34216309e-01],
                        [  1.25549316e-01,   1.25396729e-01],
                        [  1.19598389e-01,   1.19476318e-01],
                        [  1.12426758e-01,   1.12274170e-01],
                        [  1.02233887e-01,   1.02081299e-01],
                        [  9.07897949e-02,   9.06677246e-02],
                        [  8.01391602e-02,   7.99865723e-02],
                        [  7.00683594e-02,   6.99157715e-02],
                        [  5.80444336e-02,   5.79223633e-02],
                        [  4.33349609e-02,   4.32128906e-02],
                        [  2.96020508e-02,   2.94494629e-02],
                        [  2.15148926e-02,   2.13623047e-02],
                        [  2.17895508e-02,   2.16369629e-02],
                        [  3.04260254e-02,   3.03039551e-02],
                        [  4.35180664e-02,   4.33654785e-02],
                        [  5.49011230e-02,   5.47485352e-02],
                        [  6.09741211e-02,   6.08215332e-02],
                        [  6.26220703e-02,   6.24694824e-02],
                        [  6.11877441e-02,   6.10656738e-02],
                        [  5.38635254e-02,   5.37414551e-02],
                        [  3.55529785e-02,   3.54003906e-02],
                        [  5.43212891e-03,   5.31005859e-03],
                        [ -2.80151367e-02,  -2.81372070e-02],
                        [ -5.12084961e-02,  -5.13305664e-02],
                        [ -5.69152832e-02,  -5.70373535e-02],
                        [ -4.73937988e-02,  -4.75158691e-02],
                        [ -2.52685547e-02,  -2.54211426e-02],
                        [  9.82666016e-03,   9.70458984e-03],
                        [  5.27954102e-02,   5.26733398e-02],
                        [  8.86230469e-02,   8.85009766e-02],
                        [  1.02386475e-01,   1.02264404e-01],
                        [  9.15527344e-02,   9.14306641e-02],
                        [  6.62841797e-02,   6.61621094e-02],
                        [  4.19616699e-02,   4.18395996e-02],
                        [  2.93579102e-02,   2.92358398e-02],
                        [  2.74353027e-02,   2.73437500e-02],
                        [  2.85949707e-02,   2.84729004e-02],
                        [  2.78625488e-02,   2.77404785e-02],
                        [  2.46887207e-02,   2.45666504e-02],
                        [  2.09350586e-02,   2.08435059e-02],
                        [  1.82800293e-02,   1.81884766e-02],
                        [  1.55334473e-02,   1.54418945e-02],
                        [  1.00402832e-02,   9.94873047e-03],
                        [  9.46044922e-04,   8.54492188e-04],
                        [ -9.27734375e-03,  -9.36889648e-03],
                        [ -1.84631348e-02,  -1.85546875e-02],
                        [ -2.71606445e-02,  -2.72216797e-02],
                        [ -3.38134766e-02,  -3.38745117e-02],
                        [ -3.43627930e-02,  -3.44543457e-02],
                        [ -3.03039551e-02,  -3.03955078e-02],
                        [ -2.87780762e-02,  -2.88391113e-02],
                        [ -3.21655273e-02,  -3.22265625e-02],
                        [ -3.47290039e-02,  -3.47900391e-02],
                        [ -3.16772461e-02,  -3.17382812e-02],
                        [ -2.60009766e-02,  -2.60620117e-02],
                        [ -2.30102539e-02,  -2.30712891e-02],
                        [ -2.26440430e-02,  -2.27050781e-02],
                        [ -2.11791992e-02,  -2.12097168e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -1.06506348e-02,  -1.07116699e-02],
                        [  1.52587891e-04,   1.22070312e-04],
                        [  1.72729492e-02,   1.72424316e-02],
                        [  3.78417969e-02,   3.78112793e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  6.52465820e-02,   6.52465820e-02],
                        [  6.71081543e-02,   6.70776367e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -1.23870850e-01,  -1.23901367e-01],
                        [ -2.10052490e-01,  -2.10052490e-01],
                        [ -2.69287109e-01,  -2.69287109e-01],
                        [ -2.82867432e-01,  -2.82836914e-01],
                        [ -2.52532959e-01,  -2.52502441e-01],
                        [ -2.00439453e-01,  -2.00439453e-01],
                        [ -1.54357910e-01,  -1.54327393e-01],
                        [ -1.27716064e-01,  -1.27685547e-01],
                        [ -1.14624023e-01,  -1.14593506e-01],
                        [ -1.04125977e-01,  -1.04095459e-01],
                        [ -9.17663574e-02,  -9.17358398e-02],
                        [ -7.67211914e-02,  -7.66906738e-02],
                        [ -5.82580566e-02,  -5.81970215e-02],
                        [ -3.81469727e-02,  -3.80859375e-02],
                        [ -1.94396973e-02,  -1.93786621e-02],
                        [ -9.76562500e-04,  -9.15527344e-04],
                        [  2.01110840e-02,   2.01721191e-02],
                        [  4.06188965e-02,   4.06799316e-02],
                        [  5.12390137e-02,   5.13000488e-02],
                        [  4.62036133e-02,   4.62646484e-02],
                        [  3.08837891e-02,   3.09448242e-02],
                        [  1.81274414e-02,   1.81884766e-02],
                        [  1.63574219e-02,   1.64489746e-02],
                        [  2.37731934e-02,   2.38342285e-02],
                        [  3.44238281e-02,   3.45153809e-02],
                        [  4.73937988e-02,   4.74853516e-02],
                        [  6.69250488e-02,   6.70166016e-02],
                        [  9.45434570e-02,   9.46350098e-02],
                        [  1.24237061e-01,   1.24328613e-01],
                        [  1.44714355e-01,   1.44836426e-01],
                        [  1.43310547e-01,   1.43432617e-01],
                        [  1.09008789e-01,   1.09130859e-01],
                        [  3.80859375e-02,   3.82080078e-02],
                        [ -5.83496094e-02,  -5.82275391e-02],
                        [ -1.52160645e-01,  -1.52038574e-01],
                        [ -2.09716797e-01,  -2.09594727e-01],
                        [ -2.13684082e-01,  -2.13562012e-01],
                        [ -1.75750732e-01,  -1.75628662e-01],
                        [ -1.24694824e-01,  -1.24572754e-01],
                        [ -8.06274414e-02,  -8.05053711e-02],
                        [ -4.19006348e-02,  -4.17785645e-02],
                        [  4.82177734e-03,   4.94384766e-03],
                        [  6.16455078e-02,   6.17980957e-02],
                        [  1.10870361e-01,   1.10992432e-01],
                        [  1.33483887e-01,   1.33636475e-01],
                        [  1.28326416e-01,   1.28479004e-01],
                        [  1.09344482e-01,   1.09497070e-01],
                        [  9.30480957e-02,   9.32006836e-02],
                        [  8.80432129e-02,   8.81958008e-02],
                        [  9.19494629e-02,   9.21020508e-02],
                        [  9.68627930e-02,   9.70153809e-02],
                        [  9.68933105e-02,   9.70458984e-02],
                        [  9.21020508e-02,   9.22241211e-02],
                        [  8.55407715e-02,   8.56933594e-02],
                        [  7.76672363e-02,   7.78198242e-02],
                        [  6.69860840e-02,   6.71386719e-02],
                        [  5.39245605e-02,   5.40771484e-02],
                        [  4.13208008e-02,   4.14733887e-02],
                        [  3.27453613e-02,   3.28674316e-02],
                        [  2.96630859e-02,   2.98156738e-02],
                        [  3.14331055e-02,   3.15856934e-02],
                        [  3.73229980e-02,   3.74755859e-02],
                        [  4.53796387e-02,   4.55322266e-02],
                        [  5.13610840e-02,   5.15136719e-02],
                        [  5.32836914e-02,   5.34362793e-02],
                        [  5.34667969e-02,   5.36499023e-02],
                        [  5.37109375e-02,   5.38635254e-02],
                        [  5.15136719e-02,   5.16662598e-02],
                        [  4.22668457e-02,   4.24194336e-02],
                        [  2.24914551e-02,   2.26745605e-02],
                        [ -6.22558594e-03,  -6.07299805e-03],
                        [ -3.56750488e-02,  -3.55224609e-02],
                        [ -5.72204590e-02,  -5.70373535e-02],
                        [ -6.70166016e-02,  -6.68945312e-02],
                        [ -6.26831055e-02,  -6.25305176e-02],
                        [ -4.01000977e-02,  -3.99475098e-02],
                        [  2.19726562e-03,   2.34985352e-03],
                        [  5.56945801e-02,   5.58166504e-02],
                        [  1.00402832e-01,   1.00524902e-01],
                        [  1.16485596e-01,   1.16607666e-01],
                        [  1.00311279e-01,   1.00463867e-01],
                        [  6.89086914e-02,   6.90307617e-02],
                        [  4.47082520e-02,   4.48303223e-02],
                        [  3.44543457e-02,   3.46069336e-02],
                        [  2.81982422e-02,   2.83203125e-02],
                        [  1.77307129e-02,   1.78527832e-02],
                        [  6.56127930e-03,   6.68334961e-03],
                        [  2.44140625e-03,   2.56347656e-03],
                        [  6.50024414e-03,   6.62231445e-03],
                        [  1.13220215e-02,   1.14440918e-02],
                        [  9.09423828e-03,   9.18579102e-03],
                        [ -4.27246094e-04,  -3.35693359e-04],
                        [ -1.09863281e-02,  -1.08947754e-02],
                        [ -1.76086426e-02,  -1.75170898e-02],
                        [ -2.12402344e-02,  -2.11486816e-02],
                        [ -2.59399414e-02,  -2.58483887e-02],
                        [ -3.43017578e-02,  -3.42102051e-02],
                        [ -4.33959961e-02,  -4.33044434e-02],
                        [ -4.51660156e-02,  -4.50744629e-02],
                        [ -3.54309082e-02,  -3.53393555e-02],
                        [ -1.94396973e-02,  -1.93481445e-02],
                        [ -6.65283203e-03,  -6.59179688e-03],
                        [ -3.66210938e-03,  -3.57055664e-03],
                        [ -9.00268555e-03,  -8.94165039e-03],
                        [ -1.49536133e-02,  -1.48925781e-02],
                        [ -1.58386230e-02,  -1.57775879e-02],
                        [ -1.13220215e-02,  -1.12915039e-02],
                        [ -3.63159180e-03,  -3.57055664e-03],
                        [  5.95092773e-03,   6.01196289e-03],
                        [  1.78833008e-02,   1.79443359e-02],
                        [  3.05175781e-02,   3.05480957e-02],
                        [  3.84826660e-02,   3.85131836e-02],
                        [  3.82385254e-02,   3.82690430e-02],
                        [  2.99682617e-02,   2.99987793e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -1.58386230e-02,  -1.58081055e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -1.19232178e-01,  -1.19232178e-01],
                        [ -1.77368164e-01,  -1.77368164e-01],
                        [ -2.20977783e-01,  -2.20977783e-01],
                        [ -2.37060547e-01,  -2.37060547e-01],
                        [ -2.21923828e-01,  -2.21923828e-01],
                        [ -1.89666748e-01,  -1.89666748e-01],
                        [ -1.63208008e-01,  -1.63238525e-01],
                        [ -1.51214600e-01,  -1.51245117e-01],
                        [ -1.43432617e-01,  -1.43432617e-01],
                        [ -1.28784180e-01,  -1.28784180e-01],
                        [ -1.06567383e-01,  -1.06597900e-01],
                        [ -8.09020996e-02,  -8.09326172e-02],
                        [ -5.45043945e-02,  -5.45349121e-02],
                        [ -2.93273926e-02,  -2.93884277e-02],
                        [ -9.18579102e-03,  -9.21630859e-03],
                        [  2.25830078e-03,   2.22778320e-03],
                        [  5.49316406e-03,   5.46264648e-03],
                        [  4.51660156e-03,   4.48608398e-03],
                        [  2.53295898e-03,   2.47192383e-03],
                        [  7.32421875e-04,   6.71386719e-04],
                        [  1.28173828e-03,   1.22070312e-03],
                        [  8.20922852e-03,   8.14819336e-03],
                        [  2.23083496e-02,   2.22167969e-02],
                        [  3.81469727e-02,   3.80859375e-02],
                        [  5.03845215e-02,   5.02929688e-02],
                        [  5.85937500e-02,   5.85021973e-02],
                        [  6.62231445e-02,   6.61315918e-02],
                        [  7.80334473e-02,   7.79418945e-02],
                        [  9.69238281e-02,   9.68322754e-02],
                        [  1.19720459e-01,   1.19598389e-01],
                        [  1.35742188e-01,   1.35650635e-01],
                        [  1.30737305e-01,   1.30645752e-01],
                        [  9.26818848e-02,   9.25598145e-02],
                        [  1.81579590e-02,   1.80358887e-02],
                        [ -7.93457031e-02,  -7.94677734e-02],
                        [ -1.67846680e-01,  -1.67968750e-01],
                        [ -2.11486816e-01,  -2.11639404e-01],
                        [ -1.94519043e-01,  -1.94641113e-01],
                        [ -1.33331299e-01,  -1.33453369e-01],
                        [ -6.27441406e-02,  -6.28967285e-02],
                        [ -8.94165039e-03,  -9.06372070e-03],
                        [  2.37121582e-02,   2.35900879e-02],
                        [  4.44946289e-02,   4.43725586e-02],
                        [  6.13098145e-02,   6.11877441e-02],
                        [  7.27844238e-02,   7.26623535e-02],
                        [  7.52563477e-02,   7.51342773e-02],
                        [  7.29675293e-02,   7.28149414e-02],
                        [  7.44628906e-02,   7.43103027e-02],
                        [  8.12072754e-02,   8.10546875e-02],
                        [  8.77075195e-02,   8.75549316e-02],
                        [  9.10949707e-02,   9.09423828e-02],
                        [  9.34448242e-02,   9.32922363e-02],
                        [  9.59777832e-02,   9.58251953e-02],
                        [  9.64355469e-02,   9.62829590e-02],
                        [  9.21020508e-02,   9.19189453e-02],
                        [  8.07495117e-02,   8.05969238e-02],
                        [  6.22863770e-02,   6.21337891e-02],
                        [  4.31518555e-02,   4.29992676e-02],
                        [  3.28674316e-02,   3.26843262e-02],
                        [  3.23181152e-02,   3.21350098e-02],
                        [  3.47900391e-02,   3.46069336e-02],
                        [  3.66821289e-02,   3.65295410e-02],
                        [  3.84216309e-02,   3.82690430e-02],
                        [  3.98559570e-02,   3.96728516e-02],
                        [  4.07104492e-02,   4.05578613e-02],
                        [  4.22973633e-02,   4.21447754e-02],
                        [  4.51660156e-02,   4.49829102e-02],
                        [  4.58374023e-02,   4.56848145e-02],
                        [  4.05273438e-02,   4.03442383e-02],
                        [  3.00292969e-02,   2.98767090e-02],
                        [  1.55334473e-02,   1.53808594e-02],
                        [ -5.67626953e-03,  -5.85937500e-03],
                        [ -3.40576172e-02,  -3.42102051e-02],
                        [ -6.09436035e-02,  -6.10961914e-02],
                        [ -7.00683594e-02,  -7.02514648e-02],
                        [ -4.90722656e-02,  -4.92248535e-02],
                        [ -6.71386719e-04,  -8.23974609e-04],
                        [  5.86853027e-02,   5.85021973e-02],
                        [  1.08642578e-01,   1.08489990e-01],
                        [  1.33483887e-01,   1.33331299e-01],
                        [  1.28204346e-01,   1.28082275e-01],
                        [  1.00006104e-01,   9.98535156e-02],
                        [  6.41479492e-02,   6.39953613e-02],
                        [  3.55834961e-02,   3.54309082e-02],
                        [  2.00195312e-02,   1.98669434e-02],
                        [  1.29699707e-02,   1.28479004e-02],
                        [  8.48388672e-03,   8.36181641e-03],
                        [  7.01904297e-03,   6.86645508e-03],
                        [  1.17492676e-02,   1.16271973e-02],
                        [  1.92260742e-02,   1.90734863e-02],
                        [  2.07519531e-02,   2.06298828e-02],
                        [  1.26342773e-02,   1.25122070e-02],
                        [ -1.15966797e-03,  -1.28173828e-03],
                        [ -1.53198242e-02,  -1.54418945e-02],
                        [ -2.72216797e-02,  -2.73437500e-02],
                        [ -3.40576172e-02,  -3.41796875e-02],
                        [ -3.18603516e-02,  -3.19824219e-02],
                        [ -2.13623047e-02,  -2.14538574e-02],
                        [ -1.05285645e-02,  -1.06506348e-02],
                        [ -7.84301758e-03,  -7.93457031e-03],
                        [ -1.26342773e-02,  -1.27258301e-02],
                        [ -1.66320801e-02,  -1.67541504e-02],
                        [ -1.56250000e-02,  -1.57165527e-02],
                        [ -1.34582520e-02,  -1.35498047e-02],
                        [ -1.40380859e-02,  -1.41296387e-02],
                        [ -1.54113770e-02,  -1.54724121e-02],
                        [ -1.19628906e-02,  -1.20544434e-02],
                        [ -6.71386719e-04,  -7.32421875e-04],
                        [  1.44042969e-02,   1.43127441e-02],
                        [  2.45056152e-02,   2.44750977e-02],
                        [  2.46582031e-02,   2.45971680e-02],
                        [  1.83715820e-02,   1.83105469e-02],
                        [  1.23596191e-02,   1.23291016e-02],
                        [  6.37817383e-03,   6.31713867e-03],
                        [ -6.74438477e-03,  -6.77490234e-03],
                        [ -3.33557129e-02,  -3.33862305e-02],
                        [ -7.30895996e-02,  -7.31201172e-02],
                        [ -1.16851807e-01,  -1.16882324e-01],
                        [ -1.53442383e-01,  -1.53442383e-01],
                        [ -1.76940918e-01,  -1.76940918e-01],
                        [ -1.86187744e-01,  -1.86218262e-01],
                        [ -1.82983398e-01,  -1.82983398e-01],
                        [ -1.70989990e-01,  -1.71020508e-01],
                        [ -1.54632568e-01,  -1.54632568e-01],
                        [ -1.38031006e-01,  -1.38061523e-01],
                        [ -1.22772217e-01,  -1.22772217e-01],
                        [ -1.08154297e-01,  -1.08123779e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -7.16247559e-02,  -7.15942383e-02],
                        [ -5.95397949e-02,  -5.95092773e-02],
                        [ -4.55932617e-02,  -4.55627441e-02],
                        [ -3.19824219e-02,  -3.19213867e-02],
                        [ -1.93176270e-02,  -1.92565918e-02],
                        [ -4.60815430e-03,  -4.57763672e-03],
                        [  1.12609863e-02,   1.12915039e-02],
                        [  2.23999023e-02,   2.24609375e-02],
                        [  2.62145996e-02,   2.62756348e-02],
                        [  2.56347656e-02,   2.56958008e-02],
                        [  2.50854492e-02,   2.51464844e-02],
                        [  2.88085938e-02,   2.88696289e-02],
                        [  3.92761230e-02,   3.93371582e-02],
                        [  5.38024902e-02,   5.38635254e-02],
                        [  6.69555664e-02,   6.70166016e-02],
                        [  7.79418945e-02,   7.80334473e-02],
                        [  9.17358398e-02,   9.18273926e-02],
                        [  1.10595703e-01,   1.10687256e-01],
                        [  1.27380371e-01,   1.27471924e-01],
                        [  1.29119873e-01,   1.29211426e-01],
                        [  1.04339600e-01,   1.04431152e-01],
                        [  4.76989746e-02,   4.77905273e-02],
                        [ -3.49426270e-02,  -3.48205566e-02],
                        [ -1.22406006e-01,  -1.22283936e-01],
                        [ -1.84234619e-01,  -1.84112549e-01],
                        [ -1.95861816e-01,  -1.95739746e-01],
                        [ -1.55426025e-01,  -1.55303955e-01],
                        [ -8.79821777e-02,  -8.78601074e-02],
                        [ -2.67639160e-02,  -2.66418457e-02],
                        [  1.17492676e-02,   1.18713379e-02],
                        [  3.44238281e-02,   3.45458984e-02],
                        [  5.44433594e-02,   5.45654297e-02],
                        [  7.10144043e-02,   7.11364746e-02],
                        [  7.29980469e-02,   7.31506348e-02],
                        [  5.92041016e-02,   5.93566895e-02],
                        [  4.26635742e-02,   4.28161621e-02],
                        [  3.68652344e-02,   3.70178223e-02],
                        [  4.53491211e-02,   4.55017090e-02],
                        [  6.25000000e-02,   6.26525879e-02],
                        [  7.87048340e-02,   7.88574219e-02],
                        [  8.67004395e-02,   8.68835449e-02],
                        [  8.58154297e-02,   8.59680176e-02],
                        [  7.93151855e-02,   7.94677734e-02],
                        [  6.96105957e-02,   6.97937012e-02],
                        [  5.88989258e-02,   5.90820312e-02],
                        [  5.00183105e-02,   5.02014160e-02],
                        [  4.29992676e-02,   4.31518555e-02],
                        [  3.46984863e-02,   3.48510742e-02],
                        [  2.47497559e-02,   2.49328613e-02],
                        [  1.79748535e-02,   1.81579590e-02],
                        [  1.90734863e-02,   1.92565918e-02],
                        [  2.71606445e-02,   2.73437500e-02],
                        [  3.79028320e-02,   3.80554199e-02],
                        [  4.74853516e-02,   4.76379395e-02],
                        [  5.22766113e-02,   5.24291992e-02],
                        [  4.83093262e-02,   4.84924316e-02],
                        [  3.37219238e-02,   3.38745117e-02],
                        [  1.13830566e-02,   1.15661621e-02],
                        [ -1.08337402e-02,  -1.06506348e-02],
                        [ -2.56347656e-02,  -2.54516602e-02],
                        [ -3.29284668e-02,  -3.27758789e-02],
                        [ -3.73229980e-02,  -3.71704102e-02],
                        [ -3.85131836e-02,  -3.83300781e-02],
                        [ -2.83203125e-02,  -2.81677246e-02],
                        [  1.40380859e-03,   1.55639648e-03],
                        [  4.79125977e-02,   4.80957031e-02],
                        [  9.35974121e-02,   9.37805176e-02],
                        [  1.17126465e-01,   1.17279053e-01],
                        [  1.10534668e-01,   1.10717773e-01],
                        [  8.56018066e-02,   8.57543945e-02],
                        [  6.25305176e-02,   6.26831055e-02],
                        [  5.00183105e-02,   5.01708984e-02],
                        [  4.08935547e-02,   4.10766602e-02],
                        [  2.98461914e-02,   2.99682617e-02],
                        [  2.12707520e-02,   2.14233398e-02],
                        [  1.91345215e-02,   1.92871094e-02],
                        [  2.10571289e-02,   2.11791992e-02],
                        [  2.14843750e-02,   2.16369629e-02],
                        [  1.68151855e-02,   1.69677734e-02],
                        [  6.59179688e-03,   6.74438477e-03],
                        [ -8.81958008e-03,  -8.66699219e-03],
                        [ -2.74353027e-02,  -2.72827148e-02],
                        [ -4.26940918e-02,  -4.25720215e-02],
                        [ -4.63867188e-02,  -4.62646484e-02],
                        [ -3.52172852e-02,  -3.51257324e-02],
                        [ -1.67846680e-02,  -1.66625977e-02],
                        [ -5.70678711e-03,  -5.58471680e-03],
                        [ -8.33129883e-03,  -8.20922852e-03],
                        [ -1.63574219e-02,  -1.62658691e-02],
                        [ -1.91040039e-02,  -1.89819336e-02],
                        [ -1.54724121e-02,  -1.53808594e-02],
                        [ -1.14746094e-02,  -1.13525391e-02],
                        [ -9.85717773e-03,  -9.76562500e-03],
                        [ -7.99560547e-03,  -7.90405273e-03],
                        [ -3.63159180e-03,  -3.54003906e-03],
                        [  1.77001953e-03,   1.86157227e-03],
                        [  6.65283203e-03,   6.74438477e-03],
                        [  1.26953125e-02,   1.27868652e-02],
                        [  2.18505859e-02,   2.19116211e-02],
                        [  3.16467285e-02,   3.17077637e-02],
                        [  3.50036621e-02,   3.50646973e-02],
                        [  2.36206055e-02,   2.37121582e-02],
                        [ -5.37109375e-03,  -5.34057617e-03],
                        [ -4.81872559e-02,  -4.81262207e-02],
                        [ -1.00494385e-01,  -1.00433350e-01],
                        [ -1.57043457e-01,  -1.56982422e-01],
                        [ -2.04132080e-01,  -2.04101562e-01],
                        [ -2.24639893e-01,  -2.24578857e-01],
                        [ -2.13897705e-01,  -2.13867188e-01],
                        [ -1.85333252e-01,  -1.85302734e-01],
                        [ -1.56585693e-01,  -1.56585693e-01],
                        [ -1.34857178e-01,  -1.34826660e-01],
                        [ -1.17401123e-01,  -1.17370605e-01],
                        [ -1.00952148e-01,  -1.00952148e-01],
                        [ -8.62426758e-02,  -8.62426758e-02],
                        [ -7.61718750e-02,  -7.61718750e-02],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -6.64978027e-02,  -6.65283203e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -4.34875488e-02,  -4.35180664e-02],
                        [ -2.70080566e-02,  -2.70385742e-02],
                        [ -1.36718750e-02,  -1.37023926e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  1.06811523e-03,   1.03759766e-03],
                        [  9.15527344e-03,   9.12475586e-03],
                        [  1.85546875e-02,   1.85241699e-02],
                        [  2.49023438e-02,   2.48413086e-02],
                        [  2.74963379e-02,   2.74353027e-02],
                        [  2.89306641e-02,   2.89001465e-02],
                        [  3.17993164e-02,   3.17382812e-02],
                        [  3.88183594e-02,   3.87573242e-02],
                        [  5.10253906e-02,   5.09643555e-02],
                        [  6.74438477e-02,   6.73522949e-02],
                        [  8.75854492e-02,   8.75244141e-02],
                        [  1.10931396e-01,   1.10839844e-01],
                        [  1.33209229e-01,   1.33117676e-01],
                        [  1.42944336e-01,   1.42852783e-01],
                        [  1.26190186e-01,   1.26098633e-01],
                        [  7.90100098e-02,   7.89184570e-02],
                        [  8.78906250e-03,   8.69750977e-03],
                        [ -7.11059570e-02,  -7.11975098e-02],
                        [ -1.38305664e-01,  -1.38427734e-01],
                        [ -1.64154053e-01,  -1.64276123e-01],
                        [ -1.33605957e-01,  -1.33697510e-01],
                        [ -6.32934570e-02,  -6.34155273e-02],
                        [  6.95800781e-03,   6.80541992e-03],
                        [  4.54711914e-02,   4.53796387e-02],
                        [  5.04455566e-02,   5.03234863e-02],
                        [  4.08630371e-02,   4.07104492e-02],
                        [  3.35998535e-02,   3.34777832e-02],
                        [  3.25622559e-02,   3.24401855e-02],
                        [  3.38134766e-02,   3.36914062e-02],
                        [  3.46374512e-02,   3.45153809e-02],
                        [  3.70178223e-02,   3.68957520e-02],
                        [  4.31518555e-02,   4.30297852e-02],
                        [  5.20629883e-02,   5.19104004e-02],
                        [  6.23168945e-02,   6.21643066e-02],
                        [  7.26928711e-02,   7.25402832e-02],
                        [  7.79724121e-02,   7.78198242e-02],
                        [  7.16247559e-02,   7.14416504e-02],
                        [  5.53283691e-02,   5.52062988e-02],
                        [  4.14733887e-02,   4.13208008e-02],
                        [  4.02832031e-02,   4.01306152e-02],
                        [  4.82788086e-02,   4.80957031e-02],
                        [  5.41992188e-02,   5.40466309e-02],
                        [  5.20019531e-02,   5.18493652e-02],
                        [  4.41284180e-02,   4.39453125e-02],
                        [  3.69567871e-02,   3.68041992e-02],
                        [  3.48815918e-02,   3.47290039e-02],
                        [  3.66210938e-02,   3.64685059e-02],
                        [  3.78112793e-02,   3.76586914e-02],
                        [  3.56445312e-02,   3.54614258e-02],
                        [  2.91137695e-02,   2.89611816e-02],
                        [  1.69677734e-02,   1.67846680e-02],
                        [ -4.88281250e-04,  -6.71386719e-04],
                        [ -1.90124512e-02,  -1.91650391e-02],
                        [ -3.43017578e-02,  -3.44543457e-02],
                        [ -4.45861816e-02,  -4.47692871e-02],
                        [ -4.75463867e-02,  -4.76989746e-02],
                        [ -4.04052734e-02,  -4.05578613e-02],
                        [ -2.20947266e-02,  -2.22778320e-02],
                        [  6.31713867e-03,   6.16455078e-03],
                        [  4.06799316e-02,   4.05273438e-02],
                        [  7.24792480e-02,   7.22961426e-02],
                        [  9.15527344e-02,   9.14001465e-02],
                        [  9.29870605e-02,   9.28344727e-02],
                        [  8.18176270e-02,   8.16650391e-02],
                        [  6.78710938e-02,   6.77185059e-02],
                        [  5.68542480e-02,   5.66711426e-02],
                        [  4.83398438e-02,   4.81872559e-02],
                        [  3.99169922e-02,   3.97644043e-02],
                        [  3.07617188e-02,   3.06091309e-02],
                        [  2.23999023e-02,   2.22167969e-02],
                        [  1.49536133e-02,   1.48010254e-02],
                        [  5.85937500e-03,   5.73730469e-03],
                        [ -4.97436523e-03,  -5.12695312e-03],
                        [ -1.42517090e-02,  -1.44042969e-02],
                        [ -2.07519531e-02,  -2.09045410e-02],
                        [ -2.62451172e-02,  -2.63977051e-02],
                        [ -2.99377441e-02,  -3.00598145e-02],
                        [ -2.69470215e-02,  -2.70690918e-02],
                        [ -1.55639648e-02,  -1.56860352e-02],
                        [ -2.68554688e-03,  -2.80761719e-03],
                        [  3.41796875e-03,   3.26538086e-03],
                        [  2.25830078e-03,   2.13623047e-03],
                        [ -1.86157227e-03,  -1.98364258e-03],
                        [ -5.49316406e-03,  -5.61523438e-03],
                        [ -6.31713867e-03,  -6.43920898e-03],
                        [ -4.11987305e-03,  -4.21142578e-03],
                        [ -3.96728516e-04,  -5.18798828e-04],
                        [  3.23486328e-03,   3.11279297e-03],
                        [  6.83593750e-03,   6.74438477e-03],
                        [  1.37023926e-02,   1.35803223e-02],
                        [  2.66723633e-02,   2.65502930e-02],
                        [  4.42810059e-02,   4.42199707e-02],
                        [  6.22863770e-02,   6.21948242e-02],
                        [  7.37609863e-02,   7.36694336e-02],
                        [  6.76269531e-02,   6.75354004e-02],
                        [  3.17382812e-02,   3.16772461e-02],
                        [ -3.69262695e-02,  -3.69873047e-02],
                        [ -1.24481201e-01,  -1.24572754e-01],
                        [ -2.06604004e-01,  -2.06665039e-01],
                        [ -2.60772705e-01,  -2.60833740e-01],
                        [ -2.72796631e-01,  -2.72857666e-01],
                        [ -2.43469238e-01,  -2.43530273e-01],
                        [ -1.91864014e-01,  -1.91925049e-01],
                        [ -1.44744873e-01,  -1.44805908e-01],
                        [ -1.18377686e-01,  -1.18438721e-01],
                        [ -1.10168457e-01,  -1.10198975e-01],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -1.02691650e-01,  -1.02722168e-01],
                        [ -9.51843262e-02,  -9.52148438e-02],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -7.12585449e-02,  -7.12890625e-02],
                        [ -5.43518066e-02,  -5.43823242e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  5.98144531e-03,   6.01196289e-03],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  1.94702148e-02,   1.95007324e-02],
                        [  1.50756836e-02,   1.51062012e-02],
                        [  8.05664062e-03,   8.08715820e-03],
                        [  2.16674805e-03,   2.19726562e-03],
                        [ -5.18798828e-04,  -4.88281250e-04],
                        [  1.25122070e-03,   1.31225586e-03],
                        [  9.52148438e-03,   9.55200195e-03],
                        [  2.40783691e-02,   2.41394043e-02],
                        [  4.07409668e-02,   4.08020020e-02],
                        [  5.92956543e-02,   5.93566895e-02],
                        [  8.46862793e-02,   8.47473145e-02],
                        [  1.13922119e-01,   1.13983154e-01],
                        [  1.34216309e-01,   1.34277344e-01],
                        [  1.36962891e-01,   1.37054443e-01],
                        [  1.23565674e-01,   1.23626709e-01],
                        [  9.53369141e-02,   9.54284668e-02],
                        [  4.82177734e-02,   4.83093262e-02],
                        [ -1.58386230e-02,  -1.57470703e-02],
                        [ -7.86743164e-02,  -7.85522461e-02],
                        [ -1.13708496e-01,  -1.13616943e-01],
                        [ -1.03179932e-01,  -1.03088379e-01],
                        [ -5.34667969e-02,  -5.33752441e-02],
                        [  4.97436523e-03,   5.09643555e-03],
                        [  3.96118164e-02,   3.97033691e-02],
                        [  3.96118164e-02,   3.97338867e-02],
                        [  2.13623047e-02,   2.14843750e-02],
                        [  1.10473633e-02,   1.11694336e-02],
                        [  1.78527832e-02,   1.79748535e-02],
                        [  2.81066895e-02,   2.82592773e-02],
                        [  2.78930664e-02,   2.80456543e-02],
                        [  2.10571289e-02,   2.11791992e-02],
                        [  2.07214355e-02,   2.08435059e-02],
                        [  3.06396484e-02,   3.07922363e-02],
                        [  4.35180664e-02,   4.36401367e-02],
                        [  5.26428223e-02,   5.27954102e-02],
                        [  5.53283691e-02,   5.54809570e-02],
                        [  5.06896973e-02,   5.08422852e-02],
                        [  4.16870117e-02,   4.18090820e-02],
                        [  3.47290039e-02,   3.48815918e-02],
                        [  3.54003906e-02,   3.55529785e-02],
                        [  4.27551270e-02,   4.29077148e-02],
                        [  4.79736328e-02,   4.81262207e-02],
                        [  4.36096191e-02,   4.37622070e-02],
                        [  3.33557129e-02,   3.35083008e-02],
                        [  2.76184082e-02,   2.77709961e-02],
                        [  3.02429199e-02,   3.04260254e-02],
                        [  3.48510742e-02,   3.50036621e-02],
                        [  3.36914062e-02,   3.38439941e-02],
                        [  2.55432129e-02,   2.57263184e-02],
                        [  1.34277344e-02,   1.36108398e-02],
                        [ -7.32421875e-04,  -5.79833984e-04],
                        [ -1.61132812e-02,  -1.59606934e-02],
                        [ -3.07312012e-02,  -3.05480957e-02],
                        [ -4.22363281e-02,  -4.20837402e-02],
                        [ -4.97131348e-02,  -4.95605469e-02],
                        [ -5.21545410e-02,  -5.20019531e-02],
                        [ -4.53491211e-02,  -4.51660156e-02],
                        [ -2.19116211e-02,  -2.17590332e-02],
                        [  2.02636719e-02,   2.04162598e-02],
                        [  7.09533691e-02,   7.11059570e-02],
                        [  1.12274170e-01,   1.12426758e-01],
                        [  1.28814697e-01,   1.28997803e-01],
                        [  1.15722656e-01,   1.15875244e-01],
                        [  8.29772949e-02,   8.31604004e-02],
                        [  4.91943359e-02,   4.93774414e-02],
                        [  2.68859863e-02,   2.70385742e-02],
                        [  1.50146484e-02,   1.51977539e-02],
                        [  6.19506836e-03,   6.34765625e-03],
                        [ -8.23974609e-04,  -6.71386719e-04],
                        [ -2.44140625e-04,  -9.15527344e-05],
                        [  9.55200195e-03,   9.70458984e-03],
                        [  2.13012695e-02,   2.14538574e-02],
                        [  2.52075195e-02,   2.53906250e-02],
                        [  1.65405273e-02,   1.66931152e-02],
                        [ -1.09863281e-03,  -9.46044922e-04],
                        [ -1.87988281e-02,  -1.86767578e-02],
                        [ -2.85644531e-02,  -2.84118652e-02],
                        [ -2.79846191e-02,  -2.78320312e-02],
                        [ -2.12097168e-02,  -2.10571289e-02],
                        [ -1.38549805e-02,  -1.37329102e-02],
                        [ -6.89697266e-03,  -6.77490234e-03],
                        [  2.47192383e-03,   2.62451172e-03],
                        [  1.40686035e-02,   1.41906738e-02],
                        [  2.26135254e-02,   2.27355957e-02],
                        [  2.36511230e-02,   2.37731934e-02],
                        [  1.88598633e-02,   1.89819336e-02],
                        [  1.40380859e-02,   1.41601562e-02],
                        [  1.43127441e-02,   1.44348145e-02],
                        [  2.07519531e-02,   2.08740234e-02],
                        [  3.04260254e-02,   3.05175781e-02],
                        [  4.06494141e-02,   4.07714844e-02],
                        [  5.19714355e-02,   5.20629883e-02],
                        [  6.20422363e-02,   6.21643066e-02],
                        [  5.92956543e-02,   5.94177246e-02],
                        [  2.90527344e-02,   2.91442871e-02],
                        [ -3.22265625e-02,  -3.21350098e-02],
                        [ -1.11114502e-01,  -1.11022949e-01],
                        [ -1.84753418e-01,  -1.84692383e-01],
                        [ -2.33398438e-01,  -2.33306885e-01],
                        [ -2.47741699e-01,  -2.47680664e-01],
                        [ -2.30560303e-01,  -2.30499268e-01],
                        [ -1.94824219e-01,  -1.94732666e-01],
                        [ -1.56768799e-01,  -1.56707764e-01],
                        [ -1.27746582e-01,  -1.27685547e-01],
                        [ -1.10565186e-01,  -1.10504150e-01],
                        [ -1.00585938e-01,  -1.00555420e-01],
                        [ -9.27124023e-02,  -9.26513672e-02],
                        [ -8.58459473e-02,  -8.58154297e-02],
                        [ -7.98034668e-02,  -7.97729492e-02],
                        [ -7.24487305e-02,  -7.23876953e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -2.47192383e-02,  -2.46887207e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  3.06091309e-02,   3.06396484e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  1.38549805e-02,   1.38244629e-02],
                        [  5.27954102e-03,   5.24902344e-03],
                        [ -3.96728516e-04,  -4.27246094e-04],
                        [ -1.52587891e-04,  -1.83105469e-04],
                        [  8.27026367e-03,   8.23974609e-03],
                        [  2.31018066e-02,   2.30712891e-02],
                        [  4.15039062e-02,   4.14733887e-02],
                        [  6.24694824e-02,   6.24389648e-02],
                        [  8.33740234e-02,   8.33129883e-02],
                        [  9.94567871e-02,   9.93957520e-02],
                        [  1.10321045e-01,   1.10260010e-01],
                        [  1.19476318e-01,   1.19415283e-01],
                        [  1.23931885e-01,   1.23901367e-01],
                        [  1.13220215e-01,   1.13159180e-01],
                        [  7.98034668e-02,   7.97119141e-02],
                        [  2.60314941e-02,   2.59399414e-02],
                        [ -3.47595215e-02,  -3.48205566e-02],
                        [ -7.93762207e-02,  -7.94677734e-02],
                        [ -8.56933594e-02,  -8.57849121e-02],
                        [ -5.30395508e-02,  -5.31005859e-02],
                        [ -7.87353516e-03,  -7.96508789e-03],
                        [  1.97753906e-02,   1.96838379e-02],
                        [  2.35900879e-02,   2.34985352e-02],
                        [  2.02026367e-02,   2.01110840e-02],
                        [  2.46887207e-02,   2.45666504e-02],
                        [  3.32946777e-02,   3.32031250e-02],
                        [  3.44543457e-02,   3.43322754e-02],
                        [  2.70690918e-02,   2.69470215e-02],
                        [  1.89208984e-02,   1.87988281e-02],
                        [  1.49536133e-02,   1.48315430e-02],
                        [  1.52587891e-02,   1.51367188e-02],
                        [  1.97448730e-02,   1.96228027e-02],
                        [  2.89611816e-02,   2.88391113e-02],
                        [  4.15039062e-02,   4.13818359e-02],
                        [  5.47790527e-02,   5.46264648e-02],
                        [  6.47583008e-02,   6.46057129e-02],
                        [  6.51855469e-02,   6.50634766e-02],
                        [  5.35278320e-02,   5.33752441e-02],
                        [  3.44543457e-02,   3.43017578e-02],
                        [  1.58691406e-02,   1.57470703e-02],
                        [  6.10351562e-03,   5.92041016e-03],
                        [  9.67407227e-03,   9.52148438e-03],
                        [  2.19726562e-02,   2.18200684e-02],
                        [  3.23181152e-02,   3.21655273e-02],
                        [  3.33251953e-02,   3.31726074e-02],
                        [  2.57263184e-02,   2.55737305e-02],
                        [  1.49230957e-02,   1.47705078e-02],
                        [  5.21850586e-03,   5.06591797e-03],
                        [ -2.47192383e-03,  -2.62451172e-03],
                        [ -1.02233887e-02,  -1.03759766e-02],
                        [ -2.05078125e-02,  -2.06604004e-02],
                        [ -3.14331055e-02,  -3.15856934e-02],
                        [ -3.81469727e-02,  -3.82995605e-02],
                        [ -3.56140137e-02,  -3.57666016e-02],
                        [ -1.79443359e-02,  -1.80969238e-02],
                        [  1.74865723e-02,   1.73339844e-02],
                        [  6.28051758e-02,   6.26220703e-02],
                        [  1.00830078e-01,   1.00646973e-01],
                        [  1.16485596e-01,   1.16333008e-01],
                        [  1.07269287e-01,   1.07116699e-01],
                        [  8.23974609e-02,   8.22448730e-02],
                        [  5.48400879e-02,   5.46569824e-02],
                        [  3.35083008e-02,   3.33557129e-02],
                        [  2.06604004e-02,   2.05078125e-02],
                        [  1.44348145e-02,   1.42517090e-02],
                        [  1.33666992e-02,   1.32141113e-02],
                        [  1.75170898e-02,   1.73645020e-02],
                        [  2.51464844e-02,   2.49938965e-02],
                        [  2.92663574e-02,   2.91137695e-02],
                        [  2.15454102e-02,   2.13928223e-02],
                        [  2.53295898e-03,   2.38037109e-03],
                        [ -1.71203613e-02,  -1.72729492e-02],
                        [ -2.79235840e-02,  -2.80456543e-02],
                        [ -3.07006836e-02,  -3.08227539e-02],
                        [ -3.11279297e-02,  -3.12805176e-02],
                        [ -3.05480957e-02,  -3.06701660e-02],
                        [ -2.64587402e-02,  -2.65808105e-02],
                        [ -1.81884766e-02,  -1.83410645e-02],
                        [ -7.87353516e-03,  -8.02612305e-03],
                        [  3.08227539e-03,   2.92968750e-03],
                        [  1.44348145e-02,   1.43127441e-02],
                        [  2.37426758e-02,   2.35900879e-02],
                        [  2.73437500e-02,   2.72216797e-02],
                        [  2.61840820e-02,   2.60620117e-02],
                        [  2.46582031e-02,   2.45361328e-02],
                        [  2.50244141e-02,   2.49023438e-02],
                        [  2.61840820e-02,   2.60620117e-02],
                        [  2.87780762e-02,   2.86560059e-02],
                        [  3.56445312e-02,   3.55224609e-02],
                        [  4.25720215e-02,   4.24499512e-02],
                        [  3.67126465e-02,   3.66210938e-02],
                        [  9.61303711e-03,   9.49096680e-03],
                        [ -3.70483398e-02,  -3.71704102e-02],
                        [ -9.85107422e-02,  -9.86022949e-02],
                        [ -1.66839600e-01,  -1.66931152e-01],
                        [ -2.24639893e-01,  -2.24731445e-01],
                        [ -2.51037598e-01,  -2.51129150e-01],
                        [ -2.38739014e-01,  -2.38830566e-01],
                        [ -2.00958252e-01,  -2.01049805e-01],
                        [ -1.59545898e-01,  -1.59637451e-01],
                        [ -1.29974365e-01,  -1.30065918e-01],
                        [ -1.15692139e-01,  -1.15753174e-01],
                        [ -1.09985352e-01,  -1.10076904e-01],
                        [ -1.03302002e-01,  -1.03363037e-01],
                        [ -9.14001465e-02,  -9.14306641e-02],
                        [ -7.67517090e-02,  -7.68127441e-02],
                        [ -6.34765625e-02,  -6.35375977e-02],
                        [ -5.41687012e-02,  -5.41992188e-02],
                        [ -4.76989746e-02,  -4.77294922e-02],
                        [ -3.85437012e-02,  -3.86047363e-02],
                        [ -2.34069824e-02,  -2.34375000e-02],
                        [ -5.46264648e-03,  -5.49316406e-03],
                        [  1.04370117e-02,   1.04064941e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  1.93786621e-02,   1.93481445e-02],
                        [  9.67407227e-03,   9.64355469e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  4.08935547e-03,   4.11987305e-03],
                        [  2.22778320e-02,   2.23083496e-02],
                        [  4.13818359e-02,   4.14123535e-02],
                        [  5.75866699e-02,   5.76171875e-02],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  9.32617188e-02,   9.32922363e-02],
                        [  1.15783691e-01,   1.15844727e-01],
                        [  1.35498047e-01,   1.35528564e-01],
                        [  1.44744873e-01,   1.44775391e-01],
                        [  1.36474609e-01,   1.36535645e-01],
                        [  1.05133057e-01,   1.05194092e-01],
                        [  5.15136719e-02,   5.15747070e-02],
                        [ -9.79614258e-03,  -9.73510742e-03],
                        [ -5.52368164e-02,  -5.51452637e-02],
                        [ -6.85729980e-02,  -6.85424805e-02],
                        [ -5.16662598e-02,  -5.16052246e-02],
                        [ -2.24609375e-02,  -2.23693848e-02],
                        [ -1.15966797e-03,  -1.06811523e-03],
                        [  5.76782227e-03,   5.82885742e-03],
                        [  6.25610352e-03,   6.37817383e-03],
                        [  9.06372070e-03,   9.15527344e-03],
                        [  1.21765137e-02,   1.22375488e-02],
                        [  7.44628906e-03,   7.53784180e-03],
                        [ -4.51660156e-03,  -4.39453125e-03],
                        [ -1.16577148e-02,  -1.15661621e-02],
                        [ -3.78417969e-03,  -3.69262695e-03],
                        [  1.84020996e-02,   1.84936523e-02],
                        [  4.53796387e-02,   4.54711914e-02],
                        [  6.51245117e-02,   6.52160645e-02],
                        [  7.07397461e-02,   7.08312988e-02],
                        [  6.55212402e-02,   6.56433105e-02],
                        [  5.81665039e-02,   5.82885742e-02],
                        [  5.20324707e-02,   5.21545410e-02],
                        [  4.42504883e-02,   4.44030762e-02],
                        [  3.37524414e-02,   3.39050293e-02],
                        [  2.32543945e-02,   2.33459473e-02],
                        [  1.36413574e-02,   1.37634277e-02],
                        [  3.14331055e-03,   3.26538086e-03],
                        [ -6.07299805e-03,  -5.95092773e-03],
                        [ -6.68334961e-03,  -6.56127930e-03],
                        [  2.83813477e-03,   2.96020508e-03],
                        [  1.39465332e-02,   1.40686035e-02],
                        [  1.73645020e-02,   1.75170898e-02],
                        [  1.08337402e-02,   1.09863281e-02],
                        [ -2.28881836e-03,  -2.16674805e-03],
                        [ -1.94396973e-02,  -1.92871094e-02],
                        [ -3.92761230e-02,  -3.91235352e-02],
                        [ -5.55419922e-02,  -5.54199219e-02],
                        [ -5.80444336e-02,  -5.78918457e-02],
                        [ -4.08630371e-02,  -4.07104492e-02],
                        [ -4.33349609e-03,  -4.18090820e-03],
                        [  4.54101562e-02,   4.55627441e-02],
                        [  9.39636230e-02,   9.41162109e-02],
                        [  1.20941162e-01,   1.21093750e-01],
                        [  1.13342285e-01,   1.13494873e-01],
                        [  7.99865723e-02,   8.01391602e-02],
                        [  4.60510254e-02,   4.61730957e-02],
                        [  2.96325684e-02,   2.97851562e-02],
                        [  2.94189453e-02,   2.95715332e-02],
                        [  3.39660645e-02,   3.41186523e-02],
                        [  3.45764160e-02,   3.47290039e-02],
                        [  2.83203125e-02,   2.84729004e-02],
                        [  1.80053711e-02,   1.81274414e-02],
                        [  1.10473633e-02,   1.11694336e-02],
                        [  1.01623535e-02,   1.03149414e-02],
                        [  7.20214844e-03,   7.35473633e-03],
                        [ -5.09643555e-03,  -4.94384766e-03],
                        [ -2.06604004e-02,  -2.05078125e-02],
                        [ -2.78015137e-02,  -2.76489258e-02],
                        [ -2.50854492e-02,  -2.49328613e-02],
                        [ -2.08129883e-02,  -2.06909180e-02],
                        [ -1.82495117e-02,  -1.80969238e-02],
                        [ -1.34582520e-02,  -1.33056641e-02],
                        [ -5.52368164e-03,  -5.37109375e-03],
                        [  3.11279297e-03,   3.23486328e-03],
                        [  1.16577148e-02,   1.18103027e-02],
                        [  1.96533203e-02,   1.97753906e-02],
                        [  2.45361328e-02,   2.46582031e-02],
                        [  2.52990723e-02,   2.54516602e-02],
                        [  2.79235840e-02,   2.80456543e-02],
                        [  4.15344238e-02,   4.16259766e-02],
                        [  6.55517578e-02,   6.56738281e-02],
                        [  8.62426758e-02,   8.63647461e-02],
                        [  8.95690918e-02,   8.96911621e-02],
                        [  7.25402832e-02,   7.26318359e-02],
                        [  3.87573242e-02,   3.88793945e-02],
                        [ -9.73510742e-03,  -9.64355469e-03],
                        [ -7.12585449e-02,  -7.11364746e-02],
                        [ -1.37969971e-01,  -1.37847900e-01],
                        [ -1.96685791e-01,  -1.96594238e-01],
                        [ -2.35137939e-01,  -2.35046387e-01],
                        [ -2.46612549e-01,  -2.46520996e-01],
                        [ -2.31597900e-01,  -2.31536865e-01],
                        [ -1.99127197e-01,  -1.99035645e-01],
                        [ -1.63299561e-01,  -1.63208008e-01],
                        [ -1.33850098e-01,  -1.33758545e-01],
                        [ -1.12396240e-01,  -1.12335205e-01],
                        [ -9.60388184e-02,  -9.59472656e-02],
                        [ -8.09631348e-02,  -8.08715820e-02],
                        [ -6.64672852e-02,  -6.63757324e-02],
                        [ -5.56030273e-02,  -5.55419922e-02],
                        [ -4.91943359e-02,  -4.91333008e-02],
                        [ -4.29077148e-02,  -4.28771973e-02],
                        [ -3.33251953e-02,  -3.32946777e-02],
                        [ -2.26745605e-02,  -2.26135254e-02],
                        [ -1.48925781e-02,  -1.48620605e-02],
                        [ -9.55200195e-03,  -9.52148438e-03],
                        [ -3.81469727e-03,  -3.78417969e-03],
                        [  2.10571289e-03,   2.16674805e-03],
                        [  7.01904297e-03,   7.04956055e-03],
                        [  1.21154785e-02,   1.21459961e-02],
                        [  1.71508789e-02,   1.71813965e-02],
                        [  1.75170898e-02,   1.75476074e-02],
                        [  1.09863281e-02,   1.10168457e-02],
                        [  2.59399414e-03,   2.62451172e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  2.49328613e-02,   2.49023438e-02],
                        [  4.06799316e-02,   4.06494141e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  9.34143066e-02,   9.33837891e-02],
                        [  1.36871338e-01,   1.36840820e-01],
                        [  1.83685303e-01,   1.83654785e-01],
                        [  2.19848633e-01,   2.19818115e-01],
                        [  2.30590820e-01,   2.30560303e-01],
                        [  2.02331543e-01,   2.02301025e-01],
                        [  1.29608154e-01,   1.29577637e-01],
                        [  2.79235840e-02,   2.78930664e-02],
                        [ -6.43920898e-02,  -6.44531250e-02],
                        [ -1.09436035e-01,  -1.09466553e-01],
                        [ -9.92736816e-02,  -9.93347168e-02],
                        [ -6.12182617e-02,  -6.12487793e-02],
                        [ -3.19213867e-02,  -3.19824219e-02],
                        [ -2.72216797e-02,  -2.72827148e-02],
                        [ -3.53698730e-02,  -3.54309082e-02],
                        [ -3.61938477e-02,  -3.62548828e-02],
                        [ -2.36206055e-02,  -2.36816406e-02],
                        [ -8.20922852e-03,  -8.27026367e-03],
                        [ -2.74658203e-04,  -3.35693359e-04],
                        [  2.01416016e-03,   1.92260742e-03],
                        [  6.13403320e-03,   6.04248047e-03],
                        [  1.43432617e-02,   1.42517090e-02],
                        [  2.39562988e-02,   2.38647461e-02],
                        [  3.46679688e-02,   3.45764160e-02],
                        [  4.74548340e-02,   4.73632812e-02],
                        [  5.87463379e-02,   5.86547852e-02],
                        [  6.34460449e-02,   6.33544922e-02],
                        [  6.02416992e-02,   6.01501465e-02],
                        [  5.04150391e-02,   5.03234863e-02],
                        [  3.72924805e-02,   3.71704102e-02],
                        [  2.56042480e-02,   2.55126953e-02],
                        [  1.79138184e-02,   1.77917480e-02],
                        [  1.22070312e-02,   1.20849609e-02],
                        [  6.28662109e-03,   6.19506836e-03],
                        [  1.98364258e-03,   1.86157227e-03],
                        [  8.54492188e-04,   7.32421875e-04],
                        [ -1.22070312e-03,  -1.31225586e-03],
                        [ -8.54492188e-03,  -8.63647461e-03],
                        [ -1.91650391e-02,  -1.92871094e-02],
                        [ -2.89306641e-02,  -2.90527344e-02],
                        [ -3.73840332e-02,  -3.75061035e-02],
                        [ -4.47692871e-02,  -4.48913574e-02],
                        [ -4.66003418e-02,  -4.67224121e-02],
                        [ -3.63769531e-02,  -3.64990234e-02],
                        [ -1.16271973e-02,  -1.17187500e-02],
                        [  2.55737305e-02,   2.54516602e-02],
                        [  6.86340332e-02,   6.85119629e-02],
                        [  1.04125977e-01,   1.04003906e-01],
                        [  1.16424561e-01,   1.16302490e-01],
                        [  1.02233887e-01,   1.02111816e-01],
                        [  7.75756836e-02,   7.74841309e-02],
                        [  6.20727539e-02,   6.19506836e-02],
                        [  5.84106445e-02,   5.82885742e-02],
                        [  5.46875000e-02,   5.45349121e-02],
                        [  4.22363281e-02,   4.21142578e-02],
                        [  2.55737305e-02,   2.54516602e-02],
                        [  1.42211914e-02,   1.40991211e-02],
                        [  9.39941406e-03,   9.30786133e-03],
                        [  4.30297852e-03,   4.18090820e-03],
                        [ -5.49316406e-03,  -5.61523438e-03],
                        [ -1.79748535e-02,  -1.80969238e-02],
                        [ -2.79541016e-02,  -2.80761719e-02],
                        [ -3.10974121e-02,  -3.11889648e-02],
                        [ -2.67944336e-02,  -2.69165039e-02],
                        [ -1.74865723e-02,  -1.75781250e-02],
                        [ -4.73022461e-03,  -4.85229492e-03],
                        [  1.05285645e-02,   1.04064941e-02],
                        [  2.35290527e-02,   2.34375000e-02],
                        [  2.75573730e-02,   2.74353027e-02],
                        [  2.33764648e-02,   2.32543945e-02],
                        [  2.01721191e-02,   2.00805664e-02],
                        [  2.43530273e-02,   2.42309570e-02],
                        [  3.46984863e-02,   3.46069336e-02],
                        [  4.81567383e-02,   4.80651855e-02],
                        [  6.35070801e-02,   6.34155273e-02],
                        [  7.92846680e-02,   7.91625977e-02],
                        [  9.16442871e-02,   9.15527344e-02],
                        [  9.51232910e-02,   9.50317383e-02],
                        [  8.25500488e-02,   8.24584961e-02],
                        [  4.58068848e-02,   4.57153320e-02],
                        [ -1.88293457e-02,  -1.89208984e-02],
                        [ -1.04858398e-01,  -1.04949951e-01],
                        [ -1.94763184e-01,  -1.94854736e-01],
                        [ -2.64587402e-01,  -2.64678955e-01],
                        [ -2.92022705e-01,  -2.92114258e-01],
                        [ -2.68890381e-01,  -2.68981934e-01],
                        [ -2.12951660e-01,  -2.13012695e-01],
                        [ -1.59820557e-01,  -1.59881592e-01],
                        [ -1.32598877e-01,  -1.32659912e-01],
                        [ -1.25610352e-01,  -1.25671387e-01],
                        [ -1.20941162e-01,  -1.21002197e-01],
                        [ -1.09802246e-01,  -1.09863281e-01],
                        [ -9.39941406e-02,  -9.40551758e-02],
                        [ -7.70874023e-02,  -7.71484375e-02],
                        [ -6.15234375e-02,  -6.15844727e-02],
                        [ -4.92248535e-02,  -4.92858887e-02],
                        [ -3.86962891e-02,  -3.87268066e-02],
                        [ -2.58483887e-02,  -2.59094238e-02],
                        [ -1.07421875e-02,  -1.08032227e-02],
                        [  1.15966797e-03,   1.12915039e-03],
                        [  5.06591797e-03,   5.00488281e-03],
                        [  1.86157227e-03,   1.83105469e-03],
                        [ -3.66210938e-03,  -3.69262695e-03],
                        [ -7.81250000e-03,  -7.87353516e-03],
                        [ -8.42285156e-03,  -8.45336914e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [  2.31933594e-03,   2.28881836e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -2.34985352e-03,  -2.38037109e-03],
                        [ -1.03149414e-02,  -1.03454590e-02],
                        [ -1.56555176e-02,  -1.56860352e-02],
                        [ -1.79138184e-02,  -1.79443359e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.08917236e-01,   1.08917236e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  2.12829590e-01,   2.12829590e-01],
                        [  2.66784668e-01,   2.66815186e-01],
                        [  2.91534424e-01,   2.91534424e-01],
                        [  2.65380859e-01,   2.65380859e-01],
                        [  1.81274414e-01,   1.81304932e-01],
                        [  5.82275391e-02,   5.82275391e-02],
                        [ -6.12182617e-02,  -6.11877441e-02],
                        [ -1.36199951e-01,  -1.36169434e-01],
                        [ -1.53076172e-01,  -1.53045654e-01],
                        [ -1.26617432e-01,  -1.26586914e-01],
                        [ -8.37097168e-02,  -8.36791992e-02],
                        [ -4.58984375e-02,  -4.58679199e-02],
                        [ -2.07824707e-02,  -2.07519531e-02],
                        [ -6.34765625e-03,  -6.28662109e-03],
                        [ -1.52587891e-03,  -1.46484375e-03],
                        [ -9.12475586e-03,  -9.06372070e-03],
                        [ -2.73437500e-02,  -2.73132324e-02],
                        [ -4.35791016e-02,  -4.35485840e-02],
                        [ -4.35791016e-02,  -4.35485840e-02],
                        [ -2.68249512e-02,  -2.67639160e-02],
                        [ -4.76074219e-03,  -4.69970703e-03],
                        [  1.54113770e-02,   1.54724121e-02],
                        [  3.53393555e-02,   3.54003906e-02],
                        [  5.49621582e-02,   5.50231934e-02],
                        [  6.78710938e-02,   6.79321289e-02],
                        [  6.98852539e-02,   6.99462891e-02],
                        [  6.38732910e-02,   6.39343262e-02],
                        [  5.45043945e-02,   5.45654297e-02],
                        [  4.38842773e-02,   4.39758301e-02],
                        [  3.22570801e-02,   3.23181152e-02],
                        [  1.72424316e-02,   1.73034668e-02],
                        [ -2.59399414e-03,  -2.53295898e-03],
                        [ -2.15454102e-02,  -2.14843750e-02],
                        [ -3.05480957e-02,  -3.04870605e-02],
                        [ -2.75878906e-02,  -2.75268555e-02],
                        [ -1.94396973e-02,  -1.93786621e-02],
                        [ -1.46179199e-02,  -1.45263672e-02],
                        [ -1.75781250e-02,  -1.75170898e-02],
                        [ -2.69165039e-02,  -2.68554688e-02],
                        [ -3.71093750e-02,  -3.70483398e-02],
                        [ -4.24194336e-02,  -4.23278809e-02],
                        [ -3.61938477e-02,  -3.61328125e-02],
                        [ -1.09863281e-02,  -1.09252930e-02],
                        [  3.30810547e-02,   3.31726074e-02],
                        [  8.12683105e-02,   8.13293457e-02],
                        [  1.12213135e-01,   1.12304688e-01],
                        [  1.14410400e-01,   1.14471436e-01],
                        [  9.42382812e-02,   9.43298340e-02],
                        [  6.90307617e-02,   6.91223145e-02],
                        [  5.22766113e-02,   5.23681641e-02],
                        [  4.40368652e-02,   4.41284180e-02],
                        [  3.55224609e-02,   3.56140137e-02],
                        [  2.31323242e-02,   2.32238770e-02],
                        [  1.27258301e-02,   1.28173828e-02],
                        [  1.06506348e-02,   1.07116699e-02],
                        [  1.58691406e-02,   1.59606934e-02],
                        [  1.98364258e-02,   1.99279785e-02],
                        [  1.21154785e-02,   1.22070312e-02],
                        [ -8.97216797e-03,  -8.88061523e-03],
                        [ -3.25622559e-02,  -3.24707031e-02],
                        [ -4.49829102e-02,  -4.48913574e-02],
                        [ -4.08935547e-02,  -4.08325195e-02],
                        [ -2.37121582e-02,  -2.36206055e-02],
                        [ -1.15966797e-03,  -1.06811523e-03],
                        [  1.72729492e-02,   1.73339844e-02],
                        [  2.55126953e-02,   2.55737305e-02],
                        [  2.59399414e-02,   2.60314941e-02],
                        [  2.58483887e-02,   2.59399414e-02],
                        [  3.09448242e-02,   3.10058594e-02],
                        [  4.33654785e-02,   4.34265137e-02],
                        [  6.20422363e-02,   6.21032715e-02],
                        [  8.38012695e-02,   8.38623047e-02],
                        [  1.05041504e-01,   1.05102539e-01],
                        [  1.20513916e-01,   1.20574951e-01],
                        [  1.21154785e-01,   1.21215820e-01],
                        [  9.81140137e-02,   9.81750488e-02],
                        [  5.10253906e-02,   5.11169434e-02],
                        [ -1.43432617e-02,  -1.42517090e-02],
                        [ -9.52148438e-02,  -9.51538086e-02],
                        [ -1.84692383e-01,  -1.84600830e-01],
                        [ -2.59521484e-01,  -2.59460449e-01],
                        [ -2.92083740e-01,  -2.92022705e-01],
                        [ -2.74505615e-01,  -2.74444580e-01],
                        [ -2.25158691e-01,  -2.25097656e-01],
                        [ -1.73461914e-01,  -1.73400879e-01],
                        [ -1.40258789e-01,  -1.40197754e-01],
                        [ -1.26983643e-01,  -1.26922607e-01],
                        [ -1.21582031e-01,  -1.21551514e-01],
                        [ -1.14044189e-01,  -1.14013672e-01],
                        [ -1.03363037e-01,  -1.03332520e-01],
                        [ -9.06677246e-02,  -9.06372070e-02],
                        [ -7.47680664e-02,  -7.47375488e-02],
                        [ -5.60913086e-02,  -5.60302734e-02],
                        [ -3.72924805e-02,  -3.72314453e-02],
                        [ -1.95617676e-02,  -1.95312500e-02],
                        [ -4.30297852e-03,  -4.27246094e-03],
                        [  4.82177734e-03,   4.85229492e-03],
                        [  7.23266602e-03,   7.26318359e-03],
                        [  7.35473633e-03,   7.38525391e-03],
                        [  7.17163086e-03,   7.23266602e-03],
                        [  5.21850586e-03,   5.24902344e-03],
                        [  2.53295898e-03,   2.56347656e-03],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -3.44848633e-03,  -3.41796875e-03],
                        [ -6.74438477e-03,  -6.71386719e-03],
                        [ -4.18090820e-03,  -4.15039062e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  1.22070312e-04,   1.52587891e-04],
                        [ -1.07727051e-02,  -1.07421875e-02],
                        [ -1.49230957e-02,  -1.48925781e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  7.07702637e-02,   7.08007812e-02],
                        [  1.37756348e-01,   1.37756348e-01],
                        [  2.11395264e-01,   2.11395264e-01],
                        [  2.73925781e-01,   2.73925781e-01],
                        [  3.09875488e-01,   3.09875488e-01],
                        [  3.08532715e-01,   3.08532715e-01],
                        [  2.62756348e-01,   2.62756348e-01],
                        [  1.72607422e-01,   1.72607422e-01],
                        [  5.19409180e-02,   5.19104004e-02],
                        [ -6.98242188e-02,  -6.98242188e-02],
                        [ -1.55181885e-01,  -1.55181885e-01],
                        [ -1.78344727e-01,  -1.78344727e-01],
                        [ -1.45751953e-01,  -1.45782471e-01],
                        [ -9.33227539e-02,  -9.33227539e-02],
                        [ -5.34973145e-02,  -5.35278320e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -1.45263672e-02,  -1.45568848e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [  9.46044922e-04,   9.15527344e-04],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -2.60314941e-02,  -2.60620117e-02],
                        [ -3.34472656e-02,  -3.34777832e-02],
                        [ -2.06604004e-02,  -2.06909180e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  3.00598145e-02,   3.00292969e-02],
                        [  4.03137207e-02,   4.02832031e-02],
                        [  4.37927246e-02,   4.37622070e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  4.74548340e-02,   4.74243164e-02],
                        [  3.89404297e-02,   3.89099121e-02],
                        [  2.49633789e-02,   2.49328613e-02],
                        [  1.26953125e-02,   1.26647949e-02],
                        [  5.00488281e-03,   4.97436523e-03],
                        [ -1.83105469e-04,  -2.13623047e-04],
                        [ -4.85229492e-03,  -4.88281250e-03],
                        [ -8.60595703e-03,  -8.66699219e-03],
                        [ -1.19018555e-02,  -1.19323730e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -2.76184082e-02,  -2.76794434e-02],
                        [ -2.79235840e-02,  -2.79541016e-02],
                        [ -2.99072266e-02,  -2.99682617e-02],
                        [ -3.52783203e-02,  -3.53088379e-02],
                        [ -3.55834961e-02,  -3.56140137e-02],
                        [ -1.97753906e-02,  -1.98364258e-02],
                        [  1.45874023e-02,   1.45263672e-02],
                        [  5.84106445e-02,   5.83801270e-02],
                        [  9.62829590e-02,   9.62219238e-02],
                        [  1.16027832e-01,   1.15966797e-01],
                        [  1.16210938e-01,   1.16149902e-01],
                        [  1.03393555e-01,   1.03363037e-01],
                        [  8.44116211e-02,   8.43505859e-02],
                        [  6.39038086e-02,   6.38732910e-02],
                        [  4.50439453e-02,   4.50134277e-02],
                        [  2.91748047e-02,   2.91442871e-02],
                        [  1.75476074e-02,   1.75170898e-02],
                        [  1.19934082e-02,   1.19628906e-02],
                        [  1.15051270e-02,   1.14746094e-02],
                        [  1.09863281e-02,   1.09252930e-02],
                        [  4.66918945e-03,   4.60815430e-03],
                        [ -9.85717773e-03,  -9.91821289e-03],
                        [ -2.81066895e-02,  -2.81372070e-02],
                        [ -3.86962891e-02,  -3.87268066e-02],
                        [ -3.37524414e-02,  -3.37829590e-02],
                        [ -1.78833008e-02,  -1.79138184e-02],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [  1.16882324e-02,   1.16271973e-02],
                        [  2.15454102e-02,   2.15148926e-02],
                        [  2.98461914e-02,   2.98156738e-02],
                        [  3.78112793e-02,   3.77807617e-02],
                        [  4.50439453e-02,   4.49829102e-02],
                        [  5.00793457e-02,   5.00488281e-02],
                        [  5.64575195e-02,   5.63964844e-02],
                        [  7.13500977e-02,   7.13195801e-02],
                        [  9.43298340e-02,   9.42993164e-02],
                        [  1.14196777e-01,   1.14166260e-01],
                        [  1.18499756e-01,   1.18469238e-01],
                        [  1.00128174e-01,   1.00067139e-01],
                        [  5.72204590e-02,   5.71899414e-02],
                        [ -6.04248047e-03,  -6.07299805e-03],
                        [ -8.19396973e-02,  -8.20007324e-02],
                        [ -1.63391113e-01,  -1.63421631e-01],
                        [ -2.38647461e-01,  -2.38677979e-01],
                        [ -2.84393311e-01,  -2.84423828e-01],
                        [ -2.79754639e-01,  -2.79785156e-01],
                        [ -2.31140137e-01,  -2.31170654e-01],
                        [ -1.71234131e-01,  -1.71264648e-01],
                        [ -1.30920410e-01,  -1.30950928e-01],
                        [ -1.18041992e-01,  -1.18072510e-01],
                        [ -1.21215820e-01,  -1.21246338e-01],
                        [ -1.24114990e-01,  -1.24145508e-01],
                        [ -1.15936279e-01,  -1.15966797e-01],
                        [ -9.69543457e-02,  -9.69848633e-02],
                        [ -7.70874023e-02,  -7.71179199e-02],
                        [ -6.32019043e-02,  -6.32324219e-02],
                        [ -4.96520996e-02,  -4.96826172e-02],
                        [ -2.85339355e-02,  -2.85644531e-02],
                        [ -3.81469727e-03,  -3.84521484e-03],
                        [  1.38244629e-02,   1.37939453e-02],
                        [  2.10876465e-02,   2.10571289e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [ -9.30786133e-03,  -9.33837891e-03],
                        [ -2.80761719e-02,  -2.81066895e-02],
                        [ -3.31115723e-02,  -3.31420898e-02],
                        [ -2.60620117e-02,  -2.60925293e-02],
                        [ -1.87988281e-02,  -1.88293457e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -9.82666016e-03,  -9.85717773e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  1.51977539e-01,   1.51947021e-01],
                        [  2.26104736e-01,   2.26104736e-01],
                        [  2.81555176e-01,   2.81524658e-01],
                        [  3.04107666e-01,   3.04107666e-01],
                        [  2.93090820e-01,   2.93090820e-01],
                        [  2.54791260e-01,   2.54760742e-01],
                        [  1.93450928e-01,   1.93450928e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  7.81250000e-03,   7.81250000e-03],
                        [ -8.99047852e-02,  -8.99047852e-02],
                        [ -1.50421143e-01,  -1.50421143e-01],
                        [ -1.52130127e-01,  -1.52130127e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -5.50537109e-02,  -5.50537109e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -6.24694824e-02,  -6.24389648e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -1.16882324e-02,  -1.16577148e-02],
                        [  2.24304199e-02,   2.24609375e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  5.31311035e-02,   5.31616211e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -2.37731934e-02,  -2.37426758e-02],
                        [ -2.37426758e-02,  -2.37121582e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -7.84301758e-03,  -7.81250000e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -2.70385742e-02,  -2.70080566e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -6.13403320e-02,  -6.13098145e-02],
                        [ -4.49829102e-02,  -4.49523926e-02],
                        [ -9.49096680e-03,  -9.46044922e-03],
                        [  4.14428711e-02,   4.14733887e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.36932373e-01,   1.36932373e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  3.08837891e-02,   3.09143066e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  1.46789551e-02,   1.47094727e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -4.91333008e-03,  -4.88281250e-03],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.20336914e-02,  -2.20031738e-02],
                        [ -1.98059082e-02,  -1.97753906e-02],
                        [ -1.37939453e-02,  -1.37634277e-02],
                        [ -4.88281250e-03,  -4.85229492e-03],
                        [  4.02832031e-03,   4.05883789e-03],
                        [  1.15661621e-02,   1.15966797e-02],
                        [  2.10876465e-02,   2.11181641e-02],
                        [  3.53698730e-02,   3.54003906e-02],
                        [  5.14831543e-02,   5.15136719e-02],
                        [  6.65893555e-02,   6.66198730e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  9.84802246e-02,   9.85107422e-02],
                        [  1.11450195e-01,   1.11480713e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -1.66290283e-01,  -1.66259766e-01],
                        [ -2.49755859e-01,  -2.49755859e-01],
                        [ -3.04962158e-01,  -3.04931641e-01],
                        [ -3.14422607e-01,  -3.14422607e-01],
                        [ -2.75115967e-01,  -2.75115967e-01],
                        [ -2.11181641e-01,  -2.11181641e-01],
                        [ -1.57012939e-01,  -1.57012939e-01],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -7.16247559e-02,  -7.16247559e-02],
                        [ -7.48291016e-02,  -7.47985840e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -1.45874023e-02,  -1.45568848e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.50036621e-02,  -3.49731445e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  7.76062012e-02,   7.76062012e-02],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.91223145e-01,   1.91223145e-01],
                        [  2.34924316e-01,   2.34954834e-01],
                        [  2.61291504e-01,   2.61291504e-01],
                        [  2.68188477e-01,   2.68188477e-01],
                        [  2.57995605e-01,   2.57995605e-01],
                        [  2.37823486e-01,   2.37823486e-01],
                        [  2.11547852e-01,   2.11547852e-01],
                        [  1.71722412e-01,   1.71722412e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  2.05078125e-02,   2.05078125e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -1.36291504e-01,  -1.36291504e-01],
                        [ -1.58691406e-01,  -1.58691406e-01],
                        [ -1.44744873e-01,  -1.44744873e-01],
                        [ -1.20239258e-01,  -1.20239258e-01],
                        [ -1.03149414e-01,  -1.03149414e-01],
                        [ -9.23156738e-02,  -9.23156738e-02],
                        [ -8.04138184e-02,  -8.04138184e-02],
                        [ -6.57043457e-02,  -6.57043457e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -5.34057617e-03,  -5.37109375e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -3.89404297e-02,  -3.89709473e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  4.69665527e-02,   4.69665527e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [ -4.11987305e-03,  -4.15039062e-03],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  8.54492188e-04,   8.23974609e-04],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [ -9.06982422e-02,  -9.06982422e-02],
                        [ -2.00286865e-01,  -2.00286865e-01],
                        [ -2.81280518e-01,  -2.81280518e-01],
                        [ -3.08898926e-01,  -3.08898926e-01],
                        [ -2.83935547e-01,  -2.83935547e-01],
                        [ -2.31170654e-01,  -2.31170654e-01],
                        [ -1.80755615e-01,  -1.80755615e-01],
                        [ -1.49139404e-01,  -1.49139404e-01],
                        [ -1.32324219e-01,  -1.32324219e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -9.16137695e-02,  -9.16137695e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.93359375e-01,   1.93359375e-01],
                        [  2.35015869e-01,   2.35015869e-01],
                        [  2.44476318e-01,   2.44476318e-01],
                        [  2.33123779e-01,   2.33123779e-01],
                        [  2.20794678e-01,   2.20794678e-01],
                        [  2.19116211e-01,   2.19116211e-01],
                        [  2.24395752e-01,   2.24395752e-01],
                        [  2.21984863e-01,   2.21984863e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  6.35681152e-02,   6.35681152e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -1.14715576e-01,  -1.14715576e-01],
                        [ -1.69464111e-01,  -1.69464111e-01],
                        [ -1.81365967e-01,  -1.81365967e-01],
                        [ -1.55181885e-01,  -1.55181885e-01],
                        [ -1.14776611e-01,  -1.14776611e-01],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -6.91528320e-02,  -6.91528320e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -2.88696289e-02,  -2.89001465e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  3.08532715e-02,   3.08227539e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  4.11071777e-02,   4.10766602e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.17187500e-02,  -1.16882324e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  2.16674805e-02,   2.16979980e-02],
                        [  4.75463867e-02,   4.75769043e-02],
                        [  7.80029297e-02,   7.80334473e-02],
                        [  1.02447510e-01,   1.02478027e-01],
                        [  1.08032227e-01,   1.08062744e-01],
                        [  9.14916992e-02,   9.15222168e-02],
                        [  6.49414062e-02,   6.49719238e-02],
                        [  4.42504883e-02,   4.42810059e-02],
                        [  3.31726074e-02,   3.32031250e-02],
                        [  2.41699219e-02,   2.42004395e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  7.96508789e-03,   7.93457031e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.23901367e-02,   1.23596191e-02],
                        [  3.81469727e-03,   3.78417969e-03],
                        [ -7.50732422e-03,  -7.53784180e-03],
                        [ -1.52282715e-02,  -1.52893066e-02],
                        [ -1.44958496e-02,  -1.45263672e-02],
                        [ -3.96728516e-03,  -3.99780273e-03],
                        [  1.05590820e-02,   1.04980469e-02],
                        [  1.91955566e-02,   1.91345215e-02],
                        [  1.90734863e-02,   1.90124512e-02],
                        [  1.85852051e-02,   1.85241699e-02],
                        [  2.63977051e-02,   2.63671875e-02],
                        [  4.25720215e-02,   4.25415039e-02],
                        [  6.52465820e-02,   6.52160645e-02],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.56738281e-01,   1.56738281e-01],
                        [  1.51092529e-01,   1.51092529e-01],
                        [  1.14807129e-01,   1.14837646e-01],
                        [  5.41381836e-02,   5.41992188e-02],
                        [ -2.73742676e-02,  -2.72827148e-02],
                        [ -1.22802734e-01,  -1.22711182e-01],
                        [ -2.13714600e-01,  -2.13623047e-01],
                        [ -2.76702881e-01,  -2.76611328e-01],
                        [ -2.95135498e-01,  -2.95043945e-01],
                        [ -2.67272949e-01,  -2.67181396e-01],
                        [ -2.11425781e-01,  -2.11364746e-01],
                        [ -1.59820557e-01,  -1.59759521e-01],
                        [ -1.34765625e-01,  -1.34674072e-01],
                        [ -1.31622314e-01,  -1.31561279e-01],
                        [ -1.30187988e-01,  -1.30157471e-01],
                        [ -1.17187500e-01,  -1.17156982e-01],
                        [ -9.37805176e-02,  -9.37805176e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -5.07507324e-02,  -5.07812500e-02],
                        [ -3.95202637e-02,  -3.95507812e-02],
                        [ -2.86560059e-02,  -2.87170410e-02],
                        [ -1.44958496e-02,  -1.45874023e-02],
                        [ -1.77001953e-03,  -1.86157227e-03],
                        [  4.08935547e-03,   3.99780273e-03],
                        [  4.54711914e-03,   4.42504883e-03],
                        [  2.62451172e-03,   2.50244141e-03],
                        [ -3.44848633e-03,  -3.57055664e-03],
                        [ -1.47705078e-02,  -1.48620605e-02],
                        [ -2.57873535e-02,  -2.59094238e-02],
                        [ -3.14941406e-02,  -3.15856934e-02],
                        [ -3.56750488e-02,  -3.57666016e-02],
                        [ -4.43115234e-02,  -4.44030762e-02],
                        [ -5.35583496e-02,  -5.36193848e-02],
                        [ -5.19104004e-02,  -5.19409180e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  2.63671875e-02,   2.63977051e-02],
                        [  5.99060059e-02,   5.99670410e-02],
                        [  9.86633301e-02,   9.87243652e-02],
                        [  1.43402100e-01,   1.43493652e-01],
                        [  1.88873291e-01,   1.88964844e-01],
                        [  2.23815918e-01,   2.23937988e-01],
                        [  2.37701416e-01,   2.37823486e-01],
                        [  2.31597900e-01,   2.31719971e-01],
                        [  2.19238281e-01,   2.19360352e-01],
                        [  2.12646484e-01,   2.12768555e-01],
                        [  2.10754395e-01,   2.10906982e-01],
                        [  2.03918457e-01,   2.04071045e-01],
                        [  1.83135986e-01,   1.83258057e-01],
                        [  1.42242432e-01,   1.42333984e-01],
                        [  7.65075684e-02,   7.65991211e-02],
                        [ -1.28479004e-02,  -1.27563477e-02],
                        [ -1.09619141e-01,  -1.09558105e-01],
                        [ -1.83929443e-01,  -1.83898926e-01],
                        [ -2.10968018e-01,  -2.10968018e-01],
                        [ -1.90948486e-01,  -1.90979004e-01],
                        [ -1.48681641e-01,  -1.48712158e-01],
                        [ -1.12121582e-01,  -1.12182617e-01],
                        [ -9.04846191e-02,  -9.06066895e-02],
                        [ -7.22351074e-02,  -7.23571777e-02],
                        [ -4.49218750e-02,  -4.50439453e-02],
                        [ -1.23901367e-02,  -1.25122070e-02],
                        [  1.22070312e-02,   1.20544434e-02],
                        [  2.35290527e-02,   2.33459473e-02],
                        [  2.68859863e-02,   2.67028809e-02],
                        [  2.74047852e-02,   2.72521973e-02],
                        [  2.48413086e-02,   2.46887207e-02],
                        [  1.81579590e-02,   1.80053711e-02],
                        [  8.85009766e-03,   8.66699219e-03],
                        [ -9.76562500e-04,  -1.09863281e-03],
                        [ -9.30786133e-03,  -9.39941406e-03],
                        [ -1.35803223e-02,  -1.36413574e-02],
                        [ -1.34887695e-02,  -1.35498047e-02],
                        [ -1.40075684e-02,  -1.40380859e-02],
                        [ -1.95007324e-02,  -1.94702148e-02],
                        [ -2.61230469e-02,  -2.60620117e-02],
                        [ -2.58483887e-02,  -2.57873535e-02],
                        [ -1.77307129e-02,  -1.76086426e-02],
                        [ -9.61303711e-03,  -9.46044922e-03],
                        [ -9.27734375e-03,  -9.09423828e-03],
                        [ -1.80053711e-02,  -1.78222656e-02],
                        [ -3.24707031e-02,  -3.22570801e-02],
                        [ -4.76379395e-02,  -4.73937988e-02],
                        [ -5.69458008e-02,  -5.67016602e-02],
                        [ -5.16052246e-02,  -5.13916016e-02],
                        [ -2.34375000e-02,  -2.31933594e-02],
                        [  2.73132324e-02,   2.75268555e-02],
                        [  8.57849121e-02,   8.59680176e-02],
                        [  1.28265381e-01,   1.28387451e-01],
                        [  1.38732910e-01,   1.38885498e-01],
                        [  1.20391846e-01,   1.20483398e-01],
                        [  9.06066895e-02,   9.06372070e-02],
                        [  6.59484863e-02,   6.59179688e-02],
                        [  5.06286621e-02,   5.05676270e-02],
                        [  3.75976562e-02,   3.75061035e-02],
                        [  1.97143555e-02,   1.95617676e-02],
                        [ -1.09863281e-03,  -1.31225586e-03],
                        [ -1.68151855e-02,  -1.70898438e-02],
                        [ -2.21252441e-02,  -2.24304199e-02],
                        [ -1.82800293e-02,  -1.85852051e-02],
                        [ -1.00097656e-02,  -1.03149414e-02],
                        [ -3.11279297e-03,  -3.44848633e-03],
                        [ -3.11279297e-03,  -3.47900391e-03],
                        [ -9.49096680e-03,  -9.79614258e-03],
                        [ -1.30004883e-02,  -1.32446289e-02],
                        [ -6.59179688e-03,  -6.80541992e-03],
                        [  3.96728516e-03,   3.75366211e-03],
                        [  1.11694336e-02,   1.09863281e-02],
                        [  2.01110840e-02,   2.00500488e-02],
                        [  3.92456055e-02,   3.92761230e-02],
                        [  6.44836426e-02,   6.45141602e-02],
                        [  8.55102539e-02,   8.56018066e-02],
                        [  1.00433350e-01,   1.00646973e-01],
                        [  1.13891602e-01,   1.14166260e-01],
                        [  1.26037598e-01,   1.26312256e-01],
                        [  1.29425049e-01,   1.29730225e-01],
                        [  1.14196777e-01,   1.14562988e-01],
                        [  7.54394531e-02,   7.58666992e-02],
                        [  1.63574219e-02,   1.67541504e-02],
                        [ -5.70373535e-02,  -5.66711426e-02],
                        [ -1.40625000e-01,  -1.40289307e-01],
                        [ -2.24609375e-01,  -2.24273682e-01],
                        [ -2.84759521e-01,  -2.84454346e-01],
                        [ -2.95837402e-01,  -2.95593262e-01],
                        [ -2.59063721e-01,  -2.58911133e-01],
                        [ -2.06176758e-01,  -2.06115723e-01],
                        [ -1.67816162e-01,  -1.67816162e-01],
                        [ -1.46575928e-01,  -1.46636963e-01],
                        [ -1.27777100e-01,  -1.27899170e-01],
                        [ -1.04705811e-01,  -1.04919434e-01],
                        [ -8.20312500e-02,  -8.23364258e-02],
                        [ -6.34460449e-02,  -6.37817383e-02],
                        [ -4.91943359e-02,  -4.95300293e-02],
                        [ -4.06188965e-02,  -4.09851074e-02],
                        [ -3.72924805e-02,  -3.77197266e-02],
                        [ -3.25622559e-02,  -3.29589844e-02],
                        [ -2.08129883e-02,  -2.11791992e-02],
                        [ -7.50732422e-03,  -7.87353516e-03],
                        [ -3.93676758e-03,  -4.27246094e-03],
                        [ -1.24511719e-02,  -1.26953125e-02],
                        [ -2.48107910e-02,  -2.49938965e-02],
                        [ -3.34472656e-02,  -3.36303711e-02],
                        [ -3.66821289e-02,  -3.67736816e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -2.81372070e-02,  -2.80456543e-02],
                        [ -2.66113281e-02,  -2.64892578e-02],
                        [ -3.62548828e-02,  -3.60412598e-02],
                        [ -4.93774414e-02,  -4.91027832e-02],
                        [ -4.88586426e-02,  -4.85534668e-02],
                        [ -2.62756348e-02,  -2.59399414e-02],
                        [  1.13830566e-02,   1.17492676e-02],
                        [  5.34057617e-02,   5.37719727e-02],
                        [  9.81140137e-02,   9.84802246e-02],
                        [  1.49322510e-01,   1.49658203e-01],
                        [  2.00103760e-01,   2.00408936e-01],
                        [  2.29217529e-01,   2.29492188e-01],
                        [  2.22991943e-01,   2.23236084e-01],
                        [  1.95373535e-01,   1.95556641e-01],
                        [  1.74743652e-01,   1.74865723e-01],
                        [  1.75170898e-01,   1.75201416e-01],
                        [  1.88690186e-01,   1.88690186e-01],
                        [  1.99798584e-01,   1.99768066e-01],
                        [  1.97753906e-01,   1.97631836e-01],
                        [  1.78100586e-01,   1.77917480e-01],
                        [  1.37908936e-01,   1.37725830e-01],
                        [  7.24487305e-02,   7.22656250e-02],
                        [ -1.76696777e-02,  -1.79138184e-02],
                        [ -1.14715576e-01,  -1.15020752e-01],
                        [ -1.87927246e-01,  -1.88232422e-01],
                        [ -2.14935303e-01,  -2.15179443e-01],
                        [ -1.96716309e-01,  -1.96929932e-01],
                        [ -1.52954102e-01,  -1.53198242e-01],
                        [ -1.06842041e-01,  -1.07086182e-01],
                        [ -7.24792480e-02,  -7.27233887e-02],
                        [ -5.08422852e-02,  -5.09948730e-02],
                        [ -3.50036621e-02,  -3.50952148e-02],
                        [ -2.02331543e-02,  -2.02941895e-02],
                        [ -8.45336914e-03,  -8.54492188e-03],
                        [ -4.02832031e-03,  -4.05883789e-03],
                        [ -7.04956055e-03,  -6.98852539e-03],
                        [ -1.18713379e-02,  -1.17797852e-02],
                        [ -1.05285645e-02,  -1.04675293e-02],
                        [  1.70898438e-03,   1.80053711e-03],
                        [  2.24304199e-02,   2.26440430e-02],
                        [  4.06188965e-02,   4.08325195e-02],
                        [  4.06799316e-02,   4.08325195e-02],
                        [  1.65405273e-02,   1.67236328e-02],
                        [ -1.63879395e-02,  -1.61437988e-02],
                        [ -3.38134766e-02,  -3.35693359e-02],
                        [ -3.00292969e-02,  -2.98461914e-02],
                        [ -2.03247070e-02,  -2.01416016e-02],
                        [ -1.58081055e-02,  -1.55944824e-02],
                        [ -1.24816895e-02,  -1.22680664e-02],
                        [ -7.32421875e-03,  -7.17163086e-03],
                        [ -6.77490234e-03,  -6.68334961e-03],
                        [ -1.53503418e-02,  -1.52587891e-02],
                        [ -2.95410156e-02,  -2.94494629e-02],
                        [ -4.54101562e-02,  -4.53796387e-02],
                        [ -5.92651367e-02,  -5.92956543e-02],
                        [ -6.05468750e-02,  -6.05773926e-02],
                        [ -3.65295410e-02,  -3.66210938e-02],
                        [  1.25732422e-02,   1.24511719e-02],
                        [  7.09533691e-02,   7.08007812e-02],
                        [  1.18713379e-01,   1.18530273e-01],
                        [  1.41204834e-01,   1.40960693e-01],
                        [  1.33300781e-01,   1.33056641e-01],
                        [  1.03942871e-01,   1.03668213e-01],
                        [  7.08312988e-02,   7.05261230e-02],
                        [  4.42199707e-02,   4.39147949e-02],
                        [  2.13623047e-02,   2.10876465e-02],
                        [ -1.83105469e-04,  -4.27246094e-04],
                        [ -1.38854980e-02,  -1.41601562e-02],
                        [ -1.34277344e-02,  -1.36718750e-02],
                        [ -1.34277344e-03,  -1.49536133e-03],
                        [  1.34582520e-02,   1.33666992e-02],
                        [  2.09960938e-02,   2.09045410e-02],
                        [  1.58386230e-02,   1.58081055e-02],
                        [  3.60107422e-03,   3.66210938e-03],
                        [ -3.96728516e-03,  -3.75366211e-03],
                        [ -3.69262695e-03,  -3.47900391e-03],
                        [ -2.01416016e-03,  -1.80053711e-03],
                        [  1.31225586e-03,   1.61743164e-03],
                        [  1.51367188e-02,   1.55944824e-02],
                        [  3.94897461e-02,   3.99169922e-02],
                        [  6.13708496e-02,   6.17370605e-02],
                        [  7.46154785e-02,   7.50122070e-02],
                        [  8.86230469e-02,   8.91418457e-02],
                        [  1.11419678e-01,   1.11877441e-01],
                        [  1.35650635e-01,   1.35955811e-01],
                        [  1.46728516e-01,   1.46972656e-01],
                        [  1.34399414e-01,   1.34674072e-01],
                        [  9.28955078e-02,   9.31396484e-02],
                        [  2.10876465e-02,   2.11486816e-02],
                        [ -7.34252930e-02,  -7.35168457e-02],
                        [ -1.75445557e-01,  -1.75598145e-01],
                        [ -2.63916016e-01,  -2.64099121e-01],
                        [ -3.10913086e-01,  -3.11218262e-01],
                        [ -2.96386719e-01,  -2.96813965e-01],
                        [ -2.36236572e-01,  -2.36785889e-01],
                        [ -1.77581787e-01,  -1.78131104e-01],
                        [ -1.50817871e-01,  -1.51397705e-01],
                        [ -1.41662598e-01,  -1.42242432e-01],
                        [ -1.22070312e-01,  -1.22680664e-01],
                        [ -9.09423828e-02,  -9.15527344e-02],
                        [ -6.78100586e-02,  -6.83593750e-02],
                        [ -6.07604980e-02,  -6.12182617e-02],
                        [ -5.86242676e-02,  -5.89599609e-02],
                        [ -4.91027832e-02,  -4.93469238e-02],
                        [ -3.08837891e-02,  -3.10668945e-02],
                        [ -1.11999512e-02,  -1.12304688e-02],
                        [ -6.10351562e-05,   9.15527344e-05],
                        [ -3.96728516e-03,  -3.66210938e-03],
                        [ -1.95617676e-02,  -1.91345215e-02],
                        [ -3.60717773e-02,  -3.56140137e-02],
                        [ -4.44946289e-02,  -4.39147949e-02],
                        [ -4.26025391e-02,  -4.18701172e-02],
                        [ -3.54614258e-02,  -3.46679688e-02],
                        [ -3.17077637e-02,  -3.09448242e-02],
                        [ -3.45764160e-02,  -3.38745117e-02],
                        [ -3.85742188e-02,  -3.78112793e-02],
                        [ -3.86352539e-02,  -3.79028320e-02],
                        [ -3.50952148e-02,  -3.44848633e-02],
                        [ -2.61230469e-02,  -2.56652832e-02],
                        [ -5.58471680e-03,  -5.21850586e-03],
                        [  2.88085938e-02,   2.90832520e-02],
                        [  7.41271973e-02,   7.42187500e-02],
                        [  1.26129150e-01,   1.26007080e-01],
                        [  1.75079346e-01,   1.74835205e-01],
                        [  2.04223633e-01,   2.03857422e-01],
                        [  2.03887939e-01,   2.03399658e-01],
                        [  1.83349609e-01,   1.82708740e-01],
                        [  1.60583496e-01,   1.59820557e-01],
                        [  1.45751953e-01,   1.44927979e-01],
                        [  1.39160156e-01,   1.38336182e-01],
                        [  1.38275146e-01,   1.37420654e-01],
                        [  1.40991211e-01,   1.40075684e-01],
                        [  1.45660400e-01,   1.44775391e-01],
                        [  1.50451660e-01,   1.49719238e-01],
                        [  1.49963379e-01,   1.49353027e-01],
                        [  1.32720947e-01,   1.32202148e-01],
                        [  8.72497559e-02,   8.68225098e-02],
                        [  1.27258301e-02,   1.25122070e-02],
                        [ -7.58972168e-02,  -7.59582520e-02],
                        [ -1.52404785e-01,  -1.52282715e-01],
                        [ -1.89880371e-01,  -1.89605713e-01],
                        [ -1.77093506e-01,  -1.76635742e-01],
                        [ -1.31378174e-01,  -1.30828857e-01],
                        [ -8.85925293e-02,  -8.79516602e-02],
                        [ -7.04345703e-02,  -6.96716309e-02],
                        [ -6.66503906e-02,  -6.57348633e-02],
                        [ -5.70373535e-02,  -5.61218262e-02],
                        [ -4.17480469e-02,  -4.08935547e-02],
                        [ -3.56750488e-02,  -3.48205566e-02],
                        [ -4.15039062e-02,  -4.05883789e-02],
                        [ -4.52575684e-02,  -4.44335938e-02],
                        [ -3.61328125e-02,  -3.54919434e-02],
                        [ -1.67236328e-02,  -1.62048340e-02],
                        [  4.82177734e-03,   5.27954102e-03],
                        [  2.20336914e-02,   2.23693848e-02],
                        [  2.95715332e-02,   2.96936035e-02],
                        [  2.38037109e-02,   2.37426758e-02],
                        [  7.65991211e-03,   7.47680664e-03],
                        [ -9.49096680e-03,  -9.76562500e-03],
                        [ -1.97753906e-02,  -2.01721191e-02],
                        [ -2.30407715e-02,  -2.36206055e-02],
                        [ -2.28271484e-02,  -2.35900879e-02],
                        [ -1.97448730e-02,  -2.05078125e-02],
                        [ -1.29394531e-02,  -1.36718750e-02],
                        [ -6.89697266e-03,  -7.78198242e-03],
                        [ -9.97924805e-03,  -1.09863281e-02],
                        [ -2.37121582e-02,  -2.46276855e-02],
                        [ -3.91540527e-02,  -3.98864746e-02],
                        [ -4.72412109e-02,  -4.80041504e-02],
                        [ -4.69360352e-02,  -4.77294922e-02],
                        [ -3.68652344e-02,  -3.75061035e-02],
                        [ -8.78906250e-03,  -9.18579102e-03],
                        [  3.95507812e-02,   3.92150879e-02],
                        [  8.97521973e-02,   8.94470215e-02],
                        [  1.15631104e-01,   1.15539551e-01],
                        [  1.09771729e-01,   1.09893799e-01],
                        [  8.66394043e-02,   8.68225098e-02],
                        [  6.12182617e-02,   6.14929199e-02],
                        [  3.78417969e-02,   3.83300781e-02],
                        [  2.01416016e-02,   2.08435059e-02],
                        [  1.63574219e-02,   1.70898438e-02],
                        [  2.68554688e-02,   2.75573730e-02],
                        [  3.86962891e-02,   3.95507812e-02],
                        [  4.05273438e-02,   4.15954590e-02],
                        [  3.41491699e-02,   3.51867676e-02],
                        [  2.46582031e-02,   2.55126953e-02],
                        [  1.16882324e-02,   1.25427246e-02],
                        [ -3.26538086e-03,  -2.31933594e-03],
                        [ -1.30004883e-02,  -1.21154785e-02],
                        [ -1.37329102e-02,  -1.30310059e-02],
                        [ -8.02612305e-03,  -7.44628906e-03],
                        [  4.51660156e-03,   5.00488281e-03],
                        [  2.77709961e-02,   2.80761719e-02],
                        [  5.88989258e-02,   5.89599609e-02],
                        [  8.78295898e-02,   8.77990723e-02],
                        [  1.09069824e-01,   1.08917236e-01],
                        [  1.23596191e-01,   1.23138428e-01],
                        [  1.31011963e-01,   1.30279541e-01],
                        [  1.29272461e-01,   1.28479004e-01],
                        [  1.19018555e-01,   1.18225098e-01],
                        [  9.77783203e-02,   9.67712402e-02],
                        [  5.47180176e-02,   5.34667969e-02],
                        [ -1.81579590e-02,  -1.94091797e-02],
                        [ -1.13159180e-01,  -1.14318848e-01],
                        [ -2.10357666e-01,  -2.11547852e-01],
                        [ -2.84545898e-01,  -2.85797119e-01],
                        [ -3.10363770e-01,  -3.11523438e-01],
                        [ -2.79022217e-01,  -2.80029297e-01],
                        [ -2.13958740e-01,  -2.14813232e-01],
                        [ -1.54327393e-01,  -1.55029297e-01],
                        [ -1.20025635e-01,  -1.20452881e-01],
                        [ -1.02996826e-01,  -1.03179932e-01],
                        [ -8.92944336e-02,  -8.93249512e-02],
                        [ -7.56835938e-02,  -7.55004883e-02],
                        [ -6.53991699e-02,  -6.48803711e-02],
                        [ -5.93872070e-02,  -5.85937500e-02],
                        [ -5.40771484e-02,  -5.31921387e-02],
                        [ -4.47082520e-02,  -4.36706543e-02],
                        [ -3.03649902e-02,  -2.90527344e-02],
                        [ -1.56250000e-02,  -1.40991211e-02],
                        [ -5.55419922e-03,  -4.05883789e-03],
                        [ -9.46044922e-04,   4.88281250e-04],
                        [ -6.10351562e-04,   9.46044922e-04],
                        [ -4.82177734e-03,  -3.23486328e-03],
                        [ -1.44348145e-02,  -1.30920410e-02],
                        [ -2.85949707e-02,  -2.75573730e-02],
                        [ -4.44946289e-02,  -4.34265137e-02],
                        [ -5.82580566e-02,  -5.73120117e-02],
                        [ -6.79931641e-02,  -6.74743652e-02],
                        [ -7.36999512e-02,  -7.36389160e-02],
                        [ -7.23266602e-02,  -7.23876953e-02],
                        [ -5.57861328e-02,  -5.59692383e-02],
                        [ -1.81274414e-02,  -1.87072754e-02],
                        [  3.75671387e-02,   3.65600586e-02],
                        [  1.02447510e-01,   1.01257324e-01],
                        [  1.66412354e-01,   1.65161133e-01],
                        [  2.16247559e-01,   2.14752197e-01],
                        [  2.36328125e-01,   2.34588623e-01],
                        [  2.21679688e-01,   2.19940186e-01],
                        [  1.86614990e-01,   1.84967041e-01],
                        [  1.52160645e-01,   1.50451660e-01],
                        [  1.27716064e-01,   1.26007080e-01],
                        [  1.11968994e-01,   1.10534668e-01],
                        [  1.04339600e-01,   1.03179932e-01],
                        [  1.05438232e-01,   1.04339600e-01],
                        [  1.12243652e-01,   1.11328125e-01],
                        [  1.21856689e-01,   1.21368408e-01],
                        [  1.35101318e-01,   1.35009766e-01],
                        [  1.50268555e-01,   1.50360107e-01],
                        [  1.55120850e-01,   1.55395508e-01],
                        [  1.30706787e-01,   1.31408691e-01],
                        [  6.52465820e-02,   6.63146973e-02],
                        [ -3.33862305e-02,  -3.21350098e-02],
                        [ -1.35070801e-01,  -1.33758545e-01],
                        [ -2.00531006e-01,  -1.98974609e-01],
                        [ -2.06848145e-01,  -2.05047607e-01],
                        [ -1.65740967e-01,  -1.63909912e-01],
                        [ -1.12854004e-01,  -1.11175537e-01],
                        [ -7.78808594e-02,  -7.62329102e-02],
                        [ -6.62841797e-02,  -6.46057129e-02],
                        [ -6.42089844e-02,  -6.26220703e-02],
                        [ -5.54199219e-02,  -5.41381836e-02],
                        [ -3.76586914e-02,  -3.67126465e-02],
                        [ -2.46887207e-02,  -2.39257812e-02],
                        [ -2.77099609e-02,  -2.70690918e-02],
                        [ -3.96728516e-02,  -3.93066406e-02],
                        [ -4.49218750e-02,  -4.50439453e-02],
                        [ -3.72009277e-02,  -3.76586914e-02],
                        [ -2.06604004e-02,  -2.12707520e-02],
                        [ -1.64794922e-03,  -2.47192383e-03],
                        [  1.27563477e-02,   1.15966797e-02],
                        [  1.65405273e-02,   1.51367188e-02],
                        [  1.07116699e-02,   9.21630859e-03],
                        [  1.92260742e-03,   3.05175781e-04],
                        [ -5.82885742e-03,  -7.59887695e-03],
                        [ -1.23291016e-02,  -1.40686035e-02],
                        [ -1.62048340e-02,  -1.78527832e-02],
                        [ -1.69982910e-02,  -1.86767578e-02],
                        [ -1.91955566e-02,  -2.08740234e-02],
                        [ -2.67333984e-02,  -2.81372070e-02],
                        [ -3.62243652e-02,  -3.72924805e-02],
                        [ -4.25109863e-02,  -4.34570312e-02],
                        [ -4.56848145e-02,  -4.64782715e-02],
                        [ -4.51660156e-02,  -4.56237793e-02],
                        [ -3.20739746e-02,  -3.21960449e-02],
                        [  1.77001953e-03,   1.89208984e-03],
                        [  4.98962402e-02,   5.03540039e-02],
                        [  9.38110352e-02,   9.46044922e-02],
                        [  1.16729736e-01,   1.17675781e-01],
                        [  1.11389160e-01,   1.12487793e-01],
                        [  8.39538574e-02,   8.53881836e-02],
                        [  5.31616211e-02,   5.48706055e-02],
                        [  3.56140137e-02,   3.73535156e-02],
                        [  3.03649902e-02,   3.20434570e-02],
                        [  2.61535645e-02,   2.79541016e-02],
                        [  1.83410645e-02,   2.02331543e-02],
                        [  1.00708008e-02,   1.17797852e-02],
                        [  4.73022461e-03,   6.28662109e-03],
                        [  5.58471680e-03,   7.08007812e-03],
                        [  1.31530762e-02,   1.43737793e-02],
                        [  1.95312500e-02,   2.03857422e-02],
                        [  1.48925781e-02,   1.55334473e-02],
                        [  2.22778320e-03,   2.71606445e-03],
                        [ -2.56347656e-03,  -2.44140625e-03],
                        [  1.12609863e-02,   1.08947754e-02],
                        [  3.73535156e-02,   3.66516113e-02],
                        [  6.28662109e-02,   6.20422363e-02],
                        [  8.41674805e-02,   8.30993652e-02],
                        [  1.03881836e-01,   1.02416992e-01],
                        [  1.20056152e-01,   1.18255615e-01],
                        [  1.29486084e-01,   1.27593994e-01],
                        [  1.35681152e-01,   1.33819580e-01],
                        [  1.39923096e-01,   1.38000488e-01],
                        [  1.29730225e-01,   1.27655029e-01],
                        [  8.79516602e-02,   8.58459473e-02],
                        [  1.08337402e-02,   9.03320312e-03],
                        [ -8.85009766e-02,  -8.99963379e-02],
                        [ -1.89514160e-01,  -1.90948486e-01],
                        [ -2.69073486e-01,  -2.70355225e-01],
                        [ -3.03527832e-01,  -3.04351807e-01],
                        [ -2.81707764e-01,  -2.82043457e-01],
                        [ -2.21160889e-01,  -2.21282959e-01],
                        [ -1.60705566e-01,  -1.60614014e-01],
                        [ -1.28540039e-01,  -1.27960205e-01],
                        [ -1.20788574e-01,  -1.19689941e-01],
                        [ -1.15081787e-01,  -1.13739014e-01],
                        [ -9.77172852e-02,  -9.62829590e-02],
                        [ -7.17468262e-02,  -7.00073242e-02],
                        [ -4.68139648e-02,  -4.47082520e-02],
                        [ -3.14941406e-02,  -2.93579102e-02],
                        [ -3.07922363e-02,  -2.87475586e-02],
                        [ -4.03747559e-02,  -3.82385254e-02],
                        [ -4.68750000e-02,  -4.47082520e-02],
                        [ -4.11376953e-02,  -3.92761230e-02],
                        [ -2.71606445e-02,  -2.55737305e-02],
                        [ -1.33666992e-02,  -1.18713379e-02],
                        [ -3.05175781e-03,  -1.73950195e-03],
                        [  1.73950195e-03,   2.47192383e-03],
                        [ -4.66918945e-03,  -4.45556641e-03],
                        [ -2.34680176e-02,  -2.33764648e-02],
                        [ -4.52575684e-02,  -4.53796387e-02],
                        [ -6.03942871e-02,  -6.10961914e-02],
                        [ -6.86340332e-02,  -6.98852539e-02],
                        [ -6.99157715e-02,  -7.12890625e-02],
                        [ -5.51757812e-02,  -5.66101074e-02],
                        [ -1.79748535e-02,  -1.97448730e-02],
                        [  3.39355469e-02,   3.17993164e-02],
                        [  8.97827148e-02,   8.76464844e-02],
                        [  1.46301270e-01,   1.44348145e-01],
                        [  1.96960449e-01,   1.94915771e-01],
                        [  2.24182129e-01,   2.22106934e-01],
                        [  2.17041016e-01,   2.15209961e-01],
                        [  1.87316895e-01,   1.85882568e-01],
                        [  1.57989502e-01,   1.56707764e-01],
                        [  1.40563965e-01,   1.39434814e-01],
                        [  1.31378174e-01,   1.30645752e-01],
                        [  1.23962402e-01,   1.23718262e-01],
                        [  1.17279053e-01,   1.17370605e-01],
                        [  1.15142822e-01,   1.15447998e-01],
                        [  1.21124268e-01,   1.21734619e-01],
                        [  1.32843018e-01,   1.33850098e-01],
                        [  1.41510010e-01,   1.42791748e-01],
                        [  1.39221191e-01,   1.40655518e-01],
                        [  1.23291016e-01,   1.24938965e-01],
                        [  9.12475586e-02,   9.30786133e-02],
                        [  3.69262695e-02,   3.86962891e-02],
                        [ -4.13818359e-02,  -3.96423340e-02],
                        [ -1.27410889e-01,  -1.25518799e-01],
                        [ -1.89605713e-01,  -1.87683105e-01],
                        [ -2.04345703e-01,  -2.02819824e-01],
                        [ -1.76147461e-01,  -1.74957275e-01],
                        [ -1.31408691e-01,  -1.30218506e-01],
                        [ -9.56420898e-02,  -9.45129395e-02],
                        [ -7.81250000e-02,  -7.74230957e-02],
                        [ -7.13195801e-02,  -7.10754395e-02],
                        [ -6.15844727e-02,  -6.14929199e-02],
                        [ -4.32739258e-02,  -4.33654785e-02],
                        [ -2.35900879e-02,  -2.40478516e-02],
                        [ -1.28173828e-02,  -1.36108398e-02],
                        [ -1.33361816e-02,  -1.42211914e-02],
                        [ -1.80358887e-02,  -1.91345215e-02],
                        [ -1.84020996e-02,  -1.98364258e-02],
                        [ -1.28173828e-02,  -1.43737793e-02],
                        [ -5.46264648e-03,  -6.86645508e-03],
                        [  9.15527344e-04,  -5.18798828e-04],
                        [  4.94384766e-03,   3.26538086e-03],
                        [  3.23486328e-03,   1.49536133e-03],
                        [ -4.30297852e-03,  -5.73730469e-03],
                        [ -1.05590820e-02,  -1.17187500e-02],
                        [ -1.08032227e-02,  -1.20239258e-02],
                        [ -1.15051270e-02,  -1.26953125e-02],
                        [ -2.08435059e-02,  -2.16979980e-02],
                        [ -3.57666016e-02,  -3.62548828e-02],
                        [ -4.61425781e-02,  -4.64782715e-02],
                        [ -4.97131348e-02,  -4.99267578e-02],
                        [ -5.40466309e-02,  -5.38940430e-02],
                        [ -6.12792969e-02,  -6.07910156e-02],
                        [ -6.02416992e-02,  -5.96313477e-02],
                        [ -3.72924805e-02,  -3.65295410e-02],
                        [  1.01928711e-02,   1.13525391e-02],
                        [  6.94885254e-02,   7.08923340e-02],
                        [  1.16241455e-01,   1.17584229e-01],
                        [  1.29302979e-01,   1.30615234e-01],
                        [  1.09558105e-01,   1.11175537e-01],
                        [  7.94982910e-02,   8.13293457e-02],
                        [  5.95092773e-02,   6.10961914e-02],
                        [  5.07507324e-02,   5.20935059e-02],
                        [  4.40063477e-02,   4.54101562e-02],
                        [  3.46069336e-02,   3.60412598e-02],
                        [  2.38647461e-02,   2.49938965e-02],
                        [  1.36718750e-02,   1.44042969e-02],
                        [  6.16455078e-03,   6.71386719e-03],
                        [  4.36401367e-03,   4.73022461e-03],
                        [  7.90405273e-03,   7.99560547e-03],
                        [  1.20544434e-02,   1.17797852e-02],
                        [  1.24511719e-02,   1.17797852e-02],
                        [  9.73510742e-03,   8.85009766e-03],
                        [  1.03454590e-02,   9.33837891e-03],
                        [  2.16674805e-02,   2.03857422e-02],
                        [  4.47387695e-02,   4.30908203e-02],
                        [  7.41577148e-02,   7.23571777e-02],
                        [  1.05163574e-01,   1.03485107e-01],
                        [  1.34246826e-01,   1.32568359e-01],
                        [  1.54815674e-01,   1.52954102e-01],
                        [  1.60888672e-01,   1.59057617e-01],
                        [  1.51824951e-01,   1.50238037e-01],
                        [  1.26861572e-01,   1.25579834e-01],
                        [  8.07495117e-02,   7.95898438e-02],
                        [  8.94165039e-03,   8.02612305e-03],
                        [ -8.59069824e-02,  -8.64562988e-02],
                        [ -1.91619873e-01,  -1.91864014e-01],
                        [ -2.83447266e-01,  -2.83355713e-01],
                        [ -3.27880859e-01,  -3.27423096e-01],
                        [ -3.05053711e-01,  -3.04168701e-01],
                        [ -2.31567383e-01,  -2.30468750e-01],
                        [ -1.52801514e-01,  -1.51519775e-01],
                        [ -1.05224609e-01,  -1.03637695e-01],
                        [ -9.04541016e-02,  -8.85925293e-02],
                        [ -8.81958008e-02,  -8.62426758e-02],
                        [ -8.48693848e-02,  -8.29772949e-02],
                        [ -8.18176270e-02,  -7.99865723e-02],
                        [ -8.27026367e-02,  -8.08715820e-02],
                        [ -8.33129883e-02,  -8.15734863e-02],
                        [ -7.59887695e-02,  -7.44934082e-02],
                        [ -5.93261719e-02,  -5.81665039e-02],
                        [ -3.87268066e-02,  -3.79028320e-02],
                        [ -1.95922852e-02,  -1.90124512e-02],
                        [ -4.45556641e-03,  -4.21142578e-03],
                        [  3.66210938e-03,   3.47900391e-03],
                        [  2.10571289e-03,   1.52587891e-03],
                        [ -6.77490234e-03,  -7.62939453e-03],
                        [ -1.80664062e-02,  -1.91650391e-02],
                        [ -3.22570801e-02,  -3.36914062e-02],
                        [ -5.31311035e-02,  -5.48706055e-02],
                        [ -7.57446289e-02,  -7.75146484e-02],
                        [ -8.49609375e-02,  -8.67004395e-02],
                        [ -7.07397461e-02,  -7.25708008e-02],
                        [ -3.73229980e-02,  -3.92761230e-02],
                        [  6.74438477e-03,   4.97436523e-03],
                        [  5.85327148e-02,   5.71594238e-02],
                        [  1.15631104e-01,   1.14471436e-01],
                        [  1.67663574e-01,   1.66625977e-01],
                        [  2.00103760e-01,   1.99279785e-01],
                        [  2.05261230e-01,   2.04895020e-01],
                        [  1.88171387e-01,   1.88262939e-01],
                        [  1.61621094e-01,   1.62048340e-01],
                        [  1.36260986e-01,   1.36901855e-01],
                        [  1.16302490e-01,   1.17126465e-01],
                        [  1.02416992e-01,   1.03546143e-01],
                        [  9.51538086e-02,   9.66186523e-02],
                        [  9.54895020e-02,   9.71679688e-02],
                        [  1.03851318e-01,   1.05468750e-01],
                        [  1.17553711e-01,   1.19110107e-01],
                        [  1.29119873e-01,   1.30676270e-01],
                        [  1.30645752e-01,   1.32202148e-01],
                        [  1.22100830e-01,   1.23535156e-01],
                        [  1.12060547e-01,   1.13281250e-01],
                        [  1.05377197e-01,   1.06262207e-01],
                        [  9.10949707e-02,   9.16137695e-02],
                        [  5.07812500e-02,   5.11779785e-02],
                        [ -1.94702148e-02,  -1.91650391e-02],
                        [ -1.01745605e-01,  -1.01867676e-01],
                        [ -1.69555664e-01,  -1.70227051e-01],
                        [ -2.01507568e-01,  -2.02362061e-01],
                        [ -1.89575195e-01,  -1.90307617e-01],
                        [ -1.47308350e-01,  -1.48223877e-01],
                        [ -1.04980469e-01,  -1.06353760e-01],
                        [ -8.33435059e-02,  -8.48388672e-02],
                        [ -7.65686035e-02,  -7.77893066e-02],
                        [ -6.81762695e-02,  -6.93054199e-02],
                        [ -5.42297363e-02,  -5.55725098e-02],
                        [ -4.16870117e-02,  -4.30297852e-02],
                        [ -3.38439941e-02,  -3.48205566e-02],
                        [ -2.78930664e-02,  -2.85644531e-02],
                        [ -2.22778320e-02,  -2.29187012e-02],
                        [ -1.80664062e-02,  -1.86767578e-02],
                        [ -1.35803223e-02,  -1.37939453e-02],
                        [ -4.36401367e-03,  -4.21142578e-03],
                        [  8.39233398e-03,   8.63647461e-03],
                        [  1.56555176e-02,   1.59301758e-02],
                        [  1.12304688e-02,   1.17187500e-02],
                        [ -1.52587891e-04,   6.40869141e-04],
                        [ -9.70458984e-03,  -8.81958008e-03],
                        [ -1.54724121e-02,  -1.46179199e-02],
                        [ -2.21862793e-02,  -2.12707520e-02],
                        [ -3.29589844e-02,  -3.19824219e-02],
                        [ -4.42810059e-02,  -4.32739258e-02],
                        [ -5.13305664e-02,  -5.03845215e-02],
                        [ -5.58776855e-02,  -5.49926758e-02],
                        [ -6.16455078e-02,  -6.08520508e-02],
                        [ -6.33850098e-02,  -6.27136230e-02],
                        [ -4.88891602e-02,  -4.83703613e-02],
                        [ -1.19323730e-02,  -1.15356445e-02],
                        [  4.11376953e-02,   4.14428711e-02],
                        [  9.35668945e-02,   9.37500000e-02],
                        [  1.25457764e-01,   1.25518799e-01],
                        [  1.26312256e-01,   1.26159668e-01],
                        [  1.03332520e-01,   1.02996826e-01],
                        [  7.45239258e-02,   7.41577148e-02],
                        [  5.34362793e-02,   5.30700684e-02],
                        [  4.16564941e-02,   4.11071777e-02],
                        [  3.37524414e-02,   3.29589844e-02],
                        [  2.69165039e-02,   2.61230469e-02],
                        [  2.42614746e-02,   2.35900879e-02],
                        [  2.75878906e-02,   2.68859863e-02],
                        [  3.14331055e-02,   3.04870605e-02],
                        [  2.78625488e-02,   2.69165039e-02],
                        [  1.66320801e-02,   1.59301758e-02],
                        [  6.28662109e-03,   5.64575195e-03],
                        [  4.63867188e-03,   3.81469727e-03],
                        [  1.08642578e-02,   1.01013184e-02],
                        [  1.98059082e-02,   1.93481445e-02],
                        [  3.05480957e-02,   3.02734375e-02],
                        [  4.64477539e-02,   4.60510254e-02],
                        [  6.93054199e-02,   6.89697266e-02],
                        [  9.86633301e-02,   9.87243652e-02],
                        [  1.32080078e-01,   1.32476807e-01],
                        [  1.60919189e-01,   1.61254883e-01],
                        [  1.70837402e-01,   1.71142578e-01],
                        [  1.52404785e-01,   1.53015137e-01],
                        [  1.06750488e-01,   1.07727051e-01],
                        [  3.83605957e-02,   3.94592285e-02],
                        [ -5.16357422e-02,  -5.05676270e-02],
                        [ -1.57440186e-01,  -1.56402588e-01],
                        [ -2.55706787e-01,  -2.54547119e-01],
                        [ -3.09631348e-01,  -3.08288574e-01],
                        [ -2.95379639e-01,  -2.93945312e-01],
                        [ -2.28240967e-01,  -2.27081299e-01],
                        [ -1.55914307e-01,  -1.55090332e-01],
                        [ -1.16394043e-01,  -1.15539551e-01],
                        [ -1.06689453e-01,  -1.05712891e-01],
                        [ -1.00830078e-01,  -1.00189209e-01],
                        [ -8.79211426e-02,  -8.78295898e-02],
                        [ -7.68737793e-02,  -7.69958496e-02],
                        [ -7.37609863e-02,  -7.39440918e-02],
                        [ -7.24182129e-02,  -7.29064941e-02],
                        [ -6.40563965e-02,  -6.50024414e-02],
                        [ -4.53796387e-02,  -4.65393066e-02],
                        [ -1.98974609e-02,  -2.12097168e-02],
                        [  2.16674805e-03,   6.10351562e-04],
                        [  1.04370117e-02,   8.66699219e-03],
                        [  3.57055664e-03,   1.77001953e-03],
                        [ -1.16577148e-02,  -1.34582520e-02],
                        [ -2.89916992e-02,  -3.08227539e-02],
                        [ -4.51965332e-02,  -4.69360352e-02],
                        [ -5.74645996e-02,  -5.90820312e-02],
                        [ -6.45141602e-02,  -6.59179688e-02],
                        [ -6.72607422e-02,  -6.82983398e-02],
                        [ -6.46972656e-02,  -6.53686523e-02],
                        [ -5.27343750e-02,  -5.31921387e-02],
                        [ -2.73132324e-02,  -2.74353027e-02],
                        [  1.55334473e-02,   1.59606934e-02],
                        [  7.63244629e-02,   7.72094727e-02],
                        [  1.43249512e-01,   1.44409180e-01],
                        [  1.94091797e-01,   1.95556641e-01],
                        [  2.12829590e-01,   2.14721680e-01],
                        [  2.00408936e-01,   2.02484131e-01],
                        [  1.70074463e-01,   1.72241211e-01],
                        [  1.39404297e-01,   1.41754150e-01],
                        [  1.21368408e-01,   1.23870850e-01],
                        [  1.16149902e-01,   1.18499756e-01],
                        [  1.13616943e-01,   1.15600586e-01],
                        [  1.05529785e-01,   1.07421875e-01],
                        [  9.32617188e-02,   9.50622559e-02],
                        [  8.28247070e-02,   8.42285156e-02],
                        [  7.65686035e-02,   7.73010254e-02],
                        [  7.14416504e-02,   7.16857910e-02],
                        [  6.54602051e-02,   6.54296875e-02],
                        [  6.24084473e-02,   6.20117188e-02],
                        [  6.86035156e-02,   6.75964355e-02],
                        [  8.56628418e-02,   8.41369629e-02],
                        [  1.06658936e-01,   1.04736328e-01],
                        [  1.16790771e-01,   1.14624023e-01],
                        [  1.00616455e-01,   9.82971191e-02],
                        [  5.11779785e-02,   4.86755371e-02],
                        [ -2.57568359e-02,  -2.85034180e-02],
                        [ -1.11999512e-01,  -1.14837646e-01],
                        [ -1.79412842e-01,  -1.81976318e-01],
                        [ -2.01843262e-01,  -2.03979492e-01],
                        [ -1.77032471e-01,  -1.79046631e-01],
                        [ -1.33666992e-01,  -1.35681152e-01],
                        [ -1.04644775e-01,  -1.06109619e-01],
                        [ -9.43603516e-02,  -9.49401855e-02],
                        [ -8.38012695e-02,  -8.39843750e-02],
                        [ -6.38732910e-02,  -6.40563965e-02],
                        [ -4.53186035e-02,  -4.50134277e-02],
                        [ -3.72314453e-02,  -3.59497070e-02],
                        [ -3.45764160e-02,  -3.27453613e-02],
                        [ -3.09448242e-02,  -2.91748047e-02],
                        [ -2.74963379e-02,  -2.56652832e-02],
                        [ -2.50244141e-02,  -2.25830078e-02],
                        [ -2.00805664e-02,  -1.72119141e-02],
                        [ -1.28479004e-02,  -1.01318359e-02],
                        [ -7.87353516e-03,  -5.40161133e-03],
                        [ -5.58471680e-03,  -3.17382812e-03],
                        [ -3.60107422e-03,  -1.22070312e-03],
                        [ -5.18798828e-03,  -2.99072266e-03],
                        [ -1.49230957e-02,  -1.30310059e-02],
                        [ -2.83508301e-02,  -2.70080566e-02],
                        [ -3.73840332e-02,  -3.66210938e-02],
                        [ -4.15039062e-02,  -4.10156250e-02],
                        [ -4.56237793e-02,  -4.53186035e-02],
                        [ -5.30395508e-02,  -5.32836914e-02],
                        [ -6.37207031e-02,  -6.47277832e-02],
                        [ -7.06481934e-02,  -7.19909668e-02],
                        [ -5.90820312e-02,  -6.04858398e-02],
                        [ -2.12402344e-02,  -2.29187012e-02],
                        [  3.07617188e-02,   2.86254883e-02],
                        [  7.57446289e-02,   7.33947754e-02],
                        [  1.02691650e-01,   1.00402832e-01],
                        [  1.12609863e-01,   1.10290527e-01],
                        [  1.08612061e-01,   1.06231689e-01],
                        [  9.35363770e-02,   9.13391113e-02],
                        [  7.30285645e-02,   7.10754395e-02],
                        [  5.21850586e-02,   5.03540039e-02],
                        [  3.23486328e-02,   3.06701660e-02],
                        [  1.67846680e-02,   1.55944824e-02],
                        [  1.41906738e-02,   1.34887695e-02],
                        [  2.78015137e-02,   2.72521973e-02],
                        [  4.61730957e-02,   4.58374023e-02],
                        [  5.36499023e-02,   5.38330078e-02],
                        [  4.74243164e-02,   4.81567383e-02],
                        [  3.70483398e-02,   3.79028320e-02],
                        [  3.05480957e-02,   3.15246582e-02],
                        [  3.04565430e-02,   3.18603516e-02],
                        [  3.87573242e-02,   4.06188965e-02],
                        [  5.52978516e-02,   5.71289062e-02],
                        [  7.42492676e-02,   7.59887695e-02],
                        [  9.25598145e-02,   9.45129395e-02],
                        [  1.15417480e-01,   1.17645264e-01],
                        [  1.42913818e-01,   1.45050049e-01],
                        [  1.59637451e-01,   1.61499023e-01],
                        [  1.46728516e-01,   1.48437500e-01],
                        [  9.67407227e-02,   9.84191895e-02],
                        [  1.46179199e-02,   1.62048340e-02],
                        [ -8.51135254e-02,  -8.37402344e-02],
                        [ -1.81182861e-01,  -1.80297852e-01],
                        [ -2.52197266e-01,  -2.51800537e-01],
                        [ -2.81890869e-01,  -2.81585693e-01],
                        [ -2.63458252e-01,  -2.63153076e-01],
                        [ -2.08923340e-01,  -2.09075928e-01],
                        [ -1.49749756e-01,  -1.50634766e-01],
                        [ -1.14410400e-01,  -1.15600586e-01],
                        [ -1.04522705e-01,  -1.05621338e-01],
                        [ -1.01165771e-01,  -1.02416992e-01],
                        [ -9.22851562e-02,  -9.40856934e-02],
                        [ -8.41369629e-02,  -8.63342285e-02],
                        [ -8.43505859e-02,  -8.65173340e-02],
                        [ -8.60595703e-02,  -8.80737305e-02],
                        [ -7.60803223e-02,  -7.81555176e-02],
                        [ -5.08728027e-02,  -5.31921387e-02],
                        [ -1.87072754e-02,  -2.09960938e-02],
                        [  9.30786133e-03,   7.32421875e-03],
                        [  2.48107910e-02,   2.31628418e-02],
                        [  2.31628418e-02,   2.16674805e-02],
                        [  4.15039062e-03,   2.83813477e-03],
                        [ -2.46887207e-02,  -2.56347656e-02],
                        [ -4.95300293e-02,  -4.99267578e-02],
                        [ -6.08825684e-02,  -6.09130859e-02],
                        [ -6.18591309e-02,  -6.15844727e-02],
                        [ -5.98449707e-02,  -5.91125488e-02],
                        [ -5.40161133e-02,  -5.27954102e-02],
                        [ -3.64074707e-02,  -3.48510742e-02],
                        [ -8.54492188e-04,   1.00708008e-03],
                        [  5.25512695e-02,   5.47790527e-02],
                        [  1.15844727e-01,   1.18255615e-01],
                        [  1.72271729e-01,   1.74774170e-01],
                        [  2.04437256e-01,   2.07122803e-01],
                        [  2.07519531e-01,   2.10327148e-01],
                        [  1.91192627e-01,   1.93817139e-01],
                        [  1.66870117e-01,   1.69189453e-01],
                        [  1.39160156e-01,   1.41326904e-01],
                        [  1.11328125e-01,   1.13403320e-01],
                        [  8.90808105e-02,   9.07287598e-02],
                        [  7.51037598e-02,   7.60803223e-02],
                        [  6.75048828e-02,   6.80236816e-02],
                        [  6.47277832e-02,   6.49719238e-02],
                        [  6.52160645e-02,   6.50024414e-02],
                        [  6.49719238e-02,   6.40869141e-02],
                        [  6.18591309e-02,   6.04553223e-02],
                        [  5.88073730e-02,   5.70373535e-02],
                        [  5.85327148e-02,   5.63659668e-02],
                        [  6.02111816e-02,   5.76782227e-02],
                        [  6.47277832e-02,   6.20117188e-02],
                        [  7.60803223e-02,   7.32421875e-02],
                        [  9.29260254e-02,   8.98742676e-02],
                        [  1.03149414e-01,   1.00097656e-01],
                        [  9.21936035e-02,   8.93859863e-02],
                        [  5.39550781e-02,   5.14526367e-02],
                        [ -6.56127930e-03,  -8.88061523e-03],
                        [ -7.51953125e-02,  -7.72399902e-02],
                        [ -1.31561279e-01,  -1.33087158e-01],
                        [ -1.58569336e-01,  -1.59545898e-01],
                        [ -1.53503418e-01,  -1.54022217e-01],
                        [ -1.27746582e-01,  -1.27746582e-01],
                        [ -9.72595215e-02,  -9.67102051e-02],
                        [ -7.40051270e-02,  -7.29675293e-02],
                        [ -6.11572266e-02,  -5.96923828e-02],
                        [ -5.42297363e-02,  -5.23071289e-02],
                        [ -4.85839844e-02,  -4.62341309e-02],
                        [ -4.39453125e-02,  -4.13208008e-02],
                        [ -4.05578613e-02,  -3.77502441e-02],
                        [ -3.51867676e-02,  -3.23486328e-02],
                        [ -2.46276855e-02,  -2.17895508e-02],
                        [ -1.03454590e-02,  -7.44628906e-03],
                        [  2.04467773e-03,   4.79125977e-03],
                        [  7.47680664e-03,   9.85717773e-03],
                        [  5.52368164e-03,   7.47680664e-03],
                        [  0.00000000e+00,   1.64794922e-03],
                        [ -5.40161133e-03,  -4.05883789e-03],
                        [ -1.06201172e-02,  -9.76562500e-03],
                        [ -1.81579590e-02,  -1.78527832e-02],
                        [ -2.95104980e-02,  -2.96936035e-02],
                        [ -4.41894531e-02,  -4.48608398e-02],
                        [ -6.04858398e-02,  -6.15844727e-02],
                        [ -7.49816895e-02,  -7.63549805e-02],
                        [ -8.29772949e-02,  -8.46862793e-02],
                        [ -8.14514160e-02,  -8.36181641e-02],
                        [ -6.86035156e-02,  -7.11059570e-02],
                        [ -4.05883789e-02,  -4.30297852e-02],
                        [  4.91333008e-03,   2.62451172e-03],
                        [  5.85021973e-02,   5.60607910e-02],
                        [  9.94873047e-02,   9.68627930e-02],
                        [  1.12518311e-01,   1.10168457e-01],
                        [  1.01379395e-01,   9.94873047e-02],
                        [  8.09020996e-02,   7.92846680e-02],
                        [  6.05163574e-02,   5.90209961e-02],
                        [  4.18701172e-02,   4.06799316e-02],
                        [  2.70690918e-02,   2.63977051e-02],
                        [  1.97448730e-02,   1.95312500e-02],
                        [  2.04467773e-02,   2.05688477e-02],
                        [  2.67333984e-02,   2.71606445e-02],
                        [  3.48205566e-02,   3.56140137e-02],
                        [  4.06799316e-02,   4.18395996e-02],
                        [  4.30908203e-02,   4.45251465e-02],
                        [  4.40063477e-02,   4.55932617e-02],
                        [  4.45861816e-02,   4.63256836e-02],
                        [  4.58984375e-02,   4.78515625e-02],
                        [  5.22460938e-02,   5.42907715e-02],
                        [  6.75048828e-02,   6.94885254e-02],
                        [  8.91723633e-02,   9.10339355e-02],
                        [  1.10687256e-01,   1.12518311e-01],
                        [  1.27929688e-01,   1.29730225e-01],
                        [  1.39678955e-01,   1.41265869e-01],
                        [  1.41052246e-01,   1.42303467e-01],
                        [  1.19476318e-01,   1.20422363e-01],
                        [  6.30493164e-02,   6.38122559e-02],
                        [ -2.54211426e-02,  -2.48413086e-02],
                        [ -1.26983643e-01,  -1.26739502e-01],
                        [ -2.17620850e-01,  -2.17803955e-01],
                        [ -2.75848389e-01,  -2.76275635e-01],
                        [ -2.87170410e-01,  -2.87750244e-01],
                        [ -2.54180908e-01,  -2.54974365e-01],
                        [ -1.99127197e-01,  -2.00256348e-01],
                        [ -1.47796631e-01,  -1.49108887e-01],
                        [ -1.11206055e-01,  -1.12640381e-01],
                        [ -8.68225098e-02,  -8.83483887e-02],
                        [ -7.04956055e-02,  -7.21130371e-02],
                        [ -6.17980957e-02,  -6.34155273e-02],
                        [ -6.03027344e-02,  -6.18896484e-02],
                        [ -6.21948242e-02,  -6.37512207e-02],
                        [ -6.16760254e-02,  -6.31713867e-02],
                        [ -5.49316406e-02,  -5.63049316e-02],
                        [ -4.16564941e-02,  -4.28161621e-02],
                        [ -2.35900879e-02,  -2.45361328e-02],
                        [ -4.82177734e-03,  -5.61523438e-03],
                        [  7.17163086e-03,   6.59179688e-03],
                        [  6.16455078e-03,   5.88989258e-03],
                        [ -7.78198242e-03,  -7.72094727e-03],
                        [ -2.99682617e-02,  -2.97851562e-02],
                        [ -5.45349121e-02,  -5.41381836e-02],
                        [ -7.32727051e-02,  -7.25097656e-02],
                        [ -7.72705078e-02,  -7.62634277e-02],
                        [ -6.31713867e-02,  -6.21032715e-02],
                        [ -3.33251953e-02,  -3.21960449e-02],
                        [  1.02844238e-02,   1.17187500e-02],
                        [  6.62231445e-02,   6.78100586e-02],
                        [  1.25976562e-01,   1.27471924e-01],
                        [  1.73034668e-01,   1.74407959e-01],
                        [  1.93603516e-01,   1.95037842e-01],
                        [  1.86859131e-01,   1.88354492e-01],
                        [  1.63085938e-01,   1.64398193e-01],
                        [  1.34216309e-01,   1.35223389e-01],
                        [  1.09313965e-01,   1.10168457e-01],
                        [  9.36584473e-02,   9.43603516e-02],
                        [  8.62426758e-02,   8.67004395e-02],
                        [  8.16650391e-02,   8.18786621e-02],
                        [  7.87048340e-02,   7.87353516e-02],
                        [  8.00476074e-02,   7.97729492e-02],
                        [  8.14514160e-02,   8.07800293e-02],
                        [  7.18688965e-02,   7.10449219e-02],
                        [  4.93774414e-02,   4.86450195e-02],
                        [  2.76794434e-02,   2.67639160e-02],
                        [  2.05993652e-02,   1.92565918e-02],
                        [  2.81372070e-02,   2.65502930e-02],
                        [  4.22058105e-02,   4.08630371e-02],
                        [  6.00585938e-02,   5.89904785e-02],
                        [  8.35876465e-02,   8.23669434e-02],
                        [  1.09252930e-01,   1.07757568e-01],
                        [  1.26617432e-01,   1.25274658e-01],
                        [  1.25976562e-01,   1.25152588e-01],
                        [  1.01043701e-01,   1.00463867e-01],
                        [  4.66613770e-02,   4.59899902e-02],
                        [ -3.48205566e-02,  -3.54614258e-02],
                        [ -1.22985840e-01,  -1.23229980e-01],
                        [ -1.84997559e-01,  -1.84753418e-01],
                        [ -1.99798584e-01,  -1.99462891e-01],
                        [ -1.75720215e-01,  -1.75445557e-01],
                        [ -1.40258789e-01,  -1.39770508e-01],
                        [ -1.14135742e-01,  -1.13250732e-01],
                        [ -9.82055664e-02,  -9.72290039e-02],
                        [ -8.33129883e-02,  -8.24279785e-02],
                        [ -6.38122559e-02,  -6.28967285e-02],
                        [ -4.11987305e-02,  -4.00085449e-02],
                        [ -2.20336914e-02,  -2.08129883e-02],
                        [ -1.49230957e-02,  -1.40380859e-02],
                        [ -2.23083496e-02,  -2.15454102e-02],
                        [ -3.38134766e-02,  -3.28674316e-02],
                        [ -3.53698730e-02,  -3.44543457e-02],
                        [ -2.53906250e-02,  -2.48718262e-02],
                        [ -1.48925781e-02,  -1.46484375e-02],
                        [ -1.15051270e-02,  -1.12304688e-02],
                        [ -1.19323730e-02,  -1.16577148e-02],
                        [ -1.12609863e-02,  -1.12915039e-02],
                        [ -1.17187500e-02,  -1.20239258e-02],
                        [ -1.76086426e-02,  -1.79138184e-02],
                        [ -2.90527344e-02,  -2.93884277e-02],
                        [ -4.53186035e-02,  -4.58679199e-02],
                        [ -6.62536621e-02,  -6.69250488e-02],
                        [ -8.61816406e-02,  -8.67614746e-02],
                        [ -9.34448242e-02,  -9.40551758e-02],
                        [ -7.97729492e-02,  -8.05358887e-02],
                        [ -4.43725586e-02,  -4.50744629e-02],
                        [  7.50732422e-03,   6.95800781e-03],
                        [  6.35070801e-02,   6.29882812e-02],
                        [  1.06323242e-01,   1.05804443e-01],
                        [  1.25305176e-01,   1.24938965e-01],
                        [  1.22741699e-01,   1.22467041e-01],
                        [  1.07086182e-01,   1.06811523e-01],
                        [  8.64868164e-02,   8.63647461e-02],
                        [  6.90002441e-02,   6.91528320e-02],
                        [  5.83496094e-02,   5.84716797e-02],
                        [  4.90722656e-02,   4.90112305e-02],
                        [  3.60717773e-02,   3.61938477e-02],
                        [  2.65808105e-02,   2.70385742e-02],
                        [  3.00292969e-02,   3.04565430e-02],
                        [  4.09240723e-02,   4.10766602e-02],
                        [  4.62036133e-02,   4.63562012e-02],
                        [  4.48303223e-02,   4.52270508e-02],
                        [  4.64477539e-02,   4.68750000e-02],
                        [  5.55419922e-02,   5.56945801e-02],
                        [  6.93054199e-02,   6.93664551e-02],
                        [  8.68530273e-02,   8.70361328e-02],
                        [  1.09375000e-01,   1.09558105e-01],
                        [  1.33178711e-01,   1.33209229e-01],
                        [  1.49200439e-01,   1.49169922e-01],
                        [  1.48254395e-01,   1.48162842e-01],
                        [  1.23657227e-01,   1.23565674e-01],
                        [  7.26013184e-02,   7.25402832e-02],
                        [ -2.41088867e-03,  -2.47192383e-03],
                        [ -9.35974121e-02,  -9.38110352e-02],
                        [ -1.87103271e-01,  -1.87377930e-01],
                        [ -2.59552002e-01,  -2.59643555e-01],
                        [ -2.84942627e-01,  -2.84881592e-01],
                        [ -2.56866455e-01,  -2.56958008e-01],
                        [ -1.99920654e-01,  -2.00195312e-01],
                        [ -1.48590088e-01,  -1.48681641e-01],
                        [ -1.18225098e-01,  -1.17950439e-01],
                        [ -1.02355957e-01,  -1.02081299e-01],
                        [ -9.06066895e-02,  -9.05761719e-02],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -7.44628906e-02,  -7.41271973e-02],
                        [ -6.97937012e-02,  -6.92443848e-02],
                        [ -6.10046387e-02,  -6.06079102e-02],
                        [ -4.58984375e-02,  -4.57153320e-02],
                        [ -2.64587402e-02,  -2.61840820e-02],
                        [ -5.88989258e-03,  -5.43212891e-03],
                        [  9.39941406e-03,   9.82666016e-03],
                        [  1.22070312e-02,   1.25122070e-02],
                        [  3.99780273e-03,   4.21142578e-03],
                        [ -7.59887695e-03,  -7.44628906e-03],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -7.06787109e-02,  -7.06481934e-02],
                        [ -8.23059082e-02,  -8.25195312e-02],
                        [ -7.21435547e-02,  -7.26318359e-02],
                        [ -4.52270508e-02,  -4.57153320e-02],
                        [ -6.13403320e-03,  -6.56127930e-03],
                        [  4.73937988e-02,   4.68444824e-02],
                        [  1.14410400e-01,   1.13677979e-01],
                        [  1.81579590e-01,   1.80786133e-01],
                        [  2.26623535e-01,   2.25830078e-01],
                        [  2.31292725e-01,   2.30499268e-01],
                        [  1.96838379e-01,   1.96136475e-01],
                        [  1.46301270e-01,   1.45660400e-01],
                        [  1.05560303e-01,   1.04827881e-01],
                        [  8.39538574e-02,   8.32519531e-02],
                        [  7.66906738e-02,   7.63244629e-02],
                        [  7.64770508e-02,   7.63549805e-02],
                        [  7.66601562e-02,   7.65075684e-02],
                        [  7.18994141e-02,   7.18078613e-02],
                        [  6.17675781e-02,   6.20422363e-02],
                        [  4.89196777e-02,   4.94995117e-02],
                        [  3.40881348e-02,   3.46984863e-02],
                        [  1.80053711e-02,   1.86462402e-02],
                        [  6.28662109e-03,   7.26318359e-03],
                        [  6.92749023e-03,   8.14819336e-03],
                        [  2.16064453e-02,   2.27661133e-02],
                        [  4.33959961e-02,   4.44335938e-02],
                        [  6.52770996e-02,   6.65283203e-02],
                        [  8.73413086e-02,   8.88061523e-02],
                        [  1.11022949e-01,   1.12304688e-01],
                        [  1.30828857e-01,   1.31774902e-01],
                        [  1.37023926e-01,   1.37878418e-01],
                        [  1.21368408e-01,   1.22283936e-01],
                        [  7.67211914e-02,   7.75146484e-02],
                        [  3.66210938e-04,   7.32421875e-04],
                        [ -9.50927734e-02,  -9.50927734e-02],
                        [ -1.79199219e-01,  -1.79382324e-01],
                        [ -2.20367432e-01,  -2.20672607e-01],
                        [ -2.09106445e-01,  -2.09686279e-01],
                        [ -1.64550781e-01,  -1.65435791e-01],
                        [ -1.16821289e-01,  -1.18011475e-01],
                        [ -8.53881836e-02,  -8.67919922e-02],
                        [ -7.15942383e-02,  -7.30895996e-02],
                        [ -6.54296875e-02,  -6.69250488e-02],
                        [ -5.84716797e-02,  -6.00891113e-02],
                        [ -5.34973145e-02,  -5.52978516e-02],
                        [ -5.71899414e-02,  -5.89294434e-02],
                        [ -6.31408691e-02,  -6.46057129e-02],
                        [ -5.49011230e-02,  -5.62133789e-02],
                        [ -2.84118652e-02,  -2.97241211e-02],
                        [  2.16674805e-03,   1.00708008e-03],
                        [  2.21557617e-02,   2.14538574e-02],
                        [  2.69775391e-02,   2.66113281e-02],
                        [  1.77917480e-02,   1.76391602e-02],
                        [ -4.88281250e-04,  -4.27246094e-04],
                        [ -1.95617676e-02,  -1.91650391e-02],
                        [ -3.39660645e-02,  -3.30810547e-02],
                        [ -4.57763672e-02,  -4.45861816e-02],
                        [ -6.15234375e-02,  -6.03027344e-02],
                        [ -8.36486816e-02,  -8.22753906e-02],
                        [ -1.03057861e-01,  -1.01318359e-01],
                        [ -1.03027344e-01,  -1.01013184e-01],
                        [ -7.56835938e-02,  -7.37609863e-02],
                        [ -3.08837891e-02,  -2.90832520e-02],
                        [  1.61132812e-02,   1.79138184e-02],
                        [  5.77697754e-02,   5.96008301e-02],
                        [  9.10949707e-02,   9.28344727e-02],
                        [  1.10382080e-01,   1.11877441e-01],
                        [  1.09985352e-01,   1.11114502e-01],
                        [  9.16748047e-02,   9.24377441e-02],
                        [  6.68945312e-02,   6.75659180e-02],
                        [  5.03845215e-02,   5.09033203e-02],
                        [  4.74548340e-02,   4.74853516e-02],
                        [  5.05065918e-02,   4.98962402e-02],
                        [  5.14526367e-02,   5.06591797e-02],
                        [  5.27343750e-02,   5.19714355e-02],
                        [  5.93872070e-02,   5.82885742e-02],
                        [  6.74133301e-02,   6.57348633e-02],
                        [  6.90917969e-02,   6.72607422e-02],
                        [  6.61010742e-02,   6.44226074e-02],
                        [  6.66503906e-02,   6.48193359e-02],
                        [  7.21435547e-02,   6.99768066e-02],
                        [  7.74841309e-02,   7.53173828e-02],
                        [  8.37402344e-02,   8.19702148e-02],
                        [  9.83886719e-02,   9.66796875e-02],
                        [  1.20635986e-01,   1.18774414e-01],
                        [  1.37512207e-01,   1.35833740e-01],
                        [  1.34704590e-01,   1.33514404e-01],
                        [  1.02508545e-01,   1.01654053e-01],
                        [  3.53088379e-02,   3.45458984e-02],
                        [ -6.32019043e-02,  -6.37207031e-02],
                        [ -1.72790527e-01,  -1.72882080e-01],
                        [ -2.60742188e-01,  -2.60437012e-01],
                        [ -2.97149658e-01,  -2.96447754e-01],
                        [ -2.73223877e-01,  -2.72277832e-01],
                        [ -2.10479736e-01,  -2.09289551e-01],
                        [ -1.46118164e-01,  -1.44653320e-01],
                        [ -1.05834961e-01,  -1.04064941e-01],
                        [ -9.07592773e-02,  -8.87756348e-02],
                        [ -8.73718262e-02,  -8.51745605e-02],
                        [ -8.36181641e-02,  -8.13598633e-02],
                        [ -7.80944824e-02,  -7.59582520e-02],
                        [ -7.68127441e-02,  -7.46765137e-02],
                        [ -7.93457031e-02,  -7.70263672e-02],
                        [ -7.34558105e-02,  -7.11669922e-02],
                        [ -5.14221191e-02,  -4.95605469e-02],
                        [ -2.34680176e-02,  -2.20947266e-02],
                        [ -3.93676758e-03,  -2.62451172e-03],
                        [  6.56127930e-03,   7.87353516e-03],
                        [  1.32141113e-02,   1.40686035e-02],
                        [  1.14746094e-02,   1.15356445e-02],
                        [ -7.50732422e-03,  -7.87353516e-03],
                        [ -4.02526855e-02,  -4.07104492e-02],
                        [ -7.01904297e-02,  -7.09228516e-02],
                        [ -8.30078125e-02,  -8.43811035e-02],
                        [ -7.48291016e-02,  -7.67822266e-02],
                        [ -4.46472168e-02,  -4.67224121e-02],
                        [  1.00708008e-02,   7.87353516e-03],
                        [  8.26110840e-02,   8.00476074e-02],
                        [  1.51550293e-01,   1.48681641e-01],
                        [  1.94793701e-01,   1.91955566e-01],
                        [  2.05078125e-01,   2.02362061e-01],
                        [  1.89086914e-01,   1.86309814e-01],
                        [  1.59912109e-01,   1.57196045e-01],
                        [  1.31866455e-01,   1.29547119e-01],
                        [  1.13220215e-01,   1.11267090e-01],
                        [  1.01043701e-01,   9.92736816e-02],
                        [  8.86840820e-02,   8.73413086e-02],
                        [  7.69958496e-02,   7.63549805e-02],
                        [  7.03735352e-02,   7.02514648e-02],
                        [  6.49719238e-02,   6.51245117e-02],
                        [  5.21850586e-02,   5.29479980e-02],
                        [  3.34777832e-02,   3.50646973e-02],
                        [  1.79138184e-02,   1.99279785e-02],
                        [  6.46972656e-03,   8.57543945e-03],
                        [ -5.40161133e-03,  -2.83813477e-03],
                        [ -1.21154785e-02,  -8.85009766e-03],
                        [ -3.29589844e-03,   1.52587891e-04],
                        [  1.63574219e-02,   1.95617676e-02],
                        [  3.14025879e-02,   3.46374512e-02],
                        [  3.90014648e-02,   4.24499512e-02],
                        [  5.14831543e-02,   5.48095703e-02],
                        [  7.63549805e-02,   7.91625977e-02],
                        [  1.07452393e-01,   1.09832764e-01],
                        [  1.32995605e-01,   1.35101318e-01],
                        [  1.38092041e-01,   1.39709473e-01],
                        [  1.04858398e-01,   1.05804443e-01],
                        [  2.64282227e-02,   2.67639160e-02],
                        [ -7.77587891e-02,  -7.80029297e-02],
                        [ -1.69555664e-01,  -1.70440674e-01],
                        [ -2.16339111e-01,  -2.17864990e-01],
                        [ -2.10296631e-01,  -2.12341309e-01],
                        [ -1.69769287e-01,  -1.72302246e-01],
                        [ -1.24023438e-01,  -1.26983643e-01],
                        [ -9.21325684e-02,  -9.54589844e-02],
                        [ -7.56835938e-02,  -7.92236328e-02],
                        [ -6.85119629e-02,  -7.22045898e-02],
                        [ -6.70776367e-02,  -7.07702637e-02],
                        [ -7.00073242e-02,  -7.35778809e-02],
                        [ -7.38830566e-02,  -7.72094727e-02],
                        [ -7.35168457e-02,  -7.65686035e-02],
                        [ -6.67114258e-02,  -6.94274902e-02],
                        [ -5.43212891e-02,  -5.65490723e-02],
                        [ -3.52478027e-02,  -3.68041992e-02],
                        [ -8.66699219e-03,  -9.64355469e-03],
                        [  1.59912109e-02,   1.55334473e-02],
                        [  2.26745605e-02,   2.28271484e-02],
                        [  7.04956055e-03,   7.90405273e-03],
                        [ -1.81884766e-02,  -1.67236328e-02],
                        [ -3.85131836e-02,  -3.65600586e-02],
                        [ -5.00793457e-02,  -4.75769043e-02],
                        [ -5.80139160e-02,  -5.50842285e-02],
                        [ -6.98547363e-02,  -6.67419434e-02],
                        [ -8.70666504e-02,  -8.37707520e-02],
                        [ -9.89074707e-02,  -9.53063965e-02],
                        [ -8.88061523e-02,  -8.51135254e-02],
                        [ -5.15136719e-02,  -4.81567383e-02],
                        [  4.27246094e-04,   3.44848633e-03],
                        [  4.94689941e-02,   5.24597168e-02],
                        [  8.60595703e-02,   8.88977051e-02],
                        [  1.06201172e-01,   1.08398438e-01],
                        [  1.06567383e-01,   1.08062744e-01],
                        [  9.13696289e-02,   9.24682617e-02],
                        [  7.56225586e-02,   7.64465332e-02],
                        [  7.03430176e-02,   7.04650879e-02],
                        [  6.99462891e-02,   6.93054199e-02],
                        [  6.59484863e-02,   6.48803711e-02],
                        [  6.30187988e-02,   6.16760254e-02],
                        [  6.91528320e-02,   6.72302246e-02],
                        [  7.83996582e-02,   7.58666992e-02],
                        [  7.80639648e-02,   7.53479004e-02],
                        [  6.82678223e-02,   6.55822754e-02],
                        [  6.14929199e-02,   5.85632324e-02],
                        [  6.46667480e-02,   6.12792969e-02],
                        [  7.40661621e-02,   7.06787109e-02],
                        [  8.81347656e-02,   8.52661133e-02],
                        [  1.10534668e-01,   1.07940674e-01],
                        [  1.35711670e-01,   1.32934570e-01],
                        [  1.45690918e-01,   1.42974854e-01],
                        [  1.28417969e-01,   1.26403809e-01],
                        [  8.70666504e-02,   8.57543945e-02],
                        [  2.40478516e-02,   2.29492188e-02],
                        [ -6.64062500e-02,  -6.73217773e-02],
                        [ -1.76391602e-01,  -1.76757812e-01],
                        [ -2.70904541e-01,  -2.70568848e-01],
                        [ -3.10852051e-01,  -3.09997559e-01],
                        [ -2.85491943e-01,  -2.84271240e-01],
                        [ -2.19238281e-01,  -2.17742920e-01],
                        [ -1.51031494e-01,  -1.49139404e-01],
                        [ -1.06262207e-01,  -1.03912354e-01],
                        [ -8.57849121e-02,  -8.30688477e-02],
                        [ -7.81860352e-02,  -7.53784180e-02],
                        [ -7.53784180e-02,  -7.25097656e-02],
                        [ -7.38830566e-02,  -7.08618164e-02],
                        [ -7.11975098e-02,  -6.80847168e-02],
                        [ -6.62841797e-02,  -6.33239746e-02],
                        [ -5.88073730e-02,  -5.60607910e-02],
                        [ -4.64172363e-02,  -4.38232422e-02],
                        [ -2.79235840e-02,  -2.56042480e-02],
                        [ -8.14819336e-03,  -6.22558594e-03],
                        [  4.63867188e-03,   6.16455078e-03],
                        [  4.97436523e-03,   6.07299805e-03],
                        [ -7.84301758e-03,  -7.32421875e-03],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -5.38330078e-02,  -5.42297363e-02],
                        [ -6.53991699e-02,  -6.63146973e-02],
                        [ -5.74645996e-02,  -5.90209961e-02],
                        [ -3.24096680e-02,  -3.44848633e-02],
                        [  5.79833984e-03,   3.50952148e-03],
                        [  5.93872070e-02,   5.67932129e-02],
                        [  1.25793457e-01,   1.22711182e-01],
                        [  1.85424805e-01,   1.82006836e-01],
                        [  2.14202881e-01,   2.10784912e-01],
                        [  2.07550049e-01,   2.04254150e-01],
                        [  1.81182861e-01,   1.77886963e-01],
                        [  1.50115967e-01,   1.46850586e-01],
                        [  1.19659424e-01,   1.16607666e-01],
                        [  9.32006836e-02,   9.06372070e-02],
                        [  7.43713379e-02,   7.22961426e-02],
                        [  6.18286133e-02,   6.01501465e-02],
                        [  5.31616211e-02,   5.19714355e-02],
                        [  5.06591797e-02,   5.01098633e-02],
                        [  5.45043945e-02,   5.45959473e-02],
                        [  5.53588867e-02,   5.60302734e-02],
                        [  4.27246094e-02,   4.40063477e-02],
                        [  1.87683105e-02,   2.06604004e-02],
                        [ -3.02124023e-03,  -6.40869141e-04],
                        [ -1.16577148e-02,  -8.88061523e-03],
                        [ -6.43920898e-03,  -3.26538086e-03],
                        [  7.38525391e-03,   1.09252930e-02],
                        [  2.47192383e-02,   2.83813477e-02],
                        [  4.16564941e-02,   4.52880859e-02],
                        [  5.60913086e-02,   5.97229004e-02],
                        [  6.89086914e-02,   7.24487305e-02],
                        [  8.12988281e-02,   8.45031738e-02],
                        [  9.17053223e-02,   9.44824219e-02],
                        [  9.89074707e-02,   1.01287842e-01],
                        [  1.02935791e-01,   1.04858398e-01],
                        [  9.78393555e-02,   9.91210938e-02],
                        [  7.09838867e-02,   7.15332031e-02],
                        [  1.49230957e-02,   1.48925781e-02],
                        [ -6.26525879e-02,  -6.32629395e-02],
                        [ -1.40594482e-01,  -1.41784668e-01],
                        [ -1.93054199e-01,  -1.94915771e-01],
                        [ -2.03277588e-01,  -2.05718994e-01],
                        [ -1.75048828e-01,  -1.77886963e-01],
                        [ -1.30065918e-01,  -1.33087158e-01],
                        [ -9.15832520e-02,  -9.48181152e-02],
                        [ -7.10754395e-02,  -7.46154785e-02],
                        [ -6.66503906e-02,  -7.03430176e-02],
                        [ -6.89392090e-02,  -7.24487305e-02],
                        [ -6.86035156e-02,  -7.17163086e-02],
                        [ -6.30493164e-02,  -6.58874512e-02],
                        [ -5.83190918e-02,  -6.10351562e-02],
                        [ -6.06994629e-02,  -6.30798340e-02],
                        [ -6.41174316e-02,  -6.58264160e-02],
                        [ -5.36499023e-02,  -5.45959473e-02],
                        [ -2.62145996e-02,  -2.66723633e-02],
                        [  1.15966797e-03,   9.76562500e-04],
                        [  1.10168457e-02,   1.14135742e-02],
                        [  4.11987305e-03,   5.31005859e-03],
                        [ -8.05664062e-03,  -6.37817383e-03],
                        [ -2.12402344e-02,  -1.93176270e-02],
                        [ -4.02526855e-02,  -3.80249023e-02],
                        [ -6.61315918e-02,  -6.35070801e-02],
                        [ -8.88977051e-02,  -8.60900879e-02],
                        [ -9.68017578e-02,  -9.39636230e-02],
                        [ -8.58459473e-02,  -8.29772949e-02],
                        [ -5.79528809e-02,  -5.50842285e-02],
                        [ -1.60217285e-02,  -1.33361816e-02],
                        [  3.40576172e-02,   3.64379883e-02],
                        [  8.06884766e-02,   8.28552246e-02],
                        [  1.10565186e-01,   1.12457275e-01],
                        [  1.16821289e-01,   1.18316650e-01],
                        [  1.04339600e-01,   1.05407715e-01],
                        [  8.58764648e-02,   8.65478516e-02],
                        [  7.15637207e-02,   7.18383789e-02],
                        [  6.30187988e-02,   6.28356934e-02],
                        [  5.83801270e-02,   5.78918457e-02],
                        [  5.83496094e-02,   5.75561523e-02],
                        [  6.36596680e-02,   6.24694824e-02],
                        [  7.13500977e-02,   6.97937012e-02],
                        [  7.63549805e-02,   7.45849609e-02],
                        [  7.52258301e-02,   7.34558105e-02],
                        [  6.95495605e-02,   6.76574707e-02],
                        [  6.51550293e-02,   6.30493164e-02],
                        [  6.66809082e-02,   6.44836426e-02],
                        [  7.52563477e-02,   7.31811523e-02],
                        [  9.14611816e-02,   8.96301270e-02],
                        [  1.13861084e-01,   1.12060547e-01],
                        [  1.32843018e-01,   1.31011963e-01],
                        [  1.32476807e-01,   1.30859375e-01],
                        [  9.89074707e-02,   9.76562500e-02],
                        [  2.58483887e-02,   2.48413086e-02],
                        [ -8.01391602e-02,  -8.09936523e-02],
                        [ -1.93084717e-01,  -1.93695068e-01],
                        [ -2.75695801e-01,  -2.75970459e-01],
                        [ -3.03344727e-01,  -3.03283691e-01],
                        [ -2.78015137e-01,  -2.77770996e-01],
                        [ -2.21679688e-01,  -2.21221924e-01],
                        [ -1.61621094e-01,  -1.60858154e-01],
                        [ -1.17126465e-01,  -1.16088867e-01],
                        [ -9.17053223e-02,  -9.04541016e-02],
                        [ -7.92236328e-02,  -7.78198242e-02],
                        [ -7.51647949e-02,  -7.36083984e-02],
                        [ -7.57751465e-02,  -7.40966797e-02],
                        [ -7.20214844e-02,  -7.02209473e-02],
                        [ -5.49011230e-02,  -5.30090332e-02],
                        [ -2.61535645e-02,  -2.42919922e-02],
                        [  1.55639648e-03,   3.32641602e-03],
                        [  1.51367188e-02,   1.68151855e-02],
                        [  1.13220215e-02,   1.30004883e-02],
                        [ -2.22778320e-03,  -7.01904297e-04],
                        [ -1.89208984e-02,  -1.76696777e-02],
                        [ -4.06494141e-02,  -3.97644043e-02],
                        [ -6.73522949e-02,  -6.66198730e-02],
                        [ -8.66088867e-02,  -8.60595703e-02],
                        [ -8.38928223e-02,  -8.37097168e-02],
                        [ -5.67016602e-02,  -5.69152832e-02],
                        [ -1.23596191e-02,  -1.28784180e-02],
                        [  4.18701172e-02,   4.11071777e-02],
                        [  1.00860596e-01,   9.97619629e-02],
                        [  1.55456543e-01,   1.54083252e-01],
                        [  1.91864014e-01,   1.90307617e-01],
                        [  2.00958252e-01,   1.99188232e-01],
                        [  1.85760498e-01,   1.83746338e-01],
                        [  1.58874512e-01,   1.56768799e-01],
                        [  1.34155273e-01,   1.32202148e-01],
                        [  1.17279053e-01,   1.15417480e-01],
                        [  1.02569580e-01,   1.00555420e-01],
                        [  8.24584961e-02,   8.04748535e-02],
                        [  6.04248047e-02,   5.88378906e-02],
                        [  4.72412109e-02,   4.61120605e-02],
                        [  4.52575684e-02,   4.42504883e-02],
                        [  4.37316895e-02,   4.27856445e-02],
                        [  3.24401855e-02,   3.19824219e-02],
                        [  1.28479004e-02,   1.29699707e-02],
                        [ -5.98144531e-03,  -5.58471680e-03],
                        [ -1.64184570e-02,  -1.58691406e-02],
                        [ -1.64184570e-02,  -1.55334473e-02],
                        [ -8.75854492e-03,  -7.41577148e-03],
                        [  2.38037109e-03,   3.96728516e-03],
                        [  1.46789551e-02,   1.62658691e-02],
                        [  2.81677246e-02,   2.99072266e-02],
                        [  4.37316895e-02,   4.57458496e-02],
                        [  6.16149902e-02,   6.36596680e-02],
                        [  8.02001953e-02,   8.20007324e-02],
                        [  9.51843262e-02,   9.68322754e-02],
                        [  1.02539062e-01,   1.04248047e-01],
                        [  1.03393555e-01,   1.05010986e-01],
                        [  1.00891113e-01,   1.02111816e-01],
                        [  9.05456543e-02,   9.14001465e-02],
                        [  5.86547852e-02,   5.92956543e-02],
                        [ -5.82885742e-03,  -5.37109375e-03],
                        [ -9.49401855e-02,  -9.48486328e-02],
                        [ -1.78588867e-01,  -1.78863525e-01],
                        [ -2.22869873e-01,  -2.23358154e-01],
                        [ -2.15515137e-01,  -2.16247559e-01],
                        [ -1.74224854e-01,  -1.75201416e-01],
                        [ -1.30920410e-01,  -1.32049561e-01],
                        [ -1.06018066e-01,  -1.07208252e-01],
                        [ -9.53063965e-02,  -9.65881348e-02],
                        [ -8.26416016e-02,  -8.41064453e-02],
                        [ -6.36596680e-02,  -6.51245117e-02],
                        [ -4.96826172e-02,  -5.09643555e-02],
                        [ -4.87365723e-02,  -4.98657227e-02],
                        [ -5.35888672e-02,  -5.47790527e-02],
                        [ -5.30700684e-02,  -5.42297363e-02],
                        [ -4.52880859e-02,  -4.62036133e-02],
                        [ -3.40881348e-02,  -3.46984863e-02],
                        [ -2.25219727e-02,  -2.30102539e-02],
                        [ -1.41906738e-02,  -1.46484375e-02],
                        [ -1.32446289e-02,  -1.35192871e-02],
                        [ -2.09655762e-02,  -2.09960938e-02],
                        [ -3.63159180e-02,  -3.61938477e-02],
                        [ -5.71594238e-02,  -5.69152832e-02],
                        [ -7.78503418e-02,  -7.75451660e-02],
                        [ -8.98742676e-02,  -8.95080566e-02],
                        [ -8.88671875e-02,  -8.84094238e-02],
                        [ -7.65686035e-02,  -7.60192871e-02],
                        [ -5.36499023e-02,  -5.30700684e-02],
                        [ -1.82800293e-02,  -1.77001953e-02],
                        [  2.63671875e-02,   2.69775391e-02],
                        [  7.08618164e-02,   7.14721680e-02],
                        [  1.05834961e-01,   1.06506348e-01],
                        [  1.24359131e-01,   1.25030518e-01],
                        [  1.22039795e-01,   1.22680664e-01],
                        [  1.02111816e-01,   1.02722168e-01],
                        [  7.72705078e-02,   7.79113770e-02],
                        [  6.13708496e-02,   6.20422363e-02],
                        [  5.97229004e-02,   6.03332520e-02],
                        [  6.74133301e-02,   6.79626465e-02],
                        [  7.55310059e-02,   7.61413574e-02],
                        [  7.93151855e-02,   7.99255371e-02],
                        [  8.16040039e-02,   8.20922852e-02],
                        [  8.67309570e-02,   8.71582031e-02],
                        [  9.31701660e-02,   9.35363770e-02],
                        [  9.63745117e-02,   9.66796875e-02],
                        [  9.61914062e-02,   9.64050293e-02],
                        [  9.71069336e-02,   9.72290039e-02],
                        [  1.03607178e-01,   1.03546143e-01],
                        [  1.15509033e-01,   1.15264893e-01],
                        [  1.24328613e-01,   1.23931885e-01],
                        [  1.13494873e-01,   1.13067627e-01],
                        [  6.67419434e-02,   6.61621094e-02],
                        [ -1.99890137e-02,  -2.08129883e-02],
                        [ -1.30798340e-01,  -1.31866455e-01],
                        [ -2.32452393e-01,  -2.33520508e-01],
                        [ -2.88574219e-01,  -2.89611816e-01],
                        [ -2.83630371e-01,  -2.84790039e-01],
                        [ -2.36572266e-01,  -2.37854004e-01],
                        [ -1.84326172e-01,  -1.85607910e-01],
                        [ -1.49749756e-01,  -1.50909424e-01],
                        [ -1.29211426e-01,  -1.30249023e-01],
                        [ -1.08551025e-01,  -1.09527588e-01],
                        [ -8.38317871e-02,  -8.46862793e-02],
                        [ -6.24694824e-02,  -6.31103516e-02],
                        [ -5.04455566e-02,  -5.08728027e-02],
                        [ -4.60510254e-02,  -4.62646484e-02],
                        [ -4.37927246e-02,  -4.37316895e-02],
                        [ -3.87878418e-02,  -3.84216309e-02],
                        [ -2.99682617e-02,  -2.93884277e-02],
                        [ -2.10266113e-02,  -2.03247070e-02],
                        [ -1.64794922e-02,  -1.54724121e-02],
                        [ -1.75170898e-02,  -1.61743164e-02],
                        [ -2.36511230e-02,  -2.22167969e-02],
                        [ -3.50341797e-02,  -3.36914062e-02],
                        [ -4.79736328e-02,  -4.65087891e-02],
                        [ -5.13916016e-02,  -4.97131348e-02],
                        [ -3.62854004e-02,  -3.46374512e-02],
                        [ -5.24902344e-03,  -3.84521484e-03],
                        [  3.60717773e-02,   3.73535156e-02],
                        [  8.93249512e-02,   9.06066895e-02],
                        [  1.51306152e-01,   1.52374268e-01],
                        [  1.99798584e-01,   2.00500488e-01],
                        [  2.09503174e-01,   2.09930420e-01],
                        [  1.82373047e-01,   1.82678223e-01],
                        [  1.47888184e-01,   1.47979736e-01],
                        [  1.30554199e-01,   1.30187988e-01],
                        [  1.26464844e-01,   1.25762939e-01],
                        [  1.16912842e-01,   1.16119385e-01],
                        [  9.56420898e-02,   9.47875977e-02],
                        [  7.35168457e-02,   7.23266602e-02],
                        [  5.96923828e-02,   5.81665039e-02],
                        [  5.08117676e-02,   4.92858887e-02],
                        [  3.95812988e-02,   3.81774902e-02],
                        [  2.41699219e-02,   2.27355957e-02],
                        [  8.05664062e-03,   6.50024414e-03],
                        [ -3.60107422e-03,  -5.09643555e-03],
                        [ -8.02612305e-03,  -9.33837891e-03],
                        [ -6.86645508e-03,  -8.02612305e-03],
                        [ -3.17382812e-03,  -4.18090820e-03],
                        [  1.61743164e-03,   8.23974609e-04],
                        [  7.78198242e-03,   7.23266602e-03],
                        [  1.52893066e-02,   1.48925781e-02],
                        [  2.20031738e-02,   2.18200684e-02],
                        [  2.63366699e-02,   2.64892578e-02],
                        [  3.20434570e-02,   3.24401855e-02],
                        [  4.61730957e-02,   4.66613770e-02],
                        [  6.90307617e-02,   6.96716309e-02],
                        [  8.99047852e-02,   9.07897949e-02],
                        [  9.78698730e-02,   9.89379883e-02],
                        [  9.41162109e-02,   9.52148438e-02],
                        [  8.60900879e-02,   8.72497559e-02],
                        [  7.14416504e-02,   7.26623535e-02],
                        [  3.54309082e-02,   3.66821289e-02],
                        [ -3.29895020e-02,  -3.17382812e-02],
                        [ -1.22039795e-01,  -1.20819092e-01],
                        [ -1.96136475e-01,  -1.95007324e-01],
                        [ -2.21649170e-01,  -2.20611572e-01],
                        [ -1.95800781e-01,  -1.94885254e-01],
                        [ -1.46759033e-01,  -1.45935059e-01],
                        [ -1.05407715e-01,  -1.04736328e-01],
                        [ -8.19091797e-02,  -8.14208984e-02],
                        [ -6.87866211e-02,  -6.84509277e-02],
                        [ -5.77697754e-02,  -5.75866699e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -4.27551270e-02,  -4.29382324e-02],
                        [ -4.44946289e-02,  -4.48913574e-02],
                        [ -5.07202148e-02,  -5.13000488e-02],
                        [ -5.42907715e-02,  -5.49316406e-02],
                        [ -5.01403809e-02,  -5.09033203e-02],
                        [ -4.15039062e-02,  -4.25109863e-02],
                        [ -3.62548828e-02,  -3.74145508e-02],
                        [ -3.74450684e-02,  -3.85742188e-02],
                        [ -4.15039062e-02,  -4.26330566e-02],
                        [ -4.49829102e-02,  -4.62646484e-02],
                        [ -4.94384766e-02,  -5.07812500e-02],
                        [ -5.81359863e-02,  -5.93872070e-02],
                        [ -7.15332031e-02,  -7.26928711e-02],
                        [ -8.61206055e-02,  -8.71887207e-02],
                        [ -9.54589844e-02,  -9.64965820e-02],
                        [ -8.96606445e-02,  -9.05761719e-02],
                        [ -5.83190918e-02,  -5.90209961e-02],
                        [ -1.89208984e-03,  -2.34985352e-03],
                        [  6.22558594e-02,   6.19812012e-02],
                        [  1.11145020e-01,   1.11022949e-01],
                        [  1.31744385e-01,   1.31866455e-01],
                        [  1.25427246e-01,   1.25854492e-01],
                        [  1.02752686e-01,   1.03393555e-01],
                        [  7.80029297e-02,   7.88574219e-02],
                        [  6.45446777e-02,   6.56127930e-02],
                        [  6.65588379e-02,   6.78100586e-02],
                        [  7.46765137e-02,   7.60192871e-02],
                        [  7.74841309e-02,   7.89794922e-02],
                        [  7.69653320e-02,   7.85522461e-02],
                        [  8.27331543e-02,   8.43200684e-02],
                        [  9.40856934e-02,   9.56420898e-02],
                        [  1.00250244e-01,   1.01806641e-01],
                        [  9.86328125e-02,   1.00067139e-01],
                        [  9.96398926e-02,   1.00860596e-01],
                        [  1.11541748e-01,   1.12548828e-01],
                        [  1.29425049e-01,   1.30310059e-01],
                        [  1.39221191e-01,   1.39862061e-01],
                        [  1.26251221e-01,   1.26495361e-01],
                        [  8.34350586e-02,   8.33435059e-02],
                        [  1.35803223e-02,   1.33056641e-02],
                        [ -7.68127441e-02,  -7.72705078e-02],
                        [ -1.75689697e-01,  -1.76544189e-01],
                        [ -2.55920410e-01,  -2.57141113e-01],
                        [ -2.86071777e-01,  -2.87445068e-01],
                        [ -2.59796143e-01,  -2.61230469e-01],
                        [ -2.03704834e-01,  -2.05291748e-01],
                        [ -1.52618408e-01,  -1.54388428e-01],
                        [ -1.24023438e-01,  -1.25854492e-01],
                        [ -1.13983154e-01,  -1.15753174e-01],
                        [ -1.07330322e-01,  -1.08947754e-01],
                        [ -9.21936035e-02,  -9.36584473e-02],
                        [ -7.10144043e-02,  -7.23876953e-02],
                        [ -5.53283691e-02,  -5.65490723e-02],
                        [ -4.94384766e-02,  -5.03540039e-02],
                        [ -4.66613770e-02,  -4.72106934e-02],
                        [ -4.04052734e-02,  -4.06799316e-02],
                        [ -3.09753418e-02,  -3.10363770e-02],
                        [ -2.19726562e-02,  -2.16979980e-02],
                        [ -1.69677734e-02,  -1.63574219e-02],
                        [ -2.07214355e-02,  -1.98364258e-02],
                        [ -3.58886719e-02,  -3.47900391e-02],
                        [ -5.52673340e-02,  -5.39550781e-02],
                        [ -6.32629395e-02,  -6.17675781e-02],
                        [ -4.85839844e-02,  -4.69665527e-02],
                        [ -1.15051270e-02,  -9.85717773e-03],
                        [  4.11376953e-02,   4.28161621e-02],
                        [  1.01928711e-01,   1.03576660e-01],
                        [  1.59881592e-01,   1.61468506e-01],
                        [  1.97998047e-01,   1.99432373e-01],
                        [  2.02545166e-01,   2.03765869e-01],
                        [  1.76971436e-01,   1.78009033e-01],
                        [  1.42303467e-01,   1.43157959e-01],
                        [  1.20544434e-01,   1.21124268e-01],
                        [  1.16973877e-01,   1.17279053e-01],
                        [  1.19201660e-01,   1.19232178e-01],
                        [  1.12365723e-01,   1.12152100e-01],
                        [  9.32922363e-02,   9.28039551e-02],
                        [  7.07092285e-02,   6.99768066e-02],
                        [  5.35888672e-02,   5.27038574e-02],
                        [  4.17175293e-02,   4.06799316e-02],
                        [  3.02429199e-02,   2.89611816e-02],
                        [  1.79138184e-02,   1.65405273e-02],
                        [  3.87573242e-03,   2.56347656e-03],
                        [ -1.35192871e-02,  -1.48315430e-02],
                        [ -2.77709961e-02,  -2.91748047e-02],
                        [ -2.84118652e-02,  -2.97851562e-02],
                        [ -1.68457031e-02,  -1.80358887e-02],
                        [ -4.27246094e-03,  -5.31005859e-03],
                        [  5.34057617e-03,   4.39453125e-03],
                        [  1.55639648e-02,   1.47399902e-02],
                        [  2.42309570e-02,   2.36206055e-02],
                        [  2.51159668e-02,   2.47192383e-02],
                        [  2.16369629e-02,   2.14843750e-02],
                        [  2.58483887e-02,   2.58789062e-02],
                        [  4.25109863e-02,   4.26940918e-02],
                        [  6.37817383e-02,   6.41784668e-02],
                        [  7.99560547e-02,   8.05664062e-02],
                        [  8.93554688e-02,   9.00878906e-02],
                        [  9.49096680e-02,   9.57336426e-02],
                        [  9.15527344e-02,   9.24987793e-02],
                        [  6.23474121e-02,   6.33850098e-02],
                        [ -4.69970703e-03,  -3.60107422e-03],
                        [ -9.60388184e-02,  -9.49401855e-02],
                        [ -1.76025391e-01,  -1.74926758e-01],
                        [ -2.12799072e-01,  -2.11730957e-01],
                        [ -1.99249268e-01,  -1.98272705e-01],
                        [ -1.53808594e-01,  -1.52862549e-01],
                        [ -1.06445312e-01,  -1.05590820e-01],
                        [ -7.91625977e-02,  -7.84912109e-02],
                        [ -7.22351074e-02,  -7.17163086e-02],
                        [ -7.12280273e-02,  -7.08007812e-02],
                        [ -6.59484863e-02,  -6.56433105e-02],
                        [ -5.87158203e-02,  -5.86242676e-02],
                        [ -5.64880371e-02,  -5.66101074e-02],
                        [ -6.05773926e-02,  -6.08520508e-02],
                        [ -6.54296875e-02,  -6.57958984e-02],
                        [ -6.52465820e-02,  -6.57043457e-02],
                        [ -5.88989258e-02,  -5.95703125e-02],
                        [ -4.91943359e-02,  -5.00793457e-02],
                        [ -4.02221680e-02,  -4.11376953e-02],
                        [ -3.51562500e-02,  -3.59802246e-02],
                        [ -3.64379883e-02,  -3.73535156e-02],
                        [ -4.67224121e-02,  -4.77905273e-02],
                        [ -6.53991699e-02,  -6.64672852e-02],
                        [ -8.63647461e-02,  -8.72802734e-02],
                        [ -1.01654053e-01,  -1.02478027e-01],
                        [ -1.04675293e-01,  -1.05529785e-01],
                        [ -8.96301270e-02,  -9.04235840e-02],
                        [ -5.27954102e-02,  -5.33752441e-02],
                        [  2.41088867e-03,   2.01416016e-03],
                        [  6.14318848e-02,   6.10961914e-02],
                        [  1.04187012e-01,   1.03973389e-01],
                        [  1.18774414e-01,   1.18835449e-01],
                        [  1.11328125e-01,   1.11572266e-01],
                        [  1.00189209e-01,   1.00494385e-01],
                        [  9.89074707e-02,   9.93347168e-02],
                        [  1.06262207e-01,   1.06933594e-01],
                        [  1.12609863e-01,   1.13433838e-01],
                        [  1.10992432e-01,   1.11846924e-01],
                        [  1.02539062e-01,   1.03393555e-01],
                        [  9.57641602e-02,   9.67102051e-02],
                        [  9.85107422e-02,   9.95483398e-02],
                        [  1.08367920e-01,   1.09375000e-01],
                        [  1.15173340e-01,   1.16088867e-01],
                        [  1.14471436e-01,   1.15325928e-01],
                        [  1.15203857e-01,   1.15997314e-01],
                        [  1.27502441e-01,   1.28204346e-01],
                        [  1.42028809e-01,   1.42578125e-01],
                        [  1.31652832e-01,   1.32049561e-01],
                        [  8.05664062e-02,   8.08105469e-02],
                        [  2.13623047e-04,   2.44140625e-04],
                        [ -8.92333984e-02,  -8.93554688e-02],
                        [ -1.77642822e-01,  -1.77917480e-01],
                        [ -2.53662109e-01,  -2.54089355e-01],
                        [ -2.91564941e-01,  -2.92114258e-01],
                        [ -2.71606445e-01,  -2.72277832e-01],
                        [ -2.09625244e-01,  -2.10418701e-01],
                        [ -1.48284912e-01,  -1.49139404e-01],
                        [ -1.16394043e-01,  -1.17279053e-01],
                        [ -1.08581543e-01,  -1.09497070e-01],
                        [ -1.05834961e-01,  -1.06719971e-01],
                        [ -1.00585938e-01,  -1.01440430e-01],
                        [ -9.50927734e-02,  -9.58862305e-02],
                        [ -8.81042480e-02,  -8.88061523e-02],
                        [ -7.47680664e-02,  -7.53784180e-02],
                        [ -5.35888672e-02,  -5.40466309e-02],
                        [ -2.89001465e-02,  -2.92663574e-02],
                        [ -1.00402832e-02,  -1.02539062e-02],
                        [ -5.06591797e-03,  -5.12695312e-03],
                        [ -1.31225586e-02,  -1.30310059e-02],
                        [ -2.55432129e-02,  -2.53601074e-02],
                        [ -3.50646973e-02,  -3.46984863e-02],
                        [ -3.94897461e-02,  -3.90014648e-02],
                        [ -3.58581543e-02,  -3.53393555e-02],
                        [ -1.64794922e-02,  -1.58996582e-02],
                        [  2.34375000e-02,   2.41699219e-02],
                        [  7.89794922e-02,   7.97119141e-02],
                        [  1.37359619e-01,   1.38031006e-01],
                        [  1.82556152e-01,   1.83227539e-01],
                        [  2.01538086e-01,   2.02270508e-01],
                        [  1.92840576e-01,   1.93511963e-01],
                        [  1.67755127e-01,   1.68273926e-01],
                        [  1.41601562e-01,   1.42059326e-01],
                        [  1.24206543e-01,   1.24633789e-01],
                        [  1.15417480e-01,   1.15722656e-01],
                        [  1.07513428e-01,   1.07666016e-01],
                        [  9.43603516e-02,   9.44213867e-02],
                        [  7.94372559e-02,   7.94067383e-02],
                        [  7.08618164e-02,   7.07092285e-02],
                        [  6.68945312e-02,   6.66503906e-02],
                        [  5.59387207e-02,   5.56030273e-02],
                        [  3.26538086e-02,   3.22570801e-02],
                        [  4.91333008e-03,   4.48608398e-03],
                        [ -1.68151855e-02,  -1.73034668e-02],
                        [ -2.89001465e-02,  -2.94494629e-02],
                        [ -3.40576172e-02,  -3.45764160e-02],
                        [ -3.56445312e-02,  -3.61633301e-02],
                        [ -3.21960449e-02,  -3.27148438e-02],
                        [ -1.91650391e-02,  -1.96533203e-02],
                        [  2.19726562e-03,   1.83105469e-03],
                        [  2.21557617e-02,   2.18200684e-02],
                        [  3.14331055e-02,   3.10974121e-02],
                        [  3.04260254e-02,   3.01818848e-02],
                        [  2.73742676e-02,   2.72521973e-02],
                        [  2.98767090e-02,   2.98156738e-02],
                        [  3.89099121e-02,   3.88488770e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.85327148e-02,   5.86853027e-02],
                        [  7.00683594e-02,   7.03125000e-02],
                        [  8.79821777e-02,   8.81652832e-02],
                        [  1.05834961e-01,   1.06048584e-01],
                        [  1.06628418e-01,   1.06933594e-01],
                        [  7.32421875e-02,   7.36083984e-02],
                        [  1.80053711e-03,   2.13623047e-03],
                        [ -9.11560059e-02,  -9.07897949e-02],
                        [ -1.71417236e-01,  -1.71081543e-01],
                        [ -2.04193115e-01,  -2.03887939e-01],
                        [ -1.82373047e-01,  -1.82067871e-01],
                        [ -1.36718750e-01,  -1.36413574e-01],
                        [ -1.06140137e-01,  -1.05895996e-01],
                        [ -1.01287842e-01,  -1.01104736e-01],
                        [ -1.04003906e-01,  -1.03790283e-01],
                        [ -9.51843262e-02,  -9.50317383e-02],
                        [ -7.53173828e-02,  -7.52563477e-02],
                        [ -5.83190918e-02,  -5.82580566e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.38024902e-02,  -5.38940430e-02],
                        [ -5.53588867e-02,  -5.54809570e-02],
                        [ -5.33142090e-02,  -5.34057617e-02],
                        [ -4.73937988e-02,  -4.75463867e-02],
                        [ -4.16259766e-02,  -4.18395996e-02],
                        [ -4.22973633e-02,  -4.25415039e-02],
                        [ -4.98962402e-02,  -5.01098633e-02],
                        [ -5.86547852e-02,  -5.88989258e-02],
                        [ -6.81457520e-02,  -6.84204102e-02],
                        [ -8.34960938e-02,  -8.37707520e-02],
                        [ -1.00067139e-01,  -1.00280762e-01],
                        [ -1.02050781e-01,  -1.02233887e-01],
                        [ -8.05053711e-02,  -8.07189941e-02],
                        [ -4.07409668e-02,  -4.09240723e-02],
                        [  8.66699219e-03,   8.54492188e-03],
                        [  6.13403320e-02,   6.12487793e-02],
                        [  1.06628418e-01,   1.06536865e-01],
                        [  1.31011963e-01,   1.30950928e-01],
                        [  1.32843018e-01,   1.32873535e-01],
                        [  1.26342773e-01,   1.26403809e-01],
                        [  1.23565674e-01,   1.23657227e-01],
                        [  1.20971680e-01,   1.21063232e-01],
                        [  1.10107422e-01,   1.10229492e-01],
                        [  9.35668945e-02,   9.36889648e-02],
                        [  8.19091797e-02,   8.20922852e-02],
                        [  8.05358887e-02,   8.07495117e-02],
                        [  8.73107910e-02,   8.74633789e-02],
                        [  9.94262695e-02,   9.96093750e-02],
                        [  1.16241455e-01,   1.16455078e-01],
                        [  1.36047363e-01,   1.36230469e-01],
                        [  1.53839111e-01,   1.54022217e-01],
                        [  1.62414551e-01,   1.62536621e-01],
                        [  1.55639648e-01,   1.55761719e-01],
                        [  1.28601074e-01,   1.28692627e-01],
                        [  7.39440918e-02,   7.40356445e-02],
                        [ -1.25732422e-02,  -1.25122070e-02],
                        [ -1.20300293e-01,  -1.20300293e-01],
                        [ -2.23510742e-01,  -2.23541260e-01],
                        [ -2.93701172e-01,  -2.93731689e-01],
                        [ -3.10882568e-01,  -3.10943604e-01],
                        [ -2.72796631e-01,  -2.72918701e-01],
                        [ -2.03582764e-01,  -2.03674316e-01],
                        [ -1.43829346e-01,  -1.43920898e-01],
                        [ -1.16516113e-01,  -1.16638184e-01],
                        [ -1.09191895e-01,  -1.09344482e-01],
                        [ -1.00585938e-01,  -1.00738525e-01],
                        [ -8.88671875e-02,  -8.89892578e-02],
                        [ -8.16040039e-02,  -8.17260742e-02],
                        [ -7.62023926e-02,  -7.62939453e-02],
                        [ -6.50024414e-02,  -6.51245117e-02],
                        [ -4.91943359e-02,  -4.93164062e-02],
                        [ -3.52172852e-02,  -3.53088379e-02],
                        [ -2.46582031e-02,  -2.47192383e-02],
                        [ -1.72424316e-02,  -1.72729492e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -3.28674316e-02,  -3.28369141e-02],
                        [ -3.13720703e-02,  -3.13110352e-02],
                        [ -1.46789551e-02,  -1.46179199e-02],
                        [  1.86157227e-02,   1.86767578e-02],
                        [  6.58874512e-02,   6.59484863e-02],
                        [  1.18652344e-01,   1.18743896e-01],
                        [  1.65740967e-01,   1.65832520e-01],
                        [  1.96502686e-01,   1.96563721e-01],
                        [  2.01965332e-01,   2.02026367e-01],
                        [  1.82403564e-01,   1.82495117e-01],
                        [  1.54174805e-01,   1.54266357e-01],
                        [  1.34582520e-01,   1.34643555e-01],
                        [  1.21917725e-01,   1.21948242e-01],
                        [  1.05560303e-01,   1.05590820e-01],
                        [  8.70056152e-02,   8.70361328e-02],
                        [  7.37915039e-02,   7.38220215e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  5.48400879e-02,   5.48095703e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  3.24096680e-02,   3.23791504e-02],
                        [  1.68457031e-02,   1.68151855e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.19628906e-02,  -1.19934082e-02],
                        [ -1.71813965e-02,  -1.72424316e-02],
                        [ -1.77307129e-02,  -1.77612305e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.28173828e-02,  -1.28784180e-02],
                        [ -3.69262695e-03,  -3.72314453e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.14843750e-02,   2.14233398e-02],
                        [  3.16467285e-02,   3.16772461e-02],
                        [  3.65295410e-02,   3.65600586e-02],
                        [  3.20129395e-02,   3.19824219e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  3.28369141e-02,   3.28674316e-02],
                        [  4.69970703e-02,   4.70275879e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  7.92236328e-02,   7.92541504e-02],
                        [  9.08203125e-02,   9.08508301e-02],
                        [  8.69140625e-02,   8.68835449e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [ -1.14440918e-02,  -1.14135742e-02],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -1.73858643e-01,  -1.73858643e-01],
                        [ -2.06176758e-01,  -2.06176758e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -1.40563965e-01,  -1.40563965e-01],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -7.89794922e-02,  -7.89794922e-02],
                        [ -7.82470703e-02,  -7.82470703e-02],
                        [ -7.87048340e-02,  -7.87353516e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -7.50427246e-02,  -7.50732422e-02],
                        [ -8.57849121e-02,  -8.57849121e-02],
                        [ -8.98437500e-02,  -8.98132324e-02],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -7.49511719e-02,  -7.49816895e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -4.62036133e-02,  -4.61730957e-02],
                        [ -4.39147949e-02,  -4.39453125e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -6.67724609e-02,  -6.67419434e-02],
                        [ -7.36999512e-02,  -7.36694336e-02],
                        [ -7.47375488e-02,  -7.47680664e-02],
                        [ -6.68334961e-02,  -6.68029785e-02],
                        [ -4.31518555e-02,  -4.31213379e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  3.90319824e-02,   3.90014648e-02],
                        [  7.41271973e-02,   7.41577148e-02],
                        [  9.52453613e-02,   9.52453613e-02],
                        [  1.02111816e-01,   1.02111816e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  8.79211426e-02,   8.78906250e-02],
                        [  9.50317383e-02,   9.50317383e-02],
                        [  1.00982666e-01,   1.00982666e-01],
                        [  9.87243652e-02,   9.86938477e-02],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.37084961e-01,   1.37084961e-01],
                        [  1.66900635e-01,   1.66900635e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  1.96960449e-01,   1.96960449e-01],
                        [  1.76239014e-01,   1.76239014e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  5.69152832e-02,   5.69152832e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -1.42333984e-01,  -1.42333984e-01],
                        [ -2.45819092e-01,  -2.45819092e-01],
                        [ -3.11492920e-01,  -3.11492920e-01],
                        [ -3.17016602e-01,  -3.17016602e-01],
                        [ -2.71545410e-01,  -2.71545410e-01],
                        [ -2.08618164e-01,  -2.08618164e-01],
                        [ -1.59301758e-01,  -1.59271240e-01],
                        [ -1.30554199e-01,  -1.30554199e-01],
                        [ -1.10137939e-01,  -1.10168457e-01],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -6.75048828e-02,  -6.74743652e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -3.60107422e-02,  -3.59802246e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.74658203e-02,  -2.74353027e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.74243164e-02,  -4.74548340e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [  1.71508789e-02,   1.71203613e-02],
                        [  7.76062012e-02,   7.76367188e-02],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.78924561e-01,   1.78894043e-01],
                        [  2.04223633e-01,   2.04193115e-01],
                        [  2.13745117e-01,   2.13775635e-01],
                        [  2.08251953e-01,   2.08251953e-01],
                        [  1.91467285e-01,   1.91436768e-01],
                        [  1.67877197e-01,   1.67877197e-01],
                        [  1.39678955e-01,   1.39709473e-01],
                        [  1.10778809e-01,   1.10748291e-01],
                        [  8.62426758e-02,   8.62426758e-02],
                        [  6.73522949e-02,   6.73828125e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  4.44946289e-02,   4.44641113e-02],
                        [  3.68041992e-02,   3.68347168e-02],
                        [  2.62756348e-02,   2.63061523e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.58386230e-02,   1.58691406e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [ -3.35693359e-04,  -3.66210938e-04],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -8.57543945e-03,  -8.54492188e-03],
                        [ -5.67626953e-03,  -5.70678711e-03],
                        [ -3.17382812e-03,  -3.20434570e-03],
                        [ -1.49536133e-03,  -1.46484375e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  9.61303711e-03,   9.64355469e-03],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  2.56042480e-02,   2.56347656e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  5.01708984e-02,   5.02014160e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.12091064e-01,  -1.12091064e-01],
                        [ -1.83319092e-01,  -1.83319092e-01],
                        [ -2.13592529e-01,  -2.13592529e-01],
                        [ -1.95678711e-01,  -1.95678711e-01],
                        [ -1.46972656e-01,  -1.46972656e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -6.88781738e-02,  -6.88781738e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -7.93457031e-02,  -7.93762207e-02],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -5.85021973e-02,  -5.84716797e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -7.40356445e-02,  -7.40661621e-02],
                        [ -7.76672363e-02,  -7.76672363e-02],
                        [ -7.35168457e-02,  -7.34863281e-02],
                        [ -6.42700195e-02,  -6.43005371e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -3.82080078e-02,  -3.81774902e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  5.97534180e-02,   5.97839355e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  1.17034912e-01,   1.17004395e-01],
                        [  1.17645264e-01,   1.17645264e-01],
                        [  1.06292725e-01,   1.06323242e-01],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  8.94775391e-02,   8.94775391e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.17370605e-01,   1.17340088e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  1.36291504e-01,   1.36322021e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.75231934e-01,   1.75231934e-01],
                        [  1.96502686e-01,   1.96533203e-01],
                        [  1.93878174e-01,   1.93908691e-01],
                        [  1.57440186e-01,   1.57409668e-01],
                        [  8.98742676e-02,   8.98742676e-02],
                        [ -1.52587891e-03,  -1.49536133e-03],
                        [ -1.06140137e-01,  -1.06170654e-01],
                        [ -2.08282471e-01,  -2.08282471e-01],
                        [ -2.87292480e-01,  -2.87292480e-01],
                        [ -3.18328857e-01,  -3.18298340e-01],
                        [ -2.84973145e-01,  -2.85003662e-01],
                        [ -2.06237793e-01,  -2.06237793e-01],
                        [ -1.33636475e-01,  -1.33605957e-01],
                        [ -1.02844238e-01,  -1.02874756e-01],
                        [ -1.01806641e-01,  -1.01806641e-01],
                        [ -9.95178223e-02,  -9.95178223e-02],
                        [ -8.80737305e-02,  -8.80432129e-02],
                        [ -8.04138184e-02,  -8.04138184e-02],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -8.93249512e-02,  -8.93249512e-02],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -6.49719238e-02,  -6.50024414e-02],
                        [ -3.72314453e-02,  -3.72009277e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.99279785e-02,  -1.99584961e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.50952148e-02,  -3.50646973e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [  3.01513672e-02,   3.01208496e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  1.49169922e-01,   1.49169922e-01],
                        [  1.97479248e-01,   1.97479248e-01],
                        [  2.19177246e-01,   2.19177246e-01],
                        [  2.06604004e-01,   2.06604004e-01],
                        [  1.69769287e-01,   1.69769287e-01],
                        [  1.33148193e-01,   1.33117676e-01],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  1.11572266e-01,   1.11602783e-01],
                        [  1.10778809e-01,   1.10748291e-01],
                        [  1.05255127e-01,   1.05255127e-01],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  8.09631348e-02,   8.09936523e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.43530273e-02,  -2.43835449e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.86462402e-02,  -1.86767578e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  1.05285645e-02,   1.05590820e-02],
                        [  1.68457031e-02,   1.68151855e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.66931152e-02,   1.67236328e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.34277344e-02,   1.33972168e-02],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  8.39538574e-02,   8.39233398e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -7.03735352e-02,  -7.03735352e-02],
                        [ -1.40197754e-01,  -1.40167236e-01],
                        [ -1.82617188e-01,  -1.82617188e-01],
                        [ -1.82556152e-01,  -1.82556152e-01],
                        [ -1.50329590e-01,  -1.50299072e-01],
                        [ -1.14349365e-01,  -1.14349365e-01],
                        [ -9.39941406e-02,  -9.40246582e-02],
                        [ -8.92944336e-02,  -8.92944336e-02],
                        [ -9.26818848e-02,  -9.26818848e-02],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -9.85107422e-02,  -9.85107422e-02],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -7.65686035e-02,  -7.65380859e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -4.49218750e-02,  -4.49523926e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -5.09643555e-02,  -5.09338379e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -2.62451172e-03,  -2.59399414e-03],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  1.34124756e-01,   1.34124756e-01],
                        [  1.35742188e-01,   1.35742188e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.12304688e-01,   1.12274170e-01],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  1.22100830e-01,   1.22131348e-01],
                        [  1.47033691e-01,   1.47033691e-01],
                        [  1.66931152e-01,   1.66931152e-01],
                        [  1.77032471e-01,   1.77032471e-01],
                        [  1.71936035e-01,   1.71936035e-01],
                        [  1.40380859e-01,   1.40380859e-01],
                        [  7.25708008e-02,   7.25708008e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -1.42730713e-01,  -1.42730713e-01],
                        [ -2.42858887e-01,  -2.42858887e-01],
                        [ -2.99560547e-01,  -2.99560547e-01],
                        [ -2.95166016e-01,  -2.95166016e-01],
                        [ -2.40631104e-01,  -2.40631104e-01],
                        [ -1.75872803e-01,  -1.75872803e-01],
                        [ -1.38336182e-01,  -1.38336182e-01],
                        [ -1.31225586e-01,  -1.31256104e-01],
                        [ -1.30249023e-01,  -1.30249023e-01],
                        [ -1.16851807e-01,  -1.16851807e-01],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -7.71789551e-02,  -7.71789551e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.80969238e-02,  -1.81274414e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  1.13220215e-01,   1.13220215e-01],
                        [  1.68457031e-01,   1.68457031e-01],
                        [  2.05535889e-01,   2.05505371e-01],
                        [  2.13775635e-01,   2.13775635e-01],
                        [  1.99096680e-01,   1.99096680e-01],
                        [  1.76574707e-01,   1.76574707e-01],
                        [  1.56433105e-01,   1.56402588e-01],
                        [  1.38641357e-01,   1.38641357e-01],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  1.07299805e-01,   1.07269287e-01],
                        [  9.37805176e-02,   9.38110352e-02],
                        [  7.80029297e-02,   7.80334473e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  3.18603516e-02,   3.18908691e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [ -3.69262695e-03,  -3.72314453e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [  6.25610352e-03,   6.22558594e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  5.52368164e-03,   5.55419922e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -5.82885742e-03,  -5.85937500e-03],
                        [ -4.11987305e-03,  -4.15039062e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  2.38037109e-03,   2.34985352e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -6.56127930e-03,  -6.53076172e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  5.58471680e-03,   5.55419922e-03],
                        [  2.47497559e-02,   2.47802734e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  8.26721191e-02,   8.26416016e-02],
                        [  1.00524902e-01,   1.00555420e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.01470947e-01,   1.01440430e-01],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  2.16369629e-02,   2.16674805e-02],
                        [ -5.77697754e-02,  -5.78002930e-02],
                        [ -1.37817383e-01,  -1.37847900e-01],
                        [ -1.91101074e-01,  -1.91070557e-01],
                        [ -2.04650879e-01,  -2.04650879e-01],
                        [ -1.84844971e-01,  -1.84875488e-01],
                        [ -1.49688721e-01,  -1.49688721e-01],
                        [ -1.17004395e-01,  -1.16973877e-01],
                        [ -9.61303711e-02,  -9.61303711e-02],
                        [ -8.66394043e-02,  -8.66699219e-02],
                        [ -8.34655762e-02,  -8.34655762e-02],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -8.50219727e-02,  -8.50524902e-02],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -8.59680176e-02,  -8.59680176e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  4.44641113e-02,   4.44946289e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  1.01898193e-01,   1.01898193e-01],
                        [  1.00128174e-01,   1.00158691e-01],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  9.59777832e-02,   9.60083008e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  1.22100830e-01,   1.22070312e-01],
                        [  1.34552002e-01,   1.34582520e-01],
                        [  1.44927979e-01,   1.44927979e-01],
                        [  1.58111572e-01,   1.58111572e-01],
                        [  1.77032471e-01,   1.77032471e-01],
                        [  1.96472168e-01,   1.96472168e-01],
                        [  2.05902100e-01,   2.05902100e-01],
                        [  1.93023682e-01,   1.92993164e-01],
                        [  1.45751953e-01,   1.45751953e-01],
                        [  5.96923828e-02,   5.96923828e-02],
                        [ -5.33447266e-02,  -5.33752441e-02],
                        [ -1.68975830e-01,  -1.68975830e-01],
                        [ -2.62969971e-01,  -2.62939453e-01],
                        [ -3.17108154e-01,  -3.17108154e-01],
                        [ -3.18969727e-01,  -3.18969727e-01],
                        [ -2.68920898e-01,  -2.68920898e-01],
                        [ -1.90185547e-01,  -1.90155029e-01],
                        [ -1.21124268e-01,  -1.21124268e-01],
                        [ -8.82568359e-02,  -8.82568359e-02],
                        [ -8.62731934e-02,  -8.62731934e-02],
                        [ -9.04846191e-02,  -9.04846191e-02],
                        [ -8.63342285e-02,  -8.63647461e-02],
                        [ -7.76977539e-02,  -7.76977539e-02],
                        [ -7.09533691e-02,  -7.09228516e-02],
                        [ -6.57958984e-02,  -6.58264160e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -7.14721680e-02,  -7.14721680e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.67022705e-01,   1.67022705e-01],
                        [  1.91558838e-01,   1.91558838e-01],
                        [  1.89666748e-01,   1.89666748e-01],
                        [  1.67297363e-01,   1.67327881e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.09436035e-01,   1.09466553e-01],
                        [  1.06994629e-01,   1.06964111e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  8.71887207e-02,   8.72192383e-02],
                        [  7.64465332e-02,   7.64160156e-02],
                        [  6.02416992e-02,   6.02111816e-02],
                        [  3.64990234e-02,   3.65295410e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  8.08715820e-03,   8.05664062e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.19323730e-02,  -1.19018555e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.19421387e-02,  -2.19726562e-02],
                        [ -8.14819336e-03,  -8.17871094e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  4.91333008e-03,   4.94384766e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  7.93457031e-04,   7.62939453e-04],
                        [  9.39941406e-03,   9.42993164e-03],
                        [  2.89916992e-02,   2.90222168e-02],
                        [  5.23376465e-02,   5.23071289e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  8.55407715e-02,   8.55712891e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  7.09228516e-02,   7.09533691e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -1.22344971e-01,  -1.22344971e-01],
                        [ -1.74499512e-01,  -1.74468994e-01],
                        [ -1.89849854e-01,  -1.89849854e-01],
                        [ -1.68823242e-01,  -1.68823242e-01],
                        [ -1.29364014e-01,  -1.29364014e-01],
                        [ -9.63134766e-02,  -9.63134766e-02],
                        [ -8.38012695e-02,  -8.38012695e-02],
                        [ -8.81042480e-02,  -8.81042480e-02],
                        [ -9.61914062e-02,  -9.61914062e-02],
                        [ -9.77478027e-02,  -9.77478027e-02],
                        [ -9.20104980e-02,  -9.20410156e-02],
                        [ -8.69140625e-02,  -8.68835449e-02],
                        [ -8.79821777e-02,  -8.79516602e-02],
                        [ -8.75244141e-02,  -8.75244141e-02],
                        [ -7.46154785e-02,  -7.46154785e-02],
                        [ -5.54809570e-02,  -5.54504395e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -5.32226562e-02,  -5.32531738e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -6.49414062e-02,  -6.49108887e-02],
                        [ -5.89904785e-02,  -5.90209961e-02],
                        [ -4.21447754e-02,  -4.21752930e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [  2.52685547e-02,   2.52990723e-02],
                        [  6.30493164e-02,   6.30187988e-02],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  1.12762451e-01,   1.12792969e-01],
                        [  1.12792969e-01,   1.12792969e-01],
                        [  1.00982666e-01,   1.00982666e-01],
                        [  9.17968750e-02,   9.18273926e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  1.04461670e-01,   1.04431152e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  1.32995605e-01,   1.33026123e-01],
                        [  1.53381348e-01,   1.53381348e-01],
                        [  1.77917480e-01,   1.77886963e-01],
                        [  1.97875977e-01,   1.97906494e-01],
                        [  2.04315186e-01,   2.04345703e-01],
                        [  1.92749023e-01,   1.92718506e-01],
                        [  1.58569336e-01,   1.58569336e-01],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [ -1.03851318e-01,  -1.03851318e-01],
                        [ -2.10144043e-01,  -2.10144043e-01],
                        [ -2.88909912e-01,  -2.88909912e-01],
                        [ -3.14300537e-01,  -3.14300537e-01],
                        [ -2.79724121e-01,  -2.79724121e-01],
                        [ -2.09777832e-01,  -2.09777832e-01],
                        [ -1.44683838e-01,  -1.44714355e-01],
                        [ -1.10412598e-01,  -1.10412598e-01],
                        [ -1.02294922e-01,  -1.02294922e-01],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -6.02722168e-02,  -6.02416992e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.05578613e-02,  -4.05883789e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  1.56738281e-01,   1.56768799e-01],
                        [  1.94030762e-01,   1.94030762e-01],
                        [  2.02087402e-01,   2.02056885e-01],
                        [  1.83471680e-01,   1.83502197e-01],
                        [  1.53808594e-01,   1.53839111e-01],
                        [  1.29760742e-01,   1.29760742e-01],
                        [  1.18591309e-01,   1.18591309e-01],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.03515625e-01,   1.03485107e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  8.36791992e-02,   8.36486816e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  3.48205566e-02,   3.48510742e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -7.32421875e-03,  -7.35473633e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -3.69262695e-03,  -3.66210938e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  6.53381348e-02,   6.53686523e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  1.02172852e-01,   1.02142334e-01],
                        [  1.03790283e-01,   1.03790283e-01],
                        [  9.28649902e-02,   9.28955078e-02],
                        [  6.27136230e-02,   6.27136230e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -1.41326904e-01,  -1.41326904e-01],
                        [ -1.84936523e-01,  -1.84967041e-01],
                        [ -1.85943604e-01,  -1.85943604e-01],
                        [ -1.60003662e-01,  -1.60003662e-01],
                        [ -1.33483887e-01,  -1.33483887e-01],
                        [ -1.21429443e-01,  -1.21429443e-01],
                        [ -1.21978760e-01,  -1.21978760e-01],
                        [ -1.23443604e-01,  -1.23443604e-01],
                        [ -1.15173340e-01,  -1.15173340e-01],
                        [ -9.78698730e-02,  -9.78698730e-02],
                        [ -8.43811035e-02,  -8.43811035e-02],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -6.95800781e-02,  -6.95495605e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -2.91442871e-02,  -2.91137695e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  5.15441895e-02,   5.15136719e-02],
                        [  9.04235840e-02,   9.04235840e-02],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.20330811e-01,   1.20330811e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.45996094e-01,   1.45996094e-01],
                        [  1.64306641e-01,   1.64306641e-01],
                        [  1.89605713e-01,   1.89605713e-01],
                        [  2.11914062e-01,   2.11944580e-01],
                        [  2.14111328e-01,   2.14111328e-01],
                        [  1.84448242e-01,   1.84448242e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  2.72827148e-02,   2.72827148e-02],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -1.90063477e-01,  -1.90063477e-01],
                        [ -2.73834229e-01,  -2.73803711e-01],
                        [ -3.11431885e-01,  -3.11431885e-01],
                        [ -2.91046143e-01,  -2.91046143e-01],
                        [ -2.28820801e-01,  -2.28820801e-01],
                        [ -1.64581299e-01,  -1.64581299e-01],
                        [ -1.29150391e-01,  -1.29150391e-01],
                        [ -1.19842529e-01,  -1.19842529e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -9.72595215e-02,  -9.72290039e-02],
                        [ -7.69958496e-02,  -7.69958496e-02],
                        [ -6.65283203e-02,  -6.65588379e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -8.19396973e-02,  -8.19396973e-02],
                        [ -8.35571289e-02,  -8.35876465e-02],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  1.35650635e-01,   1.35650635e-01],
                        [  1.90673828e-01,   1.90673828e-01],
                        [  2.17254639e-01,   2.17254639e-01],
                        [  2.08892822e-01,   2.08892822e-01],
                        [  1.78741455e-01,   1.78741455e-01],
                        [  1.48406982e-01,   1.48406982e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  3.20129395e-02,   3.20434570e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.96020508e-02,  -2.95715332e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  7.55615234e-02,   7.55310059e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.10839844e-01,   1.10809326e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  7.93762207e-02,   7.93762207e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [ -3.20129395e-02,  -3.20434570e-02],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -1.67144775e-01,  -1.67144775e-01],
                        [ -1.94763184e-01,  -1.94763184e-01],
                        [ -1.87316895e-01,  -1.87316895e-01],
                        [ -1.59423828e-01,  -1.59423828e-01],
                        [ -1.31439209e-01,  -1.31439209e-01],
                        [ -1.13342285e-01,  -1.13342285e-01],
                        [ -1.03576660e-01,  -1.03576660e-01],
                        [ -1.00036621e-01,  -1.00036621e-01],
                        [ -1.03881836e-01,  -1.03881836e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -1.23352051e-01,  -1.23352051e-01],
                        [ -1.26586914e-01,  -1.26586914e-01],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  1.13769531e-01,   1.13769531e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.30310059e-01,   1.30279541e-01],
                        [  1.40533447e-01,   1.40502930e-01],
                        [  1.57196045e-01,   1.57196045e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  1.98760986e-01,   1.98760986e-01],
                        [  2.12493896e-01,   2.12493896e-01],
                        [  2.07916260e-01,   2.07916260e-01],
                        [  1.72912598e-01,   1.72912598e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -2.07153320e-01,  -2.07153320e-01],
                        [ -2.82745361e-01,  -2.82745361e-01],
                        [ -3.07189941e-01,  -3.07189941e-01],
                        [ -2.76519775e-01,  -2.76519775e-01],
                        [ -2.13073730e-01,  -2.13073730e-01],
                        [ -1.52618408e-01,  -1.52618408e-01],
                        [ -1.18499756e-01,  -1.18499756e-01],
                        [ -1.09558105e-01,  -1.09558105e-01],
                        [ -1.11541748e-01,  -1.11572266e-01],
                        [ -1.14166260e-01,  -1.14166260e-01],
                        [ -1.14776611e-01,  -1.14776611e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -9.98535156e-02,  -9.98535156e-02],
                        [ -8.16345215e-02,  -8.16345215e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  1.76483154e-01,   1.76483154e-01],
                        [  2.19757080e-01,   2.19757080e-01],
                        [  2.29522705e-01,   2.29522705e-01],
                        [  2.10235596e-01,   2.10235596e-01],
                        [  1.78192139e-01,   1.78192139e-01],
                        [  1.49353027e-01,   1.49322510e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.22039795e-01,   1.22039795e-01],
                        [  1.13067627e-01,   1.13037109e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  7.72705078e-02,   7.72705078e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  4.94384766e-03,   4.97436523e-03],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -1.79443359e-02,  -1.79138184e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -2.23693848e-02,  -2.23388672e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  4.05883789e-03,   4.02832031e-03],
                        [  4.57763672e-03,   4.60815430e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  7.73925781e-02,   7.73925781e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -1.31439209e-01,  -1.31439209e-01],
                        [ -1.82189941e-01,  -1.82189941e-01],
                        [ -1.97601318e-01,  -1.97601318e-01],
                        [ -1.82525635e-01,  -1.82495117e-01],
                        [ -1.58508301e-01,  -1.58508301e-01],
                        [ -1.43493652e-01,  -1.43493652e-01],
                        [ -1.37329102e-01,  -1.37329102e-01],
                        [ -1.28723145e-01,  -1.28723145e-01],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -1.03332520e-01,  -1.03332520e-01],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -1.11450195e-01,  -1.11419678e-01],
                        [ -1.08795166e-01,  -1.08795166e-01],
                        [ -9.17053223e-02,  -9.17053223e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.44641113e-02,  -4.44946289e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.52880859e-02,  -4.53186035e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -1.19323730e-02,  -1.19018555e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  7.67822266e-02,   7.67517090e-02],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  1.09558105e-01,   1.09558105e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.42974854e-01,   1.42974854e-01],
                        [  1.58386230e-01,   1.58386230e-01],
                        [  1.76757812e-01,   1.76757812e-01],
                        [  2.03094482e-01,   2.03094482e-01],
                        [  2.25036621e-01,   2.25036621e-01],
                        [  2.18933105e-01,   2.18933105e-01],
                        [  1.75384521e-01,   1.75384521e-01],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.39465332e-02,   1.39465332e-02],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -2.02392578e-01,  -2.02392578e-01],
                        [ -2.89642334e-01,  -2.89642334e-01],
                        [ -3.22601318e-01,  -3.22601318e-01],
                        [ -2.91320801e-01,  -2.91320801e-01],
                        [ -2.20214844e-01,  -2.20214844e-01],
                        [ -1.54266357e-01,  -1.54266357e-01],
                        [ -1.22161865e-01,  -1.22161865e-01],
                        [ -1.15905762e-01,  -1.15905762e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -1.08581543e-01,  -1.08612061e-01],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.07391357e-01,  -1.07391357e-01],
                        [ -1.06262207e-01,  -1.06292725e-01],
                        [ -9.89379883e-02,  -9.89379883e-02],
                        [ -8.64257812e-02,  -8.64257812e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  2.00653076e-01,   2.00653076e-01],
                        [  2.34161377e-01,   2.34161377e-01],
                        [  2.22320557e-01,   2.22320557e-01],
                        [  1.79321289e-01,   1.79321289e-01],
                        [  1.43127441e-01,   1.43127441e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.17309570e-01,   1.17279053e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  8.73413086e-02,   8.73413086e-02],
                        [  7.49511719e-02,   7.49206543e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  2.10571289e-03,   2.13623047e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -2.55432129e-02,  -2.55737305e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  2.83508301e-02,   2.83813477e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.74353027e-02,   2.74658203e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -1.17401123e-01,  -1.17401123e-01],
                        [ -1.92138672e-01,  -1.92138672e-01],
                        [ -2.25585938e-01,  -2.25585938e-01],
                        [ -2.08801270e-01,  -2.08770752e-01],
                        [ -1.65893555e-01,  -1.65893555e-01],
                        [ -1.31927490e-01,  -1.31927490e-01],
                        [ -1.19689941e-01,  -1.19659424e-01],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -1.18988037e-01,  -1.18988037e-01],
                        [ -1.16882324e-01,  -1.16882324e-01],
                        [ -1.14746094e-01,  -1.14746094e-01],
                        [ -1.11511230e-01,  -1.11511230e-01],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -9.09729004e-02,  -9.09729004e-02],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -7.93151855e-02,  -7.93151855e-02],
                        [ -8.45031738e-02,  -8.45031738e-02],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  8.86535645e-02,   8.86230469e-02],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.19476318e-01,   1.19506836e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  1.00036621e-01,   1.00036621e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.59362793e-01,   1.59362793e-01],
                        [  1.77642822e-01,   1.77642822e-01],
                        [  1.90155029e-01,   1.90155029e-01],
                        [  2.06756592e-01,   2.06756592e-01],
                        [  2.18139648e-01,   2.18139648e-01],
                        [  2.04132080e-01,   2.04132080e-01],
                        [  1.59667969e-01,   1.59667969e-01],
                        [  9.06677246e-02,   9.06677246e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.18103027e-01,  -1.18103027e-01],
                        [ -2.30133057e-01,  -2.30133057e-01],
                        [ -3.04351807e-01,  -3.04351807e-01],
                        [ -3.18542480e-01,  -3.18542480e-01],
                        [ -2.76489258e-01,  -2.76489258e-01],
                        [ -2.08465576e-01,  -2.08465576e-01],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.31469727e-01,  -1.31469727e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -1.23931885e-01,  -1.23931885e-01],
                        [ -1.13555908e-01,  -1.13525391e-01],
                        [ -1.05255127e-01,  -1.05255127e-01],
                        [ -1.01226807e-01,  -1.01226807e-01],
                        [ -9.78393555e-02,  -9.78088379e-02],
                        [ -9.30175781e-02,  -9.30175781e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  8.00781250e-02,   8.00781250e-02],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  1.77917480e-01,   1.77917480e-01],
                        [  2.08892822e-01,   2.08892822e-01],
                        [  2.15789795e-01,   2.15759277e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  1.64093018e-01,   1.64093018e-01],
                        [  1.31713867e-01,   1.31713867e-01],
                        [  1.12121582e-01,   1.12152100e-01],
                        [  1.07116699e-01,   1.07116699e-01],
                        [  1.08825684e-01,   1.08825684e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  9.79919434e-02,   9.79614258e-02],
                        [  8.64868164e-02,   8.65173340e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  1.03759766e-01,   1.03790283e-01],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -1.42944336e-01,  -1.42944336e-01],
                        [ -2.05322266e-01,  -2.05322266e-01],
                        [ -2.20428467e-01,  -2.20428467e-01],
                        [ -1.94396973e-01,  -1.94396973e-01],
                        [ -1.51916504e-01,  -1.51916504e-01],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -1.03942871e-01,  -1.03942871e-01],
                        [ -1.07940674e-01,  -1.07940674e-01],
                        [ -1.15631104e-01,  -1.15631104e-01],
                        [ -1.14715576e-01,  -1.14715576e-01],
                        [ -1.06018066e-01,  -1.06018066e-01],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -8.92944336e-02,  -8.92944336e-02],
                        [ -8.06884766e-02,  -8.06884766e-02],
                        [ -7.66296387e-02,  -7.66601562e-02],
                        [ -7.99255371e-02,  -7.99255371e-02],
                        [ -8.04443359e-02,  -8.04443359e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.13555908e-01,   1.13555908e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.71936035e-01,   1.71936035e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  1.98364258e-01,   1.98364258e-01],
                        [  1.97631836e-01,   1.97631836e-01],
                        [  1.76361084e-01,   1.76361084e-01],
                        [  1.23596191e-01,   1.23596191e-01],
                        [  3.57971191e-02,   3.57666016e-02],
                        [ -7.57141113e-02,  -7.57141113e-02],
                        [ -1.88934326e-01,  -1.88934326e-01],
                        [ -2.79479980e-01,  -2.79479980e-01],
                        [ -3.24462891e-01,  -3.24462891e-01],
                        [ -3.09326172e-01,  -3.09326172e-01],
                        [ -2.44415283e-01,  -2.44415283e-01],
                        [ -1.69555664e-01,  -1.69555664e-01],
                        [ -1.22985840e-01,  -1.22985840e-01],
                        [ -1.07299805e-01,  -1.07299805e-01],
                        [ -1.01806641e-01,  -1.01806641e-01],
                        [ -9.67712402e-02,  -9.68017578e-02],
                        [ -9.63134766e-02,  -9.63134766e-02],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -9.14306641e-02,  -9.14306641e-02],
                        [ -7.52258301e-02,  -7.52258301e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  1.88934326e-01,   1.88934326e-01],
                        [  2.22167969e-01,   2.22167969e-01],
                        [  2.17651367e-01,   2.17651367e-01],
                        [  1.84051514e-01,   1.84051514e-01],
                        [  1.43096924e-01,   1.43096924e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  1.04125977e-01,   1.04125977e-01],
                        [  1.07360840e-01,   1.07360840e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.22070312e-04,  -9.15527344e-05],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  8.90808105e-02,   8.90808105e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  4.69970703e-03,   4.66918945e-03],
                        [ -8.02612305e-02,  -8.02612305e-02],
                        [ -1.63360596e-01,  -1.63360596e-01],
                        [ -2.13012695e-01,  -2.13012695e-01],
                        [ -2.11944580e-01,  -2.11944580e-01],
                        [ -1.72180176e-01,  -1.72180176e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -9.10644531e-02,  -9.10644531e-02],
                        [ -8.23669434e-02,  -8.23669434e-02],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -1.08551025e-01,  -1.08551025e-01],
                        [ -1.13037109e-01,  -1.13037109e-01],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -9.98229980e-02,  -9.98229980e-02],
                        [ -9.57641602e-02,  -9.57641602e-02],
                        [ -8.51745605e-02,  -8.51745605e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -3.24096680e-02,  -3.24401855e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  9.48791504e-02,   9.48791504e-02],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  1.12365723e-01,   1.12365723e-01],
                        [  1.27380371e-01,   1.27380371e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.49261475e-01,   1.49261475e-01],
                        [  1.66473389e-01,   1.66473389e-01],
                        [  1.86553955e-01,   1.86523438e-01],
                        [  1.97357178e-01,   1.97357178e-01],
                        [  1.88232422e-01,   1.88232422e-01],
                        [  1.50451660e-01,   1.50451660e-01],
                        [  7.59582520e-02,   7.59582520e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -1.60552979e-01,  -1.60552979e-01],
                        [ -2.70477295e-01,  -2.70446777e-01],
                        [ -3.28887939e-01,  -3.28887939e-01],
                        [ -3.16864014e-01,  -3.16864014e-01],
                        [ -2.48718262e-01,  -2.48718262e-01],
                        [ -1.68884277e-01,  -1.68884277e-01],
                        [ -1.19689941e-01,  -1.19689941e-01],
                        [ -1.09771729e-01,  -1.09771729e-01],
                        [ -1.16333008e-01,  -1.16363525e-01],
                        [ -1.17706299e-01,  -1.17706299e-01],
                        [ -1.14532471e-01,  -1.14501953e-01],
                        [ -1.14898682e-01,  -1.14898682e-01],
                        [ -1.14746094e-01,  -1.14746094e-01],
                        [ -1.05834961e-01,  -1.05834961e-01],
                        [ -8.95996094e-02,  -8.96301270e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -3.74450684e-02,  -3.74145508e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  1.35070801e-01,   1.35070801e-01],
                        [  1.86309814e-01,   1.86279297e-01],
                        [  2.15026855e-01,   2.15026855e-01],
                        [  2.12554932e-01,   2.12554932e-01],
                        [  1.84600830e-01,   1.84570312e-01],
                        [  1.49841309e-01,   1.49841309e-01],
                        [  1.25488281e-01,   1.25488281e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  5.87463379e-02,   5.87158203e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -9.40856934e-02,  -9.40856934e-02],
                        [ -1.88323975e-01,  -1.88323975e-01],
                        [ -2.42736816e-01,  -2.42736816e-01],
                        [ -2.40509033e-01,  -2.40539551e-01],
                        [ -1.93206787e-01,  -1.93206787e-01],
                        [ -1.37054443e-01,  -1.37054443e-01],
                        [ -1.03363037e-01,  -1.03363037e-01],
                        [ -9.41162109e-02,  -9.41162109e-02],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -8.94165039e-02,  -8.94165039e-02],
                        [ -8.69445801e-02,  -8.69445801e-02],
                        [ -9.14306641e-02,  -9.14306641e-02],
                        [ -1.02416992e-01,  -1.02416992e-01],
                        [ -1.11968994e-01,  -1.11968994e-01],
                        [ -1.12487793e-01,  -1.12487793e-01],
                        [ -1.05133057e-01,  -1.05133057e-01],
                        [ -9.46044922e-02,  -9.46044922e-02],
                        [ -7.70568848e-02,  -7.70568848e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  1.32659912e-01,   1.32659912e-01],
                        [  1.37298584e-01,   1.37298584e-01],
                        [  1.19628906e-01,   1.19659424e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  8.18176270e-02,   8.18176270e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  1.00097656e-01,   1.00097656e-01],
                        [  1.22619629e-01,   1.22619629e-01],
                        [  1.44744873e-01,   1.44744873e-01],
                        [  1.67846680e-01,   1.67846680e-01],
                        [  1.97509766e-01,   1.97509766e-01],
                        [  2.25860596e-01,   2.25860596e-01],
                        [  2.30072021e-01,   2.30072021e-01],
                        [  1.92504883e-01,   1.92504883e-01],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -1.26190186e-01,  -1.26190186e-01],
                        [ -2.49114990e-01,  -2.49114990e-01],
                        [ -3.30932617e-01,  -3.30932617e-01],
                        [ -3.43078613e-01,  -3.43048096e-01],
                        [ -2.89550781e-01,  -2.89550781e-01],
                        [ -2.08770752e-01,  -2.08770752e-01],
                        [ -1.45172119e-01,  -1.45141602e-01],
                        [ -1.16760254e-01,  -1.16760254e-01],
                        [ -1.10687256e-01,  -1.10687256e-01],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -1.19537354e-01,  -1.19537354e-01],
                        [ -1.06811523e-01,  -1.06811523e-01],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  1.60186768e-01,   1.60186768e-01],
                        [  2.22900391e-01,   2.22900391e-01],
                        [  2.47528076e-01,   2.47528076e-01],
                        [  2.31292725e-01,   2.31292725e-01],
                        [  1.91314697e-01,   1.91314697e-01],
                        [  1.52008057e-01,   1.52008057e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  9.70458984e-02,   9.70153809e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  8.19396973e-02,   8.19396973e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  9.27734375e-03,   9.24682617e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.09350586e-02,  -2.09655762e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.13525391e-02,  -1.13220215e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  8.34960938e-02,   8.34960938e-02],
                        [  1.03607178e-01,   1.03576660e-01],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -1.32385254e-01,  -1.32385254e-01],
                        [ -1.94824219e-01,  -1.94824219e-01],
                        [ -2.19177246e-01,  -2.19177246e-01],
                        [ -2.04498291e-01,  -2.04498291e-01],
                        [ -1.70135498e-01,  -1.70135498e-01],
                        [ -1.40930176e-01,  -1.40930176e-01],
                        [ -1.24206543e-01,  -1.24206543e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -9.87854004e-02,  -9.87854004e-02],
                        [ -9.29260254e-02,  -9.29260254e-02],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -9.15527344e-02,  -9.15527344e-02],
                        [ -8.70056152e-02,  -8.70056152e-02],
                        [ -8.40759277e-02,  -8.40759277e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  1.38488770e-01,   1.38488770e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  7.83081055e-02,   7.83386230e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  9.53063965e-02,   9.53063965e-02],
                        [  1.15051270e-01,   1.15051270e-01],
                        [  1.40563965e-01,   1.40563965e-01],
                        [  1.75201416e-01,   1.75201416e-01],
                        [  2.11822510e-01,   2.11822510e-01],
                        [  2.30957031e-01,   2.30957031e-01],
                        [  2.14324951e-01,   2.14324951e-01],
                        [  1.55975342e-01,   1.55975342e-01],
                        [  6.24389648e-02,   6.24389648e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -1.66290283e-01,  -1.66290283e-01],
                        [ -2.59124756e-01,  -2.59124756e-01],
                        [ -3.04595947e-01,  -3.04595947e-01],
                        [ -2.87017822e-01,  -2.87017822e-01],
                        [ -2.21496582e-01,  -2.21496582e-01],
                        [ -1.54357910e-01,  -1.54357910e-01],
                        [ -1.24298096e-01,  -1.24298096e-01],
                        [ -1.28692627e-01,  -1.28692627e-01],
                        [ -1.39709473e-01,  -1.39678955e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -1.33422852e-01,  -1.33422852e-01],
                        [ -1.26770020e-01,  -1.26770020e-01],
                        [ -1.24481201e-01,  -1.24481201e-01],
                        [ -1.20208740e-01,  -1.20208740e-01],
                        [ -1.00372314e-01,  -1.00372314e-01],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.93847656e-01,   1.93847656e-01],
                        [  2.18566895e-01,   2.18566895e-01],
                        [  2.14019775e-01,   2.14019775e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  1.60980225e-01,   1.60980225e-01],
                        [  1.39129639e-01,   1.39099121e-01],
                        [  1.24908447e-01,   1.24938965e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  9.20104980e-02,   9.20410156e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -1.17797852e-02,  -1.17492676e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -1.43432617e-03,  -1.46484375e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  5.18798828e-02,   5.19104004e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -8.92028809e-02,  -8.92028809e-02],
                        [ -1.64825439e-01,  -1.64825439e-01],
                        [ -2.10052490e-01,  -2.10052490e-01],
                        [ -2.14172363e-01,  -2.14172363e-01],
                        [ -1.88262939e-01,  -1.88262939e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -1.15264893e-01,  -1.15264893e-01],
                        [ -1.06292725e-01,  -1.06292725e-01],
                        [ -9.60693359e-02,  -9.60693359e-02],
                        [ -8.49914551e-02,  -8.49914551e-02],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -9.20410156e-02,  -9.20410156e-02],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.25000000e-01,   1.25000000e-01],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  8.35876465e-02,   8.35876465e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  1.65313721e-01,   1.65313721e-01],
                        [  1.88629150e-01,   1.88659668e-01],
                        [  2.01416016e-01,   2.01385498e-01],
                        [  1.99340820e-01,   1.99340820e-01],
                        [  1.72180176e-01,   1.72210693e-01],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  1.15356445e-02,   1.15356445e-02],
                        [ -1.09497070e-01,  -1.09497070e-01],
                        [ -2.25006104e-01,  -2.25006104e-01],
                        [ -3.00689697e-01,  -3.00689697e-01],
                        [ -3.14392090e-01,  -3.14392090e-01],
                        [ -2.72338867e-01,  -2.72338867e-01],
                        [ -2.08404541e-01,  -2.08404541e-01],
                        [ -1.58843994e-01,  -1.58843994e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.29394531e-01,  -1.29394531e-01],
                        [ -1.28540039e-01,  -1.28540039e-01],
                        [ -1.30004883e-01,  -1.30004883e-01],
                        [ -1.32568359e-01,  -1.32537842e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.20422363e-01,  -1.20422363e-01],
                        [ -9.50012207e-02,  -9.49707031e-02],
                        [ -5.36499023e-02,  -5.36804199e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  1.51031494e-01,   1.51031494e-01],
                        [  2.08435059e-01,   2.08435059e-01],
                        [  2.29339600e-01,   2.29339600e-01],
                        [  2.11395264e-01,   2.11395264e-01],
                        [  1.71112061e-01,   1.71112061e-01],
                        [  1.32934570e-01,   1.32934570e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.16546631e-01,   1.16546631e-01],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.28021240e-01,   1.28051758e-01],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.09191895e-01,   1.09191895e-01],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  3.23486328e-02,   3.23791504e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.66931152e-02,   1.66625977e-02],
                        [  1.87988281e-02,   1.87683105e-02],
                        [  1.22375488e-02,   1.22680664e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -3.72314453e-03,  -3.69262695e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  8.01086426e-02,   8.01086426e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.13067627e-01,  -1.13067627e-01],
                        [ -1.80786133e-01,  -1.80786133e-01],
                        [ -2.11120605e-01,  -2.11120605e-01],
                        [ -2.01293945e-01,  -2.01263428e-01],
                        [ -1.72149658e-01,  -1.72149658e-01],
                        [ -1.47094727e-01,  -1.47125244e-01],
                        [ -1.34582520e-01,  -1.34582520e-01],
                        [ -1.28662109e-01,  -1.28662109e-01],
                        [ -1.21276855e-01,  -1.21276855e-01],
                        [ -1.10015869e-01,  -1.10015869e-01],
                        [ -9.75646973e-02,  -9.75646973e-02],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -9.45434570e-02,  -9.45129395e-02],
                        [ -1.03210449e-01,  -1.03210449e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.32202148e-01,   1.32171631e-01],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.00891113e-01,   1.00921631e-01],
                        [  8.58459473e-02,   8.58459473e-02],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  1.12762451e-01,   1.12792969e-01],
                        [  1.40747070e-01,   1.40747070e-01],
                        [  1.70593262e-01,   1.70593262e-01],
                        [  1.96472168e-01,   1.96472168e-01],
                        [  2.10601807e-01,   2.10601807e-01],
                        [  2.08160400e-01,   2.08160400e-01],
                        [  1.81427002e-01,   1.81396484e-01],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -1.20300293e-01,  -1.20300293e-01],
                        [ -2.37121582e-01,  -2.37121582e-01],
                        [ -3.09936523e-01,  -3.09936523e-01],
                        [ -3.20343018e-01,  -3.20373535e-01],
                        [ -2.74627686e-01,  -2.74627686e-01],
                        [ -2.08435059e-01,  -2.08435059e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.44500732e-01,  -1.44500732e-01],
                        [ -1.40289307e-01,  -1.40289307e-01],
                        [ -1.35406494e-01,  -1.35406494e-01],
                        [ -1.32080078e-01,  -1.32080078e-01],
                        [ -1.32995605e-01,  -1.32995605e-01],
                        [ -1.29089355e-01,  -1.29089355e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -7.85827637e-02,  -7.85827637e-02],
                        [ -3.52172852e-02,  -3.52478027e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.69677734e-01,   1.69677734e-01],
                        [  2.17620850e-01,   2.17620850e-01],
                        [  2.28881836e-01,   2.28881836e-01],
                        [  2.06481934e-01,   2.06481934e-01],
                        [  1.67938232e-01,   1.67938232e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.39465332e-02,   1.39160156e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [ -1.83105469e-03,  -1.80053711e-03],
                        [ -1.67846680e-02,  -1.68151855e-02],
                        [ -2.52075195e-02,  -2.52380371e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.82897949e-02,  -2.83203125e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.41699219e-02,  -2.41394043e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -2.84729004e-02,  -2.85034180e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  4.49829102e-02,   4.49829102e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -1.14593506e-01,  -1.14593506e-01],
                        [ -1.80938721e-01,  -1.80938721e-01],
                        [ -2.09167480e-01,  -2.09167480e-01],
                        [ -1.96899414e-01,  -1.96899414e-01],
                        [ -1.66412354e-01,  -1.66412354e-01],
                        [ -1.42211914e-01,  -1.42211914e-01],
                        [ -1.32659912e-01,  -1.32659912e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -1.18316650e-01,  -1.18286133e-01],
                        [ -1.03698730e-01,  -1.03698730e-01],
                        [ -9.59777832e-02,  -9.59777832e-02],
                        [ -9.76257324e-02,  -9.76257324e-02],
                        [ -9.83581543e-02,  -9.83581543e-02],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.20330811e-01,   1.20330811e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.54724121e-01,   1.54724121e-01],
                        [  1.81518555e-01,   1.81518555e-01],
                        [  2.02972412e-01,   2.02972412e-01],
                        [  2.16247559e-01,   2.16217041e-01],
                        [  2.11242676e-01,   2.11273193e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  9.10644531e-02,   9.10339355e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.47766113e-01,  -1.47766113e-01],
                        [ -2.51190186e-01,  -2.51190186e-01],
                        [ -3.07617188e-01,  -3.07647705e-01],
                        [ -3.04779053e-01,  -3.04779053e-01],
                        [ -2.53417969e-01,  -2.53417969e-01],
                        [ -1.85974121e-01,  -1.86004639e-01],
                        [ -1.37176514e-01,  -1.37207031e-01],
                        [ -1.20483398e-01,  -1.20483398e-01],
                        [ -1.25579834e-01,  -1.25579834e-01],
                        [ -1.36627197e-01,  -1.36657715e-01],
                        [ -1.44866943e-01,  -1.44866943e-01],
                        [ -1.44012451e-01,  -1.44012451e-01],
                        [ -1.27075195e-01,  -1.27105713e-01],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  5.78308105e-02,   5.78308105e-02],
                        [  1.18896484e-01,   1.18896484e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  2.08007812e-01,   2.08007812e-01],
                        [  2.07580566e-01,   2.07580566e-01],
                        [  1.80114746e-01,   1.80114746e-01],
                        [  1.46362305e-01,   1.46362305e-01],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.05041504e-01,   1.05041504e-01],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  8.71582031e-02,   8.71276855e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  8.70056152e-02,   8.70056152e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  7.44934082e-02,   7.44934082e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  5.50231934e-02,   5.50231934e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  3.60412598e-02,   3.60107422e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  2.04467773e-02,   2.04772949e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.54724121e-02,   1.55029297e-02],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.35900879e-02,  -2.35595703e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -4.91638184e-02,  -4.91943359e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -4.07409668e-02,  -4.07104492e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.49536133e-02,  -1.49230957e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.37121582e-02,   2.36816406e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  3.84216309e-02,   3.84521484e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  8.16345215e-02,   8.16650391e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  2.94494629e-02,   2.94799805e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -1.60430908e-01,  -1.60430908e-01],
                        [ -2.14019775e-01,  -2.13989258e-01],
                        [ -2.26409912e-01,  -2.26440430e-01],
                        [ -1.98760986e-01,  -1.98760986e-01],
                        [ -1.54937744e-01,  -1.54907227e-01],
                        [ -1.23291016e-01,  -1.23291016e-01],
                        [ -1.14105225e-01,  -1.14135742e-01],
                        [ -1.15600586e-01,  -1.15600586e-01],
                        [ -1.10198975e-01,  -1.10198975e-01],
                        [ -9.40551758e-02,  -9.40551758e-02],
                        [ -8.02001953e-02,  -8.02001953e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -9.14611816e-02,  -9.14916992e-02],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -8.11157227e-02,  -8.11157227e-02],
                        [ -5.06286621e-02,  -5.06591797e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  8.70666504e-02,   8.70666504e-02],
                        [  1.20391846e-01,   1.20391846e-01],
                        [  1.34796143e-01,   1.34796143e-01],
                        [  1.36535645e-01,   1.36535645e-01],
                        [  1.36352539e-01,   1.36352539e-01],
                        [  1.38916016e-01,   1.38916016e-01],
                        [  1.44134521e-01,   1.44134521e-01],
                        [  1.55334473e-01,   1.55334473e-01],
                        [  1.75811768e-01,   1.75811768e-01],
                        [  1.98089600e-01,   1.98089600e-01],
                        [  2.07550049e-01,   2.07550049e-01],
                        [  1.94488525e-01,   1.94488525e-01],
                        [  1.54785156e-01,   1.54785156e-01],
                        [  8.34350586e-02,   8.34655762e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.45019531e-01,  -1.45019531e-01],
                        [ -2.57476807e-01,  -2.57446289e-01],
                        [ -3.22570801e-01,  -3.22570801e-01],
                        [ -3.19671631e-01,  -3.19671631e-01],
                        [ -2.59490967e-01,  -2.59490967e-01],
                        [ -1.81793213e-01,  -1.81793213e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -1.16271973e-01,  -1.16302490e-01],
                        [ -1.25762939e-01,  -1.25762939e-01],
                        [ -1.33270264e-01,  -1.33270264e-01],
                        [ -1.31225586e-01,  -1.31225586e-01],
                        [ -1.24633789e-01,  -1.24633789e-01],
                        [ -1.12548828e-01,  -1.12548828e-01],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  9.38110352e-02,   9.38415527e-02],
                        [  1.54388428e-01,   1.54388428e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  2.21099854e-01,   2.21099854e-01],
                        [  2.05230713e-01,   2.05230713e-01],
                        [  1.64550781e-01,   1.64550781e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  7.08312988e-02,   7.08007812e-02],
                        [  6.79626465e-02,   6.79931641e-02],
                        [  6.04248047e-02,   6.03942871e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  3.17382812e-02,   3.17687988e-02],
                        [  2.18505859e-02,   2.18811035e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  4.27246094e-03,   4.30297852e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -3.05175781e-03,  -3.08227539e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -3.18298340e-02,  -3.18603516e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.55322266e-02,  -4.55017090e-02],
                        [ -4.88586426e-02,  -4.88891602e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [  7.93457031e-04,   7.93457031e-04],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  3.15856934e-02,   3.15551758e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  3.84216309e-02,   3.84521484e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  5.81054688e-02,   5.81359863e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  5.26733398e-02,   5.26428223e-02],
                        [  4.58679199e-02,   4.58984375e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  3.18298340e-02,   3.17993164e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -1.18652344e-01,  -1.18652344e-01],
                        [ -1.82922363e-01,  -1.82922363e-01],
                        [ -2.18994141e-01,  -2.18963623e-01],
                        [ -2.15209961e-01,  -2.15209961e-01],
                        [ -1.79962158e-01,  -1.79962158e-01],
                        [ -1.36718750e-01,  -1.36688232e-01],
                        [ -1.07421875e-01,  -1.07391357e-01],
                        [ -9.87548828e-02,  -9.87548828e-02],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -1.04705811e-01,  -1.04675293e-01],
                        [ -1.03210449e-01,  -1.03210449e-01],
                        [ -1.00158691e-01,  -1.00158691e-01],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -8.67004395e-02,  -8.67004395e-02],
                        [ -6.75659180e-02,  -6.75964355e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.28692627e-01,   1.28662109e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.56646729e-01,   1.56616211e-01],
                        [  1.87042236e-01,   1.87042236e-01],
                        [  2.10296631e-01,   2.10296631e-01],
                        [  2.12402344e-01,   2.12402344e-01],
                        [  1.88323975e-01,   1.88293457e-01],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  3.92456055e-02,   3.92456055e-02],
                        [ -8.74633789e-02,  -8.74938965e-02],
                        [ -2.16857910e-01,  -2.16857910e-01],
                        [ -3.06152344e-01,  -3.06152344e-01],
                        [ -3.25836182e-01,  -3.25866699e-01],
                        [ -2.80426025e-01,  -2.80426025e-01],
                        [ -2.08221436e-01,  -2.08221436e-01],
                        [ -1.54663086e-01,  -1.54663086e-01],
                        [ -1.38244629e-01,  -1.38244629e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -1.49078369e-01,  -1.49078369e-01],
                        [ -1.42028809e-01,  -1.42059326e-01],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -1.02478027e-01,  -1.02478027e-01],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  1.60491943e-01,   1.60491943e-01],
                        [  2.18475342e-01,   2.18505859e-01],
                        [  2.34436035e-01,   2.34436035e-01],
                        [  2.09747314e-01,   2.09747314e-01],
                        [  1.67236328e-01,   1.67236328e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.09619141e-01,   1.09619141e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  8.91113281e-02,   8.91418457e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  8.56323242e-02,   8.56628418e-02],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  6.63452148e-02,   6.63452148e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  6.13098145e-02,   6.13098145e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  5.61828613e-02,   5.61523438e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  4.17175293e-02,   4.17480469e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.18505859e-02,   2.18811035e-02],
                        [  6.10351562e-03,   6.07299805e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -2.04772949e-02,  -2.04467773e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.17175293e-02,  -4.16870117e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -4.80957031e-02,  -4.81262207e-02],
                        [ -5.10559082e-02,  -5.10864258e-02],
                        [ -5.08117676e-02,  -5.07812500e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -2.76184082e-02,  -2.76489258e-02],
                        [ -6.65283203e-03,  -6.62231445e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  2.22778320e-03,   2.25830078e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.78833008e-02,   1.79138184e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  3.39050293e-02,   3.38745117e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  3.08227539e-02,   3.07922363e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  8.23974609e-03,   8.27026367e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  2.76794434e-02,   2.77099609e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -1.46026611e-01,  -1.45996094e-01],
                        [ -2.03674316e-01,  -2.03674316e-01],
                        [ -2.20001221e-01,  -2.20001221e-01],
                        [ -1.92840576e-01,  -1.92810059e-01],
                        [ -1.49749756e-01,  -1.49749756e-01],
                        [ -1.18774414e-01,  -1.18804932e-01],
                        [ -1.04675293e-01,  -1.04675293e-01],
                        [ -9.81140137e-02,  -9.81140137e-02],
                        [ -9.49707031e-02,  -9.50012207e-02],
                        [ -9.70458984e-02,  -9.70764160e-02],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -1.05285645e-01,  -1.05285645e-01],
                        [ -9.90905762e-02,  -9.91210938e-02],
                        [ -8.14514160e-02,  -8.14514160e-02],
                        [ -5.13305664e-02,  -5.13000488e-02],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  9.15527344e-02,   9.15832520e-02],
                        [  1.31134033e-01,   1.31134033e-01],
                        [  1.50451660e-01,   1.50451660e-01],
                        [  1.48742676e-01,   1.48773193e-01],
                        [  1.41113281e-01,   1.41143799e-01],
                        [  1.49291992e-01,   1.49261475e-01],
                        [  1.77703857e-01,   1.77703857e-01],
                        [  2.08129883e-01,   2.08129883e-01],
                        [  2.22503662e-01,   2.22503662e-01],
                        [  2.17346191e-01,   2.17315674e-01],
                        [  1.89819336e-01,   1.89849854e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  2.69165039e-02,   2.69165039e-02],
                        [ -9.78088379e-02,  -9.78088379e-02],
                        [ -2.17437744e-01,  -2.17437744e-01],
                        [ -3.02368164e-01,  -3.02368164e-01],
                        [ -3.26843262e-01,  -3.26843262e-01],
                        [ -2.84942627e-01,  -2.84912109e-01],
                        [ -2.07733154e-01,  -2.07733154e-01],
                        [ -1.45080566e-01,  -1.45080566e-01],
                        [ -1.22283936e-01,  -1.22314453e-01],
                        [ -1.26861572e-01,  -1.26831055e-01],
                        [ -1.35589600e-01,  -1.35589600e-01],
                        [ -1.38122559e-01,  -1.38153076e-01],
                        [ -1.33178711e-01,  -1.33178711e-01],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -8.60290527e-02,  -8.60595703e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [  4.08325195e-02,   4.08630371e-02],
                        [  1.26281738e-01,   1.26251221e-01],
                        [  1.94763184e-01,   1.94763184e-01],
                        [  2.20703125e-01,   2.20703125e-01],
                        [  2.05993652e-01,   2.05963135e-01],
                        [  1.73767090e-01,   1.73767090e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  7.91625977e-02,   7.91931152e-02],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  7.87963867e-02,   7.87658691e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  7.73010254e-02,   7.72705078e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -2.61535645e-02,  -2.61230469e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -4.27856445e-02,  -4.28161621e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.65295410e-02,  -3.65600586e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  7.04956055e-03,   7.08007812e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  7.41577148e-03,   7.38525391e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  6.74438477e-03,   6.71386719e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.31823730e-02,   4.32128906e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [ -2.64892578e-02,  -2.65197754e-02],
                        [ -8.96606445e-02,  -8.96606445e-02],
                        [ -1.54510498e-01,  -1.54479980e-01],
                        [ -1.95037842e-01,  -1.95037842e-01],
                        [ -1.99493408e-01,  -1.99493408e-01],
                        [ -1.79412842e-01,  -1.79412842e-01],
                        [ -1.56005859e-01,  -1.55975342e-01],
                        [ -1.41418457e-01,  -1.41448975e-01],
                        [ -1.32690430e-01,  -1.32690430e-01],
                        [ -1.20117188e-01,  -1.20086670e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -8.70361328e-02,  -8.70666504e-02],
                        [ -8.22143555e-02,  -8.22143555e-02],
                        [ -8.08715820e-02,  -8.08715820e-02],
                        [ -7.14721680e-02,  -7.14721680e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.52160645e-01,   1.52160645e-01],
                        [  1.60278320e-01,   1.60308838e-01],
                        [  1.69769287e-01,   1.69738770e-01],
                        [  1.83074951e-01,   1.83074951e-01],
                        [  1.96075439e-01,   1.96075439e-01],
                        [  2.04101562e-01,   2.04101562e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  1.75415039e-01,   1.75415039e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  1.53198242e-02,   1.53198242e-02],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -2.11639404e-01,  -2.11639404e-01],
                        [ -2.87139893e-01,  -2.87139893e-01],
                        [ -3.09356689e-01,  -3.09356689e-01],
                        [ -2.78656006e-01,  -2.78656006e-01],
                        [ -2.20001221e-01,  -2.20001221e-01],
                        [ -1.69250488e-01,  -1.69281006e-01],
                        [ -1.47949219e-01,  -1.47949219e-01],
                        [ -1.50390625e-01,  -1.50390625e-01],
                        [ -1.54235840e-01,  -1.54235840e-01],
                        [ -1.44378662e-01,  -1.44409180e-01],
                        [ -1.25244141e-01,  -1.25213623e-01],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -8.05664062e-02,  -8.05664062e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  1.37329102e-01,   1.37329102e-01],
                        [  2.05657959e-01,   2.05627441e-01],
                        [  2.33032227e-01,   2.33062744e-01],
                        [  2.15332031e-01,   2.15332031e-01],
                        [  1.68731689e-01,   1.68701172e-01],
                        [  1.20880127e-01,   1.20880127e-01],
                        [  9.14001465e-02,   9.14306641e-02],
                        [  7.98339844e-02,   7.98034668e-02],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  6.82373047e-02,   6.82678223e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  6.75964355e-02,   6.75659180e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  5.86242676e-02,   5.85937500e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  6.13403320e-02,   6.13403320e-02],
                        [  6.38122559e-02,   6.37817383e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  7.70568848e-02,   7.70874023e-02],
                        [  7.73620605e-02,   7.73620605e-02],
                        [  7.23266602e-02,   7.22961426e-02],
                        [  6.39953613e-02,   6.39953613e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.72412109e-02,  -4.72106934e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  7.78198242e-03,   7.75146484e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -1.01776123e-01,  -1.01776123e-01],
                        [ -1.65252686e-01,  -1.65252686e-01],
                        [ -1.99340820e-01,  -1.99340820e-01],
                        [ -1.93725586e-01,  -1.93725586e-01],
                        [ -1.62231445e-01,  -1.62231445e-01],
                        [ -1.32629395e-01,  -1.32598877e-01],
                        [ -1.19445801e-01,  -1.19476318e-01],
                        [ -1.13952637e-01,  -1.13983154e-01],
                        [ -1.02813721e-01,  -1.02813721e-01],
                        [ -8.64562988e-02,  -8.64562988e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -7.11059570e-02,  -7.10754395e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -6.43310547e-02,  -6.43615723e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.47430420e-01,   1.47430420e-01],
                        [  1.57226562e-01,   1.57226562e-01],
                        [  1.64672852e-01,   1.64703369e-01],
                        [  1.82342529e-01,   1.82342529e-01],
                        [  2.08984375e-01,   2.08953857e-01],
                        [  2.28271484e-01,   2.28271484e-01],
                        [  2.20245361e-01,   2.20245361e-01],
                        [  1.74102783e-01,   1.74072266e-01],
                        [  9.10339355e-02,   9.10339355e-02],
                        [ -2.03857422e-02,  -2.03552246e-02],
                        [ -1.45355225e-01,  -1.45355225e-01],
                        [ -2.58453369e-01,  -2.58483887e-01],
                        [ -3.26843262e-01,  -3.26843262e-01],
                        [ -3.29589844e-01,  -3.29559326e-01],
                        [ -2.77526855e-01,  -2.77526855e-01],
                        [ -2.09960938e-01,  -2.09960938e-01],
                        [ -1.64489746e-01,  -1.64489746e-01],
                        [ -1.48254395e-01,  -1.48254395e-01],
                        [ -1.42150879e-01,  -1.42181396e-01],
                        [ -1.30554199e-01,  -1.30554199e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -1.03271484e-01,  -1.03271484e-01],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  2.17681885e-01,   2.17681885e-01],
                        [  2.26226807e-01,   2.26226807e-01],
                        [  2.06207275e-01,   2.06207275e-01],
                        [  1.71142578e-01,   1.71142578e-01],
                        [  1.29516602e-01,   1.29547119e-01],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  7.28454590e-02,   7.28759766e-02],
                        [  6.41479492e-02,   6.41174316e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  4.90417480e-02,   4.90722656e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.80139160e-02,   5.80139160e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  5.59387207e-02,   5.59082031e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -6.15539551e-02,  -6.15844727e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.50146484e-02,  -1.49841309e-02],
                        [ -1.55639648e-02,  -1.55944824e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  4.27246094e-03,   4.24194336e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -1.03729248e-01,  -1.03729248e-01],
                        [ -1.57409668e-01,  -1.57409668e-01],
                        [ -1.85150146e-01,  -1.85180664e-01],
                        [ -1.76635742e-01,  -1.76635742e-01],
                        [ -1.48193359e-01,  -1.48193359e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.08123779e-01,  -1.08123779e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -8.69750977e-02,  -8.69750977e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -5.14526367e-02,  -5.14831543e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  5.35583496e-02,   5.35278320e-02],
                        [  1.11511230e-01,   1.11480713e-01],
                        [  1.58874512e-01,   1.58874512e-01],
                        [  1.92657471e-01,   1.92657471e-01],
                        [  2.17559814e-01,   2.17559814e-01],
                        [  2.36267090e-01,   2.36267090e-01],
                        [  2.45300293e-01,   2.45300293e-01],
                        [  2.35839844e-01,   2.35839844e-01],
                        [  1.97540283e-01,   1.97540283e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  2.28271484e-02,   2.28271484e-02],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -2.21282959e-01,  -2.21282959e-01],
                        [ -3.18634033e-01,  -3.18634033e-01],
                        [ -3.55163574e-01,  -3.55194092e-01],
                        [ -3.17535400e-01,  -3.17535400e-01],
                        [ -2.39105225e-01,  -2.39105225e-01],
                        [ -1.76300049e-01,  -1.76300049e-01],
                        [ -1.55639648e-01,  -1.55639648e-01],
                        [ -1.58508301e-01,  -1.58508301e-01],
                        [ -1.55517578e-01,  -1.55517578e-01],
                        [ -1.37786865e-01,  -1.37786865e-01],
                        [ -1.12854004e-01,  -1.12884521e-01],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  9.66491699e-02,   9.66186523e-02],
                        [  1.76727295e-01,   1.76727295e-01],
                        [  2.24060059e-01,   2.24060059e-01],
                        [  2.25189209e-01,   2.25189209e-01],
                        [  1.93786621e-01,   1.93786621e-01],
                        [  1.55212402e-01,   1.55212402e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  4.15649414e-02,   4.15954590e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  6.70166016e-02,   6.70166016e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  7.11975098e-02,   7.12280273e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  5.82580566e-02,   5.82580566e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.12609863e-02,   1.12304688e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  1.80053711e-03,   1.77001953e-03],
                        [  6.71386719e-04,   7.01904297e-04],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.51062012e-02,   1.50756836e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.36413574e-02,   1.36718750e-02],
                        [  6.86645508e-03,   6.83593750e-03],
                        [ -2.56347656e-03,  -2.59399414e-03],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  3.96728516e-04,   4.27246094e-04],
                        [  6.71386719e-03,   6.74438477e-03],
                        [  1.39160156e-02,   1.38854980e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.45861816e-02,   4.45556641e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -1.39129639e-01,  -1.39129639e-01],
                        [ -1.81457520e-01,  -1.81427002e-01],
                        [ -1.97326660e-01,  -1.97326660e-01],
                        [ -1.81396484e-01,  -1.81427002e-01],
                        [ -1.44805908e-01,  -1.44805908e-01],
                        [ -1.08856201e-01,  -1.08856201e-01],
                        [ -8.63647461e-02,  -8.63647461e-02],
                        [ -7.59582520e-02,  -7.59582520e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -7.24487305e-02,  -7.24487305e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -5.39855957e-02,  -5.39550781e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  8.56933594e-02,   8.56933594e-02],
                        [  1.34002686e-01,   1.34002686e-01],
                        [  1.70989990e-01,   1.70989990e-01],
                        [  2.00347900e-01,   2.00347900e-01],
                        [  2.20733643e-01,   2.20764160e-01],
                        [  2.27355957e-01,   2.27355957e-01],
                        [  2.20428467e-01,   2.20428467e-01],
                        [  1.99035645e-01,   1.99035645e-01],
                        [  1.52587891e-01,   1.52587891e-01],
                        [  7.12280273e-02,   7.12280273e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -1.57989502e-01,  -1.57958984e-01],
                        [ -2.60314941e-01,  -2.60314941e-01],
                        [ -3.20404053e-01,  -3.20404053e-01],
                        [ -3.20831299e-01,  -3.20831299e-01],
                        [ -2.69226074e-01,  -2.69226074e-01],
                        [ -2.02789307e-01,  -2.02789307e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.53656006e-01,  -1.53625488e-01],
                        [ -1.53808594e-01,  -1.53808594e-01],
                        [ -1.39312744e-01,  -1.39312744e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  1.43341064e-01,   1.43341064e-01],
                        [  1.94549561e-01,   1.94549561e-01],
                        [  2.12432861e-01,   2.12432861e-01],
                        [  1.97784424e-01,   1.97784424e-01],
                        [  1.65710449e-01,   1.65710449e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  1.08886719e-01,   1.08917236e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.07495117e-02,   8.07800293e-02],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  7.39135742e-02,   7.39135742e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  3.53393555e-02,   3.53088379e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  2.78015137e-02,   2.78320312e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [ -4.63867188e-03,  -4.66918945e-03],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -3.02734375e-02,  -3.02429199e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  7.41577148e-03,   7.38525391e-03],
                        [  1.19934082e-02,   1.20239258e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  8.17871094e-03,   8.14819336e-03],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.27563477e-02,   1.27258301e-02],
                        [  1.07421875e-02,   1.07727051e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.54724121e-02,   1.54418945e-02],
                        [  1.52893066e-02,   1.53198242e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -1.10961914e-01,  -1.10961914e-01],
                        [ -1.61499023e-01,  -1.61499023e-01],
                        [ -1.86614990e-01,  -1.86614990e-01],
                        [ -1.75933838e-01,  -1.75933838e-01],
                        [ -1.41815186e-01,  -1.41784668e-01],
                        [ -1.09710693e-01,  -1.09710693e-01],
                        [ -9.29870605e-02,  -9.30175781e-02],
                        [ -8.59375000e-02,  -8.59069824e-02],
                        [ -8.02612305e-02,  -8.02612305e-02],
                        [ -7.62329102e-02,  -7.62634277e-02],
                        [ -7.58056641e-02,  -7.58056641e-02],
                        [ -7.43103027e-02,  -7.42797852e-02],
                        [ -6.08520508e-02,  -6.08825684e-02],
                        [ -2.56042480e-02,  -2.56347656e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.45477295e-01,   1.45477295e-01],
                        [  1.78741455e-01,   1.78741455e-01],
                        [  1.99188232e-01,   1.99188232e-01],
                        [  2.15850830e-01,   2.15850830e-01],
                        [  2.29736328e-01,   2.29736328e-01],
                        [  2.29980469e-01,   2.29980469e-01],
                        [  1.99249268e-01,   1.99249268e-01],
                        [  1.26861572e-01,   1.26861572e-01],
                        [  1.91345215e-02,   1.91345215e-02],
                        [ -1.03546143e-01,  -1.03546143e-01],
                        [ -2.17864990e-01,  -2.17864990e-01],
                        [ -3.00903320e-01,  -3.00903320e-01],
                        [ -3.31054688e-01,  -3.31054688e-01],
                        [ -3.02581787e-01,  -3.02581787e-01],
                        [ -2.40051270e-01,  -2.40051270e-01],
                        [ -1.84234619e-01,  -1.84234619e-01],
                        [ -1.58538818e-01,  -1.58538818e-01],
                        [ -1.54968262e-01,  -1.54968262e-01],
                        [ -1.51702881e-01,  -1.51702881e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.06109619e-01,  -1.06109619e-01],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  2.02697754e-01,   2.02697754e-01],
                        [  1.96014404e-01,   1.96014404e-01],
                        [  1.70898438e-01,   1.70928955e-01],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.10015869e-01,   1.09985352e-01],
                        [  9.14306641e-02,   9.14306641e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  5.35583496e-02,   5.35278320e-02],
                        [  5.55419922e-02,   5.55114746e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.17785645e-02,   4.18090820e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.61743164e-03,   1.64794922e-03],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.25427246e-02,  -1.25122070e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  7.01904297e-03,   7.04956055e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  2.25830078e-03,   2.28881836e-03],
                        [  8.72802734e-03,   8.69750977e-03],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.21350098e-02,   3.21044922e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -1.58447266e-01,  -1.58447266e-01],
                        [ -1.83685303e-01,  -1.83685303e-01],
                        [ -1.75262451e-01,  -1.75231934e-01],
                        [ -1.46392822e-01,  -1.46423340e-01],
                        [ -1.19506836e-01,  -1.19506836e-01],
                        [ -1.07391357e-01,  -1.07360840e-01],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -9.24682617e-02,  -9.24987793e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.61743164e-01,   1.61743164e-01],
                        [  1.99737549e-01,   1.99768066e-01],
                        [  2.19818115e-01,   2.19818115e-01],
                        [  2.28942871e-01,   2.28942871e-01],
                        [  2.29309082e-01,   2.29309082e-01],
                        [  2.08038330e-01,   2.08038330e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  5.13610840e-02,   5.13305664e-02],
                        [ -7.10449219e-02,  -7.10449219e-02],
                        [ -1.96533203e-01,  -1.96533203e-01],
                        [ -2.96661377e-01,  -2.96691895e-01],
                        [ -3.41003418e-01,  -3.41003418e-01],
                        [ -3.18878174e-01,  -3.18847656e-01],
                        [ -2.55157471e-01,  -2.55157471e-01],
                        [ -1.93511963e-01,  -1.93511963e-01],
                        [ -1.61621094e-01,  -1.61590576e-01],
                        [ -1.54968262e-01,  -1.54968262e-01],
                        [ -1.51611328e-01,  -1.51611328e-01],
                        [ -1.35955811e-01,  -1.35955811e-01],
                        [ -1.06170654e-01,  -1.06140137e-01],
                        [ -6.34765625e-02,  -6.35070801e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  6.39953613e-02,   6.39953613e-02],
                        [  1.35375977e-01,   1.35375977e-01],
                        [  1.90399170e-01,   1.90368652e-01],
                        [  2.14111328e-01,   2.14111328e-01],
                        [  2.03674316e-01,   2.03704834e-01],
                        [  1.71081543e-01,   1.71081543e-01],
                        [  1.33514404e-01,   1.33483887e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  8.31604004e-02,   8.31909180e-02],
                        [  7.70874023e-02,   7.70874023e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  4.33959961e-02,   4.34265137e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  8.09631348e-02,   8.09326172e-02],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  5.49316406e-02,   5.49621582e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -3.80554199e-02,  -3.80249023e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -2.38952637e-02,  -2.39257812e-02],
                        [ -1.11694336e-02,  -1.11999512e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  5.06591797e-03,   5.09643555e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  1.49536133e-03,   1.52587891e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -1.20239258e-02,  -1.19934082e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.63574219e-02,  -1.63879395e-02],
                        [ -1.51977539e-02,  -1.51672363e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -1.18835449e-01,  -1.18835449e-01],
                        [ -1.66625977e-01,  -1.66625977e-01],
                        [ -1.90185547e-01,  -1.90185547e-01],
                        [ -1.81549072e-01,  -1.81549072e-01],
                        [ -1.50482178e-01,  -1.50482178e-01],
                        [ -1.17858887e-01,  -1.17828369e-01],
                        [ -9.68322754e-02,  -9.68322754e-02],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  1.41998291e-01,   1.42028809e-01],
                        [  1.92352295e-01,   1.92352295e-01],
                        [  2.27813721e-01,   2.27783203e-01],
                        [  2.43225098e-01,   2.43225098e-01],
                        [  2.34893799e-01,   2.34893799e-01],
                        [  1.99981689e-01,   1.99981689e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  3.33557129e-02,   3.33862305e-02],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -2.11334229e-01,  -2.11364746e-01],
                        [ -3.01483154e-01,  -3.01483154e-01],
                        [ -3.36853027e-01,  -3.36853027e-01],
                        [ -3.11889648e-01,  -3.11889648e-01],
                        [ -2.50335693e-01,  -2.50335693e-01],
                        [ -1.94976807e-01,  -1.94976807e-01],
                        [ -1.72119141e-01,  -1.72119141e-01],
                        [ -1.70074463e-01,  -1.70074463e-01],
                        [ -1.59973145e-01,  -1.59973145e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -8.21533203e-02,  -8.21533203e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  1.14654541e-01,   1.14654541e-01],
                        [  1.73034668e-01,   1.73065186e-01],
                        [  2.02972412e-01,   2.02972412e-01],
                        [  2.02239990e-01,   2.02239990e-01],
                        [  1.80236816e-01,   1.80236816e-01],
                        [  1.51062012e-01,   1.51062012e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  8.21838379e-02,   8.22143555e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  6.09741211e-02,   6.09436035e-02],
                        [  6.72607422e-02,   6.72912598e-02],
                        [  6.88171387e-02,   6.88171387e-02],
                        [  5.84411621e-02,   5.84411621e-02],
                        [  4.40368652e-02,   4.40673828e-02],
                        [  3.56445312e-02,   3.56750488e-02],
                        [  3.57055664e-02,   3.56750488e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  5.49011230e-02,   5.49316406e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  8.23364258e-02,   8.23364258e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.86254883e-02,   2.85949707e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -1.51367188e-02,  -1.51062012e-02],
                        [ -1.54418945e-02,  -1.54113770e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -2.71911621e-02,  -2.72216797e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  2.01721191e-02,   2.01416016e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -1.18682861e-01,  -1.18682861e-01],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -1.57135010e-01,  -1.57104492e-01],
                        [ -1.33911133e-01,  -1.33911133e-01],
                        [ -1.05712891e-01,  -1.05743408e-01],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -7.97729492e-02,  -7.97729492e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -2.19421387e-02,  -2.19726562e-02],
                        [  1.62353516e-02,   1.62658691e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  1.78192139e-01,   1.78192139e-01],
                        [  2.18475342e-01,   2.18475342e-01],
                        [  2.38525391e-01,   2.38525391e-01],
                        [  2.30377197e-01,   2.30377197e-01],
                        [  1.88415527e-01,   1.88415527e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -1.17950439e-01,  -1.17950439e-01],
                        [ -2.40600586e-01,  -2.40600586e-01],
                        [ -3.25408936e-01,  -3.25408936e-01],
                        [ -3.44757080e-01,  -3.44757080e-01],
                        [ -3.02001953e-01,  -3.02001953e-01],
                        [ -2.31872559e-01,  -2.31872559e-01],
                        [ -1.77001953e-01,  -1.77001953e-01],
                        [ -1.57867432e-01,  -1.57867432e-01],
                        [ -1.59484863e-01,  -1.59484863e-01],
                        [ -1.50390625e-01,  -1.50390625e-01],
                        [ -1.15386963e-01,  -1.15386963e-01],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.82373047e-01,   1.82403564e-01],
                        [  2.10266113e-01,   2.10266113e-01],
                        [  2.06176758e-01,   2.06176758e-01],
                        [  1.83868408e-01,   1.83898926e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.07208252e-01,   1.07238770e-01],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  6.15539551e-02,   6.15234375e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.37011719e-02,   4.37011719e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  7.87353516e-03,   7.90405273e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -1.35589600e-01,  -1.35589600e-01],
                        [ -1.63299561e-01,  -1.63299561e-01],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -1.40045166e-01,  -1.40045166e-01],
                        [ -1.16271973e-01,  -1.16271973e-01],
                        [ -9.78698730e-02,  -9.78698730e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.84600830e-01,   1.84600830e-01],
                        [  2.31323242e-01,   2.31323242e-01],
                        [  2.41638184e-01,   2.41638184e-01],
                        [  2.12402344e-01,   2.12402344e-01],
                        [  1.48742676e-01,   1.48742676e-01],
                        [  5.43518066e-02,   5.43518066e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -1.86889648e-01,  -1.86889648e-01],
                        [ -2.84240723e-01,  -2.84240723e-01],
                        [ -3.28643799e-01,  -3.28643799e-01],
                        [ -3.11462402e-01,  -3.11462402e-01],
                        [ -2.53479004e-01,  -2.53479004e-01],
                        [ -1.95709229e-01,  -1.95709229e-01],
                        [ -1.67175293e-01,  -1.67175293e-01],
                        [ -1.61743164e-01,  -1.61743164e-01],
                        [ -1.51733398e-01,  -1.51733398e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  9.36584473e-02,   9.36584473e-02],
                        [  1.47247314e-01,   1.47247314e-01],
                        [  1.82159424e-01,   1.82159424e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.79687500e-01,   1.79687500e-01],
                        [  1.58142090e-01,   1.58142090e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.11999512e-01,   1.11999512e-01],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  6.41479492e-02,   6.41479492e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  6.61926270e-02,   6.61926270e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  5.58471680e-03,   5.55419922e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.82495117e-02,   1.82189941e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -1.00433350e-01,  -1.00433350e-01],
                        [ -1.37329102e-01,  -1.37329102e-01],
                        [ -1.50970459e-01,  -1.50970459e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -1.12945557e-01,  -1.12945557e-01],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -3.30200195e-02,  -3.29895020e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  1.56158447e-01,   1.56158447e-01],
                        [  2.03247070e-01,   2.03247070e-01],
                        [  2.18719482e-01,   2.18719482e-01],
                        [  1.91558838e-01,   1.91558838e-01],
                        [  1.24816895e-01,   1.24816895e-01],
                        [  2.76489258e-02,   2.76489258e-02],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -2.08282471e-01,  -2.08282471e-01],
                        [ -2.95349121e-01,  -2.95349121e-01],
                        [ -3.21258545e-01,  -3.21258545e-01],
                        [ -2.87384033e-01,  -2.87384033e-01],
                        [ -2.30407715e-01,  -2.30407715e-01],
                        [ -1.89880371e-01,  -1.89880371e-01],
                        [ -1.73370361e-01,  -1.73370361e-01],
                        [ -1.60064697e-01,  -1.60064697e-01],
                        [ -1.33087158e-01,  -1.33087158e-01],
                        [ -9.48181152e-02,  -9.48181152e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.53198242e-01,   1.53198242e-01],
                        [  1.73980713e-01,   1.73980713e-01],
                        [  1.71386719e-01,   1.71386719e-01],
                        [  1.61499023e-01,   1.61499023e-01],
                        [  1.53961182e-01,   1.53961182e-01],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.27166748e-01,   1.27166748e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  3.46679688e-02,   3.46679688e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -1.25000000e-01,  -1.25000000e-01],
                        [ -1.54785156e-01,  -1.54785156e-01],
                        [ -1.54602051e-01,  -1.54602051e-01],
                        [ -1.29638672e-01,  -1.29638672e-01],
                        [ -9.41467285e-02,  -9.41467285e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.97998047e-01,   1.97998047e-01],
                        [  2.39196777e-01,   2.39196777e-01],
                        [  2.37152100e-01,   2.37152100e-01],
                        [  1.87316895e-01,   1.87316895e-01],
                        [  9.86938477e-02,   9.86938477e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.49108887e-01,  -1.49108887e-01],
                        [ -2.71972656e-01,  -2.71972656e-01],
                        [ -3.49212646e-01,  -3.49212646e-01],
                        [ -3.56292725e-01,  -3.56292725e-01],
                        [ -3.07312012e-01,  -3.07312012e-01],
                        [ -2.46398926e-01,  -2.46398926e-01],
                        [ -2.08679199e-01,  -2.08679199e-01],
                        [ -1.92626953e-01,  -1.92626953e-01],
                        [ -1.72271729e-01,  -1.72271729e-01],
                        [ -1.30737305e-01,  -1.30737305e-01],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.62689209e-01,   1.62689209e-01],
                        [  1.88415527e-01,   1.88415527e-01],
                        [  1.91162109e-01,   1.91162109e-01],
                        [  1.82586670e-01,   1.82586670e-01],
                        [  1.71752930e-01,   1.71752930e-01],
                        [  1.55853271e-01,   1.55853271e-01],
                        [  1.27899170e-01,   1.27899170e-01],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  6.42089844e-02,   6.42089844e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  8.63342285e-02,   8.63342285e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.31652832e-01,  -1.31652832e-01],
                        [ -1.31927490e-01,  -1.31927490e-01],
                        [ -1.17401123e-01,  -1.17401123e-01],
                        [ -9.71374512e-02,  -9.71374512e-02],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  1.22863770e-01,   1.22863770e-01],
                        [  1.78436279e-01,   1.78436279e-01],
                        [  2.24670410e-01,   2.24670410e-01],
                        [  2.38983154e-01,   2.38983154e-01],
                        [  2.04528809e-01,   2.04528809e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.31530762e-02,   1.31530762e-02],
                        [ -1.17279053e-01,  -1.17248535e-01],
                        [ -2.47436523e-01,  -2.47436523e-01],
                        [ -3.40301514e-01,  -3.40301514e-01],
                        [ -3.62854004e-01,  -3.62854004e-01],
                        [ -3.21319580e-01,  -3.21319580e-01],
                        [ -2.58178711e-01,  -2.58178711e-01],
                        [ -2.10693359e-01,  -2.10693359e-01],
                        [ -1.83807373e-01,  -1.83807373e-01],
                        [ -1.62628174e-01,  -1.62628174e-01],
                        [ -1.34124756e-01,  -1.34124756e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.71478271e-01,   1.71478271e-01],
                        [  1.79046631e-01,   1.79046631e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  1.69677734e-01,   1.69677734e-01],
                        [  1.54327393e-01,   1.54327393e-01],
                        [  1.32904053e-01,   1.32904053e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  6.24084473e-02,   6.24389648e-02],
                        [  7.62329102e-02,   7.62329102e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -1.08642578e-01,  -1.08642578e-01],
                        [ -1.23321533e-01,  -1.23321533e-01],
                        [ -1.16516113e-01,  -1.16516113e-01],
                        [ -9.70458984e-02,  -9.70458984e-02],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -7.41577148e-02,  -7.41577148e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  1.39709473e-01,   1.39709473e-01],
                        [  1.99829102e-01,   1.99829102e-01],
                        [  2.36267090e-01,   2.36267090e-01],
                        [  2.27752686e-01,   2.27752686e-01],
                        [  1.66503906e-01,   1.66503906e-01],
                        [  6.00280762e-02,   6.00280762e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -2.03186035e-01,  -2.03186035e-01],
                        [ -3.05816650e-01,  -3.05816650e-01],
                        [ -3.55072021e-01,  -3.55072021e-01],
                        [ -3.42132568e-01,  -3.42132568e-01],
                        [ -2.86102295e-01,  -2.86102295e-01],
                        [ -2.23999023e-01,  -2.23999023e-01],
                        [ -1.82678223e-01,  -1.82678223e-01],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -1.39953613e-01,  -1.39953613e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  8.02001953e-02,   8.02001953e-02],
                        [  1.34246826e-01,   1.34246826e-01],
                        [  1.71356201e-01,   1.71356201e-01],
                        [  1.87652588e-01,   1.87652588e-01],
                        [  1.89727783e-01,   1.89727783e-01],
                        [  1.85119629e-01,   1.85119629e-01],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  1.45080566e-01,   1.45080566e-01],
                        [  1.13281250e-01,   1.13281250e-01],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.55212402e-02,   6.55517578e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  3.02429199e-02,   3.02124023e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  8.08715820e-02,   8.08715820e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  6.64978027e-02,   6.64978027e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.47497559e-02,  -2.47192383e-02],
                        [ -2.48718262e-02,  -2.48413086e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -9.70458984e-03,  -9.67407227e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -7.47680664e-03,  -7.50732422e-03],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -7.17163086e-03,  -7.20214844e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -1.08428955e-01,  -1.08428955e-01],
                        [ -1.34368896e-01,  -1.34368896e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -9.76257324e-02,  -9.76257324e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -5.65490723e-02,  -5.65795898e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  1.82098389e-01,   1.82098389e-01],
                        [  2.15911865e-01,   2.15911865e-01],
                        [  2.15484619e-01,   2.15484619e-01],
                        [  1.71142578e-01,   1.71142578e-01],
                        [  8.16040039e-02,   8.16040039e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -1.79290771e-01,  -1.79290771e-01],
                        [ -2.90496826e-01,  -2.90496826e-01],
                        [ -3.45184326e-01,  -3.45184326e-01],
                        [ -3.35235596e-01,  -3.35235596e-01],
                        [ -2.83416748e-01,  -2.83416748e-01],
                        [ -2.27691650e-01,  -2.27691650e-01],
                        [ -1.93603516e-01,  -1.93603516e-01],
                        [ -1.78222656e-01,  -1.78222656e-01],
                        [ -1.59149170e-01,  -1.59149170e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.61804199e-01,   1.61804199e-01],
                        [  1.59729004e-01,   1.59729004e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.56066895e-01,   1.56066895e-01],
                        [  1.63604736e-01,   1.63604736e-01],
                        [  1.57135010e-01,   1.57135010e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  8.52966309e-02,   8.52966309e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  1.10778809e-02,   1.10473633e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.42822266e-02,   1.43127441e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.45666504e-02,   2.45361328e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -1.01837158e-01,  -1.01837158e-01],
                        [ -1.41174316e-01,  -1.41174316e-01],
                        [ -1.49230957e-01,  -1.49230957e-01],
                        [ -1.22894287e-01,  -1.22894287e-01],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.63269043e-01,   1.63299561e-01],
                        [  1.88079834e-01,   1.88079834e-01],
                        [  1.84936523e-01,   1.84936523e-01],
                        [  1.40747070e-01,   1.40777588e-01],
                        [  5.67016602e-02,   5.66711426e-02],
                        [ -5.56335449e-02,  -5.56640625e-02],
                        [ -1.79016113e-01,  -1.78985596e-01],
                        [ -2.85644531e-01,  -2.85644531e-01],
                        [ -3.40820312e-01,  -3.40850830e-01],
                        [ -3.26171875e-01,  -3.26171875e-01],
                        [ -2.62329102e-01,  -2.62329102e-01],
                        [ -1.98608398e-01,  -1.98608398e-01],
                        [ -1.69891357e-01,  -1.69921875e-01],
                        [ -1.66900635e-01,  -1.66870117e-01],
                        [ -1.54205322e-01,  -1.54205322e-01],
                        [ -1.09710693e-01,  -1.09710693e-01],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  1.06872559e-01,   1.06842041e-01],
                        [  1.48101807e-01,   1.48101807e-01],
                        [  1.60888672e-01,   1.60919189e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.53411865e-01,   1.53411865e-01],
                        [  1.54083252e-01,   1.54083252e-01],
                        [  1.50299072e-01,   1.50299072e-01],
                        [  1.32507324e-01,   1.32476807e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.50244141e-02,   2.50549316e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  6.20727539e-02,   6.20422363e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  4.64172363e-02,   4.64477539e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  1.41296387e-02,   1.41601562e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -1.36413574e-02,  -1.36108398e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.40380859e-02,  -1.40075684e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -5.00488281e-03,  -5.03540039e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  3.05175781e-05,   6.10351562e-05],
                        [ -7.93457031e-04,  -8.23974609e-04],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  6.40869141e-04,   6.71386719e-04],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -1.28173828e-03,  -1.31225586e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.69982910e-02,  -1.70288086e-02],
                        [ -3.10058594e-02,  -3.09753418e-02],
                        [ -3.97033691e-02,  -3.96728516e-02],
                        [ -4.12597656e-02,  -4.12902832e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -3.00903320e-02,  -3.01208496e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.80053711e-03,  -1.77001953e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  3.69873047e-02,   3.70178223e-02],
                        [  2.87170410e-02,   2.86865234e-02],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -3.77197266e-02,  -3.76892090e-02],
                        [ -8.26416016e-02,  -8.26721191e-02],
                        [ -1.19354248e-01,  -1.19354248e-01],
                        [ -1.34552002e-01,  -1.34521484e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -9.65270996e-02,  -9.65576172e-02],
                        [ -6.59179688e-02,  -6.58874512e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  4.13513184e-02,   4.13818359e-02],
                        [  9.22241211e-02,   9.22241211e-02],
                        [  1.45996094e-01,   1.45965576e-01],
                        [  1.87377930e-01,   1.87408447e-01],
                        [  2.05596924e-01,   2.05596924e-01],
                        [  1.89422607e-01,   1.89422607e-01],
                        [  1.25946045e-01,   1.25946045e-01],
                        [  1.36108398e-02,   1.36108398e-02],
                        [ -1.26892090e-01,  -1.26922607e-01],
                        [ -2.59552002e-01,  -2.59582520e-01],
                        [ -3.47930908e-01,  -3.47900391e-01],
                        [ -3.68835449e-01,  -3.68835449e-01],
                        [ -3.27056885e-01,  -3.27087402e-01],
                        [ -2.57385254e-01,  -2.57385254e-01],
                        [ -1.99890137e-01,  -1.99859619e-01],
                        [ -1.69708252e-01,  -1.69738770e-01],
                        [ -1.52130127e-01,  -1.52160645e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  1.35131836e-01,   1.35162354e-01],
                        [  1.57714844e-01,   1.57684326e-01],
                        [  1.58294678e-01,   1.58325195e-01],
                        [  1.53717041e-01,   1.53717041e-01],
                        [  1.52008057e-01,   1.52008057e-01],
                        [  1.48559570e-01,   1.48559570e-01],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.19140625e-01,   1.19140625e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.14135742e-02,   1.13830566e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  4.27551270e-02,   4.27246094e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  6.52465820e-02,   6.52770996e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  3.04565430e-02,   3.04260254e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  1.45568848e-02,   1.45874023e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -2.06909180e-02,  -2.06604004e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.58789062e-02,  -2.59094238e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.74047852e-02,  -2.73742676e-02],
                        [ -2.25219727e-02,  -2.25524902e-02],
                        [ -1.23901367e-02,  -1.24206543e-02],
                        [ -1.73950195e-03,  -1.70898438e-03],
                        [  5.76782227e-03,   5.73730469e-03],
                        [  1.07116699e-02,   1.06811523e-02],
                        [  1.72729492e-02,   1.73034668e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.40881348e-02,   3.40576172e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -7.53784180e-03,  -7.50732422e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -3.39965820e-02,  -3.40270996e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.60925293e-02,  -2.61230469e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  3.34472656e-02,   3.34167480e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -1.41296387e-01,  -1.41296387e-01],
                        [ -1.47308350e-01,  -1.47308350e-01],
                        [ -1.23260498e-01,  -1.23260498e-01],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  1.27380371e-01,   1.27380371e-01],
                        [  1.75262451e-01,   1.75262451e-01],
                        [  2.08557129e-01,   2.08587646e-01],
                        [  2.12554932e-01,   2.12554932e-01],
                        [  1.69860840e-01,   1.69860840e-01],
                        [  7.65075684e-02,   7.65380859e-02],
                        [ -5.09338379e-02,  -5.09033203e-02],
                        [ -1.86248779e-01,  -1.86248779e-01],
                        [ -3.01574707e-01,  -3.01544189e-01],
                        [ -3.69049072e-01,  -3.69049072e-01],
                        [ -3.72344971e-01,  -3.72344971e-01],
                        [ -3.21960449e-01,  -3.21960449e-01],
                        [ -2.52197266e-01,  -2.52197266e-01],
                        [ -1.95617676e-01,  -1.95617676e-01],
                        [ -1.59301758e-01,  -1.59301758e-01],
                        [ -1.25152588e-01,  -1.25152588e-01],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  1.28967285e-01,   1.28967285e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  1.40197754e-01,   1.40197754e-01],
                        [  1.46331787e-01,   1.46331787e-01],
                        [  1.50054932e-01,   1.50054932e-01],
                        [  1.44256592e-01,   1.44256592e-01],
                        [  1.28540039e-01,   1.28509521e-01],
                        [  1.11633301e-01,   1.11633301e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  7.22961426e-02,   7.22961426e-02],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  6.97631836e-02,   6.97631836e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.64794922e-03,   1.67846680e-03],
                        [ -2.31933594e-03,  -2.34985352e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  3.60107422e-03,   3.57055664e-03],
                        [  1.98364258e-03,   2.01416016e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.13623047e-02,   2.13928223e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.77001953e-02,   1.76696777e-02],
                        [  9.36889648e-03,   9.39941406e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -2.25830078e-03,  -2.28881836e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -6.34765625e-03,  -6.31713867e-03],
                        [ -9.55200195e-03,  -9.58251953e-03],
                        [ -1.65100098e-02,  -1.65405273e-02],
                        [ -2.34680176e-02,  -2.34375000e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.93884277e-02,  -2.94189453e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.49731445e-02,  -3.50036621e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.92761230e-02,  -3.93066406e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.33251953e-02,  -3.32946777e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  2.41699219e-02,   2.42004395e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -5.34973145e-02,  -5.35278320e-02],
                        [ -1.01196289e-01,  -1.01165771e-01],
                        [ -1.29150391e-01,  -1.29150391e-01],
                        [ -1.29211426e-01,  -1.29241943e-01],
                        [ -1.07086182e-01,  -1.07086182e-01],
                        [ -7.44628906e-02,  -7.44323730e-02],
                        [ -4.50439453e-02,  -4.50744629e-02],
                        [ -2.63366699e-02,  -2.63671875e-02],
                        [ -9.73510742e-03,  -9.70458984e-03],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  6.62536621e-02,   6.62231445e-02],
                        [  1.22406006e-01,   1.22436523e-01],
                        [  1.74743652e-01,   1.74774170e-01],
                        [  2.05108643e-01,   2.05047607e-01],
                        [  1.97174072e-01,   1.97204590e-01],
                        [  1.44653320e-01,   1.44714355e-01],
                        [  4.90112305e-02,   4.89807129e-02],
                        [ -8.03527832e-02,  -8.03833008e-02],
                        [ -2.18658447e-01,  -2.18597412e-01],
                        [ -3.29833984e-01,  -3.29833984e-01],
                        [ -3.84674072e-01,  -3.84704590e-01],
                        [ -3.75305176e-01,  -3.75274658e-01],
                        [ -3.20526123e-01,  -3.20526123e-01],
                        [ -2.55981445e-01,  -2.56011963e-01],
                        [ -2.07214355e-01,  -2.07214355e-01],
                        [ -1.70501709e-01,  -1.70471191e-01],
                        [ -1.24206543e-01,  -1.24206543e-01],
                        [ -5.52673340e-02,  -5.52978516e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  1.04736328e-01,   1.04766846e-01],
                        [  1.52557373e-01,   1.52526855e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.60614014e-01,   1.60644531e-01],
                        [  1.53686523e-01,   1.53656006e-01],
                        [  1.50360107e-01,   1.50329590e-01],
                        [  1.44592285e-01,   1.44622803e-01],
                        [  1.29730225e-01,   1.29699707e-01],
                        [  1.05804443e-01,   1.05773926e-01],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.70898438e-03,   1.67846680e-03],
                        [ -6.71386719e-04,  -7.01904297e-04],
                        [  1.01928711e-02,   1.02233887e-02],
                        [  2.99072266e-02,   2.99377441e-02],
                        [  5.04760742e-02,   5.04455566e-02],
                        [  6.76269531e-02,   6.76574707e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  9.20715332e-02,   9.20410156e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.50317383e-02,   9.50622559e-02],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  7.80334473e-02,   7.80029297e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  3.36303711e-02,   3.35998535e-02],
                        [  2.08129883e-02,   2.08435059e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -1.46484375e-02,  -1.46789551e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [  4.42504883e-03,   4.39453125e-03],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.57873535e-02,   2.57568359e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -2.10876465e-02,  -2.11181641e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -3.28063965e-02,  -3.28369141e-02],
                        [ -3.26843262e-02,  -3.27148438e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.12597656e-02,  -4.12902832e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.45666504e-02,  -2.45361328e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  1.28479004e-02,   1.28784180e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.26745605e-02,   2.27050781e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -9.07592773e-02,  -9.07592773e-02],
                        [ -1.33270264e-01,  -1.33270264e-01],
                        [ -1.45080566e-01,  -1.45111084e-01],
                        [ -1.21490479e-01,  -1.21490479e-01],
                        [ -7.49816895e-02,  -7.49511719e-02],
                        [ -2.83813477e-02,  -2.84118652e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  1.70288086e-02,   1.70593262e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.50543213e-01,   1.50543213e-01],
                        [  1.82403564e-01,   1.82373047e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  1.37115479e-01,   1.37115479e-01],
                        [  4.36096191e-02,   4.36096191e-02],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -2.19757080e-01,  -2.19757080e-01],
                        [ -3.26477051e-01,  -3.26477051e-01],
                        [ -3.76220703e-01,  -3.76220703e-01],
                        [ -3.61724854e-01,  -3.61694336e-01],
                        [ -3.03771973e-01,  -3.03771973e-01],
                        [ -2.39562988e-01,  -2.39562988e-01],
                        [ -1.94824219e-01,  -1.94824219e-01],
                        [ -1.64489746e-01,  -1.64489746e-01],
                        [ -1.24145508e-01,  -1.24176025e-01],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.29791260e-01,   1.29791260e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.34124756e-01,   1.34124756e-01],
                        [  1.35131836e-01,   1.35101318e-01],
                        [  1.40594482e-01,   1.40594482e-01],
                        [  1.38916016e-01,   1.38946533e-01],
                        [  1.23229980e-01,   1.23199463e-01],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  7.70263672e-02,   7.70568848e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  4.50744629e-02,   4.50439453e-02],
                        [  3.32031250e-02,   3.32336426e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.58483887e-02,   2.58789062e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  5.38940430e-02,   5.38635254e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  8.89282227e-02,   8.88977051e-02],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [ -2.38037109e-03,  -2.41088867e-03],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  6.74438477e-03,   6.77490234e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.01721191e-02,  -2.02026367e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -3.03955078e-02,  -3.03649902e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.29492188e-02,  -2.29187012e-02],
                        [ -1.33361816e-02,  -1.33666992e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [  8.30078125e-03,   8.33129883e-03],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [ -6.25610352e-03,  -6.22558594e-03],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -7.29675293e-02,  -7.29980469e-02],
                        [ -9.56726074e-02,  -9.56420898e-02],
                        [ -9.16137695e-02,  -9.15832520e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -1.73339844e-02,  -1.73034668e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  1.73645020e-02,   1.73339844e-02],
                        [  5.01708984e-02,   5.02014160e-02],
                        [  9.14916992e-02,   9.15222168e-02],
                        [  1.33697510e-01,   1.33666992e-01],
                        [  1.64306641e-01,   1.64276123e-01],
                        [  1.67663574e-01,   1.67663574e-01],
                        [  1.29211426e-01,   1.29211426e-01],
                        [  4.23889160e-02,   4.23889160e-02],
                        [ -8.21533203e-02,  -8.21533203e-02],
                        [ -2.14050293e-01,  -2.14050293e-01],
                        [ -3.14819336e-01,  -3.14819336e-01],
                        [ -3.57208252e-01,  -3.57238770e-01],
                        [ -3.38531494e-01,  -3.38531494e-01],
                        [ -2.80914307e-01,  -2.80914307e-01],
                        [ -2.17681885e-01,  -2.17712402e-01],
                        [ -1.70379639e-01,  -1.70379639e-01],
                        [ -1.35437012e-01,  -1.35437012e-01],
                        [ -9.50927734e-02,  -9.51232910e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  1.05133057e-01,   1.05163574e-01],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.32324219e-01,   1.32324219e-01],
                        [  1.33056641e-01,   1.33056641e-01],
                        [  1.22314453e-01,   1.22344971e-01],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  7.38220215e-02,   7.37915039e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.01306152e-02,   4.01000977e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  6.51245117e-02,   6.51245117e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  7.13500977e-02,   7.13195801e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  6.24084473e-02,   6.24389648e-02],
                        [  5.02014160e-02,   5.01708984e-02],
                        [  3.29284668e-02,   3.28979492e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -5.52368164e-03,  -5.55419922e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -8.17871094e-03,  -8.20922852e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  1.20239258e-02,   1.20544434e-02],
                        [  2.06909180e-02,   2.06604004e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  1.10778809e-02,   1.11083984e-02],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  2.68554688e-03,   2.65502930e-03],
                        [  1.27258301e-02,   1.27563477e-02],
                        [  2.74963379e-02,   2.75268555e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  1.53503418e-02,   1.53808594e-02],
                        [  5.70678711e-03,   5.73730469e-03],
                        [  3.57055664e-03,   3.54003906e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.22070312e-03,   1.25122070e-03],
                        [ -7.26318359e-03,  -7.29370117e-03],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -3.02429199e-02,  -3.02124023e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.77099609e-02,  -2.77404785e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -1.16882324e-02,  -1.16577148e-02],
                        [ -6.22558594e-03,  -6.25610352e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -2.80761719e-03,  -2.77709961e-03],
                        [ -7.32421875e-04,  -7.01904297e-04],
                        [ -3.38745117e-03,  -3.41796875e-03],
                        [ -1.47399902e-02,  -1.47094727e-02],
                        [ -3.10974121e-02,  -3.10668945e-02],
                        [ -4.73632812e-02,  -4.73937988e-02],
                        [ -6.00280762e-02,  -6.00585938e-02],
                        [ -6.38122559e-02,  -6.37817383e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -3.75366211e-02,  -3.75671387e-02],
                        [ -1.55639648e-02,  -1.55334473e-02],
                        [  6.07299805e-03,   6.10351562e-03],
                        [  2.06909180e-02,   2.06604004e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  1.57165527e-02,   1.57470703e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -4.20227051e-02,  -4.19921875e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -8.11767578e-03,  -8.14819336e-03],
                        [  1.11083984e-02,   1.10778809e-02],
                        [  3.07312012e-02,   3.07617188e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.56646729e-01,   1.56646729e-01],
                        [  1.44592285e-01,   1.44592285e-01],
                        [  8.52661133e-02,   8.52355957e-02],
                        [ -1.61437988e-02,  -1.61132812e-02],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -2.55859375e-01,  -2.55859375e-01],
                        [ -3.42010498e-01,  -3.42010498e-01],
                        [ -3.75732422e-01,  -3.75701904e-01],
                        [ -3.53637695e-01,  -3.53637695e-01],
                        [ -2.96752930e-01,  -2.96783447e-01],
                        [ -2.32696533e-01,  -2.32666016e-01],
                        [ -1.74530029e-01,  -1.74499512e-01],
                        [ -1.18835449e-01,  -1.18865967e-01],
                        [ -5.70373535e-02,  -5.70068359e-02],
                        [  1.21765137e-02,   1.22070312e-02],
                        [  7.65991211e-02,   7.65686035e-02],
                        [  1.19445801e-01,   1.19445801e-01],
                        [  1.33880615e-01,   1.33911133e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.13006592e-01,   1.12976074e-01],
                        [  1.08245850e-01,   1.08276367e-01],
                        [  1.14868164e-01,   1.14868164e-01],
                        [  1.20208740e-01,   1.20178223e-01],
                        [  1.15509033e-01,   1.15509033e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  2.82592773e-02,   2.82287598e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.38244629e-02,   1.38549805e-02],
                        [  2.15148926e-02,   2.14843750e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  4.94079590e-02,   4.94384766e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  7.26623535e-02,   7.26318359e-02],
                        [  8.03222656e-02,   8.03527832e-02],
                        [  8.40454102e-02,   8.40454102e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  7.06481934e-02,   7.06787109e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  4.17785645e-02,   4.17480469e-02],
                        [  2.74658203e-02,   2.74963379e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -8.23974609e-03,  -8.20922852e-03],
                        [ -5.00488281e-03,  -4.97436523e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  6.86645508e-03,   6.89697266e-03],
                        [  1.83105469e-03,   1.80053711e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -7.99560547e-03,  -7.96508789e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  2.61230469e-02,   2.60925293e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  4.97436523e-03,   5.00488281e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -1.11083984e-02,  -1.11389160e-02],
                        [ -2.54516602e-02,  -2.54211426e-02],
                        [ -3.54919434e-02,  -3.54614258e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.90417480e-02,  -4.90112305e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -5.30700684e-02,  -5.31005859e-02],
                        [ -5.29785156e-02,  -5.29479980e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -4.45251465e-02,  -4.45556641e-02],
                        [ -3.82080078e-02,  -3.81774902e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -5.37109375e-03,  -5.40161133e-03],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  3.26538086e-02,   3.26843262e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [ -2.75268555e-02,  -2.74963379e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -5.80749512e-02,  -5.80444336e-02],
                        [ -5.00793457e-02,  -5.00488281e-02],
                        [ -3.48815918e-02,  -3.49121094e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  4.78515625e-02,   4.78515625e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.61804199e-01,   1.61804199e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  8.05053711e-02,   8.05053711e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -1.50939941e-01,  -1.50939941e-01],
                        [ -2.79327393e-01,  -2.79327393e-01],
                        [ -3.66577148e-01,  -3.66577148e-01],
                        [ -3.89038086e-01,  -3.89038086e-01],
                        [ -3.51928711e-01,  -3.51959229e-01],
                        [ -2.81951904e-01,  -2.81951904e-01],
                        [ -2.10235596e-01,  -2.10205078e-01],
                        [ -1.54357910e-01,  -1.54388428e-01],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -5.09643555e-02,  -5.09338379e-02],
                        [  2.12707520e-02,   2.12402344e-02],
                        [  8.98437500e-02,   8.98132324e-02],
                        [  1.32141113e-01,   1.32141113e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.31866455e-01,   1.31835938e-01],
                        [  1.20300293e-01,   1.20300293e-01],
                        [  1.16790771e-01,   1.16821289e-01],
                        [  1.16424561e-01,   1.16394043e-01],
                        [  1.11755371e-01,   1.11724854e-01],
                        [  1.03057861e-01,   1.03088379e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  7.48291016e-02,   7.47985840e-02],
                        [  5.08117676e-02,   5.08422852e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  5.95092773e-03,   5.92041016e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -5.49316406e-03,  -5.46264648e-03],
                        [  1.27563477e-02,   1.27258301e-02],
                        [  3.97033691e-02,   3.96728516e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  8.78906250e-02,   8.78601074e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  8.25805664e-02,   8.26110840e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  6.05163574e-02,   6.05468750e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  9.21630859e-03,   9.18579102e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.74255371e-02,  -1.74560547e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.98364258e-02,   1.98669434e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.07116699e-02,   1.07421875e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.24206543e-02,   1.23901367e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.66320801e-02,   1.66015625e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  5.82885742e-03,   5.79833984e-03],
                        [ -1.19018555e-03,  -1.22070312e-03],
                        [ -1.01013184e-02,  -1.00708008e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -1.62963867e-02,  -1.63269043e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -4.21142578e-02,  -4.21447754e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.59191895e-02,  -3.58886719e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -6.89697266e-03,  -6.86645508e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  6.89697266e-03,   6.86645508e-03],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -6.34155273e-02,  -6.34460449e-02],
                        [ -7.80944824e-02,  -7.80944824e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.56829834e-01,   1.56860352e-01],
                        [  1.60095215e-01,   1.60095215e-01],
                        [  1.24298096e-01,   1.24267578e-01],
                        [  4.10766602e-02,   4.10766602e-02],
                        [ -8.28247070e-02,  -8.28247070e-02],
                        [ -2.20947266e-01,  -2.20947266e-01],
                        [ -3.33526611e-01,  -3.33526611e-01],
                        [ -3.86199951e-01,  -3.86199951e-01],
                        [ -3.70452881e-01,  -3.70483398e-01],
                        [ -3.08166504e-01,  -3.08166504e-01],
                        [ -2.35382080e-01,  -2.35382080e-01],
                        [ -1.75140381e-01,  -1.75140381e-01],
                        [ -1.22131348e-01,  -1.22131348e-01],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.18347168e-01,   1.18377686e-01],
                        [  1.05743408e-01,   1.05712891e-01],
                        [  9.44213867e-02,   9.43908691e-02],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  7.97729492e-02,   7.98034668e-02],
                        [  7.01599121e-02,   7.01904297e-02],
                        [  6.70471191e-02,   6.70166016e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  6.10656738e-02,   6.10961914e-02],
                        [  4.95605469e-02,   4.95300293e-02],
                        [  3.35083008e-02,   3.34777832e-02],
                        [  1.99279785e-02,   1.99584961e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.73645020e-02,   1.73339844e-02],
                        [  2.85949707e-02,   2.86254883e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  7.60192871e-02,   7.59887695e-02],
                        [  9.69848633e-02,   9.70153809e-02],
                        [  1.07757568e-01,   1.07788086e-01],
                        [  1.06933594e-01,   1.06903076e-01],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  8.18176270e-02,   8.18481445e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  5.28259277e-02,   5.27954102e-02],
                        [  3.50646973e-02,   3.50952148e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  4.45556641e-03,   4.42504883e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -6.65283203e-03,  -6.62231445e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -1.06201172e-02,  -1.05895996e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.89208984e-03,  -1.92260742e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -3.26538086e-03,  -3.23486328e-03],
                        [ -3.05175781e-04,  -3.35693359e-04],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.77001953e-02,   1.77307129e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  4.38842773e-02,   4.38537598e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  2.81066895e-02,   2.80761719e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -3.24401855e-02,  -3.24096680e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -6.43920898e-03,  -6.40869141e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -8.48388672e-03,  -8.45336914e-03],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -4.11682129e-02,  -4.11987305e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -3.99169922e-02,  -3.99475098e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.20635986e-01,   1.20666504e-01],
                        [  1.50115967e-01,   1.50115967e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  4.63562012e-02,   4.63562012e-02],
                        [ -7.39746094e-02,  -7.40051270e-02],
                        [ -2.11883545e-01,  -2.11883545e-01],
                        [ -3.25897217e-01,  -3.25897217e-01],
                        [ -3.78143311e-01,  -3.78143311e-01],
                        [ -3.59985352e-01,  -3.60015869e-01],
                        [ -2.96905518e-01,  -2.96905518e-01],
                        [ -2.26776123e-01,  -2.26776123e-01],
                        [ -1.71936035e-01,  -1.71936035e-01],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  1.05560303e-01,   1.05590820e-01],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.05224609e-01,   1.05224609e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  9.29260254e-02,   9.29260254e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  9.03625488e-02,   9.03320312e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.15783691e-01,   1.15814209e-01],
                        [  1.20422363e-01,   1.20391846e-01],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  9.46350098e-02,   9.46655273e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -2.94799805e-02,  -2.95104980e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -5.03845215e-02,  -5.03540039e-02],
                        [ -4.05273438e-02,  -4.05578613e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  8.30078125e-03,   8.27026367e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -9.15527344e-05,  -6.10351562e-05],
                        [  5.18798828e-03,   5.15747070e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.46887207e-02,   2.47192383e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  3.96728516e-02,   3.97033691e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.10668945e-02,   3.10363770e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  2.02941895e-02,   2.02636719e-02],
                        [  1.84020996e-02,   1.84326172e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -5.49316406e-03,  -5.52368164e-03],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -3.09448242e-02,  -3.09143066e-02],
                        [ -3.98559570e-02,  -3.98864746e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -7.82470703e-02,  -7.82470703e-02],
                        [ -7.66906738e-02,  -7.66906738e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.53472900e-01,   1.53472900e-01],
                        [  1.75781250e-01,   1.75750732e-01],
                        [  1.75598145e-01,   1.75598145e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  4.91027832e-02,   4.91027832e-02],
                        [ -8.88671875e-02,  -8.88671875e-02],
                        [ -2.49481201e-01,  -2.49481201e-01],
                        [ -3.84765625e-01,  -3.84765625e-01],
                        [ -4.50744629e-01,  -4.50744629e-01],
                        [ -4.34448242e-01,  -4.34448242e-01],
                        [ -3.60015869e-01,  -3.60015869e-01],
                        [ -2.70935059e-01,  -2.70965576e-01],
                        [ -1.98425293e-01,  -1.98425293e-01],
                        [ -1.40563965e-01,  -1.40563965e-01],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  6.82983398e-02,   6.82678223e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [ -2.09350586e-02,  -2.09655762e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -2.98156738e-02,  -2.97851562e-02],
                        [ -4.51660156e-03,  -4.54711914e-03],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  5.41076660e-02,   5.41381836e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  1.13250732e-01,   1.13281250e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  8.66699219e-02,   8.67004395e-02],
                        [  6.91528320e-02,   6.91528320e-02],
                        [  5.09643555e-02,   5.09338379e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  1.68762207e-02,   1.69067383e-02],
                        [ -2.83813477e-03,  -2.86865234e-03],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.60009766e-02,  -2.59704590e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  4.09851074e-02,   4.09545898e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -7.07092285e-02,  -7.06787109e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -7.10449219e-02,  -7.10144043e-02],
                        [ -7.75146484e-02,  -7.75146484e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -3.08532715e-02,  -3.08227539e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  1.48193359e-01,   1.48193359e-01],
                        [  1.70654297e-01,   1.70654297e-01],
                        [  1.71386719e-01,   1.71386719e-01],
                        [  1.36932373e-01,   1.36962891e-01],
                        [  5.16052246e-02,   5.16052246e-02],
                        [ -8.51745605e-02,  -8.51745605e-02],
                        [ -2.40844727e-01,  -2.40814209e-01],
                        [ -3.62823486e-01,  -3.62823486e-01],
                        [ -4.13940430e-01,  -4.13940430e-01],
                        [ -3.91265869e-01,  -3.91265869e-01],
                        [ -3.20953369e-01,  -3.20922852e-01],
                        [ -2.40417480e-01,  -2.40417480e-01],
                        [ -1.74377441e-01,  -1.74377441e-01],
                        [ -1.20666504e-01,  -1.20666504e-01],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  4.88586426e-02,   4.88281250e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  7.97424316e-02,   7.97119141e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  7.60803223e-02,   7.61108398e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  5.34057617e-02,   5.33752441e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.52587891e-04,   1.22070312e-04],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  7.47680664e-03,   7.50732422e-03],
                        [  1.28173828e-02,   1.27868652e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.43017578e-02,  -3.42712402e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.53186035e-02,  -4.53491211e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  5.00183105e-02,   4.99877930e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -4.73022461e-02,  -4.73327637e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -2.64892578e-02,  -2.64587402e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -2.30590820e-01,  -2.30590820e-01],
                        [ -3.29956055e-01,  -3.29925537e-01],
                        [ -3.71917725e-01,  -3.71917725e-01],
                        [ -3.49456787e-01,  -3.49456787e-01],
                        [ -2.84667969e-01,  -2.84667969e-01],
                        [ -2.10632324e-01,  -2.10632324e-01],
                        [ -1.47705078e-01,  -1.47705078e-01],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [  3.14941406e-02,   3.15246582e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  7.39440918e-02,   7.39440918e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  5.80749512e-02,   5.81054688e-02],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  7.82775879e-02,   7.82775879e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  1.70288086e-02,   1.70593262e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  1.03393555e-01,   1.03363037e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  2.97851562e-02,   2.98156738e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  1.02539062e-02,   1.02233887e-02],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  1.52587891e-04,   1.52587891e-04],
                        [ -2.41088867e-03,  -2.44140625e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -2.86865234e-02,  -2.86560059e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  1.23748779e-01,   1.23748779e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.38916016e-01,   1.38885498e-01],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -1.13372803e-01,  -1.13372803e-01],
                        [ -2.41241455e-01,  -2.41241455e-01],
                        [ -3.35754395e-01,  -3.35754395e-01],
                        [ -3.65081787e-01,  -3.65081787e-01],
                        [ -3.31146240e-01,  -3.31176758e-01],
                        [ -2.64770508e-01,  -2.64770508e-01],
                        [ -2.00531006e-01,  -2.00531006e-01],
                        [ -1.54052734e-01,  -1.54052734e-01],
                        [ -1.16973877e-01,  -1.16973877e-01],
                        [ -7.21130371e-02,  -7.21130371e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.13281250e-01,   1.13311768e-01],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.08154297e-01,   1.08154297e-01],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  6.97631836e-02,   6.97631836e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  7.02819824e-02,   7.02514648e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.47290039e-02,   3.46984863e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.57165527e-02,   1.56860352e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -1.43127441e-02,  -1.43432617e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  1.09497070e-01,   1.09497070e-01],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -1.53045654e-01,  -1.53045654e-01],
                        [ -2.41668701e-01,  -2.41668701e-01],
                        [ -2.91076660e-01,  -2.91076660e-01],
                        [ -2.89489746e-01,  -2.89489746e-01],
                        [ -2.51281738e-01,  -2.51281738e-01],
                        [ -2.05749512e-01,  -2.05749512e-01],
                        [ -1.72302246e-01,  -1.72302246e-01],
                        [ -1.46240234e-01,  -1.46240234e-01],
                        [ -1.08886719e-01,  -1.08886719e-01],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  5.96008301e-02,   5.96313477e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.52478027e-02,   3.52172852e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.25817871e-02,   5.25817871e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.78039551e-01,   1.78039551e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  1.34796143e-01,   1.34796143e-01],
                        [  5.33142090e-02,   5.33142090e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -1.84387207e-01,  -1.84387207e-01],
                        [ -2.86071777e-01,  -2.86071777e-01],
                        [ -3.41125488e-01,  -3.41125488e-01],
                        [ -3.43322754e-01,  -3.43322754e-01],
                        [ -3.09448242e-01,  -3.09448242e-01],
                        [ -2.65899658e-01,  -2.65899658e-01],
                        [ -2.25830078e-01,  -2.25830078e-01],
                        [ -1.82739258e-01,  -1.82739258e-01],
                        [ -1.25762939e-01,  -1.25762939e-01],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  8.43505859e-02,   8.43505859e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.10717773e-01,   1.10717773e-01],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -7.58056641e-02,  -7.58056641e-02],
                        [ -8.62121582e-02,  -8.62121582e-02],
                        [ -8.67919922e-02,  -8.67919922e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -8.61206055e-02,  -8.61206055e-02],
                        [ -8.85620117e-02,  -8.85620117e-02],
                        [ -7.65380859e-02,  -7.65380859e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  7.09228516e-02,   7.09228516e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.82666016e-02,   9.82666016e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -1.96868896e-01,  -1.96868896e-01],
                        [ -2.87200928e-01,  -2.87200928e-01],
                        [ -3.39996338e-01,  -3.39996338e-01],
                        [ -3.43383789e-01,  -3.43383789e-01],
                        [ -3.05938721e-01,  -3.05938721e-01],
                        [ -2.50885010e-01,  -2.50885010e-01],
                        [ -1.98822021e-01,  -1.98822021e-01],
                        [ -1.53808594e-01,  -1.53808594e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  8.37402344e-02,   8.37402344e-02],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  9.19799805e-02,   9.19799805e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  5.80749512e-02,   5.80444336e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [ -2.99072266e-03,  -2.96020508e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  3.83605957e-02,   3.83300781e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  5.33447266e-02,   5.33752441e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -1.47094727e-01,  -1.47094727e-01],
                        [ -2.42309570e-01,  -2.42309570e-01],
                        [ -3.01025391e-01,  -3.01025391e-01],
                        [ -3.12042236e-01,  -3.12042236e-01],
                        [ -2.84423828e-01,  -2.84423828e-01],
                        [ -2.40661621e-01,  -2.40661621e-01],
                        [ -2.00744629e-01,  -2.00714111e-01],
                        [ -1.69525146e-01,  -1.69525146e-01],
                        [ -1.37542725e-01,  -1.37542725e-01],
                        [ -9.19494629e-02,  -9.19494629e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  2.60925293e-02,   2.61230469e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  8.03833008e-02,   8.03833008e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.60620117e-02,   2.60314941e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.09545898e-02,  -4.09851074e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.73950195e-03,   1.70898438e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -1.14440918e-02,  -1.14135742e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -4.00085449e-02,  -3.99780273e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  7.45544434e-02,   7.45544434e-02],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  1.47125244e-01,   1.47125244e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.82373047e-01,   1.82373047e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.60827637e-02,   1.60827637e-02],
                        [ -1.12091064e-01,  -1.12091064e-01],
                        [ -2.41455078e-01,  -2.41455078e-01],
                        [ -3.38745117e-01,  -3.38745117e-01],
                        [ -3.79821777e-01,  -3.79852295e-01],
                        [ -3.62030029e-01,  -3.62030029e-01],
                        [ -3.09051514e-01,  -3.09051514e-01],
                        [ -2.53784180e-01,  -2.53784180e-01],
                        [ -2.11181641e-01,  -2.11181641e-01],
                        [ -1.71417236e-01,  -1.71417236e-01],
                        [ -1.17706299e-01,  -1.17706299e-01],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.14349365e-01,   1.14318848e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.48620605e-02,   1.48925781e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.42211914e-02,   1.41906738e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.53503418e-02,   1.53198242e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  4.46472168e-02,   4.46472168e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.67639160e-02,  -2.67333984e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -3.86657715e-02,  -3.86352539e-02],
                        [ -3.82385254e-02,  -3.82690430e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  1.60522461e-02,   1.60827637e-02],
                        [  2.71301270e-02,   2.70996094e-02],
                        [  2.24609375e-02,   2.24914551e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.40673828e-02,  -4.40979004e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  7.62939453e-04,   7.93457031e-04],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  6.90307617e-02,   6.90307617e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  8.52355957e-02,   8.52050781e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -1.57165527e-01,  -1.57165527e-01],
                        [ -2.39746094e-01,  -2.39746094e-01],
                        [ -2.86560059e-01,  -2.86560059e-01],
                        [ -2.92053223e-01,  -2.92053223e-01],
                        [ -2.67639160e-01,  -2.67639160e-01],
                        [ -2.32910156e-01,  -2.32910156e-01],
                        [ -2.03857422e-01,  -2.03857422e-01],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -1.58355713e-01,  -1.58355713e-01],
                        [ -1.16210938e-01,  -1.16210938e-01],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  6.80847168e-02,   6.81152344e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.34429932e-01,   1.34460449e-01],
                        [  1.44470215e-01,   1.44470215e-01],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  1.23229980e-01,   1.23229980e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  4.90417480e-02,   4.90722656e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.17492676e-02,  -1.17187500e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.63562012e-02,   4.63562012e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -7.53784180e-03,  -7.50732422e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.93273926e-02,   2.93579102e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.01708984e-02,  -5.02014160e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -4.79125977e-03,  -4.76074219e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.38854980e-02,   1.38549805e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.23504639e-01,   1.23504639e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  7.87963867e-02,   7.87658691e-02],
                        [  1.25122070e-03,   1.28173828e-03],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -2.30224609e-01,  -2.30255127e-01],
                        [ -3.18389893e-01,  -3.18389893e-01],
                        [ -3.52661133e-01,  -3.52661133e-01],
                        [ -3.36425781e-01,  -3.36456299e-01],
                        [ -2.92266846e-01,  -2.92266846e-01],
                        [ -2.44781494e-01,  -2.44750977e-01],
                        [ -2.04681396e-01,  -2.04681396e-01],
                        [ -1.66259766e-01,  -1.66259766e-01],
                        [ -1.18927002e-01,  -1.18927002e-01],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.39892578e-01,   1.39862061e-01],
                        [  1.47125244e-01,   1.47125244e-01],
                        [  1.49627686e-01,   1.49658203e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.30493164e-01,   1.30462646e-01],
                        [  1.08489990e-01,   1.08520508e-01],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  2.34375000e-02,   2.34680176e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  8.02307129e-02,   8.02307129e-02],
                        [  6.77490234e-02,   6.77795410e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  3.32946777e-02,   3.32641602e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  3.20434570e-03,   3.20434570e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.75781250e-02,  -1.75476074e-02],
                        [ -1.50756836e-02,  -1.51062012e-02],
                        [ -1.29394531e-02,  -1.29699707e-02],
                        [ -1.19018555e-02,  -1.18713379e-02],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.08129883e-02,   2.08435059e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  9.67407227e-03,   9.64355469e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -4.36401367e-03,  -4.33349609e-03],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -1.54724121e-02,  -1.55029297e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -1.30004883e-02,  -1.29699707e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -4.22973633e-02,  -4.22668457e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -5.15136719e-02,  -5.15441895e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -7.26318359e-03,  -7.23266602e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -6.13403320e-03,  -6.10351562e-03],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  4.43115234e-02,   4.42810059e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.99475098e-02,   3.99169922e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  6.04248047e-02,   6.04553223e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  8.55407715e-02,   8.55102539e-02],
                        [  9.31701660e-02,   9.31701660e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  9.55810547e-02,   9.55505371e-02],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -1.36077881e-01,  -1.36077881e-01],
                        [ -2.36541748e-01,  -2.36541748e-01],
                        [ -3.04656982e-01,  -3.04656982e-01],
                        [ -3.24676514e-01,  -3.24676514e-01],
                        [ -3.04534912e-01,  -3.04534912e-01],
                        [ -2.68005371e-01,  -2.68005371e-01],
                        [ -2.35717773e-01,  -2.35717773e-01],
                        [ -2.09167480e-01,  -2.09167480e-01],
                        [ -1.72607422e-01,  -1.72607422e-01],
                        [ -1.12823486e-01,  -1.12823486e-01],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  1.12213135e-01,   1.12213135e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  7.28454590e-02,   7.28759766e-02],
                        [  5.87463379e-02,   5.87768555e-02],
                        [  5.41687012e-02,   5.41381836e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.34777832e-02,   3.34472656e-02],
                        [  2.17590332e-02,   2.17285156e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  2.68249512e-02,   2.68554688e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.29589844e-02,   3.29895020e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  5.61523438e-02,   5.61218262e-02],
                        [  4.90112305e-02,   4.90417480e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  4.69970703e-03,   4.66918945e-03],
                        [ -1.65710449e-02,  -1.65405273e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.89306641e-02,  -2.89611816e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.24511719e-02,  -1.24206543e-02],
                        [ -1.34277344e-03,  -1.37329102e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.02233887e-02,   1.02539062e-02],
                        [  4.66918945e-03,   4.63867188e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -1.15966797e-02,  -1.15661621e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.29187012e-02,  -2.28881836e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.35083008e-02,   3.34777832e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.08947754e-02,   1.09252930e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.55639648e-03,  -1.52587891e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.69372559e-02,   1.69067383e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  6.24389648e-02,   6.24694824e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.46240234e-01,   1.46240234e-01],
                        [  1.43981934e-01,   1.43981934e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  4.81872559e-02,   4.81872559e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -1.78497314e-01,  -1.78497314e-01],
                        [ -2.72949219e-01,  -2.72949219e-01],
                        [ -3.18237305e-01,  -3.18237305e-01],
                        [ -3.12286377e-01,  -3.12286377e-01],
                        [ -2.74566650e-01,  -2.74536133e-01],
                        [ -2.32666016e-01,  -2.32635498e-01],
                        [ -2.00775146e-01,  -2.00805664e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.35009766e-01,  -1.35009766e-01],
                        [ -8.40148926e-02,  -8.40454102e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [  2.40783691e-02,   2.41088867e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  8.64868164e-02,   8.64868164e-02],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.51342773e-02,   7.51342773e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.78417969e-02,   3.78112793e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.79541016e-02,   2.79235840e-02],
                        [  3.19213867e-02,   3.19519043e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.54919434e-02,   3.54614258e-02],
                        [  3.56445312e-02,   3.56750488e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  1.96228027e-02,   1.95922852e-02],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -1.89208984e-02,  -1.88903809e-02],
                        [ -1.86767578e-02,  -1.87072754e-02],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -1.12915039e-02,  -1.13220215e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.66320801e-02,  -1.66015625e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  5.76782227e-03,   5.79833984e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.28271484e-02,   2.27966309e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.79125977e-02,   4.79431152e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.80969238e-02,   1.81274414e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [ -1.04064941e-02,  -1.03759766e-02],
                        [ -1.90734863e-02,  -1.91040039e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.85852051e-02,  -1.85546875e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.20642090e-02,  -2.20947266e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  2.92968750e-03,   2.89916992e-03],
                        [ -5.79833984e-03,  -5.82885742e-03],
                        [ -1.45568848e-02,  -1.45263672e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -2.96020508e-02,  -2.96325684e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -4.70581055e-02,  -4.70275879e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.10461426e-02,  -4.10156250e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -6.10351562e-03,  -6.07299805e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  1.07116699e-02,   1.06811523e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  8.08715820e-03,   8.05664062e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.84521484e-02,   3.84216309e-02],
                        [  4.21752930e-02,   4.22058105e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  6.92138672e-02,   6.92138672e-02],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  1.34735107e-01,   1.34735107e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  2.74658203e-04,   3.05175781e-04],
                        [ -1.10412598e-01,  -1.10412598e-01],
                        [ -2.25219727e-01,  -2.25219727e-01],
                        [ -3.12744141e-01,  -3.12744141e-01],
                        [ -3.50433350e-01,  -3.50433350e-01],
                        [ -3.35418701e-01,  -3.35418701e-01],
                        [ -2.84637451e-01,  -2.84606934e-01],
                        [ -2.23602295e-01,  -2.23602295e-01],
                        [ -1.72119141e-01,  -1.72149658e-01],
                        [ -1.33453369e-01,  -1.33453369e-01],
                        [ -9.40856934e-02,  -9.40551758e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.00372314e-01,   1.00372314e-01],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  7.45239258e-02,   7.45544434e-02],
                        [  6.82373047e-02,   6.82067871e-02],
                        [  6.92749023e-02,   6.92749023e-02],
                        [  7.14416504e-02,   7.14721680e-02],
                        [  7.04650879e-02,   7.04345703e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  4.06799316e-02,   4.06494141e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  8.92944336e-02,   8.92944336e-02],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.42919922e-02,  -2.43225098e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  4.01306152e-02,   4.01000977e-02],
                        [  4.81262207e-02,   4.80957031e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  6.20422363e-02,   6.20422363e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  6.89697266e-03,   6.86645508e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.09558105e-02,  -1.09252930e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [ -9.73510742e-03,  -9.76562500e-03],
                        [ -1.13830566e-02,  -1.14135742e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.96118164e-02,  -3.96423340e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  8.42285156e-03,   8.39233398e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [ -1.00708008e-03,  -9.76562500e-04],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -6.07299805e-03,  -6.10351562e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  2.49023438e-02,   2.49328613e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  8.29772949e-02,   8.30078125e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -2.86132812e-01,  -2.86132812e-01],
                        [ -3.39782715e-01,  -3.39782715e-01],
                        [ -3.32153320e-01,  -3.32153320e-01],
                        [ -2.83386230e-01,  -2.83386230e-01],
                        [ -2.29492188e-01,  -2.29492188e-01],
                        [ -1.93298340e-01,  -1.93298340e-01],
                        [ -1.69769287e-01,  -1.69769287e-01],
                        [ -1.38854980e-01,  -1.38854980e-01],
                        [ -8.85009766e-02,  -8.85009766e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.04339600e-01,   1.04370117e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  1.30218506e-01,   1.30249023e-01],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.20635986e-01,   1.20605469e-01],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  8.35571289e-02,   8.35876465e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  1.07727051e-02,   1.07421875e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  1.19018555e-03,   1.22070312e-03],
                        [  1.11694336e-02,   1.11389160e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  4.42504883e-02,   4.42810059e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  6.25305176e-02,   6.25000000e-02],
                        [  5.88378906e-02,   5.88684082e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  2.55126953e-02,   2.54821777e-02],
                        [  8.88061523e-03,   8.91113281e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  4.47387695e-02,   4.47692871e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.40478516e-02,   2.40173340e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  1.65710449e-02,   1.66015625e-02],
                        [  1.32751465e-02,   1.32446289e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.15966797e-03,   1.19018555e-03],
                        [ -7.75146484e-03,  -7.78198242e-03],
                        [ -1.71203613e-02,  -1.71508789e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -3.96118164e-02,  -3.95812988e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -2.99072266e-03,  -3.02124023e-03],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.85241699e-02,  -1.84936523e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -1.55944824e-02,  -1.55639648e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -9.15527344e-04,  -8.85009766e-04],
                        [  3.26538086e-03,   3.23486328e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  5.49316406e-03,   5.52368164e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  4.97436523e-03,   5.00488281e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  3.58276367e-02,   3.57971191e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  9.01489258e-02,   9.01794434e-02],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.55090332e-01,   1.55090332e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  3.38439941e-02,   3.38439941e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -1.79046631e-01,  -1.79046631e-01],
                        [ -2.79113770e-01,  -2.79113770e-01],
                        [ -3.37341309e-01,  -3.37341309e-01],
                        [ -3.40332031e-01,  -3.40332031e-01],
                        [ -3.02062988e-01,  -3.02062988e-01],
                        [ -2.51037598e-01,  -2.51037598e-01],
                        [ -2.07092285e-01,  -2.07122803e-01],
                        [ -1.71478271e-01,  -1.71478271e-01],
                        [ -1.31835938e-01,  -1.31835938e-01],
                        [ -7.74230957e-02,  -7.74230957e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  1.02935791e-01,   1.02966309e-01],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  3.02124023e-02,   3.01818848e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  6.90917969e-02,   6.90917969e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.62243652e-02,   3.62548828e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  4.20532227e-02,   4.20227051e-02],
                        [  4.69360352e-02,   4.69055176e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.22766113e-02,   5.22460938e-02],
                        [  5.61218262e-02,   5.61523438e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.25830078e-03,   2.22778320e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -5.43212891e-03,  -5.40161133e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.15148926e-02,  -2.15454102e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -2.74658203e-04,  -2.44140625e-04],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  1.09832764e-01,   1.09832764e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -1.46789551e-01,  -1.46789551e-01],
                        [ -2.43804932e-01,  -2.43835449e-01],
                        [ -3.06976318e-01,  -3.06945801e-01],
                        [ -3.16833496e-01,  -3.16833496e-01],
                        [ -2.83142090e-01,  -2.83142090e-01],
                        [ -2.40631104e-01,  -2.40631104e-01],
                        [ -2.14477539e-01,  -2.14477539e-01],
                        [ -1.96014404e-01,  -1.96044922e-01],
                        [ -1.61102295e-01,  -1.61102295e-01],
                        [ -1.01562500e-01,  -1.01562500e-01],
                        [ -2.94189453e-02,  -2.94494629e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  7.82470703e-02,   7.82775879e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  8.88061523e-02,   8.88061523e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  5.93566895e-02,   5.93566895e-02],
                        [  4.73937988e-02,   4.73632812e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  2.83508301e-02,   2.83813477e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  5.08117676e-02,   5.07812500e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.23693848e-02,   2.23999023e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.72119141e-02,   1.71813965e-02],
                        [  1.99890137e-02,   2.00195312e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  1.40075684e-02,   1.39770508e-02],
                        [  5.82885742e-03,   5.82885742e-03],
                        [ -3.75366211e-03,  -3.72314453e-03],
                        [ -1.16271973e-02,  -1.16577148e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -3.19519043e-02,  -3.19213867e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.62133789e-02,  -5.62438965e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  8.97216797e-03,   9.00268555e-03],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  3.28979492e-02,   3.28674316e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  5.20324707e-02,   5.20629883e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  6.80847168e-02,   6.80847168e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  8.34960938e-02,   8.35266113e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -1.63940430e-01,  -1.63909912e-01],
                        [ -2.55310059e-01,  -2.55340576e-01],
                        [ -3.12622070e-01,  -3.12652588e-01],
                        [ -3.21502686e-01,  -3.21472168e-01],
                        [ -2.89398193e-01,  -2.89398193e-01],
                        [ -2.39685059e-01,  -2.39715576e-01],
                        [ -1.96502686e-01,  -1.96502686e-01],
                        [ -1.67144775e-01,  -1.67144775e-01],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -9.45129395e-02,  -9.45129395e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  9.36584473e-02,   9.36584473e-02],
                        [  1.10107422e-01,   1.10107422e-01],
                        [  1.17218018e-01,   1.17187500e-01],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  9.66186523e-02,   9.66186523e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.34680176e-02,   2.34375000e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  1.19934082e-02,   1.19628906e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.36181641e-02,   8.35876465e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.12402344e-02,  -2.12707520e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -3.03039551e-02,  -3.02734375e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.06396484e-02,  -3.06091309e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  3.93981934e-02,   3.93676758e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  2.33154297e-02,   2.32849121e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -1.91040039e-02,  -1.90734863e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.35595703e-02,   2.35290527e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  3.05175781e-04,   3.35693359e-04],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -2.89916992e-03,  -2.86865234e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  4.78515625e-02,   4.78820801e-02],
                        [  6.30493164e-02,   6.30493164e-02],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  1.13708496e-01,   1.13739014e-01],
                        [  1.33117676e-01,   1.33087158e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  6.28662109e-02,   6.28662109e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.41082764e-01,  -1.41082764e-01],
                        [ -2.47253418e-01,  -2.47253418e-01],
                        [ -3.13659668e-01,  -3.13659668e-01],
                        [ -3.22143555e-01,  -3.22113037e-01],
                        [ -2.80242920e-01,  -2.80273438e-01],
                        [ -2.22259521e-01,  -2.22259521e-01],
                        [ -1.86401367e-01,  -1.86370850e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.80664062e-01,  -1.80664062e-01],
                        [ -1.56921387e-01,  -1.56890869e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -3.84521484e-02,  -3.84826660e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  1.16027832e-01,   1.16027832e-01],
                        [  1.30950928e-01,   1.30950928e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  1.08856201e-01,   1.08856201e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  9.20715332e-02,   9.20715332e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  3.34472656e-02,   3.34167480e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.94189453e-02,   2.93884277e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.23376465e-02,   5.23071289e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.99987793e-02,  -2.99682617e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -4.63562012e-02,  -4.63256836e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.53601074e-02,   2.53295898e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.28674316e-02,   3.28979492e-02],
                        [  2.95410156e-02,   2.95104980e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.32238770e-02,   2.31933594e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  1.58996582e-02,   1.59301758e-02],
                        [  1.49536133e-02,   1.49230957e-02],
                        [  1.86767578e-02,   1.86462402e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.11181641e-02,   2.10876465e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  2.62451172e-03,   2.65502930e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -2.93884277e-02,  -2.93579102e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.15551758e-02,  -3.15856934e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -3.60107422e-02,  -3.59802246e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.10363770e-02,  -3.10058594e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.98669434e-02,  -1.98974609e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -8.51440430e-03,  -8.48388672e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -6.10351562e-04,  -5.79833984e-04],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  9.68627930e-02,   9.68933105e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -1.43798828e-01,  -1.43798828e-01],
                        [ -2.48443604e-01,  -2.48443604e-01],
                        [ -3.17840576e-01,  -3.17840576e-01],
                        [ -3.26751709e-01,  -3.26751709e-01],
                        [ -2.84637451e-01,  -2.84637451e-01],
                        [ -2.27325439e-01,  -2.27325439e-01],
                        [ -1.85272217e-01,  -1.85272217e-01],
                        [ -1.63391113e-01,  -1.63391113e-01],
                        [ -1.48223877e-01,  -1.48223877e-01],
                        [ -1.24664307e-01,  -1.24664307e-01],
                        [ -8.52355957e-02,  -8.52355957e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  6.17370605e-02,   6.17065430e-02],
                        [  9.61914062e-02,   9.61914062e-02],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.33331299e-01,   1.33331299e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.23596191e-01,   1.23596191e-01],
                        [  1.15051270e-01,   1.15051270e-01],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  5.95703125e-02,   5.95397949e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  4.60815430e-02,   4.61120605e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  4.93774414e-02,   4.94079590e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.28576660e-02,  -2.28271484e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.26647949e-02,  -1.26953125e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.08032227e-02,  -1.07727051e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.42517090e-02,  -1.42211914e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -4.30297852e-03,  -4.33349609e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  3.87878418e-02,   3.88183594e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  4.44335938e-02,   4.44030762e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  3.32336426e-02,   3.32641602e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  3.07312012e-02,   3.07006836e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -9.58251953e-03,  -9.55200195e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.23999023e-02,  -2.24304199e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.42004395e-02,  -2.41699219e-02],
                        [ -2.65808105e-02,  -2.66113281e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.02844238e-02,  -1.02539062e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.40380859e-02,  -1.40075684e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  7.81250000e-03,   7.78198242e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  1.75781250e-02,   1.75476074e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.39068604e-01,   1.39099121e-01],
                        [  1.18225098e-01,   1.18225098e-01],
                        [  6.84814453e-02,   6.84509277e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.18682861e-01,  -1.18682861e-01],
                        [ -2.28302002e-01,  -2.28302002e-01],
                        [ -3.07159424e-01,  -3.07159424e-01],
                        [ -3.27880859e-01,  -3.27850342e-01],
                        [ -2.93457031e-01,  -2.93457031e-01],
                        [ -2.37945557e-01,  -2.37945557e-01],
                        [ -1.97845459e-01,  -1.97875977e-01],
                        [ -1.83471680e-01,  -1.83441162e-01],
                        [ -1.77154541e-01,  -1.77154541e-01],
                        [ -1.55639648e-01,  -1.55670166e-01],
                        [ -1.11785889e-01,  -1.11755371e-01],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  1.10961914e-01,   1.10992432e-01],
                        [  1.41662598e-01,   1.41632080e-01],
                        [  1.50970459e-01,   1.50939941e-01],
                        [  1.42974854e-01,   1.42974854e-01],
                        [  1.26831055e-01,   1.26800537e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.85021973e-02,   5.85327148e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -2.08435059e-02,  -2.08740234e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -2.01110840e-02,  -2.01416016e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.57263184e-02,  -2.56958008e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  4.42504883e-03,   4.45556641e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  2.31933594e-02,   2.32238770e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  3.87268066e-02,   3.86962891e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  3.98864746e-02,   3.99169922e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.72314453e-02,   3.72619629e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -4.88281250e-03,  -4.85229492e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.74755859e-02,  -3.75061035e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.42407227e-02,  -3.42102051e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.40478516e-02,  -2.40783691e-02],
                        [ -1.89819336e-02,  -1.89514160e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -5.73730469e-03,  -5.70678711e-03],
                        [ -8.27026367e-03,  -8.30078125e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.34277344e-02,  -1.33972168e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -7.47680664e-03,  -7.44628906e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.95922852e-02,  -1.95617676e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  8.54492188e-04,   8.23974609e-04],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  8.81958008e-03,   8.85009766e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  7.17163086e-03,   7.14111328e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  1.17248535e-01,   1.17248535e-01],
                        [  1.43005371e-01,   1.43005371e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  6.80236816e-02,   6.80236816e-02],
                        [ -2.62756348e-02,  -2.63061523e-02],
                        [ -1.43280029e-01,  -1.43249512e-01],
                        [ -2.54089355e-01,  -2.54089355e-01],
                        [ -3.25378418e-01,  -3.25378418e-01],
                        [ -3.39599609e-01,  -3.39599609e-01],
                        [ -3.04931641e-01,  -3.04931641e-01],
                        [ -2.48382568e-01,  -2.48382568e-01],
                        [ -1.99768066e-01,  -1.99768066e-01],
                        [ -1.72393799e-01,  -1.72363281e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.26159668e-01,  -1.26159668e-01],
                        [ -8.32214355e-02,  -8.32214355e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  9.58251953e-02,   9.58557129e-02],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.28112793e-01,   1.28082275e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.18255615e-01,   1.18225098e-01],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  7.63549805e-02,   7.63244629e-02],
                        [  7.06787109e-02,   7.06481934e-02],
                        [  7.93151855e-02,   7.93457031e-02],
                        [  8.79821777e-02,   8.79821777e-02],
                        [  8.30078125e-02,   8.29772949e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  1.39770508e-02,   1.39465332e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.02941895e-02,  -2.03247070e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -2.07519531e-03,  -2.10571289e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -1.92565918e-02,  -1.92260742e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -1.70593262e-02,  -1.70288086e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  3.16467285e-02,   3.16772461e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  3.66516113e-02,   3.66210938e-02],
                        [  2.32543945e-02,   2.32849121e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -2.12402344e-02,  -2.12097168e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.94494629e-02,  -2.94799805e-02],
                        [ -2.88391113e-02,  -2.88085938e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.29284668e-02,  -3.28979492e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -1.95922852e-02,  -1.95617676e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -1.41601562e-02,  -1.41906738e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -9.46044922e-04,  -9.15527344e-04],
                        [  1.80053711e-03,   1.77001953e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -1.06811523e-03,  -1.03759766e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.08337402e-02,   1.08642578e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.67639160e-02,   2.67333984e-02],
                        [  5.08728027e-02,   5.09033203e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.52587891e-01,   1.52618408e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.26953125e-01,   1.26953125e-01],
                        [  6.32934570e-02,   6.32934570e-02],
                        [ -3.53698730e-02,  -3.53393555e-02],
                        [ -1.54296875e-01,  -1.54296875e-01],
                        [ -2.62634277e-01,  -2.62664795e-01],
                        [ -3.26751709e-01,  -3.26751709e-01],
                        [ -3.30474854e-01,  -3.30474854e-01],
                        [ -2.86376953e-01,  -2.86407471e-01],
                        [ -2.28820801e-01,  -2.28820801e-01],
                        [ -1.89910889e-01,  -1.89880371e-01],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -1.70227051e-01,  -1.70257568e-01],
                        [ -1.52343750e-01,  -1.52313232e-01],
                        [ -1.16699219e-01,  -1.16699219e-01],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  4.87365723e-02,   4.87670898e-02],
                        [  1.05468750e-01,   1.05438232e-01],
                        [  1.46331787e-01,   1.46301270e-01],
                        [  1.61254883e-01,   1.61285400e-01],
                        [  1.55456543e-01,   1.55456543e-01],
                        [  1.43432617e-01,   1.43402100e-01],
                        [  1.31225586e-01,   1.31256104e-01],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  1.03820801e-01,   1.03790283e-01],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  9.75952148e-02,   9.76257324e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  9.24682617e-02,   9.24377441e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -5.33142090e-02,  -5.33447266e-02],
                        [ -3.48510742e-02,  -3.48815918e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [  3.54003906e-03,   3.57055664e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  9.21630859e-03,   9.18579102e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.01416016e-02,   2.01721191e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  2.26745605e-02,   2.26440430e-02],
                        [  3.07006836e-02,   3.06701660e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  4.28771973e-02,   4.28466797e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  3.37219238e-02,   3.37524414e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  4.34570312e-02,   4.34875488e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  3.81469727e-02,   3.81164551e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.78527832e-02,   1.78833008e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.70690918e-02,  -2.70996094e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.09045410e-02,  -2.09350586e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.28271484e-02,  -2.27966309e-02],
                        [ -2.38037109e-02,  -2.38342285e-02],
                        [ -2.43835449e-02,  -2.44140625e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.81579590e-02,  -1.81884766e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.75476074e-02,  -1.75781250e-02],
                        [ -1.49230957e-02,  -1.49536133e-02],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  1.55639648e-03,   1.52587891e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -6.10351562e-05,  -3.05175781e-05],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  1.25122070e-03,   1.28173828e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  6.53076172e-03,   6.50024414e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.33361816e-02,   1.33056641e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  3.25012207e-02,   3.25317383e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  6.77490234e-02,   6.77185059e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.24176025e-01,   1.24176025e-01],
                        [  9.98840332e-02,   9.98840332e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -1.39739990e-01,  -1.39739990e-01],
                        [ -2.39410400e-01,  -2.39410400e-01],
                        [ -3.06518555e-01,  -3.06518555e-01],
                        [ -3.19274902e-01,  -3.19274902e-01],
                        [ -2.83996582e-01,  -2.83966064e-01],
                        [ -2.34069824e-01,  -2.34069824e-01],
                        [ -1.99951172e-01,  -1.99951172e-01],
                        [ -1.83502197e-01,  -1.83471680e-01],
                        [ -1.66839600e-01,  -1.66839600e-01],
                        [ -1.38000488e-01,  -1.38000488e-01],
                        [ -9.92736816e-02,  -9.92736816e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.43798828e-01,   1.43829346e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.32537842e-01,   1.32537842e-01],
                        [  1.28265381e-01,   1.28234863e-01],
                        [  1.22680664e-01,   1.22711182e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  9.04235840e-02,   9.03930664e-02],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -9.73510742e-03,  -9.76562500e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  3.50952148e-03,   3.47900391e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.83105469e-02,   1.83410645e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  5.06896973e-02,   5.06896973e-02],
                        [  4.59899902e-02,   4.60205078e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  2.87780762e-02,   2.87475586e-02],
                        [  2.49633789e-02,   2.49938965e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.41394043e-02,   2.41088867e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  2.46582031e-02,   2.46887207e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.78320312e-02,   2.78625488e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.81066895e-02,  -2.80761719e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.26135254e-02,  -2.25830078e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -2.06604004e-02,  -2.06298828e-02],
                        [ -1.70898438e-02,  -1.70593262e-02],
                        [ -1.15051270e-02,  -1.15356445e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  7.72094727e-03,   7.69042969e-03],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  5.46264648e-03,   5.43212891e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -1.39770508e-02,  -1.39465332e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -6.92749023e-03,  -6.89697266e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  8.81958008e-03,   8.85009766e-03],
                        [  1.23291016e-02,   1.23596191e-02],
                        [  1.38244629e-02,   1.37939453e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  8.27941895e-02,   8.28247070e-02],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  1.34979248e-01,   1.35009766e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  4.35180664e-02,   4.34875488e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -1.54785156e-01,  -1.54785156e-01],
                        [ -2.50976562e-01,  -2.51007080e-01],
                        [ -3.09600830e-01,  -3.09631348e-01],
                        [ -3.13415527e-01,  -3.13415527e-01],
                        [ -2.71881104e-01,  -2.71881104e-01],
                        [ -2.17590332e-01,  -2.17620850e-01],
                        [ -1.80603027e-01,  -1.80603027e-01],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -1.59576416e-01,  -1.59576416e-01],
                        [ -1.46789551e-01,  -1.46789551e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -8.97827148e-02,  -8.97827148e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  1.42883301e-01,   1.42913818e-01],
                        [  1.80511475e-01,   1.80511475e-01],
                        [  1.90063477e-01,   1.90063477e-01],
                        [  1.79534912e-01,   1.79565430e-01],
                        [  1.62139893e-01,   1.62139893e-01],
                        [  1.47094727e-01,   1.47094727e-01],
                        [  1.36199951e-01,   1.36230469e-01],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  1.08612061e-01,   1.08612061e-01],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  2.31018066e-02,   2.30712891e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  4.18090820e-02,   4.18395996e-02],
                        [  2.67028809e-02,   2.66723633e-02],
                        [  2.14233398e-02,   2.13928223e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  4.94689941e-02,   4.94384766e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.34777832e-02,   3.35083008e-02],
                        [  2.43530273e-02,   2.43225098e-02],
                        [  1.57165527e-02,   1.56860352e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -1.16271973e-02,  -1.15966797e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.15246582e-02,  -3.14941406e-02],
                        [ -2.42309570e-02,  -2.42614746e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.34069824e-02,  -2.34375000e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -2.09960938e-02,  -2.10266113e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -2.12707520e-02,  -2.13012695e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -8.48388672e-03,  -8.45336914e-03],
                        [ -6.92749023e-03,  -6.95800781e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -9.67407227e-03,  -9.70458984e-03],
                        [ -1.11694336e-02,  -1.11389160e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  6.53076172e-03,   6.50024414e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -1.12915039e-03,  -1.09863281e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  5.69763184e-02,   5.69458008e-02],
                        [  7.55920410e-02,   7.56225586e-02],
                        [  1.02569580e-01,   1.02569580e-01],
                        [  1.28692627e-01,   1.28662109e-01],
                        [  1.37145996e-01,   1.37145996e-01],
                        [  1.13189697e-01,   1.13220215e-01],
                        [  5.12390137e-02,   5.12084961e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -1.55761719e-01,  -1.55761719e-01],
                        [ -2.57629395e-01,  -2.57629395e-01],
                        [ -3.17260742e-01,  -3.17291260e-01],
                        [ -3.16955566e-01,  -3.16955566e-01],
                        [ -2.69073486e-01,  -2.69073486e-01],
                        [ -2.08557129e-01,  -2.08557129e-01],
                        [ -1.66870117e-01,  -1.66900635e-01],
                        [ -1.51947021e-01,  -1.51916504e-01],
                        [ -1.49261475e-01,  -1.49230957e-01],
                        [ -1.40594482e-01,  -1.40625000e-01],
                        [ -1.19720459e-01,  -1.19720459e-01],
                        [ -8.94775391e-02,  -8.94470215e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  6.84509277e-02,   6.84814453e-02],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.68640137e-01,   1.68640137e-01],
                        [  1.85119629e-01,   1.85119629e-01],
                        [  1.84143066e-01,   1.84173584e-01],
                        [  1.74621582e-01,   1.74621582e-01],
                        [  1.62231445e-01,   1.62231445e-01],
                        [  1.46026611e-01,   1.46057129e-01],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -3.52172852e-02,  -3.52478027e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.52062988e-02,  -5.51757812e-02],
                        [ -3.76586914e-02,  -3.76892090e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.83813477e-03,  -2.80761719e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -4.79125977e-03,  -4.82177734e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  9.58251953e-03,   9.55200195e-03],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  3.74755859e-02,   3.75061035e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  6.25305176e-02,   6.25000000e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  2.20336914e-02,   2.20642090e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.05688477e-02,   2.05383301e-02],
                        [  2.49938965e-02,   2.50244141e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  2.91748047e-02,   2.91442871e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.59802246e-02,   3.60107422e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  3.29895020e-02,   3.29589844e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  3.76586914e-02,   3.76892090e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -4.63867188e-03,  -4.66918945e-03],
                        [ -5.21850586e-03,  -5.18798828e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -3.32031250e-02,  -3.32336426e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -5.28564453e-02,  -5.28259277e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -3.35083008e-02,  -3.35388184e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.96838379e-02,  -1.96533203e-02],
                        [ -1.41296387e-02,  -1.41601562e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -3.32641602e-03,  -3.35693359e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.33361816e-02,  -1.33666992e-02],
                        [ -6.95800781e-03,  -6.92749023e-03],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -2.16674805e-02,  -2.16369629e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.56555176e-02,  -1.56250000e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.34887695e-02,   1.35192871e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.67236328e-02,   1.66931152e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  5.08728027e-02,   5.08422852e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.34033203e-01,   1.34033203e-01],
                        [  1.36535645e-01,   1.36535645e-01],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  4.66918945e-02,   4.66613770e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -1.51519775e-01,  -1.51519775e-01],
                        [ -2.57110596e-01,  -2.57110596e-01],
                        [ -3.25958252e-01,  -3.25988770e-01],
                        [ -3.34259033e-01,  -3.34259033e-01],
                        [ -2.89154053e-01,  -2.89154053e-01],
                        [ -2.22625732e-01,  -2.22625732e-01],
                        [ -1.66595459e-01,  -1.66595459e-01],
                        [ -1.35192871e-01,  -1.35162354e-01],
                        [ -1.22985840e-01,  -1.22985840e-01],
                        [ -1.14685059e-01,  -1.14685059e-01],
                        [ -1.00067139e-01,  -1.00036621e-01],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -5.46264648e-02,  -5.46569824e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [  3.97338867e-02,   3.97644043e-02],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  1.66625977e-01,   1.66625977e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  1.98516846e-01,   1.98486328e-01],
                        [  1.84631348e-01,   1.84631348e-01],
                        [  1.68853760e-01,   1.68853760e-01],
                        [  1.49871826e-01,   1.49871826e-01],
                        [  1.18774414e-01,   1.18774414e-01],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -4.99877930e-02,  -4.99572754e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -2.71911621e-02,  -2.71606445e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  4.36096191e-02,   4.36401367e-02],
                        [  4.86450195e-02,   4.86145020e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  1.14746094e-02,   1.14440918e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.44958496e-02,   1.45263672e-02],
                        [  1.55639648e-02,   1.55334473e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  4.96215820e-02,   4.95910645e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [ -9.15527344e-05,  -6.10351562e-05],
                        [ -1.18713379e-02,  -1.19018555e-02],
                        [ -2.02941895e-02,  -2.02941895e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.63671875e-02,  -2.63977051e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.57153320e-02,  -4.57458496e-02],
                        [ -3.42407227e-02,  -3.42102051e-02],
                        [ -1.90124512e-02,  -1.89819336e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.97143555e-02,  -1.96838379e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.56555176e-02,  -1.56250000e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -2.89916992e-03,  -2.92968750e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -2.02941895e-02,  -2.03247070e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -5.64575195e-03,  -5.61523438e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.98669434e-02,  -1.98364258e-02],
                        [ -2.42004395e-02,  -2.42309570e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.74255371e-02,  -1.73950195e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.73742676e-02,   2.73437500e-02],
                        [  4.02526855e-02,   4.02221680e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  1.34582520e-01,   1.34582520e-01],
                        [  1.28967285e-01,   1.28967285e-01],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -1.57104492e-01,  -1.57073975e-01],
                        [ -2.53387451e-01,  -2.53387451e-01],
                        [ -3.10638428e-01,  -3.10638428e-01],
                        [ -3.11828613e-01,  -3.11828613e-01],
                        [ -2.67700195e-01,  -2.67700195e-01],
                        [ -2.08343506e-01,  -2.08343506e-01],
                        [ -1.63085938e-01,  -1.63085938e-01],
                        [ -1.43280029e-01,  -1.43280029e-01],
                        [ -1.38519287e-01,  -1.38519287e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.14257812e-01,  -1.14257812e-01],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.84020996e-01,   1.84020996e-01],
                        [  2.12768555e-01,   2.12768555e-01],
                        [  2.11059570e-01,   2.11059570e-01],
                        [  1.90826416e-01,   1.90826416e-01],
                        [  1.66625977e-01,   1.66656494e-01],
                        [  1.40045166e-01,   1.40014648e-01],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -4.07104492e-02,  -4.07409668e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.23083496e-02,  -2.22778320e-02],
                        [ -2.14843750e-02,  -2.15148926e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  3.30810547e-02,   3.30505371e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  5.31616211e-02,   5.31921387e-02],
                        [  5.88684082e-02,   5.88378906e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -4.02832031e-03,  -4.05883789e-03],
                        [ -5.31005859e-03,  -5.27954102e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  2.20031738e-02,   2.19726562e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  4.04357910e-02,   4.04663086e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.76379395e-02,   4.76684570e-02],
                        [  4.05883789e-02,   4.05578613e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.55529785e-02,   3.55834961e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  3.20434570e-03,   3.23486328e-03],
                        [ -6.40869141e-03,  -6.43920898e-03],
                        [ -1.45874023e-02,  -1.46179199e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.54614258e-02,  -3.54919434e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.23083496e-02,  -2.23388672e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -3.05175781e-04,  -2.74658203e-04],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.41601562e-02,  -1.41906738e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  1.09954834e-01,   1.09924316e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.34582520e-01,   1.34613037e-01],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  5.03234863e-02,   5.03234863e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -1.51855469e-01,  -1.51855469e-01],
                        [ -2.45697021e-01,  -2.45697021e-01],
                        [ -3.00201416e-01,  -3.00201416e-01],
                        [ -3.01483154e-01,  -3.01483154e-01],
                        [ -2.57965088e-01,  -2.57965088e-01],
                        [ -2.00317383e-01,  -2.00317383e-01],
                        [ -1.60736084e-01,  -1.60736084e-01],
                        [ -1.47399902e-01,  -1.47399902e-01],
                        [ -1.43798828e-01,  -1.43798828e-01],
                        [ -1.32965088e-01,  -1.32965088e-01],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [  3.27148438e-02,   3.26843262e-02],
                        [  1.10656738e-01,   1.10626221e-01],
                        [  1.83593750e-01,   1.83624268e-01],
                        [  2.27478027e-01,   2.27478027e-01],
                        [  2.30529785e-01,   2.30529785e-01],
                        [  2.01995850e-01,   2.01995850e-01],
                        [  1.60797119e-01,   1.60827637e-01],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -1.52587891e-02,  -1.52893066e-02],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -3.38745117e-03,  -3.35693359e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  5.43212891e-03,   5.46264648e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  5.20019531e-02,   5.19714355e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  5.20324707e-02,   5.20629883e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  2.83508301e-02,   2.83203125e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.44042969e-02,   1.44348145e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  3.18603516e-02,   3.18908691e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.60717773e-02,  -3.60412598e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.13928223e-02,  -2.13623047e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -1.51672363e-02,  -1.51977539e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.26647949e-02,  -1.26342773e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -8.75854492e-03,  -8.72802734e-03],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  4.78515625e-02,   4.78515625e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  1.39251709e-01,   1.39251709e-01],
                        [  1.42150879e-01,   1.42150879e-01],
                        [  1.15692139e-01,   1.15692139e-01],
                        [  5.50231934e-02,   5.50231934e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -1.31622314e-01,  -1.31622314e-01],
                        [ -2.24456787e-01,  -2.24456787e-01],
                        [ -2.84545898e-01,  -2.84545898e-01],
                        [ -2.90710449e-01,  -2.90710449e-01],
                        [ -2.49176025e-01,  -2.49145508e-01],
                        [ -1.94091797e-01,  -1.94091797e-01],
                        [ -1.58660889e-01,  -1.58660889e-01],
                        [ -1.50634766e-01,  -1.50604248e-01],
                        [ -1.56036377e-01,  -1.56036377e-01],
                        [ -1.58416748e-01,  -1.58416748e-01],
                        [ -1.50115967e-01,  -1.50085449e-01],
                        [ -1.29211426e-01,  -1.29211426e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.71661377e-01,   1.71661377e-01],
                        [  2.20001221e-01,   2.20001221e-01],
                        [  2.37518311e-01,   2.37518311e-01],
                        [  2.21954346e-01,   2.21954346e-01],
                        [  1.77612305e-01,   1.77612305e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  4.13818359e-02,   4.13818359e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.04309082e-01,   1.04309082e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  7.93151855e-02,   7.93151855e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  2.85644531e-02,   2.85339355e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.74353027e-02,   2.74658203e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.13720703e-02,   3.13415527e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  4.24194336e-02,   4.24499512e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  3.26232910e-02,   3.26538086e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.86560059e-02,   2.86254883e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.78625488e-02,  -2.78320312e-02],
                        [ -3.06396484e-02,  -3.06701660e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.26135254e-02,  -2.25830078e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.55944824e-02,  -1.56250000e-02],
                        [ -1.20239258e-02,  -1.19934082e-02],
                        [ -1.40991211e-02,  -1.40686035e-02],
                        [ -2.45361328e-02,  -2.45666504e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -1.82495117e-02,  -1.82800293e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.72119141e-02,  -1.71813965e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  3.03649902e-02,   3.03344727e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  6.86950684e-02,   6.86950684e-02],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.32843018e-01,   1.32812500e-01],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  5.88684082e-02,   5.88684082e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -2.23632812e-01,  -2.23602295e-01],
                        [ -2.90008545e-01,  -2.90008545e-01],
                        [ -2.99377441e-01,  -2.99377441e-01],
                        [ -2.56256104e-01,  -2.56256104e-01],
                        [ -1.95800781e-01,  -1.95800781e-01],
                        [ -1.52252197e-01,  -1.52252197e-01],
                        [ -1.33575439e-01,  -1.33575439e-01],
                        [ -1.28356934e-01,  -1.28356934e-01],
                        [ -1.24572754e-01,  -1.24572754e-01],
                        [ -1.17248535e-01,  -1.17248535e-01],
                        [ -1.05163574e-01,  -1.05133057e-01],
                        [ -8.43200684e-02,  -8.43200684e-02],
                        [ -4.58679199e-02,  -4.58984375e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  9.29565430e-02,   9.29870605e-02],
                        [  1.65466309e-01,   1.65466309e-01],
                        [  2.13531494e-01,   2.13531494e-01],
                        [  2.25616455e-01,   2.25646973e-01],
                        [  1.99645996e-01,   1.99645996e-01],
                        [  1.42639160e-01,   1.42608643e-01],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  4.91333008e-03,   4.94384766e-03],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  1.00097656e-02,   9.97924805e-03],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  4.37316895e-02,   4.37622070e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  9.66491699e-02,   9.66796875e-02],
                        [  8.71276855e-02,   8.71276855e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.36816406e-02,   2.36511230e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.92358398e-02,   2.92663574e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.51367188e-02,  -1.51672363e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.74145508e-02,  -3.73840332e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.27355957e-02,  -2.27050781e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.82592773e-02,  -2.82897949e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.88598633e-02,  -1.88293457e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -2.46582031e-02,  -2.46887207e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -2.38342285e-02,  -2.38037109e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.71911621e-02,  -2.72216797e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -1.40380859e-02,  -1.40075684e-02],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  2.17895508e-02,   2.17590332e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  5.62744141e-02,   5.62438965e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  8.67004395e-02,   8.67309570e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -1.58203125e-01,  -1.58203125e-01],
                        [ -2.50061035e-01,  -2.50061035e-01],
                        [ -3.03985596e-01,  -3.03985596e-01],
                        [ -2.99011230e-01,  -2.99011230e-01],
                        [ -2.44812012e-01,  -2.44812012e-01],
                        [ -1.79016113e-01,  -1.79016113e-01],
                        [ -1.36169434e-01,  -1.36169434e-01],
                        [ -1.22131348e-01,  -1.22131348e-01],
                        [ -1.20849609e-01,  -1.20849609e-01],
                        [ -1.16973877e-01,  -1.16973877e-01],
                        [ -1.06933594e-01,  -1.06933594e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -7.94982910e-02,  -7.94982910e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  1.49780273e-01,   1.49780273e-01],
                        [  2.13684082e-01,   2.13684082e-01],
                        [  2.30133057e-01,   2.30133057e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  2.94189453e-02,   2.94189453e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  3.58581543e-02,   3.58276367e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  6.90002441e-02,   6.90002441e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.25219727e-02,   2.25524902e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  2.87170410e-02,   2.86865234e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.26440430e-02,   2.26745605e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  3.21350098e-02,   3.21044922e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  2.36206055e-02,   2.36511230e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  2.82592773e-02,   2.82897949e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  9.39941406e-03,   9.42993164e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  3.41796875e-03,   3.44848633e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  9.61303711e-03,   9.58251953e-03],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.93164062e-02,   4.92858887e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.17156982e-01,   1.17126465e-01],
                        [  1.20330811e-01,   1.20361328e-01],
                        [  1.01623535e-01,   1.01623535e-01],
                        [  5.10864258e-02,   5.10559082e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -1.37908936e-01,  -1.37908936e-01],
                        [ -2.39379883e-01,  -2.39379883e-01],
                        [ -3.02978516e-01,  -3.02978516e-01],
                        [ -3.03802490e-01,  -3.03802490e-01],
                        [ -2.48535156e-01,  -2.48535156e-01],
                        [ -1.75903320e-01,  -1.75903320e-01],
                        [ -1.26007080e-01,  -1.26007080e-01],
                        [ -1.08917236e-01,  -1.08917236e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -1.03210449e-01,  -1.03210449e-01],
                        [ -9.30786133e-02,  -9.30786133e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -4.47998047e-02,  -4.48303223e-02],
                        [ -9.76562500e-03,  -9.73510742e-03],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  1.06597900e-01,   1.06567383e-01],
                        [  1.58050537e-01,   1.58050537e-01],
                        [  1.73217773e-01,   1.73248291e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  8.44421387e-02,   8.44116211e-02],
                        [  2.40478516e-02,   2.40783691e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  5.03845215e-02,   5.03540039e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  2.21862793e-02,   2.22167969e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -4.36401367e-03,  -4.39453125e-03],
                        [  3.84521484e-03,   3.87573242e-03],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  4.57763672e-02,   4.57458496e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.03515625e-01,   1.03485107e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  7.68432617e-02,   7.68737793e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  3.57666016e-02,   3.57971191e-02],
                        [  2.15454102e-02,   2.15148926e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.91345215e-02,   1.91040039e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.00500488e-02,   2.00805664e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  1.40380859e-02,   1.40075684e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -2.12402344e-02,  -2.12097168e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -1.86462402e-02,  -1.86767578e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -1.14440918e-02,  -1.14746094e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -1.98059082e-02,  -1.98364258e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.65100098e-02,  -1.64794922e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  3.63159180e-03,   3.66210938e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  4.98352051e-02,   4.98046875e-02],
                        [  7.27233887e-02,   7.27233887e-02],
                        [  9.74731445e-02,   9.75036621e-02],
                        [  1.20269775e-01,   1.20239258e-01],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.35711670e-01,   1.35711670e-01],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  5.50842285e-02,   5.50842285e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -1.24053955e-01,  -1.24084473e-01],
                        [ -2.21740723e-01,  -2.21740723e-01],
                        [ -2.87445068e-01,  -2.87414551e-01],
                        [ -2.94952393e-01,  -2.94952393e-01],
                        [ -2.48474121e-01,  -2.48474121e-01],
                        [ -1.84600830e-01,  -1.84600830e-01],
                        [ -1.39709473e-01,  -1.39709473e-01],
                        [ -1.21398926e-01,  -1.21398926e-01],
                        [ -1.16180420e-01,  -1.16149902e-01],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -1.02691650e-01,  -1.02691650e-01],
                        [ -8.64868164e-02,  -8.64868164e-02],
                        [ -6.38732910e-02,  -6.38427734e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  9.14916992e-02,   9.14916992e-02],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  7.74536133e-02,   7.74536133e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  2.82287598e-02,   2.81982422e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.57263184e-02,   2.56958008e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  8.79821777e-02,   8.80126953e-02],
                        [  9.93347168e-02,   9.93347168e-02],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  7.52868652e-02,   7.52868652e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  2.89611816e-02,   2.89306641e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  4.97436523e-03,   4.94384766e-03],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  2.31323242e-02,   2.31628418e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  2.31323242e-02,   2.31018066e-02],
                        [  2.18811035e-02,   2.19116211e-02],
                        [  2.39868164e-02,   2.40173340e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -5.85937500e-03,  -5.82885742e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -9.15527344e-04,  -9.46044922e-04],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.03747559e-02,  -4.03442383e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -4.05578613e-02,  -4.05883789e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.12402344e-02,  -2.12707520e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -2.70690918e-02,  -2.70385742e-02],
                        [ -3.33862305e-02,  -3.34167480e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -1.57165527e-02,  -1.56860352e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -4.88281250e-03,  -4.85229492e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.51367188e-02,   1.51062012e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  7.20214844e-02,   7.20520020e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.07910156e-01,   1.07879639e-01],
                        [  5.97839355e-02,   5.97839355e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.22863770e-01,  -1.22894287e-01],
                        [ -2.20581055e-01,  -2.20581055e-01],
                        [ -2.81005859e-01,  -2.81005859e-01],
                        [ -2.87292480e-01,  -2.87292480e-01],
                        [ -2.46643066e-01,  -2.46673584e-01],
                        [ -1.86584473e-01,  -1.86553955e-01],
                        [ -1.38153076e-01,  -1.38153076e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -1.01776123e-01,  -1.01776123e-01],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -7.44628906e-02,  -7.44628906e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -5.30395508e-02,  -5.30090332e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  5.17578125e-02,   5.17272949e-02],
                        [  6.69860840e-02,   6.69860840e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  2.70996094e-02,   2.71301270e-02],
                        [  2.60620117e-02,   2.60314941e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  3.87573242e-02,   3.87878418e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  6.24389648e-02,   6.24084473e-02],
                        [  8.20922852e-02,   8.20922852e-02],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  1.11938477e-01,   1.11938477e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.29260254e-02,   9.29565430e-02],
                        [  6.85729980e-02,   6.85424805e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  3.43322754e-02,   3.43627930e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  3.31726074e-02,   3.31420898e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  3.86047363e-02,   3.86352539e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.66821289e-02,   3.66516113e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  3.85437012e-02,   3.85742188e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.84020996e-02,  -1.84326172e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.78112793e-02,  -3.78417969e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  2.29797363e-02,   2.30102539e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  9.48791504e-02,   9.48791504e-02],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -1.41143799e-01,  -1.41143799e-01],
                        [ -2.27569580e-01,  -2.27600098e-01],
                        [ -2.77893066e-01,  -2.77923584e-01],
                        [ -2.76000977e-01,  -2.76000977e-01],
                        [ -2.29064941e-01,  -2.29064941e-01],
                        [ -1.69677734e-01,  -1.69677734e-01],
                        [ -1.30676270e-01,  -1.30676270e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  7.77587891e-02,   7.77282715e-02],
                        [  9.72595215e-02,   9.72595215e-02],
                        [  9.32312012e-02,   9.32312012e-02],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  4.03137207e-02,   4.03442383e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  3.47595215e-02,   3.47290039e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  5.06896973e-02,   5.06896973e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  4.30297852e-02,   4.29992676e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  2.72827148e-02,   2.72521973e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.69372559e-02,   1.69677734e-02],
                        [  2.33154297e-02,   2.32849121e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.07421875e-02,   1.07727051e-02],
                        [  9.24682617e-03,   9.21630859e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  6.56127930e-03,   6.59179688e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  3.17382812e-03,   3.14331055e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.48718262e-02,  -2.49023438e-02],
                        [ -2.74658203e-02,  -2.74353027e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.76892090e-02,  -3.77197266e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.90222168e-02,  -2.90527344e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.30615234e-02,  -1.30310059e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  2.55432129e-02,   2.55737305e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.15551758e-02,   3.15856934e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  9.32617188e-02,   9.32922363e-02],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.21398926e-01,   1.21368408e-01],
                        [  9.30480957e-02,   9.30786133e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [ -3.27453613e-02,  -3.27758789e-02],
                        [ -1.23291016e-01,  -1.23291016e-01],
                        [ -2.16308594e-01,  -2.16308594e-01],
                        [ -2.80517578e-01,  -2.80517578e-01],
                        [ -2.85034180e-01,  -2.85034180e-01],
                        [ -2.31719971e-01,  -2.31719971e-01],
                        [ -1.57775879e-01,  -1.57775879e-01],
                        [ -1.02142334e-01,  -1.02172852e-01],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -7.03735352e-02,  -7.03430176e-02],
                        [ -6.44226074e-02,  -6.44531250e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -4.29992676e-02,  -4.29687500e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -1.04034424e-01,  -1.04003906e-01],
                        [ -1.11663818e-01,  -1.11694336e-01],
                        [ -9.50927734e-02,  -9.51232910e-02],
                        [ -4.95910645e-02,  -4.95605469e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  7.13500977e-02,   7.13195801e-02],
                        [  1.02294922e-01,   1.02294922e-01],
                        [  1.02722168e-01,   1.02752686e-01],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  6.94580078e-02,   6.94580078e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.11816406e-01,   1.11785889e-01],
                        [  9.62829590e-02,   9.62829590e-02],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  5.49011230e-02,   5.48706055e-02],
                        [  4.79431152e-02,   4.79736328e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.19519043e-02,   3.19213867e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.62756348e-02,   2.62451172e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.88391113e-02,   2.88696289e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.68859863e-02,   2.69165039e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  2.30712891e-02,   2.30407715e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  8.30078125e-03,   8.27026367e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.45263672e-02,  -1.45568848e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.41601562e-02,  -1.41906738e-02],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.93786621e-02,   1.94091797e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.38702393e-01,   1.38702393e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  4.41894531e-02,   4.41894531e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -1.32141113e-01,  -1.32110596e-01],
                        [ -2.15301514e-01,  -2.15301514e-01],
                        [ -2.65838623e-01,  -2.65838623e-01],
                        [ -2.66601562e-01,  -2.66601562e-01],
                        [ -2.21130371e-01,  -2.21130371e-01],
                        [ -1.57531738e-01,  -1.57531738e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -8.09326172e-02,  -8.09326172e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -8.02001953e-02,  -8.02001953e-02],
                        [ -1.18499756e-01,  -1.18499756e-01],
                        [ -1.47094727e-01,  -1.47094727e-01],
                        [ -1.50817871e-01,  -1.50817871e-01],
                        [ -1.22131348e-01,  -1.22131348e-01],
                        [ -6.43005371e-02,  -6.43310547e-02],
                        [  9.67407227e-03,   9.70458984e-03],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  1.22314453e-01,   1.22314453e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  5.25817871e-02,   5.26123047e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  8.70666504e-02,   8.70666504e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.00280762e-01,   1.00280762e-01],
                        [  8.62426758e-02,   8.62121582e-02],
                        [  7.41882324e-02,   7.42187500e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  4.98962402e-02,   4.99267578e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  3.06701660e-02,   3.07006836e-02],
                        [  2.95715332e-02,   2.96020508e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  2.28576660e-02,   2.28271484e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.04064941e-02,   1.03759766e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.24511719e-02,   1.24816895e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.67541504e-02,   1.67236328e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  2.44140625e-02,   2.44445801e-02],
                        [  1.96228027e-02,   1.95922852e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  6.46972656e-03,   6.50024414e-03],
                        [  8.85009766e-03,   8.81958008e-03],
                        [  1.22375488e-02,   1.22070312e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.85644531e-02,  -2.85339355e-02],
                        [ -3.25622559e-02,  -3.25317383e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -3.58276367e-02,  -3.57971191e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.99682617e-02,  -2.99987793e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.43225098e-02,  -2.42919922e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -4.11987305e-03,  -4.15039062e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  3.50646973e-02,   3.50952148e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  8.94775391e-02,   8.95080566e-02],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  1.24084473e-01,   1.24084473e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.39495850e-01,   1.39526367e-01],
                        [  1.13311768e-01,   1.13311768e-01],
                        [  5.76171875e-02,   5.76171875e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.20910645e-01,  -1.20910645e-01],
                        [ -2.12341309e-01,  -2.12341309e-01],
                        [ -2.72796631e-01,  -2.72796631e-01],
                        [ -2.82379150e-01,  -2.82379150e-01],
                        [ -2.42797852e-01,  -2.42797852e-01],
                        [ -1.78924561e-01,  -1.78924561e-01],
                        [ -1.19476318e-01,  -1.19476318e-01],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -1.52221680e-01,  -1.52221680e-01],
                        [ -1.77612305e-01,  -1.77612305e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.32659912e-01,  -1.32659912e-01],
                        [ -6.36291504e-02,  -6.36596680e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  9.65576172e-02,   9.65576172e-02],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  5.59387207e-02,   5.59082031e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  7.33337402e-02,   7.33642578e-02],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.18652344e-01,   1.18652344e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  7.03735352e-02,   7.03430176e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  6.71386719e-02,   6.71691895e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  6.21948242e-02,   6.22253418e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  3.43627930e-02,   3.43933105e-02],
                        [  2.98461914e-02,   2.98767090e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.27355957e-02,   2.27661133e-02],
                        [  2.25524902e-02,   2.25830078e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.14746094e-02,   1.15051270e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  2.13928223e-02,   2.14233398e-02],
                        [  2.43225098e-02,   2.43530273e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.18200684e-02,   2.18505859e-02],
                        [  1.94702148e-02,   1.94396973e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.95312500e-03,   1.92260742e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.25012207e-02,  -3.24707031e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.45764160e-02,  -3.45458984e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.88598633e-02,  -1.88903809e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -4.39453125e-03,  -4.36401367e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  7.03125000e-02,   7.02819824e-02],
                        [  9.03930664e-02,   9.04235840e-02],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.31896973e-01,   1.31866455e-01],
                        [  1.48803711e-01,   1.48803711e-01],
                        [  1.48620605e-01,   1.48620605e-01],
                        [  1.20483398e-01,   1.20452881e-01],
                        [  6.24694824e-02,   6.24694824e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.16516113e-01,  -1.16516113e-01],
                        [ -2.09991455e-01,  -2.09991455e-01],
                        [ -2.75360107e-01,  -2.75360107e-01],
                        [ -2.90374756e-01,  -2.90374756e-01],
                        [ -2.52593994e-01,  -2.52593994e-01],
                        [ -1.85119629e-01,  -1.85119629e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -7.89184570e-02,  -7.89184570e-02],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -4.28161621e-02,  -4.28466797e-02],
                        [ -3.91845703e-02,  -3.92150879e-02],
                        [ -5.77392578e-02,  -5.77087402e-02],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -1.58386230e-01,  -1.58386230e-01],
                        [ -1.99707031e-01,  -1.99707031e-01],
                        [ -2.08953857e-01,  -2.08953857e-01],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -1.31317139e-01,  -1.31317139e-01],
                        [ -6.84509277e-02,  -6.84509277e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  5.30395508e-02,   5.30395508e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.47918701e-01,   1.47918701e-01],
                        [  1.30493164e-01,   1.30493164e-01],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  6.91528320e-02,   6.91528320e-02],
                        [  5.84411621e-02,   5.84716797e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  6.91528320e-02,   6.91223145e-02],
                        [  7.29370117e-02,   7.29675293e-02],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.36413574e-01,   1.36413574e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.24481201e-01,   1.24481201e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  7.75146484e-02,   7.75451660e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  4.83093262e-02,   4.82788086e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.47705078e-02,   1.48010254e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -4.88281250e-04,  -5.18798828e-04],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  1.25122070e-03,   1.22070312e-03],
                        [  6.53076172e-03,   6.56127930e-03],
                        [  1.31225586e-02,   1.31530762e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.88293457e-02,   1.88598633e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.15148926e-02,   2.14843750e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  4.08935547e-03,   4.11987305e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -2.84423828e-02,  -2.84729004e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.06701660e-02,  -3.07006836e-02],
                        [ -3.31115723e-02,  -3.30810547e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.37622070e-02,  -4.37927246e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.01708984e-02,  -5.01403809e-02],
                        [ -4.89196777e-02,  -4.89501953e-02],
                        [ -4.64477539e-02,  -4.64782715e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.08020020e-02,  -4.08325195e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -4.55932617e-02,  -4.55627441e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  6.35681152e-02,   6.35986328e-02],
                        [  7.60498047e-02,   7.60498047e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.51855469e-01,   1.51855469e-01],
                        [  1.61804199e-01,   1.61773682e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -8.96606445e-02,  -8.96606445e-02],
                        [ -1.94000244e-01,  -1.93969727e-01],
                        [ -2.70690918e-01,  -2.70690918e-01],
                        [ -2.91137695e-01,  -2.91137695e-01],
                        [ -2.51037598e-01,  -2.51037598e-01],
                        [ -1.76147461e-01,  -1.76147461e-01],
                        [ -1.03576660e-01,  -1.03576660e-01],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -9.68933105e-02,  -9.68933105e-02],
                        [ -1.44989014e-01,  -1.44989014e-01],
                        [ -1.91833496e-01,  -1.91833496e-01],
                        [ -2.19024658e-01,  -2.19024658e-01],
                        [ -2.12188721e-01,  -2.12188721e-01],
                        [ -1.72485352e-01,  -1.72454834e-01],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  6.56433105e-02,   6.56127930e-02],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  1.18957520e-01,   1.18927002e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  8.45947266e-02,   8.45947266e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  8.64257812e-02,   8.64257812e-02],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  9.17053223e-02,   9.16748047e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.36962891e-01,   1.36962891e-01],
                        [  1.46270752e-01,   1.46240234e-01],
                        [  1.44439697e-01,   1.44439697e-01],
                        [  1.30920410e-01,   1.30950928e-01],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  7.45544434e-02,   7.45544434e-02],
                        [  7.13500977e-02,   7.13500977e-02],
                        [  6.54907227e-02,   6.55212402e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  7.62939453e-04,   7.93457031e-04],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  1.89819336e-02,   1.89514160e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  4.57763672e-04,   4.27246094e-04],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -2.59399414e-03,  -2.56347656e-03],
                        [ -3.60107422e-03,  -3.63159180e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -4.63867188e-03,  -4.60815430e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.85644531e-02,  -2.85339355e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -4.89807129e-02,  -4.90112305e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.40771484e-02,  -5.41076660e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -3.94592285e-02,  -3.94287109e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.93066406e-02,  -3.93371582e-02],
                        [ -4.51965332e-02,  -4.51660156e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.55432129e-02,  -2.55737305e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.34277344e-03,  -1.31225586e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.53747559e-01,   1.53747559e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  8.63647461e-03,   8.66699219e-03],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -1.91070557e-01,  -1.91101074e-01],
                        [ -2.60406494e-01,  -2.60375977e-01],
                        [ -2.73406982e-01,  -2.73406982e-01],
                        [ -2.32482910e-01,  -2.32513428e-01],
                        [ -1.63665771e-01,  -1.63665771e-01],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -6.17065430e-02,  -6.17370605e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -7.03430176e-02,  -7.03430176e-02],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -1.52618408e-01,  -1.52618408e-01],
                        [ -1.95159912e-01,  -1.95159912e-01],
                        [ -2.14385986e-01,  -2.14416504e-01],
                        [ -2.02636719e-01,  -2.02606201e-01],
                        [ -1.67053223e-01,  -1.67053223e-01],
                        [ -1.23413086e-01,  -1.23443604e-01],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -4.36706543e-02,  -4.36401367e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.37878418e-01,   1.37847900e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  9.73205566e-02,   9.73205566e-02],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  1.35131836e-01,   1.35131836e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  7.95898438e-02,   7.95898438e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  8.54797363e-02,   8.54492188e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  5.78002930e-02,   5.77697754e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  7.93457031e-04,   7.93457031e-04],
                        [  1.64794922e-03,   1.67846680e-03],
                        [  5.03540039e-03,   5.00488281e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.09863281e-02,   1.09558105e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -2.68554688e-02,  -2.68249512e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.85949707e-02,  -2.85644531e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.97546387e-02,  -2.97851562e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -3.65905762e-02,  -3.66210938e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -5.19714355e-02,  -5.20019531e-02],
                        [ -5.77087402e-02,  -5.77392578e-02],
                        [ -5.83190918e-02,  -5.82885742e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.35888672e-02,  -5.35583496e-02],
                        [ -4.34875488e-02,  -4.35180664e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -2.85644531e-02,  -2.85339355e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.70080566e-02,  -2.70385742e-02],
                        [ -2.93273926e-02,  -2.92968750e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -5.73730469e-03,  -5.70678711e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  3.14941406e-02,   3.15246582e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.22619629e-01,   1.22589111e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.14044189e-01,   1.14013672e-01],
                        [  6.10656738e-02,   6.10656738e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.03271484e-01,  -1.03271484e-01],
                        [ -1.91619873e-01,  -1.91619873e-01],
                        [ -2.51525879e-01,  -2.51525879e-01],
                        [ -2.59307861e-01,  -2.59307861e-01],
                        [ -2.14721680e-01,  -2.14721680e-01],
                        [ -1.45629883e-01,  -1.45629883e-01],
                        [ -8.90197754e-02,  -8.89892578e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -8.44421387e-02,  -8.44421387e-02],
                        [ -1.08551025e-01,  -1.08551025e-01],
                        [ -1.40014648e-01,  -1.40014648e-01],
                        [ -1.72332764e-01,  -1.72332764e-01],
                        [ -1.91436768e-01,  -1.91406250e-01],
                        [ -1.87408447e-01,  -1.87408447e-01],
                        [ -1.64276123e-01,  -1.64276123e-01],
                        [ -1.34246826e-01,  -1.34246826e-01],
                        [ -1.04797363e-01,  -1.04797363e-01],
                        [ -7.50732422e-02,  -7.51037598e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  1.38763428e-01,   1.38763428e-01],
                        [  1.35925293e-01,   1.35925293e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  9.93347168e-02,   9.93347168e-02],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.36047363e-01,   1.36047363e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.14868164e-01,   1.14868164e-01],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  7.58361816e-02,   7.58056641e-02],
                        [  7.05871582e-02,   7.05566406e-02],
                        [  6.73217773e-02,   6.73522949e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  6.16760254e-02,   6.16455078e-02],
                        [  6.03637695e-02,   6.03942871e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  3.57360840e-02,   3.57666016e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  2.28881836e-03,   2.28881836e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.62756348e-02,   2.63061523e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -4.36401367e-03,  -4.33349609e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  3.66210938e-04,   3.96728516e-04],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -3.19519043e-02,  -3.19824219e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -6.01806641e-02,  -6.02111816e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.18603516e-02,  -3.18908691e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.75781250e-02,   1.75476074e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  3.38745117e-02,   3.39050293e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  9.32006836e-02,   9.31701660e-02],
                        [  1.26373291e-01,   1.26342773e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.57653809e-01,   1.57623291e-01],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  7.09533691e-02,   7.09533691e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.01867676e-01,  -1.01867676e-01],
                        [ -1.90399170e-01,  -1.90399170e-01],
                        [ -2.45941162e-01,  -2.45941162e-01],
                        [ -2.45819092e-01,  -2.45819092e-01],
                        [ -1.93206787e-01,  -1.93206787e-01],
                        [ -1.20605469e-01,  -1.20605469e-01],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -8.25805664e-02,  -8.25805664e-02],
                        [ -1.23596191e-01,  -1.23596191e-01],
                        [ -1.65313721e-01,  -1.65313721e-01],
                        [ -1.95831299e-01,  -1.95831299e-01],
                        [ -2.05230713e-01,  -2.05230713e-01],
                        [ -1.90490723e-01,  -1.90490723e-01],
                        [ -1.59667969e-01,  -1.59667969e-01],
                        [ -1.26373291e-01,  -1.26373291e-01],
                        [ -1.00280762e-01,  -1.00280762e-01],
                        [ -8.28552246e-02,  -8.28552246e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  1.32781982e-01,   1.32781982e-01],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.08489990e-01,   1.08489990e-01],
                        [  1.02416992e-01,   1.02416992e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.66748047e-01,   1.66717529e-01],
                        [  1.65649414e-01,   1.65649414e-01],
                        [  1.48529053e-01,   1.48529053e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  6.52465820e-02,   6.52160645e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  6.77795410e-02,   6.77795410e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  5.82275391e-02,   5.82580566e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [ -2.50244141e-03,  -2.47192383e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.55639648e-02,  -1.55334473e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [  1.17187500e-02,   1.17492676e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  4.84008789e-02,   4.84313965e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  1.24786377e-01,   1.24755859e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.50024414e-01,   1.50024414e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -8.10241699e-02,  -8.09936523e-02],
                        [ -1.67297363e-01,  -1.67297363e-01],
                        [ -2.25280762e-01,  -2.25280762e-01],
                        [ -2.32238770e-01,  -2.32238770e-01],
                        [ -1.90399170e-01,  -1.90399170e-01],
                        [ -1.30462646e-01,  -1.30462646e-01],
                        [ -9.09118652e-02,  -9.09118652e-02],
                        [ -9.07287598e-02,  -9.07287598e-02],
                        [ -1.19476318e-01,  -1.19476318e-01],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.78314209e-01,  -1.78314209e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.83654785e-01,  -1.83654785e-01],
                        [ -1.67572021e-01,  -1.67572021e-01],
                        [ -1.48040771e-01,  -1.48040771e-01],
                        [ -1.31408691e-01,  -1.31408691e-01],
                        [ -1.17401123e-01,  -1.17401123e-01],
                        [ -1.02569580e-01,  -1.02569580e-01],
                        [ -8.47778320e-02,  -8.47778320e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  9.26208496e-02,   9.26513672e-02],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.60858154e-01,   1.60858154e-01],
                        [  1.56433105e-01,   1.56433105e-01],
                        [  1.37359619e-01,   1.37359619e-01],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  1.13769531e-01,   1.13739014e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  1.25183105e-01,   1.25183105e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  1.52801514e-01,   1.52801514e-01],
                        [  1.65222168e-01,   1.65222168e-01],
                        [  1.68548584e-01,   1.68548584e-01],
                        [  1.61376953e-01,   1.61376953e-01],
                        [  1.46972656e-01,   1.46972656e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  3.05175781e-05,   6.10351562e-05],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  1.81884766e-02,   1.82189941e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -7.05261230e-02,  -7.05261230e-02],
                        [ -7.98950195e-02,  -7.98950195e-02],
                        [ -7.89489746e-02,  -7.89489746e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.00085449e-02,  -3.99780273e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -2.99987793e-02,  -2.99682617e-02],
                        [ -3.32641602e-02,  -3.32946777e-02],
                        [ -3.56445312e-02,  -3.56750488e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.62243652e-02,  -3.62548828e-02],
                        [ -3.31420898e-02,  -3.31115723e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.52282715e-01,   1.52282715e-01],
                        [  1.54754639e-01,   1.54754639e-01],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  7.92846680e-02,   7.92846680e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -1.75231934e-01,  -1.75231934e-01],
                        [ -2.24761963e-01,  -2.24792480e-01],
                        [ -2.24182129e-01,  -2.24182129e-01],
                        [ -1.81091309e-01,  -1.81091309e-01],
                        [ -1.29058838e-01,  -1.29058838e-01],
                        [ -1.04553223e-01,  -1.04553223e-01],
                        [ -1.20025635e-01,  -1.20025635e-01],
                        [ -1.59057617e-01,  -1.59057617e-01],
                        [ -1.93267822e-01,  -1.93298340e-01],
                        [ -2.02880859e-01,  -2.02880859e-01],
                        [ -1.86737061e-01,  -1.86737061e-01],
                        [ -1.58386230e-01,  -1.58386230e-01],
                        [ -1.32781982e-01,  -1.32781982e-01],
                        [ -1.16363525e-01,  -1.16363525e-01],
                        [ -1.07330322e-01,  -1.07330322e-01],
                        [ -1.00921631e-01,  -1.00921631e-01],
                        [ -9.30786133e-02,  -9.30786133e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.60827637e-01,   1.60858154e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.47125244e-01,   1.47125244e-01],
                        [  1.31896973e-01,   1.31896973e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.29425049e-01,   1.29425049e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.52709961e-01,   1.52709961e-01],
                        [  1.62078857e-01,   1.62078857e-01],
                        [  1.64794922e-01,   1.64794922e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.38916016e-01,   1.38916016e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  9.16442871e-02,   9.16442871e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.78100586e-02,  -6.78100586e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.78210449e-02,  -4.77905273e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  1.08123779e-01,   1.08123779e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.40289307e-01,   1.40289307e-01],
                        [  1.37817383e-01,   1.37847900e-01],
                        [  1.14959717e-01,   1.14959717e-01],
                        [  6.50329590e-02,   6.50329590e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -1.75445557e-01,  -1.75445557e-01],
                        [ -2.16278076e-01,  -2.16278076e-01],
                        [ -2.11059570e-01,  -2.11059570e-01],
                        [ -1.72027588e-01,  -1.72027588e-01],
                        [ -1.35833740e-01,  -1.35833740e-01],
                        [ -1.37176514e-01,  -1.37176514e-01],
                        [ -1.76971436e-01,  -1.76971436e-01],
                        [ -2.23266602e-01,  -2.23266602e-01],
                        [ -2.43438721e-01,  -2.43438721e-01],
                        [ -2.30285645e-01,  -2.30285645e-01],
                        [ -1.97967529e-01,  -1.97967529e-01],
                        [ -1.61682129e-01,  -1.61682129e-01],
                        [ -1.28601074e-01,  -1.28601074e-01],
                        [ -1.01623535e-01,  -1.01623535e-01],
                        [ -8.00781250e-02,  -8.00781250e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.54907227e-01,   1.54907227e-01],
                        [  1.66046143e-01,   1.66046143e-01],
                        [  1.55975342e-01,   1.55975342e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.11999512e-01,   1.11999512e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  1.40258789e-01,   1.40258789e-01],
                        [  1.63024902e-01,   1.63024902e-01],
                        [  1.79656982e-01,   1.79656982e-01],
                        [  1.84509277e-01,   1.84509277e-01],
                        [  1.76635742e-01,   1.76635742e-01],
                        [  1.57135010e-01,   1.57135010e-01],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -4.73022461e-03,  -4.76074219e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -3.35693359e-03,  -3.32641602e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  4.99572754e-02,   4.99572754e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.57775879e-01,   1.57775879e-01],
                        [  1.42059326e-01,   1.42089844e-01],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  4.05273438e-02,   4.05273438e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -1.24938965e-01,  -1.24938965e-01],
                        [ -1.95709229e-01,  -1.95709229e-01],
                        [ -2.29034424e-01,  -2.29034424e-01],
                        [ -2.25708008e-01,  -2.25708008e-01],
                        [ -2.12158203e-01,  -2.12158203e-01],
                        [ -2.12554932e-01,  -2.12554932e-01],
                        [ -2.24853516e-01,  -2.24853516e-01],
                        [ -2.29797363e-01,  -2.29797363e-01],
                        [ -2.14782715e-01,  -2.14782715e-01],
                        [ -1.83288574e-01,  -1.83288574e-01],
                        [ -1.49597168e-01,  -1.49597168e-01],
                        [ -1.27990723e-01,  -1.27990723e-01],
                        [ -1.20849609e-01,  -1.20849609e-01],
                        [ -1.15417480e-01,  -1.15417480e-01],
                        [ -9.85412598e-02,  -9.85412598e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  1.30065918e-01,   1.30065918e-01],
                        [  1.54907227e-01,   1.54907227e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.53106689e-01,   1.53106689e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.50360107e-01,   1.50360107e-01],
                        [  1.70410156e-01,   1.70410156e-01],
                        [  1.95373535e-01,   1.95373535e-01],
                        [  2.09289551e-01,   2.09289551e-01],
                        [  2.05322266e-01,   2.05322266e-01],
                        [  1.88415527e-01,   1.88415527e-01],
                        [  1.65557861e-01,   1.65557861e-01],
                        [  1.41479492e-01,   1.41479492e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  9.86938477e-02,   9.86938477e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  4.53796387e-02,   4.53796387e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -5.71594238e-02,  -5.71899414e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.68121338e-01,   1.68121338e-01],
                        [  1.85516357e-01,   1.85516357e-01],
                        [  1.80389404e-01,   1.80389404e-01],
                        [  1.53167725e-01,   1.53167725e-01],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  3.86352539e-02,   3.86352539e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -1.34490967e-01,  -1.34490967e-01],
                        [ -2.05108643e-01,  -2.05108643e-01],
                        [ -2.47344971e-01,  -2.47344971e-01],
                        [ -2.62817383e-01,  -2.62817383e-01],
                        [ -2.61108398e-01,  -2.61108398e-01],
                        [ -2.53875732e-01,  -2.53875732e-01],
                        [ -2.47344971e-01,  -2.47344971e-01],
                        [ -2.35961914e-01,  -2.35961914e-01],
                        [ -2.09686279e-01,  -2.09686279e-01],
                        [ -1.70684814e-01,  -1.70684814e-01],
                        [ -1.35375977e-01,  -1.35375977e-01],
                        [ -1.14837646e-01,  -1.14837646e-01],
                        [ -1.01043701e-01,  -1.01043701e-01],
                        [ -8.16040039e-02,  -8.16040039e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.51336670e-01,   1.51336670e-01],
                        [  1.64428711e-01,   1.64428711e-01],
                        [  1.67297363e-01,   1.67297363e-01],
                        [  1.67510986e-01,   1.67510986e-01],
                        [  1.73858643e-01,   1.73858643e-01],
                        [  1.85791016e-01,   1.85791016e-01],
                        [  1.94549561e-01,   1.94549561e-01],
                        [  1.93878174e-01,   1.93878174e-01],
                        [  1.84509277e-01,   1.84509277e-01],
                        [  1.68609619e-01,   1.68609619e-01],
                        [  1.48254395e-01,   1.48254395e-01],
                        [  1.27319336e-01,   1.27319336e-01],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  1.21734619e-01,   1.21734619e-01],
                        [  1.53717041e-01,   1.53717041e-01],
                        [  1.80755615e-01,   1.80755615e-01],
                        [  1.88659668e-01,   1.88659668e-01],
                        [  1.62414551e-01,   1.62414551e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -1.22406006e-01,  -1.22406006e-01],
                        [ -2.33428955e-01,  -2.33428955e-01],
                        [ -3.10882568e-01,  -3.10882568e-01],
                        [ -3.40240479e-01,  -3.40240479e-01],
                        [ -3.27239990e-01,  -3.27239990e-01],
                        [ -2.91198730e-01,  -2.91198730e-01],
                        [ -2.50274658e-01,  -2.50274658e-01],
                        [ -2.11822510e-01,  -2.11822510e-01],
                        [ -1.74835205e-01,  -1.74835205e-01],
                        [ -1.40106201e-01,  -1.40106201e-01],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.55126953e-02,   2.55126953e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  1.48132324e-01,   1.48132324e-01],
                        [  1.76391602e-01,   1.76391602e-01],
                        [  1.88690186e-01,   1.88690186e-01],
                        [  1.94610596e-01,   1.94610596e-01],
                        [  2.02850342e-01,   2.02850342e-01],
                        [  2.11608887e-01,   2.11608887e-01],
                        [  2.11975098e-01,   2.11975098e-01],
                        [  2.00286865e-01,   2.00286865e-01],
                        [  1.83868408e-01,   1.83868408e-01],
                        [  1.71447754e-01,   1.71447754e-01],
                        [  1.61834717e-01,   1.61834717e-01],
                        [  1.47064209e-01,   1.47064209e-01],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  9.92126465e-02,   9.92126465e-02],
                        [  7.91015625e-02,   7.91015625e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -8.63952637e-02,  -8.63952637e-02],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  8.80432129e-02,   8.80432129e-02],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.66595459e-01,   1.66595459e-01],
                        [  1.97998047e-01,   1.97998047e-01],
                        [  2.04589844e-01,   2.04589844e-01],
                        [  1.76361084e-01,   1.76361084e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -1.28906250e-01,  -1.28906250e-01],
                        [ -2.61108398e-01,  -2.61108398e-01],
                        [ -3.59344482e-01,  -3.59344482e-01],
                        [ -3.94775391e-01,  -3.94775391e-01],
                        [ -3.67187500e-01,  -3.67187500e-01],
                        [ -3.06213379e-01,  -3.06213379e-01],
                        [ -2.45025635e-01,  -2.45025635e-01],
                        [ -1.98394775e-01,  -1.98394775e-01],
                        [ -1.64855957e-01,  -1.64855957e-01],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -1.13739014e-01,  -1.13739014e-01],
                        [ -9.23767090e-02,  -9.23767090e-02],
                        [ -7.98950195e-02,  -7.98950195e-02],
                        [ -7.77282715e-02,  -7.77282715e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  1.88201904e-01,   1.88201904e-01],
                        [  2.27874756e-01,   2.27874756e-01],
                        [  2.49786377e-01,   2.49786377e-01],
                        [  2.56713867e-01,   2.56713867e-01],
                        [  2.52166748e-01,   2.52166748e-01],
                        [  2.40081787e-01,   2.40081787e-01],
                        [  2.22412109e-01,   2.22412109e-01],
                        [  1.99218750e-01,   1.99218750e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.49627686e-01,   1.49627686e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  7.00683594e-02,   7.00683594e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -7.29064941e-02,  -7.29064941e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  1.23474121e-01,   1.23474121e-01],
                        [  1.58630371e-01,   1.58630371e-01],
                        [  1.90673828e-01,   1.90673828e-01],
                        [  2.01324463e-01,   2.01324463e-01],
                        [  1.74682617e-01,   1.74682617e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.59729004e-01,  -1.59729004e-01],
                        [ -2.99011230e-01,  -2.99011230e-01],
                        [ -3.90014648e-01,  -3.90014648e-01],
                        [ -4.06066895e-01,  -4.06066895e-01],
                        [ -3.55560303e-01,  -3.55560303e-01],
                        [ -2.74566650e-01,  -2.74566650e-01],
                        [ -2.01934814e-01,  -2.01934814e-01],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -1.40716553e-01,  -1.40716553e-01],
                        [ -1.28356934e-01,  -1.28356934e-01],
                        [ -1.07177734e-01,  -1.07177734e-01],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  8.79516602e-02,   8.79516602e-02],
                        [  1.64916992e-01,   1.64916992e-01],
                        [  2.34008789e-01,   2.34008789e-01],
                        [  2.73651123e-01,   2.73651123e-01],
                        [  2.78106689e-01,   2.78106689e-01],
                        [  2.62847900e-01,   2.62847900e-01],
                        [  2.45117188e-01,   2.45117188e-01],
                        [  2.27081299e-01,   2.27081299e-01],
                        [  2.04040527e-01,   2.04040527e-01],
                        [  1.78039551e-01,   1.78039551e-01],
                        [  1.53961182e-01,   1.53961182e-01],
                        [  1.31500244e-01,   1.31500244e-01],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -7.92236328e-02,  -7.92236328e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.37725830e-01,   1.37725830e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.75964355e-01,   1.75964355e-01],
                        [  1.63360596e-01,   1.63360596e-01],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  2.55126953e-02,   2.55126953e-02],
                        [ -9.82055664e-02,  -9.82055664e-02],
                        [ -2.37091064e-01,  -2.37091064e-01],
                        [ -3.54217529e-01,  -3.54217529e-01],
                        [ -4.06646729e-01,  -4.06646729e-01],
                        [ -3.79028320e-01,  -3.79028320e-01],
                        [ -3.01055908e-01,  -3.01055908e-01],
                        [ -2.22564697e-01,  -2.22564697e-01],
                        [ -1.74011230e-01,  -1.74011230e-01],
                        [ -1.52618408e-01,  -1.52618408e-01],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -1.17614746e-01,  -1.17614746e-01],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -7.64770508e-02,  -7.64770508e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.74255371e-01,   1.74255371e-01],
                        [  2.37304688e-01,   2.37304688e-01],
                        [  2.77435303e-01,   2.77435303e-01],
                        [  2.86285400e-01,   2.86285400e-01],
                        [  2.67944336e-01,   2.67944336e-01],
                        [  2.36114502e-01,   2.36114502e-01],
                        [  2.05444336e-01,   2.05444336e-01],
                        [  1.82403564e-01,   1.82403564e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.46301270e-01,   1.46301270e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  1.60797119e-01,   1.60797119e-01],
                        [  1.84173584e-01,   1.84173584e-01],
                        [  1.83685303e-01,   1.83685303e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  7.32116699e-02,   7.32116699e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -1.78314209e-01,  -1.78314209e-01],
                        [ -3.09906006e-01,  -3.09906006e-01],
                        [ -3.91998291e-01,  -3.91998291e-01],
                        [ -3.98742676e-01,  -3.98742676e-01],
                        [ -3.41949463e-01,  -3.41949463e-01],
                        [ -2.63031006e-01,  -2.63031006e-01],
                        [ -2.00561523e-01,  -2.00561523e-01],
                        [ -1.66198730e-01,  -1.66198730e-01],
                        [ -1.48925781e-01,  -1.48925781e-01],
                        [ -1.33880615e-01,  -1.33880615e-01],
                        [ -1.15142822e-01,  -1.15142822e-01],
                        [ -9.56420898e-02,  -9.56420898e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  1.15753174e-01,   1.15753174e-01],
                        [  1.95220947e-01,   1.95220947e-01],
                        [  2.61047363e-01,   2.61047363e-01],
                        [  2.98950195e-01,   2.98950195e-01],
                        [  3.01483154e-01,   3.01483154e-01],
                        [  2.73651123e-01,   2.73651123e-01],
                        [  2.34375000e-01,   2.34375000e-01],
                        [  2.03277588e-01,   2.03277588e-01],
                        [  1.84631348e-01,   1.84631348e-01],
                        [  1.70593262e-01,   1.70593262e-01],
                        [  1.54998779e-01,   1.54998779e-01],
                        [  1.37023926e-01,   1.37023926e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -8.98742676e-02,  -8.98742676e-02],
                        [ -8.70056152e-02,  -8.70056152e-02],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -6.75659180e-02,  -6.75659180e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.32446289e-01,   1.32446289e-01],
                        [  1.62719727e-01,   1.62719727e-01],
                        [  1.84356689e-01,   1.84356689e-01],
                        [  1.82739258e-01,   1.82739258e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  6.85424805e-02,   6.85424805e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -1.86553955e-01,  -1.86553955e-01],
                        [ -3.11096191e-01,  -3.11096191e-01],
                        [ -3.85284424e-01,  -3.85284424e-01],
                        [ -3.89953613e-01,  -3.89953613e-01],
                        [ -3.37066650e-01,  -3.37066650e-01],
                        [ -2.62023926e-01,  -2.62023926e-01],
                        [ -1.99371338e-01,  -1.99371338e-01],
                        [ -1.62811279e-01,  -1.62811279e-01],
                        [ -1.43981934e-01,  -1.43981934e-01],
                        [ -1.26922607e-01,  -1.26922607e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -8.33740234e-02,  -8.33740234e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.76940918e-01,   1.76940918e-01],
                        [  2.58819580e-01,   2.58819580e-01],
                        [  3.14697266e-01,   3.14697266e-01],
                        [  3.27575684e-01,   3.27575684e-01],
                        [  3.01696777e-01,   3.01696777e-01],
                        [  2.58300781e-01,   2.58300781e-01],
                        [  2.16278076e-01,   2.16278076e-01],
                        [  1.81518555e-01,   1.81518555e-01],
                        [  1.52252197e-01,   1.52252197e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  8.89587402e-02,   8.89587402e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -6.58569336e-02,  -6.58569336e-02],
                        [ -7.38525391e-02,  -7.38525391e-02],
                        [ -7.58361816e-02,  -7.58361816e-02],
                        [ -7.50122070e-02,  -7.50122070e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -6.96411133e-02,  -6.96411133e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.79901123e-01,   1.79901123e-01],
                        [  1.80969238e-01,   1.80969238e-01],
                        [  1.48162842e-01,   1.48162842e-01],
                        [  8.41064453e-02,   8.41064453e-02],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.06079102e-01,  -1.06079102e-01],
                        [ -2.08831787e-01,  -2.08831787e-01],
                        [ -2.96966553e-01,  -2.96966553e-01],
                        [ -3.51959229e-01,  -3.51959229e-01],
                        [ -3.59954834e-01,  -3.59954834e-01],
                        [ -3.23211670e-01,  -3.23211670e-01],
                        [ -2.61444092e-01,  -2.61444092e-01],
                        [ -2.00592041e-01,  -2.00592041e-01],
                        [ -1.58020020e-01,  -1.58020020e-01],
                        [ -1.32537842e-01,  -1.32537842e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.83685303e-01,   1.83685303e-01],
                        [  2.54882812e-01,   2.54882812e-01],
                        [  2.98217773e-01,   2.98217773e-01],
                        [  3.04840088e-01,   3.04840088e-01],
                        [  2.81707764e-01,   2.81707764e-01],
                        [  2.44476318e-01,   2.44476318e-01],
                        [  2.04864502e-01,   2.04864502e-01],
                        [  1.68426514e-01,   1.68426514e-01],
                        [  1.39831543e-01,   1.39831543e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.56646729e-01,   1.56646729e-01],
                        [  1.56341553e-01,   1.56341553e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -1.45019531e-01,  -1.45019531e-01],
                        [ -2.29095459e-01,  -2.29095459e-01],
                        [ -3.00842285e-01,  -3.00842285e-01],
                        [ -3.44573975e-01,  -3.44573975e-01],
                        [ -3.45733643e-01,  -3.45733643e-01],
                        [ -3.03588867e-01,  -3.03588867e-01],
                        [ -2.39349365e-01,  -2.39349365e-01],
                        [ -1.83135986e-01,  -1.83135986e-01],
                        [ -1.48742676e-01,  -1.48742676e-01],
                        [ -1.25823975e-01,  -1.25823975e-01],
                        [ -9.85107422e-02,  -9.85107422e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  1.11633301e-01,   1.11633301e-01],
                        [  1.92321777e-01,   1.92321777e-01],
                        [  2.62573242e-01,   2.62573242e-01],
                        [  3.04412842e-01,   3.04412842e-01],
                        [  3.12164307e-01,   3.12164307e-01],
                        [  2.91137695e-01,   2.91137695e-01],
                        [  2.52258301e-01,   2.52258301e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  1.68365479e-01,   1.68365479e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.16790771e-01,   1.16790771e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  4.60815430e-03,   4.60815430e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.45233154e-01,   1.45233154e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -1.62475586e-01,  -1.62475586e-01],
                        [ -2.35229492e-01,  -2.35229492e-01],
                        [ -3.02307129e-01,  -3.02307129e-01],
                        [ -3.47717285e-01,  -3.47717285e-01],
                        [ -3.48175049e-01,  -3.48175049e-01],
                        [ -2.97729492e-01,  -2.97729492e-01],
                        [ -2.21862793e-01,  -2.21862793e-01],
                        [ -1.57287598e-01,  -1.57287598e-01],
                        [ -1.20269775e-01,  -1.20269775e-01],
                        [ -1.00097656e-01,  -1.00097656e-01],
                        [ -8.08715820e-02,  -8.08715820e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  3.20434570e-03,   3.20434570e-03],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  9.53979492e-02,   9.53979492e-02],
                        [  1.61010742e-01,   1.61010742e-01],
                        [  2.24365234e-01,   2.24365234e-01],
                        [  2.72613525e-01,   2.72613525e-01],
                        [  2.95593262e-01,   2.95593262e-01],
                        [  2.88970947e-01,   2.88970947e-01],
                        [  2.58361816e-01,   2.58361816e-01],
                        [  2.19024658e-01,   2.19024658e-01],
                        [  1.85485840e-01,   1.85485840e-01],
                        [  1.61254883e-01,   1.61254883e-01],
                        [  1.41632080e-01,   1.41632080e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.05712891e-01,   1.05712891e-01],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  7.93151855e-02,   7.93151855e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -5.25207520e-02,  -5.25207520e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -7.69653320e-02,  -7.69653320e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -1.24328613e-01,  -1.24328613e-01],
                        [ -1.88903809e-01,  -1.88903809e-01],
                        [ -2.70324707e-01,  -2.70324707e-01],
                        [ -3.31024170e-01,  -3.31024170e-01],
                        [ -3.34228516e-01,  -3.34228516e-01],
                        [ -2.79998779e-01,  -2.79998779e-01],
                        [ -2.02789307e-01,  -2.02789307e-01],
                        [ -1.40655518e-01,  -1.40655518e-01],
                        [ -1.08825684e-01,  -1.08825684e-01],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -7.80334473e-02,  -7.80334473e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.59088135e-01,   1.59088135e-01],
                        [  2.05169678e-01,   2.05169678e-01],
                        [  2.44995117e-01,   2.44995117e-01],
                        [  2.71514893e-01,   2.71514893e-01],
                        [  2.75787354e-01,   2.75787354e-01],
                        [  2.55645752e-01,   2.55645752e-01],
                        [  2.21801758e-01,   2.21801758e-01],
                        [  1.88171387e-01,   1.88171387e-01],
                        [  1.60522461e-01,   1.60522461e-01],
                        [  1.37878418e-01,   1.37878418e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  9.86633301e-02,   9.86633301e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  2.55126953e-02,   2.55126953e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.14929199e-01,   1.14929199e-01],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -1.10534668e-01,  -1.10534668e-01],
                        [ -1.89544678e-01,  -1.89544678e-01],
                        [ -2.75268555e-01,  -2.75268555e-01],
                        [ -3.26324463e-01,  -3.26324463e-01],
                        [ -3.16406250e-01,  -3.16406250e-01],
                        [ -2.57385254e-01,  -2.57385254e-01],
                        [ -1.87622070e-01,  -1.87622070e-01],
                        [ -1.38366699e-01,  -1.38366699e-01],
                        [ -1.12823486e-01,  -1.12823486e-01],
                        [ -9.41162109e-02,  -9.41162109e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  1.48284912e-01,   1.48284912e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  2.31994629e-01,   2.31994629e-01],
                        [  2.68127441e-01,   2.68127441e-01],
                        [  2.88085938e-01,   2.88085938e-01],
                        [  2.79052734e-01,   2.79052734e-01],
                        [  2.41455078e-01,   2.41455078e-01],
                        [  1.93145752e-01,   1.93145752e-01],
                        [  1.52160645e-01,   1.52160645e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.01104736e-01,   1.01104736e-01],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.75048828e-02,  -6.75048828e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  7.73010254e-02,   7.73010254e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -1.06872559e-01,  -1.06872559e-01],
                        [ -1.97052002e-01,  -1.97052002e-01],
                        [ -2.83142090e-01,  -2.83142090e-01],
                        [ -3.25286865e-01,  -3.25286865e-01],
                        [ -3.07220459e-01,  -3.07220459e-01],
                        [ -2.45727539e-01,  -2.45727539e-01],
                        [ -1.74865723e-01,  -1.74865723e-01],
                        [ -1.22497559e-01,  -1.22497559e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  1.37054443e-01,   1.37054443e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.91894531e-01,   1.91894531e-01],
                        [  2.29034424e-01,   2.29034424e-01],
                        [  2.57843018e-01,   2.57843018e-01],
                        [  2.62542725e-01,   2.62542725e-01],
                        [  2.43194580e-01,   2.43194580e-01],
                        [  2.12768555e-01,   2.12768555e-01],
                        [  1.80297852e-01,   1.80297852e-01],
                        [  1.47735596e-01,   1.47735596e-01],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -6.72607422e-02,  -6.72607422e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  2.27966309e-02,   2.27966309e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -1.73309326e-01,  -1.73309326e-01],
                        [ -2.59368896e-01,  -2.59368896e-01],
                        [ -3.06945801e-01,  -3.06945801e-01],
                        [ -2.99011230e-01,  -2.99011230e-01],
                        [ -2.45239258e-01,  -2.45239258e-01],
                        [ -1.76086426e-01,  -1.76086426e-01],
                        [ -1.19354248e-01,  -1.19354248e-01],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.80419922e-01,   1.80419922e-01],
                        [  2.19970703e-01,   2.19970703e-01],
                        [  2.41607666e-01,   2.41607666e-01],
                        [  2.34558105e-01,   2.34558105e-01],
                        [  2.02850342e-01,   2.02850342e-01],
                        [  1.61224365e-01,   1.61224365e-01],
                        [  1.26373291e-01,   1.26373291e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  3.60107422e-03,   3.60107422e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -7.02514648e-02,  -7.02514648e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -8.78295898e-02,  -8.78295898e-02],
                        [ -9.97314453e-02,  -9.97314453e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -1.31225586e-01,  -1.31225586e-01],
                        [ -2.08770752e-01,  -2.08770752e-01],
                        [ -2.60467529e-01,  -2.60467529e-01],
                        [ -2.65014648e-01,  -2.65014648e-01],
                        [ -2.26684570e-01,  -2.26684570e-01],
                        [ -1.71630859e-01,  -1.71630859e-01],
                        [ -1.24450684e-01,  -1.24450684e-01],
                        [ -9.34448242e-02,  -9.34448242e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  6.88171387e-02,   6.88171387e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  1.23504639e-01,   1.23504639e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.92840576e-01,   1.92840576e-01],
                        [  2.23175049e-01,   2.23175049e-01],
                        [  2.35412598e-01,   2.35412598e-01],
                        [  2.26379395e-01,   2.26379395e-01],
                        [  2.00195312e-01,   2.00195312e-01],
                        [  1.68487549e-01,   1.68487549e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.37524414e-02,   3.37524414e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  9.52453613e-02,   9.52453613e-02],
                        [  9.86633301e-02,   9.86633301e-02],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -9.75952148e-02,  -9.75952148e-02],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -9.68017578e-02,  -9.68017578e-02],
                        [ -1.80938721e-01,  -1.80938721e-01],
                        [ -2.56835938e-01,  -2.56835938e-01],
                        [ -2.91473389e-01,  -2.91473389e-01],
                        [ -2.69134521e-01,  -2.69134521e-01],
                        [ -2.06390381e-01,  -2.06390381e-01],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.58416748e-01,   1.58416748e-01],
                        [  1.99066162e-01,   1.99066162e-01],
                        [  2.27233887e-01,   2.27233887e-01],
                        [  2.32543945e-01,   2.32543945e-01],
                        [  2.16400146e-01,   2.16400146e-01],
                        [  1.89392090e-01,   1.89392090e-01],
                        [  1.61651611e-01,   1.61651611e-01],
                        [  1.39068604e-01,   1.39068604e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -6.92443848e-02,  -6.92443848e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -6.83288574e-02,  -6.83288574e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -1.09436035e-01,  -1.09436035e-01],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -1.87164307e-01,  -1.87164307e-01],
                        [ -2.50427246e-01,  -2.50427246e-01],
                        [ -2.68524170e-01,  -2.68524170e-01],
                        [ -2.37518311e-01,  -2.37518311e-01],
                        [ -1.80725098e-01,  -1.80725098e-01],
                        [ -1.28723145e-01,  -1.28723145e-01],
                        [ -9.70153809e-02,  -9.70153809e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  9.07897949e-02,   9.07897949e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  1.09466553e-01,   1.09466553e-01],
                        [  1.43402100e-01,   1.43402100e-01],
                        [  1.83258057e-01,   1.83258057e-01],
                        [  2.14263916e-01,   2.14263916e-01],
                        [  2.24853516e-01,   2.24853516e-01],
                        [  2.13012695e-01,   2.13012695e-01],
                        [  1.85913086e-01,   1.85913086e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  9.65881348e-02,   9.65881348e-02],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -1.13677979e-01,  -1.13677979e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -2.10601807e-01,  -2.10601807e-01],
                        [ -2.61932373e-01,  -2.61932373e-01],
                        [ -2.62298584e-01,  -2.62298584e-01],
                        [ -2.18048096e-01,  -2.18048096e-01],
                        [ -1.54113770e-01,  -1.54113770e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  7.28454590e-02,   7.28454590e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.00036621e-01,   1.00036621e-01],
                        [  1.45202637e-01,   1.45202637e-01],
                        [  1.88262939e-01,   1.88262939e-01],
                        [  2.17254639e-01,   2.17254639e-01],
                        [  2.23846436e-01,   2.23846436e-01],
                        [  2.05718994e-01,   2.05718994e-01],
                        [  1.72882080e-01,   1.72882080e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  7.93762207e-02,   7.93762207e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -1.03546143e-01,  -1.03546143e-01],
                        [ -1.44592285e-01,  -1.44592285e-01],
                        [ -1.42211914e-01,  -1.42211914e-01],
                        [ -9.79919434e-02,  -9.79919434e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  7.58666992e-02,   7.58666992e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -1.78558350e-01,  -1.78558350e-01],
                        [ -2.55126953e-01,  -2.55126953e-01],
                        [ -2.83843994e-01,  -2.83843994e-01],
                        [ -2.54608154e-01,  -2.54608154e-01],
                        [ -1.88507080e-01,  -1.88507080e-01],
                        [ -1.24084473e-01,  -1.24084473e-01],
                        [ -8.79516602e-02,  -8.79516602e-02],
                        [ -7.77587891e-02,  -7.77587891e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  1.40106201e-01,   1.40106201e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  1.41540527e-01,   1.41540527e-01],
                        [  1.90429688e-01,   1.90429688e-01],
                        [  2.27233887e-01,   2.27233887e-01],
                        [  2.39288330e-01,   2.39288330e-01],
                        [  2.23083496e-01,   2.23083496e-01],
                        [  1.86553955e-01,   1.86553955e-01],
                        [  1.46820068e-01,   1.46820068e-01],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -8.06884766e-02,  -8.06884766e-02],
                        [ -1.22833252e-01,  -1.22833252e-01],
                        [ -1.29119873e-01,  -1.29119873e-01],
                        [ -9.66491699e-02,  -9.66491699e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -2.19360352e-01,  -2.19360352e-01],
                        [ -2.73498535e-01,  -2.73498535e-01],
                        [ -2.72521973e-01,  -2.72521973e-01],
                        [ -2.23999023e-01,  -2.23999023e-01],
                        [ -1.58325195e-01,  -1.58325195e-01],
                        [ -1.05407715e-01,  -1.05407715e-01],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  6.90002441e-02,   6.90002441e-02],
                        [  1.03302002e-01,   1.03302002e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  9.41162109e-02,   9.41162109e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  7.64770508e-02,   7.64770508e-02],
                        [  1.01959229e-01,   1.01959229e-01],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.75354004e-01,   1.75354004e-01],
                        [  2.04803467e-01,   2.04803467e-01],
                        [  2.14477539e-01,   2.14477539e-01],
                        [  2.01782227e-01,   2.01782227e-01],
                        [  1.74987793e-01,   1.74987793e-01],
                        [  1.47460938e-01,   1.47460938e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  6.52770996e-02,   6.52770996e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -1.31408691e-01,  -1.31408691e-01],
                        [ -1.64459229e-01,  -1.64459229e-01],
                        [ -1.49169922e-01,  -1.49169922e-01],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  6.53991699e-02,   6.53991699e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -1.15112305e-01,  -1.15112305e-01],
                        [ -2.04284668e-01,  -2.04284668e-01],
                        [ -2.58331299e-01,  -2.58331299e-01],
                        [ -2.56011963e-01,  -2.56011963e-01],
                        [ -2.06268311e-01,  -2.06268311e-01],
                        [ -1.43066406e-01,  -1.43066406e-01],
                        [ -9.78088379e-02,  -9.78088379e-02],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.46514893e-01,   1.46514893e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.68395996e-01,   1.68395996e-01],
                        [  2.07885742e-01,   2.07885742e-01],
                        [  2.24151611e-01,   2.24151611e-01],
                        [  2.12799072e-01,   2.12799072e-01],
                        [  1.82250977e-01,   1.82250977e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.00128174e-01,   1.00128174e-01],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  7.78198242e-02,   7.78198242e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  6.45446777e-02,   6.45446777e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.96728516e-03,   3.96728516e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.93359375e-02,  -6.93359375e-02],
                        [ -7.36083984e-02,  -7.36083984e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -6.92443848e-02,  -6.92443848e-02],
                        [ -7.58361816e-02,  -7.58361816e-02],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -1.21490479e-01,  -1.21490479e-01],
                        [ -1.57012939e-01,  -1.57012939e-01],
                        [ -1.47338867e-01,  -1.47338867e-01],
                        [ -1.03942871e-01,  -1.03942871e-01],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  4.18701172e-02,   4.18701172e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -1.40045166e-01,  -1.40045166e-01],
                        [ -2.15332031e-01,  -2.15332031e-01],
                        [ -2.47222900e-01,  -2.47222900e-01],
                        [ -2.30712891e-01,  -2.30712891e-01],
                        [ -1.83380127e-01,  -1.83380127e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -8.66088867e-02,  -8.66088867e-02],
                        [ -6.59179688e-02,  -6.59179688e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  6.52770996e-02,   6.52770996e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.53533936e-01,   1.53533936e-01],
                        [  1.52801514e-01,   1.52801514e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  1.40106201e-01,   1.40106201e-01],
                        [  1.78161621e-01,   1.78161621e-01],
                        [  2.01141357e-01,   2.01141357e-01],
                        [  2.03796387e-01,   2.03796387e-01],
                        [  1.88568115e-01,   1.88568115e-01],
                        [  1.65802002e-01,   1.65802002e-01],
                        [  1.47277832e-01,   1.47277832e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -7.00683594e-02,  -7.00683594e-02],
                        [ -7.54394531e-02,  -7.54394531e-02],
                        [ -7.73010254e-02,  -7.73010254e-02],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -7.27844238e-02,  -7.27844238e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -1.56707764e-01,  -1.56707764e-01],
                        [ -1.68731689e-01,  -1.68731689e-01],
                        [ -1.38580322e-01,  -1.38580322e-01],
                        [ -8.45031738e-02,  -8.45031738e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.05957031e-01,  -1.05957031e-01],
                        [ -1.91223145e-01,  -1.91223145e-01],
                        [ -2.49542236e-01,  -2.49542236e-01],
                        [ -2.61688232e-01,  -2.61688232e-01],
                        [ -2.27508545e-01,  -2.27508545e-01],
                        [ -1.68121338e-01,  -1.68121338e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -7.01599121e-02,  -7.01599121e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  1.02691650e-01,   1.02691650e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  1.48986816e-01,   1.48986816e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.63787842e-01,   1.63787842e-01],
                        [  2.04864502e-01,   2.04864502e-01],
                        [  2.27050781e-01,   2.27050781e-01],
                        [  2.22045898e-01,   2.22045898e-01],
                        [  1.93725586e-01,   1.93725586e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -7.37609863e-02,  -7.37609863e-02],
                        [ -7.33947754e-02,  -7.33947754e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -1.85485840e-01,  -1.85485840e-01],
                        [ -1.65893555e-01,  -1.65893555e-01],
                        [ -1.06964111e-01,  -1.06964111e-01],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -1.39343262e-01,  -1.39343262e-01],
                        [ -2.23052979e-01,  -2.23052979e-01],
                        [ -2.63549805e-01,  -2.63549805e-01],
                        [ -2.50823975e-01,  -2.50823975e-01],
                        [ -2.00317383e-01,  -2.00317383e-01],
                        [ -1.40441895e-01,  -1.40441895e-01],
                        [ -9.67102051e-02,  -9.67102051e-02],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  1.26586914e-01,   1.26586914e-01],
                        [  1.15905762e-01,   1.15905762e-01],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  7.82775879e-02,   7.82775879e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  5.21545410e-02,   5.21545410e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.83929443e-01,   1.83929443e-01],
                        [  2.13165283e-01,   2.13165283e-01],
                        [  2.16888428e-01,   2.16888428e-01],
                        [  1.96166992e-01,   1.96166992e-01],
                        [  1.65588379e-01,   1.65588379e-01],
                        [  1.39678955e-01,   1.39678955e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  4.46472168e-02,   4.46472168e-02],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -1.27716064e-01,  -1.27716064e-01],
                        [ -1.66870117e-01,  -1.66870117e-01],
                        [ -1.69006348e-01,  -1.69006348e-01],
                        [ -1.35101318e-01,  -1.35101318e-01],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  5.11474609e-02,   5.11474609e-02],
                        [  6.41479492e-02,   6.41479492e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -1.98547363e-01,  -1.98547363e-01],
                        [ -2.32849121e-01,  -2.32849121e-01],
                        [ -2.17895508e-01,  -2.17895508e-01],
                        [ -1.69250488e-01,  -1.69250488e-01],
                        [ -1.17950439e-01,  -1.17950439e-01],
                        [ -8.71582031e-02,  -8.71582031e-02],
                        [ -7.78808594e-02,  -7.78808594e-02],
                        [ -7.61718750e-02,  -7.61718750e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  1.27807617e-01,   1.27807617e-01],
                        [  1.18347168e-01,   1.18347168e-01],
                        [  1.03546143e-01,   1.03546143e-01],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.58508301e-01,   1.58508301e-01],
                        [  1.95465088e-01,   1.95465088e-01],
                        [  2.15728760e-01,   2.15728760e-01],
                        [  2.13256836e-01,   2.13256836e-01],
                        [  1.89544678e-01,   1.89544678e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  8.72802734e-02,   8.72802734e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -6.86950684e-02,  -6.86950684e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -1.26647949e-01,  -1.26647949e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.27746582e-01,  -1.27746582e-01],
                        [ -8.32214355e-02,  -8.32214355e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -2.11517334e-01,  -2.11517334e-01],
                        [ -2.38281250e-01,  -2.38281250e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.09619141e-01,  -1.09619141e-01],
                        [ -7.69348145e-02,  -7.69348145e-02],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.34674072e-01,   1.34674072e-01],
                        [  1.41510010e-01,   1.41510010e-01],
                        [  1.34460449e-01,   1.34460449e-01],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.40167236e-01,   1.40167236e-01],
                        [  1.84143066e-01,   1.84143066e-01],
                        [  2.06817627e-01,   2.06817627e-01],
                        [  2.03674316e-01,   2.03674316e-01],
                        [  1.80389404e-01,   1.80389404e-01],
                        [  1.48254395e-01,   1.48254395e-01],
                        [  1.17156982e-01,   1.17156982e-01],
                        [  9.16442871e-02,   9.16442871e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -7.20214844e-02,  -7.20214844e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -7.88879395e-02,  -7.88879395e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -1.28143311e-01,  -1.28143311e-01],
                        [ -1.74896240e-01,  -1.74896240e-01],
                        [ -1.84082031e-01,  -1.84082031e-01],
                        [ -1.52893066e-01,  -1.52893066e-01],
                        [ -1.01226807e-01,  -1.01226807e-01],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -1.51733398e-01,  -1.51733398e-01],
                        [ -2.07244873e-01,  -2.07244873e-01],
                        [ -2.22137451e-01,  -2.22137451e-01],
                        [ -1.97753906e-01,  -1.97753906e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.17706299e-01,  -1.17706299e-01],
                        [ -9.86938477e-02,  -9.86938477e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  1.47277832e-01,   1.47277832e-01],
                        [  1.35375977e-01,   1.35375977e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.82220459e-01,   1.82220459e-01],
                        [  2.14355469e-01,   2.14355469e-01],
                        [  2.19177246e-01,   2.19177246e-01],
                        [  1.95739746e-01,   1.95739746e-01],
                        [  1.55120850e-01,   1.55120850e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  6.88171387e-02,   6.88171387e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -1.06811523e-01,  -1.06811523e-01],
                        [ -1.63482666e-01,  -1.63482666e-01],
                        [ -1.90734863e-01,  -1.90734863e-01],
                        [ -1.75750732e-01,  -1.75750732e-01],
                        [ -1.30004883e-01,  -1.30004883e-01],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -1.44042969e-01,  -1.44042969e-01],
                        [ -2.01477051e-01,  -2.01477051e-01],
                        [ -2.20642090e-01,  -2.20642090e-01],
                        [ -1.98730469e-01,  -1.98730469e-01],
                        [ -1.54876709e-01,  -1.54876709e-01],
                        [ -1.14166260e-01,  -1.14166260e-01],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  1.33819580e-01,   1.33819580e-01],
                        [  1.49047852e-01,   1.49047852e-01],
                        [  1.46270752e-01,   1.46270752e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  6.97021484e-02,   6.97021484e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.62475586e-01,   1.62475586e-01],
                        [  1.91406250e-01,   1.91406250e-01],
                        [  1.96807861e-01,   1.96807861e-01],
                        [  1.78344727e-01,   1.78344727e-01],
                        [  1.48345947e-01,   1.48345947e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -7.38830566e-02,  -7.38830566e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -1.37725830e-01,  -1.37725830e-01],
                        [ -1.89117432e-01,  -1.89117432e-01],
                        [ -2.05383301e-01,  -2.05383301e-01],
                        [ -1.84020996e-01,  -1.84020996e-01],
                        [ -1.38946533e-01,  -1.38946533e-01],
                        [ -8.90197754e-02,  -8.90197754e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -1.24359131e-01,  -1.24359131e-01],
                        [ -1.90826416e-01,  -1.90826416e-01],
                        [ -2.20184326e-01,  -2.20184326e-01],
                        [ -2.05291748e-01,  -2.05291748e-01],
                        [ -1.63635254e-01,  -1.63635254e-01],
                        [ -1.20819092e-01,  -1.20819092e-01],
                        [ -9.14916992e-02,  -9.14916992e-02],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.16882324e-01,   1.16882324e-01],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  9.95788574e-02,   9.95788574e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  1.03912354e-01,   1.03912354e-01],
                        [  1.43524170e-01,   1.43524170e-01],
                        [  1.76818848e-01,   1.76818848e-01],
                        [  1.92779541e-01,   1.92779541e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  7.30285645e-02,   7.30285645e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -1.21490479e-01,  -1.21490479e-01],
                        [ -1.84661865e-01,  -1.84661865e-01],
                        [ -2.07885742e-01,  -2.07885742e-01],
                        [ -1.88720703e-01,  -1.88720703e-01],
                        [ -1.46636963e-01,  -1.46636963e-01],
                        [ -1.06872559e-01,  -1.06872559e-01],
                        [ -8.05969238e-02,  -8.05969238e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  8.19396973e-02,   8.19396973e-02],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  5.02014160e-02,   5.02014160e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -1.38854980e-01,  -1.38854980e-01],
                        [ -2.14416504e-01,  -2.14416504e-01],
                        [ -2.42218018e-01,  -2.42218018e-01],
                        [ -2.19238281e-01,  -2.19238281e-01],
                        [ -1.66259766e-01,  -1.66259766e-01],
                        [ -1.14532471e-01,  -1.14532471e-01],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  4.49829102e-02,   4.49829102e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.47857666e-01,   1.47857666e-01],
                        [  1.78985596e-01,   1.78985596e-01],
                        [  1.92596436e-01,   1.92596436e-01],
                        [  1.80236816e-01,   1.80236816e-01],
                        [  1.50726318e-01,   1.50726318e-01],
                        [  1.22863770e-01,   1.22863770e-01],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  6.71386719e-04,   6.71386719e-04],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.75048828e-02,  -6.75048828e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -9.07897949e-02,  -9.07897949e-02],
                        [ -1.59606934e-01,  -1.59606934e-01],
                        [ -1.96777344e-01,  -1.96777344e-01],
                        [ -1.95526123e-01,  -1.95526123e-01],
                        [ -1.67297363e-01,  -1.67297363e-01],
                        [ -1.30554199e-01,  -1.30554199e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  4.99877930e-02,   4.99877930e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.35375977e-01,  -1.35375977e-01],
                        [ -2.13256836e-01,  -2.13256836e-01],
                        [ -2.42095947e-01,  -2.42095947e-01],
                        [ -2.20397949e-01,  -2.20397949e-01],
                        [ -1.70349121e-01,  -1.70349121e-01],
                        [ -1.21673584e-01,  -1.21673584e-01],
                        [ -9.04846191e-02,  -9.04846191e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.32873535e-01,   1.32873535e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  1.04553223e-01,   1.04553223e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  9.22241211e-02,   9.22241211e-02],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.64306641e-01,   1.64306641e-01],
                        [  1.80450439e-01,   1.80450439e-01],
                        [  1.70745850e-01,   1.70745850e-01],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -7.51342773e-02,  -7.51342773e-02],
                        [ -7.37609863e-02,  -7.37609863e-02],
                        [ -6.90307617e-02,  -6.90307617e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -1.10351562e-01,  -1.10351562e-01],
                        [ -1.63635254e-01,  -1.63635254e-01],
                        [ -1.93817139e-01,  -1.93817139e-01],
                        [ -1.93817139e-01,  -1.93817139e-01],
                        [ -1.67510986e-01,  -1.67510986e-01],
                        [ -1.31134033e-01,  -1.31134033e-01],
                        [ -9.96704102e-02,  -9.96704102e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.46026611e-01,   1.46026611e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  2.49938965e-02,   2.49938965e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -1.87225342e-01,  -1.87225342e-01],
                        [ -2.50823975e-01,  -2.50823975e-01],
                        [ -2.55950928e-01,  -2.55950928e-01],
                        [ -2.12097168e-01,  -2.12097168e-01],
                        [ -1.50360107e-01,  -1.50360107e-01],
                        [ -1.01837158e-01,  -1.01837158e-01],
                        [ -7.55920410e-02,  -7.55920410e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  6.69860840e-02,   6.69860840e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  1.25457764e-01,   1.25457764e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  1.05255127e-01,   1.05255127e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.54449463e-01,   1.54449463e-01],
                        [  1.74133301e-01,   1.74133301e-01],
                        [  1.71691895e-01,   1.71691895e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  9.66796875e-02,   9.66796875e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -1.02050781e-01,  -1.02050781e-01],
                        [ -1.73950195e-01,  -1.73950195e-01],
                        [ -2.21191406e-01,  -2.21191406e-01],
                        [ -2.27355957e-01,  -2.27355957e-01],
                        [ -1.93511963e-01,  -1.93511963e-01],
                        [ -1.40411377e-01,  -1.40411377e-01],
                        [ -9.35668945e-02,  -9.35668945e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  4.58984375e-02,   4.58984375e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -1.51885986e-01,  -1.51885986e-01],
                        [ -2.26531982e-01,  -2.26531982e-01],
                        [ -2.47772217e-01,  -2.47772217e-01],
                        [ -2.17559814e-01,  -2.17559814e-01],
                        [ -1.62506104e-01,  -1.62506104e-01],
                        [ -1.13067627e-01,  -1.13067627e-01],
                        [ -8.32214355e-02,  -8.32214355e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.55517578e-01,   1.55517578e-01],
                        [  1.44378662e-01,   1.44378662e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  1.90093994e-01,   1.90093994e-01],
                        [  1.75659180e-01,   1.75659180e-01],
                        [  1.46911621e-01,   1.46911621e-01],
                        [  1.20300293e-01,   1.20300293e-01],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -7.90100098e-02,  -7.90100098e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -1.39678955e-01,  -1.39678955e-01],
                        [ -1.95465088e-01,  -1.95465088e-01],
                        [ -2.21618652e-01,  -2.21618652e-01],
                        [ -2.07672119e-01,  -2.07672119e-01],
                        [ -1.65405273e-01,  -1.65405273e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -9.35668945e-02,  -9.35668945e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -6.93664551e-02,  -6.93664551e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.33453369e-01,   1.33453369e-01],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  3.85437012e-02,   3.85437012e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -1.50604248e-01,  -1.50604248e-01],
                        [ -2.23541260e-01,  -2.23541260e-01],
                        [ -2.45269775e-01,  -2.45269775e-01],
                        [ -2.13714600e-01,  -2.13714600e-01],
                        [ -1.53991699e-01,  -1.53991699e-01],
                        [ -1.00158691e-01,  -1.00158691e-01],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.47613525e-01,   1.47613525e-01],
                        [  1.52221680e-01,   1.52221680e-01],
                        [  1.39739990e-01,   1.39739990e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.64093018e-01,   1.64093018e-01],
                        [  1.63085938e-01,   1.63085938e-01],
                        [  1.43554688e-01,   1.43554688e-01],
                        [  1.19140625e-01,   1.19140625e-01],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -8.89587402e-02,  -8.89587402e-02],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  7.37609863e-02,   7.37609863e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -1.52770996e-01,  -1.52770996e-01],
                        [ -2.24639893e-01,  -2.24639893e-01],
                        [ -2.52716064e-01,  -2.52716064e-01],
                        [ -2.34222412e-01,  -2.34222412e-01],
                        [ -1.85974121e-01,  -1.85974121e-01],
                        [ -1.32263184e-01,  -1.32263184e-01],
                        [ -9.04846191e-02,  -9.04846191e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.54113770e-01,   1.54113770e-01],
                        [  1.62506104e-01,   1.62506104e-01],
                        [  1.33056641e-01,   1.33056641e-01],
                        [  5.72814941e-02,   5.72814941e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -1.53503418e-01,  -1.53503418e-01],
                        [ -2.27447510e-01,  -2.27447510e-01],
                        [ -2.50885010e-01,  -2.50885010e-01],
                        [ -2.21984863e-01,  -2.21984863e-01],
                        [ -1.62658691e-01,  -1.62658691e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  1.19659424e-01,   1.19659424e-01],
                        [  1.43310547e-01,   1.43310547e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.38977051e-01,   1.38977051e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  1.36474609e-01,   1.36474609e-01],
                        [  1.59698486e-01,   1.59698486e-01],
                        [  1.57928467e-01,   1.57928467e-01],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.00372314e-01,   1.00372314e-01],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -7.20825195e-02,  -7.20825195e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  6.97631836e-02,   6.97631836e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -9.05151367e-02,  -9.05151367e-02],
                        [ -1.72973633e-01,  -1.72973633e-01],
                        [ -2.33001709e-01,  -2.33001709e-01],
                        [ -2.51373291e-01,  -2.51373291e-01],
                        [ -2.24761963e-01,  -2.24761963e-01],
                        [ -1.72180176e-01,  -1.72180176e-01],
                        [ -1.22894287e-01,  -1.22894287e-01],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -7.30590820e-02,  -7.30590820e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  1.38092041e-01,   1.38092041e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  7.41577148e-03,   7.41577148e-03],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -1.78131104e-01,  -1.78131104e-01],
                        [ -2.32940674e-01,  -2.32940674e-01],
                        [ -2.35229492e-01,  -2.35229492e-01],
                        [ -1.94030762e-01,  -1.94030762e-01],
                        [ -1.38763428e-01,  -1.38763428e-01],
                        [ -9.74121094e-02,  -9.74121094e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  1.36840820e-01,   1.36840820e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.39038086e-01,   1.39038086e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.46209717e-01,   1.46209717e-01],
                        [  1.69921875e-01,   1.69921875e-01],
                        [  1.68029785e-01,   1.68029785e-01],
                        [  1.44470215e-01,   1.44470215e-01],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -1.18621826e-01,  -1.18621826e-01],
                        [ -1.95037842e-01,  -1.95037842e-01],
                        [ -2.40234375e-01,  -2.40234375e-01],
                        [ -2.38525391e-01,  -2.38525391e-01],
                        [ -1.99493408e-01,  -1.99493408e-01],
                        [ -1.48590088e-01,  -1.48590088e-01],
                        [ -1.06903076e-01,  -1.06903076e-01],
                        [ -8.01696777e-02,  -8.01696777e-02],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  1.38885498e-01,   1.38885498e-01],
                        [  1.55700684e-01,   1.55700684e-01],
                        [  1.44592285e-01,   1.44592285e-01],
                        [  9.97314453e-02,   9.97619629e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -1.78771973e-01,  -1.78771973e-01],
                        [ -2.33123779e-01,  -2.33123779e-01],
                        [ -2.30804443e-01,  -2.30804443e-01],
                        [ -1.83593750e-01,  -1.83593750e-01],
                        [ -1.23046875e-01,  -1.23046875e-01],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.43310547e-01,   1.43310547e-01],
                        [  1.44256592e-01,   1.44256592e-01],
                        [  1.28417969e-01,   1.28417969e-01],
                        [  1.13067627e-01,   1.13067627e-01],
                        [  1.07910156e-01,   1.07910156e-01],
                        [  1.09771729e-01,   1.09771729e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  1.32659912e-01,   1.32659912e-01],
                        [  1.65527344e-01,   1.65527344e-01],
                        [  1.66961670e-01,   1.66961670e-01],
                        [  1.43768311e-01,   1.43768311e-01],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.19104004e-02,   5.19104004e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -1.18835449e-01,  -1.18835449e-01],
                        [ -1.81732178e-01,  -1.81732178e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -2.13104248e-01,  -2.13104248e-01],
                        [ -1.77337646e-01,  -1.77337646e-01],
                        [ -1.32080078e-01,  -1.32080078e-01],
                        [ -9.95483398e-02,  -9.95483398e-02],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -7.05261230e-02,  -7.05261230e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -4.35180664e-02,  -4.34875488e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  1.29638672e-01,   1.29638672e-01],
                        [  1.43035889e-01,   1.43035889e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  4.09240723e-02,   4.09240723e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -1.34979248e-01,  -1.34979248e-01],
                        [ -2.01171875e-01,  -2.01171875e-01],
                        [ -2.20397949e-01,  -2.20397949e-01],
                        [ -1.91314697e-01,  -1.91314697e-01],
                        [ -1.36749268e-01,  -1.36749268e-01],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  1.13616943e-01,   1.13616943e-01],
                        [  1.38519287e-01,   1.38519287e-01],
                        [  1.44927979e-01,   1.44927979e-01],
                        [  1.39434814e-01,   1.39434814e-01],
                        [  1.32446289e-01,   1.32446289e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.18316650e-01,   1.18316650e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  5.10253906e-02,   5.09948730e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  5.29785156e-02,   5.29785156e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.56311035e-01,   1.56311035e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  4.75769043e-02,   4.75769043e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -1.49841309e-02,  -1.50146484e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -7.16857910e-02,  -7.17163086e-02],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -7.29675293e-02,  -7.29675293e-02],
                        [ -7.63244629e-02,  -7.63244629e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -7.66906738e-02,  -7.66906738e-02],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [ -5.00488281e-03,  -5.03540039e-03],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -1.15692139e-01,  -1.15692139e-01],
                        [ -1.77246094e-01,  -1.77246094e-01],
                        [ -2.15942383e-01,  -2.15942383e-01],
                        [ -2.16979980e-01,  -2.16979980e-01],
                        [ -1.81610107e-01,  -1.81610107e-01],
                        [ -1.28662109e-01,  -1.28662109e-01],
                        [ -8.57849121e-02,  -8.57849121e-02],
                        [ -6.93359375e-02,  -6.93359375e-02],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -3.30810547e-02,  -3.30810547e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  1.15539551e-01,   1.15539551e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  4.37316895e-02,   4.37316895e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -1.26525879e-01,  -1.26525879e-01],
                        [ -1.95526123e-01,  -1.95526123e-01],
                        [ -2.19848633e-01,  -2.19848633e-01],
                        [ -1.95617676e-01,  -1.95617676e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -9.62524414e-02,  -9.62524414e-02],
                        [ -7.07092285e-02,  -7.07397461e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -3.45764160e-02,  -3.46069336e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  5.24902344e-03,   5.21850586e-03],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  1.41113281e-01,   1.41113281e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  1.54602051e-01,   1.54632568e-01],
                        [  1.40197754e-01,   1.40228271e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  8.39843750e-02,   8.39843750e-02],
                        [  7.58666992e-02,   7.58666992e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.34887695e-01,   1.34887695e-01],
                        [  1.36474609e-01,   1.36474609e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  9.24377441e-02,   9.24377441e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  6.24084473e-02,   6.23779297e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.39465332e-02,  -1.39770508e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -7.32421875e-02,  -7.32727051e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -1.17126465e-01,  -1.17126465e-01],
                        [ -1.84631348e-01,  -1.84631348e-01],
                        [ -2.27813721e-01,  -2.27813721e-01],
                        [ -2.30407715e-01,  -2.30407715e-01],
                        [ -1.95495605e-01,  -1.95495605e-01],
                        [ -1.43890381e-01,  -1.43890381e-01],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -5.00488281e-02,  -5.00183105e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  6.15539551e-02,   6.15539551e-02],
                        [ -1.30920410e-02,  -1.30615234e-02],
                        [ -9.82055664e-02,  -9.82055664e-02],
                        [ -1.72119141e-01,  -1.72119141e-01],
                        [ -2.11944580e-01,  -2.11944580e-01],
                        [ -2.05718994e-01,  -2.05718994e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.13067627e-01,  -1.13067627e-01],
                        [ -7.65380859e-02,  -7.65380859e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  7.04040527e-02,   7.04040527e-02],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.50817871e-01,   1.50817871e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.39331055e-02,   9.39331055e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.31774902e-01,   1.31774902e-01],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -1.95251465e-01,  -1.95251465e-01],
                        [ -2.32971191e-01,  -2.32971191e-01],
                        [ -2.28332520e-01,  -2.28332520e-01],
                        [ -1.87622070e-01,  -1.87622070e-01],
                        [ -1.36169434e-01,  -1.36169434e-01],
                        [ -9.95483398e-02,  -9.95483398e-02],
                        [ -8.44726562e-02,  -8.44726562e-02],
                        [ -7.83081055e-02,  -7.83081055e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  1.32019043e-01,   1.32019043e-01],
                        [  1.53839111e-01,   1.53839111e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.30767822e-01,   1.30737305e-01],
                        [  6.77795410e-02,   6.77795410e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.21154785e-01,  -1.21154785e-01],
                        [ -1.99890137e-01,  -1.99890137e-01],
                        [ -2.35412598e-01,  -2.35412598e-01],
                        [ -2.17773438e-01,  -2.17773438e-01],
                        [ -1.63909912e-01,  -1.63909912e-01],
                        [ -1.08886719e-01,  -1.08886719e-01],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.68151855e-02,   1.67846680e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  4.37011719e-02,   4.37011719e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.59729004e-01,   1.59729004e-01],
                        [  1.69860840e-01,   1.69860840e-01],
                        [  1.67755127e-01,   1.67755127e-01],
                        [  1.57287598e-01,   1.57287598e-01],
                        [  1.40747070e-01,   1.40747070e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  8.45031738e-02,   8.45031738e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  3.06396484e-02,   3.06701660e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.68151855e-02,  -1.67846680e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  1.47460938e-01,   1.47460938e-01],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  1.42822266e-02,   1.42517090e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -7.41577148e-02,  -7.41577148e-02],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.69970703e-03,   4.69970703e-03],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -1.39953613e-01,  -1.39953613e-01],
                        [ -2.11364746e-01,  -2.11364746e-01],
                        [ -2.53662109e-01,  -2.53662109e-01],
                        [ -2.52227783e-01,  -2.52227783e-01],
                        [ -2.12585449e-01,  -2.12585449e-01],
                        [ -1.59637451e-01,  -1.59637451e-01],
                        [ -1.17980957e-01,  -1.17980957e-01],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.39099121e-01,   1.39099121e-01],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  7.76672363e-02,   7.76672363e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -2.10388184e-01,  -2.10388184e-01],
                        [ -2.51708984e-01,  -2.51739502e-01],
                        [ -2.32940674e-01,  -2.32940674e-01],
                        [ -1.70104980e-01,  -1.70104980e-01],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  7.30590820e-02,   7.30590820e-02],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.41906738e-01,   1.41906738e-01],
                        [  1.62689209e-01,   1.62689209e-01],
                        [  1.64245605e-01,   1.64245605e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.36535645e-01,   1.36566162e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  9.86328125e-02,   9.86022949e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  1.48559570e-01,   1.48559570e-01],
                        [  1.80480957e-01,   1.80480957e-01],
                        [  1.77886963e-01,   1.77886963e-01],
                        [  1.48956299e-01,   1.48956299e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  3.05175781e-04,   2.74658203e-04],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -2.38037109e-02,  -2.38342285e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.30603027e-02,  -4.30297852e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -6.53686523e-02,  -6.53686523e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.40258789e-02,  -6.39953613e-02],
                        [ -6.36901855e-02,  -6.37207031e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  7.01904297e-03,   7.01904297e-03],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -1.07696533e-01,  -1.07696533e-01],
                        [ -1.75201416e-01,  -1.75201416e-01],
                        [ -2.16522217e-01,  -2.16522217e-01],
                        [ -2.14294434e-01,  -2.14294434e-01],
                        [ -1.79656982e-01,  -1.79656982e-01],
                        [ -1.41174316e-01,  -1.41174316e-01],
                        [ -1.17919922e-01,  -1.17919922e-01],
                        [ -1.08123779e-01,  -1.08123779e-01],
                        [ -1.00250244e-01,  -1.00250244e-01],
                        [ -8.72497559e-02,  -8.72497559e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -5.00488281e-02,  -5.00793457e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  7.89184570e-02,   7.88879395e-02],
                        [  1.12060547e-01,   1.12060547e-01],
                        [  1.34735107e-01,   1.34735107e-01],
                        [  1.43310547e-01,   1.43310547e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [ -8.03222656e-02,  -8.03222656e-02],
                        [ -1.66961670e-01,  -1.66961670e-01],
                        [ -2.15240479e-01,  -2.15270996e-01],
                        [ -2.14172363e-01,  -2.14172363e-01],
                        [ -1.73126221e-01,  -1.73126221e-01],
                        [ -1.18621826e-01,  -1.18621826e-01],
                        [ -7.89184570e-02,  -7.89184570e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  5.79833984e-03,   5.76782227e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  7.96508789e-02,   7.96203613e-02],
                        [  1.16546631e-01,   1.16546631e-01],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.52526855e-01,   1.52526855e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.25183105e-01,   1.25152588e-01],
                        [  1.25671387e-01,   1.25671387e-01],
                        [  1.24572754e-01,   1.24572754e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  9.98229980e-02,   9.98229980e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  4.80651855e-02,   4.80346680e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [ -1.12304688e-02,  -1.11999512e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.47888184e-01,   1.47888184e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  6.20117188e-02,   6.20117188e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -2.58483887e-02,  -2.58178711e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  4.17785645e-02,   4.17480469e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  7.06481934e-02,   7.06176758e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -1.30889893e-01,  -1.30889893e-01],
                        [ -2.07427979e-01,  -2.07427979e-01],
                        [ -2.50152588e-01,  -2.50152588e-01],
                        [ -2.46795654e-01,  -2.46795654e-01],
                        [ -2.08526611e-01,  -2.08526611e-01],
                        [ -1.59729004e-01,  -1.59729004e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -1.00189209e-01,  -1.00189209e-01],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -7.42492676e-02,  -7.42187500e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -1.64733887e-01,  -1.64703369e-01],
                        [ -2.15270996e-01,  -2.15240479e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -1.78436279e-01,  -1.78466797e-01],
                        [ -1.22619629e-01,  -1.22650146e-01],
                        [ -7.44323730e-02,  -7.44628906e-02],
                        [ -4.58984375e-02,  -4.59289551e-02],
                        [ -3.01513672e-02,  -3.01208496e-02],
                        [ -1.66320801e-02,  -1.66015625e-02],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [ -6.71386719e-04,  -6.40869141e-04],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  2.18811035e-02,   2.18505859e-02],
                        [  4.68139648e-02,   4.67529297e-02],
                        [  6.00585938e-02,   6.00280762e-02],
                        [  5.15136719e-02,   5.14831543e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  6.43920898e-03,   6.46972656e-03],
                        [ -7.78198242e-03,  -7.75146484e-03],
                        [ -1.20849609e-02,  -1.20544434e-02],
                        [ -1.19018555e-03,  -1.15966797e-03],
                        [  2.98156738e-02,   2.98461914e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  1.25488281e-01,   1.25457764e-01],
                        [  1.63940430e-01,   1.63879395e-01],
                        [  1.81945801e-01,   1.81884766e-01],
                        [  1.78100586e-01,   1.78070068e-01],
                        [  1.60552979e-01,   1.60522461e-01],
                        [  1.42120361e-01,   1.42150879e-01],
                        [  1.30554199e-01,   1.30615234e-01],
                        [  1.22131348e-01,   1.22192383e-01],
                        [  1.09130859e-01,   1.09191895e-01],
                        [  9.32312012e-02,   9.32617188e-02],
                        [  8.32824707e-02,   8.33129883e-02],
                        [  8.05358887e-02,   8.05053711e-02],
                        [  7.48596191e-02,   7.47985840e-02],
                        [  5.80444336e-02,   5.79528809e-02],
                        [  3.35083008e-02,   3.34167480e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -1.01318359e-02,  -1.00708008e-02],
                        [ -2.32238770e-02,  -2.30712891e-02],
                        [ -2.53295898e-02,  -2.52075195e-02],
                        [ -1.23901367e-02,  -1.22985840e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  6.29577637e-02,   6.28662109e-02],
                        [  1.11267090e-01,   1.11114502e-01],
                        [  1.43707275e-01,   1.43585205e-01],
                        [  1.47888184e-01,   1.47827148e-01],
                        [  1.27593994e-01,   1.27624512e-01],
                        [  9.79919434e-02,   9.81140137e-02],
                        [  7.11669922e-02,   7.12890625e-02],
                        [  4.82788086e-02,   4.83703613e-02],
                        [  2.72827148e-02,   2.73132324e-02],
                        [  1.20849609e-02,   1.20239258e-02],
                        [  7.90405273e-03,   7.84301758e-03],
                        [  1.26647949e-02,   1.26037598e-02],
                        [  1.91955566e-02,   1.91345215e-02],
                        [  2.31018066e-02,   2.30407715e-02],
                        [  2.15759277e-02,   2.15148926e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -6.98852539e-03,  -6.95800781e-03],
                        [ -2.23999023e-02,  -2.23083496e-02],
                        [ -2.77709961e-02,  -2.76489258e-02],
                        [ -2.41088867e-02,  -2.40173340e-02],
                        [ -1.75781250e-02,  -1.75170898e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.56860352e-02,  -1.57470703e-02],
                        [ -1.84631348e-02,  -1.86462402e-02],
                        [ -2.05078125e-02,  -2.07519531e-02],
                        [ -2.47192383e-02,  -2.48718262e-02],
                        [ -3.43933105e-02,  -3.43322754e-02],
                        [ -4.80651855e-02,  -4.78210449e-02],
                        [ -5.99060059e-02,  -5.96008301e-02],
                        [ -6.46972656e-02,  -6.45141602e-02],
                        [ -6.28662109e-02,  -6.28356934e-02],
                        [ -5.98754883e-02,  -5.99975586e-02],
                        [ -5.99060059e-02,  -6.00891113e-02],
                        [ -6.08215332e-02,  -6.10046387e-02],
                        [ -5.82580566e-02,  -5.83801270e-02],
                        [ -5.23986816e-02,  -5.24291992e-02],
                        [ -4.71191406e-02,  -4.70886230e-02],
                        [ -4.39758301e-02,  -4.38842773e-02],
                        [ -4.01916504e-02,  -4.00390625e-02],
                        [ -3.16467285e-02,  -3.14636230e-02],
                        [ -1.74560547e-02,  -1.73034668e-02],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  1.43432617e-02,   1.42517090e-02],
                        [  2.83508301e-02,   2.81677246e-02],
                        [  4.14123535e-02,   4.12292480e-02],
                        [  5.13305664e-02,   5.11474609e-02],
                        [  5.24597168e-02,   5.23071289e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [ -5.76782227e-03,  -5.55419922e-03],
                        [ -7.10754395e-02,  -7.07092285e-02],
                        [ -1.44744873e-01,  -1.44378662e-01],
                        [ -2.04254150e-01,  -2.04101562e-01],
                        [ -2.30316162e-01,  -2.30438232e-01],
                        [ -2.16888428e-01,  -2.17224121e-01],
                        [ -1.77490234e-01,  -1.77825928e-01],
                        [ -1.36718750e-01,  -1.36901855e-01],
                        [ -1.10626221e-01,  -1.10626221e-01],
                        [ -9.75646973e-02,  -9.75036621e-02],
                        [ -8.68225098e-02,  -8.67004395e-02],
                        [ -7.05566406e-02,  -7.04345703e-02],
                        [ -4.94995117e-02,  -4.93469238e-02],
                        [ -2.94189453e-02,  -2.92358398e-02],
                        [ -1.35498047e-02,  -1.33666992e-02],
                        [  1.31225586e-03,   1.37329102e-03],
                        [  2.01721191e-02,   2.00805664e-02],
                        [  4.44030762e-02,   4.41589355e-02],
                        [  7.16857910e-02,   7.13500977e-02],
                        [  9.90905762e-02,   9.87548828e-02],
                        [  1.22772217e-01,   1.22558594e-01],
                        [  1.35833740e-01,   1.35864258e-01],
                        [  1.27227783e-01,   1.27532959e-01],
                        [  8.34655762e-02,   8.39843750e-02],
                        [ -8.23974609e-04,  -3.35693359e-04],
                        [ -1.07482910e-01,  -1.07208252e-01],
                        [ -1.97021484e-01,  -1.97082520e-01],
                        [ -2.34527588e-01,  -2.34893799e-01],
                        [ -2.12738037e-01,  -2.13226318e-01],
                        [ -1.53442383e-01,  -1.53930664e-01],
                        [ -9.05761719e-02,  -9.09118652e-02],
                        [ -4.88281250e-02,  -4.88891602e-02],
                        [ -3.26843262e-02,  -3.24707031e-02],
                        [ -3.01818848e-02,  -2.96936035e-02],
                        [ -2.60009766e-02,  -2.54516602e-02],
                        [ -1.49841309e-02,  -1.45568848e-02],
                        [ -3.90625000e-03,  -3.75366211e-03],
                        [  6.40869141e-04,   5.18798828e-04],
                        [  2.68554688e-03,   2.31933594e-03],
                        [  1.05895996e-02,   1.01013184e-02],
                        [  2.45971680e-02,   2.40783691e-02],
                        [  3.74450684e-02,   3.71093750e-02],
                        [  4.51049805e-02,   4.51354980e-02],
                        [  4.74853516e-02,   4.78515625e-02],
                        [  4.25415039e-02,   4.31213379e-02],
                        [  2.94189453e-02,   2.99072266e-02],
                        [  1.37939453e-02,   1.40075684e-02],
                        [  4.24194336e-03,   4.08935547e-03],
                        [  5.88989258e-03,   5.52368164e-03],
                        [  1.94396973e-02,   1.91040039e-02],
                        [  4.42810059e-02,   4.41589355e-02],
                        [  7.99560547e-02,   8.00170898e-02],
                        [  1.21185303e-01,   1.21246338e-01],
                        [  1.54083252e-01,   1.54022217e-01],
                        [  1.65679932e-01,   1.65527344e-01],
                        [  1.58142090e-01,   1.58050537e-01],
                        [  1.46636963e-01,   1.46820068e-01],
                        [  1.41418457e-01,   1.41876221e-01],
                        [  1.39068604e-01,   1.39587402e-01],
                        [  1.32202148e-01,   1.32415771e-01],
                        [  1.19598389e-01,   1.19323730e-01],
                        [  1.03546143e-01,   1.02874756e-01],
                        [  8.52355957e-02,   8.45031738e-02],
                        [  6.53686523e-02,   6.49108887e-02],
                        [  4.49218750e-02,   4.49829102e-02],
                        [  2.40783691e-02,   2.46887207e-02],
                        [  2.04467773e-03,   2.96020508e-03],
                        [ -1.99584961e-02,  -1.91345215e-02],
                        [ -3.60717773e-02,  -3.57971191e-02],
                        [ -3.90625000e-02,  -3.95507812e-02],
                        [ -2.46582031e-02,  -2.56652832e-02],
                        [  7.69042969e-03,   6.74438477e-03],
                        [  5.23681641e-02,   5.19409180e-02],
                        [  9.57336426e-02,   9.60083008e-02],
                        [  1.23352051e-01,   1.24023438e-01],
                        [  1.29425049e-01,   1.30065918e-01],
                        [  1.18133545e-01,   1.18469238e-01],
                        [  9.81445312e-02,   9.82055664e-02],
                        [  7.70568848e-02,   7.69958496e-02],
                        [  5.80749512e-02,   5.80139160e-02],
                        [  4.04663086e-02,   4.04052734e-02],
                        [  2.37731934e-02,   2.35900879e-02],
                        [  1.02844238e-02,   9.88769531e-03],
                        [  2.38037109e-03,   1.92260742e-03],
                        [ -1.83105469e-04,  -4.88281250e-04],
                        [  1.03759766e-03,   1.12915039e-03],
                        [  3.72314453e-03,   4.24194336e-03],
                        [  5.12695312e-03,   5.82885742e-03],
                        [  4.18090820e-03,   4.73022461e-03],
                        [  1.00708008e-03,   1.06811523e-03],
                        [ -6.07299805e-03,  -6.56127930e-03],
                        [ -1.83715820e-02,  -1.91040039e-02],
                        [ -3.27758789e-02,  -3.32946777e-02],
                        [ -4.26940918e-02,  -4.27551270e-02],
                        [ -4.38232422e-02,  -4.35180664e-02],
                        [ -3.84216309e-02,  -3.80554199e-02],
                        [ -3.28979492e-02,  -3.27453613e-02],
                        [ -3.16772461e-02,  -3.17077637e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -4.19921875e-02,  -4.18395996e-02],
                        [ -4.91943359e-02,  -4.89196777e-02],
                        [ -5.25817871e-02,  -5.24597168e-02],
                        [ -5.16052246e-02,  -5.17578125e-02],
                        [ -5.08117676e-02,  -5.13000488e-02],
                        [ -5.34057617e-02,  -5.40771484e-02],
                        [ -5.66406250e-02,  -5.72509766e-02],
                        [ -5.77392578e-02,  -5.79223633e-02],
                        [ -5.85937500e-02,  -5.80749512e-02],
                        [ -6.09130859e-02,  -5.97839355e-02],
                        [ -6.24389648e-02,  -6.11572266e-02],
                        [ -5.99365234e-02,  -5.91735840e-02],
                        [ -5.14831543e-02,  -5.17578125e-02],
                        [ -3.57055664e-02,  -3.69873047e-02],
                        [ -1.24816895e-02,  -1.41296387e-02],
                        [  1.52893066e-02,   1.42211914e-02],
                        [  4.13208008e-02,   4.13818359e-02],
                        [  5.90515137e-02,   6.00280762e-02],
                        [  6.57043457e-02,   6.68945312e-02],
                        [  6.02416992e-02,   6.10046387e-02],
                        [  3.68041992e-02,   3.69567871e-02],
                        [ -1.19018555e-02,  -1.21154785e-02],
                        [ -8.21533203e-02,  -8.24584961e-02],
                        [ -1.55639648e-01,  -1.55914307e-01],
                        [ -2.09594727e-01,  -2.09808350e-01],
                        [ -2.27508545e-01,  -2.27722168e-01],
                        [ -2.07641602e-01,  -2.07855225e-01],
                        [ -1.67236328e-01,  -1.67419434e-01],
                        [ -1.31378174e-01,  -1.31408691e-01],
                        [ -1.11785889e-01,  -1.11663818e-01],
                        [ -1.00891113e-01,  -1.00646973e-01],
                        [ -8.68835449e-02,  -8.65173340e-02],
                        [ -6.77185059e-02,  -6.73217773e-02],
                        [ -4.91943359e-02,  -4.89501953e-02],
                        [ -3.53088379e-02,  -3.54003906e-02],
                        [ -2.50549316e-02,  -2.54821777e-02],
                        [ -1.45874023e-02,  -1.51367188e-02],
                        [  8.85009766e-04,   5.79833984e-04],
                        [  2.49328613e-02,   2.50244141e-02],
                        [  5.73730469e-02,   5.77087402e-02],
                        [  9.39941406e-02,   9.42687988e-02],
                        [  1.26403809e-01,   1.26403809e-01],
                        [  1.44042969e-01,   1.43859863e-01],
                        [  1.37573242e-01,   1.37451172e-01],
                        [  9.82666016e-02,   9.83581543e-02],
                        [  2.13928223e-02,   2.16369629e-02],
                        [ -8.17871094e-02,  -8.15734863e-02],
                        [ -1.78680420e-01,  -1.78619385e-01],
                        [ -2.31018066e-01,  -2.31170654e-01],
                        [ -2.22351074e-01,  -2.22656250e-01],
                        [ -1.71600342e-01,  -1.71936035e-01],
                        [ -1.14044189e-01,  -1.14227295e-01],
                        [ -7.14721680e-02,  -7.13500977e-02],
                        [ -4.49523926e-02,  -4.44946289e-02],
                        [ -2.67333984e-02,  -2.61535645e-02],
                        [ -1.04064941e-02,  -1.01623535e-02],
                        [  3.47900391e-03,   3.11279297e-03],
                        [  9.06372070e-03,   8.17871094e-03],
                        [  5.55419922e-03,   4.76074219e-03],
                        [  3.60107422e-03,   3.54003906e-03],
                        [  1.41296387e-02,   1.50146484e-02],
                        [  3.31726074e-02,   3.44238281e-02],
                        [  4.66308594e-02,   4.74548340e-02],
                        [  4.85534668e-02,   4.84619141e-02],
                        [  4.40368652e-02,   4.30908203e-02],
                        [  3.71704102e-02,   3.59191895e-02],
                        [  2.73742676e-02,   2.64892578e-02],
                        [  1.47399902e-02,   1.44348145e-02],
                        [  2.34985352e-03,   2.68554688e-03],
                        [ -2.59399414e-03,  -1.73950195e-03],
                        [  8.33129883e-03,   9.39941406e-03],
                        [  3.73535156e-02,   3.82995605e-02],
                        [  7.75756836e-02,   7.79724121e-02],
                        [  1.17401123e-01,   1.16943359e-01],
                        [  1.45629883e-01,   1.44561768e-01],
                        [  1.56768799e-01,   1.55670166e-01],
                        [  1.54663086e-01,   1.54144287e-01],
                        [  1.49658203e-01,   1.49902344e-01],
                        [  1.49261475e-01,   1.49932861e-01],
                        [  1.51916504e-01,   1.52374268e-01],
                        [  1.49871826e-01,   1.49902344e-01],
                        [  1.37908936e-01,   1.37664795e-01],
                        [  1.17767334e-01,   1.17736816e-01],
                        [  9.52453613e-02,   9.56726074e-02],
                        [  7.46154785e-02,   7.52258301e-02],
                        [  5.63049316e-02,   5.65490723e-02],
                        [  3.77502441e-02,   3.74145508e-02],
                        [  1.62353516e-02,   1.55334473e-02],
                        [ -7.47680664e-03,  -8.08715820e-03],
                        [ -2.82287598e-02,  -2.85644531e-02],
                        [ -4.00695801e-02,  -4.02526855e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -2.34375000e-02,  -2.30102539e-02],
                        [  1.13220215e-02,   1.23596191e-02],
                        [  6.20422363e-02,   6.33239746e-02],
                        [  1.13250732e-01,   1.13922119e-01],
                        [  1.44012451e-01,   1.43402100e-01],
                        [  1.44042969e-01,   1.42333984e-01],
                        [  1.19720459e-01,   1.17950439e-01],
                        [  8.63037109e-02,   8.55712891e-02],
                        [  5.74035645e-02,   5.79833984e-02],
                        [  3.94897461e-02,   4.08020020e-02],
                        [  3.25927734e-02,   3.38134766e-02],
                        [  3.32336426e-02,   3.39355469e-02],
                        [  3.65905762e-02,   3.68652344e-02],
                        [  3.87878418e-02,   3.87573242e-02],
                        [  3.71398926e-02,   3.68041992e-02],
                        [  2.86560059e-02,   2.79541016e-02],
                        [  1.16882324e-02,   1.07421875e-02],
                        [ -1.10778809e-02,  -1.19323730e-02],
                        [ -3.40270996e-02,  -3.44543457e-02],
                        [ -5.13305664e-02,  -5.12390137e-02],
                        [ -5.91125488e-02,  -5.85937500e-02],
                        [ -5.78613281e-02,  -5.70373535e-02],
                        [ -5.02014160e-02,  -4.91943359e-02],
                        [ -3.75671387e-02,  -3.66821289e-02],
                        [ -2.39562988e-02,  -2.35290527e-02],
                        [ -1.76391602e-02,  -1.79443359e-02],
                        [ -2.27661133e-02,  -2.36816406e-02],
                        [ -3.26843262e-02,  -3.37524414e-02],
                        [ -3.86047363e-02,  -3.93981934e-02],
                        [ -4.09851074e-02,  -4.12902832e-02],
                        [ -4.48303223e-02,  -4.47387695e-02],
                        [ -4.87060547e-02,  -4.83703613e-02],
                        [ -4.85839844e-02,  -4.81872559e-02],
                        [ -4.70275879e-02,  -4.65698242e-02],
                        [ -4.89807129e-02,  -4.84008789e-02],
                        [ -5.37109375e-02,  -5.30700684e-02],
                        [ -5.69458008e-02,  -5.65185547e-02],
                        [ -5.73120117e-02,  -5.74035645e-02],
                        [ -5.63049316e-02,  -5.70068359e-02],
                        [ -5.46569824e-02,  -5.56945801e-02],
                        [ -5.12695312e-02,  -5.22766113e-02],
                        [ -4.40368652e-02,  -4.45861816e-02],
                        [ -2.85339355e-02,  -2.83508301e-02],
                        [ -7.62939453e-04,   1.22070312e-04],
                        [  3.52478027e-02,   3.65905762e-02],
                        [  6.70166016e-02,   6.81457520e-02],
                        [  8.27941895e-02,   8.30993652e-02],
                        [  7.68127441e-02,   7.60803223e-02],
                        [  4.39758301e-02,   4.26330566e-02],
                        [ -2.01110840e-02,  -2.13623047e-02],
                        [ -1.06414795e-01,  -1.06994629e-01],
                        [ -1.87683105e-01,  -1.87438965e-01],
                        [ -2.35321045e-01,  -2.34466553e-01],
                        [ -2.38861084e-01,  -2.37670898e-01],
                        [ -2.08892822e-01,  -2.07824707e-01],
                        [ -1.67541504e-01,  -1.66961670e-01],
                        [ -1.33880615e-01,  -1.34063721e-01],
                        [ -1.13037109e-01,  -1.14013672e-01],
                        [ -9.73205566e-02,  -9.87243652e-02],
                        [ -7.87963867e-02,  -8.00476074e-02],
                        [ -5.94177246e-02,  -6.00280762e-02],
                        [ -4.60815430e-02,  -4.57763672e-02],
                        [ -3.84826660e-02,  -3.75061035e-02],
                        [ -2.90527344e-02,  -2.77709961e-02],
                        [ -1.19934082e-02,  -1.07421875e-02],
                        [  1.43432617e-02,   1.51367188e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  8.70361328e-02,   8.61206055e-02],
                        [  1.19537354e-01,   1.18133545e-01],
                        [  1.40441895e-01,   1.39190674e-01],
                        [  1.46850586e-01,   1.46301270e-01],
                        [  1.33056641e-01,   1.33209229e-01],
                        [  8.85620117e-02,   8.90197754e-02],
                        [  8.85009766e-03,   9.21630859e-03],
                        [ -9.06982422e-02,  -9.03625488e-02],
                        [ -1.77062988e-01,  -1.76361084e-01],
                        [ -2.19543457e-01,  -2.18353271e-01],
                        [ -2.09625244e-01,  -2.08465576e-01],
                        [ -1.64642334e-01,  -1.64459229e-01],
                        [ -1.13586426e-01,  -1.14685059e-01],
                        [ -7.65686035e-02,  -7.84912109e-02],
                        [ -5.53588867e-02,  -5.71289062e-02],
                        [ -3.91540527e-02,  -4.01306152e-02],
                        [ -1.89208984e-02,  -1.89514160e-02],
                        [  2.68554688e-03,   3.47900391e-03],
                        [  1.60827637e-02,   1.75781250e-02],
                        [  1.85852051e-02,   2.05078125e-02],
                        [  1.85546875e-02,   2.03247070e-02],
                        [  2.40783691e-02,   2.49938965e-02],
                        [  3.28674316e-02,   3.23486328e-02],
                        [  3.69567871e-02,   3.50646973e-02],
                        [  3.32641602e-02,   3.08837891e-02],
                        [  2.52380371e-02,   2.34985352e-02],
                        [  1.66625977e-02,   1.61743164e-02],
                        [  7.69042969e-03,   8.27026367e-03],
                        [ -2.07519531e-03,  -1.03759766e-03],
                        [ -9.18579102e-03,  -8.02612305e-03],
                        [ -6.77490234e-03,  -5.49316406e-03],
                        [  1.07727051e-02,   1.21459961e-02],
                        [  4.47692871e-02,   4.57153320e-02],
                        [  9.04846191e-02,   9.03320312e-02],
                        [  1.37298584e-01,   1.35772705e-01],
                        [  1.72210693e-01,   1.69952393e-01],
                        [  1.86096191e-01,   1.84204102e-01],
                        [  1.78985596e-01,   1.78436279e-01],
                        [  1.61071777e-01,   1.62170410e-01],
                        [  1.45141602e-01,   1.47125244e-01],
                        [  1.35559082e-01,   1.37207031e-01],
                        [  1.27105713e-01,   1.27502441e-01],
                        [  1.13983154e-01,   1.13250732e-01],
                        [  9.67712402e-02,   9.57946777e-02],
                        [  8.03222656e-02,   7.98339844e-02],
                        [  6.75659180e-02,   6.75964355e-02],
                        [  5.63659668e-02,   5.64880371e-02],
                        [  4.06799316e-02,   4.05883789e-02],
                        [  1.66320801e-02,   1.65100098e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -3.12500000e-02,  -3.11889648e-02],
                        [ -4.06494141e-02,  -4.06799316e-02],
                        [ -3.88793945e-02,  -3.87573242e-02],
                        [ -2.34680176e-02,  -2.27355957e-02],
                        [  8.02612305e-03,   9.24682617e-03],
                        [  5.13305664e-02,   5.20629883e-02],
                        [  9.61914062e-02,   9.52758789e-02],
                        [  1.30554199e-01,   1.28021240e-01],
                        [  1.43676758e-01,   1.41021729e-01],
                        [  1.31744385e-01,   1.30889893e-01],
                        [  1.02996826e-01,   1.04797363e-01],
                        [  7.36694336e-02,   7.71484375e-02],
                        [  5.49011230e-02,   5.79833984e-02],
                        [  4.55932617e-02,   4.65393066e-02],
                        [  3.73229980e-02,   3.57666016e-02],
                        [  2.49633789e-02,   2.20947266e-02],
                        [  1.21459961e-02,   9.73510742e-03],
                        [  4.97436523e-03,   4.11987305e-03],
                        [  2.74658203e-03,   3.41796875e-03],
                        [ -1.09863281e-03,   3.05175781e-04],
                        [ -1.01623535e-02,  -8.94165039e-03],
                        [ -2.14233398e-02,  -2.08129883e-02],
                        [ -2.97851562e-02,  -2.99682617e-02],
                        [ -3.39660645e-02,  -3.47595215e-02],
                        [ -3.56140137e-02,  -3.64685059e-02],
                        [ -3.48205566e-02,  -3.49426270e-02],
                        [ -3.13720703e-02,  -3.04260254e-02],
                        [ -2.92053223e-02,  -2.76794434e-02],
                        [ -3.28063965e-02,  -3.19824219e-02],
                        [ -4.03442383e-02,  -4.11376953e-02],
                        [ -4.43420410e-02,  -4.62951660e-02],
                        [ -4.08935547e-02,  -4.24804688e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [ -3.25012207e-02,  -3.12194824e-02],
                        [ -3.66210938e-02,  -3.54003906e-02],
                        [ -4.44641113e-02,  -4.43420410e-02],
                        [ -5.20935059e-02,  -5.27038574e-02],
                        [ -5.68847656e-02,  -5.72814941e-02],
                        [ -5.88378906e-02,  -5.85327148e-02],
                        [ -5.71594238e-02,  -5.66406250e-02],
                        [ -5.03845215e-02,  -5.02929688e-02],
                        [ -4.14428711e-02,  -4.18090820e-02],
                        [ -3.58276367e-02,  -3.61022949e-02],
                        [ -3.35083008e-02,  -3.33251953e-02],
                        [ -2.79235840e-02,  -2.75268555e-02],
                        [ -1.30310059e-02,  -1.29394531e-02],
                        [  1.13830566e-02,   1.11083984e-02],
                        [  4.01611328e-02,   3.97644043e-02],
                        [  6.44226074e-02,   6.41784668e-02],
                        [  7.22961426e-02,   7.20214844e-02],
                        [  5.15136719e-02,   5.10864258e-02],
                        [ -3.78417969e-03,  -4.15039062e-03],
                        [ -8.71887207e-02,  -8.70056152e-02],
                        [ -1.78131104e-01,  -1.77124023e-01],
                        [ -2.46582031e-01,  -2.45117188e-01],
                        [ -2.68035889e-01,  -2.66937256e-01],
                        [ -2.39868164e-01,  -2.39807129e-01],
                        [ -1.84478760e-01,  -1.85455322e-01],
                        [ -1.33087158e-01,  -1.34613037e-01],
                        [ -1.02233887e-01,  -1.03576660e-01],
                        [ -8.51440430e-02,  -8.56628418e-02],
                        [ -6.78710938e-02,  -6.74743652e-02],
                        [ -4.83398438e-02,  -4.74853516e-02],
                        [ -3.45458984e-02,  -3.38134766e-02],
                        [ -3.05786133e-02,  -3.03955078e-02],
                        [ -3.10058594e-02,  -3.11584473e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -7.47680664e-03,  -7.04956055e-03],
                        [  2.32238770e-02,   2.38952637e-02],
                        [  5.95703125e-02,   5.99365234e-02],
                        [  9.36584473e-02,   9.33837891e-02],
                        [  1.21307373e-01,   1.20513916e-01],
                        [  1.40258789e-01,   1.39404297e-01],
                        [  1.45477295e-01,   1.44866943e-01],
                        [  1.28448486e-01,   1.28021240e-01],
                        [  8.05969238e-02,   8.02612305e-02],
                        [ -1.25122070e-03,  -1.28173828e-03],
                        [ -1.03912354e-01,  -1.03118896e-01],
                        [ -1.91986084e-01,  -1.90307617e-01],
                        [ -2.27905273e-01,  -2.26104736e-01],
                        [ -2.03979492e-01,  -2.03186035e-01],
                        [ -1.46911621e-01,  -1.47705078e-01],
                        [ -9.05761719e-02,  -9.23767090e-02],
                        [ -5.16662598e-02,  -5.33447266e-02],
                        [ -2.83203125e-02,  -2.91137695e-02],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [  1.83105469e-04,   5.18798828e-04],
                        [  7.56835938e-03,   7.99560547e-03],
                        [  7.04956055e-03,   7.65991211e-03],
                        [  5.79833984e-04,   1.46484375e-03],
                        [ -4.63867188e-03,  -3.78417969e-03],
                        [ -2.16674805e-03,  -1.89208984e-03],
                        [  7.56835938e-03,   7.17163086e-03],
                        [  1.83105469e-02,   1.76086426e-02],
                        [  2.44445801e-02,   2.39868164e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.82897949e-02,   2.84423828e-02],
                        [  2.77709961e-02,   2.75573730e-02],
                        [  2.12402344e-02,   2.04772949e-02],
                        [  1.37023926e-02,   1.27258301e-02],
                        [  1.61437988e-02,   1.57165527e-02],
                        [  3.34167480e-02,   3.40270996e-02],
                        [  6.30798340e-02,   6.45446777e-02],
                        [  1.01531982e-01,   1.03240967e-01],
                        [  1.43218994e-01,   1.44317627e-01],
                        [  1.76788330e-01,   1.76696777e-01],
                        [  1.90765381e-01,   1.89514160e-01],
                        [  1.83288574e-01,   1.81610107e-01],
                        [  1.62811279e-01,   1.61651611e-01],
                        [  1.39953613e-01,   1.39770508e-01],
                        [  1.20880127e-01,   1.21337891e-01],
                        [  1.06262207e-01,   1.06781006e-01],
                        [  9.40246582e-02,   9.42993164e-02],
                        [  8.43200684e-02,   8.46252441e-02],
                        [  7.95288086e-02,   7.99865723e-02],
                        [  7.84301758e-02,   7.87353516e-02],
                        [  7.47375488e-02,   7.45849609e-02],
                        [  6.14318848e-02,   6.09741211e-02],
                        [  3.69873047e-02,   3.67736816e-02],
                        [  7.84301758e-03,   8.17871094e-03],
                        [ -1.78527832e-02,  -1.74255371e-02],
                        [ -3.71093750e-02,  -3.72314453e-02],
                        [ -4.64477539e-02,  -4.70886230e-02],
                        [ -3.72924805e-02,  -3.76892090e-02],
                        [ -5.12695312e-03,  -4.63867188e-03],
                        [  4.22058105e-02,   4.29687500e-02],
                        [  8.98132324e-02,   8.96301270e-02],
                        [  1.25427246e-01,   1.23901367e-01],
                        [  1.41235352e-01,   1.39617920e-01],
                        [  1.32843018e-01,   1.32873535e-01],
                        [  1.03729248e-01,   1.05773926e-01],
                        [  6.83593750e-02,   7.08618164e-02],
                        [  4.23583984e-02,   4.33654785e-02],
                        [  3.02429199e-02,   2.91748047e-02],
                        [  2.58483887e-02,   2.38647461e-02],
                        [  2.32543945e-02,   2.20031738e-02],
                        [  2.28576660e-02,   2.30407715e-02],
                        [  2.58178711e-02,   2.69470215e-02],
                        [  2.72827148e-02,   2.83203125e-02],
                        [  2.09350586e-02,   2.11791992e-02],
                        [  7.14111328e-03,   6.34765625e-03],
                        [ -1.01928711e-02,  -1.18713379e-02],
                        [ -2.81066895e-02,  -2.99682617e-02],
                        [ -4.13513184e-02,  -4.22363281e-02],
                        [ -4.43115234e-02,  -4.31518555e-02],
                        [ -3.98864746e-02,  -3.65905762e-02],
                        [ -3.70788574e-02,  -3.31726074e-02],
                        [ -3.82080078e-02,  -3.60717773e-02],
                        [ -3.79638672e-02,  -3.92761230e-02],
                        [ -3.50341797e-02,  -3.93371582e-02],
                        [ -3.45458984e-02,  -3.93981934e-02],
                        [ -3.87878418e-02,  -4.13208008e-02],
                        [ -4.34570312e-02,  -4.22363281e-02],
                        [ -4.34570312e-02,  -3.96728516e-02],
                        [ -3.86962891e-02,  -3.50646973e-02],
                        [ -3.37829590e-02,  -3.24707031e-02],
                        [ -3.35998535e-02,  -3.46069336e-02],
                        [ -3.80554199e-02,  -3.98254395e-02],
                        [ -4.25415039e-02,  -4.36096191e-02],
                        [ -4.43115234e-02,  -4.45251465e-02],
                        [ -4.46166992e-02,  -4.45861816e-02],
                        [ -4.39453125e-02,  -4.40368652e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.13110352e-02,  -3.10974121e-02],
                        [ -1.74865723e-02,  -1.73339844e-02],
                        [  9.76562500e-04,   7.93457031e-04],
                        [  2.19421387e-02,   2.18505859e-02],
                        [  4.06188965e-02,   4.13513184e-02],
                        [  5.05065918e-02,   5.20019531e-02],
                        [  4.45556641e-02,   4.57153320e-02],
                        [  1.66320801e-02,   1.60522461e-02],
                        [ -3.63464355e-02,  -3.88793945e-02],
                        [ -1.09802246e-01,  -1.12915039e-01],
                        [ -1.85943604e-01,  -1.87652588e-01],
                        [ -2.36877441e-01,  -2.36022949e-01],
                        [ -2.41821289e-01,  -2.38800049e-01],
                        [ -2.06054688e-01,  -2.02423096e-01],
                        [ -1.58050537e-01,  -1.55578613e-01],
                        [ -1.23748779e-01,  -1.23443604e-01],
                        [ -1.06231689e-01,  -1.07788086e-01],
                        [ -9.35058594e-02,  -9.57641602e-02],
                        [ -7.94067383e-02,  -8.15124512e-02],
                        [ -6.83593750e-02,  -7.02514648e-02],
                        [ -6.36291504e-02,  -6.53381348e-02],
                        [ -5.92346191e-02,  -6.02111816e-02],
                        [ -4.52880859e-02,  -4.44641113e-02],
                        [ -1.77307129e-02,  -1.47705078e-02],
                        [  1.85546875e-02,   2.26135254e-02],
                        [  5.55419922e-02,   5.87768555e-02],
                        [  8.80737305e-02,   8.89892578e-02],
                        [  1.14410400e-01,   1.12854004e-01],
                        [  1.34002686e-01,   1.30920410e-01],
                        [  1.45599365e-01,   1.42272949e-01],
                        [  1.43218994e-01,   1.40625000e-01],
                        [  1.13586426e-01,   1.12213135e-01],
                        [  4.58679199e-02,   4.59594727e-02],
                        [ -5.17883301e-02,  -5.00488281e-02],
                        [ -1.50115967e-01,  -1.46972656e-01],
                        [ -2.15026855e-01,  -2.11608887e-01],
                        [ -2.27020264e-01,  -2.25006104e-01],
                        [ -1.90979004e-01,  -1.91345215e-01],
                        [ -1.32934570e-01,  -1.35009766e-01],
                        [ -8.24584961e-02,  -8.46557617e-02],
                        [ -5.24902344e-02,  -5.37719727e-02],
                        [ -3.48815918e-02,  -3.55224609e-02],
                        [ -1.70593262e-02,  -1.77307129e-02],
                        [  1.89208984e-03,   1.03759766e-03],
                        [  1.26342773e-02,   1.23291016e-02],
                        [  9.88769531e-03,   1.09252930e-02],
                        [  1.09863281e-03,   3.44848633e-03],
                        [ -2.44140625e-04,   2.44140625e-03],
                        [  1.10168457e-02,   1.27258301e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  4.02526855e-02,   3.86962891e-02],
                        [  4.39453125e-02,   4.15039062e-02],
                        [  3.88488770e-02,   3.63159180e-02],
                        [  2.78015137e-02,   2.58789062e-02],
                        [  1.43127441e-02,   1.37329102e-02],
                        [  3.05175781e-04,   1.49536133e-03],
                        [ -1.12915039e-02,  -8.75854492e-03],
                        [ -1.25427246e-02,  -9.70458984e-03],
                        [  5.58471680e-03,   7.53784180e-03],
                        [  4.34875488e-02,   4.38537598e-02],
                        [  9.25292969e-02,   9.13391113e-02],
                        [  1.42639160e-01,   1.40411377e-01],
                        [  1.82983398e-01,   1.80541992e-01],
                        [  2.01080322e-01,   1.99249268e-01],
                        [  1.92169189e-01,   1.91680908e-01],
                        [  1.66839600e-01,   1.68090820e-01],
                        [  1.42150879e-01,   1.44805908e-01],
                        [  1.27075195e-01,   1.29943848e-01],
                        [  1.17645264e-01,   1.19232178e-01],
                        [  1.05224609e-01,   1.04553223e-01],
                        [  8.78295898e-02,   8.53576660e-02],
                        [  7.10449219e-02,   6.81762695e-02],
                        [  5.83801270e-02,   5.64270020e-02],
                        [  4.77905273e-02,   4.74243164e-02],
                        [  3.57666016e-02,   3.69262695e-02],
                        [  1.93481445e-02,   2.15454102e-02],
                        [ -3.17382812e-03,  -8.23974609e-04],
                        [ -2.94189453e-02,  -2.78625488e-02],
                        [ -5.12084961e-02,  -5.09948730e-02],
                        [ -5.92346191e-02,  -6.02111816e-02],
                        [ -5.01403809e-02,  -5.16052246e-02],
                        [ -2.58178711e-02,  -2.71911621e-02],
                        [  1.28479004e-02,   1.17492676e-02],
                        [  6.36901855e-02,   6.27441406e-02],
                        [  1.14440918e-01,   1.13708496e-01],
                        [  1.45477295e-01,   1.45233154e-01],
                        [  1.45599365e-01,   1.46301270e-01],
                        [  1.22589111e-01,   1.24481201e-01],
                        [  9.43908691e-02,   9.70153809e-02],
                        [  7.18383789e-02,   7.40661621e-02],
                        [  5.52978516e-02,   5.60607910e-02],
                        [  4.34570312e-02,   4.24499512e-02],
                        [  3.47595215e-02,   3.25622559e-02],
                        [  2.40478516e-02,   2.15454102e-02],
                        [  8.08715820e-03,   6.01196289e-03],
                        [ -8.48388672e-03,  -9.82666016e-03],
                        [ -1.95312500e-02,  -1.97143555e-02],
                        [ -2.46276855e-02,  -2.34985352e-02],
                        [ -2.67944336e-02,  -2.45971680e-02],
                        [ -2.76184082e-02,  -2.51770020e-02],
                        [ -2.83508301e-02,  -2.65502930e-02],
                        [ -3.07312012e-02,  -2.98767090e-02],
                        [ -3.43627930e-02,  -3.42712402e-02],
                        [ -3.70178223e-02,  -3.77197266e-02],
                        [ -3.79638672e-02,  -3.98864746e-02],
                        [ -3.84216309e-02,  -4.16870117e-02],
                        [ -3.86047363e-02,  -4.20837402e-02],
                        [ -3.67736816e-02,  -3.82995605e-02],
                        [ -3.21044922e-02,  -3.00903320e-02],
                        [ -2.72216797e-02,  -2.23999023e-02],
                        [ -2.58483887e-02,  -2.11486816e-02],
                        [ -2.87780762e-02,  -2.70690918e-02],
                        [ -3.52478027e-02,  -3.70788574e-02],
                        [ -4.51049805e-02,  -4.86450195e-02],
                        [ -5.70678711e-02,  -5.99670410e-02],
                        [ -6.68029785e-02,  -6.80236816e-02],
                        [ -6.98852539e-02,  -6.99157715e-02],
                        [ -6.57043457e-02,  -6.52465820e-02],
                        [ -5.67321777e-02,  -5.57556152e-02],
                        [ -4.46777344e-02,  -4.29077148e-02],
                        [ -2.69165039e-02,  -2.48718262e-02],
                        [  9.15527344e-05,   1.09863281e-03],
                        [  3.38134766e-02,   3.30505371e-02],
                        [  6.45751953e-02,   6.28051758e-02],
                        [  8.12683105e-02,   8.00170898e-02],
                        [  7.68127441e-02,   7.69348145e-02],
                        [  4.89196777e-02,   4.96826172e-02],
                        [ -2.56347656e-03,  -2.59399414e-03],
                        [ -7.50732422e-02,  -7.65686035e-02],
                        [ -1.57165527e-01,  -1.59179688e-01],
                        [ -2.25311279e-01,  -2.26104736e-01],
                        [ -2.54669189e-01,  -2.53051758e-01],
                        [ -2.38433838e-01,  -2.34924316e-01],
                        [ -1.95159912e-01,  -1.91680908e-01],
                        [ -1.51977539e-01,  -1.50512695e-01],
                        [ -1.22161865e-01,  -1.23382568e-01],
                        [ -1.02386475e-01,  -1.05499268e-01],
                        [ -8.57238770e-02,  -8.93249512e-02],
                        [ -7.15942383e-02,  -7.44018555e-02],
                        [ -6.44531250e-02,  -6.55822754e-02],
                        [ -6.35070801e-02,  -6.25305176e-02],
                        [ -5.80139160e-02,  -5.49621582e-02],
                        [ -3.79333496e-02,  -3.37829590e-02],
                        [ -4.39453125e-03,  -1.12915039e-03],
                        [  3.38745117e-02,   3.42712402e-02],
                        [  6.84204102e-02,   6.55212402e-02],
                        [  9.50317383e-02,   9.06066895e-02],
                        [  1.14624023e-01,   1.11541748e-01],
                        [  1.28723145e-01,   1.28875732e-01],
                        [  1.35101318e-01,   1.37908936e-01],
                        [  1.28723145e-01,   1.31866455e-01],
                        [  1.01928711e-01,   1.03271484e-01],
                        [  4.46777344e-02,   4.37622070e-02],
                        [ -4.42810059e-02,  -4.63562012e-02],
                        [ -1.43035889e-01,  -1.44714355e-01],
                        [ -2.11761475e-01,  -2.12249756e-01],
                        [ -2.22137451e-01,  -2.21466064e-01],
                        [ -1.80999756e-01,  -1.79748535e-01],
                        [ -1.22344971e-01,  -1.21154785e-01],
                        [ -7.80334473e-02,  -7.73925781e-02],
                        [ -5.69763184e-02,  -5.71594238e-02],
                        [ -4.62646484e-02,  -4.70886230e-02],
                        [ -3.04260254e-02,  -3.14025879e-02],
                        [ -9.46044922e-03,  -9.85717773e-03],
                        [  6.22558594e-03,   6.68334961e-03],
                        [  1.28173828e-02,   1.34887695e-02],
                        [  1.61743164e-02,   1.61437988e-02],
                        [  2.34680176e-02,   2.23999023e-02],
                        [  3.61938477e-02,   3.48205566e-02],
                        [  4.81262207e-02,   4.77600098e-02],
                        [  5.11779785e-02,   5.24902344e-02],
                        [  4.47387695e-02,   4.69970703e-02],
                        [  3.47900391e-02,   3.65905762e-02],
                        [  2.48718262e-02,   2.52380371e-02],
                        [  1.40686035e-02,   1.29699707e-02],
                        [  2.89916992e-03,   1.15966797e-03],
                        [ -3.69262695e-03,  -5.31005859e-03],
                        [  2.44140625e-04,  -8.85009766e-04],
                        [  1.72729492e-02,   1.67541504e-02],
                        [  4.62646484e-02,   4.64477539e-02],
                        [  8.50524902e-02,   8.58154297e-02],
                        [  1.30187988e-01,   1.31256104e-01],
                        [  1.72271729e-01,   1.73339844e-01],
                        [  1.96319580e-01,   1.97326660e-01],
                        [  1.93756104e-01,   1.94946289e-01],
                        [  1.72241211e-01,   1.73675537e-01],
                        [  1.48376465e-01,   1.49444580e-01],
                        [  1.32446289e-01,   1.31744385e-01],
                        [  1.22497559e-01,   1.18865967e-01],
                        [  1.11511230e-01,   1.05712891e-01],
                        [  9.72290039e-02,   9.24377441e-02],
                        [  8.33740234e-02,   8.31298828e-02],
                        [  7.16857910e-02,   7.69958496e-02],
                        [  5.88989258e-02,   6.71081543e-02],
                        [  4.25415039e-02,   4.90417480e-02],
                        [  2.39868164e-02,   2.54516602e-02],
                        [  4.85229492e-03,   9.76562500e-04],
                        [ -1.53808594e-02,  -2.19726562e-02],
                        [ -3.60107422e-02,  -4.18395996e-02],
                        [ -5.29174805e-02,  -5.55114746e-02],
                        [ -5.88989258e-02,  -5.79223633e-02],
                        [ -4.56848145e-02,  -4.24499512e-02],
                        [ -8.72802734e-03,  -5.12695312e-03],
                        [  4.64782715e-02,   4.90112305e-02],
                        [  1.03424072e-01,   1.04217529e-01],
                        [  1.41540527e-01,   1.40777588e-01],
                        [  1.47979736e-01,   1.46575928e-01],
                        [  1.27197266e-01,   1.26281738e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  7.64770508e-02,   7.65991211e-02],
                        [  6.42700195e-02,   6.33239746e-02],
                        [  5.37719727e-02,   5.16357422e-02],
                        [  4.02221680e-02,   3.83911133e-02],
                        [  2.42919922e-02,   2.46582031e-02],
                        [  9.42993164e-03,   1.25732422e-02],
                        [ -2.44140625e-04,   4.05883789e-03],
                        [ -4.39453125e-03,  -1.55639648e-03],
                        [ -8.33129883e-03,  -8.75854492e-03],
                        [ -1.71508789e-02,  -2.06298828e-02],
                        [ -2.93884277e-02,  -3.39355469e-02],
                        [ -3.87573242e-02,  -4.20227051e-02],
                        [ -4.11682129e-02,  -4.17175293e-02],
                        [ -3.82690430e-02,  -3.63159180e-02],
                        [ -3.51257324e-02,  -3.21350098e-02],
                        [ -3.45764160e-02,  -3.20739746e-02],
                        [ -3.43322754e-02,  -3.30505371e-02],
                        [ -3.10974121e-02,  -3.06396484e-02],
                        [ -2.70080566e-02,  -2.66418457e-02],
                        [ -2.78625488e-02,  -2.74353027e-02],
                        [ -3.42407227e-02,  -3.46069336e-02],
                        [ -4.04968262e-02,  -4.28161621e-02],
                        [ -4.36096191e-02,  -4.80346680e-02],
                        [ -4.64782715e-02,  -5.12084961e-02],
                        [ -5.10253906e-02,  -5.29174805e-02],
                        [ -5.46875000e-02,  -5.16967773e-02],
                        [ -5.55725098e-02,  -4.85229492e-02],
                        [ -5.47485352e-02,  -4.73022461e-02],
                        [ -5.18798828e-02,  -4.82177734e-02],
                        [ -4.36706543e-02,  -4.56848145e-02],
                        [ -2.75573730e-02,  -3.37829590e-02],
                        [ -3.93676758e-03,  -1.10473633e-02],
                        [  2.34680176e-02,   1.87072754e-02],
                        [  4.79431152e-02,   4.73022461e-02],
                        [  6.31713867e-02,   6.66503906e-02],
                        [  6.54602051e-02,   7.13500977e-02],
                        [  4.92553711e-02,   5.47180176e-02],
                        [  6.83593750e-03,   9.09423828e-03],
                        [ -6.20727539e-02,  -6.39343262e-02],
                        [ -1.44470215e-01,  -1.48803711e-01],
                        [ -2.19635010e-01,  -2.23571777e-01],
                        [ -2.65350342e-01,  -2.66876221e-01],
                        [ -2.64648438e-01,  -2.63885498e-01],
                        [ -2.20642090e-01,  -2.19146729e-01],
                        [ -1.62139893e-01,  -1.61468506e-01],
                        [ -1.21337891e-01,  -1.21765137e-01],
                        [ -1.05194092e-01,  -1.05560303e-01],
                        [ -9.72900391e-02,  -9.61303711e-02],
                        [ -8.41369629e-02,  -8.11462402e-02],
                        [ -6.80847168e-02,  -6.47583008e-02],
                        [ -5.58776855e-02,  -5.44738770e-02],
                        [ -4.73022461e-02,  -4.93164062e-02],
                        [ -3.83911133e-02,  -4.33044434e-02],
                        [ -2.57568359e-02,  -3.14025879e-02],
                        [ -4.79125977e-03,  -8.51440430e-03],
                        [  2.67028809e-02,   2.65808105e-02],
                        [  6.21643066e-02,   6.55212402e-02],
                        [  9.17053223e-02,   9.70153809e-02],
                        [  1.12304688e-01,   1.17645264e-01],
                        [  1.25854492e-01,   1.29760742e-01],
                        [  1.30981445e-01,   1.32385254e-01],
                        [  1.21582031e-01,   1.19842529e-01],
                        [  9.06372070e-02,   8.59985352e-02],
                        [  3.33557129e-02,   2.72216797e-02],
                        [ -4.78210449e-02,  -5.32226562e-02],
                        [ -1.35528564e-01,  -1.38214111e-01],
                        [ -1.98547363e-01,  -1.97814941e-01],
                        [ -2.10937500e-01,  -2.07122803e-01],
                        [ -1.73400879e-01,  -1.67663574e-01],
                        [ -1.14654541e-01,  -1.08520508e-01],
                        [ -6.84814453e-02,  -6.40258789e-02],
                        [ -4.76379395e-02,  -4.66918945e-02],
                        [ -3.89709473e-02,  -4.22973633e-02],
                        [ -2.52380371e-02,  -3.15856934e-02],
                        [ -5.73730469e-03,  -1.23596191e-02],
                        [  7.81250000e-03,   3.63159180e-03],
                        [  8.63647461e-03,   8.20922852e-03],
                        [  2.47192383e-03,   5.31005859e-03],
                        [  7.62939453e-04,   5.34057617e-03],
                        [  8.88061523e-03,   1.35192871e-02],
                        [  2.20642090e-02,   2.54516602e-02],
                        [  3.15246582e-02,   3.28369141e-02],
                        [  3.31115723e-02,   3.21655273e-02],
                        [  2.97546387e-02,   2.72216797e-02],
                        [  2.59704590e-02,   2.30712891e-02],
                        [  2.11791992e-02,   1.87988281e-02],
                        [  1.27563477e-02,   1.08947754e-02],
                        [  4.88281250e-03,   3.20434570e-03],
                        [  6.37817383e-03,   5.06591797e-03],
                        [  2.13623047e-02,   2.16979980e-02],
                        [  4.92553711e-02,   5.24597168e-02],
                        [  8.88061523e-02,   9.45434570e-02],
                        [  1.35284424e-01,   1.41021729e-01],
                        [  1.75354004e-01,   1.77703857e-01],
                        [  1.93420410e-01,   1.90704346e-01],
                        [  1.85760498e-01,   1.79382324e-01],
                        [  1.64031982e-01,   1.57531738e-01],
                        [  1.42059326e-01,   1.38519287e-01],
                        [  1.24603271e-01,   1.24694824e-01],
                        [  1.10626221e-01,   1.13159180e-01],
                        [  9.98535156e-02,   1.03363037e-01],
                        [  9.20104980e-02,   9.57641602e-02],
                        [  8.46862793e-02,   8.80737305e-02],
                        [  7.54089355e-02,   7.73620605e-02],
                        [  6.47277832e-02,   6.43310547e-02],
                        [  5.32836914e-02,   5.06896973e-02],
                        [  3.71398926e-02,   3.34777832e-02],
                        [  1.22985840e-02,   8.94165039e-03],
                        [ -1.64184570e-02,  -1.87072754e-02],
                        [ -3.83911133e-02,  -3.92761230e-02],
                        [ -4.79125977e-02,  -4.71801758e-02],
                        [ -4.75769043e-02,  -4.50439453e-02],
                        [ -4.08630371e-02,  -3.67126465e-02],
                        [ -2.44140625e-02,  -1.97753906e-02],
                        [  7.99560547e-03,   1.11999512e-02],
                        [  5.42602539e-02,   5.38330078e-02],
                        [  1.00097656e-01,   9.52758789e-02],
                        [  1.28509521e-01,   1.21154785e-01],
                        [  1.30218506e-01,   1.24298096e-01],
                        [  1.07879639e-01,   1.06811523e-01],
                        [  7.52868652e-02,   7.93457031e-02],
                        [  4.92858887e-02,   5.56640625e-02],
                        [  3.72924805e-02,   4.25109863e-02],
                        [  3.41491699e-02,   3.63464355e-02],
                        [  3.18298340e-02,   3.13415527e-02],
                        [  2.80456543e-02,   2.60009766e-02],
                        [  2.37731934e-02,   2.09960938e-02],
                        [  1.85546875e-02,   1.54113770e-02],
                        [  9.73510742e-03,   6.80541992e-03],
                        [ -4.57763672e-03,  -6.25610352e-03],
                        [ -2.12707520e-02,  -2.11486816e-02],
                        [ -3.36608887e-02,  -3.19824219e-02],
                        [ -3.83300781e-02,  -3.60107422e-02],
                        [ -3.75976562e-02,  -3.51562500e-02],
                        [ -3.42712402e-02,  -3.15856934e-02],
                        [ -2.90832520e-02,  -2.63366699e-02],
                        [ -2.33764648e-02,  -2.17895508e-02],
                        [ -1.99584961e-02,  -2.11791992e-02],
                        [ -2.09655762e-02,  -2.54516602e-02],
                        [ -2.53295898e-02,  -3.14331055e-02],
                        [ -3.00292969e-02,  -3.47595215e-02],
                        [ -3.39050293e-02,  -3.50646973e-02],
                        [ -3.88488770e-02,  -3.61328125e-02],
                        [ -4.63867188e-02,  -4.10156250e-02],
                        [ -5.44128418e-02,  -4.81567383e-02],
                        [ -5.77392578e-02,  -5.27038574e-02],
                        [ -5.39855957e-02,  -5.24291992e-02],
                        [ -4.63256836e-02,  -4.95605469e-02],
                        [ -3.72619629e-02,  -4.42504883e-02],
                        [ -2.47802734e-02,  -3.22265625e-02],
                        [ -8.81958008e-03,  -1.30004883e-02],
                        [  7.93457031e-03,   8.78906250e-03],
                        [  2.64587402e-02,   3.14025879e-02],
                        [  4.82482910e-02,   5.46569824e-02],
                        [  6.48803711e-02,   7.01599121e-02],
                        [  6.03637695e-02,   6.28051758e-02],
                        [  2.44140625e-02,   2.37121582e-02],
                        [ -3.96728516e-02,  -4.29077148e-02],
                        [ -1.19323730e-01,  -1.23870850e-01],
                        [ -1.97235107e-01,  -2.01812744e-01],
                        [ -2.51403809e-01,  -2.54913330e-01],
                        [ -2.62908936e-01,  -2.64343262e-01],
                        [ -2.31872559e-01,  -2.30499268e-01],
                        [ -1.80358887e-01,  -1.76300049e-01],
                        [ -1.35467529e-01,  -1.30004883e-01],
                        [ -1.10473633e-01,  -1.05712891e-01],
                        [ -9.99755859e-02,  -9.75341797e-02],
                        [ -9.07592773e-02,  -9.11865234e-02],
                        [ -7.80029297e-02,  -8.08105469e-02],
                        [ -6.70776367e-02,  -7.12585449e-02],
                        [ -6.03027344e-02,  -6.48498535e-02],
                        [ -5.10559082e-02,  -5.49621582e-02],
                        [ -3.25927734e-02,  -3.48510742e-02],
                        [ -6.62231445e-03,  -6.46972656e-03],
                        [  2.01416016e-02,   2.29187012e-02],
                        [  4.42810059e-02,   4.90722656e-02],
                        [  6.72607422e-02,   7.26013184e-02],
                        [  9.10339355e-02,   9.52148438e-02],
                        [  1.15722656e-01,   1.17645264e-01],
                        [  1.38366699e-01,   1.37725830e-01],
                        [  1.50878906e-01,   1.47766113e-01],
                        [  1.43249512e-01,   1.37756348e-01],
                        [  1.08795166e-01,   1.01837158e-01],
                        [  4.53796387e-02,   3.94287109e-02],
                        [ -4.26025391e-02,  -4.42810059e-02],
                        [ -1.36871338e-01,  -1.32568359e-01],
                        [ -2.05657959e-01,  -1.96929932e-01],
                        [ -2.22473145e-01,  -2.13500977e-01],
                        [ -1.87255859e-01,  -1.82403564e-01],
                        [ -1.27288818e-01,  -1.28601074e-01],
                        [ -7.52563477e-02,  -8.14208984e-02],
                        [ -4.64172363e-02,  -5.38330078e-02],
                        [ -3.46374512e-02,  -3.97644043e-02],
                        [ -2.65197754e-02,  -2.75878906e-02],
                        [ -1.56860352e-02,  -1.32446289e-02],
                        [ -5.34057617e-03,  -1.43432617e-03],
                        [  1.52587891e-04,   3.26538086e-03],
                        [  3.17382812e-03,   4.30297852e-03],
                        [  1.05590820e-02,   1.00402832e-02],
                        [  2.35595703e-02,   2.27355957e-02],
                        [  3.47290039e-02,   3.45458984e-02],
                        [  3.72009277e-02,   3.75366211e-02],
                        [  3.28063965e-02,   3.29589844e-02],
                        [  2.71606445e-02,   2.65197754e-02],
                        [  2.02331543e-02,   1.87683105e-02],
                        [  9.49096680e-03,   7.59887695e-03],
                        [ -1.70898438e-03,  -3.17382812e-03],
                        [ -5.67626953e-03,  -5.64575195e-03],
                        [  1.52587891e-03,   3.72314453e-03],
                        [  2.00195312e-02,   2.37731934e-02],
                        [  5.02929688e-02,   5.36804199e-02],
                        [  9.11865234e-02,   9.20104980e-02],
                        [  1.36016846e-01,   1.33300781e-01],
                        [  1.73248291e-01,   1.68212891e-01],
                        [  1.91802979e-01,   1.87225342e-01],
                        [  1.88751221e-01,   1.87408447e-01],
                        [  1.72821045e-01,   1.75598145e-01],
                        [  1.56524658e-01,   1.61743164e-01],
                        [  1.45629883e-01,   1.50115967e-01],
                        [  1.37542725e-01,   1.38854980e-01],
                        [  1.26922607e-01,   1.24908447e-01],
                        [  1.11572266e-01,   1.08154297e-01],
                        [  9.40246582e-02,   9.13696289e-02],
                        [  7.68432617e-02,   7.57446289e-02],
                        [  5.91735840e-02,   5.90515137e-02],
                        [  3.94897461e-02,   3.95507812e-02],
                        [  1.91040039e-02,   1.92871094e-02],
                        [  5.18798828e-04,   1.49536133e-03],
                        [ -1.51977539e-02,  -1.31835938e-02],
                        [ -2.88391113e-02,  -2.64892578e-02],
                        [ -4.01000977e-02,  -3.86047363e-02],
                        [ -4.60815430e-02,  -4.60510254e-02],
                        [ -4.47692871e-02,  -4.58984375e-02],
                        [ -3.56140137e-02,  -3.73840332e-02],
                        [ -1.40075684e-02,  -1.63269043e-02],
                        [  2.71606445e-02,   2.43835449e-02],
                        [  8.25195312e-02,   8.02307129e-02],
                        [  1.28936768e-01,   1.28692627e-01],
                        [  1.44104004e-01,   1.46820068e-01],
                        [  1.27258301e-01,   1.31958008e-01],
                        [  9.52758789e-02,   9.94567871e-02],
                        [  6.49414062e-02,   6.64062500e-02],
                        [  4.39758301e-02,   4.23583984e-02],
                        [  3.27148438e-02,   2.96020508e-02],
                        [  2.75268555e-02,   2.50854492e-02],
                        [  2.47192383e-02,   2.36816406e-02],
                        [  2.26440430e-02,   2.20031738e-02],
                        [  1.94396973e-02,   1.80969238e-02],
                        [  1.16882324e-02,   1.01013184e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -1.66015625e-02,  -1.38244629e-02],
                        [ -2.78930664e-02,  -2.33764648e-02],
                        [ -3.37829590e-02,  -2.99682617e-02],
                        [ -3.67431641e-02,  -3.55529785e-02],
                        [ -4.04968262e-02,  -4.22973633e-02],
                        [ -4.46166992e-02,  -4.84313965e-02],
                        [ -4.40979004e-02,  -4.84313965e-02],
                        [ -3.71398926e-02,  -4.04357910e-02],
                        [ -2.93579102e-02,  -3.02124023e-02],
                        [ -2.66418457e-02,  -2.43835449e-02],
                        [ -2.90222168e-02,  -2.45971680e-02],
                        [ -3.34167480e-02,  -2.92053223e-02],
                        [ -3.73535156e-02,  -3.56750488e-02],
                        [ -3.97949219e-02,  -4.11376953e-02],
                        [ -4.20227051e-02,  -4.47998047e-02],
                        [ -4.65698242e-02,  -4.87365723e-02],
                        [ -5.29785156e-02,  -5.38024902e-02],
                        [ -5.53588867e-02,  -5.56945801e-02],
                        [ -4.71191406e-02,  -4.79431152e-02],
                        [ -2.86254883e-02,  -2.97241211e-02],
                        [ -6.89697266e-03,  -6.98852539e-03],
                        [  1.35803223e-02,   1.55944824e-02],
                        [  3.34472656e-02,   3.72619629e-02],
                        [  5.05676270e-02,   5.43212891e-02],
                        [  5.56030273e-02,   5.71289062e-02],
                        [  3.79333496e-02,   3.60107422e-02],
                        [ -7.56835938e-03,  -1.22375488e-02],
                        [ -7.69653320e-02,  -8.20312500e-02],
                        [ -1.55914307e-01,  -1.58843994e-01],
                        [ -2.22503662e-01,  -2.22137451e-01],
                        [ -2.56591797e-01,  -2.53662109e-01],
                        [ -2.49877930e-01,  -2.46124268e-01],
                        [ -2.10021973e-01,  -2.07000732e-01],
                        [ -1.58752441e-01,  -1.57135010e-01],
                        [ -1.21002197e-01,  -1.20971680e-01],
                        [ -1.06323242e-01,  -1.07635498e-01],
                        [ -1.01776123e-01,  -1.03698730e-01],
                        [ -9.03320312e-02,  -9.17968750e-02],
                        [ -7.07397461e-02,  -7.10144043e-02],
                        [ -5.38635254e-02,  -5.35583496e-02],
                        [ -4.75463867e-02,  -4.81872559e-02],
                        [ -4.82482910e-02,  -5.05981445e-02],
                        [ -4.40673828e-02,  -4.67224121e-02],
                        [ -2.50549316e-02,  -2.52990723e-02],
                        [  7.72094727e-03,   1.15051270e-02],
                        [  4.43420410e-02,   5.05065918e-02],
                        [  7.55310059e-02,   8.00781250e-02],
                        [  9.91821289e-02,   9.90600586e-02],
                        [  1.17706299e-01,   1.13281250e-01],
                        [  1.30798340e-01,   1.25366211e-01],
                        [  1.34063721e-01,   1.30889893e-01],
                        [  1.22253418e-01,   1.22222900e-01],
                        [  9.03320312e-02,   9.20715332e-02],
                        [  3.34472656e-02,   3.52783203e-02],
                        [ -4.77294922e-02,  -4.64782715e-02],
                        [ -1.37939453e-01,  -1.37207031e-01],
                        [ -2.04956055e-01,  -2.04711914e-01],
                        [ -2.17956543e-01,  -2.18322754e-01],
                        [ -1.77001953e-01,  -1.77795410e-01],
                        [ -1.16424561e-01,  -1.16973877e-01],
                        [ -7.30285645e-02,  -7.26013184e-02],
                        [ -5.60913086e-02,  -5.45043945e-02],
                        [ -4.98962402e-02,  -4.80346680e-02],
                        [ -3.79943848e-02,  -3.73229980e-02],
                        [ -1.99890137e-02,  -2.16064453e-02],
                        [ -6.10351562e-03,  -9.55200195e-03],
                        [ -1.19018555e-03,  -4.54711914e-03],
                        [  9.15527344e-04,  -2.13623047e-04],
                        [  8.51440430e-03,   1.00097656e-02],
                        [  2.19421387e-02,   2.47497559e-02],
                        [  3.40576172e-02,   3.64379883e-02],
                        [  3.82690430e-02,   3.94592285e-02],
                        [  3.38439941e-02,   3.43627930e-02],
                        [  2.49328613e-02,   2.56042480e-02],
                        [  1.56860352e-02,   1.64184570e-02],
                        [  7.26318359e-03,   7.04956055e-03],
                        [  1.00708008e-03,  -1.03759766e-03],
                        [  2.19726562e-03,  -1.25122070e-03],
                        [  1.65100098e-02,   1.33056641e-02],
                        [  4.47692871e-02,   4.35180664e-02],
                        [  8.44421387e-02,   8.55407715e-02],
                        [  1.29211426e-01,   1.31652832e-01],
                        [  1.65985107e-01,   1.68304443e-01],
                        [  1.82037354e-01,   1.83502197e-01],
                        [  1.76940918e-01,   1.77856445e-01],
                        [  1.61651611e-01,   1.62719727e-01],
                        [  1.46820068e-01,   1.48223877e-01],
                        [  1.37023926e-01,   1.37939453e-01],
                        [  1.31072998e-01,   1.30218506e-01],
                        [  1.23870850e-01,   1.20666504e-01],
                        [  1.11938477e-01,   1.07299805e-01],
                        [  9.79614258e-02,   9.39025879e-02],
                        [  8.51440430e-02,   8.35571289e-02],
                        [  7.12280273e-02,   7.28454590e-02],
                        [  5.48706055e-02,   5.90209961e-02],
                        [  4.03747559e-02,   4.55322266e-02],
                        [  3.01818848e-02,   3.46069336e-02],
                        [  1.94702148e-02,   2.14538574e-02],
                        [  2.41088867e-03,   1.00708008e-03],
                        [ -2.07519531e-02,  -2.50549316e-02],
                        [ -4.36401367e-02,  -4.87060547e-02],
                        [ -5.92041016e-02,  -6.21337891e-02],
                        [ -6.46362305e-02,  -6.38732910e-02],
                        [ -5.88684082e-02,  -5.54504395e-02],
                        [ -3.73229980e-02,  -3.43017578e-02],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  5.70678711e-02,   5.40466309e-02],
                        [  1.06750488e-01,   1.03302002e-01],
                        [  1.34857178e-01,   1.34124756e-01],
                        [  1.33605957e-01,   1.36535645e-01],
                        [  1.10961914e-01,   1.15753174e-01],
                        [  8.47778320e-02,   8.83178711e-02],
                        [  6.60705566e-02,   6.64062500e-02],
                        [  5.13916016e-02,   4.87670898e-02],
                        [  3.44543457e-02,   3.08227539e-02],
                        [  1.84631348e-02,   1.58081055e-02],
                        [  9.09423828e-03,   8.17871094e-03],
                        [  4.30297852e-03,   4.85229492e-03],
                        [ -3.05175781e-04,   9.46044922e-04],
                        [ -3.84521484e-03,  -2.47192383e-03],
                        [ -4.18090820e-03,  -3.38745117e-03],
                        [ -4.33349609e-03,  -4.73022461e-03],
                        [ -1.04064941e-02,  -1.17797852e-02],
                        [ -2.28881836e-02,  -2.38647461e-02],
                        [ -3.39050293e-02,  -3.30200195e-02],
                        [ -3.70483398e-02,  -3.44238281e-02],
                        [ -3.47290039e-02,  -3.21655273e-02],
                        [ -3.14025879e-02,  -3.08532715e-02],
                        [ -2.91137695e-02,  -3.07617188e-02],
                        [ -3.15246582e-02,  -3.38134766e-02],
                        [ -4.03747559e-02,  -4.18701172e-02],
                        [ -4.88891602e-02,  -4.94689941e-02],
                        [ -4.97741699e-02,  -5.03540039e-02],
                        [ -4.58374023e-02,  -4.68139648e-02],
                        [ -4.30603027e-02,  -4.35791016e-02],
                        [ -4.01306152e-02,  -3.90625000e-02],
                        [ -3.33557129e-02,  -3.08532715e-02],
                        [ -2.44750977e-02,  -2.22473145e-02],
                        [ -1.63574219e-02,  -1.57775879e-02],
                        [ -6.95800781e-03,  -7.65991211e-03],
                        [  5.67626953e-03,   5.21850586e-03],
                        [  1.85546875e-02,   1.89819336e-02],
                        [  2.88085938e-02,   2.91748047e-02],
                        [  3.70483398e-02,   3.60717773e-02],
                        [  4.15344238e-02,   3.92761230e-02],
                        [  3.38745117e-02,   3.17077637e-02],
                        [  1.64794922e-03,   9.76562500e-04],
                        [ -6.23168945e-02,  -6.12182617e-02],
                        [ -1.47857666e-01,  -1.46087646e-01],
                        [ -2.26593018e-01,  -2.25463867e-01],
                        [ -2.69104004e-01,  -2.69104004e-01],
                        [ -2.63824463e-01,  -2.64282227e-01],
                        [ -2.21008301e-01,  -2.20855713e-01],
                        [ -1.64459229e-01,  -1.63269043e-01],
                        [ -1.17797852e-01,  -1.16302490e-01],
                        [ -9.10949707e-02,  -9.04846191e-02],
                        [ -7.83996582e-02,  -7.92846680e-02],
                        [ -6.96716309e-02,  -7.15332031e-02],
                        [ -6.17980957e-02,  -6.34460449e-02],
                        [ -5.61828613e-02,  -5.69152832e-02],
                        [ -5.06591797e-02,  -5.08117676e-02],
                        [ -3.89404297e-02,  -3.92456055e-02],
                        [ -1.75781250e-02,  -1.80358887e-02],
                        [  1.04064941e-02,   1.06811523e-02],
                        [  3.92761230e-02,   4.09851074e-02],
                        [  6.48498535e-02,   6.73828125e-02],
                        [  8.54187012e-02,   8.70666504e-02],
                        [  1.00250244e-01,   9.98535156e-02],
                        [  1.08581543e-01,   1.06750488e-01],
                        [  1.11083984e-01,   1.09863281e-01],
                        [  1.09985352e-01,   1.10656738e-01],
                        [  1.01043701e-01,   1.02630615e-01],
                        [  6.86645508e-02,   6.88171387e-02],
                        [  1.28173828e-03,  -1.22070312e-03],
                        [ -8.83789062e-02,  -9.20410156e-02],
                        [ -1.66503906e-01,  -1.68457031e-01],
                        [ -2.02514648e-01,  -2.01293945e-01],
                        [ -1.88812256e-01,  -1.85760498e-01],
                        [ -1.42333984e-01,  -1.39953613e-01],
                        [ -9.04235840e-02,  -8.96301270e-02],
                        [ -5.33447266e-02,  -5.29174805e-02],
                        [ -3.52478027e-02,  -3.36914062e-02],
                        [ -2.74658203e-02,  -2.53295898e-02],
                        [ -2.14843750e-02,  -2.11181641e-02],
                        [ -1.87988281e-02,  -2.18811035e-02],
                        [ -2.39562988e-02,  -2.94799805e-02],
                        [ -3.17993164e-02,  -3.65905762e-02],
                        [ -2.95104980e-02,  -3.07312012e-02],
                        [ -1.15356445e-02,  -8.85009766e-03],
                        [  1.39770508e-02,   1.84326172e-02],
                        [  3.37829590e-02,   3.73840332e-02],
                        [  4.03442383e-02,   4.19006348e-02],
                        [  3.45764160e-02,   3.47290039e-02],
                        [  2.22167969e-02,   2.20642090e-02],
                        [  9.09423828e-03,   8.81958008e-03],
                        [ -8.85009766e-04,  -1.77001953e-03],
                        [ -3.20434570e-03,  -4.82177734e-03],
                        [  8.14819336e-03,   6.53076172e-03],
                        [  3.62854004e-02,   3.52172852e-02],
                        [  7.69042969e-02,   7.59582520e-02],
                        [  1.20300293e-01,   1.18804932e-01],
                        [  1.55609131e-01,   1.53930664e-01],
                        [  1.74163818e-01,   1.74041748e-01],
                        [  1.73980713e-01,   1.77032471e-01],
                        [  1.61529541e-01,   1.67358398e-01],
                        [  1.47186279e-01,   1.53076172e-01],
                        [  1.38977051e-01,   1.41540527e-01],
                        [  1.37664795e-01,   1.35223389e-01],
                        [  1.35711670e-01,   1.29455566e-01],
                        [  1.25366211e-01,   1.18347168e-01],
                        [  1.07910156e-01,   1.03149414e-01],
                        [  9.00268555e-02,   8.91418457e-02],
                        [  7.31201172e-02,   7.60192871e-02],
                        [  5.40466309e-02,   5.92651367e-02],
                        [  3.35693359e-02,   3.86962891e-02],
                        [  1.56250000e-02,   1.83105469e-02],
                        [  1.43432617e-03,   8.23974609e-04],
                        [ -9.36889648e-03,  -1.19934082e-02],
                        [ -1.65405273e-02,  -1.88293457e-02],
                        [ -2.22473145e-02,  -2.27355957e-02],
                        [ -3.08532715e-02,  -3.00598145e-02],
                        [ -4.22363281e-02,  -4.16870117e-02],
                        [ -4.89196777e-02,  -4.95605469e-02],
                        [ -4.30297852e-02,  -4.45861816e-02],
                        [ -2.40173340e-02,  -2.57873535e-02],
                        [  3.84521484e-03,   2.41088867e-03],
                        [  3.83911133e-02,   3.78112793e-02],
                        [  7.77587891e-02,   7.89489746e-02],
                        [  1.12609863e-01,   1.16088867e-01],
                        [  1.28051758e-01,   1.32476807e-01],
                        [  1.17340088e-01,   1.20025635e-01],
                        [  9.07287598e-02,   8.97827148e-02],
                        [  6.51245117e-02,   6.12487793e-02],
                        [  4.71191406e-02,   4.30603027e-02],
                        [  3.20434570e-02,   3.01208496e-02],
                        [  1.62963867e-02,   1.66015625e-02],
                        [  2.86865234e-03,   4.15039062e-03],
                        [ -3.78417969e-03,  -2.56347656e-03],
                        [ -3.38745117e-03,  -2.38037109e-03],
                        [ -3.05175781e-04,   6.40869141e-04],
                        [  1.40380859e-03,   2.07519531e-03],
                        [  1.22070312e-03,   1.03759766e-03],
                        [ -7.32421875e-04,  -1.86157227e-03],
                        [ -4.82177734e-03,  -6.13403320e-03],
                        [ -1.02844238e-02,  -1.08032227e-02],
                        [ -1.69372559e-02,  -1.64489746e-02],
                        [ -2.62451172e-02,  -2.54516602e-02],
                        [ -3.70788574e-02,  -3.64990234e-02],
                        [ -4.46472168e-02,  -4.38232422e-02],
                        [ -4.54711914e-02,  -4.39758301e-02],
                        [ -4.16870117e-02,  -4.04968262e-02],
                        [ -3.84216309e-02,  -3.94592285e-02],
                        [ -3.71704102e-02,  -4.08935547e-02],
                        [ -3.44848633e-02,  -3.86047363e-02],
                        [ -2.95715332e-02,  -3.09143066e-02],
                        [ -2.77099609e-02,  -2.52685547e-02],
                        [ -3.18908691e-02,  -2.79235840e-02],
                        [ -3.69262695e-02,  -3.45458984e-02],
                        [ -3.48510742e-02,  -3.50646973e-02],
                        [ -2.31628418e-02,  -2.44445801e-02],
                        [ -5.88989258e-03,  -5.98144531e-03],
                        [  1.26953125e-02,   1.42822266e-02],
                        [  3.15856934e-02,   3.33862305e-02],
                        [  4.88281250e-02,   4.87976074e-02],
                        [  5.55725098e-02,   5.30395508e-02],
                        [  3.81469727e-02,   3.41796875e-02],
                        [ -1.20849609e-02,  -1.56250000e-02],
                        [ -9.03015137e-02,  -9.19189453e-02],
                        [ -1.78039551e-01,  -1.77124023e-01],
                        [ -2.48016357e-01,  -2.44720459e-01],
                        [ -2.73895264e-01,  -2.69165039e-01],
                        [ -2.48291016e-01,  -2.43774414e-01],
                        [ -1.92932129e-01,  -1.90551758e-01],
                        [ -1.40808105e-01,  -1.41723633e-01],
                        [ -1.08367920e-01,  -1.12091064e-01],
                        [ -9.16137695e-02,  -9.62524414e-02],
                        [ -8.17565918e-02,  -8.52661133e-02],
                        [ -7.39746094e-02,  -7.53173828e-02],
                        [ -6.58874512e-02,  -6.50634766e-02],
                        [ -5.63964844e-02,  -5.43212891e-02],
                        [ -4.54711914e-02,  -4.34265137e-02],
                        [ -3.08227539e-02,  -2.95410156e-02],
                        [ -8.88061523e-03,  -8.08715820e-03],
                        [  1.94091797e-02,   2.05078125e-02],
                        [  4.78515625e-02,   4.93774414e-02],
                        [  7.06787109e-02,   7.13195801e-02],
                        [  8.60595703e-02,   8.42895508e-02],
                        [  9.64355469e-02,   9.24072266e-02],
                        [  1.05499268e-01,   1.01593018e-01],
                        [  1.12731934e-01,   1.11846924e-01],
                        [  1.13311768e-01,   1.16333008e-01],
                        [  1.00463867e-01,   1.05285645e-01],
                        [  6.47583008e-02,   6.80847168e-02],
                        [ -7.01904297e-04,  -8.54492188e-04],
                        [ -8.68530273e-02,  -8.97827148e-02],
                        [ -1.65283203e-01,  -1.68762207e-01],
                        [ -2.04071045e-01,  -2.06268311e-01],
                        [ -1.88995361e-01,  -1.89544678e-01],
                        [ -1.35406494e-01,  -1.34704590e-01],
                        [ -7.94677734e-02,  -7.78198242e-02],
                        [ -4.98657227e-02,  -4.73937988e-02],
                        [ -4.55017090e-02,  -4.26635742e-02],
                        [ -4.52270508e-02,  -4.32434082e-02],
                        [ -3.64074707e-02,  -3.65600586e-02],
                        [ -2.40173340e-02,  -2.65808105e-02],
                        [ -1.54418945e-02,  -1.90124512e-02],
                        [ -9.09423828e-03,  -1.16271973e-02],
                        [  5.49316406e-04,   6.10351562e-05],
                        [  1.44348145e-02,   1.51062012e-02],
                        [  2.63671875e-02,   2.66418457e-02],
                        [  2.79846191e-02,   2.74963379e-02],
                        [  1.81274414e-02,   1.83410645e-02],
                        [  4.30297852e-03,   6.89697266e-03],
                        [ -5.95092773e-03,  -1.12915039e-03],
                        [ -9.09423828e-03,  -4.42504883e-03],
                        [ -2.71606445e-03,  -1.22070312e-03],
                        [  1.58386230e-02,   1.27258301e-02],
                        [  4.78820801e-02,   4.13208008e-02],
                        [  9.04541016e-02,   8.33129883e-02],
                        [  1.33697510e-01,   1.28814697e-01],
                        [  1.64947510e-01,   1.63940430e-01],
                        [  1.77520752e-01,   1.80664062e-01],
                        [  1.73522949e-01,   1.79901123e-01],
                        [  1.60461426e-01,   1.68151855e-01],
                        [  1.47644043e-01,   1.53869629e-01],
                        [  1.40869141e-01,   1.42883301e-01],
                        [  1.36749268e-01,   1.33636475e-01],
                        [  1.27502441e-01,   1.20849609e-01],
                        [  1.13494873e-01,   1.06445312e-01],
                        [  1.02325439e-01,   9.76562500e-02],
                        [  9.43908691e-02,   9.29870605e-02],
                        [  8.17871094e-02,   8.31298828e-02],
                        [  6.33544922e-02,   6.66198730e-02],
                        [  4.61730957e-02,   5.05981445e-02],
                        [  3.19213867e-02,   3.64379883e-02],
                        [  1.68762207e-02,   1.98364258e-02],
                        [  2.68554688e-03,   2.96020508e-03],
                        [ -4.63867188e-03,  -6.80541992e-03],
                        [ -5.92041016e-03,  -9.00268555e-03],
                        [ -9.09423828e-03,  -1.16882324e-02],
                        [ -1.83410645e-02,  -2.00195312e-02],
                        [ -2.94494629e-02,  -3.04260254e-02],
                        [ -3.75976562e-02,  -3.80554199e-02],
                        [ -4.18395996e-02,  -4.15649414e-02],
                        [ -3.81164551e-02,  -3.69262695e-02],
                        [ -1.79138184e-02,  -1.61132812e-02],
                        [  1.96228027e-02,   2.14233398e-02],
                        [  6.17065430e-02,   6.30798340e-02],
                        [  9.31091309e-02,   9.40856934e-02],
                        [  1.07177734e-01,   1.07666016e-01],
                        [  1.04003906e-01,   1.03302002e-01],
                        [  8.70666504e-02,   8.44421387e-02],
                        [  6.51550293e-02,   6.11572266e-02],
                        [  4.89501953e-02,   4.58374023e-02],
                        [  4.18701172e-02,   4.20532227e-02],
                        [  3.79333496e-02,   4.17480469e-02],
                        [  3.03649902e-02,   3.55834961e-02],
                        [  2.05383301e-02,   2.41699219e-02],
                        [  1.63269043e-02,   1.66931152e-02],
                        [  2.08435059e-02,   1.80664062e-02],
                        [  2.56042480e-02,   2.10876465e-02],
                        [  1.90124512e-02,   1.46484375e-02],
                        [ -3.35693359e-04,  -2.68554688e-03],
                        [ -2.35290527e-02,  -2.26440430e-02],
                        [ -4.22668457e-02,  -3.85437012e-02],
                        [ -5.37719727e-02,  -4.92248535e-02],
                        [ -5.63354492e-02,  -5.32531738e-02],
                        [ -4.87365723e-02,  -4.80651855e-02],
                        [ -3.55224609e-02,  -3.66516113e-02],
                        [ -2.42614746e-02,  -2.62145996e-02],
                        [ -1.70898438e-02,  -1.93786621e-02],
                        [ -1.22375488e-02,  -1.46789551e-02],
                        [ -1.19934082e-02,  -1.40991211e-02],
                        [ -2.13317871e-02,  -2.21557617e-02],
                        [ -3.78723145e-02,  -3.68957520e-02],
                        [ -5.11779785e-02,  -4.89196777e-02],
                        [ -5.32836914e-02,  -5.09643555e-02],
                        [ -4.47692871e-02,  -4.33654785e-02],
                        [ -2.96630859e-02,  -2.89916992e-02],
                        [ -1.00097656e-02,  -9.30786133e-03],
                        [  1.21459961e-02,   1.29089355e-02],
                        [  3.28369141e-02,   3.27148438e-02],
                        [  4.86145020e-02,   4.65698242e-02],
                        [  5.57861328e-02,   5.22155762e-02],
                        [  4.61425781e-02,   4.28161621e-02],
                        [  7.62939453e-03,   6.34765625e-03],
                        [ -6.43920898e-02,  -6.30187988e-02],
                        [ -1.54754639e-01,  -1.51580811e-01],
                        [ -2.33093262e-01,  -2.29583740e-01],
                        [ -2.73223877e-01,  -2.70690918e-01],
                        [ -2.67730713e-01,  -2.66906738e-01],
                        [ -2.27722168e-01,  -2.28668213e-01],
                        [ -1.75659180e-01,  -1.78009033e-01],
                        [ -1.33605957e-01,  -1.36474609e-01],
                        [ -1.08642578e-01,  -1.10900879e-01],
                        [ -9.03625488e-02,  -9.09118652e-02],
                        [ -6.81762695e-02,  -6.68334961e-02],
                        [ -4.73632812e-02,  -4.51965332e-02],
                        [ -3.95812988e-02,  -3.80249023e-02],
                        [ -4.24499512e-02,  -4.20532227e-02],
                        [ -4.11987305e-02,  -4.14733887e-02],
                        [ -2.86560059e-02,  -2.90527344e-02],
                        [ -1.07421875e-02,  -1.11389160e-02],
                        [  7.56835938e-03,   7.01904297e-03],
                        [  2.89306641e-02,   2.83203125e-02],
                        [  5.36499023e-02,   5.31616211e-02],
                        [  7.43408203e-02,   7.39440918e-02],
                        [  8.56933594e-02,   8.55407715e-02],
                        [  9.18273926e-02,   9.24682617e-02],
                        [  9.82666016e-02,   1.00189209e-01],
                        [  1.02844238e-01,   1.05407715e-01],
                        [  9.71374512e-02,   9.85107422e-02],
                        [  7.10754395e-02,   6.97326660e-02],
                        [  1.72119141e-02,   1.33666992e-02],
                        [ -6.09436035e-02,  -6.52160645e-02],
                        [ -1.41510010e-01,  -1.43615723e-01],
                        [ -1.92352295e-01,  -1.91131592e-01],
                        [ -1.94458008e-01,  -1.90795898e-01],
                        [ -1.56616211e-01,  -1.52557373e-01],
                        [ -1.05834961e-01,  -1.03149414e-01],
                        [ -6.56738281e-02,  -6.48803711e-02],
                        [ -4.31518555e-02,  -4.38232422e-02],
                        [ -3.18908691e-02,  -3.36608887e-02],
                        [ -2.40173340e-02,  -2.68554688e-02],
                        [ -1.74865723e-02,  -2.08740234e-02],
                        [ -1.31835938e-02,  -1.58996582e-02],
                        [ -1.00402832e-02,  -1.07727051e-02],
                        [ -5.92041016e-03,  -4.27246094e-03],
                        [ -1.19018555e-03,   1.80053711e-03],
                        [  2.25830078e-03,   5.15747070e-03],
                        [  4.91333008e-03,   6.98852539e-03],
                        [  7.08007812e-03,   8.42285156e-03],
                        [  5.18798828e-03,   6.01196289e-03],
                        [ -9.15527344e-04,  -8.85009766e-04],
                        [ -2.44140625e-04,  -1.64794922e-03],
                        [  1.83410645e-02,   1.51672363e-02],
                        [  5.26733398e-02,   4.84008789e-02],
                        [  9.21325684e-02,   8.83483887e-02],
                        [  1.28479004e-01,   1.26922607e-01],
                        [  1.56188965e-01,   1.57775879e-01],
                        [  1.69464111e-01,   1.73736572e-01],
                        [  1.65313721e-01,   1.70745850e-01],
                        [  1.49047852e-01,   1.53747559e-01],
                        [  1.32934570e-01,   1.35223389e-01],
                        [  1.26037598e-01,   1.24938965e-01],
                        [  1.26129150e-01,   1.21887207e-01],
                        [  1.24755859e-01,   1.19049072e-01],
                        [  1.18438721e-01,   1.13769531e-01],
                        [  1.10260010e-01,   1.08581543e-01],
                        [  1.02142334e-01,   1.03759766e-01],
                        [  9.17358398e-02,   9.53369141e-02],
                        [  7.73620605e-02,   8.10546875e-02],
                        [  6.01196289e-02,   6.25305176e-02],
                        [  4.22058105e-02,   4.29077148e-02],
                        [  2.75268555e-02,   2.67028809e-02],
                        [  2.03247070e-02,   1.85241699e-02],
                        [  1.86767578e-02,   1.67236328e-02],
                        [  1.37023926e-02,   1.25427246e-02],
                        [ -3.05175781e-04,  -1.52587891e-04],
                        [ -1.92260742e-02,  -1.82189941e-02],
                        [ -3.55834961e-02,  -3.46984863e-02],
                        [ -4.65087891e-02,  -4.63867188e-02],
                        [ -5.20629883e-02,  -5.24597168e-02],
                        [ -4.94689941e-02,  -4.96520996e-02],
                        [ -3.32946777e-02,  -3.29895020e-02],
                        [ -1.40380859e-03,  -1.06811523e-03],
                        [  4.00085449e-02,   3.96728516e-02],
                        [  7.80334473e-02,   7.70263672e-02],
                        [  1.00494385e-01,   9.95178223e-02],
                        [  1.02264404e-01,   1.02050781e-01],
                        [  8.67614746e-02,   8.74328613e-02],
                        [  6.47583008e-02,   6.57958984e-02],
                        [  4.78820801e-02,   4.90112305e-02],
                        [  3.98559570e-02,   4.11987305e-02],
                        [  3.58276367e-02,   3.73229980e-02],
                        [  3.05480957e-02,   3.13720703e-02],
                        [  2.36816406e-02,   2.26440430e-02],
                        [  1.81274414e-02,   1.49230957e-02],
                        [  1.52893066e-02,   1.11083984e-02],
                        [  1.27563477e-02,   9.70458984e-03],
                        [  7.08007812e-03,   6.77490234e-03],
                        [ -3.35693359e-03,  -6.71386719e-04],
                        [ -1.77917480e-02,  -1.32446289e-02],
                        [ -3.19519043e-02,  -2.74047852e-02],
                        [ -3.98559570e-02,  -3.71704102e-02],
                        [ -3.98559570e-02,  -4.01611328e-02],
                        [ -3.61328125e-02,  -3.91235352e-02],
                        [ -3.37524414e-02,  -3.78112793e-02],
                        [ -3.47290039e-02,  -3.78417969e-02],
                        [ -3.72314453e-02,  -3.82385254e-02],
                        [ -3.86047363e-02,  -3.78417969e-02],
                        [ -3.91540527e-02,  -3.77197266e-02],
                        [ -3.95812988e-02,  -3.82995605e-02],
                        [ -3.77807617e-02,  -3.67126465e-02],
                        [ -3.20739746e-02,  -3.10668945e-02],
                        [ -2.39257812e-02,  -2.33154297e-02],
                        [ -1.60522461e-02,  -1.62353516e-02],
                        [ -1.07421875e-02,  -1.16577148e-02],
                        [ -8.30078125e-03,  -9.24682617e-03],
                        [ -4.97436523e-03,  -5.27954102e-03],
                        [  4.39453125e-03,   4.66918945e-03],
                        [  2.13012695e-02,   2.15759277e-02],
                        [  4.02832031e-02,   4.01000977e-02],
                        [  4.94995117e-02,   4.91333008e-02],
                        [  3.65905762e-02,   3.66821289e-02],
                        [ -5.12695312e-03,  -4.33349609e-03],
                        [ -7.39135742e-02,  -7.29980469e-02],
                        [ -1.57379150e-01,  -1.57257080e-01],
                        [ -2.31353760e-01,  -2.32391357e-01],
                        [ -2.68096924e-01,  -2.69836426e-01],
                        [ -2.53967285e-01,  -2.55554199e-01],
                        [ -2.03125000e-01,  -2.03826904e-01],
                        [ -1.49108887e-01,  -1.48498535e-01],
                        [ -1.16760254e-01,  -1.14685059e-01],
                        [ -1.05438232e-01,  -1.02264404e-01],
                        [ -9.96704102e-02,  -9.66186523e-02],
                        [ -8.86230469e-02,  -8.72192383e-02],
                        [ -7.33337402e-02,  -7.47375488e-02],
                        [ -6.10961914e-02,  -6.50329590e-02],
                        [ -5.39855957e-02,  -5.88073730e-02],
                        [ -4.48608398e-02,  -4.84008789e-02],
                        [ -2.66723633e-02,  -2.75573730e-02],
                        [ -6.71386719e-04,   1.22070312e-03],
                        [  2.66418457e-02,   3.05175781e-02],
                        [  5.00488281e-02,   5.44738770e-02],
                        [  6.75354004e-02,   7.10144043e-02],
                        [  8.01696777e-02,   8.14514160e-02],
                        [  9.05151367e-02,   8.92639160e-02],
                        [  1.00830078e-01,   9.78088379e-02],
                        [  1.10687256e-01,   1.07269287e-01],
                        [  1.14044189e-01,   1.11541748e-01],
                        [  9.89379883e-02,   9.78088379e-02],
                        [  5.45959473e-02,   5.46264648e-02],
                        [ -1.75476074e-02,  -1.69067383e-02],
                        [ -1.00189209e-01,  -9.91516113e-02],
                        [ -1.66442871e-01,  -1.64855957e-01],
                        [ -1.93023682e-01,  -1.90765381e-01],
                        [ -1.74499512e-01,  -1.72210693e-01],
                        [ -1.29180908e-01,  -1.27929688e-01],
                        [ -8.56628418e-02,  -8.62121582e-02],
                        [ -5.95703125e-02,  -6.16455078e-02],
                        [ -4.61425781e-02,  -4.86755371e-02],
                        [ -3.45458984e-02,  -3.66516113e-02],
                        [ -2.22167969e-02,  -2.35290527e-02],
                        [ -1.26037598e-02,  -1.30920410e-02],
                        [ -6.89697266e-03,  -6.28662109e-03],
                        [ -2.56347656e-03,  -5.79833984e-04],
                        [  3.41796875e-03,   6.37817383e-03],
                        [  1.15356445e-02,   1.41906738e-02],
                        [  1.89514160e-02,   1.98364258e-02],
                        [  2.23693848e-02,   2.08129883e-02],
                        [  1.98059082e-02,   1.67541504e-02],
                        [  1.00402832e-02,   7.29370117e-03],
                        [ -3.17382812e-03,  -4.11987305e-03],
                        [ -6.62231445e-03,  -5.64575195e-03],
                        [  1.23901367e-02,   1.41906738e-02],
                        [  5.23681641e-02,   5.37109375e-02],
                        [  9.96704102e-02,   1.00097656e-01],
                        [  1.40380859e-01,   1.40258789e-01],
                        [  1.64855957e-01,   1.64581299e-01],
                        [  1.69158936e-01,   1.68823242e-01],
                        [  1.58813477e-01,   1.58386230e-01],
                        [  1.46270752e-01,   1.45904541e-01],
                        [  1.39465332e-01,   1.39190674e-01],
                        [  1.35192871e-01,   1.34918213e-01],
                        [  1.27380371e-01,   1.27197266e-01],
                        [  1.16882324e-01,   1.17156982e-01],
                        [  1.07818604e-01,   1.08825684e-01],
                        [  1.00189209e-01,   1.01623535e-01],
                        [  9.24072266e-02,   9.32922363e-02],
                        [  8.47167969e-02,   8.43811035e-02],
                        [  7.56225586e-02,   7.41882324e-02],
                        [  6.10656738e-02,   5.92041016e-02],
                        [  4.15649414e-02,   4.00695801e-02],
                        [  2.42004395e-02,   2.35900879e-02],
                        [  1.46484375e-02,   1.51672363e-02],
                        [  1.04675293e-02,   1.20544434e-02],
                        [  3.44848633e-03,   5.64575195e-03],
                        [ -1.19018555e-02,  -9.88769531e-03],
                        [ -3.18298340e-02,  -3.10058594e-02],
                        [ -4.70886230e-02,  -4.78820801e-02],
                        [ -5.32836914e-02,  -5.53283691e-02],
                        [ -5.38940430e-02,  -5.60913086e-02],
                        [ -4.93774414e-02,  -5.05981445e-02],
                        [ -2.95715332e-02,  -2.96630859e-02],
                        [  1.34582520e-02,   1.39160156e-02],
                        [  6.87255859e-02,   6.91528320e-02],
                        [  1.12335205e-01,   1.12731934e-01],
                        [  1.28417969e-01,   1.29241943e-01],
                        [  1.17340088e-01,   1.18713379e-01],
                        [  9.03320312e-02,   9.16748047e-02],
                        [  6.21643066e-02,   6.27136230e-02],
                        [  4.27856445e-02,   4.23278809e-02],
                        [  3.18603516e-02,   3.06701660e-02],
                        [  2.28271484e-02,   2.13928223e-02],
                        [  1.03759766e-02,   9.06372070e-03],
                        [ -5.34057617e-03,  -6.43920898e-03],
                        [ -1.80969238e-02,  -1.87377930e-02],
                        [ -2.17590332e-02,  -2.13623047e-02],
                        [ -1.74560547e-02,  -1.57165527e-02],
                        [ -1.15966797e-02,  -9.06372070e-03],
                        [ -9.36889648e-03,  -7.32421875e-03],
                        [ -1.21154785e-02,  -1.16271973e-02],
                        [ -1.66320801e-02,  -1.79443359e-02],
                        [ -1.85852051e-02,  -2.09960938e-02],
                        [ -1.85852051e-02,  -2.10266113e-02],
                        [ -2.13623047e-02,  -2.28576660e-02],
                        [ -2.81372070e-02,  -2.79541016e-02],
                        [ -3.44238281e-02,  -3.25012207e-02],
                        [ -3.64379883e-02,  -3.36608887e-02],
                        [ -3.54309082e-02,  -3.34167480e-02],
                        [ -3.45153809e-02,  -3.43933105e-02],
                        [ -3.43627930e-02,  -3.59802246e-02],
                        [ -3.49121094e-02,  -3.69873047e-02],
                        [ -3.65295410e-02,  -3.78723145e-02],
                        [ -3.78112793e-02,  -3.81469727e-02],
                        [ -3.59802246e-02,  -3.57360840e-02],
                        [ -2.92053223e-02,  -2.87170410e-02],
                        [ -1.61132812e-02,  -1.54113770e-02],
                        [  3.11279297e-03,   3.99780273e-03],
                        [  2.45971680e-02,   2.54821777e-02],
                        [  4.25109863e-02,   4.30908203e-02],
                        [  5.14526367e-02,   5.15747070e-02],
                        [  4.66308594e-02,   4.63867188e-02],
                        [  2.40783691e-02,   2.35900879e-02],
                        [ -1.87988281e-02,  -1.96228027e-02],
                        [ -8.16650391e-02,  -8.29467773e-02],
                        [ -1.56372070e-01,  -1.57867432e-01],
                        [ -2.25158691e-01,  -2.26165771e-01],
                        [ -2.65441895e-01,  -2.65319824e-01],
                        [ -2.61840820e-01,  -2.60406494e-01],
                        [ -2.20214844e-01,  -2.18078613e-01],
                        [ -1.67999268e-01,  -1.65893555e-01],
                        [ -1.29913330e-01,  -1.28417969e-01],
                        [ -1.06689453e-01,  -1.06079102e-01],
                        [ -8.55102539e-02,  -8.61511230e-02],
                        [ -6.33850098e-02,  -6.55517578e-02],
                        [ -4.83703613e-02,  -5.15747070e-02],
                        [ -4.39453125e-02,  -4.69665527e-02],
                        [ -4.35180664e-02,  -4.49218750e-02],
                        [ -3.79638672e-02,  -3.70483398e-02],
                        [ -2.27966309e-02,  -2.00195312e-02],
                        [ -2.13623047e-04,   3.20434570e-03],
                        [  2.35900879e-02,   2.64282227e-02],
                        [  4.41589355e-02,   4.55017090e-02],
                        [  6.14624023e-02,   6.10351562e-02],
                        [  7.78503418e-02,   7.57446289e-02],
                        [  9.49096680e-02,   9.18579102e-02],
                        [  1.11968994e-01,   1.09191895e-01],
                        [  1.24938965e-01,   1.23626709e-01],
                        [  1.26770020e-01,   1.27410889e-01],
                        [  1.09130859e-01,   1.11083984e-01],
                        [  6.39953613e-02,   6.60095215e-02],
                        [ -1.18713379e-02,  -1.08032227e-02],
                        [ -1.06353760e-01,  -1.06262207e-01],
                        [ -1.86645508e-01,  -1.86859131e-01],
                        [ -2.16705322e-01,  -2.16613770e-01],
                        [ -1.87469482e-01,  -1.87194824e-01],
                        [ -1.25885010e-01,  -1.26098633e-01],
                        [ -7.04956055e-02,  -7.15332031e-02],
                        [ -3.99475098e-02,  -4.13513184e-02],
                        [ -2.62145996e-02,  -2.72216797e-02],
                        [ -1.52282715e-02,  -1.52893066e-02],
                        [ -6.19506836e-03,  -5.43212891e-03],
                        [ -5.79833984e-03,  -4.69970703e-03],
                        [ -1.24816895e-02,  -1.15051270e-02],
                        [ -1.72729492e-02,  -1.66320801e-02],
                        [ -1.51672363e-02,  -1.49230957e-02],
                        [ -8.60595703e-03,  -8.81958008e-03],
                        [ -2.62451172e-03,  -3.44848633e-03],
                        [  2.44140625e-04,  -1.06811523e-03],
                        [  1.34277344e-03,   2.44140625e-04],
                        [  4.11987305e-03,   4.05883789e-03],
                        [  1.32141113e-02,   1.44348145e-02],
                        [  3.38745117e-02,   3.56140137e-02],
                        [  6.72302246e-02,   6.83288574e-02],
                        [  1.07421875e-01,   1.07086182e-01],
                        [  1.43127441e-01,   1.41723633e-01],
                        [  1.62353516e-01,   1.60919189e-01],
                        [  1.60278320e-01,   1.59667969e-01],
                        [  1.45233154e-01,   1.45446777e-01],
                        [  1.32537842e-01,   1.33056641e-01],
                        [  1.30187988e-01,   1.30554199e-01],
                        [  1.33056641e-01,   1.33331299e-01],
                        [  1.32568359e-01,   1.32995605e-01],
                        [  1.27593994e-01,   1.28295898e-01],
                        [  1.21917725e-01,   1.22619629e-01],
                        [  1.15020752e-01,   1.15295410e-01],
                        [  1.04156494e-01,   1.03698730e-01],
                        [  9.00573730e-02,   8.88977051e-02],
                        [  7.45849609e-02,   7.30285645e-02],
                        [  5.77392578e-02,   5.65185547e-02],
                        [  4.11682129e-02,   4.08630371e-02],
                        [  2.72216797e-02,   2.79846191e-02],
                        [  1.48925781e-02,   1.63574219e-02],
                        [  2.25830078e-03,   3.78417969e-03],
                        [ -9.30786133e-03,  -8.27026367e-03],
                        [ -1.69067383e-02,  -1.66015625e-02],
                        [ -2.04162598e-02,  -2.09350586e-02],
                        [ -2.33154297e-02,  -2.44140625e-02],
                        [ -2.92053223e-02,  -3.04260254e-02],
                        [ -3.85131836e-02,  -3.93066406e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -4.13818359e-02,  -4.08325195e-02],
                        [ -1.38549805e-02,  -1.33972168e-02],
                        [  3.57360840e-02,   3.57055664e-02],
                        [  8.94165039e-02,   8.90502930e-02],
                        [  1.21673584e-01,   1.21582031e-01],
                        [  1.20422363e-01,   1.21124268e-01],
                        [  9.62829590e-02,   9.74426270e-02],
                        [  6.83288574e-02,   6.90307617e-02],
                        [  4.62646484e-02,   4.58984375e-02],
                        [  2.93273926e-02,   2.81372070e-02],
                        [  1.55334473e-02,   1.44958496e-02],
                        [  6.56127930e-03,   6.28662109e-03],
                        [  4.91333008e-03,   5.24902344e-03],
                        [  9.27734375e-03,   9.70458984e-03],
                        [  1.35803223e-02,   1.37939453e-02],
                        [  1.17492676e-02,   1.19018555e-02],
                        [  2.56347656e-03,   2.77709961e-03],
                        [ -1.11083984e-02,  -1.09558105e-02],
                        [ -2.45666504e-02,  -2.47192383e-02],
                        [ -3.26843262e-02,  -3.30505371e-02],
                        [ -3.38439941e-02,  -3.41491699e-02],
                        [ -3.26538086e-02,  -3.26843262e-02],
                        [ -3.28979492e-02,  -3.27148438e-02],
                        [ -3.11584473e-02,  -3.08837891e-02],
                        [ -2.34985352e-02,  -2.32238770e-02],
                        [ -1.46484375e-02,  -1.43432617e-02],
                        [ -1.29394531e-02,  -1.26037598e-02],
                        [ -2.01416016e-02,  -2.00805664e-02],
                        [ -3.14941406e-02,  -3.19824219e-02],
                        [ -4.22058105e-02,  -4.32128906e-02],
                        [ -4.99572754e-02,  -5.09338379e-02],
                        [ -5.28564453e-02,  -5.31005859e-02],
                        [ -4.82788086e-02,  -4.76379395e-02],
                        [ -3.51867676e-02,  -3.41491699e-02],
                        [ -1.62658691e-02,  -1.54418945e-02],
                        [  4.63867188e-03,   4.91333008e-03],
                        [  2.56042480e-02,   2.54821777e-02],
                        [  4.47998047e-02,   4.44641113e-02],
                        [  5.65795898e-02,   5.61828613e-02],
                        [  5.30395508e-02,   5.26733398e-02],
                        [  2.74353027e-02,   2.72827148e-02],
                        [ -2.32238770e-02,  -2.31018066e-02],
                        [ -9.47570801e-02,  -9.45739746e-02],
                        [ -1.73095703e-01,  -1.73217773e-01],
                        [ -2.36755371e-01,  -2.37243652e-01],
                        [ -2.64282227e-01,  -2.64831543e-01],
                        [ -2.46337891e-01,  -2.46459961e-01],
                        [ -1.96075439e-01,  -1.95495605e-01],
                        [ -1.43768311e-01,  -1.42669678e-01],
                        [ -1.13006592e-01,  -1.11907959e-01],
                        [ -1.02691650e-01,  -1.02081299e-01],
                        [ -9.67102051e-02,  -9.68933105e-02],
                        [ -8.62121582e-02,  -8.72192383e-02],
                        [ -7.46459961e-02,  -7.60498047e-02],
                        [ -6.57348633e-02,  -6.70166016e-02],
                        [ -5.75256348e-02,  -5.80139160e-02],
                        [ -4.68139648e-02,  -4.62951660e-02],
                        [ -3.17993164e-02,  -3.06396484e-02],
                        [ -1.06811523e-02,  -9.52148438e-03],
                        [  1.63574219e-02,   1.69372559e-02],
                        [  4.42810059e-02,   4.42504883e-02],
                        [  6.57653809e-02,   6.54296875e-02],
                        [  7.69042969e-02,   7.66296387e-02],
                        [  8.09326172e-02,   8.07495117e-02],
                        [  8.51440430e-02,   8.49304199e-02],
                        [  9.45739746e-02,   9.42993164e-02],
                        [  1.07604980e-01,   1.07299805e-01],
                        [  1.14135742e-01,   1.13983154e-01],
                        [  9.87243652e-02,   9.86938477e-02],
                        [  5.05981445e-02,   5.05676270e-02],
                        [ -2.52685547e-02,  -2.52380371e-02],
                        [ -1.06170654e-01,  -1.05895996e-01],
                        [ -1.61834717e-01,  -1.61193848e-01],
                        [ -1.72302246e-01,  -1.71539307e-01],
                        [ -1.42456055e-01,  -1.41998291e-01],
                        [ -9.87243652e-02,  -9.89379883e-02],
                        [ -6.88171387e-02,  -6.96105957e-02],
                        [ -6.05773926e-02,  -6.14929199e-02],
                        [ -5.96618652e-02,  -6.01501465e-02],
                        [ -5.02014160e-02,  -5.01403809e-02],
                        [ -3.40270996e-02,  -3.36608887e-02],
                        [ -2.28576660e-02,  -2.26135254e-02],
                        [ -2.06298828e-02,  -2.05383301e-02],
                        [ -2.31628418e-02,  -2.30407715e-02],
                        [ -2.77709961e-02,  -2.74047852e-02],
                        [ -3.25317383e-02,  -3.20739746e-02],
                        [ -3.17382812e-02,  -3.15246582e-02],
                        [ -1.93786621e-02,  -1.96838379e-02],
                        [  3.93676758e-03,   3.35693359e-03],
                        [  3.47900391e-02,   3.44238281e-02],
                        [  7.36999512e-02,   7.37304688e-02],
                        [  1.18804932e-01,   1.19018555e-01],
                        [  1.57348633e-01,   1.57440186e-01],
                        [  1.74224854e-01,   1.74072266e-01],
                        [  1.66625977e-01,   1.66351318e-01],
                        [  1.45507812e-01,   1.45446777e-01],
                        [  1.26037598e-01,   1.26251221e-01],
                        [  1.16455078e-01,   1.16790771e-01],
                        [  1.14624023e-01,   1.14837646e-01],
                        [  1.14898682e-01,   1.14929199e-01],
                        [  1.15112305e-01,   1.15051270e-01],
                        [  1.14776611e-01,   1.14746094e-01],
                        [  1.12060547e-01,   1.12060547e-01],
                        [  1.05957031e-01,   1.05865479e-01],
                        [  9.84191895e-02,   9.82360840e-02],
                        [  9.11560059e-02,   9.09118652e-02],
                        [  8.24279785e-02,   8.23364258e-02],
                        [  7.04040527e-02,   7.04956055e-02],
                        [  5.67016602e-02,   5.68847656e-02],
                        [  4.32434082e-02,   4.33959961e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  1.28173828e-02,   1.27563477e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.50451660e-02,  -1.49230957e-02],
                        [ -2.38647461e-02,  -2.36511230e-02],
                        [ -3.30505371e-02,  -3.29284668e-02],
                        [ -4.60205078e-02,  -4.60815430e-02],
                        [ -5.90820312e-02,  -5.93261719e-02],
                        [ -6.35986328e-02,  -6.38427734e-02],
                        [ -5.26733398e-02,  -5.27954102e-02],
                        [ -2.30407715e-02,  -2.29797363e-02],
                        [  2.36511230e-02,   2.37121582e-02],
                        [  7.56225586e-02,   7.55615234e-02],
                        [  1.12884521e-01,   1.12792969e-01],
                        [  1.21063232e-01,   1.21124268e-01],
                        [  1.03698730e-01,   1.03912354e-01],
                        [  7.83691406e-02,   7.86132812e-02],
                        [  5.98449707e-02,   5.99365234e-02],
                        [  4.83093262e-02,   4.82788086e-02],
                        [  3.55834961e-02,   3.54919434e-02],
                        [  1.88903809e-02,   1.88293457e-02],
                        [  4.02832031e-03,   3.96728516e-03],
                        [ -3.44848633e-03,  -3.60107422e-03],
                        [ -3.84521484e-03,  -4.05883789e-03],
                        [ -3.96728516e-04,  -5.49316406e-04],
                        [  3.02124023e-03,   3.08227539e-03],
                        [  1.80053711e-03,   2.04467773e-03],
                        [ -5.46264648e-03,  -5.24902344e-03],
                        [ -1.40075684e-02,  -1.39160156e-02],
                        [ -1.85241699e-02,  -1.86157227e-02],
                        [ -1.95007324e-02,  -1.95922852e-02],
                        [ -2.01416016e-02,  -2.01721191e-02],
                        [ -2.16369629e-02,  -2.15759277e-02],
                        [ -2.41394043e-02,  -2.40173340e-02],
                        [ -2.96630859e-02,  -2.95715332e-02],
                        [ -3.98864746e-02,  -3.98254395e-02],
                        [ -5.06286621e-02,  -5.07202148e-02],
                        [ -5.38940430e-02,  -5.41076660e-02],
                        [ -4.73632812e-02,  -4.76379395e-02],
                        [ -3.84521484e-02,  -3.86657715e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -3.48510742e-02,  -3.45764160e-02],
                        [ -3.18603516e-02,  -3.15246582e-02],
                        [ -2.17895508e-02,  -2.15759277e-02],
                        [ -3.57055664e-03,  -3.63159180e-03],
                        [  2.23999023e-02,   2.21862793e-02],
                        [  5.08728027e-02,   5.06591797e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  7.33337402e-02,   7.35168457e-02],
                        [  5.42602539e-02,   5.44738770e-02],
                        [  1.14440918e-02,   1.15051270e-02],
                        [ -5.77392578e-02,  -5.79223633e-02],
                        [ -1.47613525e-01,  -1.47918701e-01],
                        [ -2.34527588e-01,  -2.34802246e-01],
                        [ -2.84790039e-01,  -2.84881592e-01],
                        [ -2.78991699e-01,  -2.78900146e-01],
                        [ -2.29034424e-01,  -2.28790283e-01],
                        [ -1.68457031e-01,  -1.68151855e-01],
                        [ -1.25122070e-01,  -1.24877930e-01],
                        [ -1.03485107e-01,  -1.03393555e-01],
                        [ -9.18884277e-02,  -9.19494629e-02],
                        [ -8.01696777e-02,  -8.03833008e-02],
                        [ -6.69555664e-02,  -6.71997070e-02],
                        [ -5.53588867e-02,  -5.55114746e-02],
                        [ -4.78820801e-02,  -4.79125977e-02],
                        [ -4.36096191e-02,  -4.35485840e-02],
                        [ -3.71704102e-02,  -3.71093750e-02],
                        [ -2.33154297e-02,  -2.32849121e-02],
                        [ -2.86865234e-03,  -2.83813477e-03],
                        [  1.92260742e-02,   1.92871094e-02],
                        [  4.02526855e-02,   4.03747559e-02],
                        [  5.96008301e-02,   5.97229004e-02],
                        [  7.54394531e-02,   7.55004883e-02],
                        [  8.77380371e-02,   8.76770020e-02],
                        [  1.00189209e-01,   1.00067139e-01],
                        [  1.13006592e-01,   1.12884521e-01],
                        [  1.18560791e-01,   1.18469238e-01],
                        [  1.08215332e-01,   1.08184814e-01],
                        [  7.73315430e-02,   7.73620605e-02],
                        [  2.30712891e-02,   2.31018066e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -1.29333496e-01,  -1.29302979e-01],
                        [ -1.77642822e-01,  -1.77581787e-01],
                        [ -1.77886963e-01,  -1.77764893e-01],
                        [ -1.40502930e-01,  -1.40441895e-01],
                        [ -9.44519043e-02,  -9.45129395e-02],
                        [ -6.21948242e-02,  -6.23168945e-02],
                        [ -4.71191406e-02,  -4.72412109e-02],
                        [ -3.93676758e-02,  -3.94287109e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -1.63269043e-02,  -1.62658691e-02],
                        [ -1.09558105e-02,  -1.09252930e-02],
                        [ -2.15759277e-02,  -2.15454102e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -5.82885742e-02,  -5.83190918e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  3.69873047e-02,   3.70178223e-02],
                        [  7.74536133e-02,   7.74841309e-02],
                        [  1.19628906e-01,   1.19689941e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.82250977e-01,   1.82159424e-01],
                        [  1.89300537e-01,   1.89178467e-01],
                        [  1.75445557e-01,   1.75354004e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.17553711e-01,   1.17645264e-01],
                        [  1.01135254e-01,   1.01257324e-01],
                        [  9.79919434e-02,   9.80834961e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.08001709e-01,   1.07940674e-01],
                        [  1.12121582e-01,   1.12060547e-01],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  6.04553223e-02,   6.04248047e-02],
                        [  5.14221191e-02,   5.13916016e-02],
                        [  3.97949219e-02,   3.97644043e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.34069824e-02,   2.34375000e-02],
                        [  2.38647461e-02,   2.38952637e-02],
                        [  2.11791992e-02,   2.12402344e-02],
                        [  1.30920410e-02,   1.31225586e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -1.75170898e-02,  -1.75476074e-02],
                        [ -4.54711914e-02,  -4.55322266e-02],
                        [ -7.18078613e-02,  -7.18688965e-02],
                        [ -7.81555176e-02,  -7.81860352e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -1.61437988e-02,  -1.61132812e-02],
                        [  3.32031250e-02,   3.32641602e-02],
                        [  8.01086426e-02,   8.01391602e-02],
                        [  1.10229492e-01,   1.10229492e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  8.92333984e-02,   8.92333984e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.69055176e-02,   4.68750000e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  1.92565918e-02,   1.92871094e-02],
                        [  4.60815430e-03,   4.63867188e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.01623535e-02,  -1.01928711e-02],
                        [ -1.47705078e-02,  -1.48010254e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.02734375e-02,  -3.02429199e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.29895020e-02,  -3.30200195e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -1.94702148e-02,  -1.94396973e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  5.65185547e-02,   5.65185547e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.95129395e-01,  -1.95129395e-01],
                        [ -2.57873535e-01,  -2.57873535e-01],
                        [ -2.74291992e-01,  -2.74291992e-01],
                        [ -2.43988037e-01,  -2.43988037e-01],
                        [ -1.89056396e-01,  -1.89056396e-01],
                        [ -1.40136719e-01,  -1.40136719e-01],
                        [ -1.16149902e-01,  -1.16149902e-01],
                        [ -1.12548828e-01,  -1.12548828e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -1.01684570e-01,  -1.01684570e-01],
                        [ -8.62121582e-02,  -8.62121582e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  7.21435547e-02,   7.21435547e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  5.20629883e-02,   5.20629883e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.04278564e-01,  -1.04278564e-01],
                        [ -1.67266846e-01,  -1.67266846e-01],
                        [ -1.88262939e-01,  -1.88262939e-01],
                        [ -1.64794922e-01,  -1.64794922e-01],
                        [ -1.16729736e-01,  -1.16729736e-01],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  1.43859863e-01,   1.43859863e-01],
                        [  1.72241211e-01,   1.72241211e-01],
                        [  1.76544189e-01,   1.76544189e-01],
                        [  1.59027100e-01,   1.59027100e-01],
                        [  1.29211426e-01,   1.29211426e-01],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  8.73413086e-02,   8.73413086e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.35589600e-01,   1.35589600e-01],
                        [  1.28143311e-01,   1.28143311e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  8.35876465e-02,   8.35876465e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  5.11474609e-02,   5.11474609e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -1.34704590e-01,  -1.34704590e-01],
                        [ -2.12066650e-01,  -2.12066650e-01],
                        [ -2.62847900e-01,  -2.62847900e-01],
                        [ -2.71331787e-01,  -2.71331787e-01],
                        [ -2.40295410e-01,  -2.40295410e-01],
                        [ -1.90124512e-01,  -1.90124512e-01],
                        [ -1.44561768e-01,  -1.44561768e-01],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -1.08764648e-01,  -1.08764648e-01],
                        [ -1.07025146e-01,  -1.07025146e-01],
                        [ -9.93347168e-02,  -9.93347168e-02],
                        [ -8.19091797e-02,  -8.19091797e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  9.77172852e-02,   9.77172852e-02],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  5.33752441e-02,   5.33752441e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -1.37207031e-01,  -1.37207031e-01],
                        [ -1.91833496e-01,  -1.91833496e-01],
                        [ -1.88323975e-01,  -1.88323975e-01],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.82647705e-01,   1.82647705e-01],
                        [  2.14111328e-01,   2.14111328e-01],
                        [  2.10388184e-01,   2.10388184e-01],
                        [  1.77185059e-01,   1.77185059e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  7.81555176e-02,   7.81555176e-02],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  9.04541016e-02,   9.04541016e-02],
                        [  9.75341797e-02,   9.75341797e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  9.66186523e-02,   9.66186523e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.18743896e-01,   1.18743896e-01],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  5.24902344e-03,   5.24902344e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -1.38946533e-01,  -1.38946533e-01],
                        [ -2.14080811e-01,  -2.14080811e-01],
                        [ -2.60589600e-01,  -2.60589600e-01],
                        [ -2.63885498e-01,  -2.63885498e-01],
                        [ -2.31872559e-01,  -2.31872559e-01],
                        [ -1.88201904e-01,  -1.88201904e-01],
                        [ -1.51580811e-01,  -1.51580811e-01],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -9.14611816e-02,  -9.14611816e-02],
                        [ -7.98950195e-02,  -7.98950195e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -1.37084961e-01,  -1.37084961e-01],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -1.62292480e-01,  -1.62292480e-01],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  7.51342773e-02,   7.51342773e-02],
                        [  1.31286621e-01,   1.31286621e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.94458008e-01,   1.94458008e-01],
                        [  1.92596436e-01,   1.92596436e-01],
                        [  1.71478271e-01,   1.71478271e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  9.75036621e-02,   9.75036621e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  7.33337402e-02,   7.33337402e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -9.65576172e-02,  -9.65576172e-02],
                        [ -1.68853760e-01,  -1.68853760e-01],
                        [ -2.22839355e-01,  -2.22839355e-01],
                        [ -2.39105225e-01,  -2.39105225e-01],
                        [ -2.19482422e-01,  -2.19482422e-01],
                        [ -1.83959961e-01,  -1.83959961e-01],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -1.31164551e-01,  -1.31164551e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  8.89587402e-02,   8.89587402e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.14929199e-01,   1.14929199e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -1.50970459e-01,  -1.50970459e-01],
                        [ -1.89636230e-01,  -1.89636230e-01],
                        [ -1.77978516e-01,  -1.77978516e-01],
                        [ -1.36810303e-01,  -1.36810303e-01],
                        [ -9.55810547e-02,  -9.55810547e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.59667969e-01,   1.59667969e-01],
                        [  1.62170410e-01,   1.62170410e-01],
                        [  1.51336670e-01,   1.51336670e-01],
                        [  1.35711670e-01,   1.35711670e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  7.93457031e-04,   7.93457031e-04],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -1.14898682e-01,  -1.14898682e-01],
                        [ -1.92443848e-01,  -1.92443848e-01],
                        [ -2.44232178e-01,  -2.44232178e-01],
                        [ -2.55737305e-01,  -2.55737305e-01],
                        [ -2.34161377e-01,  -2.34161377e-01],
                        [ -1.98913574e-01,  -1.98913574e-01],
                        [ -1.64093018e-01,  -1.64093018e-01],
                        [ -1.33941650e-01,  -1.33941650e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -9.51232910e-02,  -9.51232910e-02],
                        [ -8.88977051e-02,  -8.88977051e-02],
                        [ -8.60290527e-02,  -8.60290527e-02],
                        [ -7.85522461e-02,  -7.85522461e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.17584229e-01,   1.17584229e-01],
                        [  1.28143311e-01,   1.28143311e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [ -7.67517090e-02,  -7.67517090e-02],
                        [ -1.51214600e-01,  -1.51214600e-01],
                        [ -1.84173584e-01,  -1.84173584e-01],
                        [ -1.69830322e-01,  -1.69830322e-01],
                        [ -1.28631592e-01,  -1.28631592e-01],
                        [ -8.86840820e-02,  -8.86840820e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  1.63299561e-01,   1.63299561e-01],
                        [  1.76635742e-01,   1.76635742e-01],
                        [  1.70989990e-01,   1.70989990e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.18835449e-01,   1.18835449e-01],
                        [  1.01623535e-01,   1.01623535e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  1.08856201e-01,   1.08856201e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -1.51855469e-01,  -1.51855469e-01],
                        [ -2.26135254e-01,  -2.26135254e-01],
                        [ -2.69195557e-01,  -2.69195557e-01],
                        [ -2.69897461e-01,  -2.69897461e-01],
                        [ -2.36755371e-01,  -2.36755371e-01],
                        [ -1.91680908e-01,  -1.91680908e-01],
                        [ -1.53717041e-01,  -1.53717041e-01],
                        [ -1.28356934e-01,  -1.28356934e-01],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -9.43603516e-02,  -9.43603516e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -1.32110596e-01,  -1.32110596e-01],
                        [ -1.64337158e-01,  -1.64337158e-01],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -1.25823975e-01,  -1.25823975e-01],
                        [ -9.73815918e-02,  -9.73815918e-02],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -7.14111328e-02,  -7.14111328e-02],
                        [ -6.39648438e-02,  -6.39648438e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  1.75170898e-01,   1.75170898e-01],
                        [  1.71386719e-01,   1.71386719e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  1.43463135e-01,   1.43463135e-01],
                        [  1.29455566e-01,   1.29455566e-01],
                        [  1.12121582e-01,   1.12121582e-01],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  1.01135254e-01,   1.01135254e-01],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.02233887e-01,  -1.02233887e-01],
                        [ -1.78131104e-01,  -1.78131104e-01],
                        [ -2.38433838e-01,  -2.38433838e-01],
                        [ -2.62573242e-01,  -2.62573242e-01],
                        [ -2.47802734e-01,  -2.47802734e-01],
                        [ -2.09625244e-01,  -2.09625244e-01],
                        [ -1.69494629e-01,  -1.69494629e-01],
                        [ -1.41082764e-01,  -1.41082764e-01],
                        [ -1.24023438e-01,  -1.24023438e-01],
                        [ -1.09893799e-01,  -1.09893799e-01],
                        [ -9.23767090e-02,  -9.23767090e-02],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [ -8.76770020e-02,  -8.76770020e-02],
                        [ -1.69860840e-01,  -1.69860840e-01],
                        [ -2.06268311e-01,  -2.06268311e-01],
                        [ -1.86950684e-01,  -1.86950684e-01],
                        [ -1.35375977e-01,  -1.35375977e-01],
                        [ -8.80737305e-02,  -8.80737305e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  1.45385742e-01,   1.45385742e-01],
                        [  1.57836914e-01,   1.57836914e-01],
                        [  1.50054932e-01,   1.50054932e-01],
                        [  1.29455566e-01,   1.29455566e-01],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  8.66699219e-02,   8.66699219e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -1.94061279e-01,  -1.94061279e-01],
                        [ -2.62756348e-01,  -2.62756348e-01],
                        [ -2.87841797e-01,  -2.87841797e-01],
                        [ -2.65197754e-01,  -2.65197754e-01],
                        [ -2.12677002e-01,  -2.12677002e-01],
                        [ -1.61102295e-01,  -1.61102295e-01],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  1.12823486e-01,   1.12823486e-01],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -1.07940674e-01,  -1.07940674e-01],
                        [ -1.58721924e-01,  -1.58721924e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.47705078e-01,  -1.47705078e-01],
                        [ -1.14471436e-01,  -1.14471436e-01],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -8.95996094e-02,  -8.95996094e-02],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -8.53576660e-02,  -8.53576660e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.41998291e-01,   1.41998291e-01],
                        [  1.57379150e-01,   1.57379150e-01],
                        [  1.51916504e-01,   1.51916504e-01],
                        [  1.39160156e-01,   1.39160156e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  7.52868652e-02,   7.52868652e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  6.90307617e-02,   6.90307617e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -2.16064453e-01,  -2.16064453e-01],
                        [ -2.82562256e-01,  -2.82562256e-01],
                        [ -3.00323486e-01,  -3.00323486e-01],
                        [ -2.64892578e-01,  -2.64892578e-01],
                        [ -1.99737549e-01,  -1.99737549e-01],
                        [ -1.40869141e-01,  -1.40869141e-01],
                        [ -1.10107422e-01,  -1.10107422e-01],
                        [ -1.02416992e-01,  -1.02416992e-01],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -8.19702148e-02,  -8.19702148e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  7.87963867e-02,   7.87963867e-02],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  1.36749268e-01,   1.36749268e-01],
                        [  1.23779297e-01,   1.23779297e-01],
                        [  6.95495605e-02,   6.95495605e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -1.86309814e-01,  -1.86309814e-01],
                        [ -2.07244873e-01,  -2.07244873e-01],
                        [ -1.85455322e-01,  -1.85455322e-01],
                        [ -1.42791748e-01,  -1.42791748e-01],
                        [ -1.04431152e-01,  -1.04431152e-01],
                        [ -8.15124512e-02,  -8.15124512e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  1.29302979e-01,   1.29302979e-01],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  9.67102051e-02,   9.67102051e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  8.18176270e-02,   8.18176270e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -1.38793945e-01,  -1.38793945e-01],
                        [ -2.24975586e-01,  -2.24975586e-01],
                        [ -2.80761719e-01,  -2.80761719e-01],
                        [ -2.89825439e-01,  -2.89825439e-01],
                        [ -2.55615234e-01,  -2.55615234e-01],
                        [ -1.99310303e-01,  -1.99310303e-01],
                        [ -1.47766113e-01,  -1.47766113e-01],
                        [ -1.16210938e-01,  -1.16210938e-01],
                        [ -1.01257324e-01,  -1.01257324e-01],
                        [ -9.20410156e-02,  -9.20410156e-02],
                        [ -8.29162598e-02,  -8.29162598e-02],
                        [ -7.14721680e-02,  -7.14721680e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  3.75671387e-02,   3.75671387e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -1.48620605e-01,  -1.48620605e-01],
                        [ -2.07122803e-01,  -2.07122803e-01],
                        [ -2.12585449e-01,  -2.12585449e-01],
                        [ -1.75140381e-01,  -1.75140381e-01],
                        [ -1.21520996e-01,  -1.21520996e-01],
                        [ -7.20825195e-02,  -7.20825195e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.06414795e-01,   1.06414795e-01],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.02264404e-01,   1.02264404e-01],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -1.30950928e-01,  -1.30950928e-01],
                        [ -1.93389893e-01,  -1.93389893e-01],
                        [ -2.37731934e-01,  -2.37731934e-01],
                        [ -2.51770020e-01,  -2.51770020e-01],
                        [ -2.31231689e-01,  -2.31231689e-01],
                        [ -1.90460205e-01,  -1.90460205e-01],
                        [ -1.55212402e-01,  -1.55212402e-01],
                        [ -1.38000488e-01,  -1.38000488e-01],
                        [ -1.29150391e-01,  -1.29150391e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -2.03887939e-01,  -2.03887939e-01],
                        [ -1.90429688e-01,  -1.90429688e-01],
                        [ -1.30828857e-01,  -1.30828857e-01],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  6.36596680e-02,   6.36596680e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -1.13433838e-01,  -1.13433838e-01],
                        [ -1.45751953e-01,  -1.45751953e-01],
                        [ -1.70318604e-01,  -1.70318604e-01],
                        [ -1.83258057e-01,  -1.83258057e-01],
                        [ -1.83868408e-01,  -1.83868408e-01],
                        [ -1.75476074e-01,  -1.75476074e-01],
                        [ -1.62567139e-01,  -1.62567139e-01],
                        [ -1.48132324e-01,  -1.48132324e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -1.12274170e-01,  -1.12274170e-01],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.44714355e-01,   1.44714355e-01],
                        [  1.44989014e-01,   1.44989014e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  6.31408691e-02,   6.31408691e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -1.06048584e-01,  -1.06048584e-01],
                        [ -1.68853760e-01,  -1.68853760e-01],
                        [ -1.84295654e-01,  -1.84295654e-01],
                        [ -1.51245117e-01,  -1.51245117e-01],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  9.29260254e-02,   9.29260254e-02],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.11785889e-01,   1.11785889e-01],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -1.52374268e-01,  -1.52374268e-01],
                        [ -1.96594238e-01,  -1.96594238e-01],
                        [ -2.17010498e-01,  -2.17010498e-01],
                        [ -2.11822510e-01,  -2.11822510e-01],
                        [ -1.93572998e-01,  -1.93572998e-01],
                        [ -1.74316406e-01,  -1.74316406e-01],
                        [ -1.55456543e-01,  -1.55456543e-01],
                        [ -1.33209229e-01,  -1.33209229e-01],
                        [ -1.08978271e-01,  -1.08978271e-01],
                        [ -8.85009766e-02,  -8.85009766e-02],
                        [ -7.38525391e-02,  -7.38525391e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  8.62426758e-02,   8.62426758e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.44348145e-01,   1.44348145e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -1.41784668e-01,  -1.41784668e-01],
                        [ -1.75079346e-01,  -1.75079346e-01],
                        [ -1.50238037e-01,  -1.50238037e-01],
                        [ -8.09631348e-02,  -8.09631348e-02],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  6.65283203e-02,   6.65283203e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  8.38623047e-02,   8.38623047e-02],
                        [  8.63342285e-02,   8.63342285e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -1.30279541e-01,  -1.30279541e-01],
                        [ -2.06817627e-01,  -2.06817627e-01],
                        [ -2.60375977e-01,  -2.60375977e-01],
                        [ -2.77313232e-01,  -2.77313232e-01],
                        [ -2.55004883e-01,  -2.55004883e-01],
                        [ -2.06970215e-01,  -2.06970215e-01],
                        [ -1.57226562e-01,  -1.57226562e-01],
                        [ -1.23779297e-01,  -1.23779297e-01],
                        [ -1.07666016e-01,  -1.07666016e-01],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -9.29565430e-02,  -9.29565430e-02],
                        [ -8.64257812e-02,  -8.64257812e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -7.77282715e-02,  -7.77282715e-02],
                        [ -1.16546631e-01,  -1.16546631e-01],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.17431641e-01,   1.17431641e-01],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -1.04125977e-01,  -1.04125977e-01],
                        [ -1.78649902e-01,  -1.78649902e-01],
                        [ -2.26409912e-01,  -2.26409912e-01],
                        [ -2.37060547e-01,  -2.37060547e-01],
                        [ -2.17468262e-01,  -2.17468262e-01],
                        [ -1.85699463e-01,  -1.85699463e-01],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -1.41815186e-01,  -1.41815186e-01],
                        [ -1.30004883e-01,  -1.30004883e-01],
                        [ -1.15539551e-01,  -1.15539551e-01],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -7.16247559e-02,  -7.16247559e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.37725830e-01,   1.37725830e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  7.06787109e-02,   7.06787109e-02],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.10809326e-01,   1.10809326e-01],
                        [  7.90405273e-02,   7.90405273e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -1.69189453e-01,  -1.69189453e-01],
                        [ -2.32238770e-01,  -2.32238770e-01],
                        [ -2.56622314e-01,  -2.56622314e-01],
                        [ -2.40753174e-01,  -2.40753174e-01],
                        [ -2.05474854e-01,  -2.05474854e-01],
                        [ -1.74163818e-01,  -1.74163818e-01],
                        [ -1.55090332e-01,  -1.55090332e-01],
                        [ -1.40716553e-01,  -1.40716553e-01],
                        [ -1.21307373e-01,  -1.21307373e-01],
                        [ -9.73815918e-02,  -9.73815918e-02],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  1.13037109e-01,   1.13037109e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.32934570e-01,   1.32934570e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  4.36401367e-02,   4.36401367e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -2.03704834e-01,  -2.03704834e-01],
                        [ -2.43591309e-01,  -2.43591309e-01],
                        [ -2.52502441e-01,  -2.52502441e-01],
                        [ -2.34466553e-01,  -2.34466553e-01],
                        [ -2.01019287e-01,  -2.01019287e-01],
                        [ -1.66320801e-01,  -1.66320801e-01],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.20910645e-01,  -1.20910645e-01],
                        [ -1.04034424e-01,  -1.04034424e-01],
                        [ -8.38317871e-02,  -8.38317871e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  1.49536133e-03,   1.49536133e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  1.38519287e-01,   1.38519287e-01],
                        [  1.80755615e-01,   1.80755615e-01],
                        [  2.14263916e-01,   2.14263916e-01],
                        [  2.22534180e-01,   2.22534180e-01],
                        [  1.90704346e-01,   1.90704346e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.21765137e-02,   1.21765137e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -9.93957520e-02,  -9.93957520e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.94384766e-02,   4.94384766e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  1.22680664e-01,   1.22680664e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -9.52758789e-02,  -9.52758789e-02],
                        [ -1.82403564e-01,  -1.82403564e-01],
                        [ -2.54608154e-01,  -2.54608154e-01],
                        [ -2.89245605e-01,  -2.89245605e-01],
                        [ -2.74688721e-01,  -2.74688721e-01],
                        [ -2.25677490e-01,  -2.25677490e-01],
                        [ -1.75476074e-01,  -1.75476074e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.26922607e-01,  -1.26922607e-01],
                        [ -1.12426758e-01,  -1.12426758e-01],
                        [ -1.00097656e-01,  -1.00097656e-01],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.59332275e-01,   1.59332275e-01],
                        [  2.10205078e-01,   2.10205078e-01],
                        [  2.55493164e-01,   2.55493164e-01],
                        [  2.77313232e-01,   2.77313232e-01],
                        [  2.56072998e-01,   2.56072998e-01],
                        [  1.79748535e-01,   1.79748535e-01],
                        [  6.11877441e-02,   6.11877441e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -1.35925293e-01,  -1.35925293e-01],
                        [ -1.53320312e-01,  -1.53320312e-01],
                        [ -1.25305176e-01,  -1.25305176e-01],
                        [ -8.16955566e-02,  -8.16955566e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  3.46679688e-02,   3.46679688e-02],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  1.08367920e-01,   1.08367920e-01],
                        [  9.12780762e-02,   9.12780762e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.70898438e-02,   1.70593262e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.14331055e-02,  -3.14636230e-02],
                        [ -1.99584961e-02,  -1.99890137e-02],
                        [ -8.05664062e-03,  -8.08715820e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  9.67407227e-03,   9.70458984e-03],
                        [  2.13317871e-02,   2.13623047e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  1.15905762e-01,   1.15875244e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [ -1.02233887e-02,  -1.01623535e-02],
                        [ -8.22753906e-02,  -8.22143555e-02],
                        [ -1.66412354e-01,  -1.66381836e-01],
                        [ -2.42218018e-01,  -2.42248535e-01],
                        [ -2.81829834e-01,  -2.81890869e-01],
                        [ -2.74871826e-01,  -2.74932861e-01],
                        [ -2.36358643e-01,  -2.36389160e-01],
                        [ -1.92230225e-01,  -1.92199707e-01],
                        [ -1.60003662e-01,  -1.59973145e-01],
                        [ -1.40625000e-01,  -1.40594482e-01],
                        [ -1.24816895e-01,  -1.24786377e-01],
                        [ -1.06719971e-01,  -1.06689453e-01],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -7.55615234e-02,  -7.56225586e-02],
                        [ -6.49108887e-02,  -6.49414062e-02],
                        [ -5.41076660e-02,  -5.41381836e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -2.87170410e-02,  -2.86865234e-02],
                        [ -1.61132812e-02,  -1.60827637e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.32751465e-02,   1.32446289e-02],
                        [  1.33972168e-02,   1.33361816e-02],
                        [  8.51440430e-03,   8.48388672e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [ -4.82177734e-03,  -4.76074219e-03],
                        [ -1.19018555e-03,  -1.12915039e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  3.99780273e-03,   3.96728516e-03],
                        [ -3.44848633e-03,  -3.50952148e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [  1.30615234e-02,   1.30920410e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.45965576e-01,   1.45935059e-01],
                        [  2.28485107e-01,   2.28454590e-01],
                        [  2.93121338e-01,   2.93151855e-01],
                        [  3.25042725e-01,   3.25134277e-01],
                        [  3.16772461e-01,   3.16833496e-01],
                        [  2.63671875e-01,   2.63641357e-01],
                        [  1.67541504e-01,   1.67419434e-01],
                        [  4.47082520e-02,   4.45556641e-02],
                        [ -7.37304688e-02,  -7.37609863e-02],
                        [ -1.52709961e-01,  -1.52618408e-01],
                        [ -1.71295166e-01,  -1.71142578e-01],
                        [ -1.37725830e-01,  -1.37603760e-01],
                        [ -8.55102539e-02,  -8.55407715e-02],
                        [ -4.73632812e-02,  -4.74548340e-02],
                        [ -3.14331055e-02,  -3.15856934e-02],
                        [ -2.70080566e-02,  -2.70690918e-02],
                        [ -2.56347656e-02,  -2.56042480e-02],
                        [ -2.82592773e-02,  -2.81066895e-02],
                        [ -3.53698730e-02,  -3.52478027e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.23181152e-02,  -3.24096680e-02],
                        [ -7.78198242e-03,  -7.90405273e-03],
                        [  2.40173340e-02,   2.39868164e-02],
                        [  4.86145020e-02,   4.87060547e-02],
                        [  6.06689453e-02,   6.08215332e-02],
                        [  6.43615723e-02,   6.44531250e-02],
                        [  6.17675781e-02,   6.17065430e-02],
                        [  5.01098633e-02,   4.99267578e-02],
                        [  2.99072266e-02,   2.97241211e-02],
                        [  8.57543945e-03,   8.51440430e-03],
                        [ -5.88989258e-03,  -5.79833984e-03],
                        [ -1.08032227e-02,  -1.05590820e-02],
                        [ -9.15527344e-03,  -8.94165039e-03],
                        [ -5.95092773e-03,  -5.88989258e-03],
                        [ -3.60107422e-03,  -3.78417969e-03],
                        [ -2.74658203e-03,  -3.05175781e-03],
                        [ -5.49316406e-03,  -5.73730469e-03],
                        [ -1.33972168e-02,  -1.34277344e-02],
                        [ -2.38952637e-02,  -2.36511230e-02],
                        [ -3.37219238e-02,  -3.33862305e-02],
                        [ -4.21142578e-02,  -4.19006348e-02],
                        [ -4.72412109e-02,  -4.73327637e-02],
                        [ -4.38232422e-02,  -4.40673828e-02],
                        [ -2.54821777e-02,  -2.56958008e-02],
                        [  1.10473633e-02,   1.09558105e-02],
                        [  6.06994629e-02,   6.07910156e-02],
                        [  1.06811523e-01,   1.06903076e-01],
                        [  1.30187988e-01,   1.30249023e-01],
                        [  1.25823975e-01,   1.25793457e-01],
                        [  1.04553223e-01,   1.04522705e-01],
                        [  8.00170898e-02,   8.00170898e-02],
                        [  6.03637695e-02,   6.03942871e-02],
                        [  4.79431152e-02,   4.80346680e-02],
                        [  3.89099121e-02,   3.89709473e-02],
                        [  2.78015137e-02,   2.77404785e-02],
                        [  1.55334473e-02,   1.52893066e-02],
                        [  6.80541992e-03,   6.50024414e-03],
                        [  9.46044922e-04,   8.54492188e-04],
                        [ -7.99560547e-03,  -7.78198242e-03],
                        [ -2.26440430e-02,  -2.22167969e-02],
                        [ -3.65905762e-02,  -3.62548828e-02],
                        [ -3.96118164e-02,  -3.95812988e-02],
                        [ -2.85339355e-02,  -2.88696289e-02],
                        [ -1.06201172e-02,  -1.11083984e-02],
                        [  5.03540039e-03,   4.73022461e-03],
                        [  1.52587891e-02,   1.53503418e-02],
                        [  2.15454102e-02,   2.19421387e-02],
                        [  2.63977051e-02,   2.67333984e-02],
                        [  3.21044922e-02,   3.21960449e-02],
                        [  3.88183594e-02,   3.86657715e-02],
                        [  4.42504883e-02,   4.40673828e-02],
                        [  5.02929688e-02,   5.02624512e-02],
                        [  6.42700195e-02,   6.43615723e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  1.10229492e-01,   1.10046387e-01],
                        [  1.18560791e-01,   1.18347168e-01],
                        [  1.05041504e-01,   1.04980469e-01],
                        [  6.87255859e-02,   6.89392090e-02],
                        [  1.37329102e-02,   1.40686035e-02],
                        [ -5.55725098e-02,  -5.52673340e-02],
                        [ -1.36688232e-01,  -1.36627197e-01],
                        [ -2.19879150e-01,  -2.20092773e-01],
                        [ -2.81188965e-01,  -2.81555176e-01],
                        [ -2.95806885e-01,  -2.96142578e-01],
                        [ -2.60437012e-01,  -2.60620117e-01],
                        [ -1.98669434e-01,  -1.98577881e-01],
                        [ -1.42944336e-01,  -1.42517090e-01],
                        [ -1.13098145e-01,  -1.12548828e-01],
                        [ -1.08123779e-01,  -1.07788086e-01],
                        [ -1.11938477e-01,  -1.12121582e-01],
                        [ -1.08398438e-01,  -1.09039307e-01],
                        [ -9.54589844e-02,  -9.60388184e-02],
                        [ -8.24584961e-02,  -8.25805664e-02],
                        [ -7.26623535e-02,  -7.22656250e-02],
                        [ -5.67321777e-02,  -5.61523438e-02],
                        [ -2.85034180e-02,  -2.81982422e-02],
                        [  2.34985352e-03,   2.13623047e-03],
                        [  2.17285156e-02,   2.12707520e-02],
                        [  2.71606445e-02,   2.69165039e-02],
                        [  2.37426758e-02,   2.38952637e-02],
                        [  1.23291016e-02,   1.26647949e-02],
                        [ -7.47680664e-03,  -7.26318359e-03],
                        [ -2.77404785e-02,  -2.78625488e-02],
                        [ -3.62854004e-02,  -3.65905762e-02],
                        [ -3.08227539e-02,  -3.10974121e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.24206543e-02,  -1.21765137e-02],
                        [ -5.70678711e-03,  -5.46264648e-03],
                        [ -1.67846680e-03,  -1.61743164e-03],
                        [ -4.05883789e-03,  -4.08935547e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  6.34765625e-03,   6.22558594e-03],
                        [  3.59497070e-02,   3.56750488e-02],
                        [  8.39843750e-02,   8.37402344e-02],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  2.23937988e-01,   2.24334717e-01],
                        [  2.82806396e-01,   2.83416748e-01],
                        [  3.11157227e-01,   3.11523438e-01],
                        [  3.05328369e-01,   3.05053711e-01],
                        [  2.69805908e-01,   2.69073486e-01],
                        [  2.08984375e-01,   2.08343506e-01],
                        [  1.23870850e-01,   1.23870850e-01],
                        [  1.95617676e-02,   2.01416016e-02],
                        [ -8.41979980e-02,  -8.35571289e-02],
                        [ -1.55609131e-01,  -1.55364990e-01],
                        [ -1.70349121e-01,  -1.70593262e-01],
                        [ -1.32873535e-01,  -1.33270264e-01],
                        [ -7.76672363e-02,  -7.79113770e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -3.61022949e-02,  -3.59802246e-02],
                        [ -4.32739258e-02,  -4.31518555e-02],
                        [ -4.94384766e-02,  -4.93469238e-02],
                        [ -5.52368164e-02,  -5.51757812e-02],
                        [ -6.30187988e-02,  -6.30493164e-02],
                        [ -6.49414062e-02,  -6.51245117e-02],
                        [ -5.06286621e-02,  -5.08117676e-02],
                        [ -1.97143555e-02,  -1.96838379e-02],
                        [  1.75170898e-02,   1.77917480e-02],
                        [  4.80957031e-02,   4.84313965e-02],
                        [  6.35375977e-02,   6.36596680e-02],
                        [  6.33850098e-02,   6.31103516e-02],
                        [  5.37109375e-02,   5.31616211e-02],
                        [  4.08630371e-02,   4.03747559e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.16882324e-02,   1.22680664e-02],
                        [ -1.83105469e-03,  -1.00708008e-03],
                        [ -8.54492188e-03,  -8.08715820e-03],
                        [ -8.54492188e-03,  -8.78906250e-03],
                        [ -8.81958008e-03,  -9.70458984e-03],
                        [ -1.43127441e-02,  -1.51977539e-02],
                        [ -2.13012695e-02,  -2.15148926e-02],
                        [ -2.45056152e-02,  -2.39257812e-02],
                        [ -2.54821777e-02,  -2.46276855e-02],
                        [ -2.95410156e-02,  -2.90832520e-02],
                        [ -3.78723145e-02,  -3.80554199e-02],
                        [ -4.55017090e-02,  -4.59594727e-02],
                        [ -4.46777344e-02,  -4.49523926e-02],
                        [ -2.90832520e-02,  -2.90527344e-02],
                        [  2.07519531e-03,   2.25830078e-03],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  8.30688477e-02,   8.27941895e-02],
                        [  1.11389160e-01,   1.11022949e-01],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.03973389e-01,   1.04431152e-01],
                        [  7.42797852e-02,   7.49511719e-02],
                        [  4.50744629e-02,   4.55017090e-02],
                        [  2.71301270e-02,   2.69775391e-02],
                        [  1.95007324e-02,   1.87988281e-02],
                        [  1.60217285e-02,   1.51367188e-02],
                        [  1.38854980e-02,   1.33972168e-02],
                        [  1.15661621e-02,   1.17492676e-02],
                        [  6.25610352e-03,   6.95800781e-03],
                        [ -1.70898438e-03,  -7.93457031e-04],
                        [ -7.90405273e-03,  -7.26318359e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -7.72094727e-03,  -8.45336914e-03],
                        [ -4.97436523e-03,  -6.07299805e-03],
                        [ -3.44848633e-03,  -4.18090820e-03],
                        [ -4.39453125e-03,  -4.21142578e-03],
                        [ -7.01904297e-03,  -6.10351562e-03],
                        [ -7.96508789e-03,  -7.01904297e-03],
                        [ -3.20434570e-03,  -2.99072266e-03],
                        [  8.85009766e-03,   8.23974609e-03],
                        [  2.67944336e-02,   2.60620117e-02],
                        [  4.67224121e-02,   4.66003418e-02],
                        [  6.44531250e-02,   6.49414062e-02],
                        [  7.87963867e-02,   7.93457031e-02],
                        [  9.11254883e-02,   9.12170410e-02],
                        [  1.02600098e-01,   1.02050781e-01],
                        [  1.12213135e-01,   1.11358643e-01],
                        [  1.12060547e-01,   1.11602783e-01],
                        [  8.63647461e-02,   8.67004395e-02],
                        [  2.42004395e-02,   2.52685547e-02],
                        [ -6.66198730e-02,  -6.54602051e-02],
                        [ -1.64581299e-01,  -1.64093018e-01],
                        [ -2.48443604e-01,  -2.49084473e-01],
                        [ -3.00445557e-01,  -3.02032471e-01],
                        [ -3.06121826e-01,  -3.07708740e-01],
                        [ -2.66357422e-01,  -2.66693115e-01],
                        [ -2.07519531e-01,  -2.06207275e-01],
                        [ -1.63085938e-01,  -1.61010742e-01],
                        [ -1.41632080e-01,  -1.40350342e-01],
                        [ -1.25061035e-01,  -1.25488281e-01],
                        [ -9.82055664e-02,  -9.99145508e-02],
                        [ -6.79321289e-02,  -6.96411133e-02],
                        [ -5.07202148e-02,  -5.12084961e-02],
                        [ -5.12390137e-02,  -5.02014160e-02],
                        [ -5.80749512e-02,  -5.63964844e-02],
                        [ -5.66406250e-02,  -5.56945801e-02],
                        [ -4.27246094e-02,  -4.32739258e-02],
                        [ -2.44140625e-02,  -2.58178711e-02],
                        [ -1.15661621e-02,  -1.26037598e-02],
                        [ -5.58471680e-03,  -5.37109375e-03],
                        [ -1.34277344e-03,  -1.52587891e-04],
                        [  3.17382812e-03,   4.36401367e-03],
                        [  4.08935547e-03,   4.30297852e-03],
                        [ -2.59399414e-03,  -3.57055664e-03],
                        [ -1.52282715e-02,  -1.65710449e-02],
                        [ -2.73742676e-02,  -2.80151367e-02],
                        [ -3.45458984e-02,  -3.40881348e-02],
                        [ -3.73840332e-02,  -3.63159180e-02],
                        [ -3.77197266e-02,  -3.68041992e-02],
                        [ -3.58886719e-02,  -3.56445312e-02],
                        [ -3.22265625e-02,  -3.26538086e-02],
                        [ -2.52075195e-02,  -2.58789062e-02],
                        [ -8.20922852e-03,  -8.75854492e-03],
                        [  2.61840820e-02,   2.58789062e-02],
                        [  7.81555176e-02,   7.81250000e-02],
                        [  1.39587402e-01,   1.39984131e-01],
                        [  1.99279785e-01,   2.00042725e-01],
                        [  2.46093750e-01,   2.46704102e-01],
                        [  2.70141602e-01,   2.70019531e-01],
                        [  2.68096924e-01,   2.67364502e-01],
                        [  2.48229980e-01,   2.47619629e-01],
                        [  2.25067139e-01,   2.25097656e-01],
                        [  2.04406738e-01,   2.04895020e-01],
                        [  1.75140381e-01,   1.75476074e-01],
                        [  1.19628906e-01,   1.19354248e-01],
                        [  3.38745117e-02,   3.32946777e-02],
                        [ -6.28051758e-02,  -6.29577637e-02],
                        [ -1.37573242e-01,  -1.36901855e-01],
                        [ -1.66748047e-01,  -1.65710449e-01],
                        [ -1.53381348e-01,  -1.53106689e-01],
                        [ -1.22131348e-01,  -1.23016357e-01],
                        [ -9.59167480e-02,  -9.72290039e-02],
                        [ -8.08715820e-02,  -8.13598633e-02],
                        [ -7.09838867e-02,  -7.01904297e-02],
                        [ -5.94787598e-02,  -5.81665039e-02],
                        [ -4.41284180e-02,  -4.34875488e-02],
                        [ -2.67639160e-02,  -2.73742676e-02],
                        [ -1.24816895e-02,  -1.37023926e-02],
                        [ -5.55419922e-03,  -6.10351562e-03],
                        [ -2.80761719e-03,  -2.07519531e-03],
                        [  4.05883789e-03,   5.37109375e-03],
                        [  1.58691406e-02,   1.63574219e-02],
                        [  2.39868164e-02,   2.30102539e-02],
                        [  2.45056152e-02,   2.28576660e-02],
                        [  2.43530273e-02,   2.35595703e-02],
                        [  2.75878906e-02,   2.85339355e-02],
                        [  2.67333984e-02,   2.86254883e-02],
                        [  1.62048340e-02,   1.74560547e-02],
                        [  3.69262695e-03,   3.23486328e-03],
                        [ -3.41796875e-03,  -5.03540039e-03],
                        [ -9.97924805e-03,  -1.13220215e-02],
                        [ -1.97143555e-02,  -1.98364258e-02],
                        [ -2.42309570e-02,  -2.34375000e-02],
                        [ -1.96228027e-02,  -1.87683105e-02],
                        [ -1.89514160e-02,  -1.86462402e-02],
                        [ -3.29895020e-02,  -3.31115723e-02],
                        [ -5.08728027e-02,  -5.09948730e-02],
                        [ -5.39245605e-02,  -5.37414551e-02],
                        [ -3.93066406e-02,  -3.90930176e-02],
                        [ -1.84936523e-02,  -1.87072754e-02],
                        [  1.89208984e-03,   1.15966797e-03],
                        [  2.57568359e-02,   2.49938965e-02],
                        [  5.53894043e-02,   5.51757812e-02],
                        [  8.32824707e-02,   8.38012695e-02],
                        [  9.89685059e-02,   1.00036621e-01],
                        [  9.88464355e-02,   9.98840332e-02],
                        [  8.63342285e-02,   8.66699219e-02],
                        [  6.86035156e-02,   6.79626465e-02],
                        [  5.35583496e-02,   5.22766113e-02],
                        [  4.32739258e-02,   4.22363281e-02],
                        [  3.26232910e-02,   3.24401855e-02],
                        [  1.92260742e-02,   1.97143555e-02],
                        [  9.27734375e-03,   1.01013184e-02],
                        [  8.27026367e-03,   9.12475586e-03],
                        [  1.09252930e-02,   1.15356445e-02],
                        [  8.17871094e-03,   8.23974609e-03],
                        [ -5.49316406e-04,  -1.22070312e-03],
                        [ -9.70458984e-03,  -1.08947754e-02],
                        [ -1.71813965e-02,  -1.81884766e-02],
                        [ -2.21862793e-02,  -2.21252441e-02],
                        [ -1.97753906e-02,  -1.85546875e-02],
                        [ -6.65283203e-03,  -5.24902344e-03],
                        [  1.20544434e-02,   1.23596191e-02],
                        [  2.72827148e-02,   2.61840820e-02],
                        [  3.52478027e-02,   3.38134766e-02],
                        [  4.06799316e-02,   4.02526855e-02],
                        [  5.07812500e-02,   5.18188477e-02],
                        [  6.78710938e-02,   6.95190430e-02],
                        [  8.98437500e-02,   9.06677246e-02],
                        [  1.13494873e-01,   1.12670898e-01],
                        [  1.33880615e-01,   1.31927490e-01],
                        [  1.42669678e-01,   1.41082764e-01],
                        [  1.29455566e-01,   1.29516602e-01],
                        [  8.61511230e-02,   8.78601074e-02],
                        [  1.11999512e-02,   1.33666992e-02],
                        [ -8.81347656e-02,  -8.70361328e-02],
                        [ -1.93572998e-01,  -1.94152832e-01],
                        [ -2.76580811e-01,  -2.78472900e-01],
                        [ -3.11889648e-01,  -3.13934326e-01],
                        [ -2.94219971e-01,  -2.95074463e-01],
                        [ -2.41516113e-01,  -2.40631104e-01],
                        [ -1.83349609e-01,  -1.81365967e-01],
                        [ -1.41845703e-01,  -1.40136719e-01],
                        [ -1.17828369e-01,  -1.17492676e-01],
                        [ -9.81750488e-02,  -9.93347168e-02],
                        [ -7.68127441e-02,  -7.86132812e-02],
                        [ -6.21337891e-02,  -6.32629395e-02],
                        [ -6.30187988e-02,  -6.25915527e-02],
                        [ -7.40356445e-02,  -7.23876953e-02],
                        [ -7.88879395e-02,  -7.74230957e-02],
                        [ -6.70166016e-02,  -6.71081543e-02],
                        [ -4.16564941e-02,  -4.32739258e-02],
                        [ -1.25122070e-02,  -1.42517090e-02],
                        [  1.21459961e-02,   1.19018555e-02],
                        [  2.78625488e-02,   2.94799805e-02],
                        [  3.42712402e-02,   3.64685059e-02],
                        [  3.10058594e-02,   3.18908691e-02],
                        [  1.49230957e-02,   1.37329102e-02],
                        [ -1.24206543e-02,  -1.47399902e-02],
                        [ -3.85742188e-02,  -4.02221680e-02],
                        [ -5.07507324e-02,  -5.05371094e-02],
                        [ -4.93774414e-02,  -4.75463867e-02],
                        [ -4.52575684e-02,  -4.32434082e-02],
                        [ -4.51660156e-02,  -4.44641113e-02],
                        [ -4.44335938e-02,  -4.54101562e-02],
                        [ -3.39660645e-02,  -3.57666016e-02],
                        [ -1.04675293e-02,  -1.15661621e-02],
                        [  2.52075195e-02,   2.55737305e-02],
                        [  7.44934082e-02,   7.58361816e-02],
                        [  1.36566162e-01,   1.37603760e-01],
                        [  1.97875977e-01,   1.97692871e-01],
                        [  2.36145020e-01,   2.34954834e-01],
                        [  2.40417480e-01,   2.39349365e-01],
                        [  2.23571777e-01,   2.23632812e-01],
                        [  2.09594727e-01,   2.10784912e-01],
                        [  2.09533691e-01,   2.10968018e-01],
                        [  2.14599609e-01,   2.15179443e-01],
                        [  2.09320068e-01,   2.08465576e-01],
                        [  1.83197021e-01,   1.81304932e-01],
                        [  1.32110596e-01,   1.30432129e-01],
                        [  5.78918457e-02,   5.77392578e-02],
                        [ -2.87475586e-02,  -2.70080566e-02],
                        [ -1.07635498e-01,  -1.05072021e-01],
                        [ -1.56616211e-01,  -1.55120850e-01],
                        [ -1.64123535e-01,  -1.65008545e-01],
                        [ -1.37542725e-01,  -1.40350342e-01],
                        [ -9.99450684e-02,  -1.02447510e-01],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -6.57348633e-02,  -6.32324219e-02],
                        [ -6.12182617e-02,  -5.85937500e-02],
                        [ -5.01098633e-02,  -4.98046875e-02],
                        [ -3.45764160e-02,  -3.66516113e-02],
                        [ -2.01721191e-02,  -2.24304199e-02],
                        [ -7.69042969e-03,  -7.87353516e-03],
                        [  4.08935547e-03,   6.10351562e-03],
                        [  1.51977539e-02,   1.73645020e-02],
                        [  2.42919922e-02,   2.43530273e-02],
                        [  2.89611816e-02,   2.66113281e-02],
                        [  2.78015137e-02,   2.52380371e-02],
                        [  2.30102539e-02,   2.27050781e-02],
                        [  1.92565918e-02,   2.14538574e-02],
                        [  2.01721191e-02,   2.28576660e-02],
                        [  2.49023438e-02,   2.59094238e-02],
                        [  2.63977051e-02,   2.53295898e-02],
                        [  1.66320801e-02,   1.46179199e-02],
                        [ -4.15039062e-03,  -5.70678711e-03],
                        [ -2.64587402e-02,  -2.68859863e-02],
                        [ -4.18701172e-02,  -4.12597656e-02],
                        [ -4.94384766e-02,  -4.82482910e-02],
                        [ -5.18188477e-02,  -5.06591797e-02],
                        [ -5.02014160e-02,  -4.94689941e-02],
                        [ -4.41589355e-02,  -4.41284180e-02],
                        [ -3.40881348e-02,  -3.49121094e-02],
                        [ -2.14538574e-02,  -2.27355957e-02],
                        [ -6.53076172e-03,  -7.44628906e-03],
                        [  1.17187500e-02,   1.16882324e-02],
                        [  3.41796875e-02,   3.49121094e-02],
                        [  6.10046387e-02,   6.18591309e-02],
                        [  8.81958008e-02,   8.86535645e-02],
                        [  1.04888916e-01,   1.04827881e-01],
                        [  1.01501465e-01,   1.01226807e-01],
                        [  8.05664062e-02,   8.05053711e-02],
                        [  5.48095703e-02,   5.50537109e-02],
                        [  3.49426270e-02,   3.50646973e-02],
                        [  2.34069824e-02,   2.27966309e-02],
                        [  1.74865723e-02,   1.62963867e-02],
                        [  1.51367188e-02,   1.43432617e-02],
                        [  1.65100098e-02,   1.71203613e-02],
                        [  2.06909180e-02,   2.26440430e-02],
                        [  2.27050781e-02,   2.45666504e-02],
                        [  1.68151855e-02,   1.69372559e-02],
                        [  4.15039062e-03,   2.22778320e-03],
                        [ -8.11767578e-03,  -1.05590820e-02],
                        [ -1.55334473e-02,  -1.64794922e-02],
                        [ -1.82189941e-02,  -1.69067383e-02],
                        [ -1.61437988e-02,  -1.38244629e-02],
                        [ -1.01928711e-02,  -9.00268555e-03],
                        [ -3.38745117e-03,  -4.27246094e-03],
                        [  4.54711914e-03,   2.62451172e-03],
                        [  1.78222656e-02,   1.67846680e-02],
                        [  3.80554199e-02,   3.88793945e-02],
                        [  6.23779297e-02,   6.41784668e-02],
                        [  8.89587402e-02,   8.99963379e-02],
                        [  1.19140625e-01,   1.18499756e-01],
                        [  1.49444580e-01,   1.47827148e-01],
                        [  1.66625977e-01,   1.65435791e-01],
                        [  1.57745361e-01,   1.57684326e-01],
                        [  1.20849609e-01,   1.21734619e-01],
                        [  5.92346191e-02,   6.02722168e-02],
                        [ -2.66418457e-02,  -2.59094238e-02],
                        [ -1.30676270e-01,  -1.30432129e-01],
                        [ -2.30712891e-01,  -2.30957031e-01],
                        [ -2.95501709e-01,  -2.96234131e-01],
                        [ -3.05236816e-01,  -3.06335449e-01],
                        [ -2.65411377e-01,  -2.66296387e-01],
                        [ -2.03857422e-01,  -2.03826904e-01],
                        [ -1.53839111e-01,  -1.52618408e-01],
                        [ -1.32446289e-01,  -1.30798340e-01],
                        [ -1.30920410e-01,  -1.30279541e-01],
                        [ -1.28936768e-01,  -1.30004883e-01],
                        [ -1.15844727e-01,  -1.17736816e-01],
                        [ -9.47265625e-02,  -9.55810547e-02],
                        [ -7.21740723e-02,  -7.10449219e-02],
                        [ -5.13000488e-02,  -4.92553711e-02],
                        [ -3.12805176e-02,  -3.03344727e-02],
                        [ -1.18713379e-02,  -1.31530762e-02],
                        [  9.76562500e-04,  -1.49536133e-03],
                        [  5.79833984e-04,  -8.54492188e-04],
                        [ -9.58251953e-03,  -8.54492188e-03],
                        [ -1.74865723e-02,  -1.48010254e-02],
                        [ -1.65405273e-02,  -1.44348145e-02],
                        [ -1.27563477e-02,  -1.29089355e-02],
                        [ -1.51977539e-02,  -1.72729492e-02],
                        [ -2.31323242e-02,  -2.53295898e-02],
                        [ -2.88696289e-02,  -2.96020508e-02],
                        [ -3.12194824e-02,  -3.03649902e-02],
                        [ -3.61328125e-02,  -3.47595215e-02],
                        [ -4.34875488e-02,  -4.27551270e-02],
                        [ -4.39147949e-02,  -4.40063477e-02],
                        [ -3.00598145e-02,  -3.03649902e-02],
                        [ -4.18090820e-03,  -4.08935547e-03],
                        [  2.72827148e-02,   2.75878906e-02],
                        [  6.17065430e-02,   6.17675781e-02],
                        [  1.01196289e-01,   1.00677490e-01],
                        [  1.46392822e-01,   1.45385742e-01],
                        [  1.91162109e-01,   1.90277100e-01],
                        [  2.22930908e-01,   2.22961426e-01],
                        [  2.31231689e-01,   2.32299805e-01],
                        [  2.19299316e-01,   2.20825195e-01],
                        [  2.04223633e-01,   2.05230713e-01],
                        [  2.00195312e-01,   2.00164795e-01],
                        [  2.05810547e-01,   2.04925537e-01],
                        [  2.08557129e-01,   2.07122803e-01],
                        [  1.94213867e-01,   1.92749023e-01],
                        [  1.52862549e-01,   1.52069092e-01],
                        [  8.20617676e-02,   8.25805664e-02],
                        [ -1.02539062e-02,  -8.33129883e-03],
                        [ -1.04187012e-01,  -1.01684570e-01],
                        [ -1.72790527e-01,  -1.71447754e-01],
                        [ -1.97143555e-01,  -1.98425293e-01],
                        [ -1.80145264e-01,  -1.83532715e-01],
                        [ -1.45080566e-01,  -1.47888184e-01],
                        [ -1.17553711e-01,  -1.17126465e-01],
                        [ -1.04187012e-01,  -1.00891113e-01],
                        [ -9.02099609e-02,  -8.71887207e-02],
                        [ -6.06994629e-02,  -6.07910156e-02],
                        [ -2.01416016e-02,  -2.29797363e-02],
                        [  1.36108398e-02,   1.09558105e-02],
                        [  2.97546387e-02,   2.99987793e-02],
                        [  3.23486328e-02,   3.53393555e-02],
                        [  2.83203125e-02,   3.10974121e-02],
                        [  1.81884766e-02,   1.77612305e-02],
                        [  3.14331055e-03,  -3.66210938e-04],
                        [ -9.88769531e-03,  -1.33056641e-02],
                        [ -1.66625977e-02,  -1.66931152e-02],
                        [ -1.79748535e-02,  -1.45568848e-02],
                        [ -1.29394531e-02,  -9.06372070e-03],
                        [ -1.98364258e-03,  -7.62939453e-04],
                        [  5.73730469e-03,   3.63159180e-03],
                        [  1.12915039e-03,  -2.41088867e-03],
                        [ -1.06201172e-02,  -1.30615234e-02],
                        [ -1.68762207e-02,  -1.66931152e-02],
                        [ -1.54418945e-02,  -1.30920410e-02],
                        [ -1.47705078e-02,  -1.20849609e-02],
                        [ -1.95922852e-02,  -1.83410645e-02],
                        [ -2.61230469e-02,  -2.69775391e-02],
                        [ -3.08532715e-02,  -3.29589844e-02],
                        [ -3.52783203e-02,  -3.70483398e-02],
                        [ -4.00390625e-02,  -4.01000977e-02],
                        [ -3.77502441e-02,  -3.61938477e-02],
                        [ -1.68457031e-02,  -1.51062012e-02],
                        [  2.48107910e-02,   2.50549316e-02],
                        [  7.29980469e-02,   7.14416504e-02],
                        [  1.06842041e-01,   1.04858398e-01],
                        [  1.14776611e-01,   1.14227295e-01],
                        [  1.00921631e-01,   1.02569580e-01],
                        [  7.91015625e-02,   8.18176270e-02],
                        [  6.22558594e-02,   6.37817383e-02],
                        [  5.42602539e-02,   5.31311035e-02],
                        [  4.77294922e-02,   4.45861816e-02],
                        [  3.20434570e-02,   2.92053223e-02],
                        [  6.77490234e-03,   6.40869141e-03],
                        [ -1.68762207e-02,  -1.43127441e-02],
                        [ -2.80456543e-02,  -2.43835449e-02],
                        [ -2.44750977e-02,  -2.25524902e-02],
                        [ -1.10473633e-02,  -1.24511719e-02],
                        [  2.50244141e-03,  -1.00708008e-03],
                        [  6.19506836e-03,   3.57055664e-03],
                        [ -1.80053711e-03,  -1.40380859e-03],
                        [ -1.15356445e-02,  -8.69750977e-03],
                        [ -1.14135742e-02,  -8.75854492e-03],
                        [ -1.86157227e-03,  -1.70898438e-03],
                        [  8.02612305e-03,   5.61523438e-03],
                        [  1.62658691e-02,   1.35192871e-02],
                        [  2.96630859e-02,   2.89916992e-02],
                        [  5.13305664e-02,   5.32226562e-02],
                        [  7.72705078e-02,   8.03527832e-02],
                        [  1.02691650e-01,   1.04644775e-01],
                        [  1.23352051e-01,   1.22741699e-01],
                        [  1.35070801e-01,   1.32171631e-01],
                        [  1.34094238e-01,   1.30706787e-01],
                        [  1.16058350e-01,   1.14562988e-01],
                        [  7.71789551e-02,   7.86743164e-02],
                        [  1.79443359e-02,   2.15148926e-02],
                        [ -5.71899414e-02,  -5.38635254e-02],
                        [ -1.42486572e-01,  -1.41448975e-01],
                        [ -2.26257324e-01,  -2.28210449e-01],
                        [ -2.85491943e-01,  -2.89306641e-01],
                        [ -2.97027588e-01,  -3.00140381e-01],
                        [ -2.62023926e-01,  -2.62176514e-01],
                        [ -2.10144043e-01,  -2.07275391e-01],
                        [ -1.70532227e-01,  -1.66961670e-01],
                        [ -1.46026611e-01,  -1.44500732e-01],
                        [ -1.23565674e-01,  -1.25061035e-01],
                        [ -9.85717773e-02,  -1.01562500e-01],
                        [ -7.72705078e-02,  -7.91931152e-02],
                        [ -6.31713867e-02,  -6.23779297e-02],
                        [ -5.34362793e-02,  -5.07202148e-02],
                        [ -4.51354980e-02,  -4.30603027e-02],
                        [ -3.55834961e-02,  -3.61633301e-02],
                        [ -2.05993652e-02,  -2.32849121e-02],
                        [ -9.15527344e-04,  -3.23486328e-03],
                        [  1.32751465e-02,   1.31530762e-02],
                        [  1.19628906e-02,   1.38854980e-02],
                        [ -2.99072266e-03,  -6.40869141e-04],
                        [ -2.10571289e-02,  -1.97143555e-02],
                        [ -3.32946777e-02,  -3.34167480e-02],
                        [ -3.63769531e-02,  -3.75976562e-02],
                        [ -3.16772461e-02,  -3.33557129e-02],
                        [ -2.55737305e-02,  -2.72216797e-02],
                        [ -2.80456543e-02,  -2.90527344e-02],
                        [ -4.32434082e-02,  -4.28161621e-02],
                        [ -6.04553223e-02,  -5.83496094e-02],
                        [ -6.17065430e-02,  -5.90820312e-02],
                        [ -3.94287109e-02,  -3.80859375e-02],
                        [ -1.37329102e-03,  -2.10571289e-03],
                        [  4.25720215e-02,   4.04357910e-02],
                        [  9.18273926e-02,   8.96301270e-02],
                        [  1.49169922e-01,   1.48040771e-01],
                        [  2.04925537e-01,   2.05383301e-01],
                        [  2.37060547e-01,   2.38677979e-01],
                        [  2.34130859e-01,   2.35687256e-01],
                        [  2.10479736e-01,   2.10937500e-01],
                        [  1.89910889e-01,   1.89453125e-01],
                        [  1.81884766e-01,   1.81488037e-01],
                        [  1.81060791e-01,   1.81335449e-01],
                        [  1.81823730e-01,   1.82128906e-01],
                        [  1.81274414e-01,   1.80603027e-01],
                        [  1.72271729e-01,   1.70379639e-01],
                        [  1.42547607e-01,   1.40747070e-01],
                        [  8.29467773e-02,   8.32214355e-02],
                        [ -3.66210938e-03,  -6.40869141e-04],
                        [ -9.79003906e-02,  -9.41772461e-02],
                        [ -1.71081543e-01,  -1.69982910e-01],
                        [ -2.01934814e-01,  -2.04772949e-01],
                        [ -1.88751221e-01,  -1.93206787e-01],
                        [ -1.48773193e-01,  -1.50970459e-01],
                        [ -1.07208252e-01,  -1.05377197e-01],
                        [ -7.94067383e-02,  -7.54394531e-02],
                        [ -6.11267090e-02,  -5.87768555e-02],
                        [ -4.07104492e-02,  -4.19006348e-02],
                        [ -1.79138184e-02,  -2.11181641e-02],
                        [ -4.60815430e-03,  -6.40869141e-03],
                        [ -8.42285156e-03,  -7.04956055e-03],
                        [ -2.11791992e-02,  -1.81579590e-02],
                        [ -2.65808105e-02,  -2.50854492e-02],
                        [ -1.74560547e-02,  -1.90734863e-02],
                        [ -6.10351562e-05,  -3.35693359e-03],
                        [  1.67541504e-02,   1.48010254e-02],
                        [  2.73437500e-02,   2.85949707e-02],
                        [  2.60314941e-02,   2.93884277e-02],
                        [  1.01013184e-02,   1.24206543e-02],
                        [ -1.13830566e-02,  -1.20544434e-02],
                        [ -2.30407715e-02,  -2.56652832e-02],
                        [ -2.22167969e-02,  -2.40173340e-02],
                        [ -2.00195312e-02,  -1.95922852e-02],
                        [ -2.11181641e-02,  -1.95922852e-02],
                        [ -1.85852051e-02,  -1.78833008e-02],
                        [ -1.13220215e-02,  -1.21765137e-02],
                        [ -9.21630859e-03,  -1.05285645e-02],
                        [ -1.75170898e-02,  -1.76086426e-02],
                        [ -3.06396484e-02,  -2.89611816e-02],
                        [ -4.21752930e-02,  -4.01916504e-02],
                        [ -4.97741699e-02,  -4.94689941e-02],
                        [ -4.70581055e-02,  -4.87365723e-02],
                        [ -2.24304199e-02,  -2.45361328e-02],
                        [  2.60925293e-02,   2.49938965e-02],
                        [  8.17871094e-02,   8.18786621e-02],
                        [  1.21795654e-01,   1.22680664e-01],
                        [  1.33453369e-01,   1.35009766e-01],
                        [  1.19018555e-01,   1.20941162e-01],
                        [  9.24072266e-02,   9.36889648e-02],
                        [  6.86340332e-02,   6.79626465e-02],
                        [  5.07202148e-02,   4.80346680e-02],
                        [  3.23486328e-02,   2.91748047e-02],
                        [  1.09863281e-02,   9.67407227e-03],
                        [ -7.78198242e-03,  -5.85937500e-03],
                        [ -1.65100098e-02,  -1.24816895e-02],
                        [ -1.21765137e-02,  -9.24682617e-03],
                        [  3.05175781e-05,  -6.10351562e-04],
                        [  8.42285156e-03,   4.69970703e-03],
                        [  4.66918945e-03,   9.76562500e-04],
                        [ -5.82885742e-03,  -6.43920898e-03],
                        [ -9.12475586e-03,  -5.92041016e-03],
                        [ -3.05175781e-04,   4.18090820e-03],
                        [  1.10168457e-02,   1.27868652e-02],
                        [  1.71813965e-02,   1.42211914e-02],
                        [  2.37121582e-02,   1.82495117e-02],
                        [  3.77197266e-02,   3.43017578e-02],
                        [  5.56335449e-02,   5.72204590e-02],
                        [  7.18383789e-02,   7.75146484e-02],
                        [  8.94470215e-02,   9.51538086e-02],
                        [  1.13189697e-01,   1.14654541e-01],
                        [  1.38061523e-01,   1.33789062e-01],
                        [  1.50634766e-01,   1.43585205e-01],
                        [  1.38000488e-01,   1.33483887e-01],
                        [  9.37194824e-02,   9.49096680e-02],
                        [  2.11181641e-02,   2.65502930e-02],
                        [ -6.90002441e-02,  -6.35070801e-02],
                        [ -1.64794922e-01,  -1.62536621e-01],
                        [ -2.51190186e-01,  -2.52868652e-01],
                        [ -3.03009033e-01,  -3.07128906e-01],
                        [ -2.99133301e-01,  -3.02978516e-01],
                        [ -2.49786377e-01,  -2.51037598e-01],
                        [ -1.93603516e-01,  -1.91864014e-01],
                        [ -1.58508301e-01,  -1.55487061e-01],
                        [ -1.38885498e-01,  -1.36840820e-01],
                        [ -1.16577148e-01,  -1.16821289e-01],
                        [ -9.03015137e-02,  -9.23767090e-02],
                        [ -7.31506348e-02,  -7.50427246e-02],
                        [ -6.99462891e-02,  -6.94885254e-02],
                        [ -7.04345703e-02,  -6.76879883e-02],
                        [ -6.22863770e-02,  -5.99670410e-02],
                        [ -4.18090820e-02,  -4.26025391e-02],
                        [ -1.45568848e-02,  -1.82189941e-02],
                        [  7.72094727e-03,   4.05883789e-03],
                        [  1.44348145e-02,   1.37329102e-02],
                        [  5.40161133e-03,   8.30078125e-03],
                        [ -1.04980469e-02,  -6.07299805e-03],
                        [ -2.52990723e-02,  -2.23083496e-02],
                        [ -3.51562500e-02,  -3.52478027e-02],
                        [ -3.93371582e-02,  -4.20532227e-02],
                        [ -4.12902832e-02,  -4.50439453e-02],
                        [ -4.54101562e-02,  -4.83703613e-02],
                        [ -5.08728027e-02,  -5.15441895e-02],
                        [ -5.46569824e-02,  -5.25817871e-02],
                        [ -5.49316406e-02,  -5.12390137e-02],
                        [ -4.56848145e-02,  -4.26330566e-02],
                        [ -1.81884766e-02,  -1.75476074e-02],
                        [  2.73437500e-02,   2.54516602e-02],
                        [  8.20617676e-02,   7.90710449e-02],
                        [  1.38305664e-01,   1.36230469e-01],
                        [  1.87713623e-01,   1.87744141e-01],
                        [  2.16644287e-01,   2.18170166e-01],
                        [  2.17407227e-01,   2.18719482e-01],
                        [  1.99310303e-01,   1.99279785e-01],
                        [  1.78985596e-01,   1.78131104e-01],
                        [  1.64855957e-01,   1.64611816e-01],
                        [  1.56005859e-01,   1.57318115e-01],
                        [  1.49414062e-01,   1.51580811e-01],
                        [  1.44226074e-01,   1.45141602e-01],
                        [  1.43035889e-01,   1.40960693e-01],
                        [  1.47613525e-01,   1.43432617e-01],
                        [  1.49932861e-01,   1.47064209e-01],
                        [  1.33209229e-01,   1.34338379e-01],
                        [  8.59680176e-02,   9.03320312e-02],
                        [  1.01013184e-02,   1.44348145e-02],
                        [ -8.09631348e-02,  -7.96203613e-02],
                        [ -1.62475586e-01,  -1.64855957e-01],
                        [ -2.03552246e-01,  -2.07794189e-01],
                        [ -1.87957764e-01,  -1.91040039e-01],
                        [ -1.34704590e-01,  -1.34674072e-01],
                        [ -8.62426758e-02,  -8.36486816e-02],
                        [ -6.75048828e-02,  -6.45751953e-02],
                        [ -6.54296875e-02,  -6.40563965e-02],
                        [ -5.69152832e-02,  -5.76171875e-02],
                        [ -4.21447754e-02,  -4.39758301e-02],
                        [ -3.61022949e-02,  -3.75976562e-02],
                        [ -4.15649414e-02,  -4.17175293e-02],
                        [ -4.55627441e-02,  -4.45556641e-02],
                        [ -3.63769531e-02,  -3.53698730e-02],
                        [ -1.51367188e-02,  -1.49230957e-02],
                        [  8.36181641e-03,   7.96508789e-03],
                        [  2.52380371e-02,   2.47192383e-02],
                        [  3.12500000e-02,   3.05786133e-02],
                        [  2.53906250e-02,   2.46276855e-02],
                        [  9.39941406e-03,   9.36889648e-03],
                        [ -1.19323730e-02,  -1.04675293e-02],
                        [ -3.06091309e-02,  -2.81372070e-02],
                        [ -3.74755859e-02,  -3.60717773e-02],
                        [ -3.00903320e-02,  -3.15856934e-02],
                        [ -1.61743164e-02,  -2.01721191e-02],
                        [ -5.03540039e-03,  -8.54492188e-03],
                        [ -6.71386719e-04,  -5.79833984e-04],
                        [ -5.64575195e-03,  -1.55639648e-03],
                        [ -2.17590332e-02,  -1.68762207e-02],
                        [ -4.40673828e-02,  -4.22973633e-02],
                        [ -6.09741211e-02,  -6.33544922e-02],
                        [ -6.30493164e-02,  -6.71386719e-02],
                        [ -4.59899902e-02,  -4.86755371e-02],
                        [ -7.38525391e-03,  -7.41577148e-03],
                        [  4.87365723e-02,   5.05065918e-02],
                        [  1.02874756e-01,   1.04827881e-01],
                        [  1.30004883e-01,   1.30981445e-01],
                        [  1.23168945e-01,   1.23291016e-01],
                        [  9.76867676e-02,   9.77172852e-02],
                        [  7.06176758e-02,   7.07397461e-02],
                        [  4.80346680e-02,   4.74548340e-02],
                        [  3.25012207e-02,   3.07922363e-02],
                        [  2.78320312e-02,   2.61230469e-02],
                        [  3.14941406e-02,   3.14636230e-02],
                        [  3.29284668e-02,   3.48815918e-02],
                        [  2.61535645e-02,   2.85949707e-02],
                        [  1.56250000e-02,   1.64489746e-02],
                        [  6.40869141e-03,   4.76074219e-03],
                        [ -2.56347656e-03,  -5.40161133e-03],
                        [ -1.30920410e-02,  -1.44042969e-02],
                        [ -2.25219727e-02,  -2.05383301e-02],
                        [ -2.52990723e-02,  -2.14843750e-02],
                        [ -1.61132812e-02,  -1.41906738e-02],
                        [  7.72094727e-03,   5.34057617e-03],
                        [  4.21752930e-02,   3.71093750e-02],
                        [  7.59277344e-02,   7.24182129e-02],
                        [  9.86938477e-02,   9.97924805e-02],
                        [  1.10992432e-01,   1.16119385e-01],
                        [  1.20086670e-01,   1.25488281e-01],
                        [  1.27624512e-01,   1.29394531e-01],
                        [  1.29272461e-01,   1.26342773e-01],
                        [  1.21826172e-01,   1.16638184e-01],
                        [  9.99450684e-02,   9.60388184e-02],
                        [  5.11474609e-02,   5.03234863e-02],
                        [ -3.21350098e-02,  -3.02734375e-02],
                        [ -1.37573242e-01,  -1.34216309e-01],
                        [ -2.36724854e-01,  -2.33215332e-01],
                        [ -2.99560547e-01,  -2.97485352e-01],
                        [ -3.06182861e-01,  -3.06793213e-01],
                        [ -2.58514404e-01,  -2.61505127e-01],
                        [ -1.86523438e-01,  -1.90063477e-01],
                        [ -1.29394531e-01,  -1.31347656e-01],
                        [ -1.04034424e-01,  -1.03363037e-01],
                        [ -9.86328125e-02,  -9.62524414e-02],
                        [ -9.56115723e-02,  -9.37500000e-02],
                        [ -8.87756348e-02,  -8.88061523e-02],
                        [ -8.09631348e-02,  -8.19396973e-02],
                        [ -7.55004883e-02,  -7.52868652e-02],
                        [ -6.94580078e-02,  -6.75354004e-02],
                        [ -5.46569824e-02,  -5.30090332e-02],
                        [ -2.87780762e-02,  -2.97851562e-02],
                        [ -1.37329102e-03,  -5.34057617e-03],
                        [  1.61132812e-02,   1.17492676e-02],
                        [  2.03857422e-02,   1.92565918e-02],
                        [  1.38549805e-02,   1.74560547e-02],
                        [  5.49316406e-04,   6.59179688e-03],
                        [ -1.37939453e-02,  -9.61303711e-03],
                        [ -2.50244141e-02,  -2.55126953e-02],
                        [ -3.56750488e-02,  -4.01611328e-02],
                        [ -5.10559082e-02,  -5.63964844e-02],
                        [ -6.95190430e-02,  -7.22656250e-02],
                        [ -8.13903809e-02,  -8.01391602e-02],
                        [ -7.81250000e-02,  -7.44018555e-02],
                        [ -5.76782227e-02,  -5.45959473e-02],
                        [ -2.15759277e-02,  -2.08129883e-02],
                        [  2.85339355e-02,   2.75268555e-02],
                        [  8.96301270e-02,   8.82568359e-02],
                        [  1.54937744e-01,   1.54113770e-01],
                        [  2.11303711e-01,   2.11303711e-01],
                        [  2.40966797e-01,   2.41516113e-01],
                        [  2.34313965e-01,   2.34588623e-01],
                        [  2.02270508e-01,   2.01385498e-01],
                        [  1.67144775e-01,   1.65374756e-01],
                        [  1.41235352e-01,   1.40075684e-01],
                        [  1.22589111e-01,   1.23596191e-01],
                        [  1.08520508e-01,   1.11907959e-01],
                        [  1.02264404e-01,   1.06170654e-01],
                        [  1.06262207e-01,   1.07513428e-01],
                        [  1.17462158e-01,   1.14257812e-01],
                        [  1.30767822e-01,   1.24877930e-01],
                        [  1.40930176e-01,   1.36627197e-01],
                        [  1.38366699e-01,   1.38824463e-01],
                        [  1.09161377e-01,   1.13922119e-01],
                        [  4.53796387e-02,   5.11169434e-02],
                        [ -4.42199707e-02,  -4.10766602e-02],
                        [ -1.33270264e-01,  -1.34460449e-01],
                        [ -1.88751221e-01,  -1.93176270e-01],
                        [ -1.91253662e-01,  -1.95953369e-01],
                        [ -1.51611328e-01,  -1.53839111e-01],
                        [ -1.03820801e-01,  -1.02539062e-01],
                        [ -7.69958496e-02,  -7.32421875e-02],
                        [ -7.48596191e-02,  -7.10449219e-02],
                        [ -7.90710449e-02,  -7.77282715e-02],
                        [ -6.94580078e-02,  -7.14721680e-02],
                        [ -4.44335938e-02,  -4.80651855e-02],
                        [ -2.23999023e-02,  -2.46276855e-02],
                        [ -1.90734863e-02,  -1.83105469e-02],
                        [ -2.81982422e-02,  -2.53295898e-02],
                        [ -3.16772461e-02,  -2.91748047e-02],
                        [ -2.24304199e-02,  -2.23999023e-02],
                        [ -6.83593750e-03,  -9.36889648e-03],
                        [  7.72094727e-03,   4.60815430e-03],
                        [  1.60827637e-02,   1.49536133e-02],
                        [  1.40380859e-02,   1.58996582e-02],
                        [  3.17382812e-03,   6.77490234e-03],
                        [ -9.39941406e-03,  -6.50024414e-03],
                        [ -1.88293457e-02,  -1.86767578e-02],
                        [ -2.42614746e-02,  -2.73437500e-02],
                        [ -2.49938965e-02,  -2.94494629e-02],
                        [ -2.18200684e-02,  -2.43835449e-02],
                        [ -1.92260742e-02,  -1.78833008e-02],
                        [ -2.10266113e-02,  -1.69677734e-02],
                        [ -2.73437500e-02,  -2.36816406e-02],
                        [ -3.72924805e-02,  -3.64990234e-02],
                        [ -4.87365723e-02,  -5.09338379e-02],
                        [ -5.32836914e-02,  -5.63049316e-02],
                        [ -3.82080078e-02,  -3.96118164e-02],
                        [  4.57763672e-04,   1.28173828e-03],
                        [  5.13000488e-02,   5.27343750e-02],
                        [  9.59472656e-02,   9.61303711e-02],
                        [  1.18286133e-01,   1.17248535e-01],
                        [  1.09619141e-01,   1.08886719e-01],
                        [  7.56530762e-02,   7.64770508e-02],
                        [  3.84826660e-02,   4.06188965e-02],
                        [  1.96228027e-02,   2.14538574e-02],
                        [  2.15148926e-02,   2.12707520e-02],
                        [  3.14941406e-02,   2.89001465e-02],
                        [  3.80859375e-02,   3.50341797e-02],
                        [  3.59802246e-02,   3.49426270e-02],
                        [  2.49938965e-02,   2.65197754e-02],
                        [  1.32751465e-02,   1.56250000e-02],
                        [  1.13525391e-02,   1.26037598e-02],
                        [  1.69677734e-02,   1.68762207e-02],
                        [  1.72424316e-02,   1.68457031e-02],
                        [  8.69750977e-03,   8.81958008e-03],
                        [  3.41796875e-03,   3.81469727e-03],
                        [  1.35803223e-02,   1.32751465e-02],
                        [  3.75366211e-02,   3.58886719e-02],
                        [  6.34155273e-02,   6.11267090e-02],
                        [  8.31298828e-02,   8.20312500e-02],
                        [  9.83276367e-02,   9.95483398e-02],
                        [  1.12152100e-01,   1.14959717e-01],
                        [  1.23596191e-01,   1.26312256e-01],
                        [  1.32110596e-01,   1.33544922e-01],
                        [  1.35742188e-01,   1.35498047e-01],
                        [  1.24420166e-01,   1.22497559e-01],
                        [  8.53271484e-02,   8.20922852e-02],
                        [  1.48620605e-02,   1.12915039e-02],
                        [ -7.96203613e-02,  -8.15429688e-02],
                        [ -1.82250977e-01,  -1.80633545e-01],
                        [ -2.68463135e-01,  -2.63366699e-01],
                        [ -3.09844971e-01,  -3.04107666e-01],
                        [ -2.91076660e-01,  -2.88604736e-01],
                        [ -2.26440430e-01,  -2.29248047e-01],
                        [ -1.56036377e-01,  -1.62170410e-01],
                        [ -1.16058350e-01,  -1.21154785e-01],
                        [ -1.09619141e-01,  -1.10412598e-01],
                        [ -1.11846924e-01,  -1.08703613e-01],
                        [ -1.02111816e-01,  -9.83276367e-02],
                        [ -8.18786621e-02,  -8.01696777e-02],
                        [ -6.19201660e-02,  -6.20727539e-02],
                        [ -4.73937988e-02,  -4.73327637e-02],
                        [ -3.81164551e-02,  -3.72009277e-02],
                        [ -3.13720703e-02,  -3.11889648e-02],
                        [ -2.25219727e-02,  -2.47497559e-02],
                        [ -1.17492676e-02,  -1.57165527e-02],
                        [ -5.37109375e-03,  -8.30078125e-03],
                        [ -5.85937500e-03,  -5.18798828e-03],
                        [ -9.55200195e-03,  -5.18798828e-03],
                        [ -1.64184570e-02,  -1.10168457e-02],
                        [ -2.97851562e-02,  -2.72827148e-02],
                        [ -4.80346680e-02,  -5.02624512e-02],
                        [ -6.50939941e-02,  -7.00683594e-02],
                        [ -7.74841309e-02,  -8.12683105e-02],
                        [ -8.35571289e-02,  -8.37402344e-02],
                        [ -7.77282715e-02,  -7.52258301e-02],
                        [ -5.27648926e-02,  -5.01708984e-02],
                        [ -8.91113281e-03,  -8.05664062e-03],
                        [  4.53186035e-02,   4.45251465e-02],
                        [  1.02783203e-01,   1.01776123e-01],
                        [  1.59973145e-01,   1.59759521e-01],
                        [  2.07489014e-01,   2.08038330e-01],
                        [  2.30133057e-01,   2.30773926e-01],
                        [  2.21221924e-01,   2.21496582e-01],
                        [  1.90490723e-01,   1.90216064e-01],
                        [  1.55639648e-01,   1.54663086e-01],
                        [  1.29211426e-01,   1.27563477e-01],
                        [  1.13891602e-01,   1.12365723e-01],
                        [  1.07543945e-01,   1.07696533e-01],
                        [  1.09039307e-01,   1.11602783e-01],
                        [  1.17675781e-01,   1.21643066e-01],
                        [  1.30950928e-01,   1.33544922e-01],
                        [  1.44073486e-01,   1.42883301e-01],
                        [  1.51367188e-01,   1.46453857e-01],
                        [  1.48071289e-01,   1.42608643e-01],
                        [  1.30615234e-01,   1.28631592e-01],
                        [  9.34753418e-02,   9.66796875e-02],
                        [  3.12500000e-02,   3.74755859e-02],
                        [ -5.18493652e-02,  -4.71496582e-02],
                        [ -1.36566162e-01,  -1.36749268e-01],
                        [ -1.95953369e-01,  -2.00531006e-01],
                        [ -2.10632324e-01,  -2.15942383e-01],
                        [ -1.81671143e-01,  -1.83746338e-01],
                        [ -1.29730225e-01,  -1.27380371e-01],
                        [ -8.15124512e-02,  -7.71179199e-02],
                        [ -5.43823242e-02,  -5.16967773e-02],
                        [ -4.80651855e-02,  -4.91027832e-02],
                        [ -4.87060547e-02,  -5.21850586e-02],
                        [ -4.45251465e-02,  -4.72412109e-02],
                        [ -3.72924805e-02,  -3.68041992e-02],
                        [ -3.49121094e-02,  -3.16772461e-02],
                        [ -3.81164551e-02,  -3.50036621e-02],
                        [ -3.90319824e-02,  -3.85742188e-02],
                        [ -3.11584473e-02,  -3.35998535e-02],
                        [ -1.66320801e-02,  -2.00805664e-02],
                        [ -2.38037109e-03,  -4.51660156e-03],
                        [  7.17163086e-03,   7.50732422e-03],
                        [  9.46044922e-03,   1.19018555e-02],
                        [  1.89208984e-03,   5.03540039e-03],
                        [ -1.22985840e-02,  -1.01318359e-02],
                        [ -2.29187012e-02,  -2.28271484e-02],
                        [ -2.36816406e-02,  -2.56652832e-02],
                        [ -1.99584961e-02,  -2.29797363e-02],
                        [ -2.10266113e-02,  -2.35290527e-02],
                        [ -2.76794434e-02,  -2.82592773e-02],
                        [ -3.29284668e-02,  -3.13110352e-02],
                        [ -3.42407227e-02,  -3.17077637e-02],
                        [ -3.73535156e-02,  -3.55834961e-02],
                        [ -4.34570312e-02,  -4.29382324e-02],
                        [ -4.15344238e-02,  -4.16870117e-02],
                        [ -1.94091797e-02,  -1.97448730e-02],
                        [  2.38037109e-02,   2.29492188e-02],
                        [  7.51953125e-02,   7.34558105e-02],
                        [  1.12640381e-01,   1.10412598e-01],
                        [  1.18041992e-01,   1.16516113e-01],
                        [  9.41162109e-02,   9.45739746e-02],
                        [  6.35070801e-02,   6.64062500e-02],
                        [  4.68750000e-02,   5.10864258e-02],
                        [  4.59289551e-02,   4.89807129e-02],
                        [  4.87060547e-02,   4.83093262e-02],
                        [  4.47692871e-02,   4.07714844e-02],
                        [  3.27758789e-02,   2.74963379e-02],
                        [  1.81884766e-02,   1.48315430e-02],
                        [  7.84301758e-03,   8.33129883e-03],
                        [  5.27954102e-03,   9.18579102e-03],
                        [  8.88061523e-03,   1.37634277e-02],
                        [  1.37023926e-02,   1.67236328e-02],
                        [  1.56860352e-02,   1.53808594e-02],
                        [  1.47705078e-02,   1.18103027e-02],
                        [  1.46179199e-02,   1.11389160e-02],
                        [  1.98974609e-02,   1.80053711e-02],
                        [  3.33251953e-02,   3.35388184e-02],
                        [  5.50842285e-02,   5.64270020e-02],
                        [  8.34655762e-02,   8.45336914e-02],
                        [  1.13647461e-01,   1.13739014e-01],
                        [  1.38305664e-01,   1.37969971e-01],
                        [  1.51641846e-01,   1.52191162e-01],
                        [  1.49993896e-01,   1.52252197e-01],
                        [  1.29272461e-01,   1.32019043e-01],
                        [  8.59680176e-02,   8.63037109e-02],
                        [  2.00195312e-02,   1.59912109e-02],
                        [ -6.68029785e-02,  -7.32116699e-02],
                        [ -1.68670654e-01,  -1.72424316e-01],
                        [ -2.64923096e-01,  -2.62481689e-01],
                        [ -3.19061279e-01,  -3.11889648e-01],
                        [ -3.04077148e-01,  -2.97454834e-01],
                        [ -2.33703613e-01,  -2.32238770e-01],
                        [ -1.57257080e-01,  -1.61224365e-01],
                        [ -1.15142822e-01,  -1.20819092e-01],
                        [ -1.05834961e-01,  -1.09283447e-01],
                        [ -1.02569580e-01,  -1.02691650e-01],
                        [ -9.04846191e-02,  -8.89892578e-02],
                        [ -7.65991211e-02,  -7.51953125e-02],
                        [ -7.07092285e-02,  -6.94580078e-02],
                        [ -7.04650879e-02,  -6.86035156e-02],
                        [ -6.59790039e-02,  -6.36291504e-02],
                        [ -5.19714355e-02,  -5.06896973e-02],
                        [ -3.22265625e-02,  -3.36303711e-02],
                        [ -1.40380859e-02,  -1.81274414e-02],
                        [ -2.34985352e-03,  -6.80541992e-03],
                        [  4.27246094e-04,  -1.22070312e-03],
                        [ -5.85937500e-03,  -3.41796875e-03],
                        [ -1.69372559e-02,  -1.20849609e-02],
                        [ -2.63977051e-02,  -2.25830078e-02],
                        [ -3.48205566e-02,  -3.43627930e-02],
                        [ -4.90417480e-02,  -5.17272949e-02],
                        [ -6.91528320e-02,  -7.25402832e-02],
                        [ -8.32519531e-02,  -8.49304199e-02],
                        [ -7.89489746e-02,  -7.83996582e-02],
                        [ -5.30700684e-02,  -5.16357422e-02],
                        [ -9.24682617e-03,  -8.42285156e-03],
                        [  4.75158691e-02,   4.74548340e-02],
                        [  1.11328125e-01,   1.11145020e-01],
                        [  1.71539307e-01,   1.71722412e-01],
                        [  2.11547852e-01,   2.11853027e-01],
                        [  2.18688965e-01,   2.18688965e-01],
                        [  1.96777344e-01,   1.96594238e-01],
                        [  1.62994385e-01,   1.63238525e-01],
                        [  1.32781982e-01,   1.33392334e-01],
                        [  1.12121582e-01,   1.12091064e-01],
                        [  1.00677490e-01,   9.92431641e-02],
                        [  9.47875977e-02,   9.25903320e-02],
                        [  9.11865234e-02,   8.99658203e-02],
                        [  9.21936035e-02,   9.34753418e-02],
                        [  1.02813721e-01,   1.06475830e-01],
                        [  1.19293213e-01,   1.23107910e-01],
                        [  1.28479004e-01,   1.29302979e-01],
                        [  1.23687744e-01,   1.20178223e-01],
                        [  1.12487793e-01,   1.06994629e-01],
                        [  1.02447510e-01,   9.92126465e-02],
                        [  8.71276855e-02,   8.85314941e-02],
                        [  5.31311035e-02,   5.76782227e-02],
                        [ -5.06591797e-03,  -1.03759766e-03],
                        [ -8.05664062e-02,  -7.96813965e-02],
                        [ -1.55609131e-01,  -1.57836914e-01],
                        [ -2.04193115e-01,  -2.07183838e-01],
                        [ -2.04620361e-01,  -2.05902100e-01],
                        [ -1.61163330e-01,  -1.60156250e-01],
                        [ -1.05834961e-01,  -1.04309082e-01],
                        [ -6.94274902e-02,  -6.93664551e-02],
                        [ -5.59997559e-02,  -5.75256348e-02],
                        [ -5.17578125e-02,  -5.30700684e-02],
                        [ -4.79125977e-02,  -4.73022461e-02],
                        [ -4.57153320e-02,  -4.33654785e-02],
                        [ -4.75158691e-02,  -4.52270508e-02],
                        [ -5.15441895e-02,  -5.12390137e-02],
                        [ -5.30090332e-02,  -5.49316406e-02],
                        [ -4.65087891e-02,  -4.90112305e-02],
                        [ -2.94799805e-02,  -3.07312012e-02],
                        [ -5.09643555e-03,  -4.82177734e-03],
                        [  1.82800293e-02,   1.90429688e-02],
                        [  3.05175781e-02,   3.10668945e-02],
                        [  2.67639160e-02,   2.74047852e-02],
                        [  1.28479004e-02,   1.41601562e-02],
                        [  3.35693359e-04,   1.98364258e-03],
                        [ -7.23266602e-03,  -6.43920898e-03],
                        [ -1.68762207e-02,  -1.81579590e-02],
                        [ -3.31115723e-02,  -3.63159180e-02],
                        [ -4.99877930e-02,  -5.31311035e-02],
                        [ -6.10351562e-02,  -6.20117188e-02],
                        [ -6.93359375e-02,  -6.75659180e-02],
                        [ -7.93151855e-02,  -7.58972168e-02],
                        [ -8.42895508e-02,  -8.10546875e-02],
                        [ -7.02209473e-02,  -6.86645508e-02],
                        [ -2.93884277e-02,  -3.00598145e-02],
                        [  3.24707031e-02,   3.00292969e-02],
                        [  9.68933105e-02,   9.38110352e-02],
                        [  1.39770508e-01,   1.37054443e-01],
                        [  1.46667480e-01,   1.45172119e-01],
                        [  1.23657227e-01,   1.24206543e-01],
                        [  8.92944336e-02,   9.23767090e-02],
                        [  5.91735840e-02,   6.39648438e-02],
                        [  3.93981934e-02,   4.34570312e-02],
                        [  2.86254883e-02,   2.92968750e-02],
                        [  2.36816406e-02,   1.98974609e-02],
                        [  2.34375000e-02,   1.68762207e-02],
                        [  2.67944336e-02,   2.12707520e-02],
                        [  2.88085938e-02,   2.80761719e-02],
                        [  2.37426758e-02,   2.84118652e-02],
                        [  1.22070312e-02,   1.90429688e-02],
                        [  2.86865234e-03,   7.41577148e-03],
                        [  4.05883789e-03,   3.81469727e-03],
                        [  1.42211914e-02,   1.01318359e-02],
                        [  2.58178711e-02,   2.11486816e-02],
                        [  3.66210938e-02,   3.43933105e-02],
                        [  5.09948730e-02,   5.18188477e-02],
                        [  7.19604492e-02,   7.39440918e-02],
                        [  9.89074707e-02,   9.97314453e-02],
                        [  1.28814697e-01,   1.28265381e-01],
                        [  1.53228760e-01,   1.53106689e-01],
                        [  1.58996582e-01,   1.60797119e-01],
                        [  1.38458252e-01,   1.41418457e-01],
                        [  9.44824219e-02,   9.59472656e-02],
                        [  3.06396484e-02,   2.85034180e-02],
                        [ -5.52673340e-02,  -6.01806641e-02],
                        [ -1.58843994e-01,  -1.62811279e-01],
                        [ -2.55218506e-01,  -2.55096436e-01],
                        [ -3.06732178e-01,  -3.03039551e-01],
                        [ -2.89886475e-01,  -2.85858154e-01],
                        [ -2.20184326e-01,  -2.18475342e-01],
                        [ -1.47125244e-01,  -1.47796631e-01],
                        [ -1.11083984e-01,  -1.12518311e-01],
                        [ -1.08123779e-01,  -1.09069824e-01],
                        [ -1.08184814e-01,  -1.08734131e-01],
                        [ -9.71984863e-02,  -9.82360840e-02],
                        [ -8.41674805e-02,  -8.58154297e-02],
                        [ -7.72094727e-02,  -7.82165527e-02],
                        [ -7.22351074e-02,  -7.11975098e-02],
                        [ -6.27441406e-02,  -5.99670410e-02],
                        [ -4.77905273e-02,  -4.49523926e-02],
                        [ -2.98156738e-02,  -2.85644531e-02],
                        [ -1.22985840e-02,  -1.32141113e-02],
                        [  3.05175781e-04,  -2.25830078e-03],
                        [  3.75366211e-03,   8.85009766e-04],
                        [ -4.42504883e-03,  -6.10351562e-03],
                        [ -2.22167969e-02,  -2.17895508e-02],
                        [ -4.02832031e-02,  -3.82690430e-02],
                        [ -4.92248535e-02,  -4.69360352e-02],
                        [ -5.12390137e-02,  -4.99877930e-02],
                        [ -5.61218262e-02,  -5.61828613e-02],
                        [ -6.41479492e-02,  -6.50024414e-02],
                        [ -6.31408691e-02,  -6.39343262e-02],
                        [ -4.13513184e-02,  -4.19616699e-02],
                        [  3.63159180e-03,   2.96020508e-03],
                        [  6.63146973e-02,   6.56433105e-02],
                        [  1.34399414e-01,   1.34338379e-01],
                        [  1.90277100e-01,   1.90979004e-01],
                        [  2.18536377e-01,   2.19421387e-01],
                        [  2.15209961e-01,   2.15637207e-01],
                        [  1.88507080e-01,   1.88446045e-01],
                        [  1.53045654e-01,   1.53015137e-01],
                        [  1.23382568e-01,   1.23840332e-01],
                        [  1.06719971e-01,   1.07330322e-01],
                        [  9.93957520e-02,   9.93957520e-02],
                        [  9.33227539e-02,   9.20410156e-02],
                        [  8.41064453e-02,   8.17260742e-02],
                        [  7.29370117e-02,   7.08923340e-02],
                        [  6.40869141e-02,   6.41479492e-02],
                        [  6.03332520e-02,   6.32934570e-02],
                        [  6.04553223e-02,   6.50634766e-02],
                        [  6.33239746e-02,   6.64978027e-02],
                        [  7.24182129e-02,   7.15026855e-02],
                        [  9.14001465e-02,   8.66394043e-02],
                        [  1.14837646e-01,   1.09405518e-01],
                        [  1.26953125e-01,   1.24420166e-01],
                        [  1.11419678e-01,   1.13098145e-01],
                        [  6.19201660e-02,   6.63452148e-02],
                        [ -1.48620605e-02,  -1.05285645e-02],
                        [ -1.00830078e-01,  -9.88464355e-02],
                        [ -1.70104980e-01,  -1.70959473e-01],
                        [ -1.99127197e-01,  -2.01751709e-01],
                        [ -1.83898926e-01,  -1.86767578e-01],
                        [ -1.46209717e-01,  -1.48315430e-01],
                        [ -1.14532471e-01,  -1.15447998e-01],
                        [ -9.75646973e-02,  -9.70153809e-02],
                        [ -8.38928223e-02,  -8.17260742e-02],
                        [ -6.60705566e-02,  -6.31408691e-02],
                        [ -5.16967773e-02,  -4.96520996e-02],
                        [ -4.78820801e-02,  -4.79125977e-02],
                        [ -4.97741699e-02,  -5.15441895e-02],
                        [ -4.91027832e-02,  -5.13000488e-02],
                        [ -4.34265137e-02,  -4.49218750e-02],
                        [ -3.32946777e-02,  -3.36914062e-02],
                        [ -2.02941895e-02,  -1.98364258e-02],
                        [ -9.21630859e-03,  -8.63647461e-03],
                        [ -4.05883789e-03,  -3.72314453e-03],
                        [ -1.52587891e-03,  -8.54492188e-04],
                        [  2.59399414e-03,   4.18090820e-03],
                        [  4.08935547e-03,   5.98144531e-03],
                        [ -2.96020508e-03,  -2.34985352e-03],
                        [ -1.65710449e-02,  -1.82495117e-02],
                        [ -3.21350098e-02,  -3.55529785e-02],
                        [ -4.95300293e-02,  -5.28564453e-02],
                        [ -6.72607422e-02,  -6.83898926e-02],
                        [ -8.02917480e-02,  -7.81860352e-02],
                        [ -8.63342285e-02,  -8.20617676e-02],
                        [ -8.40454102e-02,  -8.02001953e-02],
                        [ -6.63146973e-02,  -6.51550293e-02],
                        [ -2.78625488e-02,  -2.96630859e-02],
                        [  2.30712891e-02,   1.98059082e-02],
                        [  7.00988770e-02,   6.70471191e-02],
                        [  1.02081299e-01,   1.00219727e-01],
                        [  1.16149902e-01,   1.15875244e-01],
                        [  1.14227295e-01,   1.15509033e-01],
                        [  1.01348877e-01,   1.03973389e-01],
                        [  8.37402344e-02,   8.71276855e-02],
                        [  6.56738281e-02,   6.84204102e-02],
                        [  4.89196777e-02,   4.91333008e-02],
                        [  3.52783203e-02,   3.21960449e-02],
                        [  2.83508301e-02,   2.35290527e-02],
                        [  2.94189453e-02,   2.58483887e-02],
                        [  3.29895020e-02,   3.28063965e-02],
                        [  3.23486328e-02,   3.53088379e-02],
                        [  2.82897949e-02,   3.23486328e-02],
                        [  2.57568359e-02,   2.85644531e-02],
                        [  2.50854492e-02,   2.56042480e-02],
                        [  2.60925293e-02,   2.47497559e-02],
                        [  3.38745117e-02,   3.18908691e-02],
                        [  5.25512695e-02,   5.06896973e-02],
                        [  7.83996582e-02,   7.66601562e-02],
                        [  1.05224609e-01,   1.04034424e-01],
                        [  1.30615234e-01,   1.30950928e-01],
                        [  1.50390625e-01,   1.52709961e-01],
                        [  1.55242920e-01,   1.58416748e-01],
                        [  1.37664795e-01,   1.39678955e-01],
                        [  9.41772461e-02,   9.36279297e-02],
                        [  2.13928223e-02,   1.85852051e-02],
                        [ -7.68737793e-02,  -7.98034668e-02],
                        [ -1.80511475e-01,  -1.81182861e-01],
                        [ -2.60803223e-01,  -2.58911133e-01],
                        [ -2.94281006e-01,  -2.91961670e-01],
                        [ -2.72155762e-01,  -2.72033691e-01],
                        [ -2.11151123e-01,  -2.13439941e-01],
                        [ -1.49169922e-01,  -1.51275635e-01],
                        [ -1.15142822e-01,  -1.14471436e-01],
                        [ -1.06658936e-01,  -1.03363037e-01],
                        [ -1.03332520e-01,  -1.00189209e-01],
                        [ -9.42077637e-02,  -9.40856934e-02],
                        [ -8.56628418e-02,  -8.86230469e-02],
                        [ -8.48388672e-02,  -8.83483887e-02],
                        [ -8.44116211e-02,  -8.60900879e-02],
                        [ -7.07397461e-02,  -7.03430176e-02],
                        [ -4.21447754e-02,  -4.07104492e-02],
                        [ -1.20849609e-02,  -1.02844238e-02],
                        [  5.03540039e-03,   7.08007812e-03],
                        [  7.53784180e-03,   9.49096680e-03],
                        [  3.14331055e-03,   3.84521484e-03],
                        [ -5.24902344e-03,  -6.98852539e-03],
                        [ -2.06298828e-02,  -2.44750977e-02],
                        [ -4.02832031e-02,  -4.39758301e-02],
                        [ -5.59082031e-02,  -5.68542480e-02],
                        [ -6.34765625e-02,  -6.09741211e-02],
                        [ -6.28967285e-02,  -5.87463379e-02],
                        [ -5.30090332e-02,  -4.99267578e-02],
                        [ -3.17687988e-02,  -3.12194824e-02],
                        [  3.41796875e-03,   1.61743164e-03],
                        [  5.36804199e-02,   5.08728027e-02],
                        [  1.13800049e-01,   1.11633301e-01],
                        [  1.69921875e-01,   1.69403076e-01],
                        [  2.04406738e-01,   2.05200195e-01],
                        [  2.06512451e-01,   2.07672119e-01],
                        [  1.81365967e-01,   1.82312012e-01],
                        [  1.46026611e-01,   1.46545410e-01],
                        [  1.16058350e-01,   1.16119385e-01],
                        [  9.77783203e-02,   9.76562500e-02],
                        [  8.89282227e-02,   8.89892578e-02],
                        [  8.32824707e-02,   8.37707520e-02],
                        [  7.78503418e-02,   7.82470703e-02],
                        [  7.43713379e-02,   7.36999512e-02],
                        [  7.29064941e-02,   7.08007812e-02],
                        [  6.89086914e-02,   6.64062500e-02],
                        [  6.05163574e-02,   5.96008301e-02],
                        [  5.32531738e-02,   5.53283691e-02],
                        [  5.29479980e-02,   5.74035645e-02],
                        [  5.87463379e-02,   6.28662109e-02],
                        [  6.77185059e-02,   6.85424805e-02],
                        [  8.09936523e-02,   7.75756836e-02],
                        [  9.74426270e-02,   9.15832520e-02],
                        [  1.06079102e-01,   1.01348877e-01],
                        [  9.23156738e-02,   9.18579102e-02],
                        [  5.00488281e-02,   5.42297363e-02],
                        [ -1.38549805e-02,  -7.78198242e-03],
                        [ -8.12683105e-02,  -7.72705078e-02],
                        [ -1.30676270e-01,  -1.30950928e-01],
                        [ -1.50177002e-01,  -1.53808594e-01],
                        [ -1.44226074e-01,  -1.48529053e-01],
                        [ -1.26434326e-01,  -1.28997803e-01],
                        [ -1.07666016e-01,  -1.07635498e-01],
                        [ -9.20715332e-02,  -9.02099609e-02],
                        [ -7.94372559e-02,  -7.73315430e-02],
                        [ -6.79321289e-02,  -6.66198730e-02],
                        [ -5.71899414e-02,  -5.67016602e-02],
                        [ -4.97436523e-02,  -4.95605469e-02],
                        [ -4.65698242e-02,  -4.64477539e-02],
                        [ -4.23889160e-02,  -4.26330566e-02],
                        [ -2.99987793e-02,  -3.10668945e-02],
                        [ -9.94873047e-03,  -1.18408203e-02],
                        [  8.11767578e-03,   6.31713867e-03],
                        [  1.52282715e-02,   1.47705078e-02],
                        [  1.14440918e-02,   1.27868652e-02],
                        [  3.29589844e-03,   5.70678711e-03],
                        [ -3.66210938e-03,  -1.28173828e-03],
                        [ -7.96508789e-03,  -6.53076172e-03],
                        [ -1.15966797e-02,  -1.18103027e-02],
                        [ -1.86462402e-02,  -2.07519531e-02],
                        [ -3.37524414e-02,  -3.69873047e-02],
                        [ -5.72509766e-02,  -6.00585938e-02],
                        [ -8.10241699e-02,  -8.19091797e-02],
                        [ -9.33227539e-02,  -9.16137695e-02],
                        [ -8.95690918e-02,  -8.58154297e-02],
                        [ -7.26013184e-02,  -6.88171387e-02],
                        [ -4.34265137e-02,  -4.19311523e-02],
                        [ -1.09863281e-03,  -2.77709961e-03],
                        [  4.65393066e-02,   4.30297852e-02],
                        [  8.20922852e-02,   7.89489746e-02],
                        [  9.38110352e-02,   9.25598145e-02],
                        [  8.74328613e-02,   8.82263184e-02],
                        [  7.64465332e-02,   7.83996582e-02],
                        [  6.59484863e-02,   6.77490234e-02],
                        [  5.27648926e-02,   5.37109375e-02],
                        [  3.71398926e-02,   3.75366211e-02],
                        [  2.52685547e-02,   2.56652832e-02],
                        [  2.28576660e-02,   2.30102539e-02],
                        [  3.01818848e-02,   2.92358398e-02],
                        [  4.16564941e-02,   3.93371582e-02],
                        [  4.98046875e-02,   4.71801758e-02],
                        [  5.11474609e-02,   4.99267578e-02],
                        [  4.68750000e-02,   4.81262207e-02],
                        [  4.00390625e-02,   4.34265137e-02],
                        [  3.50952148e-02,   3.89099121e-02],
                        [  3.75366211e-02,   3.95202637e-02],
                        [  5.08728027e-02,   4.94689941e-02],
                        [  7.36999512e-02,   6.95495605e-02],
                        [  1.00463867e-01,   9.61914062e-02],
                        [  1.25030518e-01,   1.23504639e-01],
                        [  1.42395020e-01,   1.44470215e-01],
                        [  1.45629883e-01,   1.49658203e-01],
                        [  1.24603271e-01,   1.27563477e-01],
                        [  7.11364746e-02,   7.09838867e-02],
                        [ -1.35498047e-02,  -1.62353516e-02],
                        [ -1.15783691e-01,  -1.18316650e-01],
                        [ -2.11669922e-01,  -2.11730957e-01],
                        [ -2.74230957e-01,  -2.72033691e-01],
                        [ -2.85980225e-01,  -2.83905029e-01],
                        [ -2.52502441e-01,  -2.52807617e-01],
                        [ -2.00439453e-01,  -2.03063965e-01],
                        [ -1.54449463e-01,  -1.57196045e-01],
                        [ -1.20910645e-01,  -1.21459961e-01],
                        [ -9.59472656e-02,  -9.37805176e-02],
                        [ -7.86437988e-02,  -7.54699707e-02],
                        [ -7.04040527e-02,  -6.83288574e-02],
                        [ -6.90307617e-02,  -6.89392090e-02],
                        [ -6.84204102e-02,  -6.97326660e-02],
                        [ -6.27746582e-02,  -6.48803711e-02],
                        [ -5.08422852e-02,  -5.34057617e-02],
                        [ -3.51562500e-02,  -3.74450684e-02],
                        [ -1.97143555e-02,  -2.02941895e-02],
                        [ -9.21630859e-03,  -7.01904297e-03],
                        [ -6.59179688e-03,  -2.07519531e-03],
                        [ -9.55200195e-03,  -5.15747070e-03],
                        [ -1.53198242e-02,  -1.40991211e-02],
                        [ -2.58789062e-02,  -2.91748047e-02],
                        [ -4.23889160e-02,  -4.84313965e-02],
                        [ -5.78918457e-02,  -6.26831055e-02],
                        [ -6.20422363e-02,  -6.23168945e-02],
                        [ -5.12084961e-02,  -4.70275879e-02],
                        [ -2.76794434e-02,  -2.22167969e-02],
                        [  8.85009766e-03,   1.19628906e-02],
                        [  6.10656738e-02,   6.02111816e-02],
                        [  1.23626709e-01,   1.20208740e-01],
                        [  1.78833008e-01,   1.75567627e-01],
                        [  2.06542969e-01,   2.05474854e-01],
                        [  1.99676514e-01,   2.00927734e-01],
                        [  1.68701172e-01,   1.70623779e-01],
                        [  1.31439209e-01,   1.32202148e-01],
                        [  1.01562500e-01,   1.00769043e-01],
                        [  8.29467773e-02,   8.17871094e-02],
                        [  7.04956055e-02,   7.03430176e-02],
                        [  5.90515137e-02,   6.02416992e-02],
                        [  5.28259277e-02,   5.44128418e-02],
                        [  5.79833984e-02,   5.87463379e-02],
                        [  6.80236816e-02,   6.75048828e-02],
                        [  6.82373047e-02,   6.68334961e-02],
                        [  5.44128418e-02,   5.26428223e-02],
                        [  3.86352539e-02,   3.70483398e-02],
                        [  3.49426270e-02,   3.43017578e-02],
                        [  4.47387695e-02,   4.58068848e-02],
                        [  5.92041016e-02,   6.21643066e-02],
                        [  7.28454590e-02,   7.63854980e-02],
                        [  8.75549316e-02,   8.93249512e-02],
                        [  1.04736328e-01,   1.02935791e-01],
                        [  1.18804932e-01,   1.14074707e-01],
                        [  1.19354248e-01,   1.14776611e-01],
                        [  9.54589844e-02,   9.42993164e-02],
                        [  3.93676758e-02,   4.22973633e-02],
                        [ -4.53796387e-02,  -4.07104492e-02],
                        [ -1.34826660e-01,  -1.31561279e-01],
                        [ -1.92993164e-01,  -1.92718506e-01],
                        [ -2.00012207e-01,  -2.02056885e-01],
                        [ -1.69219971e-01,  -1.71813965e-01],
                        [ -1.32293701e-01,  -1.34094238e-01],
                        [ -1.10595703e-01,  -1.11236572e-01],
                        [ -1.02661133e-01,  -1.02508545e-01],
                        [ -9.50317383e-02,  -9.45129395e-02],
                        [ -7.90710449e-02,  -7.82775879e-02],
                        [ -5.63049316e-02,  -5.49926758e-02],
                        [ -3.42102051e-02,  -3.24096680e-02],
                        [ -2.11791992e-02,  -1.98364258e-02],
                        [ -1.91345215e-02,  -1.95312500e-02],
                        [ -1.89208984e-02,  -2.13928223e-02],
                        [ -1.12609863e-02,  -1.43432617e-02],
                        [  9.15527344e-05,  -1.52587891e-03],
                        [  3.35693359e-03,   4.11987305e-03],
                        [ -5.27954102e-03,  -2.89916992e-03],
                        [ -1.72119141e-02,  -1.47705078e-02],
                        [ -2.24304199e-02,  -2.11181641e-02],
                        [ -2.07824707e-02,  -2.08435059e-02],
                        [ -2.06604004e-02,  -2.17285156e-02],
                        [ -3.00903320e-02,  -3.15551758e-02],
                        [ -5.05065918e-02,  -5.20019531e-02],
                        [ -7.44323730e-02,  -7.56530762e-02],
                        [ -8.90197754e-02,  -8.93249512e-02],
                        [ -8.57849121e-02,  -8.45947266e-02],
                        [ -6.57043457e-02,  -6.34765625e-02],
                        [ -3.34167480e-02,  -3.17077637e-02],
                        [  7.59887695e-03,   7.47680664e-03],
                        [  5.13000488e-02,   4.96826172e-02],
                        [  8.67614746e-02,   8.52355957e-02],
                        [  1.04522705e-01,   1.04431152e-01],
                        [  1.03912354e-01,   1.05163574e-01],
                        [  9.14001465e-02,   9.23461914e-02],
                        [  7.36999512e-02,   7.27539062e-02],
                        [  5.63964844e-02,   5.39550781e-02],
                        [  4.42504883e-02,   4.26635742e-02],
                        [  3.72924805e-02,   3.86352539e-02],
                        [  3.32031250e-02,   3.70483398e-02],
                        [  3.55529785e-02,   3.92150879e-02],
                        [  4.94995117e-02,   5.00793457e-02],
                        [  6.83288574e-02,   6.50329590e-02],
                        [  7.72094727e-02,   7.18994141e-02],
                        [  7.11059570e-02,   6.73217773e-02],
                        [  5.90515137e-02,   5.95092773e-02],
                        [  5.12390137e-02,   5.56030273e-02],
                        [  5.20935059e-02,   5.72814941e-02],
                        [  6.45751953e-02,   6.72912598e-02],
                        [  8.88366699e-02,   8.77075195e-02],
                        [  1.16760254e-01,   1.12945557e-01],
                        [  1.36810303e-01,   1.33117676e-01],
                        [  1.42822266e-01,   1.41540527e-01],
                        [  1.30310059e-01,   1.31591797e-01],
                        [  9.08203125e-02,   9.28649902e-02],
                        [  1.87988281e-02,   1.98669434e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -1.79809570e-01,  -1.79809570e-01],
                        [ -2.56469727e-01,  -2.55920410e-01],
                        [ -2.82104492e-01,  -2.81646729e-01],
                        [ -2.52777100e-01,  -2.53173828e-01],
                        [ -1.95404053e-01,  -1.96624756e-01],
                        [ -1.46881104e-01,  -1.48101807e-01],
                        [ -1.23718262e-01,  -1.24084473e-01],
                        [ -1.16210938e-01,  -1.15722656e-01],
                        [ -1.08612061e-01,  -1.08062744e-01],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -8.89587402e-02,  -8.89282227e-02],
                        [ -8.30383301e-02,  -8.20007324e-02],
                        [ -7.08923340e-02,  -6.89086914e-02],
                        [ -4.87976074e-02,  -4.75463867e-02],
                        [ -2.36206055e-02,  -2.48413086e-02],
                        [ -3.84521484e-03,  -7.35473633e-03],
                        [  5.67626953e-03,   2.04467773e-03],
                        [  3.38745117e-03,   2.28881836e-03],
                        [ -5.70678711e-03,  -3.17382812e-03],
                        [ -1.40075684e-02,  -9.18579102e-03],
                        [ -2.26745605e-02,  -1.86462402e-02],
                        [ -3.84521484e-02,  -3.80249023e-02],
                        [ -5.71899414e-02,  -6.06689453e-02],
                        [ -6.46972656e-02,  -6.95495605e-02],
                        [ -5.52368164e-02,  -5.82580566e-02],
                        [ -3.41491699e-02,  -3.35998535e-02],
                        [ -1.03759766e-03,   2.25830078e-03],
                        [  5.11779785e-02,   5.46569824e-02],
                        [  1.18682861e-01,   1.19903564e-01],
                        [  1.82556152e-01,   1.81182861e-01],
                        [  2.22534180e-01,   2.20367432e-01],
                        [  2.27325439e-01,   2.26501465e-01],
                        [  1.99523926e-01,   2.00347900e-01],
                        [  1.55517578e-01,   1.56616211e-01],
                        [  1.14685059e-01,   1.14624023e-01],
                        [  8.67004395e-02,   8.53576660e-02],
                        [  7.09228516e-02,   6.95495605e-02],
                        [  6.23168945e-02,   6.21948242e-02],
                        [  5.59692383e-02,   5.74340820e-02],
                        [  5.04760742e-02,   5.23681641e-02],
                        [  4.56848145e-02,   4.66918945e-02],
                        [  3.93066406e-02,   3.90625000e-02],
                        [  2.91748047e-02,   2.81677246e-02],
                        [  1.78222656e-02,   1.66015625e-02],
                        [  1.19934082e-02,   1.07727051e-02],
                        [  1.75781250e-02,   1.66931152e-02],
                        [  3.45458984e-02,   3.44848633e-02],
                        [  5.56030273e-02,   5.67016602e-02],
                        [  7.35168457e-02,   7.55004883e-02],
                        [  8.82263184e-02,   9.01489258e-02],
                        [  1.03485107e-01,   1.04125977e-01],
                        [  1.17706299e-01,   1.16394043e-01],
                        [  1.22314453e-01,   1.19842529e-01],
                        [  1.07147217e-01,   1.05194092e-01],
                        [  6.42089844e-02,   6.38732910e-02],
                        [ -8.60595703e-03,  -7.56835938e-03],
                        [ -9.96093750e-02,  -9.82055664e-02],
                        [ -1.80267334e-01,  -1.79229736e-01],
                        [ -2.18780518e-01,  -2.18170166e-01],
                        [ -2.04376221e-01,  -2.03979492e-01],
                        [ -1.56982422e-01,  -1.56860352e-01],
                        [ -1.08734131e-01,  -1.09222412e-01],
                        [ -7.76367188e-02,  -7.90100098e-02],
                        [ -6.15844727e-02,  -6.35375977e-02],
                        [ -5.21240234e-02,  -5.36499023e-02],
                        [ -4.64172363e-02,  -4.62036133e-02],
                        [ -4.71801758e-02,  -4.47692871e-02],
                        [ -5.45959473e-02,  -5.11474609e-02],
                        [ -5.99670410e-02,  -5.78308105e-02],
                        [ -5.27343750e-02,  -5.35888672e-02],
                        [ -3.31115723e-02,  -3.64379883e-02],
                        [ -1.26342773e-02,  -1.60827637e-02],
                        [ -1.46484375e-03,  -2.74658203e-03],
                        [ -2.13623047e-04,   1.06811523e-03],
                        [ -3.93676758e-03,  -1.40380859e-03],
                        [ -9.76562500e-03,  -7.65991211e-03],
                        [ -1.83715820e-02,  -1.76086426e-02],
                        [ -3.01818848e-02,  -3.06396484e-02],
                        [ -4.30908203e-02,  -4.41894531e-02],
                        [ -5.62133789e-02,  -5.74340820e-02],
                        [ -7.18078613e-02,  -7.27844238e-02],
                        [ -8.80432129e-02,  -8.83789062e-02],
                        [ -9.19189453e-02,  -9.14306641e-02],
                        [ -6.94580078e-02,  -6.83898926e-02],
                        [ -2.29797363e-02,  -2.21862793e-02],
                        [  2.96020508e-02,   2.94799805e-02],
                        [  7.19604492e-02,   7.11669922e-02],
                        [  9.82666016e-02,   9.77172852e-02],
                        [  1.08459473e-01,   1.08947754e-01],
                        [  1.03698730e-01,   1.04980469e-01],
                        [  8.73413086e-02,   8.81347656e-02],
                        [  6.81152344e-02,   6.74133301e-02],
                        [  5.69458008e-02,   5.48095703e-02],
                        [  5.56030273e-02,   5.34057617e-02],
                        [  5.59082031e-02,   5.53894043e-02],
                        [  5.32836914e-02,   5.52673340e-02],
                        [  5.22460938e-02,   5.57556152e-02],
                        [  5.59692383e-02,   5.85937500e-02],
                        [  5.98449707e-02,   5.96618652e-02],
                        [  5.85937500e-02,   5.56030273e-02],
                        [  5.44433594e-02,   5.06591797e-02],
                        [  5.52368164e-02,   5.31921387e-02],
                        [  6.45141602e-02,   6.52770996e-02],
                        [  7.78808594e-02,   8.05969238e-02],
                        [  9.18579102e-02,   9.46044922e-02],
                        [  1.08245850e-01,   1.09588623e-01],
                        [  1.26159668e-01,   1.25793457e-01],
                        [  1.36779785e-01,   1.35406494e-01],
                        [  1.29119873e-01,   1.27593994e-01],
                        [  9.49401855e-02,   9.37194824e-02],
                        [  2.87170410e-02,   2.79235840e-02],
                        [ -6.73522949e-02,  -6.72607422e-02],
                        [ -1.74072266e-01,  -1.72851562e-01],
                        [ -2.58483887e-01,  -2.56622314e-01],
                        [ -2.92510986e-01,  -2.91259766e-01],
                        [ -2.71484375e-01,  -2.71789551e-01],
                        [ -2.15698242e-01,  -2.17254639e-01],
                        [ -1.54846191e-01,  -1.56341553e-01],
                        [ -1.10351562e-01,  -1.10504150e-01],
                        [ -8.80126953e-02,  -8.68530273e-02],
                        [ -8.16345215e-02,  -8.03833008e-02],
                        [ -8.05664062e-02,  -8.05969238e-02],
                        [ -7.88574219e-02,  -8.02612305e-02],
                        [ -7.83081055e-02,  -7.97729492e-02],
                        [ -7.91931152e-02,  -7.92846680e-02],
                        [ -7.30590820e-02,  -7.14416504e-02],
                        [ -5.35583496e-02,  -5.13305664e-02],
                        [ -2.80761719e-02,  -2.69165039e-02],
                        [ -8.48388672e-03,  -9.30786133e-03],
                        [  3.35693359e-03,   1.06811523e-03],
                        [  1.05285645e-02,   8.30078125e-03],
                        [  8.33129883e-03,   7.59887695e-03],
                        [ -1.01013184e-02,  -9.06372070e-03],
                        [ -3.86047363e-02,  -3.65905762e-02],
                        [ -6.06384277e-02,  -5.88684082e-02],
                        [ -6.59790039e-02,  -6.53381348e-02],
                        [ -5.50537109e-02,  -5.56640625e-02],
                        [ -2.81372070e-02,  -2.94799805e-02],
                        [  1.69677734e-02,   1.57775879e-02],
                        [  7.55004883e-02,   7.50122070e-02],
                        [  1.32781982e-01,   1.32843018e-01],
                        [  1.72973633e-01,   1.73156738e-01],
                        [  1.87316895e-01,   1.87500000e-01],
                        [  1.76116943e-01,   1.76605225e-01],
                        [  1.49414062e-01,   1.50329590e-01],
                        [  1.23901367e-01,   1.24877930e-01],
                        [  1.10992432e-01,   1.11389160e-01],
                        [  1.07299805e-01,   1.06689453e-01],
                        [  1.02111816e-01,   1.00585938e-01],
                        [  9.16442871e-02,   8.99658203e-02],
                        [  7.91320801e-02,   7.83386230e-02],
                        [  6.47583008e-02,   6.54602051e-02],
                        [  4.67834473e-02,   4.85534668e-02],
                        [  2.97851562e-02,   3.15551758e-02],
                        [  1.91345215e-02,   1.99279785e-02],
                        [  1.01013184e-02,   9.67407227e-03],
                        [ -2.99072266e-03,  -4.30297852e-03],
                        [ -1.09252930e-02,  -1.24206543e-02],
                        [ -9.46044922e-04,  -1.89208984e-03],
                        [  2.05383301e-02,   2.04467773e-02],
                        [  3.57666016e-02,   3.64379883e-02],
                        [  4.22973633e-02,   4.33654785e-02],
                        [  5.30395508e-02,   5.41076660e-02],
                        [  7.49511719e-02,   7.55615234e-02],
                        [  1.02447510e-01,   1.02233887e-01],
                        [  1.25091553e-01,   1.24298096e-01],
                        [  1.28234863e-01,   1.27410889e-01],
                        [  9.49096680e-02,   9.44519043e-02],
                        [  2.17285156e-02,   2.16064453e-02],
                        [ -7.22045898e-02,  -7.21740723e-02],
                        [ -1.57226562e-01,  -1.57135010e-01],
                        [ -2.08465576e-01,  -2.08251953e-01],
                        [ -2.13562012e-01,  -2.13012695e-01],
                        [ -1.79321289e-01,  -1.78436279e-01],
                        [ -1.31072998e-01,  -1.30310059e-01],
                        [ -9.45434570e-02,  -9.45129395e-02],
                        [ -7.75756836e-02,  -7.86437988e-02],
                        [ -7.24487305e-02,  -7.42187500e-02],
                        [ -7.00988770e-02,  -7.15637207e-02],
                        [ -6.74438477e-02,  -6.75659180e-02],
                        [ -6.44836426e-02,  -6.28662109e-02],
                        [ -6.08520508e-02,  -5.84411621e-02],
                        [ -5.53283691e-02,  -5.36804199e-02],
                        [ -4.51049805e-02,  -4.52880859e-02],
                        [ -2.76184082e-02,  -2.94799805e-02],
                        [ -7.11059570e-03,  -9.39941406e-03],
                        [  4.79125977e-03,   3.44848633e-03],
                        [  1.83105469e-04,   4.88281250e-04],
                        [ -1.57165527e-02,  -1.41296387e-02],
                        [ -3.18298340e-02,  -3.01208496e-02],
                        [ -4.32739258e-02,  -4.25109863e-02],
                        [ -5.18188477e-02,  -5.21545410e-02],
                        [ -5.95397949e-02,  -6.04858398e-02],
                        [ -6.76879883e-02,  -6.84814453e-02],
                        [ -7.55310059e-02,  -7.57751465e-02],
                        [ -7.66601562e-02,  -7.65075684e-02],
                        [ -6.09130859e-02,  -6.07299805e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [  2.36816406e-02,   2.36206055e-02],
                        [  6.77490234e-02,   6.77795410e-02],
                        [  9.56115723e-02,   9.57946777e-02],
                        [  1.03851318e-01,   1.04187012e-01],
                        [  9.57641602e-02,   9.61608887e-02],
                        [  7.99865723e-02,   8.02917480e-02],
                        [  6.88781738e-02,   6.86950684e-02],
                        [  6.79016113e-02,   6.71386719e-02],
                        [  6.93664551e-02,   6.84204102e-02],
                        [  6.57653809e-02,   6.51550293e-02],
                        [  6.31408691e-02,   6.33239746e-02],
                        [  6.91528320e-02,   7.01904297e-02],
                        [  7.56835938e-02,   7.70874023e-02],
                        [  6.96105957e-02,   7.04650879e-02],
                        [  5.49926758e-02,   5.46569824e-02],
                        [  4.78820801e-02,   4.66918945e-02],
                        [  5.39245605e-02,   5.26733398e-02],
                        [  6.60705566e-02,   6.55212402e-02],
                        [  8.19396973e-02,   8.21533203e-02],
                        [  1.05651855e-01,   1.06262207e-01],
                        [  1.32354736e-01,   1.32995605e-01],
                        [  1.45080566e-01,   1.45629883e-01],
                        [  1.30035400e-01,   1.30493164e-01],
                        [  8.64868164e-02,   8.66088867e-02],
                        [  1.94396973e-02,   1.89208984e-02],
                        [ -6.67114258e-02,  -6.77795410e-02],
                        [ -1.61102295e-01,  -1.61987305e-01],
                        [ -2.39135742e-01,  -2.39105225e-01],
                        [ -2.73864746e-01,  -2.72949219e-01],
                        [ -2.57629395e-01,  -2.56652832e-01],
                        [ -2.08862305e-01,  -2.08648682e-01],
                        [ -1.56738281e-01,  -1.57348633e-01],
                        [ -1.21093750e-01,  -1.21765137e-01],
                        [ -1.04675293e-01,  -1.04614258e-01],
                        [ -9.82055664e-02,  -9.75341797e-02],
                        [ -9.14611816e-02,  -9.09118652e-02],
                        [ -8.20922852e-02,  -8.22753906e-02],
                        [ -7.41577148e-02,  -7.49816895e-02],
                        [ -6.82373047e-02,  -6.90307617e-02],
                        [ -5.90515137e-02,  -5.92041016e-02],
                        [ -4.39453125e-02,  -4.33959961e-02],
                        [ -2.58789062e-02,  -2.50244141e-02],
                        [ -8.66699219e-03,  -8.05664062e-03],
                        [  3.14331055e-03,   3.23486328e-03],
                        [  4.11987305e-03,   3.81469727e-03],
                        [ -7.29370117e-03,  -7.75146484e-03],
                        [ -2.89611816e-02,  -2.94799805e-02],
                        [ -5.65795898e-02,  -5.70983887e-02],
                        [ -7.71484375e-02,  -7.74841309e-02],
                        [ -7.23571777e-02,  -7.22045898e-02],
                        [ -3.82995605e-02,  -3.75671387e-02],
                        [  1.19628906e-02,   1.30004883e-02],
                        [  6.99462891e-02,   7.07092285e-02],
                        [  1.35559082e-01,   1.35498047e-01],
                        [  1.95556641e-01,   1.94671631e-01],
                        [  2.24090576e-01,   2.22900391e-01],
                        [  2.11975098e-01,   2.11212158e-01],
                        [  1.77032471e-01,   1.77093506e-01],
                        [  1.40686035e-01,   1.41357422e-01],
                        [  1.10656738e-01,   1.11450195e-01],
                        [  8.75244141e-02,   8.81347656e-02],
                        [  7.27539062e-02,   7.30590820e-02],
                        [  6.68945312e-02,   6.68334961e-02],
                        [  6.80236816e-02,   6.75964355e-02],
                        [  7.23571777e-02,   7.16552734e-02],
                        [  7.35168457e-02,   7.27844238e-02],
                        [  6.46972656e-02,   6.42700195e-02],
                        [  4.47998047e-02,   4.50439453e-02],
                        [  2.03857422e-02,   2.12707520e-02],
                        [  9.15527344e-05,   1.06811523e-03],
                        [ -1.15661621e-02,  -1.11083984e-02],
                        [ -1.38854980e-02,  -1.41296387e-02],
                        [ -5.79833984e-03,  -6.53076172e-03],
                        [  1.32141113e-02,   1.24816895e-02],
                        [  3.87268066e-02,   3.83605957e-02],
                        [  6.17370605e-02,   6.18591309e-02],
                        [  7.59887695e-02,   7.63854980e-02],
                        [  8.22143555e-02,   8.25500488e-02],
                        [  8.62121582e-02,   8.63647461e-02],
                        [  9.34448242e-02,   9.35058594e-02],
                        [  1.02508545e-01,   1.02630615e-01],
                        [  1.01898193e-01,   1.01989746e-01],
                        [  7.54089355e-02,   7.53479004e-02],
                        [  1.51062012e-02,   1.48315430e-02],
                        [ -6.96411133e-02,  -7.00683594e-02],
                        [ -1.53259277e-01,  -1.53594971e-01],
                        [ -2.04925537e-01,  -2.04925537e-01],
                        [ -2.06298828e-01,  -2.05902100e-01],
                        [ -1.65863037e-01,  -1.65283203e-01],
                        [ -1.11907959e-01,  -1.11480713e-01],
                        [ -6.83288574e-02,  -6.82373047e-02],
                        [ -4.17480469e-02,  -4.19006348e-02],
                        [ -3.11889648e-02,  -3.15856934e-02],
                        [ -3.64685059e-02,  -3.69873047e-02],
                        [ -5.20019531e-02,  -5.24597168e-02],
                        [ -6.64367676e-02,  -6.65893555e-02],
                        [ -7.50427246e-02,  -7.47070312e-02],
                        [ -8.13293457e-02,  -8.05664062e-02],
                        [ -8.33435059e-02,  -8.25500488e-02],
                        [ -7.11975098e-02,  -7.08923340e-02],
                        [ -4.35485840e-02,  -4.40063477e-02],
                        [ -1.53198242e-02,  -1.62353516e-02],
                        [ -1.67846680e-03,  -2.50244141e-03],
                        [ -2.41088867e-03,  -2.56347656e-03],
                        [ -7.65991211e-03,  -7.14111328e-03],
                        [ -1.37329102e-02,  -1.29699707e-02],
                        [ -2.63977051e-02,  -2.59094238e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -7.79418945e-02,  -7.82775879e-02],
                        [ -9.53674316e-02,  -9.57336426e-02],
                        [ -9.02099609e-02,  -9.03930664e-02],
                        [ -6.04858398e-02,  -6.04553223e-02],
                        [ -1.29089355e-02,  -1.28173828e-02],
                        [  4.12292480e-02,   4.12902832e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  1.19232178e-01,   1.19201660e-01],
                        [  1.27624512e-01,   1.27685547e-01],
                        [  1.17950439e-01,   1.18103027e-01],
                        [  9.93652344e-02,   9.94567871e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  6.48193359e-02,   6.46972656e-02],
                        [  5.38940430e-02,   5.37719727e-02],
                        [  4.79125977e-02,   4.78210449e-02],
                        [  4.69360352e-02,   4.68444824e-02],
                        [  4.99877930e-02,   4.98657227e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  5.68847656e-02,   5.70373535e-02],
                        [  5.92956543e-02,   5.96008301e-02],
                        [  6.73828125e-02,   6.76574707e-02],
                        [  8.30383301e-02,   8.30688477e-02],
                        [  1.01409912e-01,   1.01196289e-01],
                        [  1.18438721e-01,   1.18072510e-01],
                        [  1.32507324e-01,   1.32171631e-01],
                        [  1.38183594e-01,   1.38061523e-01],
                        [  1.26312256e-01,   1.26464844e-01],
                        [  8.84399414e-02,   8.87756348e-02],
                        [  1.82495117e-02,   1.85852051e-02],
                        [ -8.16955566e-02,  -8.15734863e-02],
                        [ -1.90063477e-01,  -1.90185547e-01],
                        [ -2.72583008e-01,  -2.72796631e-01],
                        [ -3.04199219e-01,  -3.04321289e-01],
                        [ -2.83050537e-01,  -2.83111572e-01],
                        [ -2.28271484e-01,  -2.28363037e-01],
                        [ -1.68304443e-01,  -1.68457031e-01],
                        [ -1.24877930e-01,  -1.24938965e-01],
                        [ -1.00860596e-01,  -1.00646973e-01],
                        [ -8.63952637e-02,  -8.59680176e-02],
                        [ -7.44018555e-02,  -7.40356445e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -5.44433594e-02,  -5.48706055e-02],
                        [ -4.10461426e-02,  -4.15344238e-02],
                        [ -2.22778320e-02,  -2.25219727e-02],
                        [ -2.10571289e-03,  -1.95312500e-03],
                        [  1.26647949e-02,   1.29699707e-02],
                        [  1.78222656e-02,   1.79748535e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -6.19506836e-03,  -6.22558594e-03],
                        [ -3.94592285e-02,  -3.93981934e-02],
                        [ -7.81250000e-02,  -7.79418945e-02],
                        [ -1.01898193e-01,  -1.01806641e-01],
                        [ -9.59167480e-02,  -9.61303711e-02],
                        [ -6.29577637e-02,  -6.33850098e-02],
                        [ -1.55334473e-02,  -1.58996582e-02],
                        [  3.97338867e-02,   3.97033691e-02],
                        [  1.02966309e-01,   1.03363037e-01],
                        [  1.67144775e-01,   1.67724609e-01],
                        [  2.12799072e-01,   2.13195801e-01],
                        [  2.23968506e-01,   2.23907471e-01],
                        [  2.03887939e-01,   2.03430176e-01],
                        [  1.70562744e-01,   1.70013428e-01],
                        [  1.40716553e-01,   1.40411377e-01],
                        [  1.19689941e-01,   1.19750977e-01],
                        [  1.02508545e-01,   1.02813721e-01],
                        [  8.33435059e-02,   8.37402344e-02],
                        [  6.38732910e-02,   6.40869141e-02],
                        [  5.02624512e-02,   5.02929688e-02],
                        [  4.34570312e-02,   4.33349609e-02],
                        [  3.60412598e-02,   3.58581543e-02],
                        [  2.05993652e-02,   2.03857422e-02],
                        [ -2.13623047e-04,  -3.96728516e-04],
                        [ -1.43127441e-02,  -1.43737793e-02],
                        [ -1.34277344e-02,  -1.33361816e-02],
                        [ -2.25830078e-03,  -2.04467773e-03],
                        [  8.54492188e-03,   8.78906250e-03],
                        [  1.42211914e-02,   1.43432617e-02],
                        [  1.65405273e-02,   1.64794922e-02],
                        [  1.88903809e-02,   1.86767578e-02],
                        [  2.60009766e-02,   2.57873535e-02],
                        [  4.26025391e-02,   4.25415039e-02],
                        [  6.59484863e-02,   6.59790039e-02],
                        [  8.51440430e-02,   8.52355957e-02],
                        [  9.42993164e-02,   9.43908691e-02],
                        [  9.96704102e-02,   9.97009277e-02],
                        [  1.06140137e-01,   1.06170654e-01],
                        [  1.02783203e-01,   1.02813721e-01],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  3.96728516e-04,   3.35693359e-04],
                        [ -9.32922363e-02,  -9.34143066e-02],
                        [ -1.79382324e-01,  -1.79473877e-01],
                        [ -2.24609375e-01,  -2.24578857e-01],
                        [ -2.16400146e-01,  -2.16278076e-01],
                        [ -1.73095703e-01,  -1.72973633e-01],
                        [ -1.27380371e-01,  -1.27349854e-01],
                        [ -9.91516113e-02,  -9.92126465e-02],
                        [ -8.60900879e-02,  -8.61511230e-02],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [ -6.44226074e-02,  -6.43615723e-02],
                        [ -5.41381836e-02,  -5.41076660e-02],
                        [ -4.94995117e-02,  -4.95605469e-02],
                        [ -4.88281250e-02,  -4.89807129e-02],
                        [ -4.76074219e-02,  -4.76989746e-02],
                        [ -4.26940918e-02,  -4.26330566e-02],
                        [ -3.31115723e-02,  -3.29284668e-02],
                        [ -2.05993652e-02,  -2.04162598e-02],
                        [ -1.05590820e-02,  -1.04980469e-02],
                        [ -8.17871094e-03,  -8.30078125e-03],
                        [ -1.40686035e-02,  -1.42822266e-02],
                        [ -2.74047852e-02,  -2.75573730e-02],
                        [ -4.89807129e-02,  -4.89501953e-02],
                        [ -7.52563477e-02,  -7.51037598e-02],
                        [ -9.51232910e-02,  -9.49707031e-02],
                        [ -9.99145508e-02,  -9.98535156e-02],
                        [ -9.05456543e-02,  -9.05761719e-02],
                        [ -6.92443848e-02,  -6.93359375e-02],
                        [ -3.29284668e-02,  -3.29895020e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  7.68432617e-02,   7.68737793e-02],
                        [  1.24786377e-01,   1.24786377e-01],
                        [  1.48925781e-01,   1.48925781e-01],
                        [  1.43310547e-01,   1.43310547e-01],
                        [  1.14044189e-01,   1.14074707e-01],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  6.22863770e-02,   6.23168945e-02],
                        [  6.92749023e-02,   6.93054199e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  7.84606934e-02,   7.83996582e-02],
                        [  8.71887207e-02,   8.70971680e-02],
                        [  9.56420898e-02,   9.55810547e-02],
                        [  1.00219727e-01,   1.00250244e-01],
                        [  1.01562500e-01,   1.01654053e-01],
                        [  1.03332520e-01,   1.03424072e-01],
                        [  1.09161377e-01,   1.09222412e-01],
                        [  1.19812012e-01,   1.19781494e-01],
                        [  1.28021240e-01,   1.27929688e-01],
                        [  1.16943359e-01,   1.16851807e-01],
                        [  7.01293945e-02,   7.00988770e-02],
                        [ -1.47399902e-02,  -1.47094727e-02],
                        [ -1.22100830e-01,  -1.22039795e-01],
                        [ -2.22503662e-01,  -2.22473145e-01],
                        [ -2.82257080e-01,  -2.82226562e-01],
                        [ -2.82531738e-01,  -2.82501221e-01],
                        [ -2.36663818e-01,  -2.36663818e-01],
                        [ -1.80969238e-01,  -1.80969238e-01],
                        [ -1.44226074e-01,  -1.44287109e-01],
                        [ -1.28479004e-01,  -1.28570557e-01],
                        [ -1.17797852e-01,  -1.17858887e-01],
                        [ -1.00250244e-01,  -1.00250244e-01],
                        [ -7.76977539e-02,  -7.76062012e-02],
                        [ -5.77087402e-02,  -5.76171875e-02],
                        [ -4.41589355e-02,  -4.41284180e-02],
                        [ -3.66821289e-02,  -3.67431641e-02],
                        [ -3.23181152e-02,  -3.24096680e-02],
                        [ -2.64892578e-02,  -2.65502930e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -9.39941406e-03,  -9.36889648e-03],
                        [ -9.36889648e-03,  -9.33837891e-03],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  4.20532227e-02,   4.20227051e-02],
                        [  9.95788574e-02,   9.95483398e-02],
                        [  1.60156250e-01,   1.60125732e-01],
                        [  2.01385498e-01,   2.01385498e-01],
                        [  2.04956055e-01,   2.04986572e-01],
                        [  1.77459717e-01,   1.77490234e-01],
                        [  1.46209717e-01,   1.46240234e-01],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  1.24481201e-01,   1.24481201e-01],
                        [  1.04797363e-01,   1.04766846e-01],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  6.34765625e-02,   6.35070801e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -2.99072266e-03,  -3.02124023e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  1.06536865e-01,   1.06536865e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.15356445e-01,  -1.15356445e-01],
                        [ -1.88293457e-01,  -1.88293457e-01],
                        [ -2.10723877e-01,  -2.10723877e-01],
                        [ -1.83807373e-01,  -1.83807373e-01],
                        [ -1.39282227e-01,  -1.39282227e-01],
                        [ -1.07666016e-01,  -1.07666016e-01],
                        [ -9.48791504e-02,  -9.48791504e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -7.59582520e-02,  -7.59582520e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -7.49816895e-02,  -7.49816895e-02],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  1.35253906e-01,   1.35253906e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  9.50317383e-02,   9.50317383e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  8.37097168e-02,   8.37097168e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  1.43829346e-01,   1.43829346e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  7.08007812e-02,   7.08007812e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -1.00097656e-01,  -1.00097656e-01],
                        [ -1.95800781e-01,  -1.95800781e-01],
                        [ -2.67883301e-01,  -2.67883301e-01],
                        [ -2.89367676e-01,  -2.89367676e-01],
                        [ -2.56805420e-01,  -2.56805420e-01],
                        [ -1.97143555e-01,  -1.97143555e-01],
                        [ -1.45629883e-01,  -1.45629883e-01],
                        [ -1.20727539e-01,  -1.20727539e-01],
                        [ -1.17401123e-01,  -1.17401123e-01],
                        [ -1.17309570e-01,  -1.17309570e-01],
                        [ -1.05926514e-01,  -1.05926514e-01],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  1.05224609e-01,   1.05224609e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.80389404e-01,   1.80389404e-01],
                        [  1.82861328e-01,   1.82861328e-01],
                        [  1.64520264e-01,   1.64520264e-01],
                        [  1.44348145e-01,   1.44348145e-01],
                        [  1.36749268e-01,   1.36749268e-01],
                        [  1.36749268e-01,   1.36749268e-01],
                        [  1.29577637e-01,   1.29577637e-01],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  8.20922852e-02,   8.20922852e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.13067627e-01,   1.13067627e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  5.97839355e-02,   5.97839355e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.85028076e-01,  -1.85028076e-01],
                        [ -2.15850830e-01,  -2.15850830e-01],
                        [ -1.97601318e-01,  -1.97601318e-01],
                        [ -1.51580811e-01,  -1.51580811e-01],
                        [ -1.06567383e-01,  -1.06567383e-01],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -8.19702148e-02,  -8.19702148e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -7.48596191e-02,  -7.48596191e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  9.62829590e-02,   9.62829590e-02],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.27746582e-01,   1.27746582e-01],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  6.88476562e-02,   6.88476562e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -9.25903320e-02,  -9.25903320e-02],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -2.47253418e-01,  -2.47253418e-01],
                        [ -2.83325195e-01,  -2.83325195e-01],
                        [ -2.65930176e-01,  -2.65930176e-01],
                        [ -2.09716797e-01,  -2.09716797e-01],
                        [ -1.56219482e-01,  -1.56219482e-01],
                        [ -1.30310059e-01,  -1.30310059e-01],
                        [ -1.20483398e-01,  -1.20483398e-01],
                        [ -1.06903076e-01,  -1.06903076e-01],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  2.00134277e-01,   2.00134277e-01],
                        [  1.94335938e-01,   1.94335938e-01],
                        [  1.67907715e-01,   1.67907715e-01],
                        [  1.40380859e-01,   1.40380859e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  5.52673340e-02,   5.52673340e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [ -8.95080566e-02,  -8.95080566e-02],
                        [ -1.72851562e-01,  -1.72851562e-01],
                        [ -2.08496094e-01,  -2.08496094e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.39434814e-01,  -1.39434814e-01],
                        [ -1.00708008e-01,  -1.00708008e-01],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -9.08813477e-02,  -9.08813477e-02],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -7.44018555e-02,  -7.44018555e-02],
                        [ -6.44836426e-02,  -6.44836426e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -7.87963867e-02,  -7.87963867e-02],
                        [ -9.46655273e-02,  -9.46655273e-02],
                        [ -1.01440430e-01,  -1.01440430e-01],
                        [ -9.09729004e-02,  -9.09729004e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  1.18591309e-01,   1.18591309e-01],
                        [  1.30706787e-01,   1.30706787e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  9.21936035e-02,   9.21936035e-02],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  1.15264893e-01,   1.15264893e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.45355225e-01,   1.45355225e-01],
                        [  1.55731201e-01,   1.55731201e-01],
                        [  1.53656006e-01,   1.53656006e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  7.13500977e-02,   7.13500977e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.12365723e-01,  -1.12365723e-01],
                        [ -2.07885742e-01,  -2.07885742e-01],
                        [ -2.80487061e-01,  -2.80487061e-01],
                        [ -3.06213379e-01,  -3.06213379e-01],
                        [ -2.73468018e-01,  -2.73468018e-01],
                        [ -2.05810547e-01,  -2.05810547e-01],
                        [ -1.47949219e-01,  -1.47949219e-01],
                        [ -1.21337891e-01,  -1.21337891e-01],
                        [ -1.10412598e-01,  -1.10412598e-01],
                        [ -9.56115723e-02,  -9.56115723e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -7.52258301e-02,  -7.52258301e-02],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  1.36474609e-01,   1.36474609e-01],
                        [  1.86889648e-01,   1.86889648e-01],
                        [  2.12524414e-01,   2.12524414e-01],
                        [  2.10357666e-01,   2.10357666e-01],
                        [  1.85729980e-01,   1.85729980e-01],
                        [  1.54907227e-01,   1.54907227e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  7.30285645e-02,   7.30285645e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  8.70666504e-02,   8.70666504e-02],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -9.57336426e-02,  -9.57336426e-02],
                        [ -1.69036865e-01,  -1.69036865e-01],
                        [ -2.01538086e-01,  -2.01538086e-01],
                        [ -1.83044434e-01,  -1.83044434e-01],
                        [ -1.35253906e-01,  -1.35253906e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -7.87048340e-02,  -7.87048340e-02],
                        [ -8.14514160e-02,  -8.14514160e-02],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -7.39135742e-02,  -7.39135742e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -7.80944824e-02,  -7.80944824e-02],
                        [ -9.01184082e-02,  -9.01184082e-02],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -8.08715820e-02,  -8.08715820e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -7.11669922e-02,  -7.11669922e-02],
                        [ -7.76977539e-02,  -7.76977539e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  8.00170898e-02,   8.00170898e-02],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  1.04461670e-01,   1.04461670e-01],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.24084473e-01,   1.24084473e-01],
                        [  1.43066406e-01,   1.43066406e-01],
                        [  1.61804199e-01,   1.61804199e-01],
                        [  1.75750732e-01,   1.75750732e-01],
                        [  1.79687500e-01,   1.79687500e-01],
                        [  1.64581299e-01,   1.64581299e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  5.61218262e-02,   5.61218262e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -1.41357422e-01,  -1.41357422e-01],
                        [ -2.41485596e-01,  -2.41485596e-01],
                        [ -3.02917480e-01,  -3.02917480e-01],
                        [ -3.07128906e-01,  -3.07128906e-01],
                        [ -2.65472412e-01,  -2.65472412e-01],
                        [ -2.08831787e-01,  -2.08831787e-01],
                        [ -1.64001465e-01,  -1.64001465e-01],
                        [ -1.37390137e-01,  -1.37390137e-01],
                        [ -1.17431641e-01,  -1.17431641e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  6.90917969e-02,   6.90917969e-02],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.69403076e-01,   1.69403076e-01],
                        [  1.98944092e-01,   1.98944092e-01],
                        [  2.10388184e-01,   2.10388184e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  1.78009033e-01,   1.78009033e-01],
                        [  1.53381348e-01,   1.53381348e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.23199463e-01,   1.23199463e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  4.08935547e-03,   4.08935547e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  9.29260254e-02,   9.29260254e-02],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -1.74102783e-01,  -1.74102783e-01],
                        [ -1.92962646e-01,  -1.92962646e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.22741699e-01,  -1.22741699e-01],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -6.79931641e-02,  -6.79931641e-02],
                        [ -7.94067383e-02,  -7.94067383e-02],
                        [ -8.63952637e-02,  -8.63952637e-02],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -9.56420898e-02,  -9.56420898e-02],
                        [ -9.88464355e-02,  -9.88464355e-02],
                        [ -9.40551758e-02,  -9.40551758e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.32843018e-01,   1.32843018e-01],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.24450684e-01,   1.24450684e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.68395996e-01,   1.68395996e-01],
                        [  1.94061279e-01,   1.94061279e-01],
                        [  1.98150635e-01,   1.98150635e-01],
                        [  1.66931152e-01,   1.66931152e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -1.15295410e-01,  -1.15295410e-01],
                        [ -2.28149414e-01,  -2.28149414e-01],
                        [ -3.07159424e-01,  -3.07159424e-01],
                        [ -3.27728271e-01,  -3.27728271e-01],
                        [ -2.84118652e-01,  -2.84118652e-01],
                        [ -2.02178955e-01,  -2.02178955e-01],
                        [ -1.30706787e-01,  -1.30706787e-01],
                        [ -1.01531982e-01,  -1.01531982e-01],
                        [ -1.02996826e-01,  -1.02996826e-01],
                        [ -1.04003906e-01,  -1.04003906e-01],
                        [ -9.24377441e-02,  -9.24377441e-02],
                        [ -7.83386230e-02,  -7.83386230e-02],
                        [ -7.11669922e-02,  -7.11669922e-02],
                        [ -6.82067871e-02,  -6.82067871e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  8.58459473e-02,   8.58459473e-02],
                        [  1.37847900e-01,   1.37847900e-01],
                        [  1.79595947e-01,   1.79595947e-01],
                        [  2.03399658e-01,   2.03399658e-01],
                        [  1.99523926e-01,   1.99523926e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.36810303e-01,   1.36810303e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.18713379e-01,   1.18713379e-01],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.06274414e-02,   8.06274414e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -1.27868652e-01,  -1.27868652e-01],
                        [ -1.79748535e-01,  -1.79748535e-01],
                        [ -1.94671631e-01,  -1.94671631e-01],
                        [ -1.75415039e-01,  -1.75415039e-01],
                        [ -1.43524170e-01,  -1.43524170e-01],
                        [ -1.15539551e-01,  -1.15539551e-01],
                        [ -9.63745117e-02,  -9.63745117e-02],
                        [ -8.82263184e-02,  -8.82263184e-02],
                        [ -8.99658203e-02,  -8.99658203e-02],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -9.30175781e-02,  -9.30175781e-02],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -8.21228027e-02,  -8.21228027e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -8.04748535e-02,  -8.04748535e-02],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.38153076e-01,   1.38153076e-01],
                        [  1.36566162e-01,   1.36566162e-01],
                        [  1.28387451e-01,   1.28387451e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  8.30688477e-02,   8.30688477e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  1.32781982e-01,   1.32781982e-01],
                        [  1.57501221e-01,   1.57501221e-01],
                        [  1.73767090e-01,   1.73767090e-01],
                        [  1.71234131e-01,   1.71234131e-01],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  6.89392090e-02,   6.89392090e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -1.42059326e-01,  -1.42059326e-01],
                        [ -2.41363525e-01,  -2.41363525e-01],
                        [ -2.98004150e-01,  -2.98004150e-01],
                        [ -2.91595459e-01,  -2.91595459e-01],
                        [ -2.32635498e-01,  -2.32635498e-01],
                        [ -1.62445068e-01,  -1.62445068e-01],
                        [ -1.21429443e-01,  -1.21429443e-01],
                        [ -1.16394043e-01,  -1.16394043e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -1.22314453e-01,  -1.22314453e-01],
                        [ -1.09771729e-01,  -1.09771729e-01],
                        [ -9.22851562e-02,  -9.22851562e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.70166016e-01,   1.70166016e-01],
                        [  2.03979492e-01,   2.03979492e-01],
                        [  2.03491211e-01,   2.03491211e-01],
                        [  1.82586670e-01,   1.82586670e-01],
                        [  1.61224365e-01,   1.61224365e-01],
                        [  1.45874023e-01,   1.45874023e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  8.95996094e-02,   8.95996094e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  9.52758789e-02,   9.52758789e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -1.34002686e-01,  -1.34002686e-01],
                        [ -1.85333252e-01,  -1.85333252e-01],
                        [ -1.99432373e-01,  -1.99432373e-01],
                        [ -1.79626465e-01,  -1.79626465e-01],
                        [ -1.44317627e-01,  -1.44317627e-01],
                        [ -1.14501953e-01,  -1.14501953e-01],
                        [ -9.98535156e-02,  -9.98535156e-02],
                        [ -9.57336426e-02,  -9.57336426e-02],
                        [ -9.22241211e-02,  -9.22241211e-02],
                        [ -8.57238770e-02,  -8.57238770e-02],
                        [ -8.20007324e-02,  -8.20007324e-02],
                        [ -8.53881836e-02,  -8.53881836e-02],
                        [ -8.85925293e-02,  -8.85925293e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -6.90307617e-02,  -6.90307617e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  1.00067139e-01,   1.00067139e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.65802002e-01,   1.65802002e-01],
                        [  1.88171387e-01,   1.88171387e-01],
                        [  2.03735352e-01,   2.03735352e-01],
                        [  2.08435059e-01,   2.08435059e-01],
                        [  1.92413330e-01,   1.92413330e-01],
                        [  1.42974854e-01,   1.42974854e-01],
                        [  5.51452637e-02,   5.51452637e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -1.79229736e-01,  -1.79229736e-01],
                        [ -2.78472900e-01,  -2.78472900e-01],
                        [ -3.37982178e-01,  -3.37982178e-01],
                        [ -3.41918945e-01,  -3.41918945e-01],
                        [ -2.88208008e-01,  -2.88208008e-01],
                        [ -2.01202393e-01,  -2.01202393e-01],
                        [ -1.22711182e-01,  -1.22711182e-01],
                        [ -8.21533203e-02,  -8.21533203e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -7.30590820e-02,  -7.30590820e-02],
                        [ -7.03125000e-02,  -7.03125000e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -7.52868652e-02,  -7.52868652e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  1.26190186e-01,   1.26190186e-01],
                        [  1.69647217e-01,   1.69647217e-01],
                        [  1.91436768e-01,   1.91436768e-01],
                        [  1.88171387e-01,   1.88171387e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.13677979e-01,   1.13677979e-01],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  3.57055664e-03,   3.57055664e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  3.28369141e-02,   3.28369141e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  5.80139160e-02,   5.80139160e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -1.75201416e-01,  -1.75201416e-01],
                        [ -1.97418213e-01,  -1.97418213e-01],
                        [ -1.79626465e-01,  -1.79626465e-01],
                        [ -1.42578125e-01,  -1.42578125e-01],
                        [ -1.12335205e-01,  -1.12335205e-01],
                        [ -1.01745605e-01,  -1.01745605e-01],
                        [ -1.04583740e-01,  -1.04583740e-01],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -1.00708008e-01,  -1.00708008e-01],
                        [ -9.34448242e-02,  -9.34448242e-02],
                        [ -9.29260254e-02,  -9.29260254e-02],
                        [ -9.62524414e-02,  -9.62524414e-02],
                        [ -9.15832520e-02,  -9.15832520e-02],
                        [ -7.47070312e-02,  -7.47070312e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  1.11785889e-01,   1.11785889e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.32904053e-01,   1.32904053e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.70440674e-01,   1.70440674e-01],
                        [  1.89056396e-01,   1.89056396e-01],
                        [  1.95434570e-01,   1.95434570e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  1.60369873e-01,   1.60369873e-01],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  1.07116699e-02,   1.07116699e-02],
                        [ -1.03332520e-01,  -1.03332520e-01],
                        [ -2.16705322e-01,  -2.16705322e-01],
                        [ -3.00140381e-01,  -3.00140381e-01],
                        [ -3.27758789e-01,  -3.27758789e-01],
                        [ -2.95562744e-01,  -2.95562744e-01],
                        [ -2.28240967e-01,  -2.28240967e-01],
                        [ -1.62261963e-01,  -1.62261963e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -1.06506348e-01,  -1.06506348e-01],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -8.93554688e-02,  -8.93554688e-02],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  1.56524658e-01,   1.56524658e-01],
                        [  1.89605713e-01,   1.89605713e-01],
                        [  1.90734863e-01,   1.90734863e-01],
                        [  1.70715332e-01,   1.70715332e-01],
                        [  1.48620605e-01,   1.48620605e-01],
                        [  1.35681152e-01,   1.35681152e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.32049561e-01,   1.32049561e-01],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.22955322e-01,   1.22955322e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  7.95593262e-02,   7.95593262e-02],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.12487793e-01,   1.12487793e-01],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -1.59729004e-01,  -1.59729004e-01],
                        [ -1.96441650e-01,  -1.96441650e-01],
                        [ -1.92504883e-01,  -1.92504883e-01],
                        [ -1.63452148e-01,  -1.63452148e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -1.13342285e-01,  -1.13342285e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.32873535e-01,   1.32873535e-01],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.85424805e-01,   1.85424805e-01],
                        [  2.15179443e-01,   2.15179443e-01],
                        [  2.22961426e-01,   2.22961426e-01],
                        [  1.94732666e-01,   1.94732666e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  2.55737305e-02,   2.55737305e-02],
                        [ -9.14001465e-02,  -9.14001465e-02],
                        [ -2.00592041e-01,  -2.00592041e-01],
                        [ -2.83172607e-01,  -2.83172607e-01],
                        [ -3.21411133e-01,  -3.21411133e-01],
                        [ -3.02337646e-01,  -3.02337646e-01],
                        [ -2.39257812e-01,  -2.39257812e-01],
                        [ -1.72760010e-01,  -1.72760010e-01],
                        [ -1.34643555e-01,  -1.34643555e-01],
                        [ -1.22528076e-01,  -1.22528076e-01],
                        [ -1.15386963e-01,  -1.15386963e-01],
                        [ -1.01226807e-01,  -1.01226807e-01],
                        [ -8.44726562e-02,  -8.44726562e-02],
                        [ -7.61413574e-02,  -7.61413574e-02],
                        [ -7.99865723e-02,  -7.99865723e-02],
                        [ -8.71582031e-02,  -8.71582031e-02],
                        [ -8.51440430e-02,  -8.51440430e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  7.51342773e-02,   7.51342773e-02],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.85546875e-01,   1.85546875e-01],
                        [  2.06634521e-01,   2.06634521e-01],
                        [  1.96929932e-01,   1.96929932e-01],
                        [  1.71142578e-01,   1.71142578e-01],
                        [  1.48132324e-01,   1.48132324e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.29760742e-01,   1.29760742e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  7.76367188e-02,   7.76367188e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  1.08123779e-01,   1.08123779e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -9.72290039e-02,  -9.72290039e-02],
                        [ -1.63085938e-01,  -1.63085938e-01],
                        [ -1.98425293e-01,  -1.98425293e-01],
                        [ -1.96136475e-01,  -1.96136475e-01],
                        [ -1.69403076e-01,  -1.69403076e-01],
                        [ -1.41571045e-01,  -1.41571045e-01],
                        [ -1.25701904e-01,  -1.25701904e-01],
                        [ -1.18011475e-01,  -1.18011475e-01],
                        [ -1.11083984e-01,  -1.11083984e-01],
                        [ -1.06018066e-01,  -1.06018066e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.18560791e-01,  -1.18560791e-01],
                        [ -1.25518799e-01,  -1.25518799e-01],
                        [ -1.17889404e-01,  -1.17889404e-01],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  1.20300293e-01,   1.20300293e-01],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.36108398e-01,   1.36108398e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  1.75933838e-01,   1.75933838e-01],
                        [  1.99615479e-01,   1.99615479e-01],
                        [  2.17742920e-01,   2.17742920e-01],
                        [  2.17376709e-01,   2.17376709e-01],
                        [  1.82708740e-01,   1.82708740e-01],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.28479004e-02,   1.28479004e-02],
                        [ -9.85717773e-02,  -9.85717773e-02],
                        [ -2.09197998e-01,  -2.09197998e-01],
                        [ -2.94952393e-01,  -2.94952393e-01],
                        [ -3.28125000e-01,  -3.28125000e-01],
                        [ -2.99224854e-01,  -2.99224854e-01],
                        [ -2.30529785e-01,  -2.30529785e-01],
                        [ -1.63360596e-01,  -1.63360596e-01],
                        [ -1.26342773e-01,  -1.26342773e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -1.16455078e-01,  -1.16455078e-01],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -1.03820801e-01,  -1.03820801e-01],
                        [ -9.19189453e-02,  -9.19189453e-02],
                        [ -7.69042969e-02,  -7.69042969e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  1.16882324e-01,   1.16882324e-01],
                        [  1.81701660e-01,   1.81701660e-01],
                        [  2.25860596e-01,   2.25860596e-01],
                        [  2.34344482e-01,   2.34344482e-01],
                        [  2.10296631e-01,   2.10296631e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.11511230e-01,   1.11511230e-01],
                        [  1.17889404e-01,   1.17889404e-01],
                        [  1.05926514e-01,   1.05926514e-01],
                        [  6.67419434e-02,   6.67419434e-02],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [ -8.21838379e-02,  -8.21838379e-02],
                        [ -1.56768799e-01,  -1.56768799e-01],
                        [ -2.02301025e-01,  -2.02301025e-01],
                        [ -2.06542969e-01,  -2.06542969e-01],
                        [ -1.79473877e-01,  -1.79473877e-01],
                        [ -1.48345947e-01,  -1.48345947e-01],
                        [ -1.32476807e-01,  -1.32507324e-01],
                        [ -1.28143311e-01,  -1.28143311e-01],
                        [ -1.21734619e-01,  -1.21734619e-01],
                        [ -1.09222412e-01,  -1.09222412e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -9.41467285e-02,  -9.41467285e-02],
                        [ -9.68322754e-02,  -9.68627930e-02],
                        [ -9.64660645e-02,  -9.64660645e-02],
                        [ -8.68530273e-02,  -8.68530273e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -5.95092773e-02,  -5.95397949e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.03912354e-01,   1.03912354e-01],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  1.27319336e-01,   1.27319336e-01],
                        [  1.47369385e-01,   1.47369385e-01],
                        [  1.63635254e-01,   1.63635254e-01],
                        [  1.81488037e-01,   1.81488037e-01],
                        [  2.06909180e-01,   2.06909180e-01],
                        [  2.28851318e-01,   2.28851318e-01],
                        [  2.24700928e-01,   2.24700928e-01],
                        [  1.83624268e-01,   1.83624268e-01],
                        [  1.11938477e-01,   1.11938477e-01],
                        [  1.77001953e-02,   1.77001953e-02],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -2.07763672e-01,  -2.07763672e-01],
                        [ -2.95104980e-01,  -2.95104980e-01],
                        [ -3.25103760e-01,  -3.25103760e-01],
                        [ -2.88146973e-01,  -2.88146973e-01],
                        [ -2.13256836e-01,  -2.13256836e-01],
                        [ -1.51794434e-01,  -1.51794434e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -1.25030518e-01,  -1.25030518e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -1.10229492e-01,  -1.10229492e-01],
                        [ -1.11389160e-01,  -1.11389160e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -9.49096680e-02,  -9.49096680e-02],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.97845459e-01,   1.97845459e-01],
                        [  2.35900879e-01,   2.35900879e-01],
                        [  2.33154297e-01,   2.33154297e-01],
                        [  1.95800781e-01,   1.95800781e-01],
                        [  1.54907227e-01,   1.54907227e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  8.64562988e-02,   8.64868164e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -1.25000000e-01,  -1.25000000e-01],
                        [ -1.86004639e-01,  -1.86004639e-01],
                        [ -2.10296631e-01,  -2.10296631e-01],
                        [ -1.93939209e-01,  -1.93969727e-01],
                        [ -1.56890869e-01,  -1.56890869e-01],
                        [ -1.25823975e-01,  -1.25823975e-01],
                        [ -1.11907959e-01,  -1.11907959e-01],
                        [ -1.09069824e-01,  -1.09069824e-01],
                        [ -1.08978271e-01,  -1.08978271e-01],
                        [ -1.10198975e-01,  -1.10198975e-01],
                        [ -1.13769531e-01,  -1.13769531e-01],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -9.40246582e-02,  -9.40246582e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  7.61718750e-02,   7.61718750e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.25885010e-01,   1.25885010e-01],
                        [  1.22222900e-01,   1.22222900e-01],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.44348145e-01,   1.44348145e-01],
                        [  1.69158936e-01,   1.69189453e-01],
                        [  1.87530518e-01,   1.87530518e-01],
                        [  2.08160400e-01,   2.08160400e-01],
                        [  2.22106934e-01,   2.22106934e-01],
                        [  2.09381104e-01,   2.09411621e-01],
                        [  1.65863037e-01,   1.65863037e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [ -1.02020264e-01,  -1.02020264e-01],
                        [ -2.18261719e-01,  -2.18261719e-01],
                        [ -3.00445557e-01,  -3.00445557e-01],
                        [ -3.19885254e-01,  -3.19885254e-01],
                        [ -2.78961182e-01,  -2.78961182e-01],
                        [ -2.10845947e-01,  -2.10845947e-01],
                        [ -1.57348633e-01,  -1.57318115e-01],
                        [ -1.37786865e-01,  -1.37786865e-01],
                        [ -1.37084961e-01,  -1.37084961e-01],
                        [ -1.29974365e-01,  -1.29974365e-01],
                        [ -1.12396240e-01,  -1.12396240e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -9.36889648e-02,  -9.36889648e-02],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  1.82006836e-01,   1.82006836e-01],
                        [  2.15057373e-01,   2.15057373e-01],
                        [  2.20764160e-01,   2.20764160e-01],
                        [  2.01354980e-01,   2.01354980e-01],
                        [  1.67297363e-01,   1.67297363e-01],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.21490479e-01,   1.21459961e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  8.67309570e-02,   8.67614746e-02],
                        [  6.97631836e-02,   6.97326660e-02],
                        [  5.06896973e-02,   5.06896973e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  9.12475586e-03,   9.15527344e-03],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  1.53808594e-02,   1.53503418e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  7.98645020e-02,   7.98339844e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [ -4.11071777e-02,  -4.10766602e-02],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -2.05352783e-01,  -2.05352783e-01],
                        [ -2.26715088e-01,  -2.26715088e-01],
                        [ -2.03247070e-01,  -2.03247070e-01],
                        [ -1.57714844e-01,  -1.57714844e-01],
                        [ -1.16821289e-01,  -1.16821289e-01],
                        [ -9.79309082e-02,  -9.79309082e-02],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -1.04309082e-01,  -1.04309082e-01],
                        [ -9.98535156e-02,  -9.98535156e-02],
                        [ -8.98437500e-02,  -8.98437500e-02],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -8.05969238e-02,  -8.05969238e-02],
                        [ -8.15124512e-02,  -8.15124512e-02],
                        [ -8.22753906e-02,  -8.22448730e-02],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  9.83886719e-02,   9.84191895e-02],
                        [  1.13525391e-01,   1.13525391e-01],
                        [  1.10260010e-01,   1.10229492e-01],
                        [  9.93347168e-02,   9.93652344e-02],
                        [  9.21936035e-02,   9.22241211e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  1.52526855e-01,   1.52526855e-01],
                        [  1.71813965e-01,   1.71813965e-01],
                        [  1.79901123e-01,   1.79870605e-01],
                        [  1.84600830e-01,   1.84600830e-01],
                        [  1.90063477e-01,   1.90093994e-01],
                        [  1.91040039e-01,   1.91040039e-01],
                        [  1.73858643e-01,   1.73858643e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  3.43627930e-02,   3.43627930e-02],
                        [ -7.57751465e-02,  -7.58056641e-02],
                        [ -1.81732178e-01,  -1.81732178e-01],
                        [ -2.62176514e-01,  -2.62176514e-01],
                        [ -3.01025391e-01,  -3.01025391e-01],
                        [ -2.86468506e-01,  -2.86468506e-01],
                        [ -2.26287842e-01,  -2.26287842e-01],
                        [ -1.56677246e-01,  -1.56677246e-01],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.11267090e-01,  -1.11297607e-01],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -9.36889648e-02,  -9.36889648e-02],
                        [ -9.53063965e-02,  -9.53063965e-02],
                        [ -9.80224609e-02,  -9.80224609e-02],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -7.82775879e-02,  -7.82775879e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -2.92968750e-03,  -2.89916992e-03],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  1.34979248e-01,   1.34979248e-01],
                        [  2.01141357e-01,   2.01110840e-01],
                        [  2.34222412e-01,   2.34222412e-01],
                        [  2.24853516e-01,   2.24853516e-01],
                        [  1.85241699e-01,   1.85241699e-01],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.04309082e-01,   1.04309082e-01],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  7.48291016e-02,   7.47985840e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.15661621e-02,   1.15356445e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -2.32238770e-02,  -2.32543945e-02],
                        [ -2.86560059e-02,  -2.86865234e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.98059082e-02,   1.98364258e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  9.61303711e-02,   9.61303711e-02],
                        [  9.80834961e-02,   9.80529785e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -1.93969727e-01,  -1.93969727e-01],
                        [ -1.64367676e-01,  -1.64398193e-01],
                        [ -1.24633789e-01,  -1.24633789e-01],
                        [ -1.00189209e-01,  -1.00189209e-01],
                        [ -9.90295410e-02,  -9.90295410e-02],
                        [ -1.11267090e-01,  -1.11267090e-01],
                        [ -1.20849609e-01,  -1.20849609e-01],
                        [ -1.18530273e-01,  -1.18530273e-01],
                        [ -1.09191895e-01,  -1.09191895e-01],
                        [ -1.03698730e-01,  -1.03698730e-01],
                        [ -1.01348877e-01,  -1.01348877e-01],
                        [ -9.22546387e-02,  -9.22546387e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -6.90917969e-02,  -6.90917969e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  8.37097168e-02,   8.37097168e-02],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.22406006e-01,   1.22375488e-01],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  1.03118896e-01,   1.03118896e-01],
                        [  1.11785889e-01,   1.11755371e-01],
                        [  1.25427246e-01,   1.25457764e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.51641846e-01,   1.51641846e-01],
                        [  1.72851562e-01,   1.72851562e-01],
                        [  1.94854736e-01,   1.94854736e-01],
                        [  2.04956055e-01,   2.04956055e-01],
                        [  1.93603516e-01,   1.93603516e-01],
                        [  1.53900146e-01,   1.53930664e-01],
                        [  7.89184570e-02,   7.89184570e-02],
                        [ -2.95410156e-02,  -2.95715332e-02],
                        [ -1.52221680e-01,  -1.52191162e-01],
                        [ -2.57690430e-01,  -2.57690430e-01],
                        [ -3.15124512e-01,  -3.15124512e-01],
                        [ -3.06793213e-01,  -3.06762695e-01],
                        [ -2.43896484e-01,  -2.43865967e-01],
                        [ -1.68701172e-01,  -1.68701172e-01],
                        [ -1.24664307e-01,  -1.24664307e-01],
                        [ -1.19720459e-01,  -1.19689941e-01],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -1.27624512e-01,  -1.27624512e-01],
                        [ -1.21185303e-01,  -1.21154785e-01],
                        [ -1.18103027e-01,  -1.18103027e-01],
                        [ -1.15936279e-01,  -1.15966797e-01],
                        [ -1.08581543e-01,  -1.08581543e-01],
                        [ -9.48486328e-02,  -9.48181152e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.83044434e-01,   1.83044434e-01],
                        [  2.16064453e-01,   2.16064453e-01],
                        [  2.19024658e-01,   2.18994141e-01],
                        [  1.92077637e-01,   1.92077637e-01],
                        [  1.53839111e-01,   1.53869629e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.09832764e-01,   1.09863281e-01],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  9.53674316e-02,   9.53369141e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  5.34667969e-02,   5.34973145e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.32849121e-02,  -2.32543945e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [  4.63867188e-03,   4.60815430e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  3.41796875e-03,   3.38745117e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  1.85852051e-02,   1.85546875e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  3.86352539e-02,   3.86657715e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  7.06176758e-02,   7.05871582e-02],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  1.03454590e-01,   1.03424072e-01],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [ -7.86743164e-02,  -7.87048340e-02],
                        [ -1.62292480e-01,  -1.62292480e-01],
                        [ -2.13439941e-01,  -2.13439941e-01],
                        [ -2.18902588e-01,  -2.18902588e-01],
                        [ -1.88903809e-01,  -1.88903809e-01],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.25579834e-01,  -1.25579834e-01],
                        [ -1.15936279e-01,  -1.15936279e-01],
                        [ -1.11938477e-01,  -1.11907959e-01],
                        [ -1.06842041e-01,  -1.06842041e-01],
                        [ -1.01348877e-01,  -1.01348877e-01],
                        [ -1.00036621e-01,  -1.00036621e-01],
                        [ -1.04461670e-01,  -1.04461670e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.04095459e-01,  -1.04125977e-01],
                        [ -9.49401855e-02,  -9.49401855e-02],
                        [ -8.49914551e-02,  -8.49609375e-02],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  1.32537842e-01,   1.32537842e-01],
                        [  1.47552490e-01,   1.47552490e-01],
                        [  1.33880615e-01,   1.33850098e-01],
                        [  1.05712891e-01,   1.05712891e-01],
                        [  8.41369629e-02,   8.41369629e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.35253906e-01,   1.35284424e-01],
                        [  1.63574219e-01,   1.63543701e-01],
                        [  2.02484131e-01,   2.02484131e-01],
                        [  2.37731934e-01,   2.37762451e-01],
                        [  2.42218018e-01,   2.42187500e-01],
                        [  1.99951172e-01,   1.99920654e-01],
                        [  1.14135742e-01,   1.14166260e-01],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -1.31683350e-01,  -1.31713867e-01],
                        [ -2.51281738e-01,  -2.51281738e-01],
                        [ -3.30505371e-01,  -3.30505371e-01],
                        [ -3.44268799e-01,  -3.44268799e-01],
                        [ -2.93243408e-01,  -2.93243408e-01],
                        [ -2.11700439e-01,  -2.11669922e-01],
                        [ -1.44470215e-01,  -1.44470215e-01],
                        [ -1.12213135e-01,  -1.12213135e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -1.00738525e-01,  -1.00738525e-01],
                        [ -9.73205566e-02,  -9.73510742e-02],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -1.03240967e-01,  -1.03210449e-01],
                        [ -1.10168457e-01,  -1.10168457e-01],
                        [ -1.10900879e-01,  -1.10900879e-01],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.55419922e-03,  -5.58471680e-03],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  1.46087646e-01,   1.46118164e-01],
                        [  2.05963135e-01,   2.05932617e-01],
                        [  2.37579346e-01,   2.37579346e-01],
                        [  2.33917236e-01,   2.33917236e-01],
                        [  2.01385498e-01,   2.01385498e-01],
                        [  1.60217285e-01,   1.60217285e-01],
                        [  1.27716064e-01,   1.27746582e-01],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  9.39636230e-02,   9.39331055e-02],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  8.64257812e-02,   8.64257812e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  9.03015137e-02,   9.03015137e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  6.21337891e-02,   6.21032715e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.76586914e-02,   3.76892090e-02],
                        [  2.85034180e-02,   2.84729004e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  1.10778809e-02,   1.11083984e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  5.76782227e-03,   5.73730469e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.30004883e-02,  -1.30310059e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.44042969e-02,  -1.44348145e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -3.95812988e-02,  -3.95507812e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.34582520e-02,  -1.34887695e-02],
                        [ -8.94165039e-03,  -8.97216797e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  9.92431641e-02,   9.92431641e-02],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [ -5.64880371e-02,  -5.65185547e-02],
                        [ -1.23962402e-01,  -1.23962402e-01],
                        [ -1.76025391e-01,  -1.76025391e-01],
                        [ -2.01049805e-01,  -2.01049805e-01],
                        [ -1.94610596e-01,  -1.94610596e-01],
                        [ -1.65344238e-01,  -1.65313721e-01],
                        [ -1.32263184e-01,  -1.32232666e-01],
                        [ -1.08337402e-01,  -1.08337402e-01],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -8.27026367e-02,  -8.26721191e-02],
                        [ -8.07495117e-02,  -8.07495117e-02],
                        [ -8.83789062e-02,  -8.84094238e-02],
                        [ -1.00738525e-01,  -1.00708008e-01],
                        [ -1.10076904e-01,  -1.10076904e-01],
                        [ -1.11968994e-01,  -1.11999512e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.02264404e-01,  -1.02233887e-01],
                        [ -9.16748047e-02,  -9.17053223e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -2.08435059e-02,  -2.08129883e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  1.05377197e-01,   1.05346680e-01],
                        [  1.43920898e-01,   1.43951416e-01],
                        [  1.48956299e-01,   1.48986816e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.31091309e-02,   9.31396484e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  1.18957520e-01,   1.18988037e-01],
                        [  1.48193359e-01,   1.48193359e-01],
                        [  1.80084229e-01,   1.80084229e-01],
                        [  2.10449219e-01,   2.10449219e-01],
                        [  2.28149414e-01,   2.28179932e-01],
                        [  2.16735840e-01,   2.16705322e-01],
                        [  1.64459229e-01,   1.64459229e-01],
                        [  7.31201172e-02,   7.31201172e-02],
                        [ -4.28466797e-02,  -4.28161621e-02],
                        [ -1.63543701e-01,  -1.63574219e-01],
                        [ -2.65960693e-01,  -2.65960693e-01],
                        [ -3.21350098e-01,  -3.21350098e-01],
                        [ -3.07586670e-01,  -3.07617188e-01],
                        [ -2.37091064e-01,  -2.37121582e-01],
                        [ -1.60461426e-01,  -1.60461426e-01],
                        [ -1.22741699e-01,  -1.22741699e-01],
                        [ -1.23138428e-01,  -1.23168945e-01],
                        [ -1.31378174e-01,  -1.31378174e-01],
                        [ -1.29577637e-01,  -1.29547119e-01],
                        [ -1.22833252e-01,  -1.22863770e-01],
                        [ -1.21124268e-01,  -1.21124268e-01],
                        [ -1.24786377e-01,  -1.24755859e-01],
                        [ -1.24359131e-01,  -1.24359131e-01],
                        [ -1.07177734e-01,  -1.07177734e-01],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [  9.46044922e-04,   9.76562500e-04],
                        [  7.88574219e-02,   7.88269043e-02],
                        [  1.50512695e-01,   1.50512695e-01],
                        [  1.99127197e-01,   1.99157715e-01],
                        [  2.18322754e-01,   2.18292236e-01],
                        [  2.11303711e-01,   2.11303711e-01],
                        [  1.85638428e-01,   1.85668945e-01],
                        [  1.54235840e-01,   1.54235840e-01],
                        [  1.32141113e-01,   1.32110596e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.13464355e-01,   1.13464355e-01],
                        [  1.02630615e-01,   1.02600098e-01],
                        [  9.61303711e-02,   9.60998535e-02],
                        [  9.63439941e-02,   9.64050293e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  9.30480957e-02,   9.30175781e-02],
                        [  8.37707520e-02,   8.38012695e-02],
                        [  7.05566406e-02,   7.05871582e-02],
                        [  5.54504395e-02,   5.54199219e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  2.57873535e-02,   2.58178711e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  8.08715820e-03,   8.05664062e-03],
                        [  7.90405273e-03,   7.93457031e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  5.79833984e-03,   5.76782227e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  8.02612305e-03,   8.05664062e-03],
                        [  5.37109375e-03,   5.34057617e-03],
                        [ -9.76562500e-04,  -1.00708008e-03],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -4.89807129e-02,  -4.90112305e-02],
                        [ -5.40466309e-02,  -5.40161133e-02],
                        [ -4.38537598e-02,  -4.38232422e-02],
                        [ -3.06701660e-02,  -3.07006836e-02],
                        [ -2.45666504e-02,  -2.45971680e-02],
                        [ -2.05993652e-02,  -2.05688477e-02],
                        [ -7.75146484e-03,  -7.78198242e-03],
                        [  1.14746094e-02,   1.14440918e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [  1.51367188e-02,   1.51672363e-02],
                        [  4.54711914e-03,   4.51660156e-03],
                        [ -1.22070312e-03,  -1.19018555e-03],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [ -1.52587891e-04,  -1.83105469e-04],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  2.27355957e-02,   2.27661133e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  5.54199219e-02,   5.53894043e-02],
                        [  8.54492188e-02,   8.54797363e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.03851318e-01,   1.03820801e-01],
                        [  7.82470703e-02,   7.82470703e-02],
                        [  3.70483398e-02,   3.70788574e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -1.61010742e-01,  -1.60980225e-01],
                        [ -2.03186035e-01,  -2.03186035e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.80908203e-01,  -1.80908203e-01],
                        [ -1.50482178e-01,  -1.50482178e-01],
                        [ -1.27960205e-01,  -1.27990723e-01],
                        [ -1.15142822e-01,  -1.15142822e-01],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -8.99047852e-02,  -8.99047852e-02],
                        [ -8.57238770e-02,  -8.57238770e-02],
                        [ -9.18579102e-02,  -9.18273926e-02],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -9.80529785e-02,  -9.80834961e-02],
                        [ -8.56018066e-02,  -8.56018066e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -4.61425781e-02,  -4.61730957e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  1.16027832e-01,   1.15997314e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.72576904e-01,   1.72576904e-01],
                        [  2.05810547e-01,   2.05810547e-01],
                        [  2.25128174e-01,   2.25128174e-01],
                        [  2.24121094e-01,   2.24151611e-01],
                        [  1.94335938e-01,   1.94335938e-01],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.65405273e-02,   1.65405273e-02],
                        [ -1.18255615e-01,  -1.18255615e-01],
                        [ -2.44537354e-01,  -2.44537354e-01],
                        [ -3.22570801e-01,  -3.22570801e-01],
                        [ -3.29864502e-01,  -3.29864502e-01],
                        [ -2.77954102e-01,  -2.77954102e-01],
                        [ -2.06604004e-01,  -2.06604004e-01],
                        [ -1.55090332e-01,  -1.55090332e-01],
                        [ -1.35925293e-01,  -1.35925293e-01],
                        [ -1.36932373e-01,  -1.36932373e-01],
                        [ -1.41204834e-01,  -1.41204834e-01],
                        [ -1.40289307e-01,  -1.40289307e-01],
                        [ -1.34704590e-01,  -1.34704590e-01],
                        [ -1.28112793e-01,  -1.28112793e-01],
                        [ -1.20025635e-01,  -1.20025635e-01],
                        [ -1.02020264e-01,  -1.02020264e-01],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  1.60369873e-01,   1.60369873e-01],
                        [  2.12158203e-01,   2.12158203e-01],
                        [  2.30133057e-01,   2.30133057e-01],
                        [  2.16156006e-01,   2.16156006e-01],
                        [  1.80938721e-01,   1.80969238e-01],
                        [  1.41632080e-01,   1.41632080e-01],
                        [  1.15753174e-01,   1.15753174e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.22650146e-01,   1.22619629e-01],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  5.02929688e-02,   5.03234863e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.79333496e-02,   3.79028320e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  2.97241211e-02,   2.96936035e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  2.85034180e-02,   2.85339355e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.23291016e-02,  -1.22985840e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.34375000e-02,  -2.34680176e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -3.12805176e-02,  -3.12500000e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.30200195e-02,  -3.30505371e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -1.58691406e-02,  -1.58996582e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [  9.15527344e-05,   6.10351562e-05],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  7.44628906e-03,   7.47680664e-03],
                        [  8.33129883e-03,   8.30078125e-03],
                        [  9.64355469e-03,   9.61303711e-03],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  7.37915039e-02,   7.38220215e-02],
                        [  8.64257812e-02,   8.63952637e-02],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [ -3.76281738e-02,  -3.75976562e-02],
                        [ -1.10504150e-01,  -1.10534668e-01],
                        [ -1.79382324e-01,  -1.79382324e-01],
                        [ -2.16522217e-01,  -2.16491699e-01],
                        [ -2.12432861e-01,  -2.12463379e-01],
                        [ -1.81091309e-01,  -1.81121826e-01],
                        [ -1.43859863e-01,  -1.43859863e-01],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -1.02935791e-01,  -1.02966309e-01],
                        [ -1.00738525e-01,  -1.00738525e-01],
                        [ -1.01043701e-01,  -1.01013184e-01],
                        [ -9.85717773e-02,  -9.86022949e-02],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -9.74426270e-02,  -9.74121094e-02],
                        [ -9.96398926e-02,  -9.96704102e-02],
                        [ -9.44213867e-02,  -9.44519043e-02],
                        [ -8.08715820e-02,  -8.08410645e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -3.23791504e-02,  -3.24096680e-02],
                        [  1.12609863e-02,   1.12915039e-02],
                        [  6.25000000e-02,   6.25305176e-02],
                        [  1.04858398e-01,   1.04827881e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.13586426e-01,   1.13616943e-01],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  8.22143555e-02,   8.21838379e-02],
                        [  9.25292969e-02,   9.25598145e-02],
                        [  1.14715576e-01,   1.14746094e-01],
                        [  1.42395020e-01,   1.42364502e-01],
                        [  1.76666260e-01,   1.76666260e-01],
                        [  2.10571289e-01,   2.10601807e-01],
                        [  2.29034424e-01,   2.29003906e-01],
                        [  2.23449707e-01,   2.23419189e-01],
                        [  1.89575195e-01,   1.89605713e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  7.35473633e-03,   7.32421875e-03],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -2.47467041e-01,  -2.47467041e-01],
                        [ -3.24859619e-01,  -3.24859619e-01],
                        [ -3.35998535e-01,  -3.35998535e-01],
                        [ -2.84790039e-01,  -2.84759521e-01],
                        [ -2.08892822e-01,  -2.08892822e-01],
                        [ -1.55761719e-01,  -1.55761719e-01],
                        [ -1.40380859e-01,  -1.40380859e-01],
                        [ -1.40319824e-01,  -1.40289307e-01],
                        [ -1.34460449e-01,  -1.34490967e-01],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -1.29364014e-01,  -1.29333496e-01],
                        [ -1.29852295e-01,  -1.29852295e-01],
                        [ -1.14929199e-01,  -1.14959717e-01],
                        [ -8.57849121e-02,  -8.57543945e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [  1.22985840e-02,   1.22680664e-02],
                        [  9.30175781e-02,   9.30175781e-02],
                        [  1.76025391e-01,   1.76055908e-01],
                        [  2.30804443e-01,   2.30804443e-01],
                        [  2.41149902e-01,   2.41149902e-01],
                        [  2.14385986e-01,   2.14416504e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  1.35253906e-01,   1.35253906e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  9.66796875e-02,   9.66796875e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  8.56323242e-02,   8.56323242e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.01776123e-01,   1.01745605e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.24707031e-02,   3.25012207e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  1.39770508e-02,   1.40075684e-02],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.11389160e-02,  -1.11083984e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.40478516e-02,  -2.40783691e-02],
                        [ -2.24609375e-02,  -2.24304199e-02],
                        [ -2.02941895e-02,  -2.02636719e-02],
                        [ -2.39868164e-02,  -2.40173340e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.14025879e-02,  -3.13720703e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.98156738e-02,  -2.98461914e-02],
                        [ -2.99987793e-02,  -2.99682617e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.62145996e-02,  -2.62451172e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.80969238e-02,  -1.80664062e-02],
                        [ -6.71386719e-03,  -6.74438477e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.23791504e-02,   3.24096680e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.11682129e-02,   4.11682129e-02],
                        [  4.79125977e-02,   4.79431152e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  6.33850098e-02,   6.33544922e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  6.75659180e-02,   6.75964355e-02],
                        [  4.59899902e-02,   4.59594727e-02],
                        [  5.00488281e-03,   4.97436523e-03],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -1.30187988e-01,  -1.30187988e-01],
                        [ -1.92718506e-01,  -1.92749023e-01],
                        [ -2.17254639e-01,  -2.17224121e-01],
                        [ -2.02392578e-01,  -2.02362061e-01],
                        [ -1.71325684e-01,  -1.71325684e-01],
                        [ -1.47369385e-01,  -1.47369385e-01],
                        [ -1.36444092e-01,  -1.36413574e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -1.14440918e-01,  -1.14471436e-01],
                        [ -9.62219238e-02,  -9.62219238e-02],
                        [ -8.48693848e-02,  -8.48388672e-02],
                        [ -8.40148926e-02,  -8.40454102e-02],
                        [ -8.78906250e-02,  -8.78906250e-02],
                        [ -9.07287598e-02,  -9.06982422e-02],
                        [ -8.92333984e-02,  -8.92333984e-02],
                        [ -7.69348145e-02,  -7.69653320e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  4.91943359e-02,   4.91638184e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  1.27502441e-01,   1.27502441e-01],
                        [  1.22039795e-01,   1.22039795e-01],
                        [  1.24908447e-01,   1.24908447e-01],
                        [  1.37542725e-01,   1.37512207e-01],
                        [  1.53961182e-01,   1.53961182e-01],
                        [  1.69586182e-01,   1.69586182e-01],
                        [  1.86859131e-01,   1.86859131e-01],
                        [  2.07427979e-01,   2.07397461e-01],
                        [  2.17529297e-01,   2.17529297e-01],
                        [  1.90063477e-01,   1.90063477e-01],
                        [  1.08184814e-01,   1.08154297e-01],
                        [ -1.63574219e-02,  -1.63269043e-02],
                        [ -1.50817871e-01,  -1.50787354e-01],
                        [ -2.60375977e-01,  -2.60406494e-01],
                        [ -3.19610596e-01,  -3.19610596e-01],
                        [ -3.17138672e-01,  -3.17108154e-01],
                        [ -2.61657715e-01,  -2.61657715e-01],
                        [ -1.85516357e-01,  -1.85546875e-01],
                        [ -1.29791260e-01,  -1.29791260e-01],
                        [ -1.13708496e-01,  -1.13708496e-01],
                        [ -1.24877930e-01,  -1.24908447e-01],
                        [ -1.41906738e-01,  -1.41906738e-01],
                        [ -1.53289795e-01,  -1.53259277e-01],
                        [ -1.53656006e-01,  -1.53686523e-01],
                        [ -1.38885498e-01,  -1.38885498e-01],
                        [ -1.09191895e-01,  -1.09161377e-01],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.88873291e-01,   1.88842773e-01],
                        [  2.33886719e-01,   2.33917236e-01],
                        [  2.37701416e-01,   2.37701416e-01],
                        [  2.02850342e-01,   2.02819824e-01],
                        [  1.56158447e-01,   1.56158447e-01],
                        [  1.22009277e-01,   1.22009277e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  9.75952148e-02,   9.75952148e-02],
                        [  9.32312012e-02,   9.32312012e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  8.92028809e-02,   8.91723633e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  8.49914551e-02,   8.49609375e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  6.00585938e-02,   6.00891113e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.20336914e-02,   2.20031738e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.61230469e-02,   2.61535645e-02],
                        [  5.06591797e-03,   5.03540039e-03],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.35388184e-02,  -3.35693359e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.35290527e-02,   2.35595703e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  5.00488281e-02,   5.00793457e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  9.85717773e-02,   9.86022949e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [ -4.50134277e-02,  -4.49829102e-02],
                        [ -1.12854004e-01,  -1.12854004e-01],
                        [ -1.77886963e-01,  -1.77886963e-01],
                        [ -2.21343994e-01,  -2.21343994e-01],
                        [ -2.30224609e-01,  -2.30224609e-01],
                        [ -2.05993652e-01,  -2.05993652e-01],
                        [ -1.66839600e-01,  -1.66809082e-01],
                        [ -1.36169434e-01,  -1.36169434e-01],
                        [ -1.22253418e-01,  -1.22253418e-01],
                        [ -1.12976074e-01,  -1.12976074e-01],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -7.18994141e-02,  -7.19299316e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -7.90405273e-02,  -7.90405273e-02],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -8.52050781e-02,  -8.51745605e-02],
                        [ -6.39648438e-02,  -6.39648438e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  7.04040527e-02,   7.03735352e-02],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.41815186e-01,   1.41845703e-01],
                        [  1.54663086e-01,   1.54663086e-01],
                        [  1.56188965e-01,   1.56188965e-01],
                        [  1.51794434e-01,   1.51794434e-01],
                        [  1.46789551e-01,   1.46820068e-01],
                        [  1.50726318e-01,   1.50695801e-01],
                        [  1.71081543e-01,   1.71081543e-01],
                        [  2.00378418e-01,   2.00378418e-01],
                        [  2.18444824e-01,   2.18414307e-01],
                        [  2.08923340e-01,   2.08923340e-01],
                        [  1.65527344e-01,   1.65557861e-01],
                        [  8.75549316e-02,   8.75549316e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.45904541e-01,  -1.45904541e-01],
                        [ -2.60803223e-01,  -2.60803223e-01],
                        [ -3.29223633e-01,  -3.29223633e-01],
                        [ -3.27423096e-01,  -3.27392578e-01],
                        [ -2.67333984e-01,  -2.67333984e-01],
                        [ -1.92840576e-01,  -1.92871094e-01],
                        [ -1.45812988e-01,  -1.45812988e-01],
                        [ -1.35284424e-01,  -1.35284424e-01],
                        [ -1.40960693e-01,  -1.40960693e-01],
                        [ -1.42211914e-01,  -1.42242432e-01],
                        [ -1.36322021e-01,  -1.36322021e-01],
                        [ -1.29943848e-01,  -1.29943848e-01],
                        [ -1.20239258e-01,  -1.20269775e-01],
                        [ -9.16748047e-02,  -9.16748047e-02],
                        [ -3.43627930e-02,  -3.43322754e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.75384521e-01,   1.75384521e-01],
                        [  2.17956543e-01,   2.17956543e-01],
                        [  2.33215332e-01,   2.33184814e-01],
                        [  2.11151123e-01,   2.11151123e-01],
                        [  1.63055420e-01,   1.63055420e-01],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  9.60083008e-02,   9.59777832e-02],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.06701660e-02,   3.07006836e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.24304199e-02,   2.23999023e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  6.12792969e-02,   6.12487793e-02],
                        [  5.63964844e-02,   5.64270020e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -1.78344727e-01,  -1.78344727e-01],
                        [ -2.13378906e-01,  -2.13409424e-01],
                        [ -2.11486816e-01,  -2.11486816e-01],
                        [ -1.79534912e-01,  -1.79534912e-01],
                        [ -1.39801025e-01,  -1.39801025e-01],
                        [ -1.15966797e-01,  -1.15966797e-01],
                        [ -1.14593506e-01,  -1.14562988e-01],
                        [ -1.20697021e-01,  -1.20727539e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -8.81958008e-02,  -8.81958008e-02],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -4.50744629e-02,  -4.51049805e-02],
                        [ -2.62451172e-03,  -2.59399414e-03],
                        [  4.98962402e-02,   4.99267578e-02],
                        [  9.67407227e-02,   9.67102051e-02],
                        [  1.26373291e-01,   1.26373291e-01],
                        [  1.38946533e-01,   1.38977051e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.41357422e-01,   1.41326904e-01],
                        [  1.43615723e-01,   1.43646240e-01],
                        [  1.54541016e-01,   1.54541016e-01],
                        [  1.75659180e-01,   1.75659180e-01],
                        [  1.98577881e-01,   1.98577881e-01],
                        [  2.09289551e-01,   2.09289551e-01],
                        [  1.99035645e-01,   1.99035645e-01],
                        [  1.65710449e-01,   1.65679932e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.11694336e-02,   1.11694336e-02],
                        [ -1.07757568e-01,  -1.07757568e-01],
                        [ -2.23358154e-01,  -2.23358154e-01],
                        [ -2.97698975e-01,  -2.97698975e-01],
                        [ -3.05572510e-01,  -3.05603027e-01],
                        [ -2.55432129e-01,  -2.55401611e-01],
                        [ -1.87561035e-01,  -1.87561035e-01],
                        [ -1.43524170e-01,  -1.43524170e-01],
                        [ -1.34857178e-01,  -1.34857178e-01],
                        [ -1.44073486e-01,  -1.44042969e-01],
                        [ -1.50085449e-01,  -1.50085449e-01],
                        [ -1.45416260e-01,  -1.45446777e-01],
                        [ -1.31774902e-01,  -1.31774902e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  8.83789062e-02,   8.83789062e-02],
                        [  1.69097900e-01,   1.69097900e-01],
                        [  2.29370117e-01,   2.29370117e-01],
                        [  2.46002197e-01,   2.46002197e-01],
                        [  2.19055176e-01,   2.19055176e-01],
                        [  1.71264648e-01,   1.71264648e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  9.98535156e-02,   9.98535156e-02],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  5.93566895e-02,   5.93566895e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [ -7.50732422e-03,  -7.53784180e-03],
                        [ -1.94702148e-02,  -1.94396973e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -6.75354004e-02,  -6.75048828e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  1.85241699e-02,   1.84936523e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  7.14111328e-03,   7.11059570e-03],
                        [  9.33837891e-03,   9.36889648e-03],
                        [  1.21154785e-02,   1.21459961e-02],
                        [  1.58081055e-02,   1.57775879e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.93273926e-02,   2.93579102e-02],
                        [  3.24401855e-02,   3.24096680e-02],
                        [  3.07006836e-02,   3.06701660e-02],
                        [  2.38342285e-02,   2.38647461e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.48010254e-02,   1.47705078e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  4.93774414e-02,   4.94079590e-02],
                        [  5.85632324e-02,   5.85327148e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  2.50549316e-02,   2.50854492e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -8.47778320e-02,  -8.48083496e-02],
                        [ -1.53625488e-01,  -1.53625488e-01],
                        [ -2.03552246e-01,  -2.03521729e-01],
                        [ -2.14996338e-01,  -2.15026855e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.47369385e-01,  -1.47338867e-01],
                        [ -1.17736816e-01,  -1.17736816e-01],
                        [ -1.05255127e-01,  -1.05285645e-01],
                        [ -1.02508545e-01,  -1.02478027e-01],
                        [ -1.03698730e-01,  -1.03698730e-01],
                        [ -1.04522705e-01,  -1.04553223e-01],
                        [ -1.00006104e-01,  -1.00006104e-01],
                        [ -9.03930664e-02,  -9.03625488e-02],
                        [ -8.04138184e-02,  -8.04138184e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -4.71496582e-02,  -4.71191406e-02],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  1.29058838e-01,   1.29089355e-01],
                        [  1.49291992e-01,   1.49291992e-01],
                        [  1.49993896e-01,   1.49993896e-01],
                        [  1.44775391e-01,   1.44805908e-01],
                        [  1.53472900e-01,   1.53472900e-01],
                        [  1.81060791e-01,   1.81030273e-01],
                        [  2.11395264e-01,   2.11395264e-01],
                        [  2.26745605e-01,   2.26776123e-01],
                        [  2.21649170e-01,   2.21618652e-01],
                        [  1.90948486e-01,   1.90948486e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -2.41333008e-01,  -2.41333008e-01],
                        [ -3.18664551e-01,  -3.18634033e-01],
                        [ -3.31878662e-01,  -3.31878662e-01],
                        [ -2.80303955e-01,  -2.80303955e-01],
                        [ -1.96777344e-01,  -1.96777344e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -1.07940674e-01,  -1.07971191e-01],
                        [ -1.13952637e-01,  -1.13922119e-01],
                        [ -1.24938965e-01,  -1.24938965e-01],
                        [ -1.30401611e-01,  -1.30432129e-01],
                        [ -1.28997803e-01,  -1.28997803e-01],
                        [ -1.16973877e-01,  -1.16943359e-01],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  1.30340576e-01,   1.30340576e-01],
                        [  1.98791504e-01,   1.98791504e-01],
                        [  2.23419189e-01,   2.23419189e-01],
                        [  2.06909180e-01,   2.06909180e-01],
                        [  1.72271729e-01,   1.72271729e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  8.18481445e-02,   8.18176270e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  8.90502930e-02,   8.90197754e-02],
                        [  8.75244141e-02,   8.75549316e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  6.90612793e-02,   6.90307617e-02],
                        [  6.16149902e-02,   6.16455078e-02],
                        [  5.50231934e-02,   5.50537109e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  4.87060547e-02,   4.86755371e-02],
                        [  5.46875000e-02,   5.47180176e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.94079590e-02,   4.93774414e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -1.80053711e-02,  -1.79748535e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.45556641e-02,  -4.45251465e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.91345215e-02,  -1.91040039e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -2.41088867e-02,  -2.40783691e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [  3.02124023e-03,   3.05175781e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  1.72119141e-02,   1.72424316e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [ -3.05175781e-05,  -6.10351562e-05],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  4.11376953e-02,   4.11682129e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  2.94799805e-02,   2.95104980e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -1.55883789e-01,  -1.55883789e-01],
                        [ -1.95953369e-01,  -1.95953369e-01],
                        [ -1.98272705e-01,  -1.98272705e-01],
                        [ -1.72973633e-01,  -1.72973633e-01],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -1.28631592e-01,  -1.28662109e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.15875244e-01,  -1.15875244e-01],
                        [ -1.01196289e-01,  -1.01226807e-01],
                        [ -8.66088867e-02,  -8.66088867e-02],
                        [ -8.09936523e-02,  -8.09631348e-02],
                        [ -7.94067383e-02,  -7.94067383e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -4.26330566e-02,  -4.26025391e-02],
                        [ -1.06506348e-02,  -1.06811523e-02],
                        [  2.42004395e-02,   2.41699219e-02],
                        [  6.33544922e-02,   6.33850098e-02],
                        [  1.02355957e-01,   1.02386475e-01],
                        [  1.30523682e-01,   1.30523682e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.53533936e-01,   1.53533936e-01],
                        [  1.67175293e-01,   1.67175293e-01],
                        [  1.84295654e-01,   1.84295654e-01],
                        [  1.97082520e-01,   1.97082520e-01],
                        [  2.00286865e-01,   2.00286865e-01],
                        [  1.91192627e-01,   1.91162109e-01],
                        [  1.62109375e-01,   1.62109375e-01],
                        [  1.01196289e-01,   1.01226807e-01],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -1.09405518e-01,  -1.09405518e-01],
                        [ -2.17315674e-01,  -2.17315674e-01],
                        [ -2.90710449e-01,  -2.90710449e-01],
                        [ -3.10455322e-01,  -3.10455322e-01],
                        [ -2.76489258e-01,  -2.76489258e-01],
                        [ -2.13439941e-01,  -2.13439941e-01],
                        [ -1.58386230e-01,  -1.58416748e-01],
                        [ -1.35467529e-01,  -1.35467529e-01],
                        [ -1.40258789e-01,  -1.40258789e-01],
                        [ -1.49658203e-01,  -1.49658203e-01],
                        [ -1.46118164e-01,  -1.46118164e-01],
                        [ -1.30950928e-01,  -1.30920410e-01],
                        [ -1.11755371e-01,  -1.11755371e-01],
                        [ -8.24584961e-02,  -8.24584961e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.99371338e-01,   1.99340820e-01],
                        [  2.23999023e-01,   2.23999023e-01],
                        [  2.07031250e-01,   2.07031250e-01],
                        [  1.63879395e-01,   1.63879395e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  8.20617676e-02,   8.20312500e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  8.89587402e-02,   8.89282227e-02],
                        [  8.12377930e-02,   8.12683105e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  5.72814941e-02,   5.72509766e-02],
                        [  5.53588867e-02,   5.53894043e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.71508789e-02,  -1.71203613e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -1.34582520e-02,  -1.34277344e-02],
                        [ -1.19323730e-02,  -1.19628906e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -2.67944336e-02,  -2.67639160e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.49023438e-02,  -2.48718262e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  1.79138184e-02,   1.79443359e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.52685547e-02,   2.52380371e-02],
                        [  2.34985352e-02,   2.35290527e-02],
                        [  2.07519531e-02,   2.07824707e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  5.37109375e-03,   5.40161133e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -1.04797363e-01,  -1.04797363e-01],
                        [ -1.66351318e-01,  -1.66351318e-01],
                        [ -2.00073242e-01,  -2.00073242e-01],
                        [ -1.95526123e-01,  -1.95526123e-01],
                        [ -1.64245605e-01,  -1.64245605e-01],
                        [ -1.34246826e-01,  -1.34246826e-01],
                        [ -1.21276855e-01,  -1.21276855e-01],
                        [ -1.14715576e-01,  -1.14715576e-01],
                        [ -1.00280762e-01,  -1.00280762e-01],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  8.83789062e-02,   8.83789062e-02],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.39739990e-01,   1.39739990e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.53503418e-01,   1.53503418e-01],
                        [  1.72882080e-01,   1.72882080e-01],
                        [  2.02056885e-01,   2.02056885e-01],
                        [  2.24029541e-01,   2.24029541e-01],
                        [  2.16461182e-01,   2.16461182e-01],
                        [  1.67449951e-01,   1.67449951e-01],
                        [  8.30993652e-02,   8.30993652e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -1.34002686e-01,  -1.34002686e-01],
                        [ -2.34680176e-01,  -2.34680176e-01],
                        [ -2.97485352e-01,  -2.97485352e-01],
                        [ -3.03070068e-01,  -3.03070068e-01],
                        [ -2.60528564e-01,  -2.60559082e-01],
                        [ -2.05718994e-01,  -2.05718994e-01],
                        [ -1.72363281e-01,  -1.72363281e-01],
                        [ -1.64978027e-01,  -1.64978027e-01],
                        [ -1.63574219e-01,  -1.63574219e-01],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -1.33117676e-01,  -1.33117676e-01],
                        [ -1.11450195e-01,  -1.11450195e-01],
                        [ -8.29162598e-02,  -8.29162598e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.99859619e-01,   1.99829102e-01],
                        [  2.08343506e-01,   2.08343506e-01],
                        [  1.91497803e-01,   1.91497803e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  8.01086426e-02,   8.01086426e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  9.28344727e-02,   9.28039551e-02],
                        [  7.80944824e-02,   7.80944824e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -2.56042480e-02,  -2.56347656e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.61743164e-02,  -1.61437988e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.14941406e-02,   3.14636230e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  1.22375488e-02,   1.22070312e-02],
                        [  1.79443359e-02,   1.79748535e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  1.84936523e-02,   1.85241699e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -1.51367188e-01,  -1.51367188e-01],
                        [ -1.84387207e-01,  -1.84387207e-01],
                        [ -1.82464600e-01,  -1.82464600e-01],
                        [ -1.56738281e-01,  -1.56738281e-01],
                        [ -1.27899170e-01,  -1.27899170e-01],
                        [ -1.06536865e-01,  -1.06536865e-01],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -8.59375000e-02,  -8.59375000e-02],
                        [ -8.58459473e-02,  -8.58459473e-02],
                        [ -8.59985352e-02,  -8.59985352e-02],
                        [ -7.98950195e-02,  -7.98950195e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.57409668e-01,   1.57409668e-01],
                        [  1.78466797e-01,   1.78466797e-01],
                        [  1.94702148e-01,   1.94702148e-01],
                        [  2.11090088e-01,   2.11090088e-01],
                        [  2.22259521e-01,   2.22259521e-01],
                        [  2.17376709e-01,   2.17376709e-01],
                        [  1.86614990e-01,   1.86614990e-01],
                        [  1.24908447e-01,   1.24938965e-01],
                        [  3.38745117e-02,   3.38745117e-02],
                        [ -7.89489746e-02,  -7.89489746e-02],
                        [ -1.98822021e-01,  -1.98822021e-01],
                        [ -2.97790527e-01,  -2.97790527e-01],
                        [ -3.40118408e-01,  -3.40148926e-01],
                        [ -3.11248779e-01,  -3.11248779e-01],
                        [ -2.40478516e-01,  -2.40478516e-01],
                        [ -1.79382324e-01,  -1.79382324e-01],
                        [ -1.55059814e-01,  -1.55059814e-01],
                        [ -1.54693604e-01,  -1.54663086e-01],
                        [ -1.54022217e-01,  -1.54022217e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -1.00372314e-01,  -1.00372314e-01],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.06414795e-01,   1.06414795e-01],
                        [  1.88293457e-01,   1.88293457e-01],
                        [  2.33459473e-01,   2.33459473e-01],
                        [  2.29522705e-01,   2.29522705e-01],
                        [  1.91436768e-01,   1.91436768e-01],
                        [  1.47552490e-01,   1.47552490e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  3.92150879e-02,   3.92456055e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  7.00683594e-02,   7.00683594e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  8.14514160e-02,   8.14208984e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  7.74536133e-02,   7.74841309e-02],
                        [  7.70874023e-02,   7.70874023e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  7.09838867e-02,   7.10144043e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.99072266e-02,   2.99377441e-02],
                        [  2.06909180e-02,   2.06604004e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.96020508e-02,  -2.95715332e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -4.02526855e-02,  -4.02221680e-02],
                        [ -3.68652344e-02,  -3.68652344e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -1.61437988e-02,  -1.61132812e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [  6.34765625e-03,   6.31713867e-03],
                        [  1.14440918e-02,   1.14135742e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -9.05761719e-02,  -9.05456543e-02],
                        [ -1.44897461e-01,  -1.44897461e-01],
                        [ -1.81335449e-01,  -1.81365967e-01],
                        [ -1.90216064e-01,  -1.90216064e-01],
                        [ -1.71417236e-01,  -1.71417236e-01],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -1.04980469e-01,  -1.04980469e-01],
                        [ -8.55407715e-02,  -8.55102539e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -7.77893066e-02,  -7.77893066e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  8.33129883e-02,   8.33129883e-02],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.60919189e-01,   1.60919189e-01],
                        [  1.89636230e-01,   1.89636230e-01],
                        [  2.15301514e-01,   2.15301514e-01],
                        [  2.31353760e-01,   2.31353760e-01],
                        [  2.31903076e-01,   2.31872559e-01],
                        [  2.10418701e-01,   2.10418701e-01],
                        [  1.55303955e-01,   1.55303955e-01],
                        [  5.99670410e-02,   5.99670410e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -1.85333252e-01,  -1.85333252e-01],
                        [ -2.76824951e-01,  -2.76824951e-01],
                        [ -3.19427490e-01,  -3.19427490e-01],
                        [ -3.08410645e-01,  -3.08410645e-01],
                        [ -2.55065918e-01,  -2.55065918e-01],
                        [ -1.91040039e-01,  -1.91040039e-01],
                        [ -1.52984619e-01,  -1.52984619e-01],
                        [ -1.50115967e-01,  -1.50115967e-01],
                        [ -1.57287598e-01,  -1.57287598e-01],
                        [ -1.48193359e-01,  -1.48223877e-01],
                        [ -1.22436523e-01,  -1.22436523e-01],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  1.50878906e-01,   1.50878906e-01],
                        [  2.02545166e-01,   2.02514648e-01],
                        [  2.15057373e-01,   2.15057373e-01],
                        [  1.94183350e-01,   1.94183350e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  9.33837891e-02,   9.33837891e-02],
                        [  8.02917480e-02,   8.02612305e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.39160156e-02,  -1.39465332e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.69616699e-01,  -1.69616699e-01],
                        [ -2.01568604e-01,  -2.01568604e-01],
                        [ -1.93176270e-01,  -1.93176270e-01],
                        [ -1.56311035e-01,  -1.56311035e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -7.91320801e-02,  -7.91320801e-02],
                        [ -8.56323242e-02,  -8.56323242e-02],
                        [ -9.07287598e-02,  -9.07287598e-02],
                        [ -8.60900879e-02,  -8.60900879e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  1.47430420e-01,   1.47430420e-01],
                        [  1.86553955e-01,   1.86553955e-01],
                        [  2.12402344e-01,   2.12402344e-01],
                        [  2.27813721e-01,   2.27813721e-01],
                        [  2.34741211e-01,   2.34741211e-01],
                        [  2.28637695e-01,   2.28637695e-01],
                        [  1.96594238e-01,   1.96594238e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.80053711e-02,   1.80053711e-02],
                        [ -1.09252930e-01,  -1.09252930e-01],
                        [ -2.28363037e-01,  -2.28363037e-01],
                        [ -3.11157227e-01,  -3.11157227e-01],
                        [ -3.36547852e-01,  -3.36547852e-01],
                        [ -3.04687500e-01,  -3.04687500e-01],
                        [ -2.43774414e-01,  -2.43774414e-01],
                        [ -1.91711426e-01,  -1.91711426e-01],
                        [ -1.65283203e-01,  -1.65283203e-01],
                        [ -1.52832031e-01,  -1.52832031e-01],
                        [ -1.36413574e-01,  -1.36413574e-01],
                        [ -1.12274170e-01,  -1.12274170e-01],
                        [ -8.52661133e-02,  -8.52966309e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.93420410e-01,   1.93420410e-01],
                        [  2.16186523e-01,   2.16186523e-01],
                        [  2.08831787e-01,   2.08831787e-01],
                        [  1.79443359e-01,   1.79443359e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -1.63665771e-01,  -1.63665771e-01],
                        [ -1.88781738e-01,  -1.88781738e-01],
                        [ -1.78222656e-01,  -1.78222656e-01],
                        [ -1.49444580e-01,  -1.49444580e-01],
                        [ -1.25183105e-01,  -1.25183105e-01],
                        [ -1.15844727e-01,  -1.15844727e-01],
                        [ -1.13525391e-01,  -1.13525391e-01],
                        [ -1.04125977e-01,  -1.04125977e-01],
                        [ -8.51135254e-02,  -8.51135254e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.64947510e-01,   1.64947510e-01],
                        [  2.07702637e-01,   2.07702637e-01],
                        [  2.36877441e-01,   2.36877441e-01],
                        [  2.51831055e-01,   2.51831055e-01],
                        [  2.48016357e-01,   2.48016357e-01],
                        [  2.15393066e-01,   2.15393066e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  4.36706543e-02,   4.36706543e-02],
                        [ -8.07189941e-02,  -8.07189941e-02],
                        [ -2.06695557e-01,  -2.06695557e-01],
                        [ -3.06610107e-01,  -3.06610107e-01],
                        [ -3.50952148e-01,  -3.50952148e-01],
                        [ -3.28125000e-01,  -3.28125000e-01],
                        [ -2.60650635e-01,  -2.60650635e-01],
                        [ -1.92993164e-01,  -1.92993164e-01],
                        [ -1.56494141e-01,  -1.56494141e-01],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -1.45660400e-01,  -1.45660400e-01],
                        [ -1.29150391e-01,  -1.29150391e-01],
                        [ -9.74121094e-02,  -9.74121094e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.90307617e-01,   1.90307617e-01],
                        [  2.15148926e-01,   2.15148926e-01],
                        [  2.07183838e-01,   2.07183838e-01],
                        [  1.77001953e-01,   1.77001953e-01],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.08856201e-01,   1.08856201e-01],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  9.08813477e-02,   9.08813477e-02],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -1.18469238e-01,  -1.18469238e-01],
                        [ -1.68029785e-01,  -1.68029785e-01],
                        [ -1.89178467e-01,  -1.89178467e-01],
                        [ -1.80572510e-01,  -1.80572510e-01],
                        [ -1.53991699e-01,  -1.53991699e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -1.05346680e-01,  -1.05346680e-01],
                        [ -9.15832520e-02,  -9.15832520e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.93969727e-01,   1.93969727e-01],
                        [  2.36511230e-01,   2.36511230e-01],
                        [  2.53662109e-01,   2.53662109e-01],
                        [  2.41699219e-01,   2.41699219e-01],
                        [  2.01385498e-01,   2.01385498e-01],
                        [  1.32873535e-01,   1.32873535e-01],
                        [  3.54614258e-02,   3.54614258e-02],
                        [ -8.42285156e-02,  -8.42285156e-02],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -3.00720215e-01,  -3.00720215e-01],
                        [ -3.42926025e-01,  -3.42926025e-01],
                        [ -3.24279785e-01,  -3.24279785e-01],
                        [ -2.66143799e-01,  -2.66143799e-01],
                        [ -2.09533691e-01,  -2.09533691e-01],
                        [ -1.80511475e-01,  -1.80511475e-01],
                        [ -1.69494629e-01,  -1.69494629e-01],
                        [ -1.51763916e-01,  -1.51763916e-01],
                        [ -1.18347168e-01,  -1.18347168e-01],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.68151855e-01,   1.68151855e-01],
                        [  2.09259033e-01,   2.09259033e-01],
                        [  2.18078613e-01,   2.18078613e-01],
                        [  1.98028564e-01,   1.98028564e-01],
                        [  1.63635254e-01,   1.63635254e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  9.99450684e-02,   9.99450684e-02],
                        [  7.22961426e-02,   7.22961426e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  2.03552246e-02,   2.03247070e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -2.85644531e-02,  -2.85339355e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  2.32238770e-02,   2.31933594e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.43737793e-02,   1.43432617e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -1.17645264e-01,  -1.17645264e-01],
                        [ -1.60217285e-01,  -1.60217285e-01],
                        [ -1.69494629e-01,  -1.69494629e-01],
                        [ -1.46392822e-01,  -1.46392822e-01],
                        [ -1.13708496e-01,  -1.13708496e-01],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  7.82775879e-02,   7.82775879e-02],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.78710938e-01,   1.78741455e-01],
                        [  2.15240479e-01,   2.15240479e-01],
                        [  2.34375000e-01,   2.34375000e-01],
                        [  2.27569580e-01,   2.27569580e-01],
                        [  1.86035156e-01,   1.86035156e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [ -6.10351562e-04,  -6.40869141e-04],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -2.54394531e-01,  -2.54394531e-01],
                        [ -3.36242676e-01,  -3.36242676e-01],
                        [ -3.48663330e-01,  -3.48663330e-01],
                        [ -3.00659180e-01,  -3.00659180e-01],
                        [ -2.30590820e-01,  -2.30590820e-01],
                        [ -1.78070068e-01,  -1.78039551e-01],
                        [ -1.58691406e-01,  -1.58691406e-01],
                        [ -1.57043457e-01,  -1.57043457e-01],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -1.06964111e-01,  -1.06964111e-01],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  6.41479492e-02,   6.41479492e-02],
                        [  1.25579834e-01,   1.25579834e-01],
                        [  1.76239014e-01,   1.76239014e-01],
                        [  2.00439453e-01,   2.00408936e-01],
                        [  1.95709229e-01,   1.95739746e-01],
                        [  1.73919678e-01,   1.73950195e-01],
                        [  1.47247314e-01,   1.47247314e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  5.35278320e-02,   5.34973145e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  8.00476074e-02,   8.00781250e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  3.86047363e-02,   3.86352539e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  6.34765625e-02,   6.35070801e-02],
                        [  6.90002441e-02,   6.90002441e-02],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  5.77087402e-02,   5.77392578e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.74145508e-02,  -3.74450684e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -1.01318359e-02,  -1.01013184e-02],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -1.00708008e-03,  -1.03759766e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.18713379e-02,   1.18408203e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.62963867e-02,   1.63269043e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.61437988e-02,  -1.61132812e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.67028809e-02,  -2.67333984e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.05786133e-02,  -3.05480957e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.02734375e-02,  -3.03039551e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.56555176e-02,   1.56860352e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  1.17797852e-02,   1.17492676e-02],
                        [ -2.42614746e-02,  -2.42309570e-02],
                        [ -8.08105469e-02,  -8.08105469e-02],
                        [ -1.36291504e-01,  -1.36322021e-01],
                        [ -1.66534424e-01,  -1.66534424e-01],
                        [ -1.63818359e-01,  -1.63818359e-01],
                        [ -1.39495850e-01,  -1.39495850e-01],
                        [ -1.10351562e-01,  -1.10382080e-01],
                        [ -8.67614746e-02,  -8.67919922e-02],
                        [ -7.09533691e-02,  -7.09228516e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -2.86865234e-02,  -2.87170410e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  2.74353027e-02,   2.74658203e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  1.25915527e-01,   1.25885010e-01],
                        [  1.82586670e-01,   1.82586670e-01],
                        [  2.21588135e-01,   2.21588135e-01],
                        [  2.28332520e-01,   2.28332520e-01],
                        [  2.00256348e-01,   2.00256348e-01],
                        [  1.41937256e-01,   1.41937256e-01],
                        [  5.52368164e-02,   5.52673340e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -1.80145264e-01,  -1.80145264e-01],
                        [ -2.80670166e-01,  -2.80639648e-01],
                        [ -3.28735352e-01,  -3.28704834e-01],
                        [ -3.14910889e-01,  -3.14941406e-01],
                        [ -2.59582520e-01,  -2.59613037e-01],
                        [ -2.01202393e-01,  -2.01202393e-01],
                        [ -1.67907715e-01,  -1.67877197e-01],
                        [ -1.57531738e-01,  -1.57531738e-01],
                        [ -1.47277832e-01,  -1.47308350e-01],
                        [ -1.19750977e-01,  -1.19750977e-01],
                        [ -7.56835938e-02,  -7.56530762e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [  3.35083008e-02,   3.34777832e-02],
                        [  9.24987793e-02,   9.24682617e-02],
                        [  1.42730713e-01,   1.42761230e-01],
                        [  1.72485352e-01,   1.72515869e-01],
                        [  1.80328369e-01,   1.80297852e-01],
                        [  1.73980713e-01,   1.73950195e-01],
                        [  1.61285400e-01,   1.61315918e-01],
                        [  1.44836426e-01,   1.44866943e-01],
                        [  1.22985840e-01,   1.22955322e-01],
                        [  9.55810547e-02,   9.55505371e-02],
                        [  6.87561035e-02,   6.87866211e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.51757812e-02,   5.51452637e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  5.88378906e-02,   5.88073730e-02],
                        [  5.74645996e-02,   5.74340820e-02],
                        [  5.73425293e-02,   5.73730469e-02],
                        [  5.96923828e-02,   5.97229004e-02],
                        [  6.32629395e-02,   6.32324219e-02],
                        [  6.54296875e-02,   6.53991699e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  6.77795410e-02,   6.78100586e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  6.38122559e-02,   6.37817383e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  3.47900391e-02,   3.48205566e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  6.92749023e-03,   6.86645508e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -1.95312500e-03,  -1.92260742e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -7.59887695e-03,  -7.62939453e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.38244629e-02,  -1.37939453e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -1.78222656e-02,  -1.78527832e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -5.58471680e-03,  -5.55419922e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -7.35473633e-03,  -7.38525391e-03],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [  3.23486328e-03,   3.26538086e-03],
                        [  8.63647461e-03,   8.66699219e-03],
                        [  7.93457031e-03,   7.90405273e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  5.61523438e-03,   5.64575195e-03],
                        [  1.00708008e-02,   1.01013184e-02],
                        [  1.59606934e-02,   1.59301758e-02],
                        [  1.92565918e-02,   1.92260742e-02],
                        [  1.61132812e-02,   1.61437988e-02],
                        [  6.07299805e-03,   6.10351562e-03],
                        [ -7.53784180e-03,  -7.56835938e-03],
                        [ -2.05688477e-02,  -2.05993652e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -3.03649902e-02,  -3.03344727e-02],
                        [ -2.44445801e-02,  -2.44750977e-02],
                        [ -1.52282715e-02,  -1.52587891e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -6.16455078e-03,  -6.13403320e-03],
                        [ -1.11389160e-02,  -1.11694336e-02],
                        [ -1.88598633e-02,  -1.88903809e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.07519531e-02,  -2.06909180e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [  4.88281250e-04,   4.57763672e-04],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  2.87780762e-02,   2.88085938e-02],
                        [  3.53698730e-02,   3.54003906e-02],
                        [  2.50549316e-02,   2.50244141e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -5.60607910e-02,  -5.60302734e-02],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -1.36566162e-01,  -1.36596680e-01],
                        [ -1.49566650e-01,  -1.49597168e-01],
                        [ -1.41235352e-01,  -1.41174316e-01],
                        [ -1.16058350e-01,  -1.16027832e-01],
                        [ -8.65173340e-02,  -8.65783691e-02],
                        [ -6.44836426e-02,  -6.45141602e-02],
                        [ -5.07202148e-02,  -5.06591797e-02],
                        [ -3.90014648e-02,  -3.89709473e-02],
                        [ -2.57263184e-02,  -2.57873535e-02],
                        [ -8.88061523e-03,  -8.91113281e-03],
                        [  1.63879395e-02,   1.64184570e-02],
                        [  5.44738770e-02,   5.45043945e-02],
                        [  1.05438232e-01,   1.05407715e-01],
                        [  1.63024902e-01,   1.62994385e-01],
                        [  2.11486816e-01,   2.11517334e-01],
                        [  2.28088379e-01,   2.28118896e-01],
                        [  1.97601318e-01,   1.97570801e-01],
                        [  1.23535156e-01,   1.23504639e-01],
                        [  2.10571289e-02,   2.10876465e-02],
                        [ -9.51843262e-02,  -9.51538086e-02],
                        [ -2.09594727e-01,  -2.09625244e-01],
                        [ -2.96997070e-01,  -2.97058105e-01],
                        [ -3.30810547e-01,  -3.30780029e-01],
                        [ -3.07250977e-01,  -3.07189941e-01],
                        [ -2.54180908e-01,  -2.54211426e-01],
                        [ -2.06024170e-01,  -2.06085205e-01],
                        [ -1.73858643e-01,  -1.73858643e-01],
                        [ -1.46667480e-01,  -1.46606445e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -7.62939453e-02,  -7.63244629e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [  5.95092773e-03,   6.01196289e-03],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  1.03271484e-01,   1.03210449e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.60766602e-01,   1.60827637e-01],
                        [  1.61193848e-01,   1.61193848e-01],
                        [  1.56127930e-01,   1.56066895e-01],
                        [  1.50939941e-01,   1.50909424e-01],
                        [  1.40533447e-01,   1.40594482e-01],
                        [  1.22314453e-01,   1.22344971e-01],
                        [  1.00891113e-01,   1.00830078e-01],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  6.42395020e-02,   6.43005371e-02],
                        [  5.37719727e-02,   5.38024902e-02],
                        [  4.90112305e-02,   4.89501953e-02],
                        [  4.48303223e-02,   4.47998047e-02],
                        [  3.83911133e-02,   3.84521484e-02],
                        [  3.43017578e-02,   3.43627930e-02],
                        [  3.72314453e-02,   3.72009277e-02],
                        [  4.42504883e-02,   4.41894531e-02],
                        [  4.98352051e-02,   4.98962402e-02],
                        [  5.30090332e-02,   5.30700684e-02],
                        [  5.46875000e-02,   5.46264648e-02],
                        [  5.40161133e-02,   5.39550781e-02],
                        [  5.12695312e-02,   5.13000488e-02],
                        [  4.84619141e-02,   4.85229492e-02],
                        [  4.54101562e-02,   4.53796387e-02],
                        [  3.97033691e-02,   3.96423340e-02],
                        [  3.20434570e-02,   3.20739746e-02],
                        [  2.61230469e-02,   2.61840820e-02],
                        [  2.16674805e-02,   2.16369629e-02],
                        [  1.34582520e-02,   1.33972168e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -1.55334473e-02,  -1.54724121e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.72521973e-02,  -2.73132324e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -7.23266602e-03,  -7.14111328e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  9.79614258e-03,   9.73510742e-03],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.04370117e-02,   1.04980469e-02],
                        [  6.40869141e-04,   6.71386719e-04],
                        [ -1.26037598e-02,  -1.26647949e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.69677734e-02,  -1.69067383e-02],
                        [ -6.28662109e-03,  -6.25610352e-03],
                        [  4.88281250e-03,   4.82177734e-03],
                        [  1.24206543e-02,   1.23901367e-02],
                        [  1.70593262e-02,   1.71203613e-02],
                        [  2.05078125e-02,   2.05383301e-02],
                        [  2.13928223e-02,   2.13317871e-02],
                        [  1.69067383e-02,   1.68762207e-02],
                        [  7.87353516e-03,   7.93457031e-03],
                        [ -1.22070312e-03,  -1.19018555e-03],
                        [ -7.50732422e-03,  -7.56835938e-03],
                        [ -1.24816895e-02,  -1.25427246e-02],
                        [ -1.85852051e-02,  -1.85241699e-02],
                        [ -2.64892578e-02,  -2.64282227e-02],
                        [ -3.51562500e-02,  -3.51867676e-02],
                        [ -4.18395996e-02,  -4.19006348e-02],
                        [ -4.44946289e-02,  -4.44641113e-02],
                        [ -4.48608398e-02,  -4.47998047e-02],
                        [ -4.53796387e-02,  -4.54101562e-02],
                        [ -4.36096191e-02,  -4.36706543e-02],
                        [ -3.53088379e-02,  -3.52783203e-02],
                        [ -2.05688477e-02,  -2.05078125e-02],
                        [ -2.28881836e-03,  -2.31933594e-03],
                        [  1.79138184e-02,   1.78222656e-02],
                        [  3.72924805e-02,   3.73229980e-02],
                        [  4.94689941e-02,   4.95300293e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  2.10571289e-02,   2.09960938e-02],
                        [ -2.60009766e-02,  -2.59704590e-02],
                        [ -8.34655762e-02,  -8.34045410e-02],
                        [ -1.30249023e-01,  -1.30279541e-01],
                        [ -1.49536133e-01,  -1.49597168e-01],
                        [ -1.40441895e-01,  -1.40441895e-01],
                        [ -1.14715576e-01,  -1.14654541e-01],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -6.08520508e-02,  -6.09130859e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.97033691e-02,  -3.96118164e-02],
                        [ -3.76892090e-02,  -3.76586914e-02],
                        [ -2.95104980e-02,  -2.96020508e-02],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [  4.38842773e-02,   4.39758301e-02],
                        [  1.13159180e-01,   1.13189697e-01],
                        [  1.88690186e-01,   1.88629150e-01],
                        [  2.44049072e-01,   2.43988037e-01],
                        [  2.53662109e-01,   2.53723145e-01],
                        [  2.08801270e-01,   2.08831787e-01],
                        [  1.18499756e-01,   1.18438721e-01],
                        [ -1.86157227e-03,  -1.92260742e-03],
                        [ -1.35986328e-01,  -1.35925293e-01],
                        [ -2.60040283e-01,  -2.59979248e-01],
                        [ -3.40759277e-01,  -3.40820312e-01],
                        [ -3.53698730e-01,  -3.53759766e-01],
                        [ -3.09020996e-01,  -3.08959961e-01],
                        [ -2.48779297e-01,  -2.48718262e-01],
                        [ -2.09503174e-01,  -2.09564209e-01],
                        [ -1.92138672e-01,  -1.92230225e-01],
                        [ -1.73095703e-01,  -1.73034668e-01],
                        [ -1.35345459e-01,  -1.35284424e-01],
                        [ -8.10546875e-02,  -8.10852051e-02],
                        [ -1.92565918e-02,  -1.93481445e-02],
                        [  4.55017090e-02,   4.55322266e-02],
                        [  1.08306885e-01,   1.08398438e-01],
                        [  1.57653809e-01,   1.57653809e-01],
                        [  1.83929443e-01,   1.83837891e-01],
                        [  1.88964844e-01,   1.88964844e-01],
                        [  1.81823730e-01,   1.81945801e-01],
                        [  1.69189453e-01,   1.69189453e-01],
                        [  1.51489258e-01,   1.51397705e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  9.80834961e-02,   9.81750488e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  6.32629395e-02,   6.31713867e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  5.45654297e-02,   5.46264648e-02],
                        [  4.23889160e-02,   4.24194336e-02],
                        [  2.82897949e-02,   2.82287598e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.30712891e-02,   2.31628418e-02],
                        [  3.28063965e-02,   3.28369141e-02],
                        [  4.50134277e-02,   4.49218750e-02],
                        [  5.61218262e-02,   5.60607910e-02],
                        [  6.45446777e-02,   6.46362305e-02],
                        [  7.04345703e-02,   7.04956055e-02],
                        [  7.35168457e-02,   7.34558105e-02],
                        [  7.12890625e-02,   7.12280273e-02],
                        [  6.21337891e-02,   6.21948242e-02],
                        [  4.94384766e-02,   4.94995117e-02],
                        [  3.82995605e-02,   3.82080078e-02],
                        [  2.96020508e-02,   2.95410156e-02],
                        [  2.20642090e-02,   2.21252441e-02],
                        [  1.67236328e-02,   1.67846680e-02],
                        [  1.38854980e-02,   1.38244629e-02],
                        [  9.15527344e-03,   9.09423828e-03],
                        [ -1.25122070e-03,  -1.22070312e-03],
                        [ -1.50146484e-02,  -1.49230957e-02],
                        [ -2.65502930e-02,  -2.65808105e-02],
                        [ -3.24707031e-02,  -3.25622559e-02],
                        [ -3.17382812e-02,  -3.17077637e-02],
                        [ -2.45361328e-02,  -2.44140625e-02],
                        [ -1.35498047e-02,  -1.35803223e-02],
                        [ -4.91333008e-03,  -5.00488281e-03],
                        [ -2.01416016e-03,  -1.98364258e-03],
                        [  4.57763672e-04,   5.79833984e-04],
                        [  9.42993164e-03,   9.39941406e-03],
                        [  2.06909180e-02,   2.05993652e-02],
                        [  2.42309570e-02,   2.42614746e-02],
                        [  2.08740234e-02,   2.09655762e-02],
                        [  2.08740234e-02,   2.08435059e-02],
                        [  2.60009766e-02,   2.59094238e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.71813965e-02,   1.72729492e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [ -7.62939453e-03,  -7.72094727e-03],
                        [ -1.51977539e-02,  -1.52282715e-02],
                        [ -2.19726562e-02,  -2.18811035e-02],
                        [ -2.82287598e-02,  -2.81677246e-02],
                        [ -3.22875977e-02,  -3.23791504e-02],
                        [ -3.32031250e-02,  -3.32641602e-02],
                        [ -3.23791504e-02,  -3.22875977e-02],
                        [ -3.14025879e-02,  -3.13415527e-02],
                        [ -3.03649902e-02,  -3.04870605e-02],
                        [ -3.02124023e-02,  -3.02734375e-02],
                        [ -3.24707031e-02,  -3.23791504e-02],
                        [ -3.41491699e-02,  -3.40881348e-02],
                        [ -2.92968750e-02,  -2.93579102e-02],
                        [ -1.77307129e-02,  -1.78222656e-02],
                        [ -4.94384766e-03,  -4.88281250e-03],
                        [  6.56127930e-03,   6.62231445e-03],
                        [  1.73339844e-02,   1.72729492e-02],
                        [  2.61535645e-02,   2.60620117e-02],
                        [  3.10363770e-02,   3.10974121e-02],
                        [  3.11584473e-02,   3.12805176e-02],
                        [  2.19116211e-02,   2.18505859e-02],
                        [ -5.06591797e-03,  -5.15747070e-03],
                        [ -4.98046875e-02,  -4.97436523e-02],
                        [ -9.66796875e-02,  -9.65576172e-02],
                        [ -1.26190186e-01,  -1.26220703e-01],
                        [ -1.31408691e-01,  -1.31500244e-01],
                        [ -1.18560791e-01,  -1.18530273e-01],
                        [ -9.88159180e-02,  -9.87243652e-02],
                        [ -8.40148926e-02,  -8.40454102e-02],
                        [ -7.97119141e-02,  -7.98034668e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -5.23071289e-02,  -5.21850586e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  5.71289062e-02,   5.70068359e-02],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.87377930e-01,   1.87500000e-01],
                        [  2.41424561e-01,   2.41455078e-01],
                        [  2.58239746e-01,   2.58117676e-01],
                        [  2.20428467e-01,   2.20367432e-01],
                        [  1.33911133e-01,   1.34033203e-01],
                        [  1.55944824e-02,   1.56250000e-02],
                        [ -1.20666504e-01,  -1.20788574e-01],
                        [ -2.54455566e-01,  -2.54486084e-01],
                        [ -3.48937988e-01,  -3.48815918e-01],
                        [ -3.73168945e-01,  -3.73107910e-01],
                        [ -3.35144043e-01,  -3.35235596e-01],
                        [ -2.75543213e-01,  -2.75604248e-01],
                        [ -2.27264404e-01,  -2.27172852e-01],
                        [ -1.94000244e-01,  -1.93939209e-01],
                        [ -1.63787842e-01,  -1.63879395e-01],
                        [ -1.26068115e-01,  -1.26159668e-01],
                        [ -7.52258301e-02,  -7.51647949e-02],
                        [ -1.06201172e-02,  -1.05285645e-02],
                        [  6.01196289e-02,   6.00280762e-02],
                        [  1.21704102e-01,   1.21612549e-01],
                        [  1.61437988e-01,   1.61499023e-01],
                        [  1.78100586e-01,   1.78192139e-01],
                        [  1.79504395e-01,   1.79443359e-01],
                        [  1.73614502e-01,   1.73522949e-01],
                        [  1.64550781e-01,   1.64611816e-01],
                        [  1.51947021e-01,   1.52038574e-01],
                        [  1.33422852e-01,   1.33361816e-01],
                        [  1.11053467e-01,   1.10961914e-01],
                        [  9.25903320e-02,   9.26208496e-02],
                        [  8.17871094e-02,   8.19091797e-02],
                        [  7.20520020e-02,   7.20214844e-02],
                        [  5.50842285e-02,   5.49926758e-02],
                        [  3.32031250e-02,   3.32336426e-02],
                        [  1.55944824e-02,   1.57165527e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  6.43920898e-03,   6.31713867e-03],
                        [  1.71813965e-02,   1.71508789e-02],
                        [  3.86962891e-02,   3.88183594e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  8.04748535e-02,   8.03527832e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  8.80737305e-02,   8.81958008e-02],
                        [  7.79724121e-02,   7.80029297e-02],
                        [  6.25000000e-02,   6.23779297e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  4.52880859e-02,   4.53796387e-02],
                        [  3.92761230e-02,   3.93066406e-02],
                        [  2.57873535e-02,   2.56958008e-02],
                        [  1.10168457e-02,   1.09558105e-02],
                        [  4.02832031e-03,   4.11987305e-03],
                        [  2.92968750e-03,   3.02124023e-03],
                        [ -6.10351562e-04,  -7.01904297e-04],
                        [ -9.97924805e-03,  -1.00708008e-02],
                        [ -2.20642090e-02,  -2.19726562e-02],
                        [ -3.09448242e-02,  -3.08532715e-02],
                        [ -3.24707031e-02,  -3.25622559e-02],
                        [ -2.79235840e-02,  -2.80151367e-02],
                        [ -2.13317871e-02,  -2.12402344e-02],
                        [ -1.36108398e-02,  -1.34887695e-02],
                        [ -3.57055664e-03,  -3.63159180e-03],
                        [  6.95800781e-03,   6.86645508e-03],
                        [  1.44042969e-02,   1.44653320e-02],
                        [  1.80358887e-02,   1.81274414e-02],
                        [  1.92260742e-02,   1.91650391e-02],
                        [  1.93481445e-02,   1.92260742e-02],
                        [  2.11791992e-02,   2.12097168e-02],
                        [  2.62451172e-02,   2.63671875e-02],
                        [  2.85644531e-02,   2.85034180e-02],
                        [  2.04467773e-02,   2.03247070e-02],
                        [  5.37109375e-03,   5.40161133e-03],
                        [ -6.31713867e-03,  -6.22558594e-03],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -1.83715820e-02,  -1.84936523e-02],
                        [ -2.57263184e-02,  -2.56958008e-02],
                        [ -3.05175781e-02,  -3.03955078e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.36914062e-02,  -3.38134766e-02],
                        [ -3.50952148e-02,  -3.51257324e-02],
                        [ -3.50952148e-02,  -3.49731445e-02],
                        [ -3.56750488e-02,  -3.56445312e-02],
                        [ -3.78112793e-02,  -3.79333496e-02],
                        [ -3.72924805e-02,  -3.73535156e-02],
                        [ -3.22265625e-02,  -3.21044922e-02],
                        [ -2.71301270e-02,  -2.70690918e-02],
                        [ -2.39562988e-02,  -2.40783691e-02],
                        [ -1.75476074e-02,  -1.76086426e-02],
                        [ -4.15039062e-03,  -4.02832031e-03],
                        [  1.36108398e-02,   1.36718750e-02],
                        [  2.97241211e-02,   2.96020508e-02],
                        [  3.77502441e-02,   3.76586914e-02],
                        [  3.11584473e-02,   3.12500000e-02],
                        [  5.79833984e-03,   5.85937500e-03],
                        [ -3.64379883e-02,  -3.65295410e-02],
                        [ -8.56628418e-02,  -8.57238770e-02],
                        [ -1.25396729e-01,  -1.25305176e-01],
                        [ -1.38641357e-01,  -1.38549805e-01],
                        [ -1.20483398e-01,  -1.20574951e-01],
                        [ -8.74633789e-02,  -8.75549316e-02],
                        [ -6.49414062e-02,  -6.48803711e-02],
                        [ -6.11267090e-02,  -6.10046387e-02],
                        [ -5.98754883e-02,  -5.99060059e-02],
                        [ -4.22058105e-02,  -4.23278809e-02],
                        [ -6.13403320e-03,  -6.10351562e-03],
                        [  3.85437012e-02,   3.86657715e-02],
                        [  8.67614746e-02,   8.67309570e-02],
                        [  1.39129639e-01,   1.39007568e-01],
                        [  1.88201904e-01,   1.88232422e-01],
                        [  2.15454102e-01,   2.15606689e-01],
                        [  2.03948975e-01,   2.03918457e-01],
                        [  1.47430420e-01,   1.47308350e-01],
                        [  4.94995117e-02,   4.94995117e-02],
                        [ -7.76977539e-02,  -7.75451660e-02],
                        [ -2.11029053e-01,  -2.11029053e-01],
                        [ -3.17108154e-01,  -3.17230225e-01],
                        [ -3.63647461e-01,  -3.63677979e-01],
                        [ -3.42498779e-01,  -3.42346191e-01],
                        [ -2.80090332e-01,  -2.80059814e-01],
                        [ -2.16644287e-01,  -2.16796875e-01],
                        [ -1.75323486e-01,  -1.75384521e-01],
                        [ -1.51824951e-01,  -1.51702881e-01],
                        [ -1.26068115e-01,  -1.26007080e-01],
                        [ -8.27026367e-02,  -8.28247070e-02],
                        [ -2.42614746e-02,  -2.42919922e-02],
                        [  3.67431641e-02,   3.68652344e-02],
                        [  9.22241211e-02,   9.22546387e-02],
                        [  1.36993408e-01,   1.36871338e-01],
                        [  1.63635254e-01,   1.63543701e-01],
                        [  1.71569824e-01,   1.71661377e-01],
                        [  1.71966553e-01,   1.72058105e-01],
                        [  1.72485352e-01,   1.72393799e-01],
                        [  1.66503906e-01,   1.66412354e-01],
                        [  1.46423340e-01,   1.46514893e-01],
                        [  1.18621826e-01,   1.18713379e-01],
                        [  9.51538086e-02,   9.50622559e-02],
                        [  7.87048340e-02,   7.85827637e-02],
                        [  6.32629395e-02,   6.33544922e-02],
                        [  4.56237793e-02,   4.57458496e-02],
                        [  2.83508301e-02,   2.82897949e-02],
                        [  1.56250000e-02,   1.55029297e-02],
                        [  1.02844238e-02,   1.03149414e-02],
                        [  1.29394531e-02,   1.30615234e-02],
                        [  2.26440430e-02,   2.26135254e-02],
                        [  3.74450684e-02,   3.72924805e-02],
                        [  5.36804199e-02,   5.37414551e-02],
                        [  6.69860840e-02,   6.71386719e-02],
                        [  7.54699707e-02,   7.54089355e-02],
                        [  7.90710449e-02,   7.89489746e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  6.96411133e-02,   6.97937012e-02],
                        [  6.18591309e-02,   6.18286133e-02],
                        [  5.62133789e-02,   5.60913086e-02],
                        [  5.03540039e-02,   5.03234863e-02],
                        [  4.11376953e-02,   4.12902832e-02],
                        [  2.82287598e-02,   2.82592773e-02],
                        [  1.27258301e-02,   1.26037598e-02],
                        [ -3.35693359e-03,  -3.38745117e-03],
                        [ -1.67846680e-02,  -1.66625977e-02],
                        [ -2.50244141e-02,  -2.49633789e-02],
                        [ -2.78930664e-02,  -2.80151367e-02],
                        [ -2.76184082e-02,  -2.76794434e-02],
                        [ -2.60009766e-02,  -2.58789062e-02],
                        [ -2.25830078e-02,  -2.25219727e-02],
                        [ -1.72729492e-02,  -1.73950195e-02],
                        [ -1.22375488e-02,  -1.22985840e-02],
                        [ -8.36181641e-03,  -8.23974609e-03],
                        [ -3.23486328e-03,  -3.14331055e-03],
                        [  4.73022461e-03,   4.63867188e-03],
                        [  1.32446289e-02,   1.31225586e-02],
                        [  1.98059082e-02,   1.98974609e-02],
                        [  2.60009766e-02,   2.60925293e-02],
                        [  3.32946777e-02,   3.32031250e-02],
                        [  3.80554199e-02,   3.79333496e-02],
                        [  3.55834961e-02,   3.56445312e-02],
                        [  2.70385742e-02,   2.71606445e-02],
                        [  1.72119141e-02,   1.71508789e-02],
                        [  8.08715820e-03,   7.96508789e-03],
                        [ -1.15966797e-03,  -1.09863281e-03],
                        [ -1.08032227e-02,  -1.06506348e-02],
                        [ -1.94396973e-02,  -1.95007324e-02],
                        [ -2.58178711e-02,  -2.59399414e-02],
                        [ -3.09753418e-02,  -3.09448242e-02],
                        [ -3.74755859e-02,  -3.73535156e-02],
                        [ -4.46166992e-02,  -4.46472168e-02],
                        [ -4.67834473e-02,  -4.69055176e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -2.56347656e-02,  -2.54821777e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.57165527e-02,  -1.58386230e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.60314941e-02,  -2.58789062e-02],
                        [ -2.05993652e-02,  -2.05688477e-02],
                        [ -9.09423828e-03,  -9.24682617e-03],
                        [  3.81469727e-03,   3.78417969e-03],
                        [  1.66320801e-02,   1.67541504e-02],
                        [  2.63061523e-02,   2.63366699e-02],
                        [  2.53906250e-02,   2.52380371e-02],
                        [  9.24682617e-03,   9.18579102e-03],
                        [ -1.98364258e-02,  -1.96838379e-02],
                        [ -5.76477051e-02,  -5.75866699e-02],
                        [ -9.80224609e-02,  -9.81750488e-02],
                        [ -1.25976562e-01,  -1.26037598e-01],
                        [ -1.24633789e-01,  -1.24511719e-01],
                        [ -9.60693359e-02,  -9.59777832e-02],
                        [ -6.44836426e-02,  -6.45751953e-02],
                        [ -5.12695312e-02,  -5.13610840e-02],
                        [ -5.25207520e-02,  -5.24291992e-02],
                        [ -4.74853516e-02,  -4.73937988e-02],
                        [ -2.22778320e-02,  -2.23693848e-02],
                        [  2.16979980e-02,   2.15759277e-02],
                        [  7.64465332e-02,   7.65380859e-02],
                        [  1.34216309e-01,   1.34338379e-01],
                        [  1.85607910e-01,   1.85546875e-01],
                        [  2.16705322e-01,   2.16583252e-01],
                        [  2.12280273e-01,   2.12341309e-01],
                        [  1.63360596e-01,   1.63482666e-01],
                        [  7.18994141e-02,   7.18383789e-02],
                        [ -5.00793457e-02,  -5.02014160e-02],
                        [ -1.80999756e-01,  -1.80969238e-01],
                        [ -2.91259766e-01,  -2.91137695e-01],
                        [ -3.51318359e-01,  -3.51348877e-01],
                        [ -3.47351074e-01,  -3.47503662e-01],
                        [ -2.94036865e-01,  -2.94006348e-01],
                        [ -2.28485107e-01,  -2.28332520e-01],
                        [ -1.82952881e-01,  -1.82952881e-01],
                        [ -1.60339355e-01,  -1.60522461e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -9.66491699e-02,  -9.64965820e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [  3.60412598e-02,   3.59191895e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.33911133e-01,   1.34063721e-01],
                        [  1.54296875e-01,   1.54327393e-01],
                        [  1.56494141e-01,   1.56372070e-01],
                        [  1.49108887e-01,   1.49078369e-01],
                        [  1.45782471e-01,   1.45935059e-01],
                        [  1.47949219e-01,   1.48010254e-01],
                        [  1.41082764e-01,   1.40960693e-01],
                        [  1.18194580e-01,   1.18133545e-01],
                        [  9.25903320e-02,   9.27124023e-02],
                        [  7.55920410e-02,   7.56835938e-02],
                        [  5.96923828e-02,   5.96008301e-02],
                        [  3.71398926e-02,   3.70178223e-02],
                        [  1.76696777e-02,   1.77917480e-02],
                        [  1.38244629e-02,   1.39465332e-02],
                        [  2.12097168e-02,   2.10876465e-02],
                        [  2.71606445e-02,   2.70385742e-02],
                        [  2.94799805e-02,   2.96020508e-02],
                        [  3.55834961e-02,   3.56750488e-02],
                        [  4.81567383e-02,   4.80651855e-02],
                        [  6.21032715e-02,   6.19812012e-02],
                        [  7.32727051e-02,   7.33642578e-02],
                        [  8.21228027e-02,   8.22448730e-02],
                        [  8.80126953e-02,   8.79516602e-02],
                        [  8.75244141e-02,   8.74023438e-02],
                        [  7.97729492e-02,   7.98339844e-02],
                        [  6.72912598e-02,   6.74133301e-02],
                        [  5.19104004e-02,   5.18798828e-02],
                        [  3.43322754e-02,   3.42102051e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  8.85009766e-04,   1.03759766e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.11791992e-02,  -2.13317871e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -2.94189453e-02,  -2.92663574e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -2.72521973e-02,  -2.74047852e-02],
                        [ -1.67541504e-02,  -1.67846680e-02],
                        [ -5.49316406e-03,  -5.34057617e-03],
                        [ -1.83105469e-04,  -1.52587891e-04],
                        [  1.52587891e-04,   0.00000000e+00],
                        [  2.13623047e-03,   2.10571289e-03],
                        [  9.52148438e-03,   9.64355469e-03],
                        [  1.96533203e-02,   1.97143555e-02],
                        [  2.81372070e-02,   2.80151367e-02],
                        [  3.23486328e-02,   3.22875977e-02],
                        [  3.06396484e-02,   3.07617188e-02],
                        [  2.26135254e-02,   2.26745605e-02],
                        [  1.10168457e-02,   1.08947754e-02],
                        [  3.05175781e-04,   2.44140625e-04],
                        [ -5.55419922e-03,  -5.46264648e-03],
                        [ -5.95092773e-03,  -5.85937500e-03],
                        [ -5.34057617e-03,  -5.46264648e-03],
                        [ -8.60595703e-03,  -8.72802734e-03],
                        [ -1.47399902e-02,  -1.46484375e-02],
                        [ -2.05993652e-02,  -2.04772949e-02],
                        [ -2.64282227e-02,  -2.65197754e-02],
                        [ -3.19824219e-02,  -3.21044922e-02],
                        [ -3.39355469e-02,  -3.38439941e-02],
                        [ -3.12500000e-02,  -3.10974121e-02],
                        [ -2.71301270e-02,  -2.72216797e-02],
                        [ -2.42614746e-02,  -2.43835449e-02],
                        [ -2.18505859e-02,  -2.17895508e-02],
                        [ -1.98669434e-02,  -1.97143555e-02],
                        [ -2.09655762e-02,  -2.10266113e-02],
                        [ -2.42614746e-02,  -2.44140625e-02],
                        [ -2.18505859e-02,  -2.18200684e-02],
                        [ -8.11767578e-03,  -7.96508789e-03],
                        [  1.13220215e-02,   1.12915039e-02],
                        [  2.56652832e-02,   2.55126953e-02],
                        [  3.02734375e-02,   3.03039551e-02],
                        [  2.72521973e-02,   2.73742676e-02],
                        [  1.66015625e-02,   1.65710449e-02],
                        [ -7.93457031e-03,  -8.08715820e-03],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -9.86022949e-02,  -9.84497070e-02],
                        [ -1.34674072e-01,  -1.34643555e-01],
                        [ -1.41845703e-01,  -1.41967773e-01],
                        [ -1.19201660e-01,  -1.19262695e-01],
                        [ -8.32519531e-02,  -8.30993652e-02],
                        [ -5.43518066e-02,  -5.42907715e-02],
                        [ -3.80554199e-02,  -3.82080078e-02],
                        [ -2.39868164e-02,  -2.40173340e-02],
                        [ -3.96728516e-04,  -2.44140625e-04],
                        [  3.61633301e-02,   3.62243652e-02],
                        [  8.25500488e-02,   8.24279785e-02],
                        [  1.33514404e-01,   1.33422852e-01],
                        [  1.81976318e-01,   1.82098389e-01],
                        [  2.13989258e-01,   2.14080811e-01],
                        [  2.09197998e-01,   2.09075928e-01],
                        [  1.54266357e-01,   1.54144287e-01],
                        [  5.38024902e-02,   5.38940430e-02],
                        [ -7.41271973e-02,  -7.40051270e-02],
                        [ -2.05596924e-01,  -2.05688477e-01],
                        [ -3.11645508e-01,  -3.11767578e-01],
                        [ -3.61968994e-01,  -3.61877441e-01],
                        [ -3.42620850e-01,  -3.42498779e-01],
                        [ -2.75024414e-01,  -2.75115967e-01],
                        [ -2.05993652e-01,  -2.06115723e-01],
                        [ -1.68823242e-01,  -1.68731689e-01],
                        [ -1.56494141e-01,  -1.56372070e-01],
                        [ -1.37664795e-01,  -1.37695312e-01],
                        [ -9.16748047e-02,  -9.17968750e-02],
                        [ -2.31323242e-02,  -2.30712891e-02],
                        [  5.01098633e-02,   5.02319336e-02],
                        [  1.11297607e-01,   1.11267090e-01],
                        [  1.49047852e-01,   1.48895264e-01],
                        [  1.60308838e-01,   1.60339355e-01],
                        [  1.55426025e-01,   1.55578613e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.53411865e-01,   1.53259277e-01],
                        [  1.51306152e-01,   1.51275635e-01],
                        [  1.32354736e-01,   1.32507324e-01],
                        [  9.93957520e-02,   9.94262695e-02],
                        [  6.65283203e-02,   6.63757324e-02],
                        [  4.22973633e-02,   4.22668457e-02],
                        [  2.56042480e-02,   2.57568359e-02],
                        [  1.50756836e-02,   1.51062012e-02],
                        [  1.22070312e-02,   1.20544434e-02],
                        [  1.75170898e-02,   1.74560547e-02],
                        [  2.92358398e-02,   2.93884277e-02],
                        [  4.39147949e-02,   4.39758301e-02],
                        [  5.67321777e-02,   5.66101074e-02],
                        [  6.50024414e-02,   6.49414062e-02],
                        [  7.00683594e-02,   7.01904297e-02],
                        [  7.43103027e-02,   7.44018555e-02],
                        [  7.78198242e-02,   7.76977539e-02],
                        [  7.83386230e-02,   7.82470703e-02],
                        [  7.30895996e-02,   7.31811523e-02],
                        [  6.19506836e-02,   6.20422363e-02],
                        [  4.89501953e-02,   4.88586426e-02],
                        [  3.85742188e-02,   3.84826660e-02],
                        [  3.12500000e-02,   3.13415527e-02],
                        [  2.46276855e-02,   2.47497559e-02],
                        [  1.75781250e-02,   1.74865723e-02],
                        [  9.09423828e-03,   8.97216797e-03],
                        [ -2.41088867e-03,  -2.34985352e-03],
                        [ -1.46789551e-02,  -1.45568848e-02],
                        [ -2.25219727e-02,  -2.25830078e-02],
                        [ -2.50549316e-02,  -2.51770020e-02],
                        [ -2.38342285e-02,  -2.38037109e-02],
                        [ -1.69982910e-02,  -1.68762207e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  4.69970703e-03,   4.54711914e-03],
                        [  7.84301758e-03,   7.87353516e-03],
                        [  8.81958008e-03,   8.97216797e-03],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.58081055e-02,   1.56250000e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  1.69372559e-02,   1.70898438e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.92260742e-02,   1.90734863e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  9.73510742e-03,   9.85717773e-03],
                        [  1.28173828e-03,   1.31225586e-03],
                        [ -8.85009766e-03,  -9.00268555e-03],
                        [ -1.88598633e-02,  -1.89208984e-02],
                        [ -2.23999023e-02,  -2.22473145e-02],
                        [ -1.74255371e-02,  -1.73645020e-02],
                        [ -1.27868652e-02,  -1.29089355e-02],
                        [ -1.74865723e-02,  -1.75476074e-02],
                        [ -2.74353027e-02,  -2.73437500e-02],
                        [ -3.12500000e-02,  -3.11889648e-02],
                        [ -2.62756348e-02,  -2.63977051e-02],
                        [ -1.89514160e-02,  -1.90429688e-02],
                        [ -1.28784180e-02,  -1.27868652e-02],
                        [ -7.87353516e-03,  -7.75146484e-03],
                        [ -6.89697266e-03,  -6.98852539e-03],
                        [ -1.32751465e-02,  -1.33972168e-02],
                        [ -2.30102539e-02,  -2.29187012e-02],
                        [ -2.77404785e-02,  -2.76184082e-02],
                        [ -2.38952637e-02,  -2.40173340e-02],
                        [ -1.55944824e-02,  -1.57165527e-02],
                        [ -8.02612305e-03,  -7.90405273e-03],
                        [  1.52587891e-04,   3.05175781e-04],
                        [  1.33056641e-02,   1.32141113e-02],
                        [  2.70385742e-02,   2.69165039e-02],
                        [  2.77404785e-02,   2.78320312e-02],
                        [  6.25610352e-03,   6.37817383e-03],
                        [ -3.45153809e-02,  -3.45458984e-02],
                        [ -8.31909180e-02,  -8.33129883e-02],
                        [ -1.23382568e-01,  -1.23352051e-01],
                        [ -1.38641357e-01,  -1.38488770e-01],
                        [ -1.24176025e-01,  -1.24206543e-01],
                        [ -9.14916992e-02,  -9.16442871e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -2.76489258e-02,  -2.74963379e-02],
                        [ -6.19506836e-03,  -6.16455078e-03],
                        [  1.48315430e-02,   1.46789551e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  9.28039551e-02,   9.29565430e-02],
                        [  1.43249512e-01,   1.43280029e-01],
                        [  1.81610107e-01,   1.81457520e-01],
                        [  1.95861816e-01,   1.95831299e-01],
                        [  1.76239014e-01,   1.76361084e-01],
                        [  1.12426758e-01,   1.12487793e-01],
                        [  3.14331055e-03,   2.99072266e-03],
                        [ -1.33911133e-01,  -1.33972168e-01],
                        [ -2.65228271e-01,  -2.65075684e-01],
                        [ -3.54003906e-01,  -3.53912354e-01],
                        [ -3.76037598e-01,  -3.76159668e-01],
                        [ -3.35510254e-01,  -3.35571289e-01],
                        [ -2.65747070e-01,  -2.65625000e-01],
                        [ -2.05596924e-01,  -2.05535889e-01],
                        [ -1.70440674e-01,  -1.70532227e-01],
                        [ -1.45385742e-01,  -1.45477295e-01],
                        [ -1.05590820e-01,  -1.05499268e-01],
                        [ -4.15649414e-02,  -4.14428711e-02],
                        [  3.48510742e-02,   3.47595215e-02],
                        [  1.03698730e-01,   1.03576660e-01],
                        [  1.48712158e-01,   1.48803711e-01],
                        [  1.63848877e-01,   1.63970947e-01],
                        [  1.58294678e-01,   1.58203125e-01],
                        [  1.49658203e-01,   1.49505615e-01],
                        [  1.45233154e-01,   1.45324707e-01],
                        [  1.37908936e-01,   1.38031006e-01],
                        [  1.21185303e-01,   1.21124268e-01],
                        [  9.86022949e-02,   9.84802246e-02],
                        [  7.68737793e-02,   7.69042969e-02],
                        [  5.86853027e-02,   5.88378906e-02],
                        [  4.42504883e-02,   4.42199707e-02],
                        [  3.44848633e-02,   3.43627930e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.88085938e-02,   2.89611816e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.40576172e-02,   3.39355469e-02],
                        [  4.47692871e-02,   4.47387695e-02],
                        [  5.83801270e-02,   5.85327148e-02],
                        [  6.82373047e-02,   6.82678223e-02],
                        [  7.18994141e-02,   7.17468262e-02],
                        [  7.28759766e-02,   7.28149414e-02],
                        [  7.35473633e-02,   7.36999512e-02],
                        [  7.15026855e-02,   7.15637207e-02],
                        [  6.35070801e-02,   6.33544922e-02],
                        [  4.97741699e-02,   4.97131348e-02],
                        [  3.35693359e-02,   3.37219238e-02],
                        [  1.93786621e-02,   1.94396973e-02],
                        [  1.00708008e-02,   9.91821289e-03],
                        [  4.48608398e-03,   4.42504883e-03],
                        [  2.44140625e-04,   3.96728516e-04],
                        [ -2.44140625e-03,  -2.38037109e-03],
                        [ -3.63159180e-03,  -3.75366211e-03],
                        [ -5.06591797e-03,  -5.12695312e-03],
                        [ -6.40869141e-03,  -6.31713867e-03],
                        [ -5.55419922e-03,  -5.46264648e-03],
                        [ -3.47900391e-03,  -3.54003906e-03],
                        [ -2.96020508e-03,  -3.08227539e-03],
                        [ -3.38745117e-03,  -3.32641602e-03],
                        [ -2.28881836e-03,  -2.13623047e-03],
                        [  5.18798828e-04,   4.57763672e-04],
                        [  3.26538086e-03,   3.11279297e-03],
                        [  4.63867188e-03,   4.69970703e-03],
                        [  5.64575195e-03,   5.79833984e-03],
                        [  1.00097656e-02,   9.94873047e-03],
                        [  1.89514160e-02,   1.87988281e-02],
                        [  2.59399414e-02,   2.60009766e-02],
                        [  2.37426758e-02,   2.39257812e-02],
                        [  1.42211914e-02,   1.41601562e-02],
                        [  3.75366211e-03,   3.60107422e-03],
                        [ -5.00488281e-03,  -4.94384766e-03],
                        [ -1.11083984e-02,  -1.09558105e-02],
                        [ -1.29089355e-02,  -1.29394531e-02],
                        [ -1.14746094e-02,  -1.16271973e-02],
                        [ -9.91821289e-03,  -9.94873047e-03],
                        [ -9.61303711e-03,  -9.49096680e-03],
                        [ -1.19323730e-02,  -1.19018555e-02],
                        [ -1.87683105e-02,  -1.88903809e-02],
                        [ -2.67028809e-02,  -2.67333984e-02],
                        [ -2.81372070e-02,  -2.80151367e-02],
                        [ -2.22167969e-02,  -2.21557617e-02],
                        [ -1.70593262e-02,  -1.72119141e-02],
                        [ -1.82495117e-02,  -1.83105469e-02],
                        [ -2.30407715e-02,  -2.29187012e-02],
                        [ -2.83813477e-02,  -2.82897949e-02],
                        [ -3.45153809e-02,  -3.46374512e-02],
                        [ -3.98254395e-02,  -3.99169922e-02],
                        [ -3.99169922e-02,  -3.97949219e-02],
                        [ -3.32336426e-02,  -3.31420898e-02],
                        [ -2.11486816e-02,  -2.12707520e-02],
                        [ -3.72314453e-03,  -3.84521484e-03],
                        [  1.82495117e-02,   1.83715820e-02],
                        [  3.69262695e-02,   3.70178223e-02],
                        [  3.82080078e-02,   3.81164551e-02],
                        [  1.33666992e-02,   1.32751465e-02],
                        [ -3.17993164e-02,  -3.17077637e-02],
                        [ -8.06884766e-02,  -8.05664062e-02],
                        [ -1.16271973e-01,  -1.16333008e-01],
                        [ -1.26800537e-01,  -1.26953125e-01],
                        [ -1.10198975e-01,  -1.10107422e-01],
                        [ -7.79113770e-02,  -7.77893066e-02],
                        [ -4.81872559e-02,  -4.82482910e-02],
                        [ -2.81982422e-02,  -2.83508301e-02],
                        [ -8.33129883e-03,  -8.27026367e-03],
                        [  2.35595703e-02,   2.37121582e-02],
                        [  6.81152344e-02,   6.80847168e-02],
                        [  1.17614746e-01,   1.17492676e-01],
                        [  1.64794922e-01,   1.64794922e-01],
                        [  2.00561523e-01,   2.00683594e-01],
                        [  2.07641602e-01,   2.07641602e-01],
                        [  1.67755127e-01,   1.67602539e-01],
                        [  7.70263672e-02,   7.69958496e-02],
                        [ -5.01403809e-02,  -4.99877930e-02],
                        [ -1.89147949e-01,  -1.89117432e-01],
                        [ -3.09600830e-01,  -3.09753418e-01],
                        [ -3.79730225e-01,  -3.79760742e-01],
                        [ -3.82080078e-01,  -3.81927490e-01],
                        [ -3.28338623e-01,  -3.28308105e-01],
                        [ -2.53997803e-01,  -2.54150391e-01],
                        [ -1.92779541e-01,  -1.92840576e-01],
                        [ -1.52496338e-01,  -1.52343750e-01],
                        [ -1.15539551e-01,  -1.15478516e-01],
                        [ -6.38427734e-02,  -6.39953613e-02],
                        [  1.12915039e-03,   1.06811523e-03],
                        [  6.34765625e-02,   6.35986328e-02],
                        [  1.09161377e-01,   1.09252930e-01],
                        [  1.34307861e-01,   1.34185791e-01],
                        [  1.43188477e-01,   1.43096924e-01],
                        [  1.44439697e-01,   1.44561768e-01],
                        [  1.45721436e-01,   1.45812988e-01],
                        [  1.45812988e-01,   1.45721436e-01],
                        [  1.36444092e-01,   1.36352539e-01],
                        [  1.16058350e-01,   1.16149902e-01],
                        [  9.57031250e-02,   9.58251953e-02],
                        [  8.44726562e-02,   8.43811035e-02],
                        [  7.72399902e-02,   7.71179199e-02],
                        [  6.35986328e-02,   6.36596680e-02],
                        [  4.16870117e-02,   4.18090820e-02],
                        [  1.87683105e-02,   1.87072754e-02],
                        [  3.60107422e-03,   3.47900391e-03],
                        [  1.73950195e-03,   1.80053711e-03],
                        [  1.37023926e-02,   1.38549805e-02],
                        [  3.41491699e-02,   3.41186523e-02],
                        [  5.45349121e-02,   5.44128418e-02],
                        [  6.99157715e-02,   6.99462891e-02],
                        [  8.08105469e-02,   8.09631348e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  8.93859863e-02,   8.92333984e-02],
                        [  8.37402344e-02,   8.37402344e-02],
                        [  7.14721680e-02,   7.16552734e-02],
                        [  5.51452637e-02,   5.51452637e-02],
                        [  3.83300781e-02,   3.81469727e-02],
                        [  2.24914551e-02,   2.24609375e-02],
                        [  7.38525391e-03,   7.56835938e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -8.51440430e-03,  -8.66699219e-03],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -3.78417969e-03,  -3.66210938e-03],
                        [ -2.10571289e-03,  -2.04467773e-03],
                        [ -1.06811523e-03,  -1.19018555e-03],
                        [ -1.46484375e-03,  -1.52587891e-03],
                        [ -3.72314453e-03,  -3.60107422e-03],
                        [ -4.54711914e-03,  -4.45556641e-03],
                        [ -4.27246094e-04,  -5.49316406e-04],
                        [  6.77490234e-03,   6.68334961e-03],
                        [  1.20849609e-02,   1.21765137e-02],
                        [  1.27258301e-02,   1.28173828e-02],
                        [  9.24682617e-03,   9.15527344e-03],
                        [  4.85229492e-03,   4.73022461e-03],
                        [  4.39453125e-03,   4.51660156e-03],
                        [  9.64355469e-03,   9.79614258e-03],
                        [  1.62963867e-02,   1.62048340e-02],
                        [  1.86157227e-02,   1.84936523e-02],
                        [  1.61132812e-02,   1.62048340e-02],
                        [  1.24816895e-02,   1.26037598e-02],
                        [  9.73510742e-03,   9.67407227e-03],
                        [  6.65283203e-03,   6.53076172e-03],
                        [  3.20434570e-03,   3.26538086e-03],
                        [  1.52587891e-04,   3.05175781e-04],
                        [ -6.19506836e-03,  -6.22558594e-03],
                        [ -1.96228027e-02,  -1.97753906e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.47387695e-02,  -4.45861816e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.08020020e-02,  -4.09851074e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.34680176e-02,  -2.33154297e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -2.13012695e-02,  -2.14233398e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.85034180e-02,  -2.83813477e-02],
                        [ -2.42309570e-02,  -2.42004395e-02],
                        [ -1.50756836e-02,  -1.51977539e-02],
                        [ -3.72314453e-03,  -3.78417969e-03],
                        [  7.96508789e-03,   8.08715820e-03],
                        [  1.77612305e-02,   1.78222656e-02],
                        [  2.33764648e-02,   2.32543945e-02],
                        [  2.34985352e-02,   2.34375000e-02],
                        [  1.46484375e-02,   1.47705078e-02],
                        [ -9.94873047e-03,  -9.85717773e-03],
                        [ -5.04455566e-02,  -5.05676270e-02],
                        [ -9.22851562e-02,  -9.23767090e-02],
                        [ -1.16577148e-01,  -1.16455078e-01],
                        [ -1.16058350e-01,  -1.15936279e-01],
                        [ -9.56115723e-02,  -9.57336426e-02],
                        [ -6.52160645e-02,  -6.53381348e-02],
                        [ -3.67126465e-02,  -3.65600586e-02],
                        [ -1.56860352e-02,  -1.55639648e-02],
                        [  4.97436523e-03,   4.85229492e-03],
                        [  3.51867676e-02,   3.50952148e-02],
                        [  7.59887695e-02,   7.60803223e-02],
                        [  1.21337891e-01,   1.21429443e-01],
                        [  1.61956787e-01,   1.61895752e-01],
                        [  1.84356689e-01,   1.84234619e-01],
                        [  1.75109863e-01,   1.75170898e-01],
                        [  1.26220703e-01,   1.26342773e-01],
                        [  3.54919434e-02,   3.54614258e-02],
                        [ -8.85314941e-02,  -8.86535645e-02],
                        [ -2.20458984e-01,  -2.20428467e-01],
                        [ -3.25256348e-01,  -3.25103760e-01],
                        [ -3.74328613e-01,  -3.74328613e-01],
                        [ -3.59802246e-01,  -3.59985352e-01],
                        [ -3.02124023e-01,  -3.02124023e-01],
                        [ -2.40264893e-01,  -2.40081787e-01],
                        [ -2.00592041e-01,  -2.00592041e-01],
                        [ -1.74530029e-01,  -1.74713135e-01],
                        [ -1.34063721e-01,  -1.34063721e-01],
                        [ -6.41479492e-02,  -6.39953613e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.03057861e-01,   1.02935791e-01],
                        [  1.48406982e-01,   1.48376465e-01],
                        [  1.58325195e-01,   1.58447266e-01],
                        [  1.52709961e-01,   1.52740479e-01],
                        [  1.49871826e-01,   1.49780273e-01],
                        [  1.51641846e-01,   1.51580811e-01],
                        [  1.49749756e-01,   1.49871826e-01],
                        [  1.37023926e-01,   1.37115479e-01],
                        [  1.13342285e-01,   1.13220215e-01],
                        [  8.62731934e-02,   8.61816406e-02],
                        [  6.39038086e-02,   6.40258789e-02],
                        [  4.71191406e-02,   4.72106934e-02],
                        [  3.17382812e-02,   3.16162109e-02],
                        [  1.59301758e-02,   1.58386230e-02],
                        [  3.41796875e-03,   3.54003906e-03],
                        [  1.22070312e-03,   1.34277344e-03],
                        [  1.33361816e-02,   1.32141113e-02],
                        [  3.46984863e-02,   3.46069336e-02],
                        [  5.50842285e-02,   5.51757812e-02],
                        [  6.94580078e-02,   6.95495605e-02],
                        [  7.99255371e-02,   7.98339844e-02],
                        [  8.78601074e-02,   8.77380371e-02],
                        [  9.09118652e-02,   9.09729004e-02],
                        [  8.78906250e-02,   8.80126953e-02],
                        [  7.97729492e-02,   7.97119141e-02],
                        [  6.65588379e-02,   6.64062500e-02],
                        [  4.88586426e-02,   4.88891602e-02],
                        [  3.09143066e-02,   3.10668945e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  5.85937500e-03,   5.67626953e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.40686035e-02,  -1.39160156e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -1.81884766e-02,  -1.83410645e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.58386230e-02,  -1.56860352e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.26342773e-02,  -1.27563477e-02],
                        [ -1.23901367e-02,  -1.24206543e-02],
                        [ -9.09423828e-03,  -8.97216797e-03],
                        [  4.27246094e-03,   4.30297852e-03],
                        [  2.45056152e-02,   2.43835449e-02],
                        [  4.16259766e-02,   4.15649414e-02],
                        [  5.22460938e-02,   5.23681641e-02],
                        [  5.87463379e-02,   5.88073730e-02],
                        [  5.85327148e-02,   5.84106445e-02],
                        [  4.61120605e-02,   4.59899902e-02],
                        [  2.36816406e-02,   2.37731934e-02],
                        [  5.79833984e-04,   7.01904297e-04],
                        [ -1.56250000e-02,  -1.57165527e-02],
                        [ -2.27355957e-02,  -2.28271484e-02],
                        [ -2.24609375e-02,  -2.23693848e-02],
                        [ -1.95617676e-02,  -1.94396973e-02],
                        [ -2.00195312e-02,  -2.01110840e-02],
                        [ -2.70385742e-02,  -2.71606445e-02],
                        [ -3.75366211e-02,  -3.74450684e-02],
                        [ -4.40063477e-02,  -4.38842773e-02],
                        [ -4.26025391e-02,  -4.26635742e-02],
                        [ -3.66821289e-02,  -3.68041992e-02],
                        [ -3.02124023e-02,  -3.01513672e-02],
                        [ -2.22778320e-02,  -2.21557617e-02],
                        [ -1.25732422e-02,  -1.26037598e-02],
                        [ -6.86645508e-03,  -6.98852539e-03],
                        [ -1.03149414e-02,  -1.02844238e-02],
                        [ -1.81579590e-02,  -1.80358887e-02],
                        [ -2.06604004e-02,  -2.06909180e-02],
                        [ -1.63574219e-02,  -1.65100098e-02],
                        [ -1.16577148e-02,  -1.16271973e-02],
                        [ -8.27026367e-03,  -8.11767578e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  7.99560547e-03,   7.84301758e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.11486816e-02,   2.13012695e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  3.87573242e-03,   3.72314453e-03],
                        [ -2.86254883e-02,  -2.86560059e-02],
                        [ -7.26013184e-02,  -7.24487305e-02],
                        [ -1.09710693e-01,  -1.09649658e-01],
                        [ -1.23962402e-01,  -1.24114990e-01],
                        [ -1.12945557e-01,  -1.13006592e-01],
                        [ -8.46557617e-02,  -8.45336914e-02],
                        [ -5.15441895e-02,  -5.14526367e-02],
                        [ -2.52380371e-02,  -2.53601074e-02],
                        [ -7.84301758e-03,  -7.93457031e-03],
                        [  1.16577148e-02,   1.17492676e-02],
                        [  4.64782715e-02,   4.65698242e-02],
                        [  9.80834961e-02,   9.79919434e-02],
                        [  1.53411865e-01,   1.53320312e-01],
                        [  1.92993164e-01,   1.93084717e-01],
                        [  1.99737549e-01,   1.99798584e-01],
                        [  1.61499023e-01,   1.61407471e-01],
                        [  7.33337402e-02,   7.32421875e-02],
                        [ -5.48400879e-02,  -5.47180176e-02],
                        [ -1.94732666e-01,  -1.94610596e-01],
                        [ -3.09844971e-01,  -3.09936523e-01],
                        [ -3.70391846e-01,  -3.70544434e-01],
                        [ -3.65997314e-01,  -3.65936279e-01],
                        [ -3.13415527e-01,  -3.13262939e-01],
                        [ -2.49176025e-01,  -2.49237061e-01],
                        [ -2.03704834e-01,  -2.03826904e-01],
                        [ -1.77612305e-01,  -1.77612305e-01],
                        [ -1.46545410e-01,  -1.46423340e-01],
                        [ -8.94470215e-02,  -8.94470215e-02],
                        [ -1.01318359e-02,  -1.02539062e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  1.18865967e-01,   1.18988037e-01],
                        [  1.39739990e-01,   1.39709473e-01],
                        [  1.43981934e-01,   1.43859863e-01],
                        [  1.48864746e-01,   1.48895264e-01],
                        [  1.56829834e-01,   1.56982422e-01],
                        [  1.57104492e-01,   1.57104492e-01],
                        [  1.42852783e-01,   1.42700195e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  9.52758789e-02,   9.54284668e-02],
                        [  7.20214844e-02,   7.20825195e-02],
                        [  4.76379395e-02,   4.74853516e-02],
                        [  2.44750977e-02,   2.44140625e-02],
                        [  8.11767578e-03,   8.27026367e-03],
                        [  7.32421875e-04,   7.93457031e-04],
                        [  2.31933594e-03,   2.16674805e-03],
                        [  1.44958496e-02,   1.44042969e-02],
                        [  3.59191895e-02,   3.60717773e-02],
                        [  5.92041016e-02,   5.92651367e-02],
                        [  7.69348145e-02,   7.68127441e-02],
                        [  8.77380371e-02,   8.76464844e-02],
                        [  9.38110352e-02,   9.39636230e-02],
                        [  9.54284668e-02,   9.55200195e-02],
                        [  9.04541016e-02,   9.03015137e-02],
                        [  7.96508789e-02,   7.95288086e-02],
                        [  6.74743652e-02,   6.75964355e-02],
                        [  5.50231934e-02,   5.51757812e-02],
                        [  3.74755859e-02,   3.73840332e-02],
                        [  1.37939453e-02,   1.36413574e-02],
                        [ -6.80541992e-03,  -6.74438477e-03],
                        [ -1.76391602e-02,  -1.74865723e-02],
                        [ -2.50244141e-02,  -2.50549316e-02],
                        [ -3.57055664e-02,  -3.58581543e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.01916504e-02,  -4.00695801e-02],
                        [ -2.80761719e-02,  -2.81066895e-02],
                        [ -1.48620605e-02,  -1.50146484e-02],
                        [ -3.35693359e-03,  -3.32641602e-03],
                        [  6.56127930e-03,   6.71386719e-03],
                        [  1.44653320e-02,   1.44348145e-02],
                        [  2.21252441e-02,   2.19421387e-02],
                        [  3.32031250e-02,   3.32336426e-02],
                        [  4.77600098e-02,   4.79125977e-02],
                        [  5.90209961e-02,   5.90515137e-02],
                        [  5.98144531e-02,   5.96313477e-02],
                        [  5.06591797e-02,   5.06286621e-02],
                        [  3.75976562e-02,   3.77502441e-02],
                        [  2.23388672e-02,   2.23999023e-02],
                        [  3.44848633e-03,   3.32641602e-03],
                        [ -1.50146484e-02,  -1.50756836e-02],
                        [ -2.51464844e-02,  -2.50244141e-02],
                        [ -2.53906250e-02,  -2.53295898e-02],
                        [ -2.38342285e-02,  -2.39257812e-02],
                        [ -2.87780762e-02,  -2.88085938e-02],
                        [ -3.87878418e-02,  -3.86962891e-02],
                        [ -4.54406738e-02,  -4.54101562e-02],
                        [ -4.38537598e-02,  -4.39758301e-02],
                        [ -3.57360840e-02,  -3.57666016e-02],
                        [ -2.39257812e-02,  -2.38342285e-02],
                        [ -1.09558105e-02,  -1.08947754e-02],
                        [ -1.61743164e-03,  -1.73950195e-03],
                        [  3.05175781e-04,   2.13623047e-04],
                        [ -2.07519531e-03,  -1.98364258e-03],
                        [ -4.30297852e-03,  -4.18090820e-03],
                        [ -8.78906250e-03,  -8.85009766e-03],
                        [ -1.95312500e-02,  -1.96533203e-02],
                        [ -3.28369141e-02,  -3.28063965e-02],
                        [ -3.99169922e-02,  -3.97949219e-02],
                        [ -3.60107422e-02,  -3.60717773e-02],
                        [ -2.28881836e-02,  -2.30102539e-02],
                        [ -6.01196289e-03,  -5.95092773e-03],
                        [  9.61303711e-03,   9.73510742e-03],
                        [  2.14538574e-02,   2.13623047e-02],
                        [  2.67333984e-02,   2.66113281e-02],
                        [  1.96533203e-02,   1.97448730e-02],
                        [ -3.47900391e-03,  -3.35693359e-03],
                        [ -3.85131836e-02,  -3.85742188e-02],
                        [ -7.48596191e-02,  -7.49816895e-02],
                        [ -9.85717773e-02,  -9.85717773e-02],
                        [ -9.76562500e-02,  -9.75341797e-02],
                        [ -7.33337402e-02,  -7.33337402e-02],
                        [ -4.19311523e-02,  -4.20227051e-02],
                        [ -1.74865723e-02,  -1.75476074e-02],
                        [  1.52587891e-03,   1.61743164e-03],
                        [  2.44140625e-02,   2.44445801e-02],
                        [  5.58471680e-02,   5.57556152e-02],
                        [  9.44213867e-02,   9.43908691e-02],
                        [  1.33911133e-01,   1.34063721e-01],
                        [  1.62658691e-01,   1.62689209e-01],
                        [  1.65313721e-01,   1.65161133e-01],
                        [  1.27044678e-01,   1.27014160e-01],
                        [  4.08630371e-02,   4.10461426e-02],
                        [ -8.24584961e-02,  -8.23974609e-02],
                        [ -2.13378906e-01,  -2.13531494e-01],
                        [ -3.15704346e-01,  -3.15795898e-01],
                        [ -3.61206055e-01,  -3.61083984e-01],
                        [ -3.42010498e-01,  -3.41918945e-01],
                        [ -2.78503418e-01,  -2.78594971e-01],
                        [ -2.08801270e-01,  -2.08923340e-01],
                        [ -1.60217285e-01,  -1.60156250e-01],
                        [ -1.29791260e-01,  -1.29669189e-01],
                        [ -9.51538086e-02,  -9.52148438e-02],
                        [ -4.16564941e-02,  -4.17480469e-02],
                        [  2.22473145e-02,   2.23388672e-02],
                        [  7.32116699e-02,   7.33337402e-02],
                        [  9.65270996e-02,   9.64050293e-02],
                        [  9.98229980e-02,   9.96704102e-02],
                        [  1.01745605e-01,   1.01867676e-01],
                        [  1.10900879e-01,   1.11083984e-01],
                        [  1.22344971e-01,   1.22222900e-01],
                        [  1.29272461e-01,   1.29058838e-01],
                        [  1.29394531e-01,   1.29455566e-01],
                        [  1.22741699e-01,   1.22955322e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  9.31701660e-02,   9.29870605e-02],
                        [  7.40661621e-02,   7.40051270e-02],
                        [  5.53894043e-02,   5.55114746e-02],
                        [  3.88488770e-02,   3.88793945e-02],
                        [  2.64282227e-02,   2.63061523e-02],
                        [  2.14233398e-02,   2.13928223e-02],
                        [  2.38647461e-02,   2.39868164e-02],
                        [  2.92358398e-02,   2.92663574e-02],
                        [  3.59191895e-02,   3.57666016e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  6.17370605e-02,   6.19201660e-02],
                        [  7.08923340e-02,   7.09228516e-02],
                        [  7.02209473e-02,   7.00073242e-02],
                        [  6.52465820e-02,   6.51855469e-02],
                        [  6.20422363e-02,   6.22863770e-02],
                        [  6.08215332e-02,   6.09130859e-02],
                        [  5.94482422e-02,   5.92346191e-02],
                        [  5.45043945e-02,   5.43823242e-02],
                        [  4.14428711e-02,   4.15954590e-02],
                        [  2.22167969e-02,   2.22778320e-02],
                        [  7.14111328e-03,   7.01904297e-03],
                        [  1.70898438e-03,   1.67846680e-03],
                        [ -4.57763672e-04,  -3.35693359e-04],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -1.06506348e-02,  -1.07727051e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -6.10351562e-03,  -5.98144531e-03],
                        [  9.46044922e-04,   1.00708008e-03],
                        [  6.83593750e-03,   6.71386719e-03],
                        [  1.01623535e-02,   1.00402832e-02],
                        [  1.26342773e-02,   1.27258301e-02],
                        [  1.56860352e-02,   1.58691406e-02],
                        [  1.87683105e-02,   1.87072754e-02],
                        [  2.20336914e-02,   2.18505859e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.55126953e-02,   2.56652832e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.56347656e-03,   2.41088867e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -3.66210938e-04,  -2.74658203e-04],
                        [  3.54003906e-03,   3.50952148e-03],
                        [  3.05175781e-03,   2.96020508e-03],
                        [ -1.98364258e-03,  -1.92260742e-03],
                        [ -9.67407227e-03,  -9.55200195e-03],
                        [ -1.68151855e-02,  -1.68762207e-02],
                        [ -1.95312500e-02,  -1.96838379e-02],
                        [ -1.65405273e-02,  -1.64794922e-02],
                        [ -1.04370117e-02,  -1.02539062e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -4.63867188e-03,  -4.76074219e-03],
                        [ -7.75146484e-03,  -7.78198242e-03],
                        [ -1.06201172e-02,  -1.05285645e-02],
                        [ -1.11999512e-02,  -1.11083984e-02],
                        [ -1.34277344e-02,  -1.35192871e-02],
                        [ -2.10571289e-02,  -2.11181641e-02],
                        [ -3.31115723e-02,  -3.30505371e-02],
                        [ -4.81567383e-02,  -4.80651855e-02],
                        [ -6.29272461e-02,  -6.30187988e-02],
                        [ -6.83288574e-02,  -6.83898926e-02],
                        [ -5.73120117e-02,  -5.71594238e-02],
                        [ -3.40270996e-02,  -3.39965820e-02],
                        [ -7.35473633e-03,  -7.53784180e-03],
                        [  1.75170898e-02,   1.74560547e-02],
                        [  3.59191895e-02,   3.61328125e-02],
                        [  4.26025391e-02,   4.26635742e-02],
                        [  3.54003906e-02,   3.51867676e-02],
                        [  1.47094727e-02,   1.46179199e-02],
                        [ -1.62658691e-02,  -1.61132812e-02],
                        [ -4.79736328e-02,  -4.78515625e-02],
                        [ -6.67724609e-02,  -6.68945312e-02],
                        [ -6.52160645e-02,  -6.53076172e-02],
                        [ -4.80651855e-02,  -4.79736328e-02],
                        [ -2.56042480e-02,  -2.55126953e-02],
                        [ -3.05175781e-03,  -3.11279297e-03],
                        [  2.09960938e-02,   2.09350586e-02],
                        [  4.96215820e-02,   4.96826172e-02],
                        [  8.43200684e-02,   8.44116211e-02],
                        [  1.21795654e-01,   1.21734619e-01],
                        [  1.49383545e-01,   1.49261475e-01],
                        [  1.46820068e-01,   1.46881104e-01],
                        [  9.82055664e-02,   9.83581543e-02],
                        [  3.75366211e-03,   3.72314453e-03],
                        [ -1.19232178e-01,  -1.19384766e-01],
                        [ -2.42431641e-01,  -2.42431641e-01],
                        [ -3.33709717e-01,  -3.33587646e-01],
                        [ -3.69781494e-01,  -3.69781494e-01],
                        [ -3.50524902e-01,  -3.50646973e-01],
                        [ -2.98858643e-01,  -2.98889160e-01],
                        [ -2.41821289e-01,  -2.41729736e-01],
                        [ -1.91925049e-01,  -1.91894531e-01],
                        [ -1.43493652e-01,  -1.43585205e-01],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -6.13403320e-03,  -6.01196289e-03],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  1.26525879e-01,   1.26373291e-01],
                        [  1.45538330e-01,   1.45507812e-01],
                        [  1.38061523e-01,   1.38244629e-01],
                        [  1.25549316e-01,   1.25579834e-01],
                        [  1.23962402e-01,   1.23748779e-01],
                        [  1.30737305e-01,   1.30676270e-01],
                        [  1.30859375e-01,   1.31042480e-01],
                        [  1.17736816e-01,   1.17797852e-01],
                        [  9.97619629e-02,   9.96704102e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  7.07702637e-02,   7.08007812e-02],
                        [  5.56030273e-02,   5.55419922e-02],
                        [  4.15954590e-02,   4.15649414e-02],
                        [  3.13720703e-02,   3.14331055e-02],
                        [  2.73742676e-02,   2.74047852e-02],
                        [  3.23791504e-02,   3.23486328e-02],
                        [  4.34875488e-02,   4.34570312e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  5.78613281e-02,   5.78918457e-02],
                        [  6.14624023e-02,   6.15844727e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  6.93359375e-02,   6.91528320e-02],
                        [  7.21740723e-02,   7.21435547e-02],
                        [  7.16857910e-02,   7.18688965e-02],
                        [  6.50939941e-02,   6.51855469e-02],
                        [  5.23376465e-02,   5.21850586e-02],
                        [  3.58581543e-02,   3.57360840e-02],
                        [  1.88293457e-02,   1.89208984e-02],
                        [  4.42504883e-03,   4.51660156e-03],
                        [ -3.96728516e-03,  -4.02832031e-03],
                        [ -4.88281250e-03,  -4.94384766e-03],
                        [ -1.67846680e-03,  -1.61743164e-03],
                        [ -4.57763672e-04,  -4.27246094e-04],
                        [ -3.14331055e-03,  -3.23486328e-03],
                        [ -5.00488281e-03,  -4.97436523e-03],
                        [  2.44140625e-04,   3.35693359e-04],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  2.44750977e-02,   2.43530273e-02],
                        [  2.82897949e-02,   2.82287598e-02],
                        [  2.68554688e-02,   2.69165039e-02],
                        [  2.75878906e-02,   2.77099609e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  3.05175781e-02,   3.03344727e-02],
                        [  2.69470215e-02,   2.69165039e-02],
                        [  1.97143555e-02,   1.98974609e-02],
                        [  7.14111328e-03,   7.20214844e-03],
                        [ -8.75854492e-03,  -8.91113281e-03],
                        [ -2.24914551e-02,  -2.25219727e-02],
                        [ -3.11889648e-02,  -3.10974121e-02],
                        [ -3.40881348e-02,  -3.41186523e-02],
                        [ -2.92663574e-02,  -2.93884277e-02],
                        [ -1.62048340e-02,  -1.61437988e-02],
                        [  0.00000000e+00,   1.22070312e-04],
                        [  1.14440918e-02,   1.13525391e-02],
                        [  1.51977539e-02,   1.50146484e-02],
                        [  1.50146484e-02,   1.51062012e-02],
                        [  1.54113770e-02,   1.55639648e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.00097656e-02,   9.85717773e-03],
                        [ -3.50952148e-03,  -3.57055664e-03],
                        [ -1.96228027e-02,  -1.95312500e-02],
                        [ -3.25317383e-02,  -3.24096680e-02],
                        [ -4.27551270e-02,  -4.27856445e-02],
                        [ -5.11474609e-02,  -5.13000488e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -5.54199219e-02,  -5.53283691e-02],
                        [ -5.22766113e-02,  -5.23071289e-02],
                        [ -4.49218750e-02,  -4.49523926e-02],
                        [ -3.52172852e-02,  -3.50952148e-02],
                        [ -2.84118652e-02,  -2.83813477e-02],
                        [ -2.28576660e-02,  -2.30712891e-02],
                        [ -1.14746094e-02,  -1.15051270e-02],
                        [  5.58471680e-03,   5.82885742e-03],
                        [  2.12097168e-02,   2.12402344e-02],
                        [  3.11889648e-02,   3.09143066e-02],
                        [  3.30200195e-02,   3.29589844e-02],
                        [  2.16979980e-02,   2.19116211e-02],
                        [ -3.78417969e-03,  -3.72314453e-03],
                        [ -3.47290039e-02,  -3.48510742e-02],
                        [ -5.89904785e-02,  -5.90515137e-02],
                        [ -6.96105957e-02,  -6.95190430e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -4.84924316e-02,  -4.85534668e-02],
                        [ -2.41394043e-02,  -2.41088867e-02],
                        [  5.09643555e-03,   5.18798828e-03],
                        [  4.06799316e-02,   4.06494141e-02],
                        [  8.30688477e-02,   8.29162598e-02],
                        [  1.23901367e-01,   1.23870850e-01],
                        [  1.46789551e-01,   1.46972656e-01],
                        [  1.36505127e-01,   1.36535645e-01],
                        [  8.44726562e-02,   8.43200684e-02],
                        [ -1.09558105e-02,  -1.10473633e-02],
                        [ -1.38153076e-01,  -1.38061523e-01],
                        [ -2.64801025e-01,  -2.64709473e-01],
                        [ -3.49914551e-01,  -3.49945068e-01],
                        [ -3.69415283e-01,  -3.69506836e-01],
                        [ -3.29193115e-01,  -3.29223633e-01],
                        [ -2.58666992e-01,  -2.58605957e-01],
                        [ -1.92077637e-01,  -1.92077637e-01],
                        [ -1.45263672e-01,  -1.45294189e-01],
                        [ -1.07086182e-01,  -1.07055664e-01],
                        [ -5.73425293e-02,  -5.72814941e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [  7.06176758e-02,   7.05261230e-02],
                        [  1.11083984e-01,   1.11114502e-01],
                        [  1.22985840e-01,   1.23138428e-01],
                        [  1.16668701e-01,   1.16638184e-01],
                        [  1.08062744e-01,   1.07910156e-01],
                        [  1.05133057e-01,   1.05163574e-01],
                        [  1.05194092e-01,   1.05316162e-01],
                        [  1.04339600e-01,   1.04309082e-01],
                        [  1.02539062e-01,   1.02416992e-01],
                        [  9.75646973e-02,   9.76257324e-02],
                        [  8.50830078e-02,   8.51440430e-02],
                        [  6.64367676e-02,   6.63452148e-02],
                        [  4.80957031e-02,   4.80346680e-02],
                        [  3.31726074e-02,   3.33251953e-02],
                        [  2.24609375e-02,   2.25524902e-02],
                        [  2.05688477e-02,   2.04467773e-02],
                        [  2.95410156e-02,   2.94189453e-02],
                        [  4.10461426e-02,   4.11376953e-02],
                        [  4.64477539e-02,   4.66003418e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  5.74340820e-02,   5.73120117e-02],
                        [  7.02209473e-02,   7.01599121e-02],
                        [  8.03527832e-02,   8.04138184e-02],
                        [  8.26721191e-02,   8.27636719e-02],
                        [  7.65991211e-02,   7.65686035e-02],
                        [  6.43615723e-02,   6.42395020e-02],
                        [  4.98657227e-02,   4.98352051e-02],
                        [  3.68652344e-02,   3.69262695e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  2.18811035e-02,   2.18505859e-02],
                        [  1.56250000e-02,   1.56860352e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [ -4.02832031e-03,  -4.15039062e-03],
                        [ -1.15356445e-02,  -1.15661621e-02],
                        [ -1.68151855e-02,  -1.66931152e-02],
                        [ -1.92260742e-02,  -1.91345215e-02],
                        [ -1.46179199e-02,  -1.47399902e-02],
                        [ -2.41088867e-03,  -2.53295898e-03],
                        [  1.05285645e-02,   1.05590820e-02],
                        [  1.79443359e-02,   1.80664062e-02],
                        [  2.08129883e-02,   2.08740234e-02],
                        [  2.23693848e-02,   2.23083496e-02],
                        [  2.33459473e-02,   2.32238770e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  1.83105469e-02,   1.84020996e-02],
                        [  1.22375488e-02,   1.22680664e-02],
                        [  9.15527344e-03,   9.12475586e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  1.87988281e-02,   1.87683105e-02],
                        [  2.84729004e-02,   2.83813477e-02],
                        [  3.52478027e-02,   3.53088379e-02],
                        [  3.28979492e-02,   3.30200195e-02],
                        [  2.21862793e-02,   2.21252441e-02],
                        [  9.15527344e-03,   8.97216797e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -1.77307129e-02,  -1.75781250e-02],
                        [ -3.12500000e-02,  -3.12194824e-02],
                        [ -4.27246094e-02,  -4.28161621e-02],
                        [ -5.45654297e-02,  -5.45959473e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -7.68127441e-02,  -7.68127441e-02],
                        [ -7.46765137e-02,  -7.46154785e-02],
                        [ -6.05773926e-02,  -6.05163574e-02],
                        [ -4.02221680e-02,  -4.02526855e-02],
                        [ -2.00805664e-02,  -2.02026367e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  6.71386719e-03,   6.80541992e-03],
                        [  1.58996582e-02,   1.59606934e-02],
                        [  2.73742676e-02,   2.73437500e-02],
                        [  3.82995605e-02,   3.82385254e-02],
                        [  3.94897461e-02,   3.94592285e-02],
                        [  2.59094238e-02,   2.59399414e-02],
                        [  3.57055664e-03,   3.63159180e-03],
                        [ -1.68457031e-02,  -1.67846680e-02],
                        [ -3.01208496e-02,  -3.01818848e-02],
                        [ -3.72314453e-02,  -3.73535156e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.77294922e-02,  -4.76074219e-02],
                        [ -6.13403320e-02,  -6.12792969e-02],
                        [ -7.70874023e-02,  -7.71789551e-02],
                        [ -8.07495117e-02,  -8.08715820e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -2.74963379e-02,  -2.73742676e-02],
                        [  1.05590820e-02,   1.06201172e-02],
                        [  4.42504883e-02,   4.41894531e-02],
                        [  7.65686035e-02,   7.65075684e-02],
                        [  1.11602783e-01,   1.11572266e-01],
                        [  1.45111084e-01,   1.45172119e-01],
                        [  1.65863037e-01,   1.65924072e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.14410400e-01,   1.14349365e-01],
                        [  2.19726562e-02,   2.19116211e-02],
                        [ -1.06414795e-01,  -1.06353760e-01],
                        [ -2.41058350e-01,  -2.40966797e-01],
                        [ -3.44360352e-01,  -3.44329834e-01],
                        [ -3.87817383e-01,  -3.87878418e-01],
                        [ -3.67431641e-01,  -3.67492676e-01],
                        [ -3.06243896e-01,  -3.06274414e-01],
                        [ -2.39135742e-01,  -2.39074707e-01],
                        [ -1.87133789e-01,  -1.87042236e-01],
                        [ -1.42364502e-01,  -1.42364502e-01],
                        [ -8.21228027e-02,  -8.22143555e-02],
                        [ -2.10571289e-03,  -2.13623047e-03],
                        [  7.26928711e-02,   7.27233887e-02],
                        [  1.14379883e-01,   1.14440918e-01],
                        [  1.19384766e-01,   1.19476318e-01],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  9.60388184e-02,   9.59167480e-02],
                        [  9.95483398e-02,   9.95178223e-02],
                        [  1.08917236e-01,   1.09100342e-01],
                        [  1.10870361e-01,   1.10931396e-01],
                        [  1.02752686e-01,   1.02600098e-01],
                        [  9.23156738e-02,   9.22851562e-02],
                        [  8.59680176e-02,   8.60900879e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  7.91015625e-02,   7.90405273e-02],
                        [  6.79931641e-02,   6.80236816e-02],
                        [  4.84924316e-02,   4.85229492e-02],
                        [  2.62756348e-02,   2.62145996e-02],
                        [  9.09423828e-03,   9.03320312e-03],
                        [  1.31225586e-03,   1.37329102e-03],
                        [  5.85937500e-03,   5.95092773e-03],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  4.53186035e-02,   4.52270508e-02],
                        [  6.55212402e-02,   6.54602051e-02],
                        [  8.10546875e-02,   8.11157227e-02],
                        [  9.12475586e-02,   9.13391113e-02],
                        [  9.39025879e-02,   9.39025879e-02],
                        [  8.80432129e-02,   8.79211426e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  5.35583496e-02,   5.36193848e-02],
                        [  2.94799805e-02,   2.94494629e-02],
                        [  8.75854492e-03,   8.72802734e-03],
                        [ -3.35693359e-03,  -3.29589844e-03],
                        [ -5.55419922e-03,  -5.49316406e-03],
                        [  6.10351562e-04,   5.18798828e-04],
                        [  1.01623535e-02,   1.01013184e-02],
                        [  1.70593262e-02,   1.71813965e-02],
                        [  1.90124512e-02,   1.91345215e-02],
                        [  1.84020996e-02,   1.83105469e-02],
                        [  1.84326172e-02,   1.82800293e-02],
                        [  1.91040039e-02,   1.91345215e-02],
                        [  1.83715820e-02,   1.84936523e-02],
                        [  1.54113770e-02,   1.54724121e-02],
                        [  1.12915039e-02,   1.11999512e-02],
                        [  9.00268555e-03,   8.88061523e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.60827637e-02,   1.61743164e-02],
                        [  1.59301758e-02,   1.59912109e-02],
                        [  9.70458984e-03,   9.64355469e-03],
                        [  2.83813477e-03,   2.74658203e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  5.03540039e-03,   5.09643555e-03],
                        [  1.08642578e-02,   1.08947754e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.49536133e-02,   1.49841309e-02],
                        [  8.39233398e-03,   8.33129883e-03],
                        [ -1.95312500e-03,  -2.04467773e-03],
                        [ -1.02233887e-02,  -1.01623535e-02],
                        [ -1.45263672e-02,  -1.43737793e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -2.75573730e-02,  -2.77099609e-02],
                        [ -3.78417969e-02,  -3.79028320e-02],
                        [ -4.52880859e-02,  -4.51965332e-02],
                        [ -4.69360352e-02,  -4.68139648e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -2.85034180e-02,  -2.85949707e-02],
                        [ -1.23291016e-02,  -1.23901367e-02],
                        [  3.05175781e-05,   9.15527344e-05],
                        [  1.19018555e-03,   1.28173828e-03],
                        [ -7.99560547e-03,  -7.96508789e-03],
                        [ -1.83105469e-02,  -1.83715820e-02],
                        [ -2.23083496e-02,  -2.23693848e-02],
                        [ -1.88598633e-02,  -1.88293457e-02],
                        [ -1.02844238e-02,  -1.02233887e-02],
                        [  3.35693359e-04,   3.66210938e-04],
                        [  1.03149414e-02,   1.02844238e-02],
                        [  1.71813965e-02,   1.71203613e-02],
                        [  1.88293457e-02,   1.87988281e-02],
                        [  1.46789551e-02,   1.47094727e-02],
                        [  5.03540039e-03,   5.06591797e-03],
                        [ -1.19018555e-02,  -1.18713379e-02],
                        [ -3.72009277e-02,  -3.72314453e-02],
                        [ -6.35986328e-02,  -6.36901855e-02],
                        [ -7.75146484e-02,  -7.75146484e-02],
                        [ -7.13806152e-02,  -7.12890625e-02],
                        [ -4.78515625e-02,  -4.77905273e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [  2.52990723e-02,   2.52685547e-02],
                        [  6.78710938e-02,   6.77795410e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.56860352e-01,   1.57012939e-01],
                        [  1.79718018e-01,   1.79779053e-01],
                        [  1.63970947e-01,   1.63787842e-01],
                        [  9.64050293e-02,   9.62829590e-02],
                        [ -2.19726562e-02,  -2.18811035e-02],
                        [ -1.66839600e-01,  -1.66717529e-01],
                        [ -2.93212891e-01,  -2.93243408e-01],
                        [ -3.59069824e-01,  -3.59130859e-01],
                        [ -3.53668213e-01,  -3.53668213e-01],
                        [ -3.01910400e-01,  -3.01910400e-01],
                        [ -2.42797852e-01,  -2.42767334e-01],
                        [ -2.01141357e-01,  -2.01080322e-01],
                        [ -1.73339844e-01,  -1.73309326e-01],
                        [ -1.37939453e-01,  -1.38000488e-01],
                        [ -8.16955566e-02,  -8.17871094e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [  3.92150879e-02,   3.93371582e-02],
                        [  6.60095215e-02,   6.61010742e-02],
                        [  7.38220215e-02,   7.37304688e-02],
                        [  8.47778320e-02,   8.45947266e-02],
                        [  1.11419678e-01,   1.11450195e-01],
                        [  1.43096924e-01,   1.43280029e-01],
                        [  1.59790039e-01,   1.59851074e-01],
                        [  1.54754639e-01,   1.54602051e-01],
                        [  1.37390137e-01,   1.37298584e-01],
                        [  1.18469238e-01,   1.18530273e-01],
                        [  9.90600586e-02,   9.91516113e-02],
                        [  7.41577148e-02,   7.41882324e-02],
                        [  4.29687500e-02,   4.29077148e-02],
                        [  1.28479004e-02,   1.27868652e-02],
                        [ -4.79125977e-03,  -4.82177734e-03],
                        [ -2.99072266e-03,  -2.96020508e-03],
                        [  1.50146484e-02,   1.50756836e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  6.08215332e-02,   6.07604980e-02],
                        [  7.49206543e-02,   7.48901367e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  9.03320312e-02,   9.03625488e-02],
                        [  9.30480957e-02,   9.31091309e-02],
                        [  8.75854492e-02,   8.75549316e-02],
                        [  7.48291016e-02,   7.47375488e-02],
                        [  5.89904785e-02,   5.89599609e-02],
                        [  4.11682129e-02,   4.12597656e-02],
                        [  2.10876465e-02,   2.11181641e-02],
                        [  1.77001953e-03,   1.67846680e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -2.01110840e-02,  -2.00500488e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.27563477e-02,  -1.28173828e-02],
                        [  2.13623047e-03,   2.16674805e-03],
                        [  1.81579590e-02,   1.82495117e-02],
                        [  2.97241211e-02,   2.96936035e-02],
                        [  3.69873047e-02,   3.68652344e-02],
                        [  4.08020020e-02,   4.07714844e-02],
                        [  3.79943848e-02,   3.81164551e-02],
                        [  2.64892578e-02,   2.65502930e-02],
                        [  9.73510742e-03,   9.64355469e-03],
                        [ -5.52368164e-03,  -5.61523438e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.64794922e-02,  -1.63879395e-02],
                        [ -1.40991211e-02,  -1.40686035e-02],
                        [ -7.23266602e-03,  -7.29370117e-03],
                        [  2.71606445e-03,   2.65502930e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.54516602e-02,   2.54821777e-02],
                        [  3.10058594e-02,   3.10668945e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  2.33154297e-02,   2.32238770e-02],
                        [  6.98852539e-03,   6.92749023e-03],
                        [ -1.07421875e-02,  -1.06506348e-02],
                        [ -2.38952637e-02,  -2.37731934e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.56750488e-02,  -3.58276367e-02],
                        [ -3.60107422e-02,  -3.61022949e-02],
                        [ -3.20434570e-02,  -3.19213867e-02],
                        [ -2.67944336e-02,  -2.66113281e-02],
                        [ -2.27050781e-02,  -2.27355957e-02],
                        [ -1.88598633e-02,  -1.90429688e-02],
                        [ -1.53808594e-02,  -1.54418945e-02],
                        [ -1.61437988e-02,  -1.60217285e-02],
                        [ -2.26440430e-02,  -2.25524902e-02],
                        [ -2.92358398e-02,  -2.92968750e-02],
                        [ -2.92663574e-02,  -2.93273926e-02],
                        [ -2.25830078e-02,  -2.26440430e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -6.95800781e-03,  -6.89697266e-03],
                        [ -5.03540039e-03,  -4.97436523e-03],
                        [ -7.04956055e-03,  -7.11059570e-03],
                        [ -9.21630859e-03,  -9.27734375e-03],
                        [ -7.81250000e-03,  -7.78198242e-03],
                        [ -2.47192383e-03,  -2.41088867e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -4.65698242e-02,  -4.66003418e-02],
                        [ -6.12487793e-02,  -6.12792969e-02],
                        [ -5.43518066e-02,  -5.43212891e-02],
                        [ -2.58178711e-02,  -2.57263184e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  6.24389648e-02,   6.23474121e-02],
                        [  1.03942871e-01,   1.03881836e-01],
                        [  1.36291504e-01,   1.36322021e-01],
                        [  1.54296875e-01,   1.54357910e-01],
                        [  1.49169922e-01,   1.49200439e-01],
                        [  1.09008789e-01,   1.08947754e-01],
                        [  2.46582031e-02,   2.45666504e-02],
                        [ -1.00189209e-01,  -1.00219727e-01],
                        [ -2.42401123e-01,  -2.42340088e-01],
                        [ -3.62396240e-01,  -3.62304688e-01],
                        [ -4.20318604e-01,  -4.20318604e-01],
                        [ -4.01031494e-01,  -4.01184082e-01],
                        [ -3.26019287e-01,  -3.26110840e-01],
                        [ -2.38708496e-01,  -2.38586426e-01],
                        [ -1.72393799e-01,  -1.72210693e-01],
                        [ -1.26434326e-01,  -1.26495361e-01],
                        [ -7.65380859e-02,  -7.67517090e-02],
                        [ -1.01928711e-02,  -1.02233887e-02],
                        [  5.67932129e-02,   5.69763184e-02],
                        [  1.00341797e-01,   1.00402832e-01],
                        [  1.14105225e-01,   1.14044189e-01],
                        [  1.12731934e-01,   1.12670898e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  1.34368896e-01,   1.34429932e-01],
                        [  1.32690430e-01,   1.32751465e-01],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  9.93652344e-02,   9.92431641e-02],
                        [  8.39538574e-02,   8.38623047e-02],
                        [  6.92749023e-02,   6.94274902e-02],
                        [  4.66308594e-02,   4.67834473e-02],
                        [  1.55944824e-02,   1.55029297e-02],
                        [ -1.15966797e-02,  -1.17797852e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.58996582e-02,  -1.57775879e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.49023438e-02,   2.48718262e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  6.03027344e-02,   6.02416992e-02],
                        [  7.43103027e-02,   7.42492676e-02],
                        [  8.83483887e-02,   8.84399414e-02],
                        [  9.69543457e-02,   9.71069336e-02],
                        [  9.60388184e-02,   9.59472656e-02],
                        [  8.85314941e-02,   8.83483887e-02],
                        [  7.75756836e-02,   7.76367188e-02],
                        [  6.33239746e-02,   6.35375977e-02],
                        [  4.74548340e-02,   4.74243164e-02],
                        [  3.27148438e-02,   3.25622559e-02],
                        [  1.84326172e-02,   1.84631348e-02],
                        [  3.72314453e-03,   3.81469727e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -7.81250000e-03,  -7.87353516e-03],
                        [ -3.26538086e-03,  -3.23486328e-03],
                        [ -3.47900391e-03,  -3.44848633e-03],
                        [ -1.14746094e-02,  -1.15051270e-02],
                        [ -1.85852051e-02,  -1.86462402e-02],
                        [ -1.60217285e-02,  -1.59912109e-02],
                        [ -5.64575195e-03,  -5.58471680e-03],
                        [  2.56347656e-03,   2.59399414e-03],
                        [  2.07519531e-03,   2.01416016e-03],
                        [ -2.86865234e-03,  -2.92968750e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  8.14819336e-03,   8.20922852e-03],
                        [  2.32238770e-02,   2.32849121e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.94897461e-02,   3.94287109e-02],
                        [  3.78723145e-02,   3.78112793e-02],
                        [  3.20129395e-02,   3.21044922e-02],
                        [  2.12707520e-02,   2.13623047e-02],
                        [  6.16455078e-03,   6.16455078e-03],
                        [ -9.00268555e-03,  -9.09423828e-03],
                        [ -2.02026367e-02,  -2.02636719e-02],
                        [ -2.69165039e-02,  -2.68859863e-02],
                        [ -3.02429199e-02,  -3.01818848e-02],
                        [ -3.04870605e-02,  -3.04565430e-02],
                        [ -2.80761719e-02,  -2.81677246e-02],
                        [ -2.51464844e-02,  -2.52380371e-02],
                        [ -2.44445801e-02,  -2.44140625e-02],
                        [ -2.77709961e-02,  -2.76489258e-02],
                        [ -3.34167480e-02,  -3.33862305e-02],
                        [ -3.69262695e-02,  -3.70178223e-02],
                        [ -3.68041992e-02,  -3.68652344e-02],
                        [ -3.65600586e-02,  -3.65295410e-02],
                        [ -3.90930176e-02,  -3.90319824e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.60217285e-02,  -1.60522461e-02],
                        [ -4.63867188e-03,  -4.60815430e-03],
                        [  8.36181641e-03,   8.42285156e-03],
                        [  2.07519531e-02,   2.07214355e-02],
                        [  3.03039551e-02,   3.02429199e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.89404297e-02,   3.89709473e-02],
                        [  3.62854004e-02,   3.63159180e-02],
                        [  2.26745605e-02,   2.27050781e-02],
                        [ -6.43920898e-03,  -6.46972656e-03],
                        [ -4.50134277e-02,  -4.50744629e-02],
                        [ -7.52258301e-02,  -7.52868652e-02],
                        [ -8.01391602e-02,  -8.00781250e-02],
                        [ -5.60302734e-02,  -5.59082031e-02],
                        [ -1.30310059e-02,  -1.30615234e-02],
                        [  3.56140137e-02,   3.54309082e-02],
                        [  8.31604004e-02,   8.31298828e-02],
                        [  1.26312256e-01,   1.26495361e-01],
                        [  1.59027100e-01,   1.59118652e-01],
                        [  1.71844482e-01,   1.71691895e-01],
                        [  1.48651123e-01,   1.48559570e-01],
                        [  7.03430176e-02,   7.04345703e-02],
                        [ -6.28967285e-02,  -6.28662109e-02],
                        [ -2.17315674e-01,  -2.17376709e-01],
                        [ -3.43200684e-01,  -3.43170166e-01],
                        [ -4.04663086e-01,  -4.04571533e-01],
                        [ -3.94775391e-01,  -3.94897461e-01],
                        [ -3.34533691e-01,  -3.34686279e-01],
                        [ -2.60162354e-01,  -2.60040283e-01],
                        [ -1.98822021e-01,  -1.98638916e-01],
                        [ -1.49169922e-01,  -1.49230957e-01],
                        [ -9.22851562e-02,  -9.24987793e-02],
                        [ -2.30407715e-02,  -2.30712891e-02],
                        [  3.92456055e-02,   3.93981934e-02],
                        [  7.28454590e-02,   7.29675293e-02],
                        [  7.83386230e-02,   7.82775879e-02],
                        [  7.70568848e-02,   7.69348145e-02],
                        [  8.81958008e-02,   8.81652832e-02],
                        [  1.11785889e-01,   1.11816406e-01],
                        [  1.34277344e-01,   1.34368896e-01],
                        [  1.44805908e-01,   1.44866943e-01],
                        [  1.43157959e-01,   1.43096924e-01],
                        [  1.34887695e-01,   1.34735107e-01],
                        [  1.22863770e-01,   1.22802734e-01],
                        [  1.04125977e-01,   1.04309082e-01],
                        [  7.69653320e-02,   7.70874023e-02],
                        [  4.86450195e-02,   4.84924316e-02],
                        [  3.02429199e-02,   3.00598145e-02],
                        [  2.32238770e-02,   2.32849121e-02],
                        [  1.97143555e-02,   1.98669434e-02],
                        [  1.66015625e-02,   1.65710449e-02],
                        [  1.94396973e-02,   1.93176270e-02],
                        [  3.13415527e-02,   3.13720703e-02],
                        [  4.83703613e-02,   4.84313965e-02],
                        [  6.63452148e-02,   6.62841797e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  9.25292969e-02,   9.26208496e-02],
                        [  8.92333984e-02,   8.92639160e-02],
                        [  7.17163086e-02,   7.16247559e-02],
                        [  4.61730957e-02,   4.60815430e-02],
                        [  2.37121582e-02,   2.37731934e-02],
                        [  1.37023926e-02,   1.38244629e-02],
                        [  1.57775879e-02,   1.58081055e-02],
                        [  2.10571289e-02,   2.09960938e-02],
                        [  2.14538574e-02,   2.13623047e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  5.27954102e-03,   5.37109375e-03],
                        [ -2.96020508e-03,  -2.86865234e-03],
                        [ -5.03540039e-03,  -5.09643555e-03],
                        [  1.92260742e-03,   1.73950195e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.04565430e-02,   3.06396484e-02],
                        [  3.58886719e-02,   3.59802246e-02],
                        [  3.08532715e-02,   3.07617188e-02],
                        [  1.93176270e-02,   1.92260742e-02],
                        [  6.74438477e-03,   6.77490234e-03],
                        [ -1.00708008e-03,  -9.46044922e-04],
                        [ -8.23974609e-04,  -7.62939453e-04],
                        [  3.78417969e-03,   3.81469727e-03],
                        [  6.62231445e-03,   6.56127930e-03],
                        [  7.93457031e-03,   7.84301758e-03],
                        [  1.27258301e-02,   1.27563477e-02],
                        [  2.21557617e-02,   2.23083496e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  4.48303223e-02,   4.47082520e-02],
                        [  5.22460938e-02,   5.22155762e-02],
                        [  5.01708984e-02,   5.02319336e-02],
                        [  3.59497070e-02,   3.59802246e-02],
                        [  1.34582520e-02,   1.34887695e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -2.70080566e-02,  -2.70690918e-02],
                        [ -3.53088379e-02,  -3.54003906e-02],
                        [ -3.78723145e-02,  -3.78112793e-02],
                        [ -4.20227051e-02,  -4.19006348e-02],
                        [ -5.04455566e-02,  -5.04760742e-02],
                        [ -5.93872070e-02,  -5.95092773e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -7.55615234e-02,  -7.54699707e-02],
                        [ -8.36486816e-02,  -8.36181641e-02],
                        [ -8.57849121e-02,  -8.58154297e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -6.36596680e-02,  -6.36291504e-02],
                        [ -4.67834473e-02,  -4.68139648e-02],
                        [ -3.08227539e-02,  -3.08532715e-02],
                        [ -1.46789551e-02,  -1.46484375e-02],
                        [  3.87573242e-03,   3.93676758e-03],
                        [  2.56042480e-02,   2.55432129e-02],
                        [  4.92248535e-02,   4.91333008e-02],
                        [  7.11669922e-02,   7.11975098e-02],
                        [  8.66699219e-02,   8.67614746e-02],
                        [  9.24377441e-02,   9.24072266e-02],
                        [  8.52355957e-02,   8.52050781e-02],
                        [  6.00280762e-02,   6.00891113e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [ -3.00292969e-02,  -3.01818848e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -8.00476074e-02,  -7.98645020e-02],
                        [ -7.41271973e-02,  -7.40966797e-02],
                        [ -5.07812500e-02,  -5.10253906e-02],
                        [ -1.48925781e-02,  -1.50146484e-02],
                        [  2.34985352e-02,   2.37121582e-02],
                        [  5.27954102e-02,   5.29785156e-02],
                        [  6.50634766e-02,   6.49414062e-02],
                        [  5.11474609e-02,   5.09643555e-02],
                        [ -7.62939453e-04,  -7.01904297e-04],
                        [ -9.07592773e-02,  -9.06066895e-02],
                        [ -1.94366455e-01,  -1.94335938e-01],
                        [ -2.71911621e-01,  -2.71942139e-01],
                        [ -2.94677734e-01,  -2.94677734e-01],
                        [ -2.63916016e-01,  -2.63977051e-01],
                        [ -2.07336426e-01,  -2.07366943e-01],
                        [ -1.56707764e-01,  -1.56616211e-01],
                        [ -1.24847412e-01,  -1.24725342e-01],
                        [ -9.93041992e-02,  -9.93957520e-02],
                        [ -6.10656738e-02,  -6.12487793e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [  3.59191895e-02,   3.60717773e-02],
                        [  5.55114746e-02,   5.55725098e-02],
                        [  5.04150391e-02,   5.03234863e-02],
                        [  3.98864746e-02,   3.97644043e-02],
                        [  4.12292480e-02,   4.12597656e-02],
                        [  5.39855957e-02,   5.41076660e-02],
                        [  6.61315918e-02,   6.61621094e-02],
                        [  7.08312988e-02,   7.07702637e-02],
                        [  7.07702637e-02,   7.07397461e-02],
                        [  7.05871582e-02,   7.06176758e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  7.05871582e-02,   7.06176758e-02],
                        [  6.08825684e-02,   6.09130859e-02],
                        [  4.89807129e-02,   4.88891602e-02],
                        [  4.29382324e-02,   4.28771973e-02],
                        [  4.71191406e-02,   4.71496582e-02],
                        [  5.98754883e-02,   5.99670410e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  9.32312012e-02,   9.31701660e-02],
                        [  1.05560303e-01,   1.05529785e-01],
                        [  1.09802246e-01,   1.09832764e-01],
                        [  1.02081299e-01,   1.02111816e-01],
                        [  8.06579590e-02,   8.06884766e-02],
                        [  4.86145020e-02,   4.86450195e-02],
                        [  1.43737793e-02,   1.43432617e-02],
                        [ -1.03149414e-02,  -1.03759766e-02],
                        [ -1.66320801e-02,  -1.66015625e-02],
                        [ -6.13403320e-03,  -5.98144531e-03],
                        [  1.03454590e-02,   1.04370117e-02],
                        [  2.36816406e-02,   2.35900879e-02],
                        [  3.29589844e-02,   3.28369141e-02],
                        [  3.95507812e-02,   3.95812988e-02],
                        [  4.17175293e-02,   4.18395996e-02],
                        [  3.72924805e-02,   3.73535156e-02],
                        [  2.70080566e-02,   2.69165039e-02],
                        [  1.38854980e-02,   1.37634277e-02],
                        [  1.61743164e-03,   1.55639648e-03],
                        [ -8.11767578e-03,  -7.99560547e-03],
                        [ -1.56860352e-02,  -1.55029297e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -1.74255371e-02,  -1.76696777e-02],
                        [ -4.94384766e-03,  -5.03540039e-03],
                        [  1.01318359e-02,   1.03454590e-02],
                        [  1.79748535e-02,   1.81579590e-02],
                        [  1.82800293e-02,   1.81579590e-02],
                        [  1.78222656e-02,   1.76391602e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.70593262e-02,   1.72119141e-02],
                        [  9.42993164e-03,   9.49096680e-03],
                        [ -3.66210938e-04,  -3.96728516e-04],
                        [ -6.46972656e-03,  -6.53076172e-03],
                        [ -5.95092773e-03,  -6.04248047e-03],
                        [  3.05175781e-05,   6.10351562e-05],
                        [  7.04956055e-03,   7.14111328e-03],
                        [  1.05285645e-02,   1.05895996e-02],
                        [  1.01623535e-02,   1.01013184e-02],
                        [  8.17871094e-03,   8.08715820e-03],
                        [  4.73022461e-03,   4.76074219e-03],
                        [ -3.20434570e-03,  -3.11279297e-03],
                        [ -1.74865723e-02,  -1.74560547e-02],
                        [ -3.36303711e-02,  -3.36914062e-02],
                        [ -4.38842773e-02,  -4.39758301e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -4.15344238e-02,  -4.14733887e-02],
                        [ -4.00085449e-02,  -3.99780273e-02],
                        [ -4.42810059e-02,  -4.43420410e-02],
                        [ -5.23376465e-02,  -5.23681641e-02],
                        [ -5.97839355e-02,  -5.97229004e-02],
                        [ -6.16760254e-02,  -6.16455078e-02],
                        [ -5.23376465e-02,  -5.23681641e-02],
                        [ -3.07922363e-02,  -3.07617188e-02],
                        [ -5.37109375e-03,  -5.31005859e-03],
                        [  1.30310059e-02,   1.30004883e-02],
                        [  2.15454102e-02,   2.14843750e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  2.70690918e-02,   2.71301270e-02],
                        [  3.12805176e-02,   3.13110352e-02],
                        [  3.44543457e-02,   3.44238281e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [ -1.05895996e-02,  -1.06506348e-02],
                        [ -2.46582031e-02,  -2.45971680e-02],
                        [ -2.15454102e-02,  -2.14233398e-02],
                        [ -2.74658203e-04,  -3.05175781e-04],
                        [  3.39660645e-02,   3.38134766e-02],
                        [  7.14416504e-02,   7.13806152e-02],
                        [  9.73510742e-02,   9.75036621e-02],
                        [  9.92126465e-02,   9.93652344e-02],
                        [  7.48291016e-02,   7.47070312e-02],
                        [  2.60009766e-02,   2.58178711e-02],
                        [ -4.93164062e-02,  -4.92858887e-02],
                        [ -1.49444580e-01,  -1.49291992e-01],
                        [ -2.54302979e-01,  -2.54272461e-01],
                        [ -3.27117920e-01,  -3.27209473e-01],
                        [ -3.38684082e-01,  -3.38745117e-01],
                        [ -2.91656494e-01,  -2.91625977e-01],
                        [ -2.19116211e-01,  -2.19116211e-01],
                        [ -1.58966064e-01,  -1.58935547e-01],
                        [ -1.26312256e-01,  -1.26251221e-01],
                        [ -1.06323242e-01,  -1.06384277e-01],
                        [ -7.36999512e-02,  -7.38220215e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  2.72216797e-02,   2.73742676e-02],
                        [  4.88281250e-02,   4.88891602e-02],
                        [  4.26330566e-02,   4.24804688e-02],
                        [  3.26843262e-02,   3.25622559e-02],
                        [  4.08630371e-02,   4.09545898e-02],
                        [  6.72302246e-02,   6.73522949e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  1.12976074e-01,   1.12884521e-01],
                        [  1.16729736e-01,   1.16699219e-01],
                        [  1.11999512e-01,   1.12091064e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  9.38720703e-02,   9.38415527e-02],
                        [  8.03527832e-02,   8.03833008e-02],
                        [  6.43615723e-02,   6.43920898e-02],
                        [  5.11169434e-02,   5.10864258e-02],
                        [  4.55627441e-02,   4.55322266e-02],
                        [  4.78820801e-02,   4.78515625e-02],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  6.59179688e-02,   6.60095215e-02],
                        [  7.43103027e-02,   7.43408203e-02],
                        [  7.80029297e-02,   7.78503418e-02],
                        [  7.73620605e-02,   7.72705078e-02],
                        [  7.19909668e-02,   7.21130371e-02],
                        [  6.11877441e-02,   6.13098145e-02],
                        [  4.83703613e-02,   4.82788086e-02],
                        [  3.77197266e-02,   3.75671387e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.16979980e-02,   2.17895508e-02],
                        [  1.64489746e-02,   1.65405273e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  1.38549805e-02,   1.37329102e-02],
                        [  1.41906738e-02,   1.40686035e-02],
                        [  1.45263672e-02,   1.46179199e-02],
                        [  1.48315430e-02,   1.49536133e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  2.18505859e-02,   2.17590332e-02],
                        [  2.59094238e-02,   2.58483887e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.79541016e-02,   2.80456543e-02],
                        [  2.81677246e-02,   2.82897949e-02],
                        [  2.56042480e-02,   2.55432129e-02],
                        [  1.97753906e-02,   1.96228027e-02],
                        [  1.29394531e-02,   1.29089355e-02],
                        [  6.19506836e-03,   6.34765625e-03],
                        [  1.03759766e-03,   1.09863281e-03],
                        [  1.06811523e-03,   1.00708008e-03],
                        [  7.29370117e-03,   7.23266602e-03],
                        [  1.62658691e-02,   1.62353516e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.79235840e-02,   2.80151367e-02],
                        [  2.57873535e-02,   2.59094238e-02],
                        [  1.87072754e-02,   1.86157227e-02],
                        [  1.18713379e-02,   1.16882324e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  8.42285156e-03,   8.63647461e-03],
                        [  3.20434570e-03,   3.29589844e-03],
                        [ -6.19506836e-03,  -6.37817383e-03],
                        [ -1.60827637e-02,  -1.62353516e-02],
                        [ -2.42614746e-02,  -2.41394043e-02],
                        [ -3.06701660e-02,  -3.05175781e-02],
                        [ -3.54614258e-02,  -3.54919434e-02],
                        [ -3.74145508e-02,  -3.75366211e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -4.01611328e-02,  -4.01000977e-02],
                        [ -4.67529297e-02,  -4.67834473e-02],
                        [ -5.23986816e-02,  -5.24291992e-02],
                        [ -5.28564453e-02,  -5.27954102e-02],
                        [ -4.85229492e-02,  -4.84924316e-02],
                        [ -4.25109863e-02,  -4.26025391e-02],
                        [ -3.86352539e-02,  -3.86962891e-02],
                        [ -3.99475098e-02,  -3.98559570e-02],
                        [ -4.48608398e-02,  -4.47998047e-02],
                        [ -4.70581055e-02,  -4.71191406e-02],
                        [ -4.15954590e-02,  -4.16564941e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [  2.89916992e-03,   2.92968750e-03],
                        [  1.69982910e-02,   1.70593262e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.36914062e-02,   3.35998535e-02],
                        [  3.05480957e-02,   3.04870605e-02],
                        [  1.87072754e-02,   1.87988281e-02],
                        [  1.70898438e-03,   1.83105469e-03],
                        [ -1.39465332e-02,  -1.39770508e-02],
                        [ -2.31018066e-02,  -2.32543945e-02],
                        [ -2.44445801e-02,  -2.45056152e-02],
                        [ -1.87683105e-02,  -1.86767578e-02],
                        [ -8.85009766e-03,  -8.75854492e-03],
                        [  2.41088867e-03,   2.38037109e-03],
                        [  1.55639648e-02,   1.54418945e-02],
                        [  3.32641602e-02,   3.32336426e-02],
                        [  5.69458008e-02,   5.70373535e-02],
                        [  8.50524902e-02,   8.51135254e-02],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  1.30035400e-01,   1.29974365e-01],
                        [  1.30218506e-01,   1.30157471e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  4.55017090e-02,   4.55932617e-02],
                        [ -4.88281250e-02,  -4.87670898e-02],
                        [ -1.65008545e-01,  -1.65069580e-01],
                        [ -2.69683838e-01,  -2.69744873e-01],
                        [ -3.25500488e-01,  -3.25500488e-01],
                        [ -3.16955566e-01,  -3.16894531e-01],
                        [ -2.61932373e-01,  -2.61932373e-01],
                        [ -1.97692871e-01,  -1.97692871e-01],
                        [ -1.51733398e-01,  -1.51733398e-01],
                        [ -1.23748779e-01,  -1.23779297e-01],
                        [ -9.35974121e-02,  -9.36584473e-02],
                        [ -4.76379395e-02,  -4.76074219e-02],
                        [  3.99780273e-03,   4.08935547e-03],
                        [  3.80554199e-02,   3.80859375e-02],
                        [  4.50439453e-02,   4.49523926e-02],
                        [  3.98559570e-02,   3.97949219e-02],
                        [  4.38232422e-02,   4.38842773e-02],
                        [  6.26525879e-02,   6.27441406e-02],
                        [  8.77075195e-02,   8.76770020e-02],
                        [  1.09405518e-01,   1.09344482e-01],
                        [  1.21734619e-01,   1.21734619e-01],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.09497070e-01,   1.09527588e-01],
                        [  1.02874756e-01,   1.02935791e-01],
                        [  9.26513672e-02,   9.26208496e-02],
                        [  7.73010254e-02,   7.72094727e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  4.52880859e-02,   4.53796387e-02],
                        [  3.23791504e-02,   3.24401855e-02],
                        [  1.94702148e-02,   1.94091797e-02],
                        [  6.07299805e-03,   6.01196289e-03],
                        [ -3.50952148e-03,  -3.54003906e-03],
                        [ -3.66210938e-03,  -3.57055664e-03],
                        [  7.69042969e-03,   7.78198242e-03],
                        [  2.81372070e-02,   2.81066895e-02],
                        [  5.08728027e-02,   5.07812500e-02],
                        [  6.71081543e-02,   6.70776367e-02],
                        [  7.21740723e-02,   7.22351074e-02],
                        [  6.84509277e-02,   6.85424805e-02],
                        [  6.06689453e-02,   6.06994629e-02],
                        [  4.96215820e-02,   4.95300293e-02],
                        [  3.37219238e-02,   3.36303711e-02],
                        [  1.48315430e-02,   1.48620605e-02],
                        [ -1.80053711e-03,  -1.64794922e-03],
                        [ -1.24206543e-02,  -1.23596191e-02],
                        [ -1.75476074e-02,  -1.76696777e-02],
                        [ -1.99279785e-02,  -2.00500488e-02],
                        [ -2.09655762e-02,  -2.09045410e-02],
                        [ -2.01110840e-02,  -1.99890137e-02],
                        [ -1.59606934e-02,  -1.59301758e-02],
                        [ -7.23266602e-03,  -7.32421875e-03],
                        [  5.95092773e-03,   5.92041016e-03],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  4.03747559e-02,   4.04052734e-02],
                        [  5.39245605e-02,   5.39855957e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  5.25207520e-02,   5.24291992e-02],
                        [  4.25109863e-02,   4.24499512e-02],
                        [  3.43017578e-02,   3.43322754e-02],
                        [  2.89916992e-02,   2.90527344e-02],
                        [  2.28576660e-02,   2.28881836e-02],
                        [  1.30615234e-02,   1.30310059e-02],
                        [  1.06811523e-03,   1.00708008e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.64794922e-02,  -1.64184570e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -3.40881348e-02,  -3.41186523e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.66210938e-02,  -3.67126465e-02],
                        [ -3.38745117e-02,  -3.38439941e-02],
                        [ -3.57666016e-02,  -3.56140137e-02],
                        [ -3.97033691e-02,  -3.96728516e-02],
                        [ -3.75366211e-02,  -3.76892090e-02],
                        [ -2.47802734e-02,  -2.48718262e-02],
                        [ -7.50732422e-03,  -7.35473633e-03],
                        [  4.02832031e-03,   4.18090820e-03],
                        [  5.88989258e-03,   5.82885742e-03],
                        [  1.37329102e-03,   1.22070312e-03],
                        [ -4.33349609e-03,  -4.39453125e-03],
                        [ -8.48388672e-03,  -8.39233398e-03],
                        [ -1.16577148e-02,  -1.15356445e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -2.42919922e-02,  -2.44140625e-02],
                        [ -3.75366211e-02,  -3.75976562e-02],
                        [ -5.45043945e-02,  -5.44433594e-02],
                        [ -7.00683594e-02,  -6.99768066e-02],
                        [ -7.79113770e-02,  -7.78503418e-02],
                        [ -7.58056641e-02,  -7.58666992e-02],
                        [ -6.75048828e-02,  -6.76269531e-02],
                        [ -5.73730469e-02,  -5.74035645e-02],
                        [ -4.69665527e-02,  -4.67834473e-02],
                        [ -3.59497070e-02,  -3.58581543e-02],
                        [ -2.31933594e-02,  -2.33154297e-02],
                        [ -9.27734375e-03,  -9.39941406e-03],
                        [  2.71606445e-03,   2.74658203e-03],
                        [  1.29394531e-02,   1.30310059e-02],
                        [  2.45361328e-02,   2.45971680e-02],
                        [  3.65295410e-02,   3.64990234e-02],
                        [  4.44335938e-02,   4.43420410e-02],
                        [  4.57458496e-02,   4.57153320e-02],
                        [  4.02221680e-02,   4.02526855e-02],
                        [  2.84423828e-02,   2.84729004e-02],
                        [  1.35803223e-02,   1.36108398e-02],
                        [  7.01904297e-04,   6.71386719e-04],
                        [ -6.40869141e-03,  -6.46972656e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [  1.08947754e-02,   1.09863281e-02],
                        [  3.83911133e-02,   3.84216309e-02],
                        [  7.46459961e-02,   7.45239258e-02],
                        [  1.14562988e-01,   1.14532471e-01],
                        [  1.50634766e-01,   1.50726318e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.70867920e-01,   1.70806885e-01],
                        [  1.31927490e-01,   1.31988525e-01],
                        [  5.02624512e-02,   5.03540039e-02],
                        [ -6.31103516e-02,  -6.32019043e-02],
                        [ -1.81518555e-01,  -1.81579590e-01],
                        [ -2.74993896e-01,  -2.74932861e-01],
                        [ -3.20709229e-01,  -3.20648193e-01],
                        [ -3.12927246e-01,  -3.12927246e-01],
                        [ -2.70416260e-01,  -2.70446777e-01],
                        [ -2.22961426e-01,  -2.23022461e-01],
                        [ -1.85485840e-01,  -1.85485840e-01],
                        [ -1.51824951e-01,  -1.51763916e-01],
                        [ -1.09375000e-01,  -1.09344482e-01],
                        [ -5.52673340e-02,  -5.52978516e-02],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [  3.70483398e-02,   3.69873047e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  5.64575195e-02,   5.65795898e-02],
                        [  5.73120117e-02,   5.74035645e-02],
                        [  6.52160645e-02,   6.51245117e-02],
                        [  8.14819336e-02,   8.13293457e-02],
                        [  1.00677490e-01,   1.00708008e-01],
                        [  1.13983154e-01,   1.14135742e-01],
                        [  1.16149902e-01,   1.16180420e-01],
                        [  1.09008789e-01,   1.08856201e-01],
                        [  9.64050293e-02,   9.63439941e-02],
                        [  8.00476074e-02,   8.01086426e-02],
                        [  6.02722168e-02,   6.03637695e-02],
                        [  3.79943848e-02,   3.80249023e-02],
                        [  1.58386230e-02,   1.57775879e-02],
                        [ -2.01416016e-03,  -2.07519531e-03],
                        [ -1.22375488e-02,  -1.21765137e-02],
                        [ -1.29394531e-02,  -1.28784180e-02],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [  1.37023926e-02,   1.37329102e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  4.65698242e-02,   4.64782715e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  7.03735352e-02,   7.04650879e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  6.12182617e-02,   6.11267090e-02],
                        [  4.69360352e-02,   4.69360352e-02],
                        [  3.45153809e-02,   3.45458984e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.60522461e-02,   1.61132812e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  3.41796875e-03,   3.35693359e-03],
                        [  1.61743164e-03,   1.58691406e-03],
                        [  1.19018555e-03,   1.25122070e-03],
                        [ -1.55639648e-03,  -1.49536133e-03],
                        [ -6.56127930e-03,  -6.59179688e-03],
                        [ -1.16271973e-02,  -1.17187500e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.86157227e-02,  -1.85241699e-02],
                        [ -1.82495117e-02,  -1.82189941e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  2.62451172e-02,   2.62145996e-02],
                        [  4.29992676e-02,   4.29687500e-02],
                        [  4.98046875e-02,   4.98352051e-02],
                        [  4.74853516e-02,   4.75769043e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  4.19311523e-02,   4.18090820e-02],
                        [  4.19311523e-02,   4.18701172e-02],
                        [  3.73535156e-02,   3.74450684e-02],
                        [  2.65197754e-02,   2.66723633e-02],
                        [  1.31835938e-02,   1.31530762e-02],
                        [  3.38745117e-03,   3.20434570e-03],
                        [  2.19726562e-03,   2.16674805e-03],
                        [  9.55200195e-03,   9.67407227e-03],
                        [  1.81579590e-02,   1.82495117e-02],
                        [  1.96533203e-02,   1.95922852e-02],
                        [  1.07116699e-02,   1.06201172e-02],
                        [ -6.98852539e-03,  -7.01904297e-03],
                        [ -2.86560059e-02,  -2.86254883e-02],
                        [ -4.80957031e-02,  -4.80346680e-02],
                        [ -5.94482422e-02,  -5.93872070e-02],
                        [ -5.99975586e-02,  -6.00585938e-02],
                        [ -5.37109375e-02,  -5.38330078e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.51965332e-02,  -4.50134277e-02],
                        [ -4.23583984e-02,  -4.22668457e-02],
                        [ -3.74450684e-02,  -3.75671387e-02],
                        [ -3.17382812e-02,  -3.18298340e-02],
                        [ -2.54821777e-02,  -2.54211426e-02],
                        [ -1.70288086e-02,  -1.69372559e-02],
                        [ -7.08007812e-03,  -7.11059570e-03],
                        [  1.52587891e-03,   1.49536133e-03],
                        [  8.60595703e-03,   8.63647461e-03],
                        [  1.47399902e-02,   1.47094727e-02],
                        [  1.62048340e-02,   1.61132812e-02],
                        [  7.72094727e-03,   7.78198242e-03],
                        [ -1.01623535e-02,  -1.00402832e-02],
                        [ -2.95104980e-02,  -2.95715332e-02],
                        [ -4.22668457e-02,  -4.24499512e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -4.36401367e-02,  -4.34265137e-02],
                        [ -3.43933105e-02,  -3.43627930e-02],
                        [ -2.09960938e-02,  -2.11791992e-02],
                        [ -6.50024414e-03,  -6.53076172e-03],
                        [  7.62939453e-03,   7.75146484e-03],
                        [  2.09045410e-02,   2.09350586e-02],
                        [  3.13110352e-02,   3.12500000e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  3.32641602e-02,   3.33251953e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.92053223e-02,   2.91442871e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.67944336e-02,   2.69165039e-02],
                        [  3.00292969e-02,   3.00903320e-02],
                        [  3.79943848e-02,   3.78723145e-02],
                        [  4.83093262e-02,   4.82482910e-02],
                        [  6.03637695e-02,   6.04858398e-02],
                        [  7.69042969e-02,   7.69958496e-02],
                        [  9.88769531e-02,   9.88159180e-02],
                        [  1.21368408e-01,   1.21307373e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  9.63745117e-02,   9.64050293e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -1.74133301e-01,  -1.74133301e-01],
                        [ -2.71484375e-01,  -2.71545410e-01],
                        [ -3.34869385e-01,  -3.34899902e-01],
                        [ -3.48907471e-01,  -3.48815918e-01],
                        [ -3.17810059e-01,  -3.17749023e-01],
                        [ -2.64129639e-01,  -2.64221191e-01],
                        [ -2.11944580e-01,  -2.12066650e-01],
                        [ -1.67694092e-01,  -1.67663574e-01],
                        [ -1.19323730e-01,  -1.19171143e-01],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [  9.70458984e-03,   9.58251953e-03],
                        [  6.16149902e-02,   6.15539551e-02],
                        [  8.49304199e-02,   8.50219727e-02],
                        [  8.43505859e-02,   8.44116211e-02],
                        [  7.56225586e-02,   7.55615234e-02],
                        [  7.07702637e-02,   7.07092285e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  8.16955566e-02,   8.17260742e-02],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  6.22253418e-02,   6.22558594e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.49829102e-02,   4.49218750e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  2.95715332e-02,   2.96630859e-02],
                        [  2.70996094e-02,   2.71301270e-02],
                        [  2.91137695e-02,   2.90222168e-02],
                        [  3.15551758e-02,   3.14941406e-02],
                        [  3.14025879e-02,   3.14636230e-02],
                        [  3.01513672e-02,   3.01818848e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  2.99987793e-02,   2.99377441e-02],
                        [  3.06396484e-02,   3.05786133e-02],
                        [  3.21960449e-02,   3.22265625e-02],
                        [  3.34167480e-02,   3.34472656e-02],
                        [  3.16467285e-02,   3.16162109e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.53601074e-02,   2.53906250e-02],
                        [  2.46582031e-02,   2.45971680e-02],
                        [  2.14843750e-02,   2.14538574e-02],
                        [  1.44653320e-02,   1.45263672e-02],
                        [  7.08007812e-03,   7.14111328e-03],
                        [  2.41088867e-03,   2.31933594e-03],
                        [ -9.76562500e-04,  -1.06811523e-03],
                        [ -3.78417969e-03,  -3.75366211e-03],
                        [ -3.11279297e-03,  -2.99072266e-03],
                        [  1.80053711e-03,   1.77001953e-03],
                        [  6.53076172e-03,   6.46972656e-03],
                        [  8.66699219e-03,   8.69750977e-03],
                        [  1.16271973e-02,   1.16577148e-02],
                        [  1.73950195e-02,   1.73339844e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.73339844e-02,   1.74255371e-02],
                        [  1.21154785e-02,   1.20849609e-02],
                        [  1.09863281e-02,   1.08642578e-02],
                        [  1.28784180e-02,   1.28479004e-02],
                        [  1.45263672e-02,   1.46789551e-02],
                        [  1.64184570e-02,   1.65100098e-02],
                        [  1.85852051e-02,   1.84631348e-02],
                        [  1.73339844e-02,   1.71813965e-02],
                        [  1.15966797e-02,   1.16577148e-02],
                        [  5.98144531e-03,   6.13403320e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -6.40869141e-04,  -7.93457031e-04],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.25732422e-02,  -1.24816895e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.80969238e-02,  -1.81579590e-02],
                        [ -1.74865723e-02,  -1.74255371e-02],
                        [ -1.19628906e-02,  -1.19323730e-02],
                        [ -2.34985352e-03,  -2.47192383e-03],
                        [  6.04248047e-03,   5.98144531e-03],
                        [  9.76562500e-03,   9.88769531e-03],
                        [  9.94873047e-03,   1.00402832e-02],
                        [  7.23266602e-03,   7.14111328e-03],
                        [ -5.49316406e-04,  -6.71386719e-04],
                        [ -1.39160156e-02,  -1.38549805e-02],
                        [ -3.00292969e-02,  -2.99072266e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -5.85632324e-02,  -5.86547852e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -5.93872070e-02,  -5.93566895e-02],
                        [ -4.69970703e-02,  -4.70275879e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -1.04675293e-02,  -1.04370117e-02],
                        [  6.80541992e-03,   6.77490234e-03],
                        [  1.69677734e-02,   1.68762207e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  4.66918945e-03,   4.76074219e-03],
                        [ -9.82666016e-03,  -9.79614258e-03],
                        [ -2.12097168e-02,  -2.12402344e-02],
                        [ -2.67028809e-02,  -2.67639160e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.69982910e-02,  -1.69372559e-02],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -2.22778320e-03,  -2.25830078e-03],
                        [ -2.96020508e-03,  -2.99072266e-03],
                        [ -3.08227539e-03,  -3.05175781e-03],
                        [ -2.53295898e-03,  -2.47192383e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  2.77709961e-03,   2.74658203e-03],
                        [  6.04248047e-03,   6.01196289e-03],
                        [  6.34765625e-03,   6.31713867e-03],
                        [  5.18798828e-03,   5.21850586e-03],
                        [  6.98852539e-03,   7.08007812e-03],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  2.45666504e-02,   2.44445801e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  5.54504395e-02,   5.55419922e-02],
                        [  7.58666992e-02,   7.58972168e-02],
                        [  9.86633301e-02,   9.86022949e-02],
                        [  1.20300293e-01,   1.20269775e-01],
                        [  1.34857178e-01,   1.34887695e-01],
                        [  1.34246826e-01,   1.34277344e-01],
                        [  1.08703613e-01,   1.08734131e-01],
                        [  5.09643555e-02,   5.09338379e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -1.49627686e-01,  -1.49597168e-01],
                        [ -2.55279541e-01,  -2.55340576e-01],
                        [ -3.25439453e-01,  -3.25469971e-01],
                        [ -3.43139648e-01,  -3.43048096e-01],
                        [ -3.15887451e-01,  -3.15856934e-01],
                        [ -2.67272949e-01,  -2.67333984e-01],
                        [ -2.17376709e-01,  -2.17407227e-01],
                        [ -1.71508789e-01,  -1.71478271e-01],
                        [ -1.23809814e-01,  -1.23748779e-01],
                        [ -6.77490234e-02,  -6.77185059e-02],
                        [ -6.13403320e-03,  -6.19506836e-03],
                        [  4.79736328e-02,   4.79431152e-02],
                        [  8.21228027e-02,   8.21838379e-02],
                        [  9.57946777e-02,   9.58251953e-02],
                        [  9.98535156e-02,   9.98840332e-02],
                        [  1.04248047e-01,   1.04217529e-01],
                        [  1.08520508e-01,   1.08489990e-01],
                        [  1.07757568e-01,   1.07788086e-01],
                        [  1.00158691e-01,   1.00189209e-01],
                        [  8.86535645e-02,   8.85925293e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  6.68945312e-02,   6.69555664e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  3.92456055e-02,   3.91540527e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.35498047e-02,   1.36413574e-02],
                        [  1.26647949e-02,   1.26953125e-02],
                        [  1.99279785e-02,   1.98669434e-02],
                        [  2.82592773e-02,   2.81677246e-02],
                        [  3.23791504e-02,   3.24096680e-02],
                        [  3.37219238e-02,   3.38134766e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  4.46777344e-02,   4.46166992e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  5.83190918e-02,   5.83496094e-02],
                        [  5.99365234e-02,   5.99670410e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  2.76794434e-02,   2.76489258e-02],
                        [  1.39160156e-02,   1.38854980e-02],
                        [  4.79125977e-03,   4.82177734e-03],
                        [  1.34277344e-03,   1.43432617e-03],
                        [  1.64794922e-03,   1.61743164e-03],
                        [  1.43432617e-03,   1.37329102e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -6.40869141e-03,  -6.37817383e-03],
                        [ -8.02612305e-03,  -7.99560547e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  3.84521484e-03,   3.78417969e-03],
                        [  1.55944824e-02,   1.55639648e-02],
                        [  2.81066895e-02,   2.81677246e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.44543457e-02,   3.43933105e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  1.90124512e-02,   1.90429688e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  4.02832031e-03,   4.05883789e-03],
                        [  1.50451660e-02,   1.49841309e-02],
                        [  2.70080566e-02,   2.69775391e-02],
                        [  3.22265625e-02,   3.22875977e-02],
                        [  2.81982422e-02,   2.82287598e-02],
                        [  1.93786621e-02,   1.93176270e-02],
                        [  1.10778809e-02,   1.10168457e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -6.83593750e-03,  -6.77490234e-03],
                        [ -1.86767578e-02,  -1.86462402e-02],
                        [ -2.72521973e-02,  -2.72827148e-02],
                        [ -2.93884277e-02,  -2.94494629e-02],
                        [ -2.56652832e-02,  -2.56958008e-02],
                        [ -1.80053711e-02,  -1.79443359e-02],
                        [ -8.97216797e-03,  -8.88061523e-03],
                        [ -2.99072266e-03,  -3.05175781e-03],
                        [ -3.50952148e-03,  -3.66210938e-03],
                        [ -8.36181641e-03,  -8.33129883e-03],
                        [ -1.12915039e-02,  -1.11694336e-02],
                        [ -8.88061523e-03,  -8.85009766e-03],
                        [ -4.73022461e-03,  -4.79125977e-03],
                        [ -5.67626953e-03,  -5.73730469e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -2.44140625e-02,  -2.43225098e-02],
                        [ -3.46679688e-02,  -3.46069336e-02],
                        [ -4.24804688e-02,  -4.25720215e-02],
                        [ -4.59899902e-02,  -4.60510254e-02],
                        [ -4.41589355e-02,  -4.40979004e-02],
                        [ -3.85437012e-02,  -3.85131836e-02],
                        [ -3.20129395e-02,  -3.20434570e-02],
                        [ -2.66113281e-02,  -2.65808105e-02],
                        [ -2.23693848e-02,  -2.23999023e-02],
                        [ -1.76086426e-02,  -1.76391602e-02],
                        [ -1.11083984e-02,  -1.10778809e-02],
                        [ -3.50952148e-03,  -3.47900391e-03],
                        [  4.54711914e-03,   4.51660156e-03],
                        [  1.22070312e-02,   1.21765137e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  9.58251953e-03,   9.55200195e-03],
                        [  5.27954102e-03,   5.24902344e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  5.46264648e-03,   5.49316406e-03],
                        [  8.54492188e-03,   8.48388672e-03],
                        [  1.02539062e-02,   1.01928711e-02],
                        [  1.08947754e-02,   1.09863281e-02],
                        [  1.34887695e-02,   1.35803223e-02],
                        [  1.98059082e-02,   1.97143555e-02],
                        [  2.99987793e-02,   2.99072266e-02],
                        [  4.44030762e-02,   4.44641113e-02],
                        [  6.34460449e-02,   6.35375977e-02],
                        [  8.61511230e-02,   8.60900879e-02],
                        [  1.09039307e-01,   1.08947754e-01],
                        [  1.28814697e-01,   1.28875732e-01],
                        [  1.42120361e-01,   1.42181396e-01],
                        [  1.38244629e-01,   1.38214111e-01],
                        [  9.97009277e-02,   9.96398926e-02],
                        [  1.71508789e-02,   1.71813965e-02],
                        [ -9.73815918e-02,  -9.72900391e-02],
                        [ -2.14813232e-01,  -2.14843750e-01],
                        [ -3.03253174e-01,  -3.03405762e-01],
                        [ -3.40728760e-01,  -3.40698242e-01],
                        [ -3.25408936e-01,  -3.25225830e-01],
                        [ -2.78564453e-01,  -2.78594971e-01],
                        [ -2.29736328e-01,  -2.29949951e-01],
                        [ -1.94335938e-01,  -1.94305420e-01],
                        [ -1.65222168e-01,  -1.65069580e-01],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -6.88476562e-02,  -6.90002441e-02],
                        [ -4.21142578e-03,  -4.27246094e-03],
                        [  5.14831543e-02,   5.16052246e-02],
                        [  8.57238770e-02,   8.57543945e-02],
                        [  9.73815918e-02,   9.72900391e-02],
                        [  9.74121094e-02,   9.73815918e-02],
                        [  9.89685059e-02,   9.89990234e-02],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  9.55200195e-02,   9.55200195e-02],
                        [  8.00781250e-02,   8.00476074e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  4.08630371e-02,   4.08935547e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.22070312e-04,   9.15527344e-05],
                        [ -1.49230957e-02,  -1.48925781e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -4.91333008e-03,  -4.97436523e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  2.87475586e-02,   2.87780762e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.83703613e-02,   4.83398438e-02],
                        [  5.25207520e-02,   5.25512695e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  5.09338379e-02,   5.09033203e-02],
                        [  4.27856445e-02,   4.28161621e-02],
                        [  3.34472656e-02,   3.34777832e-02],
                        [  2.62756348e-02,   2.61840820e-02],
                        [  2.09655762e-02,   2.09045410e-02],
                        [  1.58081055e-02,   1.58996582e-02],
                        [  1.05895996e-02,   1.06201172e-02],
                        [  6.28662109e-03,   6.22558594e-03],
                        [  2.10571289e-03,   2.01416016e-03],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [ -8.17871094e-03,  -8.08715820e-03],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -2.06298828e-02,  -2.07214355e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.32543945e-02,  -2.31628418e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.34277344e-03,  -1.40380859e-03],
                        [  4.91333008e-03,   4.94384766e-03],
                        [  7.81250000e-03,   7.87353516e-03],
                        [  1.39465332e-02,   1.38854980e-02],
                        [  2.63671875e-02,   2.63366699e-02],
                        [  4.24804688e-02,   4.25415039e-02],
                        [  5.52673340e-02,   5.53283691e-02],
                        [  5.73730469e-02,   5.73425293e-02],
                        [  4.72106934e-02,   4.71191406e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  2.22473145e-02,   2.23388672e-02],
                        [  1.91345215e-02,   1.91040039e-02],
                        [  1.55639648e-02,   1.55029297e-02],
                        [  7.41577148e-03,   7.44628906e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -8.45336914e-03,  -8.48388672e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.20544434e-02,  -1.20239258e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.17797852e-02,  -1.18103027e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.47399902e-02,  -1.47094727e-02],
                        [ -1.56860352e-02,  -1.56555176e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -2.20336914e-02,  -2.20947266e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.30200195e-02,  -3.29589844e-02],
                        [ -3.30200195e-02,  -3.29895020e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.76794434e-02,  -2.77099609e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.93371582e-02,  -3.92761230e-02],
                        [ -4.31518555e-02,  -4.31213379e-02],
                        [ -3.78417969e-02,  -3.78723145e-02],
                        [ -2.60925293e-02,  -2.61535645e-02],
                        [ -1.45874023e-02,  -1.45568848e-02],
                        [ -6.77490234e-03,  -6.74438477e-03],
                        [ -1.89208984e-03,  -1.92260742e-03],
                        [  1.61743164e-03,   1.58691406e-03],
                        [  4.24194336e-03,   4.21142578e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  6.10351562e-05,   9.15527344e-05],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -2.09960938e-02,  -2.10266113e-02],
                        [ -2.71911621e-02,  -2.71606445e-02],
                        [ -2.60925293e-02,  -2.60620117e-02],
                        [ -2.09045410e-02,  -2.09350586e-02],
                        [ -1.62658691e-02,  -1.62963867e-02],
                        [ -1.39770508e-02,  -1.39465332e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  3.96728516e-04,   4.27246094e-04],
                        [  6.53076172e-03,   6.50024414e-03],
                        [  1.04675293e-02,   1.04370117e-02],
                        [  1.31835938e-02,   1.32141113e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  2.72521973e-02,   2.72216797e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  8.88977051e-02,   8.89282227e-02],
                        [  1.03973389e-01,   1.03942871e-01],
                        [  1.19293213e-01,   1.19232178e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  1.39007568e-01,   1.39038086e-01],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  2.39562988e-02,   2.39257812e-02],
                        [ -7.46765137e-02,  -7.47070312e-02],
                        [ -1.83959961e-01,  -1.83898926e-01],
                        [ -2.75604248e-01,  -2.75543213e-01],
                        [ -3.25592041e-01,  -3.25622559e-01],
                        [ -3.26995850e-01,  -3.27056885e-01],
                        [ -2.93548584e-01,  -2.93518066e-01],
                        [ -2.47375488e-01,  -2.47314453e-01],
                        [ -2.04315186e-01,  -2.04315186e-01],
                        [ -1.67205811e-01,  -1.67266846e-01],
                        [ -1.27258301e-01,  -1.27319336e-01],
                        [ -7.60803223e-02,  -7.60192871e-02],
                        [ -1.76086426e-02,  -1.75170898e-02],
                        [  3.37829590e-02,   3.37219238e-02],
                        [  6.53076172e-02,   6.52465820e-02],
                        [  7.71484375e-02,   7.72094727e-02],
                        [  8.07800293e-02,   8.08410645e-02],
                        [  8.66088867e-02,   8.65783691e-02],
                        [  9.59777832e-02,   9.59472656e-02],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.01196289e-01,   1.01226807e-01],
                        [  9.03930664e-02,   9.03930664e-02],
                        [  7.62329102e-02,   7.62023926e-02],
                        [  6.57043457e-02,   6.56738281e-02],
                        [  6.05163574e-02,   6.05468750e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.36511230e-02,   2.36206055e-02],
                        [  2.85339355e-02,   2.85949707e-02],
                        [  3.54919434e-02,   3.55224609e-02],
                        [  3.99780273e-02,   3.99169922e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  3.90319824e-02,   3.90625000e-02],
                        [  3.97338867e-02,   3.97033691e-02],
                        [  4.18090820e-02,   4.18395996e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.69873047e-02,   3.69262695e-02],
                        [  3.28979492e-02,   3.29284668e-02],
                        [  2.97241211e-02,   2.97546387e-02],
                        [  2.66113281e-02,   2.65502930e-02],
                        [  2.44140625e-02,   2.44445801e-02],
                        [  2.32238770e-02,   2.32849121e-02],
                        [  2.08740234e-02,   2.08129883e-02],
                        [  1.47705078e-02,   1.47399902e-02],
                        [  4.57763672e-03,   4.63867188e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.27868652e-02,  -1.28173828e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.05895996e-02,  -1.05590820e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  3.14636230e-02,   3.14331055e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.11889648e-02,   3.12500000e-02],
                        [  2.85034180e-02,   2.84729004e-02],
                        [  2.52380371e-02,   2.51770020e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.23388672e-02,   2.23999023e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  2.42919922e-02,   2.42309570e-02],
                        [  1.79443359e-02,   1.79138184e-02],
                        [  8.88061523e-03,   8.94165039e-03],
                        [  4.82177734e-03,   4.88281250e-03],
                        [  6.34765625e-03,   6.28662109e-03],
                        [  6.95800781e-03,   6.89697266e-03],
                        [  2.83813477e-03,   2.89916992e-03],
                        [ -4.79125977e-03,  -4.73022461e-03],
                        [ -1.35498047e-02,  -1.35803223e-02],
                        [ -2.12402344e-02,  -2.13012695e-02],
                        [ -2.58789062e-02,  -2.58178711e-02],
                        [ -2.58483887e-02,  -2.58178711e-02],
                        [ -2.14233398e-02,  -2.14843750e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -5.82885742e-03,  -5.76782227e-03],
                        [ -2.10571289e-03,  -2.13623047e-03],
                        [ -6.92749023e-03,  -7.01904297e-03],
                        [ -1.86157227e-02,  -1.85852051e-02],
                        [ -3.07006836e-02,  -3.06091309e-02],
                        [ -3.83911133e-02,  -3.84216309e-02],
                        [ -4.26330566e-02,  -4.27246094e-02],
                        [ -4.61120605e-02,  -4.60510254e-02],
                        [ -4.76379395e-02,  -4.75158691e-02],
                        [ -4.50439453e-02,  -4.50744629e-02],
                        [ -3.98254395e-02,  -3.99169922e-02],
                        [ -3.34777832e-02,  -3.35083008e-02],
                        [ -2.45056152e-02,  -2.43530273e-02],
                        [ -1.26342773e-02,  -1.25732422e-02],
                        [ -2.89916992e-03,  -3.02124023e-03],
                        [  6.10351562e-05,   0.00000000e+00],
                        [ -1.00708008e-03,  -8.85009766e-04],
                        [  1.22070312e-04,   1.83105469e-04],
                        [  4.39453125e-03,   4.27246094e-03],
                        [  7.47680664e-03,   7.41577148e-03],
                        [  6.68334961e-03,   6.77490234e-03],
                        [  3.35693359e-03,   3.38745117e-03],
                        [ -1.25122070e-03,  -1.31225586e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -8.88061523e-03,  -8.81958008e-03],
                        [ -5.98144531e-03,  -5.95092773e-03],
                        [ -1.52587891e-04,  -2.13623047e-04],
                        [  5.21850586e-03,   5.18798828e-03],
                        [  1.06811523e-02,   1.07421875e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.49023438e-02,   2.48413086e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.32336426e-02,   3.32641602e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  4.33959961e-02,   4.33654785e-02],
                        [  5.16357422e-02,   5.15747070e-02],
                        [  6.18591309e-02,   6.18896484e-02],
                        [  7.43408203e-02,   7.43713379e-02],
                        [  8.82263184e-02,   8.81958008e-02],
                        [  1.00982666e-01,   1.00952148e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.07910156e-01,  -1.07971191e-01],
                        [ -2.15332031e-01,  -2.15362549e-01],
                        [ -2.94799805e-01,  -2.94738770e-01],
                        [ -3.24157715e-01,  -3.24127197e-01],
                        [ -3.06762695e-01,  -3.06823730e-01],
                        [ -2.67303467e-01,  -2.67333984e-01],
                        [ -2.31262207e-01,  -2.31231689e-01],
                        [ -2.05810547e-01,  -2.05810547e-01],
                        [ -1.79565430e-01,  -1.79595947e-01],
                        [ -1.37359619e-01,  -1.37359619e-01],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -3.81469727e-03,  -3.78417969e-03],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  1.00128174e-01,   1.00097656e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.30889893e-01,   1.30889893e-01],
                        [  1.26037598e-01,   1.26068115e-01],
                        [  1.16638184e-01,   1.16668701e-01],
                        [  1.04034424e-01,   1.04003906e-01],
                        [  8.80737305e-02,   8.80126953e-02],
                        [  6.82067871e-02,   6.82373047e-02],
                        [  4.60205078e-02,   4.61120605e-02],
                        [  2.36511230e-02,   2.36206055e-02],
                        [  3.63159180e-03,   3.50952148e-03],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -1.62048340e-02,  -1.61132812e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.74658203e-03,  -2.80761719e-03],
                        [  5.46264648e-03,   5.43212891e-03],
                        [  1.29699707e-02,   1.30004883e-02],
                        [  2.41088867e-02,   2.42004395e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  4.86450195e-02,   4.84924316e-02],
                        [  5.42907715e-02,   5.43212891e-02],
                        [  5.71899414e-02,   5.73120117e-02],
                        [  5.90209961e-02,   5.89904785e-02],
                        [  5.74645996e-02,   5.73730469e-02],
                        [  5.07812500e-02,   5.08117676e-02],
                        [  4.14428711e-02,   4.15039062e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  2.77709961e-02,   2.76794434e-02],
                        [  2.30407715e-02,   2.30712891e-02],
                        [  1.84326172e-02,   1.85241699e-02],
                        [  1.29089355e-02,   1.28784180e-02],
                        [  4.21142578e-03,   4.11987305e-03],
                        [ -6.59179688e-03,  -6.50024414e-03],
                        [ -1.46179199e-02,  -1.45263672e-02],
                        [ -1.71813965e-02,  -1.72424316e-02],
                        [ -1.67541504e-02,  -1.68457031e-02],
                        [ -1.55334473e-02,  -1.55029297e-02],
                        [ -1.00708008e-02,  -9.94873047e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.13220215e-02,   1.11999512e-02],
                        [  1.49230957e-02,   1.48620605e-02],
                        [  1.62658691e-02,   1.63879395e-02],
                        [  2.10266113e-02,   2.10876465e-02],
                        [  2.86865234e-02,   2.85644531e-02],
                        [  3.37829590e-02,   3.36914062e-02],
                        [  3.22570801e-02,   3.23486328e-02],
                        [  2.60314941e-02,   2.60925293e-02],
                        [  1.93176270e-02,   1.92565918e-02],
                        [  1.49230957e-02,   1.48925781e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.48010254e-02,   1.48315430e-02],
                        [  1.76696777e-02,   1.77307129e-02],
                        [  2.09350586e-02,   2.09655762e-02],
                        [  2.15454102e-02,   2.14538574e-02],
                        [  1.77001953e-02,   1.76696777e-02],
                        [  9.82666016e-03,   9.91821289e-03],
                        [ -1.06811523e-03,  -1.00708008e-03],
                        [ -1.41296387e-02,  -1.41906738e-02],
                        [ -2.84729004e-02,  -2.85644531e-02],
                        [ -4.01306152e-02,  -4.00695801e-02],
                        [ -4.34265137e-02,  -4.33044434e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.41796875e-02,  -3.42712402e-02],
                        [ -3.18603516e-02,  -3.18908691e-02],
                        [ -2.96325684e-02,  -2.95410156e-02],
                        [ -2.55432129e-02,  -2.55126953e-02],
                        [ -2.27355957e-02,  -2.28271484e-02],
                        [ -2.49023438e-02,  -2.49328613e-02],
                        [ -2.97851562e-02,  -2.97241211e-02],
                        [ -3.15551758e-02,  -3.15246582e-02],
                        [ -2.73437500e-02,  -2.74353027e-02],
                        [ -1.87377930e-02,  -1.87988281e-02],
                        [ -9.64355469e-03,  -9.58251953e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -2.65502930e-03,  -2.77709961e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -1.40380859e-03,  -1.31225586e-03],
                        [  1.86157227e-03,   1.83105469e-03],
                        [  4.57763672e-04,   3.66210938e-04],
                        [ -9.61303711e-03,  -9.55200195e-03],
                        [ -2.31628418e-02,  -2.30407715e-02],
                        [ -3.25012207e-02,  -3.24707031e-02],
                        [ -3.56140137e-02,  -3.56750488e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.20031738e-02,  -2.18505859e-02],
                        [ -1.95312500e-03,  -1.80053711e-03],
                        [  1.97143555e-02,   1.96838379e-02],
                        [  3.30810547e-02,   3.29895020e-02],
                        [  3.55224609e-02,   3.56750488e-02],
                        [  3.13110352e-02,   3.14636230e-02],
                        [  2.57568359e-02,   2.56652832e-02],
                        [  2.20947266e-02,   2.20031738e-02],
                        [  2.08435059e-02,   2.09045410e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  3.00598145e-02,   2.99682617e-02],
                        [  4.17785645e-02,   4.16870117e-02],
                        [  5.73730469e-02,   5.72814941e-02],
                        [  7.63549805e-02,   7.62939453e-02],
                        [  9.57641602e-02,   9.57031250e-02],
                        [  1.11022949e-01,   1.10900879e-01],
                        [  1.18835449e-01,   1.18713379e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  9.44824219e-02,   9.44519043e-02],
                        [  4.32434082e-02,   4.31518555e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -1.47857666e-01,  -1.47766113e-01],
                        [ -2.46765137e-01,  -2.46734619e-01],
                        [ -3.08654785e-01,  -3.08624268e-01],
                        [ -3.20007324e-01,  -3.19885254e-01],
                        [ -2.90710449e-01,  -2.90557861e-01],
                        [ -2.44720459e-01,  -2.44567871e-01],
                        [ -2.04101562e-01,  -2.03979492e-01],
                        [ -1.75018311e-01,  -1.74926758e-01],
                        [ -1.45477295e-01,  -1.45355225e-01],
                        [ -1.00219727e-01,  -1.00067139e-01],
                        [ -3.88793945e-02,  -3.87878418e-02],
                        [  2.23388672e-02,   2.22778320e-02],
                        [  6.59790039e-02,   6.59484863e-02],
                        [  8.81652832e-02,   8.81958008e-02],
                        [  9.69543457e-02,   9.68933105e-02],
                        [  1.01196289e-01,   1.00952148e-01],
                        [  1.04492188e-01,   1.04278564e-01],
                        [  1.06231689e-01,   1.06201172e-01],
                        [  1.03363037e-01,   1.03210449e-01],
                        [  9.24987793e-02,   9.21325684e-02],
                        [  7.39440918e-02,   7.37609863e-02],
                        [  5.41076660e-02,   5.41076660e-02],
                        [  4.00085449e-02,   3.98864746e-02],
                        [  3.10363770e-02,   3.08837891e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.11694336e-02,   1.12609863e-02],
                        [  7.29370117e-03,   7.41577148e-03],
                        [  1.07421875e-02,   1.08642578e-02],
                        [  1.82800293e-02,   1.84020996e-02],
                        [  2.85034180e-02,   2.87475586e-02],
                        [  3.96423340e-02,   3.99780273e-02],
                        [  4.88891602e-02,   4.90722656e-02],
                        [  5.61828613e-02,   5.63354492e-02],
                        [  6.34460449e-02,   6.37512207e-02],
                        [  6.87561035e-02,   6.89697266e-02],
                        [  6.71081543e-02,   6.71386719e-02],
                        [  5.77392578e-02,   5.77697754e-02],
                        [  4.44641113e-02,   4.45251465e-02],
                        [  3.10363770e-02,   3.09448242e-02],
                        [  1.97753906e-02,   1.95922852e-02],
                        [  1.04064941e-02,   1.02233887e-02],
                        [  1.43432617e-03,   1.15966797e-03],
                        [ -6.01196289e-03,  -6.34765625e-03],
                        [ -9.70458984e-03,  -9.97924805e-03],
                        [ -8.81958008e-03,  -9.12475586e-03],
                        [ -5.09643555e-03,  -5.43212891e-03],
                        [ -2.38037109e-03,  -2.62451172e-03],
                        [ -2.19726562e-03,  -2.31933594e-03],
                        [ -3.29589844e-03,  -3.41796875e-03],
                        [ -4.85229492e-03,  -4.97436523e-03],
                        [ -4.79125977e-03,  -4.76074219e-03],
                        [  8.85009766e-04,   1.09863281e-03],
                        [  1.43737793e-02,   1.46179199e-02],
                        [  3.16467285e-02,   3.18298340e-02],
                        [  4.41894531e-02,   4.44946289e-02],
                        [  4.84313965e-02,   4.89196777e-02],
                        [  4.71496582e-02,   4.75158691e-02],
                        [  4.22363281e-02,   4.24499512e-02],
                        [  3.50646973e-02,   3.54003906e-02],
                        [  2.85644531e-02,   2.89001465e-02],
                        [  2.36816406e-02,   2.38952637e-02],
                        [  1.73339844e-02,   1.73950195e-02],
                        [  6.13403320e-03,   6.07299805e-03],
                        [ -6.01196289e-03,  -6.07299805e-03],
                        [ -1.19018555e-02,  -1.20239258e-02],
                        [ -1.18408203e-02,  -1.22070312e-02],
                        [ -1.02539062e-02,  -1.06506348e-02],
                        [ -9.21630859e-03,  -9.49096680e-03],
                        [ -9.36889648e-03,  -9.79614258e-03],
                        [ -9.30786133e-03,  -9.79614258e-03],
                        [ -8.27026367e-03,  -8.57543945e-03],
                        [ -8.33129883e-03,  -8.63647461e-03],
                        [ -1.10168457e-02,  -1.13830566e-02],
                        [ -1.65100098e-02,  -1.66625977e-02],
                        [ -2.18505859e-02,  -2.18200684e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.16979980e-02,  -2.16369629e-02],
                        [ -2.37426758e-02,  -2.34680176e-02],
                        [ -2.73437500e-02,  -2.69470215e-02],
                        [ -2.84423828e-02,  -2.80151367e-02],
                        [ -2.63977051e-02,  -2.60620117e-02],
                        [ -2.27661133e-02,  -2.23693848e-02],
                        [ -1.82189941e-02,  -1.76696777e-02],
                        [ -1.34887695e-02,  -1.30615234e-02],
                        [ -1.15661621e-02,  -1.13525391e-02],
                        [ -1.26647949e-02,  -1.24206543e-02],
                        [ -1.14440918e-02,  -1.11389160e-02],
                        [ -5.67626953e-03,  -5.61523438e-03],
                        [ -4.27246094e-04,  -6.10351562e-04],
                        [ -4.88281250e-04,  -6.40869141e-04],
                        [ -5.00488281e-03,  -5.15747070e-03],
                        [ -9.58251953e-03,  -9.97924805e-03],
                        [ -1.20544434e-02,  -1.25732422e-02],
                        [ -1.22680664e-02,  -1.26953125e-02],
                        [ -8.57543945e-03,  -8.94165039e-03],
                        [ -8.23974609e-04,  -1.28173828e-03],
                        [  7.08007812e-03,   6.59179688e-03],
                        [  1.29089355e-02,   1.25732422e-02],
                        [  1.83410645e-02,   1.81274414e-02],
                        [  2.39257812e-02,   2.37731934e-02],
                        [  2.70385742e-02,   2.69470215e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.27661133e-02,   2.29187012e-02],
                        [  2.09350586e-02,   2.12402344e-02],
                        [  2.24304199e-02,   2.27661133e-02],
                        [  2.84423828e-02,   2.87475586e-02],
                        [  3.90319824e-02,   3.94287109e-02],
                        [  5.32836914e-02,   5.37719727e-02],
                        [  7.19299316e-02,   7.23876953e-02],
                        [  9.48791504e-02,   9.52453613e-02],
                        [  1.16882324e-01,   1.17187500e-01],
                        [  1.30554199e-01,   1.30828857e-01],
                        [  1.28234863e-01,   1.28448486e-01],
                        [  9.79309082e-02,   9.80834961e-02],
                        [  2.75573730e-02,   2.75878906e-02],
                        [ -7.98339844e-02,  -7.99255371e-02],
                        [ -1.97753906e-01,  -1.97906494e-01],
                        [ -2.89093018e-01,  -2.89245605e-01],
                        [ -3.28857422e-01,  -3.29071045e-01],
                        [ -3.16406250e-01,  -3.16741943e-01],
                        [ -2.73071289e-01,  -2.73406982e-01],
                        [ -2.26684570e-01,  -2.27020264e-01],
                        [ -1.90338135e-01,  -1.90643311e-01],
                        [ -1.56402588e-01,  -1.56646729e-01],
                        [ -1.11633301e-01,  -1.11968994e-01],
                        [ -5.30090332e-02,  -5.34057617e-02],
                        [  9.15527344e-03,   8.97216797e-03],
                        [  5.88073730e-02,   5.87463379e-02],
                        [  8.46862793e-02,   8.45031738e-02],
                        [  8.63342285e-02,   8.61206055e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  6.64062500e-02,   6.65283203e-02],
                        [  6.86645508e-02,   6.87561035e-02],
                        [  7.65991211e-02,   7.66296387e-02],
                        [  8.16040039e-02,   8.17565918e-02],
                        [  8.20312500e-02,   8.23364258e-02],
                        [  8.11767578e-02,   8.15124512e-02],
                        [  7.84912109e-02,   7.87658691e-02],
                        [  7.04956055e-02,   7.08312988e-02],
                        [  5.87463379e-02,   5.91430664e-02],
                        [  4.90417480e-02,   4.94384766e-02],
                        [  4.37316895e-02,   4.40979004e-02],
                        [  3.97949219e-02,   4.01916504e-02],
                        [  3.49426270e-02,   3.52783203e-02],
                        [  3.07006836e-02,   3.09448242e-02],
                        [  2.83203125e-02,   2.85644531e-02],
                        [  2.67944336e-02,   2.69470215e-02],
                        [  2.60009766e-02,   2.59704590e-02],
                        [  2.76184082e-02,   2.74963379e-02],
                        [  3.31420898e-02,   3.29284668e-02],
                        [  4.28161621e-02,   4.24499512e-02],
                        [  5.35583496e-02,   5.30700684e-02],
                        [  5.76782227e-02,   5.70983887e-02],
                        [  4.81872559e-02,   4.75158691e-02],
                        [  2.59704590e-02,   2.52380371e-02],
                        [  7.32421875e-04,  -6.10351562e-05],
                        [ -1.55639648e-02,  -1.62963867e-02],
                        [ -1.83715820e-02,  -1.89819336e-02],
                        [ -1.48010254e-02,  -1.54418945e-02],
                        [ -1.59606934e-02,  -1.64794922e-02],
                        [ -2.47802734e-02,  -2.49633789e-02],
                        [ -3.30200195e-02,  -3.29589844e-02],
                        [ -3.11584473e-02,  -3.10363770e-02],
                        [ -1.95922852e-02,  -1.92565918e-02],
                        [ -5.92041016e-03,  -5.24902344e-03],
                        [  4.30297852e-03,   5.24902344e-03],
                        [  8.97216797e-03,   1.00097656e-02],
                        [  1.02539062e-02,   1.13220215e-02],
                        [  1.50451660e-02,   1.62353516e-02],
                        [  2.66113281e-02,   2.79541016e-02],
                        [  3.86962891e-02,   3.98559570e-02],
                        [  4.23583984e-02,   4.32739258e-02],
                        [  3.69262695e-02,   3.77502441e-02],
                        [  3.03649902e-02,   3.09753418e-02],
                        [  2.88391113e-02,   2.90222168e-02],
                        [  3.10668945e-02,   3.09448242e-02],
                        [  3.17077637e-02,   3.12805176e-02],
                        [  2.75878906e-02,   2.67944336e-02],
                        [  2.13623047e-02,   2.02331543e-02],
                        [  1.77307129e-02,   1.63574219e-02],
                        [  1.73645020e-02,   1.58081055e-02],
                        [  1.66320801e-02,   1.49536133e-02],
                        [  1.16882324e-02,   9.94873047e-03],
                        [  3.60107422e-03,   1.95312500e-03],
                        [ -2.44140625e-03,  -3.81469727e-03],
                        [ -4.05883789e-03,  -5.24902344e-03],
                        [ -3.35693359e-03,  -4.24194336e-03],
                        [ -4.15039062e-03,  -4.57763672e-03],
                        [ -9.73510742e-03,  -9.70458984e-03],
                        [ -1.86462402e-02,  -1.81579590e-02],
                        [ -2.73132324e-02,  -2.63671875e-02],
                        [ -3.38439941e-02,  -3.25317383e-02],
                        [ -3.57971191e-02,  -3.41186523e-02],
                        [ -3.23181152e-02,  -3.03039551e-02],
                        [ -2.56347656e-02,  -2.35290527e-02],
                        [ -1.84020996e-02,  -1.62963867e-02],
                        [ -1.51062012e-02,  -1.30615234e-02],
                        [ -1.88903809e-02,  -1.69982910e-02],
                        [ -2.57568359e-02,  -2.42614746e-02],
                        [ -2.96936035e-02,  -2.86254883e-02],
                        [ -2.82287598e-02,  -2.76489258e-02],
                        [ -2.27966309e-02,  -2.27355957e-02],
                        [ -1.61132812e-02,  -1.65710449e-02],
                        [ -1.03149414e-02,  -1.13830566e-02],
                        [ -8.60595703e-03,  -1.02233887e-02],
                        [ -1.22985840e-02,  -1.41906738e-02],
                        [ -1.66015625e-02,  -1.87988281e-02],
                        [ -1.80664062e-02,  -2.05383301e-02],
                        [ -1.83105469e-02,  -2.08435059e-02],
                        [ -1.80969238e-02,  -2.04467773e-02],
                        [ -1.51062012e-02,  -1.71508789e-02],
                        [ -7.84301758e-03,  -9.61303711e-03],
                        [  3.96728516e-04,  -9.76562500e-04],
                        [  4.69970703e-03,   3.96728516e-03],
                        [  4.57763672e-03,   4.54711914e-03],
                        [  2.01416016e-03,   2.53295898e-03],
                        [ -1.80053711e-03,  -7.62939453e-04],
                        [ -4.82177734e-03,  -3.20434570e-03],
                        [ -4.54711914e-03,  -2.38037109e-03],
                        [ -7.01904297e-04,   1.73950195e-03],
                        [  4.33349609e-03,   6.89697266e-03],
                        [  8.45336914e-03,   1.11389160e-02],
                        [  1.34277344e-02,   1.59912109e-02],
                        [  2.14538574e-02,   2.37121582e-02],
                        [  3.10668945e-02,   3.29589844e-02],
                        [  4.06799316e-02,   4.21142578e-02],
                        [  5.18798828e-02,   5.26733398e-02],
                        [  6.71081543e-02,   6.72607422e-02],
                        [  8.73413086e-02,   8.68835449e-02],
                        [  1.11755371e-01,   1.10687256e-01],
                        [  1.35467529e-01,   1.33850098e-01],
                        [  1.48010254e-01,   1.45904541e-01],
                        [  1.37420654e-01,   1.34979248e-01],
                        [  9.47570801e-02,   9.21936035e-02],
                        [  1.55334473e-02,   1.29089355e-02],
                        [ -9.47570801e-02,  -9.72900391e-02],
                        [ -2.13378906e-01,  -2.15637207e-01],
                        [ -3.07098389e-01,  -3.08929443e-01],
                        [ -3.51348877e-01,  -3.52691650e-01],
                        [ -3.43200684e-01,  -3.43994141e-01],
                        [ -2.99072266e-01,  -2.99194336e-01],
                        [ -2.43927002e-01,  -2.43499756e-01],
                        [ -1.97814941e-01,  -1.96868896e-01],
                        [ -1.63116455e-01,  -1.61621094e-01],
                        [ -1.24969482e-01,  -1.22955322e-01],
                        [ -6.92749023e-02,  -6.70471191e-02],
                        [ -1.46484375e-03,   8.23974609e-04],
                        [  5.75866699e-02,   5.99365234e-02],
                        [  9.24682617e-02,   9.48181152e-02],
                        [  1.03668213e-01,   1.05712891e-01],
                        [  1.00433350e-01,   1.01989746e-01],
                        [  9.28649902e-02,   9.39941406e-02],
                        [  8.78295898e-02,   8.85925293e-02],
                        [  8.64562988e-02,   8.66699219e-02],
                        [  8.56628418e-02,   8.52050781e-02],
                        [  8.29162598e-02,   8.20007324e-02],
                        [  7.91625977e-02,   7.79418945e-02],
                        [  7.54394531e-02,   7.38830566e-02],
                        [  6.87561035e-02,   6.69250488e-02],
                        [  5.58166504e-02,   5.38635254e-02],
                        [  3.94287109e-02,   3.75061035e-02],
                        [  2.77099609e-02,   2.59399414e-02],
                        [  2.66113281e-02,   2.50549316e-02],
                        [  3.46374512e-02,   3.33557129e-02],
                        [  4.50744629e-02,   4.42199707e-02],
                        [  5.22460938e-02,   5.17578125e-02],
                        [  5.55725098e-02,   5.54504395e-02],
                        [  5.88378906e-02,   5.92041016e-02],
                        [  6.38427734e-02,   6.45751953e-02],
                        [  6.64672852e-02,   6.73217773e-02],
                        [  6.12487793e-02,   6.23474121e-02],
                        [  4.73022461e-02,   4.87060547e-02],
                        [  2.73132324e-02,   2.86865234e-02],
                        [  3.87573242e-03,   5.03540039e-03],
                        [ -1.97753906e-02,  -1.86462402e-02],
                        [ -3.73229980e-02,  -3.62854004e-02],
                        [ -4.30908203e-02,  -4.22668457e-02],
                        [ -3.93676758e-02,  -3.89099121e-02],
                        [ -3.46984863e-02,  -3.45153809e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.61938477e-02,  -3.62854004e-02],
                        [ -3.91235352e-02,  -3.95507812e-02],
                        [ -3.76586914e-02,  -3.83300781e-02],
                        [ -2.63977051e-02,  -2.69165039e-02],
                        [ -6.25610352e-03,  -6.74438477e-03],
                        [  1.44653320e-02,   1.37634277e-02],
                        [  2.79541016e-02,   2.73437500e-02],
                        [  3.44848633e-02,   3.41491699e-02],
                        [  4.03137207e-02,   4.00695801e-02],
                        [  4.80957031e-02,   4.78820801e-02],
                        [  5.48706055e-02,   5.47790527e-02],
                        [  5.88073730e-02,   5.88684082e-02],
                        [  6.06079102e-02,   6.07299805e-02],
                        [  6.01196289e-02,   6.02111816e-02],
                        [  5.69152832e-02,   5.70068359e-02],
                        [  5.21850586e-02,   5.23071289e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.92150879e-02,   3.90625000e-02],
                        [  2.67944336e-02,   2.66418457e-02],
                        [  1.40075684e-02,   1.38244629e-02],
                        [  6.40869141e-03,   6.01196289e-03],
                        [  2.44140625e-03,   2.01416016e-03],
                        [ -2.89916992e-03,  -3.23486328e-03],
                        [ -9.79614258e-03,  -1.00708008e-02],
                        [ -1.44653320e-02,  -1.47399902e-02],
                        [ -1.56250000e-02,  -1.58081055e-02],
                        [ -1.43432617e-02,  -1.43127441e-02],
                        [ -1.11083984e-02,  -1.08032227e-02],
                        [ -8.72802734e-03,  -8.30078125e-03],
                        [ -1.23291016e-02,  -1.18103027e-02],
                        [ -2.21252441e-02,  -2.13623047e-02],
                        [ -3.25317383e-02,  -3.15246582e-02],
                        [ -3.88793945e-02,  -3.78723145e-02],
                        [ -4.18090820e-02,  -4.08935547e-02],
                        [ -4.43115234e-02,  -4.33654785e-02],
                        [ -4.58679199e-02,  -4.49523926e-02],
                        [ -4.38232422e-02,  -4.32128906e-02],
                        [ -3.82995605e-02,  -3.79028320e-02],
                        [ -3.15551758e-02,  -3.14331055e-02],
                        [ -2.45666504e-02,  -2.48413086e-02],
                        [ -1.69677734e-02,  -1.75476074e-02],
                        [ -9.61303711e-03,  -1.04675293e-02],
                        [ -4.24194336e-03,  -5.40161133e-03],
                        [ -2.44140625e-04,  -1.64794922e-03],
                        [  2.99072266e-03,   1.46484375e-03],
                        [  3.93676758e-03,   2.34985352e-03],
                        [  1.86157227e-03,   3.66210938e-04],
                        [ -3.23486328e-03,  -4.57763672e-03],
                        [ -1.07727051e-02,  -1.19323730e-02],
                        [ -1.73645020e-02,  -1.81579590e-02],
                        [ -2.01721191e-02,  -2.05078125e-02],
                        [ -2.02941895e-02,  -2.02636719e-02],
                        [ -2.01110840e-02,  -1.96533203e-02],
                        [ -1.98974609e-02,  -1.89208984e-02],
                        [ -1.74255371e-02,  -1.61132812e-02],
                        [ -1.12609863e-02,  -9.67407227e-03],
                        [ -2.31933594e-03,  -4.27246094e-04],
                        [  8.48388672e-03,   1.04370117e-02],
                        [  1.91040039e-02,   2.10266113e-02],
                        [  2.59399414e-02,   2.77404785e-02],
                        [  2.75878906e-02,   2.91137695e-02],
                        [  2.67028809e-02,   2.78625488e-02],
                        [  2.73742676e-02,   2.81066895e-02],
                        [  3.15856934e-02,   3.17382812e-02],
                        [  3.72924805e-02,   3.69567871e-02],
                        [  4.17785645e-02,   4.10156250e-02],
                        [  4.59899902e-02,   4.47082520e-02],
                        [  5.35888672e-02,   5.18188477e-02],
                        [  6.50329590e-02,   6.30187988e-02],
                        [  7.68432617e-02,   7.47680664e-02],
                        [  8.72802734e-02,   8.51440430e-02],
                        [  9.72900391e-02,   9.52148438e-02],
                        [  1.02050781e-01,   1.00219727e-01],
                        [  8.65478516e-02,   8.51440430e-02],
                        [  3.42712402e-02,   3.33862305e-02],
                        [ -5.80139160e-02,  -5.84411621e-02],
                        [ -1.72546387e-01,  -1.72485352e-01],
                        [ -2.74871826e-01,  -2.74139404e-01],
                        [ -3.30047607e-01,  -3.28735352e-01],
                        [ -3.25622559e-01,  -3.23944092e-01],
                        [ -2.80761719e-01,  -2.78808594e-01],
                        [ -2.29858398e-01,  -2.27691650e-01],
                        [ -1.95037842e-01,  -1.92779541e-01],
                        [ -1.73095703e-01,  -1.70959473e-01],
                        [ -1.46270752e-01,  -1.44409180e-01],
                        [ -1.01470947e-01,  -1.00006104e-01],
                        [ -4.09851074e-02,  -3.99475098e-02],
                        [  1.98364258e-02,   2.02941895e-02],
                        [  6.48498535e-02,   6.46972656e-02],
                        [  8.95690918e-02,   8.88977051e-02],
                        [  1.01196289e-01,   9.99755859e-02],
                        [  1.10260010e-01,   1.08520508e-01],
                        [  1.21826172e-01,   1.19781494e-01],
                        [  1.31805420e-01,   1.29669189e-01],
                        [  1.33361816e-01,   1.31134033e-01],
                        [  1.23962402e-01,   1.21734619e-01],
                        [  1.05316162e-01,   1.03393555e-01],
                        [  8.16650391e-02,   8.02917480e-02],
                        [  5.78308105e-02,   5.69152832e-02],
                        [  3.69262695e-02,   3.64685059e-02],
                        [  2.02636719e-02,   2.04162598e-02],
                        [  9.49096680e-03,   1.03149414e-02],
                        [  6.25610352e-03,   7.69042969e-03],
                        [  8.75854492e-03,   1.05285645e-02],
                        [  1.31835938e-02,   1.52282715e-02],
                        [  2.05688477e-02,   2.28576660e-02],
                        [  3.39050293e-02,   3.62854004e-02],
                        [  5.04150391e-02,   5.25512695e-02],
                        [  6.42700195e-02,   6.60705566e-02],
                        [  7.11975098e-02,   7.26013184e-02],
                        [  6.82373047e-02,   6.91223145e-02],
                        [  5.49621582e-02,   5.52062988e-02],
                        [  3.46679688e-02,   3.42712402e-02],
                        [  1.34887695e-02,   1.24511719e-02],
                        [ -2.92968750e-03,  -4.51660156e-03],
                        [ -1.26647949e-02,  -1.47094727e-02],
                        [ -1.73645020e-02,  -1.97143555e-02],
                        [ -1.98059082e-02,  -2.22778320e-02],
                        [ -2.36206055e-02,  -2.60925293e-02],
                        [ -3.17687988e-02,  -3.40881348e-02],
                        [ -4.20227051e-02,  -4.39453125e-02],
                        [ -4.68444824e-02,  -4.81872559e-02],
                        [ -4.06494141e-02,  -4.14123535e-02],
                        [ -2.50854492e-02,  -2.52685547e-02],
                        [ -6.19506836e-03,  -5.64575195e-03],
                        [  1.08947754e-02,   1.22070312e-02],
                        [  2.34985352e-02,   2.54211426e-02],
                        [  3.15551758e-02,   3.38439941e-02],
                        [  3.72619629e-02,   3.98559570e-02],
                        [  4.31823730e-02,   4.59899902e-02],
                        [  4.94689941e-02,   5.22766113e-02],
                        [  5.36499023e-02,   5.61828613e-02],
                        [  5.21545410e-02,   5.41992188e-02],
                        [  4.42199707e-02,   4.57153320e-02],
                        [  3.43017578e-02,   3.52172852e-02],
                        [  2.80151367e-02,   2.81372070e-02],
                        [  2.69165039e-02,   2.62145996e-02],
                        [  2.91748047e-02,   2.77404785e-02],
                        [  3.17687988e-02,   2.97241211e-02],
                        [  3.10668945e-02,   2.84729004e-02],
                        [  2.49633789e-02,   2.19726562e-02],
                        [  1.55944824e-02,   1.24511719e-02],
                        [  6.53076172e-03,   3.47900391e-03],
                        [ -1.95312500e-03,  -4.76074219e-03],
                        [ -9.94873047e-03,  -1.23901367e-02],
                        [ -1.43737793e-02,  -1.61437988e-02],
                        [ -1.36718750e-02,  -1.46484375e-02],
                        [ -1.04980469e-02,  -1.07727051e-02],
                        [ -8.30078125e-03,  -7.75146484e-03],
                        [ -1.08642578e-02,  -9.36889648e-03],
                        [ -2.08740234e-02,  -1.86767578e-02],
                        [ -3.61022949e-02,  -3.34472656e-02],
                        [ -4.96826172e-02,  -4.65698242e-02],
                        [ -5.30090332e-02,  -4.95605469e-02],
                        [ -4.16564941e-02,  -3.82385254e-02],
                        [ -2.18505859e-02,  -1.87988281e-02],
                        [ -5.88989258e-03,  -3.26538086e-03],
                        [  7.32421875e-04,   2.83813477e-03],
                        [  1.70898438e-03,   3.08227539e-03],
                        [  7.93457031e-04,   1.12915039e-03],
                        [ -2.01416016e-03,  -2.53295898e-03],
                        [ -5.49316406e-03,  -6.74438477e-03],
                        [ -8.57543945e-03,  -1.05895996e-02],
                        [ -1.35498047e-02,  -1.63269043e-02],
                        [ -2.12707520e-02,  -2.45056152e-02],
                        [ -2.66723633e-02,  -3.00598145e-02],
                        [ -2.47192383e-02,  -2.81066895e-02],
                        [ -1.83105469e-02,  -2.16064453e-02],
                        [ -1.41296387e-02,  -1.70898438e-02],
                        [ -1.37634277e-02,  -1.59606934e-02],
                        [ -1.47094727e-02,  -1.61132812e-02],
                        [ -1.57470703e-02,  -1.64794922e-02],
                        [ -1.58996582e-02,  -1.57165527e-02],
                        [ -1.44042969e-02,  -1.32141113e-02],
                        [ -1.34277344e-02,  -1.15051270e-02],
                        [ -1.52587891e-02,  -1.27563477e-02],
                        [ -1.76086426e-02,  -1.44958496e-02],
                        [ -1.51672363e-02,  -1.17797852e-02],
                        [ -6.40869141e-03,  -3.05175781e-03],
                        [  4.27246094e-03,   7.53784180e-03],
                        [  1.35192871e-02,   1.64184570e-02],
                        [  2.13012695e-02,   2.35900879e-02],
                        [  2.70080566e-02,   2.85339355e-02],
                        [  2.96630859e-02,   3.03955078e-02],
                        [  3.16467285e-02,   3.15246582e-02],
                        [  3.76586914e-02,   3.67431641e-02],
                        [  5.06591797e-02,   4.89196777e-02],
                        [  6.83898926e-02,   6.59179688e-02],
                        [  8.67309570e-02,   8.38317871e-02],
                        [  1.05651855e-01,   1.02508545e-01],
                        [  1.25244141e-01,   1.21978760e-01],
                        [  1.37603760e-01,   1.34429932e-01],
                        [  1.29760742e-01,   1.26983643e-01],
                        [  9.28955078e-02,   9.07897949e-02],
                        [  2.39562988e-02,   2.25219727e-02],
                        [ -7.48596191e-02,  -7.55920410e-02],
                        [ -1.88873291e-01,  -1.88781738e-01],
                        [ -2.87994385e-01,  -2.86987305e-01],
                        [ -3.42010498e-01,  -3.40270996e-01],
                        [ -3.41918945e-01,  -3.39599609e-01],
                        [ -3.03161621e-01,  -3.00384521e-01],
                        [ -2.51342773e-01,  -2.48321533e-01],
                        [ -2.05291748e-01,  -2.02209473e-01],
                        [ -1.66931152e-01,  -1.64001465e-01],
                        [ -1.24694824e-01,  -1.22192383e-01],
                        [ -6.83593750e-02,  -6.64062500e-02],
                        [ -1.77001953e-03,  -4.57763672e-04],
                        [  5.75561523e-02,   5.80444336e-02],
                        [  9.29260254e-02,   9.25903320e-02],
                        [  1.03210449e-01,   1.02142334e-01],
                        [  9.98535156e-02,   9.80834961e-02],
                        [  9.40551758e-02,   9.16137695e-02],
                        [  9.14306641e-02,   8.86535645e-02],
                        [  9.28955078e-02,   8.99658203e-02],
                        [  9.46350098e-02,   9.16442871e-02],
                        [  9.04235840e-02,   8.75854492e-02],
                        [  7.76672363e-02,   7.53173828e-02],
                        [  6.06689453e-02,   5.89599609e-02],
                        [  4.53491211e-02,   4.43115234e-02],
                        [  3.30200195e-02,   3.27148438e-02],
                        [  2.21557617e-02,   2.26135254e-02],
                        [  1.41906738e-02,   1.55334473e-02],
                        [  1.43432617e-02,   1.64184570e-02],
                        [  2.36816406e-02,   2.62145996e-02],
                        [  3.62854004e-02,   3.91235352e-02],
                        [  4.83398438e-02,   5.14831543e-02],
                        [  6.25305176e-02,   6.56738281e-02],
                        [  7.83996582e-02,   8.11767578e-02],
                        [  8.83178711e-02,   9.06372070e-02],
                        [  8.52966309e-02,   8.70361328e-02],
                        [  6.90307617e-02,   7.00378418e-02],
                        [  4.41589355e-02,   4.43115234e-02],
                        [  1.67236328e-02,   1.60522461e-02],
                        [ -6.40869141e-03,  -7.87353516e-03],
                        [ -2.11486816e-02,  -2.33154297e-02],
                        [ -3.01513672e-02,  -3.28979492e-02],
                        [ -3.80554199e-02,  -4.11376953e-02],
                        [ -4.42810059e-02,  -4.75158691e-02],
                        [ -4.53796387e-02,  -4.86145020e-02],
                        [ -4.05273438e-02,  -4.35180664e-02],
                        [ -3.09753418e-02,  -3.34472656e-02],
                        [ -1.73034668e-02,  -1.91040039e-02],
                        [ -1.28173828e-03,  -2.34985352e-03],
                        [  1.25122070e-02,   1.22070312e-02],
                        [  2.10571289e-02,   2.16674805e-02],
                        [  2.64587402e-02,   2.79541016e-02],
                        [  3.17993164e-02,   3.39660645e-02],
                        [  3.60717773e-02,   3.87878418e-02],
                        [  3.58276367e-02,   3.89709473e-02],
                        [  3.20129395e-02,   3.54003906e-02],
                        [  3.01208496e-02,   3.35083008e-02],
                        [  3.19519043e-02,   3.50341797e-02],
                        [  3.26232910e-02,   3.52478027e-02],
                        [  2.88391113e-02,   3.09143066e-02],
                        [  2.45971680e-02,   2.60009766e-02],
                        [  2.61230469e-02,   2.66113281e-02],
                        [  3.29284668e-02,   3.25622559e-02],
                        [  3.87268066e-02,   3.75976562e-02],
                        [  4.01611328e-02,   3.82995605e-02],
                        [  3.83911133e-02,   3.58886719e-02],
                        [  3.37524414e-02,   3.08227539e-02],
                        [  2.58483887e-02,   2.26745605e-02],
                        [  1.59606934e-02,   1.27258301e-02],
                        [  5.24902344e-03,   2.13623047e-03],
                        [ -4.97436523e-03,  -7.72094727e-03],
                        [ -1.15661621e-02,  -1.37939453e-02],
                        [ -1.44042969e-02,  -1.59912109e-02],
                        [ -1.74255371e-02,  -1.82800293e-02],
                        [ -2.17895508e-02,  -2.18505859e-02],
                        [ -2.50854492e-02,  -2.43835449e-02],
                        [ -2.60620117e-02,  -2.47192383e-02],
                        [ -2.48718262e-02,  -2.29492188e-02],
                        [ -2.13317871e-02,  -1.89514160e-02],
                        [ -1.51367188e-02,  -1.24816895e-02],
                        [ -7.81250000e-03,  -5.03540039e-03],
                        [ -3.60107422e-03,  -8.85009766e-04],
                        [ -5.34057617e-03,  -2.89916992e-03],
                        [ -1.16882324e-02,  -9.61303711e-03],
                        [ -1.99890137e-02,  -1.83715820e-02],
                        [ -2.74963379e-02,  -2.64892578e-02],
                        [ -3.09448242e-02,  -3.05480957e-02],
                        [ -2.87170410e-02,  -2.88696289e-02],
                        [ -2.25830078e-02,  -2.33154297e-02],
                        [ -1.68457031e-02,  -1.80664062e-02],
                        [ -1.48925781e-02,  -1.64184570e-02],
                        [ -1.57470703e-02,  -1.75476074e-02],
                        [ -1.51062012e-02,  -1.70898438e-02],
                        [ -1.06201172e-02,  -1.24816895e-02],
                        [ -5.43212891e-03,  -7.11059570e-03],
                        [ -3.84521484e-03,  -5.34057617e-03],
                        [ -4.51660156e-03,  -5.73730469e-03],
                        [ -2.68554688e-03,  -3.47900391e-03],
                        [  3.29589844e-03,   2.89916992e-03],
                        [  1.09863281e-02,   1.09252930e-02],
                        [  1.60217285e-02,   1.62658691e-02],
                        [  1.51367188e-02,   1.56250000e-02],
                        [  9.49096680e-03,   1.01928711e-02],
                        [  4.18090820e-03,   4.97436523e-03],
                        [  2.16674805e-03,   2.86865234e-03],
                        [  7.01904297e-04,   1.37329102e-03],
                        [ -2.10571289e-03,  -1.55639648e-03],
                        [ -2.10571289e-03,  -1.70898438e-03],
                        [  4.48608398e-03,   4.60815430e-03],
                        [  1.40380859e-02,   1.40075684e-02],
                        [  2.18200684e-02,   2.16979980e-02],
                        [  2.90527344e-02,   2.88085938e-02],
                        [  3.97949219e-02,   3.95202637e-02],
                        [  5.58776855e-02,   5.56945801e-02],
                        [  7.63244629e-02,   7.62939453e-02],
                        [  9.84802246e-02,   9.86022949e-02],
                        [  1.18865967e-01,   1.19232178e-01],
                        [  1.33392334e-01,   1.34063721e-01],
                        [  1.33422852e-01,   1.34368896e-01],
                        [  1.04736328e-01,   1.05834961e-01],
                        [  3.68041992e-02,   3.80554199e-02],
                        [ -6.59484863e-02,  -6.45141602e-02],
                        [ -1.83135986e-01,  -1.81732178e-01],
                        [ -2.85888672e-01,  -2.84759521e-01],
                        [ -3.45672607e-01,  -3.44787598e-01],
                        [ -3.46405029e-01,  -3.45825195e-01],
                        [ -2.99713135e-01,  -2.99682617e-01],
                        [ -2.42950439e-01,  -2.43530273e-01],
                        [ -2.05749512e-01,  -2.06909180e-01],
                        [ -1.83105469e-01,  -1.84814453e-01],
                        [ -1.50817871e-01,  -1.53045654e-01],
                        [ -9.65576172e-02,  -9.93041992e-02],
                        [ -2.77709961e-02,  -3.08227539e-02],
                        [  3.78417969e-02,   3.47595215e-02],
                        [  8.22143555e-02,   7.91931152e-02],
                        [  9.88769531e-02,   9.60693359e-02],
                        [  9.98840332e-02,   9.75646973e-02],
                        [  1.02844238e-01,   1.01287842e-01],
                        [  1.12060547e-01,   1.11328125e-01],
                        [  1.19689941e-01,   1.19873047e-01],
                        [  1.19567871e-01,   1.20758057e-01],
                        [  1.11419678e-01,   1.13647461e-01],
                        [  9.70153809e-02,   1.00158691e-01],
                        [  7.87963867e-02,   8.27026367e-02],
                        [  5.97229004e-02,   6.42700195e-02],
                        [  4.11987305e-02,   4.60815430e-02],
                        [  2.33764648e-02,   2.82897949e-02],
                        [  8.81958008e-03,   1.35192871e-02],
                        [  3.32641602e-03,   7.50732422e-03],
                        [  1.01928711e-02,   1.35498047e-02],
                        [  2.57263184e-02,   2.79541016e-02],
                        [  4.30603027e-02,   4.40368652e-02],
                        [  5.86242676e-02,   5.82580566e-02],
                        [  7.02819824e-02,   6.84814453e-02],
                        [  7.28149414e-02,   6.96105957e-02],
                        [  6.06689453e-02,   5.62133789e-02],
                        [  3.50036621e-02,   2.95715332e-02],
                        [  5.40161133e-03,  -7.32421875e-04],
                        [ -1.70593262e-02,  -2.36206055e-02],
                        [ -2.70385742e-02,  -3.36303711e-02],
                        [ -2.73742676e-02,  -3.35388184e-02],
                        [ -2.57263184e-02,  -3.10974121e-02],
                        [ -2.70385742e-02,  -3.13110352e-02],
                        [ -2.94494629e-02,  -3.23486328e-02],
                        [ -2.94799805e-02,  -3.07312012e-02],
                        [ -2.74963379e-02,  -2.69775391e-02],
                        [ -2.48413086e-02,  -2.25830078e-02],
                        [ -2.02331543e-02,  -1.62963867e-02],
                        [ -1.30615234e-02,  -7.59887695e-03],
                        [ -6.10351562e-03,   5.18798828e-04],
                        [ -3.96728516e-04,   7.04956055e-03],
                        [  7.65991211e-03,   1.55639648e-02],
                        [  1.92260742e-02,   2.70385742e-02],
                        [  2.96936035e-02,   3.69873047e-02],
                        [  3.80554199e-02,   4.44335938e-02],
                        [  4.88281250e-02,   5.38635254e-02],
                        [  6.03027344e-02,   6.36596680e-02],
                        [  6.26220703e-02,   6.40869141e-02],
                        [  5.20324707e-02,   5.14831543e-02],
                        [  3.64685059e-02,   3.39355469e-02],
                        [  2.50549316e-02,   2.06909180e-02],
                        [  2.02331543e-02,   1.41906738e-02],
                        [  2.05078125e-02,   1.31530762e-02],
                        [  2.30102539e-02,   1.47705078e-02],
                        [  2.31323242e-02,   1.44653320e-02],
                        [  1.86767578e-02,   1.00708008e-02],
                        [  1.34887695e-02,   5.49316406e-03],
                        [  1.23901367e-02,   5.46264648e-03],
                        [  1.60827637e-02,   1.05895996e-02],
                        [  2.19421387e-02,   1.82189941e-02],
                        [  2.56652832e-02,   2.39868164e-02],
                        [  2.30407715e-02,   2.34985352e-02],
                        [  1.26037598e-02,   1.51062012e-02],
                        [ -3.63159180e-03,   8.23974609e-04],
                        [ -2.09350586e-02,  -1.47399902e-02],
                        [ -3.41796875e-02,  -2.66418457e-02],
                        [ -4.08935547e-02,  -3.24707031e-02],
                        [ -4.22363281e-02,  -3.34167480e-02],
                        [ -4.22363281e-02,  -3.34777832e-02],
                        [ -4.44946289e-02,  -3.63159180e-02],
                        [ -4.75158691e-02,  -4.04052734e-02],
                        [ -4.71191406e-02,  -4.14733887e-02],
                        [ -4.25415039e-02,  -3.86962891e-02],
                        [ -3.53088379e-02,  -3.34167480e-02],
                        [ -2.55432129e-02,  -2.57263184e-02],
                        [ -1.49841309e-02,  -1.72424316e-02],
                        [ -9.46044922e-03,  -1.36413574e-02],
                        [ -1.17187500e-02,  -1.75170898e-02],
                        [ -1.53198242e-02,  -2.23999023e-02],
                        [ -1.37939453e-02,  -2.17895508e-02],
                        [ -1.04370117e-02,  -1.88598633e-02],
                        [ -1.06506348e-02,  -1.89514160e-02],
                        [ -1.18103027e-02,  -1.95922852e-02],
                        [ -7.99560547e-03,  -1.48315430e-02],
                        [ -3.35693359e-04,  -5.79833984e-03],
                        [  3.78417969e-03,  -3.05175781e-05],
                        [  2.04467773e-03,   3.05175781e-05],
                        [  5.79833984e-04,   4.57763672e-04],
                        [  4.24194336e-03,   6.01196289e-03],
                        [  9.30786133e-03,   1.27868652e-02],
                        [  9.52148438e-03,   1.44653320e-02],
                        [  5.49316406e-03,   1.16577148e-02],
                        [  2.68554688e-03,   9.67407227e-03],
                        [  2.89916992e-03,   1.02233887e-02],
                        [  4.15039062e-03,   1.14746094e-02],
                        [  6.16455078e-03,   1.30615234e-02],
                        [  9.06372070e-03,   1.51367188e-02],
                        [  1.10778809e-02,   1.60217285e-02],
                        [  1.18408203e-02,   1.54418945e-02],
                        [  1.41296387e-02,   1.62353516e-02],
                        [  1.99584961e-02,   2.04467773e-02],
                        [  2.87170410e-02,   2.76184082e-02],
                        [  3.92456055e-02,   3.67431641e-02],
                        [  5.17578125e-02,   4.80041504e-02],
                        [  6.79016113e-02,   6.31103516e-02],
                        [  8.90502930e-02,   8.35876465e-02],
                        [  1.11968994e-01,   1.06170654e-01],
                        [  1.26770020e-01,   1.20880127e-01],
                        [  1.21856689e-01,   1.16241455e-01],
                        [  9.01794434e-02,   8.51440430e-02],
                        [  3.01208496e-02,   2.59399414e-02],
                        [ -5.57556152e-02,  -5.89599609e-02],
                        [ -1.57989502e-01,  -1.60095215e-01],
                        [ -2.55065918e-01,  -2.55981445e-01],
                        [ -3.18664551e-01,  -3.18420410e-01],
                        [ -3.31726074e-01,  -3.30383301e-01],
                        [ -3.00537109e-01,  -2.98248291e-01],
                        [ -2.49877930e-01,  -2.46795654e-01],
                        [ -2.05535889e-01,  -2.01873779e-01],
                        [ -1.76452637e-01,  -1.72424316e-01],
                        [ -1.50726318e-01,  -1.46606445e-01],
                        [ -1.10870361e-01,  -1.06842041e-01],
                        [ -5.30395508e-02,  -4.92553711e-02],
                        [  9.67407227e-03,   1.30004883e-02],
                        [  6.22863770e-02,   6.50329590e-02],
                        [  1.00189209e-01,   1.02264404e-01],
                        [  1.23901367e-01,   1.25274658e-01],
                        [  1.31805420e-01,   1.32446289e-01],
                        [  1.25549316e-01,   1.25488281e-01],
                        [  1.13830566e-01,   1.13128662e-01],
                        [  1.03393555e-01,   1.02142334e-01],
                        [  9.21325684e-02,   9.04235840e-02],
                        [  7.60498047e-02,   7.39746094e-02],
                        [  5.88989258e-02,   5.66101074e-02],
                        [  4.81567383e-02,   4.57458496e-02],
                        [  4.37011719e-02,   4.12597656e-02],
                        [  3.81774902e-02,   3.57666016e-02],
                        [  2.91442871e-02,   2.68554688e-02],
                        [  2.34069824e-02,   2.13317871e-02],
                        [  2.83813477e-02,   2.65808105e-02],
                        [  4.42810059e-02,   4.27551270e-02],
                        [  6.43615723e-02,   6.31408691e-02],
                        [  7.95593262e-02,   7.86743164e-02],
                        [  8.17565918e-02,   8.12072754e-02],
                        [  6.80541992e-02,   6.78710938e-02],
                        [  4.38232422e-02,   4.39758301e-02],
                        [  1.82495117e-02,   1.87377930e-02],
                        [ -2.59399414e-03,  -1.73950195e-03],
                        [ -1.54113770e-02,  -1.41601562e-02],
                        [ -1.77307129e-02,  -1.61437988e-02],
                        [ -1.22985840e-02,  -1.04675293e-02],
                        [ -8.60595703e-03,  -6.53076172e-03],
                        [ -1.33972168e-02,  -1.10778809e-02],
                        [ -2.31628418e-02,  -2.07519531e-02],
                        [ -3.00598145e-02,  -2.76489258e-02],
                        [ -3.08532715e-02,  -2.85034180e-02],
                        [ -2.63061523e-02,  -2.41394043e-02],
                        [ -1.74560547e-02,  -1.55639648e-02],
                        [ -6.34765625e-03,  -4.85229492e-03],
                        [  3.96728516e-03,   4.97436523e-03],
                        [  1.33361816e-02,   1.37329102e-02],
                        [  2.34069824e-02,   2.31628418e-02],
                        [  3.29895020e-02,   3.20739746e-02],
                        [  3.84826660e-02,   3.68652344e-02],
                        [  3.93371582e-02,   3.71093750e-02],
                        [  3.88183594e-02,   3.60412598e-02],
                        [  3.83300781e-02,   3.50952148e-02],
                        [  3.61938477e-02,   3.26843262e-02],
                        [  3.23791504e-02,   2.87780762e-02],
                        [  2.88696289e-02,   2.53295898e-02],
                        [  2.59094238e-02,   2.26440430e-02],
                        [  2.34680176e-02,   2.06909180e-02],
                        [  2.33459473e-02,   2.12707520e-02],
                        [  2.49633789e-02,   2.36511230e-02],
                        [  2.42919922e-02,   2.38647461e-02],
                        [  2.20642090e-02,   2.26440430e-02],
                        [  2.53601074e-02,   2.69165039e-02],
                        [  3.53698730e-02,   3.78417969e-02],
                        [  4.26940918e-02,   4.59899902e-02],
                        [  3.96423340e-02,   4.36401367e-02],
                        [  2.86254883e-02,   3.30505371e-02],
                        [  1.51977539e-02,   1.98059082e-02],
                        [  1.64794922e-03,   6.22558594e-03],
                        [ -1.06201172e-02,  -6.40869141e-03],
                        [ -1.91955566e-02,  -1.55944824e-02],
                        [ -2.27966309e-02,  -1.99890137e-02],
                        [ -2.42004395e-02,  -2.23999023e-02],
                        [ -2.79541016e-02,  -2.73437500e-02],
                        [ -3.35388184e-02,  -3.41186523e-02],
                        [ -3.54309082e-02,  -3.71704102e-02],
                        [ -3.32031250e-02,  -3.61022949e-02],
                        [ -3.23791504e-02,  -3.62854004e-02],
                        [ -3.33251953e-02,  -3.79638672e-02],
                        [ -2.99377441e-02,  -3.50646973e-02],
                        [ -2.17285156e-02,  -2.70690918e-02],
                        [ -1.55944824e-02,  -2.08129883e-02],
                        [ -1.43737793e-02,  -1.91345215e-02],
                        [ -1.34277344e-02,  -1.74255371e-02],
                        [ -1.04675293e-02,  -1.34887695e-02],
                        [ -8.33129883e-03,  -1.01318359e-02],
                        [ -7.41577148e-03,  -7.90405273e-03],
                        [ -5.73730469e-03,  -4.85229492e-03],
                        [ -5.40161133e-03,  -3.17382812e-03],
                        [ -9.27734375e-03,  -5.79833984e-03],
                        [ -1.44958496e-02,  -1.00097656e-02],
                        [ -1.58996582e-02,  -1.06811523e-02],
                        [ -1.27258301e-02,  -7.01904297e-03],
                        [ -7.50732422e-03,  -1.73950195e-03],
                        [ -1.25122070e-03,   4.27246094e-03],
                        [  6.74438477e-03,   1.16577148e-02],
                        [  1.41296387e-02,   1.81274414e-02],
                        [  1.72119141e-02,   2.00500488e-02],
                        [  1.71203613e-02,   1.85852051e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.20239258e-02,   1.05590820e-02],
                        [  3.63159180e-03,   7.62939453e-04],
                        [ -2.65502930e-03,  -6.74438477e-03],
                        [ -1.03759766e-03,  -6.13403320e-03],
                        [  4.97436523e-03,  -7.62939453e-04],
                        [  9.24682617e-03,   3.17382812e-03],
                        [  1.36718750e-02,   7.69042969e-03],
                        [  2.35595703e-02,   1.80053711e-02],
                        [  3.63769531e-02,   3.16162109e-02],
                        [  4.69970703e-02,   4.33044434e-02],
                        [  5.98449707e-02,   5.75256348e-02],
                        [  8.31298828e-02,   8.22753906e-02],
                        [  1.12854004e-01,   1.13525391e-01],
                        [  1.34216309e-01,   1.36444092e-01],
                        [  1.36505127e-01,   1.40106201e-01],
                        [  1.14624023e-01,   1.19354248e-01],
                        [  6.12487793e-02,   6.68640137e-02],
                        [ -2.81677246e-02,  -2.20336914e-02],
                        [ -1.42181396e-01,  -1.35894775e-01],
                        [ -2.51861572e-01,  -2.45849609e-01],
                        [ -3.23883057e-01,  -3.18481445e-01],
                        [ -3.37066650e-01,  -3.32672119e-01],
                        [ -2.96325684e-01,  -2.93182373e-01],
                        [ -2.34252930e-01,  -2.32574463e-01],
                        [ -1.90338135e-01,  -1.90216064e-01],
                        [ -1.77124023e-01,  -1.78588867e-01],
                        [ -1.70043945e-01,  -1.73004150e-01],
                        [ -1.38488770e-01,  -1.42761230e-01],
                        [ -7.96813965e-02,  -8.50219727e-02],
                        [ -1.37023926e-02,  -1.97753906e-02],
                        [  4.25720215e-02,   3.61633301e-02],
                        [  8.40148926e-02,   7.76672363e-02],
                        [  1.09436035e-01,   1.03546143e-01],
                        [  1.18347168e-01,   1.13281250e-01],
                        [  1.14898682e-01,   1.10961914e-01],
                        [  1.07696533e-01,   1.05133057e-01],
                        [  1.03240967e-01,   1.02233887e-01],
                        [  1.00616455e-01,   1.01196289e-01],
                        [  9.43298340e-02,   9.64965820e-02],
                        [  8.20617676e-02,   8.56628418e-02],
                        [  6.79626465e-02,   7.28149414e-02],
                        [  5.68847656e-02,   6.26220703e-02],
                        [  4.73937988e-02,   5.36804199e-02],
                        [  3.65295410e-02,   4.30297852e-02],
                        [  2.76489258e-02,   3.39355469e-02],
                        [  2.69470215e-02,   3.25927734e-02],
                        [  3.59497070e-02,   4.06494141e-02],
                        [  5.05676270e-02,   5.40771484e-02],
                        [  6.24084473e-02,   6.44226074e-02],
                        [  6.23168945e-02,   6.27746582e-02],
                        [  4.72717285e-02,   4.61425781e-02],
                        [  2.16064453e-02,   1.89514160e-02],
                        [ -6.89697266e-03,  -1.08947754e-02],
                        [ -2.87170410e-02,  -3.37829590e-02],
                        [ -3.60717773e-02,  -4.19311523e-02],
                        [ -2.98767090e-02,  -3.61938477e-02],
                        [ -1.92260742e-02,  -2.55737305e-02],
                        [ -1.29699707e-02,  -1.89819336e-02],
                        [ -1.43432617e-02,  -1.96838379e-02],
                        [ -2.17590332e-02,  -2.60925293e-02],
                        [ -3.04260254e-02,  -3.35083008e-02],
                        [ -3.26843262e-02,  -3.43322754e-02],
                        [ -2.19421387e-02,  -2.20947266e-02],
                        [  7.32421875e-04,   2.07519531e-03],
                        [  2.54211426e-02,   2.81677246e-02],
                        [  4.07409668e-02,   4.47387695e-02],
                        [  4.22668457e-02,   4.72412109e-02],
                        [  3.37829590e-02,   3.93981934e-02],
                        [  2.26135254e-02,   2.85644531e-02],
                        [  1.42822266e-02,   2.02331543e-02],
                        [  1.00097656e-02,   1.55639648e-02],
                        [  9.09423828e-03,   1.39770508e-02],
                        [  1.22070312e-02,   1.61743164e-02],
                        [  1.89819336e-02,   2.17590332e-02],
                        [  2.56958008e-02,   2.71606445e-02],
                        [  2.98461914e-02,   2.99682617e-02],
                        [  3.27758789e-02,   3.15551758e-02],
                        [  3.52478027e-02,   3.27758789e-02],
                        [  3.64990234e-02,   3.29589844e-02],
                        [  3.73840332e-02,   3.29895020e-02],
                        [  3.86352539e-02,   3.36608887e-02],
                        [  3.85742188e-02,   3.32946777e-02],
                        [  3.68347168e-02,   3.16162109e-02],
                        [  3.57666016e-02,   3.08227539e-02],
                        [  3.45764160e-02,   3.01818848e-02],
                        [  2.87170410e-02,   2.51464844e-02],
                        [  1.70898438e-02,   1.44958496e-02],
                        [  4.05883789e-03,   2.53295898e-03],
                        [ -6.83593750e-03,  -7.23266602e-03],
                        [ -1.55334473e-02,  -1.47705078e-02],
                        [ -2.28576660e-02,  -2.10876465e-02],
                        [ -2.98767090e-02,  -2.72216797e-02],
                        [ -3.68957520e-02,  -3.34777832e-02],
                        [ -4.26025391e-02,  -3.86657715e-02],
                        [ -4.65698242e-02,  -4.23889160e-02],
                        [ -4.86145020e-02,  -4.43420410e-02],
                        [ -4.60205078e-02,  -4.19006348e-02],
                        [ -3.82690430e-02,  -3.45458984e-02],
                        [ -3.02429199e-02,  -2.70690918e-02],
                        [ -2.49023438e-02,  -2.23693848e-02],
                        [ -2.05078125e-02,  -1.87683105e-02],
                        [ -1.67541504e-02,  -1.58691406e-02],
                        [ -1.50756836e-02,  -1.49536133e-02],
                        [ -1.40991211e-02,  -1.47705078e-02],
                        [ -1.13220215e-02,  -1.27563477e-02],
                        [ -7.59887695e-03,  -9.61303711e-03],
                        [ -5.03540039e-03,  -7.50732422e-03],
                        [ -3.35693359e-03,  -6.22558594e-03],
                        [ -2.10571289e-03,  -5.15747070e-03],
                        [ -4.15039062e-03,  -7.23266602e-03],
                        [ -1.22375488e-02,  -1.52587891e-02],
                        [ -2.24304199e-02,  -2.52380371e-02],
                        [ -2.56652832e-02,  -2.81372070e-02],
                        [ -1.82189941e-02,  -2.02941895e-02],
                        [ -5.64575195e-03,  -7.29370117e-03],
                        [  5.34057617e-03,   4.21142578e-03],
                        [  1.25732422e-02,   1.19628906e-02],
                        [  1.40075684e-02,   1.39160156e-02],
                        [  7.84301758e-03,   8.20922852e-03],
                        [ -1.09863281e-03,  -2.44140625e-04],
                        [ -4.69970703e-03,  -3.41796875e-03],
                        [ -2.38037109e-03,  -7.62939453e-04],
                        [  2.44140625e-04,   2.16674805e-03],
                        [  2.07519531e-03,   4.27246094e-03],
                        [  7.29370117e-03,   9.61303711e-03],
                        [  1.67541504e-02,   1.91955566e-02],
                        [  2.63366699e-02,   2.88085938e-02],
                        [  3.32641602e-02,   3.57055664e-02],
                        [  3.95202637e-02,   4.17785645e-02],
                        [  4.84924316e-02,   5.05676270e-02],
                        [  6.21032715e-02,   6.38732910e-02],
                        [  8.02917480e-02,   8.16650391e-02],
                        [  1.00921631e-01,   1.01867676e-01],
                        [  1.18286133e-01,   1.18713379e-01],
                        [  1.22131348e-01,   1.22039795e-01],
                        [  1.02233887e-01,   1.01531982e-01],
                        [  5.33447266e-02,   5.20629883e-02],
                        [ -2.56347656e-02,  -2.74963379e-02],
                        [ -1.30828857e-01,  -1.33178711e-01],
                        [ -2.42034912e-01,  -2.44873047e-01],
                        [ -3.21655273e-01,  -3.24798584e-01],
                        [ -3.40332031e-01,  -3.43719482e-01],
                        [ -3.04290771e-01,  -3.07708740e-01],
                        [ -2.48107910e-01,  -2.51464844e-01],
                        [ -2.01965332e-01,  -2.05047607e-01],
                        [ -1.72119141e-01,  -1.74774170e-01],
                        [ -1.48773193e-01,  -1.50848389e-01],
                        [ -1.20269775e-01,  -1.21643066e-01],
                        [ -8.01391602e-02,  -8.06579590e-02],
                        [ -3.03955078e-02,  -3.00292969e-02],
                        [  1.97753906e-02,   2.10571289e-02],
                        [  6.25000000e-02,   6.46972656e-02],
                        [  9.59167480e-02,   9.89379883e-02],
                        [  1.20208740e-01,   1.23962402e-01],
                        [  1.34307861e-01,   1.38580322e-01],
                        [  1.38061523e-01,   1.42669678e-01],
                        [  1.33666992e-01,   1.38366699e-01],
                        [  1.22772217e-01,   1.27349854e-01],
                        [  1.05743408e-01,   1.09924316e-01],
                        [  8.50830078e-02,   8.86230469e-02],
                        [  6.65893555e-02,   6.92443848e-02],
                        [  5.55419922e-02,   5.71899414e-02],
                        [  5.26428223e-02,   5.31616211e-02],
                        [  5.42297363e-02,   5.34973145e-02],
                        [  5.60913086e-02,   5.41687012e-02],
                        [  5.57250977e-02,   5.26428223e-02],
                        [  5.17883301e-02,   4.76989746e-02],
                        [  4.49829102e-02,   4.00695801e-02],
                        [  3.76281738e-02,   3.21960449e-02],
                        [  2.94799805e-02,   2.37731934e-02],
                        [  1.72729492e-02,   1.15966797e-02],
                        [  1.40380859e-03,  -3.90625000e-03],
                        [ -1.15661621e-02,  -1.62048340e-02],
                        [ -1.59606934e-02,  -1.96533203e-02],
                        [ -1.25732422e-02,  -1.51367188e-02],
                        [ -6.62231445e-03,  -7.84301758e-03],
                        [ -2.83813477e-03,  -2.62451172e-03],
                        [ -4.57763672e-03,  -2.96020508e-03],
                        [ -1.27868652e-02,  -9.82666016e-03],
                        [ -2.29797363e-02,  -1.87988281e-02],
                        [ -2.78015137e-02,  -2.26745605e-02],
                        [ -2.43835449e-02,  -1.85546875e-02],
                        [ -1.49536133e-02,  -8.69750977e-03],
                        [ -2.86865234e-03,   3.38745117e-03],
                        [  8.36181641e-03,   1.43127441e-02],
                        [  1.68151855e-02,   2.20947266e-02],
                        [  2.29797363e-02,   2.73437500e-02],
                        [  2.70996094e-02,   3.02429199e-02],
                        [  2.85339355e-02,   3.03039551e-02],
                        [  2.93884277e-02,   2.96630859e-02],
                        [  3.25317383e-02,   3.13110352e-02],
                        [  3.67736816e-02,   3.40881348e-02],
                        [  3.81164551e-02,   3.41796875e-02],
                        [  3.63464355e-02,   3.13720703e-02],
                        [  3.53393555e-02,   2.95410156e-02],
                        [  3.74450684e-02,   3.12194824e-02],
                        [  4.08630371e-02,   3.45764160e-02],
                        [  4.29992676e-02,   3.69567871e-02],
                        [  4.31213379e-02,   3.76892090e-02],
                        [  4.16870117e-02,   3.71398926e-02],
                        [  3.93981934e-02,   3.60412598e-02],
                        [  3.70178223e-02,   3.49731445e-02],
                        [  3.41796875e-02,   3.35693359e-02],
                        [  3.03039551e-02,   3.11584473e-02],
                        [  2.60620117e-02,   2.82897949e-02],
                        [  2.24609375e-02,   2.59399414e-02],
                        [  1.82189941e-02,   2.27355957e-02],
                        [  1.05285645e-02,   1.57775879e-02],
                        [ -3.35693359e-04,   5.34057617e-03],
                        [ -1.00402832e-02,  -4.24194336e-03],
                        [ -1.55639648e-02,  -9.97924805e-03],
                        [ -1.91040039e-02,  -1.40686035e-02],
                        [ -2.46276855e-02,  -2.03857422e-02],
                        [ -3.19519043e-02,  -2.87475586e-02],
                        [ -3.76586914e-02,  -3.56445312e-02],
                        [ -3.97949219e-02,  -3.90319824e-02],
                        [ -3.90014648e-02,  -3.95202637e-02],
                        [ -3.62243652e-02,  -3.79943848e-02],
                        [ -3.17687988e-02,  -3.45764160e-02],
                        [ -2.63671875e-02,  -3.00598145e-02],
                        [ -2.17895508e-02,  -2.61535645e-02],
                        [ -1.91650391e-02,  -2.38952637e-02],
                        [ -1.76391602e-02,  -2.24304199e-02],
                        [ -1.55334473e-02,  -2.01721191e-02],
                        [ -1.23291016e-02,  -1.65100098e-02],
                        [ -7.99560547e-03,  -1.15051270e-02],
                        [ -4.15039062e-03,  -6.80541992e-03],
                        [ -3.54003906e-03,  -5.24902344e-03],
                        [ -5.58471680e-03,  -6.28662109e-03],
                        [ -6.98852539e-03,  -6.65283203e-03],
                        [ -8.02612305e-03,  -6.80541992e-03],
                        [ -1.04370117e-02,  -8.36181641e-03],
                        [ -1.12915039e-02,  -8.51440430e-03],
                        [ -7.99560547e-03,  -4.82177734e-03],
                        [ -3.63159180e-03,  -1.83105469e-04],
                        [ -1.22070312e-03,   2.28881836e-03],
                        [  8.23974609e-04,   4.11987305e-03],
                        [  4.82177734e-03,   7.75146484e-03],
                        [  9.70458984e-03,   1.21459961e-02],
                        [  1.22985840e-02,   1.41296387e-02],
                        [  1.11999512e-02,   1.22985840e-02],
                        [  8.27026367e-03,   8.69750977e-03],
                        [  6.59179688e-03,   6.37817383e-03],
                        [  6.92749023e-03,   6.10351562e-03],
                        [  7.14111328e-03,   5.79833984e-03],
                        [  6.77490234e-03,   5.06591797e-03],
                        [  9.91821289e-03,   7.99560547e-03],
                        [  1.99890137e-02,   1.79748535e-02],
                        [  3.46679688e-02,   3.27148438e-02],
                        [  5.05676270e-02,   4.87976074e-02],
                        [  6.85119629e-02,   6.70166016e-02],
                        [  9.06066895e-02,   8.94470215e-02],
                        [  1.14868164e-01,   1.14135742e-01],
                        [  1.34429932e-01,   1.34094238e-01],
                        [  1.39892578e-01,   1.39892578e-01],
                        [  1.21826172e-01,   1.22131348e-01],
                        [  7.24182129e-02,   7.29675293e-02],
                        [ -1.16271973e-02,  -1.09558105e-02],
                        [ -1.22985840e-01,  -1.22253418e-01],
                        [ -2.37915039e-01,  -2.37182617e-01],
                        [ -3.20220947e-01,  -3.19641113e-01],
                        [ -3.41094971e-01,  -3.40698242e-01],
                        [ -3.02734375e-01,  -3.02520752e-01],
                        [ -2.40997314e-01,  -2.41027832e-01],
                        [ -1.96411133e-01,  -1.96655273e-01],
                        [ -1.79992676e-01,  -1.80419922e-01],
                        [ -1.70959473e-01,  -1.71478271e-01],
                        [ -1.44714355e-01,  -1.45263672e-01],
                        [ -9.68627930e-02,  -9.73815918e-02],
                        [ -4.01306152e-02,  -4.05273438e-02],
                        [  1.37329102e-02,   1.35192871e-02],
                        [  6.21643066e-02,   6.22253418e-02],
                        [  1.04309082e-01,   1.04644775e-01],
                        [  1.34399414e-01,   1.35040283e-01],
                        [  1.47064209e-01,   1.48040771e-01],
                        [  1.43585205e-01,   1.44836426e-01],
                        [  1.30798340e-01,   1.32202148e-01],
                        [  1.17187500e-01,   1.18713379e-01],
                        [  1.07330322e-01,   1.08856201e-01],
                        [  9.78088379e-02,   9.91821289e-02],
                        [  8.37402344e-02,   8.49304199e-02],
                        [  6.81152344e-02,   6.89392090e-02],
                        [  5.82275391e-02,   5.86242676e-02],
                        [  5.62438965e-02,   5.61523438e-02],
                        [  5.71289062e-02,   5.65490723e-02],
                        [  5.47180176e-02,   5.35583496e-02],
                        [  4.67529297e-02,   4.51354980e-02],
                        [  3.39965820e-02,   3.19519043e-02],
                        [  1.65405273e-02,   1.41906738e-02],
                        [ -4.60815430e-03,  -7.14111328e-03],
                        [ -2.36206055e-02,  -2.61535645e-02],
                        [ -3.14331055e-02,  -3.38439941e-02],
                        [ -2.41699219e-02,  -2.63366699e-02],
                        [ -9.09423828e-03,  -1.08032227e-02],
                        [  1.80053711e-03,   6.40869141e-04],
                        [  3.87573242e-03,   3.35693359e-03],
                        [  1.58691406e-03,   1.73950195e-03],
                        [ -1.22070312e-03,  -3.05175781e-04],
                        [ -5.58471680e-03,  -3.96728516e-03],
                        [ -1.15661621e-02,  -9.36889648e-03],
                        [ -1.40075684e-02,  -1.13220215e-02],
                        [ -8.39233398e-03,  -5.34057617e-03],
                        [  2.74658203e-03,   5.98144531e-03],
                        [  1.38549805e-02,   1.70898438e-02],
                        [  2.18505859e-02,   2.49023438e-02],
                        [  2.45056152e-02,   2.71911621e-02],
                        [  2.05383301e-02,   2.26745605e-02],
                        [  1.43737793e-02,   1.58386230e-02],
                        [  1.29699707e-02,   1.36718750e-02],
                        [  1.72729492e-02,   1.71508789e-02],
                        [  2.24304199e-02,   2.15454102e-02],
                        [  2.57568359e-02,   2.40783691e-02],
                        [  2.88696289e-02,   2.65197754e-02],
                        [  3.34777832e-02,   3.05786133e-02],
                        [  3.78723145e-02,   3.45764160e-02],
                        [  3.93371582e-02,   3.58276367e-02],
                        [  3.81469727e-02,   3.46679688e-02],
                        [  3.72009277e-02,   3.39355469e-02],
                        [  3.81164551e-02,   3.52172852e-02],
                        [  3.94592285e-02,   3.71093750e-02],
                        [  3.86352539e-02,   3.69873047e-02],
                        [  3.38745117e-02,   3.29589844e-02],
                        [  2.52990723e-02,   2.51770020e-02],
                        [  1.64184570e-02,   1.71203613e-02],
                        [  1.08337402e-02,   1.22985840e-02],
                        [  6.56127930e-03,   8.66699219e-03],
                        [ -3.66210938e-04,   2.31933594e-03],
                        [ -8.30078125e-03,  -5.24902344e-03],
                        [ -1.26342773e-02,  -9.36889648e-03],
                        [ -1.29089355e-02,  -9.64355469e-03],
                        [ -1.21765137e-02,  -9.00268555e-03],
                        [ -1.24206543e-02,  -9.61303711e-03],
                        [ -1.47705078e-02,  -1.24511719e-02],
                        [ -2.02026367e-02,  -1.84326172e-02],
                        [ -2.83203125e-02,  -2.71911621e-02],
                        [ -3.71093750e-02,  -3.67126465e-02],
                        [ -4.38842773e-02,  -4.41894531e-02],
                        [ -4.56237793e-02,  -4.65698242e-02],
                        [ -4.09545898e-02,  -4.25109863e-02],
                        [ -3.27758789e-02,  -3.48510742e-02],
                        [ -2.54516602e-02,  -2.78320312e-02],
                        [ -2.04467773e-02,  -2.30407715e-02],
                        [ -1.69372559e-02,  -1.96228027e-02],
                        [ -1.37329102e-02,  -1.63574219e-02],
                        [ -9.70458984e-03,  -1.21154785e-02],
                        [ -6.22558594e-03,  -8.33129883e-03],
                        [ -7.50732422e-03,  -9.18579102e-03],
                        [ -1.44653320e-02,  -1.56555176e-02],
                        [ -2.19421387e-02,  -2.26440430e-02],
                        [ -2.45971680e-02,  -2.48107910e-02],
                        [ -2.22167969e-02,  -2.19116211e-02],
                        [ -1.69677734e-02,  -1.62048340e-02],
                        [ -9.97924805e-03,  -8.85009766e-03],
                        [ -3.66210938e-03,  -2.22778320e-03],
                        [ -3.14331055e-03,  -1.49536133e-03],
                        [ -9.55200195e-03,  -7.78198242e-03],
                        [ -1.49841309e-02,  -1.31835938e-02],
                        [ -1.15661621e-02,  -9.79614258e-03],
                        [ -2.50244141e-03,  -8.85009766e-04],
                        [  3.08227539e-03,   4.54711914e-03],
                        [  3.78417969e-03,   5.03540039e-03],
                        [  5.21850586e-03,   6.19506836e-03],
                        [  8.30078125e-03,   9.00268555e-03],
                        [  9.06372070e-03,   9.49096680e-03],
                        [  7.99560547e-03,   8.17871094e-03],
                        [  9.15527344e-03,   9.09423828e-03],
                        [  1.32446289e-02,   1.29394531e-02],
                        [  2.02331543e-02,   1.97448730e-02],
                        [  3.18603516e-02,   3.12194824e-02],
                        [  4.78820801e-02,   4.70581055e-02],
                        [  6.73217773e-02,   6.63757324e-02],
                        [  9.24987793e-02,   9.14611816e-02],
                        [  1.22619629e-01,   1.21490479e-01],
                        [  1.46301270e-01,   1.45141602e-01],
                        [  1.48590088e-01,   1.47399902e-01],
                        [  1.21490479e-01,   1.20300293e-01],
                        [  6.25610352e-02,   6.13708496e-02],
                        [ -2.91442871e-02,  -3.02429199e-02],
                        [ -1.44195557e-01,  -1.45233154e-01],
                        [ -2.54211426e-01,  -2.55096436e-01],
                        [ -3.23364258e-01,  -3.24066162e-01],
                        [ -3.32794189e-01,  -3.33282471e-01],
                        [ -2.93212891e-01,  -2.93426514e-01],
                        [ -2.36328125e-01,  -2.36236572e-01],
                        [ -1.93023682e-01,  -1.92596436e-01],
                        [ -1.73095703e-01,  -1.72363281e-01],
                        [ -1.62017822e-01,  -1.60980225e-01],
                        [ -1.39099121e-01,  -1.37725830e-01],
                        [ -9.82360840e-02,  -9.65881348e-02],
                        [ -4.74548340e-02,  -4.56237793e-02],
                        [  6.31713867e-03,   8.30078125e-03],
                        [  5.95397949e-02,   6.15844727e-02],
                        [  1.03668213e-01,   1.05621338e-01],
                        [  1.28906250e-01,   1.30737305e-01],
                        [  1.35742188e-01,   1.37298584e-01],
                        [  1.33056641e-01,   1.34246826e-01],
                        [  1.28417969e-01,   1.29150391e-01],
                        [  1.23016357e-01,   1.23229980e-01],
                        [  1.12915039e-01,   1.12579346e-01],
                        [  9.59777832e-02,   9.50622559e-02],
                        [  7.99560547e-02,   7.84912109e-02],
                        [  7.63854980e-02,   7.44323730e-02],
                        [  8.33740234e-02,   8.09631348e-02],
                        [  8.55102539e-02,   8.27941895e-02],
                        [  7.40966797e-02,   7.12585449e-02],
                        [  5.42907715e-02,   5.14221191e-02],
                        [  3.20739746e-02,   2.93579102e-02],
                        [  8.14819336e-03,   5.73730469e-03],
                        [ -1.51672363e-02,  -1.71203613e-02],
                        [ -3.16772461e-02,  -3.30505371e-02],
                        [ -3.62854004e-02,  -3.69567871e-02],
                        [ -2.89001465e-02,  -2.88391113e-02],
                        [ -1.52893066e-02,  -1.44958496e-02],
                        [ -3.99780273e-03,  -2.44140625e-03],
                        [  3.05175781e-05,   2.28881836e-03],
                        [ -9.46044922e-04,   1.83105469e-03],
                        [ -1.22070312e-03,   2.01416016e-03],
                        [  3.35693359e-04,   3.81469727e-03],
                        [ -1.06811523e-03,   2.44140625e-03],
                        [ -6.28662109e-03,  -2.92968750e-03],
                        [ -7.50732422e-03,  -4.48608398e-03],
                        [  9.15527344e-04,   3.38745117e-03],
                        [  1.31530762e-02,   1.49536133e-02],
                        [  1.95312500e-02,   2.05078125e-02],
                        [  1.86767578e-02,   1.87988281e-02],
                        [  1.71203613e-02,   1.63269043e-02],
                        [  1.96838379e-02,   1.80358887e-02],
                        [  2.49023438e-02,   2.24609375e-02],
                        [  2.81677246e-02,   2.50854492e-02],
                        [  2.77099609e-02,   2.41394043e-02],
                        [  2.62451172e-02,   2.24304199e-02],
                        [  2.71301270e-02,   2.32238770e-02],
                        [  3.02734375e-02,   2.65502930e-02],
                        [  3.48205566e-02,   3.15246582e-02],
                        [  4.04052734e-02,   3.77197266e-02],
                        [  4.38842773e-02,   4.19311523e-02],
                        [  4.13208008e-02,   4.02526855e-02],
                        [  3.49731445e-02,   3.48815918e-02],
                        [  3.04565430e-02,   3.13110352e-02],
                        [  2.78320312e-02,   2.96325684e-02],
                        [  2.26135254e-02,   2.52075195e-02],
                        [  1.44653320e-02,   1.77307129e-02],
                        [  8.69750977e-03,   1.24206543e-02],
                        [  7.47680664e-03,   1.14746094e-02],
                        [  5.82885742e-03,   9.85717773e-03],
                        [  3.66210938e-04,   4.15039062e-03],
                        [ -4.91333008e-03,  -1.55639648e-03],
                        [ -6.28662109e-03,  -3.60107422e-03],
                        [ -5.73730469e-03,  -3.87573242e-03],
                        [ -4.42504883e-03,  -3.50952148e-03],
                        [ -1.49536133e-03,  -1.52587891e-03],
                        [ -5.79833984e-04,  -1.61743164e-03],
                        [ -6.95800781e-03,  -8.91113281e-03],
                        [ -1.75781250e-02,  -2.02941895e-02],
                        [ -2.49938965e-02,  -2.83508301e-02],
                        [ -2.81982422e-02,  -3.19824219e-02],
                        [ -2.94189453e-02,  -3.34167480e-02],
                        [ -2.81677246e-02,  -3.21044922e-02],
                        [ -2.62451172e-02,  -2.99072266e-02],
                        [ -2.83203125e-02,  -3.14941406e-02],
                        [ -3.32336426e-02,  -3.56750488e-02],
                        [ -3.50341797e-02,  -3.66516113e-02],
                        [ -3.34777832e-02,  -3.41491699e-02],
                        [ -3.18908691e-02,  -3.15856934e-02],
                        [ -2.90527344e-02,  -2.78015137e-02],
                        [ -2.31628418e-02,  -2.10266113e-02],
                        [ -1.68457031e-02,  -1.39770508e-02],
                        [ -1.13525391e-02,  -7.93457031e-03],
                        [ -4.15039062e-03,  -3.96728516e-04],
                        [  3.02124023e-03,   6.86645508e-03],
                        [  4.39453125e-03,   8.11767578e-03],
                        [  1.83105469e-04,   3.60107422e-03],
                        [ -3.99780273e-03,  -1.19018555e-03],
                        [ -6.43920898e-03,  -4.33349609e-03],
                        [ -9.09423828e-03,  -7.84301758e-03],
                        [ -1.19323730e-02,  -1.15966797e-02],
                        [ -1.27258301e-02,  -1.33666992e-02],
                        [ -9.97924805e-03,  -1.15051270e-02],
                        [ -4.27246094e-03,  -6.56127930e-03],
                        [  1.25122070e-03,  -1.70898438e-03],
                        [  3.29589844e-03,  -1.52587891e-04],
                        [  3.29589844e-03,  -3.66210938e-04],
                        [  6.16455078e-03,   2.47192383e-03],
                        [  1.19018555e-02,   8.39233398e-03],
                        [  1.54418945e-02,   1.23596191e-02],
                        [  1.55639648e-02,   1.31225586e-02],
                        [  1.55029297e-02,   1.37634277e-02],
                        [  1.68151855e-02,   1.58996582e-02],
                        [  2.17895508e-02,   2.18200684e-02],
                        [  3.56140137e-02,   3.65295410e-02],
                        [  5.99975586e-02,   6.17065430e-02],
                        [  9.10339355e-02,   9.34753418e-02],
                        [  1.22344971e-01,   1.25366211e-01],
                        [  1.45202637e-01,   1.48559570e-01],
                        [  1.49078369e-01,   1.52618408e-01],
                        [  1.24481201e-01,   1.27990723e-01],
                        [  6.41479492e-02,   6.73828125e-02],
                        [ -3.29589844e-02,  -3.02124023e-02],
                        [ -1.53259277e-01,  -1.51062012e-01],
                        [ -2.64892578e-01,  -2.63427734e-01],
                        [ -3.31146240e-01,  -3.30535889e-01],
                        [ -3.33892822e-01,  -3.34136963e-01],
                        [ -2.87231445e-01,  -2.88238525e-01],
                        [ -2.27264404e-01,  -2.29064941e-01],
                        [ -1.86096191e-01,  -1.88537598e-01],
                        [ -1.70837402e-01,  -1.73736572e-01],
                        [ -1.65771484e-01,  -1.69006348e-01],
                        [ -1.51428223e-01,  -1.54815674e-01],
                        [ -1.18499756e-01,  -1.21765137e-01],
                        [ -6.92749023e-02,  -7.22656250e-02],
                        [ -1.11083984e-02,  -1.37023926e-02],
                        [  5.07812500e-02,   4.87670898e-02],
                        [  1.10290527e-01,   1.09008789e-01],
                        [  1.52618408e-01,   1.52069092e-01],
                        [  1.64764404e-01,   1.64947510e-01],
                        [  1.53839111e-01,   1.54846191e-01],
                        [  1.38488770e-01,   1.40167236e-01],
                        [  1.25793457e-01,   1.28021240e-01],
                        [  1.12548828e-01,   1.15295410e-01],
                        [  1.01226807e-01,   1.04248047e-01],
                        [  9.73205566e-02,   1.00463867e-01],
                        [  9.85107422e-02,   1.01623535e-01],
                        [  9.73205566e-02,   1.00219727e-01],
                        [  8.84399414e-02,   9.09423828e-02],
                        [  6.79016113e-02,   6.98852539e-02],
                        [  3.48205566e-02,   3.62243652e-02],
                        [ -3.66210938e-03,  -2.92968750e-03],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -5.23376465e-02,  -5.30395508e-02],
                        [ -4.92858887e-02,  -5.05981445e-02],
                        [ -2.92358398e-02,  -3.11279297e-02],
                        [ -4.88281250e-03,  -7.23266602e-03],
                        [  9.15527344e-03,   6.46972656e-03],
                        [  1.04064941e-02,   7.53784180e-03],
                        [  7.90405273e-03,   4.97436523e-03],
                        [  6.80541992e-03,   3.99780273e-03],
                        [  4.54711914e-03,   2.01416016e-03],
                        [  5.49316406e-04,  -1.58691406e-03],
                        [ -1.06811523e-03,  -2.77709961e-03],
                        [  2.34985352e-03,   1.22070312e-03],
                        [  1.11999512e-02,   1.07116699e-02],
                        [  2.34069824e-02,   2.34985352e-02],
                        [  3.26232910e-02,   3.33557129e-02],
                        [  3.37219238e-02,   3.50036621e-02],
                        [  2.93884277e-02,   3.11889648e-02],
                        [  2.61230469e-02,   2.83203125e-02],
                        [  2.61840820e-02,   2.86865234e-02],
                        [  2.74047852e-02,   3.00903320e-02],
                        [  2.70996094e-02,   2.98156738e-02],
                        [  2.45361328e-02,   2.71606445e-02],
                        [  2.24609375e-02,   2.48718262e-02],
                        [  2.57263184e-02,   2.78625488e-02],
                        [  3.51562500e-02,   3.68652344e-02],
                        [  4.44335938e-02,   4.56542969e-02],
                        [  4.72412109e-02,   4.79125977e-02],
                        [  4.42504883e-02,   4.43725586e-02],
                        [  4.04357910e-02,   3.99475098e-02],
                        [  3.87573242e-02,   3.77197266e-02],
                        [  3.80859375e-02,   3.65600586e-02],
                        [  3.47900391e-02,   3.27758789e-02],
                        [  2.71606445e-02,   2.47802734e-02],
                        [  1.79138184e-02,   1.53198242e-02],
                        [  1.04064941e-02,   7.65991211e-03],
                        [  5.27954102e-03,   2.47192383e-03],
                        [  2.07519531e-03,  -5.79833984e-04],
                        [  5.49316406e-04,  -1.89208984e-03],
                        [ -1.40380859e-03,  -3.54003906e-03],
                        [ -6.22558594e-03,  -7.87353516e-03],
                        [ -1.42517090e-02,  -1.53198242e-02],
                        [ -2.48413086e-02,  -2.53601074e-02],
                        [ -3.60107422e-02,  -3.58886719e-02],
                        [ -4.27551270e-02,  -4.19616699e-02],
                        [ -4.15344238e-02,  -4.01000977e-02],
                        [ -3.43933105e-02,  -3.24096680e-02],
                        [ -2.55432129e-02,  -2.30712891e-02],
                        [ -1.74255371e-02,  -1.45263672e-02],
                        [ -1.15966797e-02,  -8.48388672e-03],
                        [ -9.03320312e-03,  -5.79833984e-03],
                        [ -9.46044922e-03,  -6.22558594e-03],
                        [ -1.30920410e-02,  -1.00708008e-02],
                        [ -1.99279785e-02,  -1.72729492e-02],
                        [ -2.67944336e-02,  -2.45971680e-02],
                        [ -2.92358398e-02,  -2.76489258e-02],
                        [ -2.69470215e-02,  -2.60925293e-02],
                        [ -2.33459473e-02,  -2.32543945e-02],
                        [ -2.02636719e-02,  -2.09350586e-02],
                        [ -1.77917480e-02,  -1.92871094e-02],
                        [ -1.67541504e-02,  -1.90124512e-02],
                        [ -1.60522461e-02,  -1.89208984e-02],
                        [ -1.31530762e-02,  -1.65100098e-02],
                        [ -9.27734375e-03,  -1.30310059e-02],
                        [ -7.23266602e-03,  -1.11694336e-02],
                        [ -5.67626953e-03,  -9.55200195e-03],
                        [ -3.63159180e-03,  -7.32421875e-03],
                        [ -4.69970703e-03,  -7.93457031e-03],
                        [ -9.67407227e-03,  -1.22985840e-02],
                        [ -1.28173828e-02,  -1.47094727e-02],
                        [ -1.01013184e-02,  -1.11389160e-02],
                        [ -4.33349609e-03,  -4.39453125e-03],
                        [  9.15527344e-05,   1.03759766e-03],
                        [  2.47192383e-03,   4.33349609e-03],
                        [  4.11987305e-03,   6.86645508e-03],
                        [  5.61523438e-03,   9.12475586e-03],
                        [  6.83593750e-03,   1.08947754e-02],
                        [  7.99560547e-03,   1.24511719e-02],
                        [  9.79614258e-03,   1.44042969e-02],
                        [  1.40075684e-02,   1.85241699e-02],
                        [  2.28271484e-02,   2.70080566e-02],
                        [  3.61022949e-02,   3.97033691e-02],
                        [  5.18188477e-02,   5.46569824e-02],
                        [  6.89086914e-02,   7.08007812e-02],
                        [  8.66699219e-02,   8.74938965e-02],
                        [  1.02752686e-01,   1.02447510e-01],
                        [  1.12518311e-01,   1.11114502e-01],
                        [  1.08673096e-01,   1.06201172e-01],
                        [  8.25195312e-02,   7.91015625e-02],
                        [  2.90222168e-02,   2.48107910e-02],
                        [ -4.97131348e-02,  -5.44433594e-02],
                        [ -1.43737793e-01,  -1.48803711e-01],
                        [ -2.34252930e-01,  -2.39379883e-01],
                        [ -2.94799805e-01,  -2.99652100e-01],
                        [ -3.04992676e-01,  -3.09356689e-01],
                        [ -2.70538330e-01,  -2.74169922e-01],
                        [ -2.22900391e-01,  -2.25555420e-01],
                        [ -1.90124512e-01,  -1.91680908e-01],
                        [ -1.73065186e-01,  -1.73431396e-01],
                        [ -1.54968262e-01,  -1.54083252e-01],
                        [ -1.25579834e-01,  -1.23504639e-01],
                        [ -8.84704590e-02,  -8.53271484e-02],
                        [ -4.96215820e-02,  -4.55627441e-02],
                        [ -7.65991211e-03,  -2.86865234e-03],
                        [  4.12292480e-02,   4.64477539e-02],
                        [  9.23767090e-02,   9.77783203e-02],
                        [  1.32934570e-01,   1.38183594e-01],
                        [  1.53076172e-01,   1.57897949e-01],
                        [  1.54296875e-01,   1.58477783e-01],
                        [  1.45507812e-01,   1.48773193e-01],
                        [  1.34338379e-01,   1.36535645e-01],
                        [  1.24206543e-01,   1.25183105e-01],
                        [  1.15875244e-01,   1.15600586e-01],
                        [  1.08489990e-01,   1.06964111e-01],
                        [  1.00769043e-01,   9.80834961e-02],
                        [  9.13085938e-02,   8.76159668e-02],
                        [  7.68737793e-02,   7.23876953e-02],
                        [  5.42297363e-02,   4.91943359e-02],
                        [  2.41088867e-02,   1.87988281e-02],
                        [ -8.88061523e-03,  -1.41906738e-02],
                        [ -3.74755859e-02,  -4.24804688e-02],
                        [ -5.39245605e-02,  -5.83801270e-02],
                        [ -5.50231934e-02,  -5.86547852e-02],
                        [ -4.28771973e-02,  -4.55017090e-02],
                        [ -2.25830078e-02,  -2.40783691e-02],
                        [ -3.20434570e-03,  -3.50952148e-03],
                        [  6.13403320e-03,   7.08007812e-03],
                        [  5.58471680e-03,   7.65991211e-03],
                        [  2.99072266e-03,   6.10351562e-03],
                        [  2.34985352e-03,   6.31713867e-03],
                        [  1.52587891e-03,   6.10351562e-03],
                        [  4.57763672e-04,   5.40161133e-03],
                        [  3.23486328e-03,   8.27026367e-03],
                        [  1.14135742e-02,   1.62963867e-02],
                        [  2.26135254e-02,   2.70385742e-02],
                        [  3.35083008e-02,   3.72619629e-02],
                        [  3.96118164e-02,   4.25109863e-02],
                        [  3.72619629e-02,   3.91540527e-02],
                        [  2.97851562e-02,   3.05480957e-02],
                        [  2.48107910e-02,   2.45056152e-02],
                        [  2.47497559e-02,   2.33459473e-02],
                        [  2.66418457e-02,   2.42614746e-02],
                        [  2.95715332e-02,   2.63366699e-02],
                        [  3.47290039e-02,   3.08532715e-02],
                        [  4.10156250e-02,   3.67126465e-02],
                        [  4.61120605e-02,   4.16259766e-02],
                        [  4.90112305e-02,   4.45861816e-02],
                        [  4.90417480e-02,   4.48913574e-02],
                        [  4.62036133e-02,   4.25720215e-02],
                        [  4.32128906e-02,   4.02526855e-02],
                        [  4.21447754e-02,   4.00390625e-02],
                        [  4.05578613e-02,   3.93371582e-02],
                        [  3.51562500e-02,   3.49121094e-02],
                        [  2.74963379e-02,   2.81982422e-02],
                        [  2.13928223e-02,   2.29797363e-02],
                        [  1.79748535e-02,   2.03552246e-02],
                        [  1.61132812e-02,   1.91345215e-02],
                        [  1.52282715e-02,   1.86767578e-02],
                        [  1.31225586e-02,   1.68457031e-02],
                        [  5.24902344e-03,   9.03320312e-03],
                        [ -8.97216797e-03,  -5.34057617e-03],
                        [ -2.31323242e-02,  -1.98059082e-02],
                        [ -3.13720703e-02,  -2.85339355e-02],
                        [ -3.42712402e-02,  -3.20434570e-02],
                        [ -3.46374512e-02,  -3.31420898e-02],
                        [ -3.28979492e-02,  -3.21655273e-02],
                        [ -2.80456543e-02,  -2.80761719e-02],
                        [ -2.08740234e-02,  -2.16979980e-02],
                        [ -1.36413574e-02,  -1.51062012e-02],
                        [ -8.27026367e-03,  -1.03149414e-02],
                        [ -6.71386719e-03,  -9.24682617e-03],
                        [ -9.76562500e-03,  -1.26342773e-02],
                        [ -1.50756836e-02,  -1.80664062e-02],
                        [ -1.90429688e-02,  -2.20642090e-02],
                        [ -2.00805664e-02,  -2.29492188e-02],
                        [ -1.87988281e-02,  -2.13623047e-02],
                        [ -1.74255371e-02,  -1.95922852e-02],
                        [ -1.81274414e-02,  -1.98059082e-02],
                        [ -1.98364258e-02,  -2.09350586e-02],
                        [ -1.92565918e-02,  -1.97753906e-02],
                        [ -1.51977539e-02,  -1.51367188e-02],
                        [ -9.85717773e-03,  -9.24682617e-03],
                        [ -6.95800781e-03,  -5.79833984e-03],
                        [ -7.44628906e-03,  -5.85937500e-03],
                        [ -7.50732422e-03,  -5.55419922e-03],
                        [ -2.86865234e-03,  -6.71386719e-04],
                        [  3.99780273e-03,   6.31713867e-03],
                        [  5.24902344e-03,   7.56835938e-03],
                        [ -1.64794922e-03,   5.79833984e-04],
                        [ -1.03454590e-02,  -8.30078125e-03],
                        [ -1.40075684e-02,  -1.22375488e-02],
                        [ -1.19018555e-02,  -1.04980469e-02],
                        [ -7.14111328e-03,  -6.16455078e-03],
                        [ -3.17382812e-03,  -2.62451172e-03],
                        [ -1.52587891e-04,  -6.10351562e-05],
                        [  5.31005859e-03,   4.94384766e-03],
                        [  1.30004883e-02,   1.22680664e-02],
                        [  1.76696777e-02,   1.65405273e-02],
                        [  1.90124512e-02,   1.75781250e-02],
                        [  2.37426758e-02,   2.21252441e-02],
                        [  3.42712402e-02,   3.24707031e-02],
                        [  4.44946289e-02,   4.26025391e-02],
                        [  5.02319336e-02,   4.84008789e-02],
                        [  5.63964844e-02,   5.46875000e-02],
                        [  7.00378418e-02,   6.84814453e-02],
                        [  9.07592773e-02,   8.94470215e-02],
                        [  1.10046387e-01,   1.09039307e-01],
                        [  1.14776611e-01,   1.14105225e-01],
                        [  9.20104980e-02,   9.16748047e-02],
                        [  3.62854004e-02,   3.63464355e-02],
                        [ -4.80346680e-02,  -4.76074219e-02],
                        [ -1.48132324e-01,  -1.47369385e-01],
                        [ -2.40875244e-01,  -2.39807129e-01],
                        [ -2.97271729e-01,  -2.95928955e-01],
                        [ -3.00415039e-01,  -2.98889160e-01],
                        [ -2.60101318e-01,  -2.58453369e-01],
                        [ -2.07244873e-01,  -2.05566406e-01],
                        [ -1.71325684e-01,  -1.69677734e-01],
                        [ -1.58966064e-01,  -1.57440186e-01],
                        [ -1.55334473e-01,  -1.54022217e-01],
                        [ -1.44165039e-01,  -1.43096924e-01],
                        [ -1.20239258e-01,  -1.19445801e-01],
                        [ -8.51440430e-02,  -8.47167969e-02],
                        [ -3.97033691e-02,  -3.96118164e-02],
                        [  1.68151855e-02,   1.65100098e-02],
                        [  8.00170898e-02,   7.93762207e-02],
                        [  1.36535645e-01,   1.35528564e-01],
                        [  1.70776367e-01,   1.69525146e-01],
                        [  1.77124023e-01,   1.75659180e-01],
                        [  1.62872314e-01,   1.61254883e-01],
                        [  1.41998291e-01,   1.40319824e-01],
                        [  1.26953125e-01,   1.25305176e-01],
                        [  1.21276855e-01,   1.19750977e-01],
                        [  1.18164062e-01,   1.16821289e-01],
                        [  1.08581543e-01,   1.07513428e-01],
                        [  9.01489258e-02,   8.94165039e-02],
                        [  6.50634766e-02,   6.46667480e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [ -4.54711914e-03,  -4.15039062e-03],
                        [ -4.07714844e-02,  -4.00085449e-02],
                        [ -6.18896484e-02,  -6.07910156e-02],
                        [ -6.12182617e-02,  -5.98754883e-02],
                        [ -4.40673828e-02,  -4.25109863e-02],
                        [ -2.07214355e-02,  -1.90734863e-02],
                        [  5.49316406e-04,   2.22778320e-03],
                        [  1.42517090e-02,   1.58691406e-02],
                        [  1.73034668e-02,   1.87377930e-02],
                        [  1.13220215e-02,   1.24816895e-02],
                        [  1.67846680e-03,   2.56347656e-03],
                        [ -7.23266602e-03,  -6.71386719e-03],
                        [ -1.29394531e-02,  -1.28479004e-02],
                        [ -1.13525391e-02,  -1.16271973e-02],
                        [  1.06811523e-03,   3.96728516e-04],
                        [  2.12097168e-02,   2.01721191e-02],
                        [  4.13208008e-02,   4.00085449e-02],
                        [  5.43212891e-02,   5.28259277e-02],
                        [  5.50537109e-02,   5.34362793e-02],
                        [  4.40063477e-02,   4.23278809e-02],
                        [  3.03344727e-02,   2.87170410e-02],
                        [  2.33459473e-02,   2.19421387e-02],
                        [  2.28576660e-02,   2.16674805e-02],
                        [  2.35900879e-02,   2.27050781e-02],
                        [  2.42309570e-02,   2.37426758e-02],
                        [  2.60620117e-02,   2.59704590e-02],
                        [  2.87780762e-02,   2.90527344e-02],
                        [  3.28674316e-02,   3.35693359e-02],
                        [  3.93676758e-02,   4.04052734e-02],
                        [  4.41589355e-02,   4.54711914e-02],
                        [  4.20227051e-02,   4.35485840e-02],
                        [  3.61328125e-02,   3.77807617e-02],
                        [  3.36303711e-02,   3.52783203e-02],
                        [  3.49731445e-02,   3.65295410e-02],
                        [  3.63464355e-02,   3.77197266e-02],
                        [  3.66821289e-02,   3.77807617e-02],
                        [  3.59191895e-02,   3.66821289e-02],
                        [  3.24096680e-02,   3.28063965e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.84631348e-02,   1.80664062e-02],
                        [  9.42993164e-03,   8.66699219e-03],
                        [ -3.35693359e-03,  -4.42504883e-03],
                        [ -1.75781250e-02,  -1.89208984e-02],
                        [ -2.75573730e-02,  -2.90832520e-02],
                        [ -3.13415527e-02,  -3.29284668e-02],
                        [ -3.10363770e-02,  -3.26232910e-02],
                        [ -2.82897949e-02,  -2.97546387e-02],
                        [ -2.49633789e-02,  -2.62145996e-02],
                        [ -2.41394043e-02,  -2.50854492e-02],
                        [ -2.56652832e-02,  -2.63061523e-02],
                        [ -2.55737305e-02,  -2.58483887e-02],
                        [ -2.32238770e-02,  -2.30712891e-02],
                        [ -2.31933594e-02,  -2.26745605e-02],
                        [ -2.60620117e-02,  -2.52075195e-02],
                        [ -2.63366699e-02,  -2.51770020e-02],
                        [ -2.32543945e-02,  -2.18811035e-02],
                        [ -2.20947266e-02,  -2.05993652e-02],
                        [ -2.26135254e-02,  -2.10571289e-02],
                        [ -2.05078125e-02,  -1.90124512e-02],
                        [ -1.77612305e-02,  -1.63879395e-02],
                        [ -1.70288086e-02,  -1.58996582e-02],
                        [ -1.34887695e-02,  -1.26647949e-02],
                        [ -4.88281250e-03,  -4.39453125e-03],
                        [  9.46044922e-04,   1.06811523e-03],
                        [ -2.41088867e-03,  -2.65502930e-03],
                        [ -1.10168457e-02,  -1.16271973e-02],
                        [ -1.73950195e-02,  -1.83410645e-02],
                        [ -1.73645020e-02,  -1.85546875e-02],
                        [ -1.22985840e-02,  -1.36718750e-02],
                        [ -9.42993164e-03,  -1.08947754e-02],
                        [ -1.33972168e-02,  -1.48620605e-02],
                        [ -1.79443359e-02,  -1.93481445e-02],
                        [ -1.42211914e-02,  -1.54418945e-02],
                        [ -4.60815430e-03,  -5.58471680e-03],
                        [  1.83105469e-03,   1.12915039e-03],
                        [  3.38745117e-03,   2.99072266e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  9.21630859e-03,   9.52148438e-03],
                        [  1.15661621e-02,   1.22070312e-02],
                        [  9.85717773e-03,   1.08032227e-02],
                        [  6.22558594e-03,   7.38525391e-03],
                        [  6.34765625e-03,   7.65991211e-03],
                        [  1.41906738e-02,   1.55639648e-02],
                        [  2.74353027e-02,   2.88085938e-02],
                        [  4.18701172e-02,   4.31518555e-02],
                        [  5.80444336e-02,   5.91430664e-02],
                        [  7.94372559e-02,   8.02917480e-02],
                        [  1.06109619e-01,   1.06689453e-01],
                        [  1.30340576e-01,   1.30615234e-01],
                        [  1.36749268e-01,   1.36718750e-01],
                        [  1.11083984e-01,   1.10748291e-01],
                        [  4.94689941e-02,   4.88281250e-02],
                        [ -4.20532227e-02,  -4.29077148e-02],
                        [ -1.49810791e-01,  -1.50848389e-01],
                        [ -2.49450684e-01,  -2.50640869e-01],
                        [ -3.10150146e-01,  -3.11370850e-01],
                        [ -3.13781738e-01,  -3.14971924e-01],
                        [ -2.71118164e-01,  -2.72247314e-01],
                        [ -2.14996338e-01,  -2.15942383e-01],
                        [ -1.74743652e-01,  -1.75476074e-01],
                        [ -1.57073975e-01,  -1.57562256e-01],
                        [ -1.48590088e-01,  -1.48834229e-01],
                        [ -1.34368896e-01,  -1.34338379e-01],
                        [ -1.12121582e-01,  -1.11846924e-01],
                        [ -8.59680176e-02,  -8.54492188e-02],
                        [ -5.27954102e-02,  -5.20629883e-02],
                        [ -4.57763672e-03,  -3.69262695e-03],
                        [  5.75256348e-02,   5.85021973e-02],
                        [  1.18499756e-01,   1.19506836e-01],
                        [  1.60461426e-01,   1.61468506e-01],
                        [  1.77093506e-01,   1.78009033e-01],
                        [  1.76422119e-01,   1.77215576e-01],
                        [  1.70318604e-01,   1.70928955e-01],
                        [  1.63024902e-01,   1.63452148e-01],
                        [  1.50360107e-01,   1.50604248e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  9.69543457e-02,   9.67712402e-02],
                        [  6.44531250e-02,   6.40869141e-02],
                        [  3.26538086e-02,   3.21350098e-02],
                        [  1.22070312e-03,   5.79833984e-04],
                        [ -2.73437500e-02,  -2.80761719e-02],
                        [ -4.66918945e-02,  -4.74548340e-02],
                        [ -5.00488281e-02,  -5.07812500e-02],
                        [ -3.74145508e-02,  -3.81164551e-02],
                        [ -1.97448730e-02,  -2.03857422e-02],
                        [ -9.55200195e-03,  -1.00402832e-02],
                        [ -7.04956055e-03,  -7.41577148e-03],
                        [ -4.39453125e-03,  -4.63867188e-03],
                        [ -5.79833984e-04,  -6.71386719e-04],
                        [ -1.03759766e-03,  -1.00708008e-03],
                        [ -4.97436523e-03,  -4.79125977e-03],
                        [ -4.91333008e-03,  -4.63867188e-03],
                        [  2.07519531e-03,   2.47192383e-03],
                        [  1.34277344e-02,   1.38854980e-02],
                        [  2.72521973e-02,   2.77099609e-02],
                        [  4.20532227e-02,   4.25415039e-02],
                        [  5.40161133e-02,   5.44738770e-02],
                        [  5.83496094e-02,   5.87768555e-02],
                        [  5.31616211e-02,   5.35278320e-02],
                        [  4.23583984e-02,   4.26940918e-02],
                        [  3.35693359e-02,   3.38134766e-02],
                        [  2.91442871e-02,   2.92968750e-02],
                        [  2.40173340e-02,   2.41088867e-02],
                        [  1.64489746e-02,   1.64794922e-02],
                        [  1.30004883e-02,   1.29394531e-02],
                        [  1.69372559e-02,   1.68151855e-02],
                        [  2.23999023e-02,   2.22473145e-02],
                        [  2.49938965e-02,   2.47802734e-02],
                        [  2.75268555e-02,   2.73132324e-02],
                        [  3.22570801e-02,   3.20434570e-02],
                        [  3.65600586e-02,   3.63159180e-02],
                        [  3.80554199e-02,   3.78112793e-02],
                        [  3.77197266e-02,   3.74755859e-02],
                        [  3.70788574e-02,   3.68347168e-02],
                        [  3.73229980e-02,   3.70788574e-02],
                        [  3.91845703e-02,   3.89709473e-02],
                        [  4.08630371e-02,   4.06799316e-02],
                        [  3.77197266e-02,   3.75366211e-02],
                        [  2.81677246e-02,   2.80151367e-02],
                        [  1.58691406e-02,   1.57775879e-02],
                        [  4.88281250e-03,   4.82177734e-03],
                        [ -2.38037109e-03,  -2.41088867e-03],
                        [ -5.00488281e-03,  -4.97436523e-03],
                        [ -6.34765625e-03,  -6.28662109e-03],
                        [ -1.11083984e-02,  -1.09863281e-02],
                        [ -1.86462402e-02,  -1.84631348e-02],
                        [ -2.61230469e-02,  -2.59094238e-02],
                        [ -3.42712402e-02,  -3.39965820e-02],
                        [ -4.28161621e-02,  -4.25109863e-02],
                        [ -4.71801758e-02,  -4.68750000e-02],
                        [ -4.49218750e-02,  -4.45861816e-02],
                        [ -3.96728516e-02,  -3.93676758e-02],
                        [ -3.38134766e-02,  -3.35083008e-02],
                        [ -2.57263184e-02,  -2.54821777e-02],
                        [ -1.85852051e-02,  -1.83715820e-02],
                        [ -1.94396973e-02,  -1.93176270e-02],
                        [ -2.65502930e-02,  -2.65197754e-02],
                        [ -3.06091309e-02,  -3.06396484e-02],
                        [ -2.92663574e-02,  -2.93884277e-02],
                        [ -2.68859863e-02,  -2.70690918e-02],
                        [ -2.30102539e-02,  -2.32849121e-02],
                        [ -1.39160156e-02,  -1.42517090e-02],
                        [ -2.34985352e-03,  -2.74658203e-03],
                        [  3.63159180e-03,   3.20434570e-03],
                        [  9.76562500e-04,   5.49316406e-04],
                        [ -5.21850586e-03,  -5.61523438e-03],
                        [ -9.06372070e-03,  -9.42993164e-03],
                        [ -1.00708008e-02,  -1.03759766e-02],
                        [ -1.16882324e-02,  -1.19323730e-02],
                        [ -1.59606934e-02,  -1.60827637e-02],
                        [ -1.98364258e-02,  -1.98669434e-02],
                        [ -1.85546875e-02,  -1.85241699e-02],
                        [ -1.26037598e-02,  -1.24206543e-02],
                        [ -7.47680664e-03,  -7.20214844e-03],
                        [ -6.86645508e-03,  -6.53076172e-03],
                        [ -8.72802734e-03,  -8.33129883e-03],
                        [ -8.39233398e-03,  -7.96508789e-03],
                        [ -4.11987305e-03,  -3.66210938e-03],
                        [  2.04467773e-03,   2.47192383e-03],
                        [  6.95800781e-03,   7.38525391e-03],
                        [  9.18579102e-03,   9.55200195e-03],
                        [  1.10778809e-02,   1.13525391e-02],
                        [  1.78833008e-02,   1.80969238e-02],
                        [  3.18298340e-02,   3.19213867e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  6.93054199e-02,   6.91833496e-02],
                        [  9.15832520e-02,   9.13696289e-02],
                        [  1.16577148e-01,   1.16271973e-01],
                        [  1.36138916e-01,   1.35772705e-01],
                        [  1.36535645e-01,   1.36138916e-01],
                        [  1.07879639e-01,   1.07452393e-01],
                        [  4.87060547e-02,   4.83093262e-02],
                        [ -3.72619629e-02,  -3.76586914e-02],
                        [ -1.41845703e-01,  -1.42181396e-01],
                        [ -2.44812012e-01,  -2.45086670e-01],
                        [ -3.14147949e-01,  -3.14361572e-01],
                        [ -3.25775146e-01,  -3.25866699e-01],
                        [ -2.85034180e-01,  -2.85034180e-01],
                        [ -2.23907471e-01,  -2.23846436e-01],
                        [ -1.75781250e-01,  -1.75598145e-01],
                        [ -1.52374268e-01,  -1.52130127e-01],
                        [ -1.42700195e-01,  -1.42425537e-01],
                        [ -1.30706787e-01,  -1.30401611e-01],
                        [ -1.10900879e-01,  -1.10565186e-01],
                        [ -8.54187012e-02,  -8.50830078e-02],
                        [ -5.27648926e-02,  -5.24597168e-02],
                        [ -7.08007812e-03,  -6.83593750e-03],
                        [  5.21240234e-02,   5.23376465e-02],
                        [  1.15112305e-01,   1.15264893e-01],
                        [  1.66442871e-01,   1.66534424e-01],
                        [  1.93969727e-01,   1.94000244e-01],
                        [  1.96868896e-01,   1.96807861e-01],
                        [  1.85577393e-01,   1.85455322e-01],
                        [  1.70349121e-01,   1.70166016e-01],
                        [  1.50695801e-01,   1.50482178e-01],
                        [  1.21093750e-01,   1.20880127e-01],
                        [  8.16345215e-02,   8.14208984e-02],
                        [  3.76892090e-02,   3.74755859e-02],
                        [ -4.42504883e-03,  -4.63867188e-03],
                        [ -3.62854004e-02,  -3.64379883e-02],
                        [ -4.94079590e-02,  -4.95300293e-02],
                        [ -4.40979004e-02,  -4.41894531e-02],
                        [ -3.21350098e-02,  -3.21960449e-02],
                        [ -2.52075195e-02,  -2.52380371e-02],
                        [ -2.34985352e-02,  -2.34680176e-02],
                        [ -2.03857422e-02,  -2.03247070e-02],
                        [ -1.37634277e-02,  -1.36718750e-02],
                        [ -6.22558594e-03,  -6.13403320e-03],
                        [  8.23974609e-04,   9.46044922e-04],
                        [  7.56835938e-03,   7.69042969e-03],
                        [  1.42211914e-02,   1.43127441e-02],
                        [  2.17285156e-02,   2.18200684e-02],
                        [  3.19213867e-02,   3.20129395e-02],
                        [  4.40368652e-02,   4.40979004e-02],
                        [  5.33142090e-02,   5.33447266e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  4.68750000e-02,   4.68444824e-02],
                        [  3.89099121e-02,   3.88793945e-02],
                        [  3.05175781e-02,   3.04870605e-02],
                        [  2.31018066e-02,   2.30712891e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [  3.54003906e-03,   3.50952148e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.57470703e-02,   1.57775879e-02],
                        [  2.58483887e-02,   2.58789062e-02],
                        [  3.55834961e-02,   3.56445312e-02],
                        [  4.48608398e-02,   4.49218750e-02],
                        [  5.08728027e-02,   5.09033203e-02],
                        [  4.95910645e-02,   4.96215820e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  3.43017578e-02,   3.42712402e-02],
                        [  4.20837402e-02,   4.20227051e-02],
                        [  4.31823730e-02,   4.31213379e-02],
                        [  3.60107422e-02,   3.59191895e-02],
                        [  2.61230469e-02,   2.60314941e-02],
                        [  1.69982910e-02,   1.68762207e-02],
                        [  6.92749023e-03,   6.83593750e-03],
                        [ -3.72314453e-03,  -3.78417969e-03],
                        [ -1.12609863e-02,  -1.13220215e-02],
                        [ -1.50146484e-02,  -1.50451660e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.92260742e-02,  -1.91955566e-02],
                        [ -2.77709961e-02,  -2.76794434e-02],
                        [ -4.19616699e-02,  -4.18701172e-02],
                        [ -5.11169434e-02,  -5.09948730e-02],
                        [ -4.73327637e-02,  -4.72106934e-02],
                        [ -3.52172852e-02,  -3.50952148e-02],
                        [ -2.51464844e-02,  -2.49938965e-02],
                        [ -2.22167969e-02,  -2.20947266e-02],
                        [ -2.47802734e-02,  -2.46887207e-02],
                        [ -2.78015137e-02,  -2.77404785e-02],
                        [ -2.59399414e-02,  -2.59094238e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -5.15747070e-03,  -5.18798828e-03],
                        [  1.70898438e-03,   1.64794922e-03],
                        [ -2.41088867e-03,  -2.50244141e-03],
                        [ -1.39160156e-02,  -1.40380859e-02],
                        [ -2.16979980e-02,  -2.18200684e-02],
                        [ -1.92871094e-02,  -1.94396973e-02],
                        [ -1.17797852e-02,  -1.19323730e-02],
                        [ -7.87353516e-03,  -7.99560547e-03],
                        [ -8.54492188e-03,  -8.66699219e-03],
                        [ -9.09423828e-03,  -9.18579102e-03],
                        [ -8.05664062e-03,  -8.11767578e-03],
                        [ -8.36181641e-03,  -8.39233398e-03],
                        [ -1.12915039e-02,  -1.13220215e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.63269043e-02,  -1.62658691e-02],
                        [ -1.41601562e-02,  -1.40991211e-02],
                        [ -9.27734375e-03,  -9.18579102e-03],
                        [ -2.96020508e-03,  -2.83813477e-03],
                        [  4.54711914e-03,   4.66918945e-03],
                        [  1.15051270e-02,   1.16271973e-02],
                        [  1.40075684e-02,   1.41296387e-02],
                        [  1.01928711e-02,   1.02844238e-02],
                        [  4.69970703e-03,   4.79125977e-03],
                        [  5.18798828e-03,   5.24902344e-03],
                        [  1.35498047e-02,   1.36108398e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  5.97839355e-02,   5.97534180e-02],
                        [  8.93554688e-02,   8.92944336e-02],
                        [  1.21002197e-01,   1.20941162e-01],
                        [  1.42150879e-01,   1.42059326e-01],
                        [  1.40808105e-01,   1.40716553e-01],
                        [  1.09344482e-01,   1.09252930e-01],
                        [  4.52880859e-02,   4.51965332e-02],
                        [ -4.70275879e-02,  -4.70886230e-02],
                        [ -1.53503418e-01,  -1.53564453e-01],
                        [ -2.49786377e-01,  -2.49816895e-01],
                        [ -3.07495117e-01,  -3.07525635e-01],
                        [ -3.09722900e-01,  -3.09722900e-01],
                        [ -2.65014648e-01,  -2.65014648e-01],
                        [ -2.04681396e-01,  -2.04681396e-01],
                        [ -1.61376953e-01,  -1.61346436e-01],
                        [ -1.46575928e-01,  -1.46545410e-01],
                        [ -1.46209717e-01,  -1.46148682e-01],
                        [ -1.39465332e-01,  -1.39404297e-01],
                        [ -1.19201660e-01,  -1.19140625e-01],
                        [ -8.99658203e-02,  -8.99047852e-02],
                        [ -5.30700684e-02,  -5.30090332e-02],
                        [ -3.69262695e-03,  -3.66210938e-03],
                        [  5.89599609e-02,   5.89904785e-02],
                        [  1.25030518e-01,   1.25061035e-01],
                        [  1.78222656e-01,   1.78222656e-01],
                        [  2.05352783e-01,   2.05352783e-01],
                        [  2.05657959e-01,   2.05657959e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  1.70715332e-01,   1.70684814e-01],
                        [  1.44836426e-01,   1.44836426e-01],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  4.73327637e-02,   4.73022461e-02],
                        [ -1.16577148e-02,  -1.16882324e-02],
                        [ -5.32531738e-02,  -5.32836914e-02],
                        [ -6.62536621e-02,  -6.62841797e-02],
                        [ -5.47790527e-02,  -5.48095703e-02],
                        [ -3.32641602e-02,  -3.32946777e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -8.05664062e-03,  -8.02612305e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  3.66210938e-02,   3.66210938e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  6.20117188e-02,   6.20117188e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  1.03332520e-01,   1.03332520e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.28051758e-01,   1.28051758e-01],
                        [  1.07116699e-01,   1.07116699e-01],
                        [  4.97741699e-02,   4.97741699e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -2.38464355e-01,  -2.38464355e-01],
                        [ -2.95654297e-01,  -2.95654297e-01],
                        [ -2.99468994e-01,  -2.99468994e-01],
                        [ -2.57690430e-01,  -2.57690430e-01],
                        [ -2.02087402e-01,  -2.02087402e-01],
                        [ -1.64031982e-01,  -1.64031982e-01],
                        [ -1.49658203e-01,  -1.49658203e-01],
                        [ -1.42791748e-01,  -1.42791748e-01],
                        [ -1.29608154e-01,  -1.29608154e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -9.23767090e-02,  -9.23767090e-02],
                        [ -6.87866211e-02,  -6.87866211e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.90399170e-01,   1.90399170e-01],
                        [  2.29400635e-01,   2.29400635e-01],
                        [  2.29064941e-01,   2.29064941e-01],
                        [  2.02392578e-01,   2.02392578e-01],
                        [  1.64337158e-01,   1.64337158e-01],
                        [  1.20086670e-01,   1.20086670e-01],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  4.33349609e-03,   4.33349609e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  4.36401367e-02,   4.36401367e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  3.45764160e-02,   3.45458984e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  7.76062012e-02,   7.76062012e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.25915527e-01,   1.25915527e-01],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  4.70581055e-02,   4.70581055e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -1.33514404e-01,  -1.33514404e-01],
                        [ -2.27630615e-01,  -2.27630615e-01],
                        [ -2.89428711e-01,  -2.89428711e-01],
                        [ -2.96875000e-01,  -2.96875000e-01],
                        [ -2.55462646e-01,  -2.55493164e-01],
                        [ -1.98852539e-01,  -1.98852539e-01],
                        [ -1.61193848e-01,  -1.61193848e-01],
                        [ -1.51245117e-01,  -1.51245117e-01],
                        [ -1.54541016e-01,  -1.54541016e-01],
                        [ -1.53167725e-01,  -1.53167725e-01],
                        [ -1.38336182e-01,  -1.38336182e-01],
                        [ -1.10626221e-01,  -1.10626221e-01],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  2.18353271e-01,   2.18353271e-01],
                        [  2.33154297e-01,   2.33154297e-01],
                        [  2.15026855e-01,   2.15026855e-01],
                        [  1.69586182e-01,   1.69586182e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  3.40881348e-02,   3.40881348e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  8.01391602e-02,   8.01391602e-02],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  6.64978027e-02,   6.64978027e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  4.08935547e-03,   4.08935547e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  3.56140137e-02,   3.55834961e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  4.25720215e-02,   4.26025391e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -5.95092773e-03,  -5.92041016e-03],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.26342773e-02,  -1.26037598e-02],
                        [ -1.30004883e-02,  -1.29699707e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.73132324e-02,  -2.73437500e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  1.01959229e-01,   1.01959229e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  5.47485352e-02,   5.47485352e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -1.34216309e-01,  -1.34216309e-01],
                        [ -2.32910156e-01,  -2.32910156e-01],
                        [ -2.97088623e-01,  -2.97088623e-01],
                        [ -3.05236816e-01,  -3.05236816e-01],
                        [ -2.63031006e-01,  -2.63031006e-01],
                        [ -2.03948975e-01,  -2.03948975e-01],
                        [ -1.60614014e-01,  -1.60614014e-01],
                        [ -1.40014648e-01,  -1.40014648e-01],
                        [ -1.30859375e-01,  -1.30859375e-01],
                        [ -1.23413086e-01,  -1.23413086e-01],
                        [ -1.14807129e-01,  -1.14807129e-01],
                        [ -1.02050781e-01,  -1.02050781e-01],
                        [ -7.83081055e-02,  -7.83081055e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  1.76849365e-01,   1.76849365e-01],
                        [  2.19787598e-01,   2.19787598e-01],
                        [  2.25738525e-01,   2.25738525e-01],
                        [  1.96075439e-01,   1.96075439e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  7.01599121e-02,   7.01904297e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -3.28979492e-02,  -3.29284668e-02],
                        [ -4.53491211e-02,  -4.53186035e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  9.49401855e-02,   9.49401855e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  2.42919922e-02,   2.43225098e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  9.88769531e-03,   9.91821289e-03],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.07519531e-02,   2.07214355e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.49938965e-02,   2.50244141e-02],
                        [  2.85034180e-02,   2.84729004e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  4.30603027e-02,   4.30297852e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.22167969e-02,  -2.22473145e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.66320801e-02,  -1.66625977e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -1.37939453e-02,  -1.38244629e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.57470703e-02,  -1.57165527e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.37329102e-03,  -1.40380859e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -1.51092529e-01,  -1.51092529e-01],
                        [ -2.45208740e-01,  -2.45208740e-01],
                        [ -2.99621582e-01,  -2.99621582e-01],
                        [ -2.92877197e-01,  -2.92877197e-01],
                        [ -2.37640381e-01,  -2.37640381e-01],
                        [ -1.73583984e-01,  -1.73583984e-01],
                        [ -1.33789062e-01,  -1.33789062e-01],
                        [ -1.22436523e-01,  -1.22436523e-01],
                        [ -1.24328613e-01,  -1.24328613e-01],
                        [ -1.24664307e-01,  -1.24664307e-01],
                        [ -1.16973877e-01,  -1.16973877e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  2.13439941e-01,   2.13470459e-01],
                        [  2.27081299e-01,   2.27081299e-01],
                        [  1.88812256e-01,   1.88812256e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  3.01818848e-02,   3.01818848e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.79443359e-02,   1.79138184e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  5.43823242e-02,   5.44128418e-02],
                        [  7.73620605e-02,   7.73620605e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.28369141e-02,   3.28063965e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.17895508e-02,   2.17590332e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.54516602e-02,  -2.54821777e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.23083496e-02,  -2.22778320e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.60009766e-02,  -2.60314941e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.84729004e-02,  -2.85034180e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.25122070e-03,  -1.28173828e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  5.42907715e-02,   5.42907715e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -2.35015869e-01,  -2.35015869e-01],
                        [ -3.00292969e-01,  -3.00292969e-01],
                        [ -2.98095703e-01,  -2.98095703e-01],
                        [ -2.39349365e-01,  -2.39349365e-01],
                        [ -1.66778564e-01,  -1.66809082e-01],
                        [ -1.18743896e-01,  -1.18743896e-01],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -9.73815918e-02,  -9.73815918e-02],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.69067383e-01,   1.69067383e-01],
                        [  1.43218994e-01,   1.43218994e-01],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  3.70178223e-02,   3.70483398e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  2.65502930e-02,   2.65808105e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  4.94995117e-02,   4.94689941e-02],
                        [  4.40368652e-02,   4.40673828e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.15454102e-02,   2.15759277e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.81164551e-02,   3.80859375e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  3.75061035e-02,   3.75366211e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.22985840e-02,  -1.23291016e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.08337402e-02,  -1.08642578e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.95617676e-02,  -1.95312500e-02],
                        [ -2.97241211e-02,  -2.96936035e-02],
                        [ -3.83605957e-02,  -3.83911133e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.20837402e-02,  -4.20532227e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.38439941e-02,  -3.38745117e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.13220215e-02,  -1.12915039e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  1.23260498e-01,   1.23229980e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  5.47485352e-02,   5.47485352e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -2.12310791e-01,  -2.12310791e-01],
                        [ -2.75970459e-01,  -2.75939941e-01],
                        [ -2.85644531e-01,  -2.85644531e-01],
                        [ -2.46765137e-01,  -2.46765137e-01],
                        [ -1.90704346e-01,  -1.90704346e-01],
                        [ -1.47216797e-01,  -1.47186279e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -8.27941895e-02,  -8.27941895e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  5.34057617e-03,   5.37109375e-03],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  8.44116211e-02,   8.43811035e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  9.27429199e-02,   9.27734375e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  2.07214355e-02,   2.07519531e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  1.04309082e-01,   1.04309082e-01],
                        [  9.21325684e-02,   9.21630859e-02],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  6.39648438e-02,   6.39343262e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  5.08422852e-02,   5.08728027e-02],
                        [  3.79638672e-02,   3.79333496e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  1.34582520e-02,   1.34277344e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  2.85644531e-02,   2.85339355e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.74560547e-02,   1.74255371e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.98864746e-02,  -3.99169922e-02],
                        [ -4.29992676e-02,  -4.29687500e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.12597656e-02,  -4.12902832e-02],
                        [ -3.58276367e-02,  -3.57971191e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.68554688e-02,  -2.68859863e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -6.16455078e-03,  -6.19506836e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  6.70166016e-02,   6.70471191e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  9.74426270e-02,   9.74121094e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -2.26806641e-01,  -2.26806641e-01],
                        [ -2.86926270e-01,  -2.86926270e-01],
                        [ -2.90527344e-01,  -2.90527344e-01],
                        [ -2.47985840e-01,  -2.47985840e-01],
                        [ -1.87805176e-01,  -1.87805176e-01],
                        [ -1.38427734e-01,  -1.38427734e-01],
                        [ -1.10351562e-01,  -1.10351562e-01],
                        [ -9.45739746e-02,  -9.45739746e-02],
                        [ -7.99865723e-02,  -7.99560547e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -5.82580566e-02,  -5.82885742e-02],
                        [ -5.60302734e-02,  -5.59997559e-02],
                        [ -5.02014160e-02,  -5.01708984e-02],
                        [ -3.07922363e-02,  -3.08227539e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  6.64367676e-02,   6.64062500e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.57775879e-02,   1.57470703e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  3.55529785e-02,   3.55224609e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  2.72216797e-02,   2.72521973e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  1.93481445e-02,   1.93176270e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.00805664e-02,  -2.00500488e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.59704590e-02,  -2.59399414e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -4.29077148e-02,  -4.29382324e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.83496094e-02,  -5.83190918e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.68652344e-02,  -3.68957520e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.10363770e-02,  -3.10058594e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  2.76794434e-02,   2.76489258e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  5.16662598e-02,   5.16357422e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  8.51745605e-02,   8.52050781e-02],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  1.13861084e-01,   1.13861084e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  9.12780762e-02,   9.13085938e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -1.27014160e-01,  -1.27014160e-01],
                        [ -2.19390869e-01,  -2.19390869e-01],
                        [ -2.77832031e-01,  -2.77832031e-01],
                        [ -2.82531738e-01,  -2.82531738e-01],
                        [ -2.37731934e-01,  -2.37731934e-01],
                        [ -1.74713135e-01,  -1.74713135e-01],
                        [ -1.29058838e-01,  -1.29058838e-01],
                        [ -1.09130859e-01,  -1.09100342e-01],
                        [ -9.57641602e-02,  -9.57641602e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  6.90917969e-02,   6.90612793e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  8.53881836e-02,   8.53881836e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  9.56115723e-02,   9.56115723e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  4.12902832e-02,   4.13208008e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  3.51867676e-02,   3.52172852e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  2.19421387e-02,   2.19116211e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  2.56347656e-02,   2.56042480e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.46887207e-02,  -2.46582031e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.55126953e-02,  -2.54821777e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.21447754e-02,  -4.21142578e-02],
                        [ -3.47290039e-02,  -3.47595215e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.11279297e-02,  -3.10974121e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.03552246e-02,  -2.03857422e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.45568848e-02,  -1.45874023e-02],
                        [ -1.60217285e-02,  -1.60522461e-02],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.40075684e-02,   1.39770508e-02],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.28173828e-01,   1.28173828e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  5.57556152e-02,   5.57556152e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -2.10937500e-01,  -2.10937500e-01],
                        [ -2.78015137e-01,  -2.78015137e-01],
                        [ -2.86773682e-01,  -2.86804199e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -1.69952393e-01,  -1.69921875e-01],
                        [ -1.16271973e-01,  -1.16302490e-01],
                        [ -8.96606445e-02,  -8.96911621e-02],
                        [ -7.69042969e-02,  -7.69042969e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -7.94982910e-02,  -7.94982910e-02],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -1.05712891e-01,  -1.05712891e-01],
                        [ -8.97521973e-02,  -8.97827148e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  7.11975098e-02,   7.11669922e-02],
                        [  1.07360840e-01,   1.07360840e-01],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  9.28344727e-02,   9.28039551e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  1.07391357e-01,   1.07391357e-01],
                        [  1.21582031e-01,   1.21582031e-01],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  6.70166016e-02,   6.70166016e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.36206055e-02,   2.35900879e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.53808594e-02,   1.54113770e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.08935547e-03,   4.08935547e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.23291016e-02,  -1.22985840e-02],
                        [ -1.44958496e-02,  -1.45263672e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -4.48608398e-02,  -4.48303223e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.62145996e-02,  -2.61840820e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.02636719e-02,  -2.02331543e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -6.50024414e-03,  -6.53076172e-03],
                        [ -1.52587891e-03,  -1.49536133e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  1.64794922e-03,   1.61743164e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  9.42993164e-03,   9.39941406e-03],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  9.77478027e-02,   9.77783203e-02],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.36505127e-01,   1.36474609e-01],
                        [  1.35894775e-01,   1.35894775e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  4.95605469e-02,   4.95605469e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -1.35894775e-01,  -1.35864258e-01],
                        [ -2.20489502e-01,  -2.20489502e-01],
                        [ -2.69897461e-01,  -2.69897461e-01],
                        [ -2.69805908e-01,  -2.69805908e-01],
                        [ -2.24121094e-01,  -2.24121094e-01],
                        [ -1.60095215e-01,  -1.60095215e-01],
                        [ -1.10260010e-01,  -1.10260010e-01],
                        [ -8.46252441e-02,  -8.46252441e-02],
                        [ -6.95190430e-02,  -6.94885254e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -3.47290039e-02,  -3.47595215e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -4.47998047e-02,  -4.47692871e-02],
                        [ -7.51953125e-02,  -7.52258301e-02],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -1.38793945e-01,  -1.38763428e-01],
                        [ -1.44439697e-01,  -1.44439697e-01],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.19201660e-01,   1.19201660e-01],
                        [  1.08062744e-01,   1.08062744e-01],
                        [  9.75952148e-02,   9.75952148e-02],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  8.01391602e-02,   8.01696777e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.05316162e-01,   1.05316162e-01],
                        [  1.02081299e-01,   1.02050781e-01],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  7.66601562e-02,   7.66906738e-02],
                        [  6.52160645e-02,   6.52160645e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.79541016e-02,  -2.79235840e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -5.78613281e-02,  -5.78918457e-02],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -2.19726562e-02,  -2.20031738e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -3.05175781e-02,  -3.05480957e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.02026367e-02,  -2.02331543e-02],
                        [ -1.19323730e-02,  -1.19018555e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  5.06591797e-03,   5.09643555e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.44653320e-01,   1.44653320e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  6.71997070e-02,   6.71997070e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -1.11450195e-01,  -1.11480713e-01],
                        [ -1.99829102e-01,  -1.99829102e-01],
                        [ -2.60253906e-01,  -2.60253906e-01],
                        [ -2.75299072e-01,  -2.75299072e-01],
                        [ -2.43194580e-01,  -2.43194580e-01],
                        [ -1.84875488e-01,  -1.84875488e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -8.69445801e-02,  -8.69445801e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.61437988e-01,  -1.61437988e-01],
                        [ -1.85119629e-01,  -1.85119629e-01],
                        [ -1.75933838e-01,  -1.75903320e-01],
                        [ -1.30920410e-01,  -1.30920410e-01],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  1.34399414e-01,   1.34368896e-01],
                        [  1.49780273e-01,   1.49780273e-01],
                        [  1.45019531e-01,   1.45019531e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  7.58056641e-02,   7.58361816e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  1.20239258e-01,   1.20208740e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  5.06896973e-02,   5.06591797e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  4.57763672e-02,   4.58068848e-02],
                        [  5.73120117e-02,   5.72814941e-02],
                        [  6.86645508e-02,   6.86340332e-02],
                        [  7.26623535e-02,   7.26928711e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  5.67932129e-02,   5.68237305e-02],
                        [  4.30908203e-02,   4.31213379e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.07727051e-02,   1.08032227e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  1.57165527e-02,   1.56860352e-02],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.40991211e-02,   1.40686035e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  3.38745117e-03,   3.41796875e-03],
                        [  5.46264648e-03,   5.43212891e-03],
                        [  1.26037598e-02,   1.25732422e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.58789062e-02,   2.59094238e-02],
                        [  2.31933594e-02,   2.32238770e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -9.76562500e-03,  -9.79614258e-03],
                        [ -2.38037109e-03,  -2.34985352e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  7.04650879e-02,   7.04650879e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.10626221e-01,  -1.10626221e-01],
                        [ -2.07519531e-01,  -2.07519531e-01],
                        [ -2.72918701e-01,  -2.72949219e-01],
                        [ -2.84973145e-01,  -2.84973145e-01],
                        [ -2.45361328e-01,  -2.45361328e-01],
                        [ -1.79565430e-01,  -1.79595947e-01],
                        [ -1.18469238e-01,  -1.18469238e-01],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -1.13098145e-01,  -1.13098145e-01],
                        [ -1.64672852e-01,  -1.64672852e-01],
                        [ -1.97814941e-01,  -1.97814941e-01],
                        [ -1.98974609e-01,  -1.98974609e-01],
                        [ -1.70349121e-01,  -1.70349121e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.28936768e-01,   1.28936768e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.33239746e-01,   1.33239746e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  6.52465820e-02,   6.52465820e-02],
                        [  6.57043457e-02,   6.57348633e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  1.28692627e-01,   1.28692627e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  9.47265625e-02,   9.46960449e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  2.50244141e-02,   2.50549316e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.75781250e-02,   1.76086426e-02],
                        [  6.25610352e-03,   6.25610352e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -4.51660156e-03,  -4.48608398e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.19628906e-02,   1.19323730e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -2.15759277e-02,  -2.15454102e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -3.94897461e-02,  -3.95202637e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -4.40368652e-02,  -4.40063477e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.31005859e-02,  -5.31311035e-02],
                        [ -4.94079590e-02,  -4.93774414e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -1.77307129e-02,  -1.77001953e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -2.07519531e-03,  -2.10571289e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  1.52465820e-01,   1.52465820e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  8.38012695e-02,   8.38317871e-02],
                        [  1.70898438e-03,   1.67846680e-03],
                        [ -1.00067139e-01,  -1.00067139e-01],
                        [ -2.01080322e-01,  -2.01080322e-01],
                        [ -2.70263672e-01,  -2.70263672e-01],
                        [ -2.81250000e-01,  -2.81250000e-01],
                        [ -2.34436035e-01,  -2.34436035e-01],
                        [ -1.59393311e-01,  -1.59393311e-01],
                        [ -9.27429199e-02,  -9.27429199e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -9.72595215e-02,  -9.72595215e-02],
                        [ -1.37939453e-01,  -1.37939453e-01],
                        [ -1.80358887e-01,  -1.80358887e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.99859619e-01,  -1.99859619e-01],
                        [ -1.63391113e-01,  -1.63391113e-01],
                        [ -1.15325928e-01,  -1.15325928e-01],
                        [ -7.15637207e-02,  -7.15637207e-02],
                        [ -3.19519043e-02,  -3.19824219e-02],
                        [  1.12609863e-02,   1.12915039e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  1.33636475e-01,   1.33666992e-01],
                        [  1.38641357e-01,   1.38641357e-01],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  9.81750488e-02,   9.81750488e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  9.03320312e-02,   9.03320312e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  1.05346680e-01,   1.05316162e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.35833740e-01,   1.35864258e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  1.34521484e-01,   1.34521484e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  7.32727051e-02,   7.32421875e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  8.05664062e-03,   8.08715820e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  1.95312500e-03,   1.92260742e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.14123535e-02,  -4.14428711e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.49926758e-02,  -5.50231934e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -8.20922852e-03,  -8.17871094e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.36804199e-02,   5.36499023e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.52740479e-01,   1.52740479e-01],
                        [  1.57592773e-01,   1.57592773e-01],
                        [  1.37207031e-01,   1.37237549e-01],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -1.92993164e-01,  -1.92993164e-01],
                        [ -2.69897461e-01,  -2.69897461e-01],
                        [ -2.89306641e-01,  -2.89306641e-01],
                        [ -2.48535156e-01,  -2.48535156e-01],
                        [ -1.72393799e-01,  -1.72393799e-01],
                        [ -9.78393555e-02,  -9.78393555e-02],
                        [ -5.01403809e-02,  -5.01098633e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -1.51184082e-01,  -1.51184082e-01],
                        [ -1.94061279e-01,  -1.94061279e-01],
                        [ -2.13256836e-01,  -2.13256836e-01],
                        [ -2.02606201e-01,  -2.02606201e-01],
                        [ -1.67114258e-01,  -1.67114258e-01],
                        [ -1.20025635e-01,  -1.20025635e-01],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  1.36383057e-01,   1.36383057e-01],
                        [  1.47460938e-01,   1.47460938e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  7.77282715e-02,   7.76977539e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  3.97644043e-02,   3.97949219e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  2.85949707e-02,   2.86254883e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.69067383e-02,   1.68762207e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -9.85717773e-03,  -9.82666016e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  5.91430664e-02,   5.91430664e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -9.51232910e-02,  -9.51232910e-02],
                        [ -1.81152344e-01,  -1.81152344e-01],
                        [ -2.43530273e-01,  -2.43530273e-01],
                        [ -2.56195068e-01,  -2.56195068e-01],
                        [ -2.15270996e-01,  -2.15270996e-01],
                        [ -1.47888184e-01,  -1.47888184e-01],
                        [ -9.25598145e-02,  -9.25598145e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -7.46459961e-02,  -7.46459961e-02],
                        [ -8.99047852e-02,  -8.99047852e-02],
                        [ -1.10534668e-01,  -1.10534668e-01],
                        [ -1.39129639e-01,  -1.39129639e-01],
                        [ -1.70135498e-01,  -1.70135498e-01],
                        [ -1.88140869e-01,  -1.88140869e-01],
                        [ -1.83990479e-01,  -1.83990479e-01],
                        [ -1.63848877e-01,  -1.63848877e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -1.12152100e-01,  -1.12182617e-01],
                        [ -8.27331543e-02,  -8.27331543e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.34948730e-01,   1.34948730e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  9.46960449e-02,   9.46655273e-02],
                        [  9.36584473e-02,   9.36584473e-02],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  1.06262207e-01,   1.06262207e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  1.44378662e-01,   1.44378662e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.12670898e-01,   1.12670898e-01],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  7.70263672e-02,   7.70568848e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -3.56445312e-02,  -3.56140137e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.56982422e-01,   1.56982422e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  7.23571777e-02,   7.23571777e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.01745605e-01,  -1.01745605e-01],
                        [ -1.92291260e-01,  -1.92291260e-01],
                        [ -2.48413086e-01,  -2.48413086e-01],
                        [ -2.48748779e-01,  -2.48748779e-01],
                        [ -1.97753906e-01,  -1.97753906e-01],
                        [ -1.25732422e-01,  -1.25732422e-01],
                        [ -7.07702637e-02,  -7.07702637e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -1.56402588e-01,  -1.56402588e-01],
                        [ -1.84997559e-01,  -1.84997559e-01],
                        [ -1.95007324e-01,  -1.95007324e-01],
                        [ -1.84936523e-01,  -1.84936523e-01],
                        [ -1.61499023e-01,  -1.61499023e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.15142822e-01,  -1.15142822e-01],
                        [ -9.85107422e-02,  -9.85107422e-02],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  1.43554688e-01,   1.43554688e-01],
                        [  1.52587891e-01,   1.52587891e-01],
                        [  1.37115479e-01,   1.37115479e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  9.81750488e-02,   9.81750488e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.49871826e-01,   1.49841309e-01],
                        [  1.65802002e-01,   1.65802002e-01],
                        [  1.67236328e-01,   1.67236328e-01],
                        [  1.52465820e-01,   1.52465820e-01],
                        [  1.26190186e-01,   1.26190186e-01],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.43280029e-01,   1.43280029e-01],
                        [  1.44714355e-01,   1.44714355e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -8.69445801e-02,  -8.69445801e-02],
                        [ -1.72454834e-01,  -1.72454834e-01],
                        [ -2.29125977e-01,  -2.29125977e-01],
                        [ -2.34283447e-01,  -2.34283447e-01],
                        [ -1.90277100e-01,  -1.90277100e-01],
                        [ -1.28387451e-01,  -1.28387451e-01],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -8.88061523e-02,  -8.88061523e-02],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -1.54937744e-01,  -1.54937744e-01],
                        [ -1.80511475e-01,  -1.80511475e-01],
                        [ -1.91894531e-01,  -1.91894531e-01],
                        [ -1.88140869e-01,  -1.88140869e-01],
                        [ -1.70745850e-01,  -1.70745850e-01],
                        [ -1.46972656e-01,  -1.46972656e-01],
                        [ -1.25885010e-01,  -1.25885010e-01],
                        [ -1.11206055e-01,  -1.11206055e-01],
                        [ -9.93347168e-02,  -9.93347168e-02],
                        [ -8.31298828e-02,  -8.31298828e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.44134521e-01,   1.44134521e-01],
                        [  1.63452148e-01,   1.63452148e-01],
                        [  1.55731201e-01,   1.55731201e-01],
                        [  1.31927490e-01,   1.31927490e-01],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  9.92431641e-02,   9.92431641e-02],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.47918701e-01,   1.47918701e-01],
                        [  1.60552979e-01,   1.60552979e-01],
                        [  1.65283203e-01,   1.65283203e-01],
                        [  1.60369873e-01,   1.60369873e-01],
                        [  1.47644043e-01,   1.47644043e-01],
                        [  1.30187988e-01,   1.30187988e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -7.41577148e-02,  -7.41577148e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.51947021e-01,   1.51947021e-01],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  7.19299316e-02,   7.19299316e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -1.79809570e-01,  -1.79809570e-01],
                        [ -2.25860596e-01,  -2.25860596e-01],
                        [ -2.20092773e-01,  -2.20092773e-01],
                        [ -1.73248291e-01,  -1.73248291e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -9.75036621e-02,  -9.75036621e-02],
                        [ -1.12487793e-01,  -1.12487793e-01],
                        [ -1.50054932e-01,  -1.50054932e-01],
                        [ -1.85455322e-01,  -1.85455322e-01],
                        [ -2.00988770e-01,  -2.00988770e-01],
                        [ -1.92565918e-01,  -1.92565918e-01],
                        [ -1.67907715e-01,  -1.67907715e-01],
                        [ -1.39221191e-01,  -1.39221191e-01],
                        [ -1.16271973e-01,  -1.16271973e-01],
                        [ -1.02722168e-01,  -1.02722168e-01],
                        [ -9.61914062e-02,  -9.61914062e-02],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -8.43811035e-02,  -8.43811035e-02],
                        [ -7.03735352e-02,  -7.03735352e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.62597656e-01,   1.62597656e-01],
                        [  1.62658691e-01,   1.62658691e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.23504639e-01,   1.23504639e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  1.39007568e-01,   1.39007568e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.71569824e-01,   1.71569824e-01],
                        [  1.76849365e-01,   1.76849365e-01],
                        [  1.67633057e-01,   1.67633057e-01],
                        [  1.47552490e-01,   1.47552490e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  6.19812012e-02,   6.19812012e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  1.09985352e-01,   1.09985352e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.48223877e-01,   1.48223877e-01],
                        [  1.47094727e-01,   1.47094727e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  6.54907227e-02,   6.54907227e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.02905273e-01,  -1.02905273e-01],
                        [ -1.80206299e-01,  -1.80206299e-01],
                        [ -2.24609375e-01,  -2.24609375e-01],
                        [ -2.22534180e-01,  -2.22534180e-01],
                        [ -1.81518555e-01,  -1.81518555e-01],
                        [ -1.37145996e-01,  -1.37145996e-01],
                        [ -1.28692627e-01,  -1.28692627e-01],
                        [ -1.62139893e-01,  -1.62139893e-01],
                        [ -2.07214355e-01,  -2.07214355e-01],
                        [ -2.31140137e-01,  -2.31140137e-01],
                        [ -2.25189209e-01,  -2.25189209e-01],
                        [ -2.00958252e-01,  -2.00958252e-01],
                        [ -1.71783447e-01,  -1.71783447e-01],
                        [ -1.42974854e-01,  -1.42974854e-01],
                        [ -1.14715576e-01,  -1.14715576e-01],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.58447266e-01,   1.58447266e-01],
                        [  1.50207520e-01,   1.50207520e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.11480713e-01,   1.11480713e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.71295166e-01,   1.71295166e-01],
                        [  1.92687988e-01,   1.92687988e-01],
                        [  1.99737549e-01,   1.99737549e-01],
                        [  1.89392090e-01,   1.89392090e-01],
                        [  1.63909912e-01,   1.63909912e-01],
                        [  1.30523682e-01,   1.30523682e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  4.11682129e-02,   4.11682129e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  1.18713379e-01,   1.18713379e-01],
                        [  1.48406982e-01,   1.48406982e-01],
                        [  1.60919189e-01,   1.60919189e-01],
                        [  1.47399902e-01,   1.47399902e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  4.01611328e-02,   4.01611328e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -1.28356934e-01,  -1.28356934e-01],
                        [ -1.97753906e-01,  -1.97753906e-01],
                        [ -2.29553223e-01,  -2.29553223e-01],
                        [ -2.25494385e-01,  -2.25494385e-01],
                        [ -2.12615967e-01,  -2.12615967e-01],
                        [ -2.14691162e-01,  -2.14691162e-01],
                        [ -2.28881836e-01,  -2.28881836e-01],
                        [ -2.35137939e-01,  -2.35137939e-01],
                        [ -2.19696045e-01,  -2.19696045e-01],
                        [ -1.86004639e-01,  -1.86004639e-01],
                        [ -1.49078369e-01,  -1.49078369e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -1.12518311e-01,  -1.12518311e-01],
                        [ -1.05255127e-01,  -1.05255127e-01],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  1.20941162e-01,   1.20941162e-01],
                        [  1.45294189e-01,   1.45294189e-01],
                        [  1.50024414e-01,   1.50024414e-01],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.36505127e-01,   1.36505127e-01],
                        [  1.44409180e-01,   1.44409180e-01],
                        [  1.67968750e-01,   1.67968750e-01],
                        [  1.95983887e-01,   1.95983887e-01],
                        [  2.11853027e-01,   2.11853027e-01],
                        [  2.07611084e-01,   2.07611084e-01],
                        [  1.88385010e-01,   1.88385010e-01],
                        [  1.63391113e-01,   1.63391113e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  9.80834961e-02,   9.80834961e-02],
                        [  8.06274414e-02,   8.06274414e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.76818848e-01,   1.76818848e-01],
                        [  1.80328369e-01,   1.80328369e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  4.20532227e-02,   4.20532227e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -2.09472656e-01,  -2.09472656e-01],
                        [ -2.50610352e-01,  -2.50610352e-01],
                        [ -2.64434814e-01,  -2.64434814e-01],
                        [ -2.61718750e-01,  -2.61718750e-01],
                        [ -2.53845215e-01,  -2.53845215e-01],
                        [ -2.46398926e-01,  -2.46398926e-01],
                        [ -2.33856201e-01,  -2.33856201e-01],
                        [ -2.05566406e-01,  -2.05566406e-01],
                        [ -1.63391113e-01,  -1.63391113e-01],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.05102539e-01,  -1.05102539e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -7.82165527e-02,  -7.82165527e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.43096924e-01,   1.43096924e-01],
                        [  1.57440186e-01,   1.57440186e-01],
                        [  1.62109375e-01,   1.62109375e-01],
                        [  1.66961670e-01,   1.66961670e-01],
                        [  1.80572510e-01,   1.80572510e-01],
                        [  1.97784424e-01,   1.97784424e-01],
                        [  2.04803467e-01,   2.04803467e-01],
                        [  1.95861816e-01,   1.95861816e-01],
                        [  1.77185059e-01,   1.77185059e-01],
                        [  1.55914307e-01,   1.55914307e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  1.25335693e-01,   1.25335693e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.85302734e-01,   1.85302734e-01],
                        [  1.86859131e-01,   1.86859131e-01],
                        [  1.54785156e-01,   1.54785156e-01],
                        [  8.56628418e-02,   8.56628418e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.26281738e-01,  -1.26281738e-01],
                        [ -2.30926514e-01,  -2.30926514e-01],
                        [ -3.03497314e-01,  -3.03497314e-01],
                        [ -3.29284668e-01,  -3.29284668e-01],
                        [ -3.13537598e-01,  -3.13537598e-01],
                        [ -2.77740479e-01,  -2.77740479e-01],
                        [ -2.41455078e-01,  -2.41455078e-01],
                        [ -2.10174561e-01,  -2.10174561e-01],
                        [ -1.79840088e-01,  -1.79840088e-01],
                        [ -1.48864746e-01,  -1.48864746e-01],
                        [ -1.22680664e-01,  -1.22680664e-01],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -9.42382812e-02,  -9.42382812e-02],
                        [ -7.96813965e-02,  -7.96813965e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  1.49993896e-01,   1.49993896e-01],
                        [  1.82403564e-01,   1.82403564e-01],
                        [  1.97753906e-01,   1.97753906e-01],
                        [  2.03826904e-01,   2.03826904e-01],
                        [  2.09167480e-01,   2.09167480e-01],
                        [  2.14080811e-01,   2.14080811e-01],
                        [  2.11212158e-01,   2.11212158e-01],
                        [  1.96228027e-01,   1.96228027e-01],
                        [  1.75720215e-01,   1.75720215e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.38031006e-01,   1.38031006e-01],
                        [  1.18133545e-01,   1.18133545e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  1.36474609e-01,   1.36474609e-01],
                        [  1.75964355e-01,   1.75964355e-01],
                        [  2.03369141e-01,   2.03369141e-01],
                        [  2.04559326e-01,   2.04559326e-01],
                        [  1.71386719e-01,   1.71386719e-01],
                        [  9.93957520e-02,   9.93957520e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -2.75146484e-01,  -2.75146484e-01],
                        [ -3.66912842e-01,  -3.66912842e-01],
                        [ -3.93157959e-01,  -3.93157959e-01],
                        [ -3.57055664e-01,  -3.57055664e-01],
                        [ -2.91137695e-01,  -2.91137695e-01],
                        [ -2.30377197e-01,  -2.30377197e-01],
                        [ -1.88476562e-01,  -1.88476562e-01],
                        [ -1.60919189e-01,  -1.60919189e-01],
                        [ -1.39617920e-01,  -1.39617920e-01],
                        [ -1.18804932e-01,  -1.18804932e-01],
                        [ -9.72595215e-02,  -9.72595215e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.73248291e-01,   1.73248291e-01],
                        [  2.13775635e-01,   2.13775635e-01],
                        [  2.38708496e-01,   2.38708496e-01],
                        [  2.46398926e-01,   2.46398926e-01],
                        [  2.39959717e-01,   2.39959717e-01],
                        [  2.26623535e-01,   2.26623535e-01],
                        [  2.10662842e-01,   2.10662842e-01],
                        [  1.92596436e-01,   1.92596436e-01],
                        [  1.73492432e-01,   1.73492432e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.14318848e-01,   1.14318848e-01],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  6.06079102e-02,   6.06079102e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  4.21142578e-03,   4.21142578e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -7.09838867e-02,  -7.09838867e-02],
                        [ -7.37304688e-02,  -7.37304688e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  1.07879639e-01,   1.07879639e-01],
                        [  1.31286621e-01,   1.31286621e-01],
                        [  1.58935547e-01,   1.58935547e-01],
                        [  1.82739258e-01,   1.82739258e-01],
                        [  1.87896729e-01,   1.87896729e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  8.32519531e-02,   8.32519531e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -1.78588867e-01,  -1.78588867e-01],
                        [ -3.14727783e-01,  -3.14727783e-01],
                        [ -3.99566650e-01,  -3.99566650e-01],
                        [ -4.07684326e-01,  -4.07684326e-01],
                        [ -3.51318359e-01,  -3.51318359e-01],
                        [ -2.69927979e-01,  -2.69927979e-01],
                        [ -2.00683594e-01,  -2.00683594e-01],
                        [ -1.59149170e-01,  -1.59149170e-01],
                        [ -1.38732910e-01,  -1.38732910e-01],
                        [ -1.22039795e-01,  -1.22039795e-01],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.66442871e-01,   1.66442871e-01],
                        [  2.29736328e-01,   2.29736328e-01],
                        [  2.66479492e-01,   2.66479492e-01],
                        [  2.73132324e-01,   2.73132324e-01],
                        [  2.63000488e-01,   2.63000488e-01],
                        [  2.49023438e-01,   2.49023438e-01],
                        [  2.30926514e-01,   2.30926514e-01],
                        [  2.04711914e-01,   2.04711914e-01],
                        [  1.74468994e-01,   1.74468994e-01],
                        [  1.46423340e-01,   1.46423340e-01],
                        [  1.21276855e-01,   1.21276855e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -7.20825195e-02,  -7.20825195e-02],
                        [ -7.14111328e-02,  -7.14111328e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -7.48901367e-02,  -7.48901367e-02],
                        [ -6.94580078e-02,  -6.94580078e-02],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -5.50537109e-02,  -5.50537109e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  1.27105713e-01,   1.27105713e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.74865723e-01,   1.74865723e-01],
                        [  1.78314209e-01,   1.78314209e-01],
                        [  1.56066895e-01,   1.56066895e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [ -1.16516113e-01,  -1.16516113e-01],
                        [ -2.53204346e-01,  -2.53204346e-01],
                        [ -3.68041992e-01,  -3.68041992e-01],
                        [ -4.18548584e-01,  -4.18548584e-01],
                        [ -3.88580322e-01,  -3.88580322e-01],
                        [ -3.07464600e-01,  -3.07464600e-01],
                        [ -2.26226807e-01,  -2.26226807e-01],
                        [ -1.75476074e-01,  -1.75476074e-01],
                        [ -1.50299072e-01,  -1.50299072e-01],
                        [ -1.29425049e-01,  -1.29425049e-01],
                        [ -1.01928711e-01,  -1.01928711e-01],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.81823730e-01,   1.81823730e-01],
                        [  2.49694824e-01,   2.49694824e-01],
                        [  2.89978027e-01,   2.89978027e-01],
                        [  2.95959473e-01,   2.95959473e-01],
                        [  2.75329590e-01,   2.75329590e-01],
                        [  2.43072510e-01,   2.43072510e-01],
                        [  2.11517334e-01,   2.11517334e-01],
                        [  1.85058594e-01,   1.85058594e-01],
                        [  1.61956787e-01,   1.61956787e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.18743896e-01,   1.18743896e-01],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  8.61206055e-02,   8.61206055e-02],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.33972168e-01,   1.33972168e-01],
                        [  1.60675049e-01,   1.60675049e-01],
                        [  1.80694580e-01,   1.80694580e-01],
                        [  1.77581787e-01,   1.77581787e-01],
                        [  1.41204834e-01,   1.41204834e-01],
                        [  6.92749023e-02,   6.92749023e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -1.71386719e-01,  -1.71386719e-01],
                        [ -3.00537109e-01,  -3.00537109e-01],
                        [ -3.82934570e-01,  -3.82934570e-01],
                        [ -3.93157959e-01,  -3.93157959e-01],
                        [ -3.41369629e-01,  -3.41369629e-01],
                        [ -2.63946533e-01,  -2.63946533e-01],
                        [ -1.97509766e-01,  -1.97509766e-01],
                        [ -1.57745361e-01,  -1.57745361e-01],
                        [ -1.37664795e-01,  -1.37664795e-01],
                        [ -1.23046875e-01,  -1.23046875e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -9.38415527e-02,  -9.38415527e-02],
                        [ -8.42590332e-02,  -8.42590332e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.96136475e-01,   1.96136475e-01],
                        [  2.65014648e-01,   2.65014648e-01],
                        [  3.02612305e-01,   3.02612305e-01],
                        [  3.01269531e-01,   3.01269531e-01],
                        [  2.70202637e-01,   2.70202637e-01],
                        [  2.29827881e-01,   2.29827881e-01],
                        [  1.97662354e-01,   1.97662354e-01],
                        [  1.77764893e-01,   1.77764893e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.50787354e-01,   1.50787354e-01],
                        [  1.36108398e-01,   1.36108398e-01],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -8.40759277e-02,  -8.40759277e-02],
                        [ -8.09631348e-02,  -8.09631348e-02],
                        [ -7.09228516e-02,  -7.09228516e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  7.30590820e-02,   7.30590820e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  1.08489990e-01,   1.08489990e-01],
                        [  1.27899170e-01,   1.27899170e-01],
                        [  1.53472900e-01,   1.53472900e-01],
                        [  1.73400879e-01,   1.73400879e-01],
                        [  1.71661377e-01,   1.71661377e-01],
                        [  1.36047363e-01,   1.36047363e-01],
                        [  6.11877441e-02,   6.11877441e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -1.82891846e-01,  -1.82891846e-01],
                        [ -3.04565430e-01,  -3.04565430e-01],
                        [ -3.78112793e-01,  -3.78112793e-01],
                        [ -3.83605957e-01,  -3.83605957e-01],
                        [ -3.32000732e-01,  -3.32000732e-01],
                        [ -2.57476807e-01,  -2.57476807e-01],
                        [ -1.94458008e-01,  -1.94458008e-01],
                        [ -1.57409668e-01,  -1.57409668e-01],
                        [ -1.38244629e-01,  -1.38244629e-01],
                        [ -1.22009277e-01,  -1.22009277e-01],
                        [ -1.02661133e-01,  -1.02661133e-01],
                        [ -8.38928223e-02,  -8.38928223e-02],
                        [ -6.91833496e-02,  -6.91833496e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.84753418e-01,   1.84753418e-01],
                        [  2.63610840e-01,   2.63610840e-01],
                        [  3.13110352e-01,   3.13110352e-01],
                        [  3.20495605e-01,   3.20495605e-01],
                        [  2.91381836e-01,   2.91381836e-01],
                        [  2.45880127e-01,   2.45880127e-01],
                        [  2.04986572e-01,   2.04986572e-01],
                        [  1.77154541e-01,   1.77154541e-01],
                        [  1.56982422e-01,   1.56982422e-01],
                        [  1.37451172e-01,   1.37451172e-01],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.82678223e-02,  -6.82678223e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -5.91735840e-02,  -5.91735840e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  1.33453369e-01,   1.33453369e-01],
                        [  1.60949707e-01,   1.60949707e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  1.69097900e-01,   1.69097900e-01],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  7.17163086e-02,   7.17163086e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -1.04461670e-01,  -1.04461670e-01],
                        [ -2.04040527e-01,  -2.04040527e-01],
                        [ -2.92358398e-01,  -2.92358398e-01],
                        [ -3.47564697e-01,  -3.47564697e-01],
                        [ -3.54797363e-01,  -3.54797363e-01],
                        [ -3.18115234e-01,  -3.18115234e-01],
                        [ -2.57904053e-01,  -2.57904053e-01],
                        [ -1.98974609e-01,  -1.98974609e-01],
                        [ -1.57379150e-01,  -1.57379150e-01],
                        [ -1.31164551e-01,  -1.31164551e-01],
                        [ -1.07055664e-01,  -1.07055664e-01],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  1.85455322e-01,   1.85455322e-01],
                        [  2.56835938e-01,   2.56835938e-01],
                        [  2.98736572e-01,   2.98736572e-01],
                        [  3.03741455e-01,   3.03741455e-01],
                        [  2.79602051e-01,   2.79602051e-01],
                        [  2.42492676e-01,   2.42492676e-01],
                        [  2.05078125e-01,   2.05078125e-01],
                        [  1.72485352e-01,   1.72485352e-01],
                        [  1.46179199e-01,   1.46179199e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  1.12487793e-01,   1.12487793e-01],
                        [  1.00372314e-01,   1.00372314e-01],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -7.65686035e-02,  -7.65686035e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  9.98840332e-02,   9.98840332e-02],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.43585205e-01,   1.43585205e-01],
                        [  1.60614014e-01,   1.60614014e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  8.56933594e-02,   8.56933594e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -1.51367188e-01,  -1.51367188e-01],
                        [ -2.36511230e-01,  -2.36511230e-01],
                        [ -3.07159424e-01,  -3.07159424e-01],
                        [ -3.46923828e-01,  -3.46923828e-01],
                        [ -3.41613770e-01,  -3.41613770e-01],
                        [ -2.93731689e-01,  -2.93731689e-01],
                        [ -2.26745605e-01,  -2.26745605e-01],
                        [ -1.69677734e-01,  -1.69677734e-01],
                        [ -1.36444092e-01,  -1.36444092e-01],
                        [ -1.18438721e-01,  -1.18438721e-01],
                        [ -9.95788574e-02,  -9.95788574e-02],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  1.86859131e-01,   1.86859131e-01],
                        [  2.55706787e-01,   2.55706787e-01],
                        [  2.98370361e-01,   2.98370361e-01],
                        [  3.07769775e-01,   3.07769775e-01],
                        [  2.86743164e-01,   2.86743164e-01],
                        [  2.45544434e-01,   2.45544434e-01],
                        [  1.99340820e-01,   1.99340820e-01],
                        [  1.61285400e-01,   1.61285400e-01],
                        [  1.36444092e-01,   1.36444092e-01],
                        [  1.22558594e-01,   1.22558594e-01],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  9.11254883e-02,   9.11254883e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.45019531e-01,   1.45019531e-01],
                        [  1.44134521e-01,   1.44134521e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -9.02709961e-02,  -9.02709961e-02],
                        [ -1.54785156e-01,  -1.54785156e-01],
                        [ -2.20916748e-01,  -2.20916748e-01],
                        [ -2.85675049e-01,  -2.85675049e-01],
                        [ -3.32336426e-01,  -3.32336426e-01],
                        [ -3.38012695e-01,  -3.38012695e-01],
                        [ -2.96386719e-01,  -2.96386719e-01],
                        [ -2.29522705e-01,  -2.29522705e-01],
                        [ -1.70654297e-01,  -1.70654297e-01],
                        [ -1.34613037e-01,  -1.34613037e-01],
                        [ -1.11206055e-01,  -1.11206055e-01],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  1.48437500e-01,   1.48437500e-01],
                        [  2.14233398e-01,   2.14233398e-01],
                        [  2.66204834e-01,   2.66204834e-01],
                        [  2.92510986e-01,   2.92510986e-01],
                        [  2.88269043e-01,   2.88269043e-01],
                        [  2.58239746e-01,   2.58239746e-01],
                        [  2.17315674e-01,   2.17315674e-01],
                        [  1.81396484e-01,   1.81396484e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.20513916e-01,   1.20513916e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.23779297e-01,   1.23779297e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  6.95495605e-02,   6.95495605e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -1.93359375e-01,  -1.93359375e-01],
                        [ -2.75909424e-01,  -2.75909424e-01],
                        [ -3.33923340e-01,  -3.33923340e-01],
                        [ -3.32427979e-01,  -3.32427979e-01],
                        [ -2.75177002e-01,  -2.75177002e-01],
                        [ -1.99310303e-01,  -1.99310303e-01],
                        [ -1.41967773e-01,  -1.41967773e-01],
                        [ -1.14013672e-01,  -1.14013672e-01],
                        [ -9.98229980e-02,  -9.98229980e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.74499512e-01,   1.74499512e-01],
                        [  2.20489502e-01,   2.20489502e-01],
                        [  2.56835938e-01,   2.56835938e-01],
                        [  2.79388428e-01,   2.79388428e-01],
                        [  2.80883789e-01,   2.80883789e-01],
                        [  2.57537842e-01,   2.57537842e-01],
                        [  2.17803955e-01,   2.17803955e-01],
                        [  1.76940918e-01,   1.76940918e-01],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  7.95898438e-02,   7.95898438e-02],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -1.03302002e-01,  -1.03302002e-01],
                        [ -1.86065674e-01,  -1.86065674e-01],
                        [ -2.72979736e-01,  -2.72979736e-01],
                        [ -3.23852539e-01,  -3.23852539e-01],
                        [ -3.15155029e-01,  -3.15155029e-01],
                        [ -2.59399414e-01,  -2.59399414e-01],
                        [ -1.93481445e-01,  -1.93481445e-01],
                        [ -1.45782471e-01,  -1.45782471e-01],
                        [ -1.17156982e-01,  -1.17156982e-01],
                        [ -9.29870605e-02,  -9.29870605e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  1.11358643e-01,   1.11358643e-01],
                        [  1.50268555e-01,   1.50268555e-01],
                        [  1.87591553e-01,   1.87591553e-01],
                        [  2.22381592e-01,   2.22381592e-01],
                        [  2.55004883e-01,   2.55004883e-01],
                        [  2.77008057e-01,   2.77008057e-01],
                        [  2.73071289e-01,   2.73071289e-01],
                        [  2.39532471e-01,   2.39532471e-01],
                        [  1.92504883e-01,   1.92504883e-01],
                        [  1.51611328e-01,   1.51611328e-01],
                        [  1.23565674e-01,   1.23565674e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  7.93151855e-02,   7.93151855e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -7.01599121e-02,  -7.01599121e-02],
                        [ -7.36694336e-02,  -7.36694336e-02],
                        [ -8.00781250e-02,  -8.00781250e-02],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -9.58557129e-02,  -9.58557129e-02],
                        [ -1.84600830e-01,  -1.84600830e-01],
                        [ -2.70355225e-01,  -2.70355225e-01],
                        [ -3.14208984e-01,  -3.14208984e-01],
                        [ -3.00018311e-01,  -3.00018311e-01],
                        [ -2.43957520e-01,  -2.43957520e-01],
                        [ -1.79626465e-01,  -1.79626465e-01],
                        [ -1.33209229e-01,  -1.33209229e-01],
                        [ -1.08520508e-01,  -1.08520508e-01],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  1.56768799e-01,   1.56768799e-01],
                        [  1.86706543e-01,   1.86706543e-01],
                        [  2.21160889e-01,   2.21160889e-01],
                        [  2.48077393e-01,   2.48077393e-01],
                        [  2.55004883e-01,   2.55004883e-01],
                        [  2.40936279e-01,   2.40936279e-01],
                        [  2.15728760e-01,   2.15728760e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  1.59118652e-01,   1.59118652e-01],
                        [  1.31835938e-01,   1.31835938e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -6.84204102e-02,  -6.84204102e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -7.64160156e-02,  -7.64160156e-02],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -1.60675049e-01,  -1.60675049e-01],
                        [ -2.43713379e-01,  -2.43713379e-01],
                        [ -2.93029785e-01,  -2.93029785e-01],
                        [ -2.88787842e-01,  -2.88787842e-01],
                        [ -2.39044189e-01,  -2.39044189e-01],
                        [ -1.73583984e-01,  -1.73583984e-01],
                        [ -1.19293213e-01,  -1.19293213e-01],
                        [ -8.48388672e-02,  -8.48388672e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  9.15527344e-04,   9.15527344e-04],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  1.08489990e-01,   1.08489990e-01],
                        [  1.12762451e-01,   1.12762451e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.75506592e-01,   1.75506592e-01],
                        [  2.19848633e-01,   2.19848633e-01],
                        [  2.44995117e-01,   2.44995117e-01],
                        [  2.38677979e-01,   2.38677979e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  1.70745850e-01,   1.70745850e-01],
                        [  1.41784668e-01,   1.41784668e-01],
                        [  1.26434326e-01,   1.26434326e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.61218262e-02,  -5.61218262e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -7.38220215e-02,  -7.38220215e-02],
                        [ -7.66296387e-02,  -7.66296387e-02],
                        [ -7.20520020e-02,  -7.20520020e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -8.39233398e-02,  -8.39233398e-02],
                        [ -9.32006836e-02,  -9.32006836e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -1.41693115e-01,  -1.41693115e-01],
                        [ -2.18475342e-01,  -2.18475342e-01],
                        [ -2.68157959e-01,  -2.68157959e-01],
                        [ -2.69348145e-01,  -2.69348145e-01],
                        [ -2.27233887e-01,  -2.27233887e-01],
                        [ -1.69219971e-01,  -1.69219971e-01],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  1.01379395e-01,   1.01379395e-01],
                        [  1.12518311e-01,   1.12518311e-01],
                        [  1.11633301e-01,   1.11633301e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.47918701e-01,   1.47918701e-01],
                        [  1.87438965e-01,   1.87438965e-01],
                        [  2.20489502e-01,   2.20489502e-01],
                        [  2.34375000e-01,   2.34375000e-01],
                        [  2.26593018e-01,   2.26593018e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  1.68548584e-01,   1.68548584e-01],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.00097656e-01,   1.00097656e-01],
                        [  8.01696777e-02,   8.02001953e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -7.82165527e-02,  -7.82165527e-02],
                        [ -8.08105469e-02,  -8.08105469e-02],
                        [ -8.16650391e-02,  -8.16650391e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -2.12402344e-02,  -2.12707520e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  9.06066895e-02,   9.06372070e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -6.15234375e-02,  -6.15234375e-02],
                        [ -9.98535156e-02,  -9.98229980e-02],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -8.93554688e-02,  -8.93554688e-02],
                        [ -1.78710938e-01,  -1.78710938e-01],
                        [ -2.57629395e-01,  -2.57629395e-01],
                        [ -2.93518066e-01,  -2.93518066e-01],
                        [ -2.73315430e-01,  -2.73315430e-01],
                        [ -2.14416504e-01,  -2.14416504e-01],
                        [ -1.49688721e-01,  -1.49688721e-01],
                        [ -1.04766846e-01,  -1.04766846e-01],
                        [ -8.50219727e-02,  -8.50219727e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  2.34069824e-02,   2.33764648e-02],
                        [  2.32238770e-02,   2.32543945e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.56372070e-01,   1.56372070e-01],
                        [  2.04193115e-01,   2.04193115e-01],
                        [  2.39807129e-01,   2.39807129e-01],
                        [  2.48168945e-01,   2.48168945e-01],
                        [  2.29370117e-01,   2.29370117e-01],
                        [  1.97601318e-01,   1.97601318e-01],
                        [  1.66656494e-01,   1.66656494e-01],
                        [  1.41326904e-01,   1.41326904e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  7.42797852e-02,   7.42797852e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  3.87878418e-02,   3.88183594e-02],
                        [  3.87878418e-02,   3.87573242e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -2.01110840e-02,  -2.01416016e-02],
                        [ -3.23486328e-02,  -3.23181152e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -4.59289551e-02,  -4.58984375e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.61328125e-02,  -3.61022949e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -6.71997070e-02,  -6.71997070e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.84118652e-02,  -2.84423828e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  7.72399902e-02,   7.72399902e-02],
                        [  8.33129883e-02,   8.33129883e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  2.32849121e-02,   2.33154297e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -7.16247559e-02,  -7.16247559e-02],
                        [ -1.02905273e-01,  -1.02874756e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.05383301e-02,   2.05688477e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -9.90600586e-02,  -9.90905762e-02],
                        [ -1.76361084e-01,  -1.76361084e-01],
                        [ -2.37701416e-01,  -2.37670898e-01],
                        [ -2.59521484e-01,  -2.59521484e-01],
                        [ -2.36572266e-01,  -2.36572266e-01],
                        [ -1.86096191e-01,  -1.86096191e-01],
                        [ -1.34033203e-01,  -1.34033203e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -7.82775879e-02,  -7.82470703e-02],
                        [ -6.60400391e-02,  -6.60400391e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -3.43322754e-02,  -3.43017578e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  7.28759766e-02,   7.28759766e-02],
                        [  9.16748047e-02,   9.17053223e-02],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  9.88159180e-02,   9.87854004e-02],
                        [  8.66699219e-02,   8.66699219e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  9.82666016e-02,   9.82666016e-02],
                        [  1.36901855e-01,   1.36932373e-01],
                        [  1.82189941e-01,   1.82220459e-01],
                        [  2.18017578e-01,   2.18017578e-01],
                        [  2.31109619e-01,   2.31109619e-01],
                        [  2.19238281e-01,   2.19238281e-01],
                        [  1.90979004e-01,   1.90979004e-01],
                        [  1.58782959e-01,   1.58782959e-01],
                        [  1.32476807e-01,   1.32476807e-01],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  9.98535156e-02,   9.98535156e-02],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  5.54809570e-02,   5.54504395e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  2.98767090e-02,   2.98461914e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.89099121e-02,  -3.88793945e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -6.96411133e-02,  -6.96411133e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -5.82580566e-02,  -5.82885742e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.36401367e-02,  -4.36706543e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -2.95715332e-02,  -2.95410156e-02],
                        [ -2.28576660e-02,  -2.28881836e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -1.00463867e-01,  -1.00463867e-01],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.00677490e-01,  -1.00677490e-01],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  6.31713867e-03,   6.31713867e-03],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -1.34948730e-01,  -1.34948730e-01],
                        [ -2.15118408e-01,  -2.15118408e-01],
                        [ -2.64312744e-01,  -2.64282227e-01],
                        [ -2.63946533e-01,  -2.63946533e-01],
                        [ -2.18933105e-01,  -2.18933105e-01],
                        [ -1.53045654e-01,  -1.53015137e-01],
                        [ -9.42993164e-02,  -9.43298340e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -3.35388184e-02,  -3.35083008e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  1.01898193e-01,   1.01928711e-01],
                        [  1.27777100e-01,   1.27777100e-01],
                        [  1.33270264e-01,   1.33239746e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  6.61315918e-02,   6.61621094e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.92321777e-01,   1.92321777e-01],
                        [  2.20520020e-01,   2.20520020e-01],
                        [  2.27600098e-01,   2.27630615e-01],
                        [  2.10876465e-01,   2.10876465e-01],
                        [  1.78771973e-01,   1.78771973e-01],
                        [  1.48254395e-01,   1.48254395e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  8.66394043e-02,   8.66699219e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  8.17565918e-02,   8.17260742e-02],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  6.65283203e-02,   6.65283203e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  2.13623047e-03,   2.10571289e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.89208984e-03,   1.92260742e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  7.44628906e-03,   7.47680664e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [ -8.30078125e-03,  -8.27026367e-03],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -6.51855469e-02,  -6.51550293e-02],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -6.58569336e-02,  -6.58569336e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.92041016e-02,  -5.92041016e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.62646484e-02,  -4.62951660e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -4.05273438e-02,  -4.04968262e-02],
                        [ -3.48510742e-02,  -3.48815918e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  9.53063965e-02,   9.53063965e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -1.44927979e-01,  -1.44927979e-01],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  4.45556641e-02,   4.45861816e-02],
                        [  5.94177246e-02,   5.94177246e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  1.55639648e-03,   1.55639648e-03],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -1.64520264e-01,  -1.64520264e-01],
                        [ -2.40875244e-01,  -2.40875244e-01],
                        [ -2.74505615e-01,  -2.74505615e-01],
                        [ -2.52593994e-01,  -2.52593994e-01],
                        [ -1.92626953e-01,  -1.92626953e-01],
                        [ -1.31530762e-01,  -1.31500244e-01],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -8.23974609e-02,  -8.23974609e-02],
                        [ -7.34252930e-02,  -7.34252930e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -3.98559570e-02,  -3.98864746e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.44958496e-02,   1.44653320e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  9.49401855e-02,   9.49401855e-02],
                        [  7.14416504e-02,   7.14416504e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.87835693e-01,   1.87835693e-01],
                        [  2.15454102e-01,   2.15454102e-01],
                        [  2.21374512e-01,   2.21374512e-01],
                        [  2.04925537e-01,   2.04925537e-01],
                        [  1.72515869e-01,   1.72485352e-01],
                        [  1.37054443e-01,   1.37054443e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  6.87866211e-02,   6.87561035e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  5.38024902e-02,   5.37719727e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  2.54821777e-02,   2.54516602e-02],
                        [  1.81274414e-02,   1.80969238e-02],
                        [  7.75146484e-03,   7.78198242e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  1.98364258e-03,   1.95312500e-03],
                        [  7.62939453e-03,   7.65991211e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.51354980e-02,  -4.51660156e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -6.17065430e-02,  -6.16760254e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -6.84204102e-02,  -6.84204102e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -6.25000000e-02,  -6.25000000e-02],
                        [ -6.21032715e-02,  -6.21337891e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -6.10351562e-02,  -6.10046387e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.36608887e-02,  -3.36914062e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -1.29394531e-02,  -1.29089355e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.33056641e-02,  -1.32751465e-02],
                        [ -4.88281250e-04,  -5.18798828e-04],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  5.70983887e-02,   5.70678711e-02],
                        [  6.80847168e-02,   6.80847168e-02],
                        [  7.21740723e-02,   7.22045898e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -7.94982910e-02,  -7.94982910e-02],
                        [ -1.23718262e-01,  -1.23748779e-01],
                        [ -1.35681152e-01,  -1.35681152e-01],
                        [ -1.08123779e-01,  -1.08123779e-01],
                        [ -5.28259277e-02,  -5.28564453e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -1.22375488e-01,  -1.22375488e-01],
                        [ -2.13317871e-01,  -2.13317871e-01],
                        [ -2.68798828e-01,  -2.68798828e-01],
                        [ -2.69287109e-01,  -2.69287109e-01],
                        [ -2.23358154e-01,  -2.23358154e-01],
                        [ -1.61376953e-01,  -1.61376953e-01],
                        [ -1.12640381e-01,  -1.12640381e-01],
                        [ -8.59069824e-02,  -8.59069824e-02],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -1.48010254e-02,  -1.47705078e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  2.75878906e-02,   2.75573730e-02],
                        [  3.88793945e-02,   3.89099121e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  3.11279297e-02,   3.10974121e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  7.08923340e-02,   7.09228516e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.21673584e-01,   1.21673584e-01],
                        [  1.09771729e-01,   1.09802246e-01],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  6.39038086e-02,   6.39343262e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.39434814e-01,   1.39434814e-01],
                        [  1.75781250e-01,   1.75781250e-01],
                        [  2.06268311e-01,   2.06268311e-01],
                        [  2.20764160e-01,   2.20764160e-01],
                        [  2.12493896e-01,   2.12493896e-01],
                        [  1.84783936e-01,   1.84783936e-01],
                        [  1.49566650e-01,   1.49566650e-01],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  9.13391113e-02,   9.13696289e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  6.64978027e-02,   6.64978027e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  5.51147461e-02,   5.51452637e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [ -3.23486328e-03,  -3.26538086e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.91333008e-02,  -4.91638184e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -5.26123047e-02,  -5.26428223e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.74548340e-02,  -4.74853516e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.01306152e-02,  -4.01000977e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -5.82885742e-02,  -5.82580566e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -7.23266602e-02,  -7.23571777e-02],
                        [ -7.52868652e-02,  -7.52563477e-02],
                        [ -7.50122070e-02,  -7.50122070e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -6.43005371e-02,  -6.42700195e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -6.78710938e-02,  -6.79016113e-02],
                        [ -6.14318848e-02,  -6.14013672e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  3.00598145e-02,   3.00292969e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  5.13000488e-02,   5.12695312e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -6.87866211e-02,  -6.87866211e-02],
                        [ -1.31561279e-01,  -1.31561279e-01],
                        [ -1.66046143e-01,  -1.66046143e-01],
                        [ -1.56982422e-01,  -1.56982422e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [  1.28173828e-02,   1.28479004e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  7.19299316e-02,   7.19604492e-02],
                        [  4.06494141e-02,   4.06188965e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.25122070e-01,  -1.25091553e-01],
                        [ -2.14935303e-01,  -2.14935303e-01],
                        [ -2.64587402e-01,  -2.64617920e-01],
                        [ -2.57507324e-01,  -2.57507324e-01],
                        [ -2.05444336e-01,  -2.05444336e-01],
                        [ -1.41967773e-01,  -1.41998291e-01],
                        [ -9.69543457e-02,  -9.69543457e-02],
                        [ -7.54089355e-02,  -7.53784180e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -5.94482422e-02,  -5.94787598e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -1.98059082e-02,  -1.97753906e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  1.17156982e-01,   1.17156982e-01],
                        [  1.38000488e-01,   1.37969971e-01],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.14471436e-01,   1.14501953e-01],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  7.14111328e-02,   7.13806152e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.59301758e-01,   1.59301758e-01],
                        [  2.03796387e-01,   2.03796387e-01],
                        [  2.25830078e-01,   2.25799561e-01],
                        [  2.20336914e-01,   2.20367432e-01],
                        [  1.95465088e-01,   1.95495605e-01],
                        [  1.62933350e-01,   1.62933350e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  8.44726562e-02,   8.44726562e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  5.37719727e-02,   5.37414551e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.97131348e-02,   4.97436523e-02],
                        [  4.69360352e-02,   4.69360352e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -6.71386719e-03,  -6.74438477e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -9.15527344e-03,  -9.18579102e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [ -3.29895020e-02,  -3.29589844e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.86657715e-02,  -3.86962891e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -5.06591797e-02,  -5.06286621e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.16052246e-02,  -5.16357422e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -6.34765625e-02,  -6.35070801e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -5.61828613e-02,  -5.62133789e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -6.09130859e-02,  -6.08825684e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -7.45544434e-02,  -7.45239258e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -5.16967773e-02,  -5.17272949e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -1.98059082e-02,  -1.98364258e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.04870605e-02,  -3.05175781e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  6.99462891e-02,   6.99462891e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  5.42297363e-02,   5.42602539e-02],
                        [  5.79833984e-03,   5.76782227e-03],
                        [ -6.44836426e-02,  -6.45141602e-02],
                        [ -1.28448486e-01,  -1.28417969e-01],
                        [ -1.58050537e-01,  -1.58050537e-01],
                        [ -1.45416260e-01,  -1.45416260e-01],
                        [ -1.03668213e-01,  -1.03637695e-01],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -1.24206543e-02,  -1.24511719e-02],
                        [  1.72729492e-02,   1.73034668e-02],
                        [  3.97338867e-02,   3.97644043e-02],
                        [  5.47180176e-02,   5.46875000e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  1.31835938e-02,   1.32141113e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -1.55700684e-01,  -1.55731201e-01],
                        [ -2.31811523e-01,  -2.31811523e-01],
                        [ -2.58880615e-01,  -2.58880615e-01],
                        [ -2.35229492e-01,  -2.35260010e-01],
                        [ -1.82922363e-01,  -1.82922363e-01],
                        [ -1.26983643e-01,  -1.26953125e-01],
                        [ -8.59985352e-02,  -8.60290527e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -6.21032715e-02,  -6.20727539e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.70080566e-02,   2.70385742e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  1.79443359e-02,   1.79748535e-02],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  5.99060059e-02,   5.99365234e-02],
                        [  9.61914062e-02,   9.61914062e-02],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.49200439e-01,   1.49230957e-01],
                        [  1.50299072e-01,   1.50299072e-01],
                        [  1.30218506e-01,   1.30187988e-01],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.89788818e-01,   1.89788818e-01],
                        [  2.14813232e-01,   2.14813232e-01],
                        [  2.16674805e-01,   2.16674805e-01],
                        [  1.95617676e-01,   1.95617676e-01],
                        [  1.62445068e-01,   1.62445068e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.14959717e-01,   1.14959717e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  4.11987305e-02,   4.12292480e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.60620117e-02,   2.60925293e-02],
                        [  2.53906250e-02,   2.53601074e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.01623535e-02,   1.01928711e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.80053711e-02,  -1.80358887e-02],
                        [ -3.08837891e-02,  -3.08532715e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.88793945e-02,  -3.89099121e-02],
                        [ -3.65295410e-02,  -3.64990234e-02],
                        [ -3.49731445e-02,  -3.49426270e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.33862305e-02,  -3.33557129e-02],
                        [ -3.45458984e-02,  -3.45764160e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.34570312e-02,  -4.34875488e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.93469238e-02,  -4.93164062e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -7.29675293e-02,  -7.29675293e-02],
                        [ -7.78808594e-02,  -7.79113770e-02],
                        [ -7.83081055e-02,  -7.83386230e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.39648438e-02,  -6.39953613e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.69763184e-02,  -5.69458008e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -6.73522949e-02,  -6.73522949e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -4.45861816e-02,  -4.45556641e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  3.65600586e-02,   3.65295410e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -1.77978516e-01,  -1.77978516e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.13464355e-01,  -1.13464355e-01],
                        [ -2.01446533e-01,  -2.01446533e-01],
                        [ -2.60986328e-01,  -2.60986328e-01],
                        [ -2.71728516e-01,  -2.71728516e-01],
                        [ -2.33032227e-01,  -2.33032227e-01],
                        [ -1.67785645e-01,  -1.67816162e-01],
                        [ -1.08428955e-01,  -1.08428955e-01],
                        [ -7.46154785e-02,  -7.45849609e-02],
                        [ -6.38122559e-02,  -6.38427734e-02],
                        [ -6.16149902e-02,  -6.16455078e-02],
                        [ -5.76477051e-02,  -5.76171875e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -4.62951660e-02,  -4.63256836e-02],
                        [ -3.62243652e-02,  -3.61938477e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [  1.27258301e-02,   1.26953125e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  5.07507324e-02,   5.07812500e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  4.01000977e-02,   4.00695801e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  1.44439697e-01,   1.44439697e-01],
                        [  1.61071777e-01,   1.61071777e-01],
                        [  1.49719238e-01,   1.49719238e-01],
                        [  1.16027832e-01,   1.16027832e-01],
                        [  7.68737793e-02,   7.68737793e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  2.00897217e-01,   2.00897217e-01],
                        [  2.21527100e-01,   2.21527100e-01],
                        [  2.16674805e-01,   2.16674805e-01],
                        [  1.91528320e-01,   1.91497803e-01],
                        [  1.58172607e-01,   1.58172607e-01],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.04492188e-01,   1.04461670e-01],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  5.46875000e-02,   5.46569824e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  3.80249023e-02,   3.80554199e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  1.91650391e-02,   1.91345215e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  3.05175781e-04,   2.74658203e-04],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.60815430e-02,  -4.60510254e-02],
                        [ -4.40673828e-02,  -4.40979004e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -5.47485352e-02,  -5.47790527e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.23986816e-02,  -5.23681641e-02],
                        [ -4.95300293e-02,  -4.95605469e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -5.59692383e-02,  -5.59387207e-02],
                        [ -6.39648438e-02,  -6.39648438e-02],
                        [ -7.12890625e-02,  -7.13195801e-02],
                        [ -7.41271973e-02,  -7.40966797e-02],
                        [ -7.07092285e-02,  -7.06787109e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.45446777e-02,  -6.45141602e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -6.93359375e-02,  -6.93054199e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.63659668e-02,  -5.63964844e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.15356445e-02,  -1.15051270e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [  4.36401367e-03,   4.33349609e-03],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  3.33557129e-02,   3.33862305e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  7.39440918e-02,   7.39135742e-02],
                        [  8.39843750e-02,   8.39843750e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -9.47570801e-02,  -9.47570801e-02],
                        [ -1.55517578e-01,  -1.55487061e-01],
                        [ -1.81762695e-01,  -1.81793213e-01],
                        [ -1.62384033e-01,  -1.62384033e-01],
                        [ -1.06262207e-01,  -1.06231689e-01],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  6.95495605e-02,   6.95495605e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  7.40966797e-02,   7.41271973e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -1.42303467e-01,  -1.42303467e-01],
                        [ -2.27630615e-01,  -2.27600098e-01],
                        [ -2.68493652e-01,  -2.68493652e-01],
                        [ -2.56134033e-01,  -2.56164551e-01],
                        [ -2.06542969e-01,  -2.06542969e-01],
                        [ -1.46911621e-01,  -1.46881104e-01],
                        [ -1.00860596e-01,  -1.00860596e-01],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -6.89697266e-02,  -6.89392090e-02],
                        [ -6.15539551e-02,  -6.15844727e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  2.90527344e-02,   2.90222168e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  7.52868652e-02,   7.53173828e-02],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.30798340e-01,   1.30828857e-01],
                        [  1.16058350e-01,   1.16088867e-01],
                        [  9.35974121e-02,   9.35668945e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  5.47485352e-02,   5.47790527e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.47705078e-01,   1.47705078e-01],
                        [  1.99798584e-01,   1.99829102e-01],
                        [  2.34069824e-01,   2.34069824e-01],
                        [  2.37243652e-01,   2.37243652e-01],
                        [  2.10815430e-01,   2.10845947e-01],
                        [  1.71661377e-01,   1.71691895e-01],
                        [  1.37634277e-01,   1.37634277e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.39855957e-02,   5.39550781e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  2.05383301e-02,   2.05688477e-02],
                        [  7.75146484e-03,   7.72094727e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  4.42504883e-03,   4.45556641e-03],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  1.04064941e-02,   1.03759766e-02],
                        [  1.04064941e-02,   1.04370117e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.13830566e-02,   1.13525391e-02],
                        [  7.44628906e-03,   7.47680664e-03],
                        [ -1.28173828e-03,  -1.25122070e-03],
                        [ -1.43127441e-02,  -1.43432617e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -3.74145508e-02,  -3.73840332e-02],
                        [ -4.22058105e-02,  -4.22363281e-02],
                        [ -4.80651855e-02,  -4.80957031e-02],
                        [ -5.37719727e-02,  -5.37414551e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.25207520e-02,  -5.25512695e-02],
                        [ -5.32531738e-02,  -5.32226562e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -5.90515137e-02,  -5.90820312e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -6.02722168e-02,  -6.02416992e-02],
                        [ -5.93261719e-02,  -5.93566895e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.89599609e-02,  -5.89294434e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.31823730e-02,  -4.31518555e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -5.05371094e-02,  -5.05676270e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -6.01806641e-02,  -6.01501465e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.62438965e-02,  -5.62133789e-02],
                        [ -5.74035645e-02,  -5.74340820e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  3.85437012e-02,   3.85131836e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  6.99768066e-02,   6.99768066e-02],
                        [  7.41271973e-02,   7.40966797e-02],
                        [  6.79931641e-02,   6.79626465e-02],
                        [  4.56237793e-02,   4.56542969e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [ -6.44836426e-02,  -6.45141602e-02],
                        [ -1.27563477e-01,  -1.27532959e-01],
                        [ -1.65344238e-01,  -1.65344238e-01],
                        [ -1.64733887e-01,  -1.64733887e-01],
                        [ -1.28509521e-01,  -1.28509521e-01],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -1.34918213e-01,  -1.34918213e-01],
                        [ -2.03918457e-01,  -2.03948975e-01],
                        [ -2.36511230e-01,  -2.36511230e-01],
                        [ -2.21069336e-01,  -2.21069336e-01],
                        [ -1.71020508e-01,  -1.71020508e-01],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -8.43200684e-02,  -8.43200684e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -2.79235840e-02,  -2.79541016e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  8.36181641e-03,   8.33129883e-03],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  4.55017090e-02,   4.55322266e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.51354980e-02,   4.51049805e-02],
                        [  5.55725098e-02,   5.55725098e-02],
                        [  7.73315430e-02,   7.73620605e-02],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.09588623e-01,   1.09558105e-01],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  7.14721680e-02,   7.15026855e-02],
                        [  5.96923828e-02,   5.96618652e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  5.47485352e-02,   5.47790527e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  1.12152100e-01,   1.12121582e-01],
                        [  1.61834717e-01,   1.61865234e-01],
                        [  2.07153320e-01,   2.07153320e-01],
                        [  2.30377197e-01,   2.30346680e-01],
                        [  2.23205566e-01,   2.23205566e-01],
                        [  1.92687988e-01,   1.92718506e-01],
                        [  1.52923584e-01,   1.52893066e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  7.40966797e-02,   7.40966797e-02],
                        [  7.17773438e-02,   7.17468262e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  7.45544434e-02,   7.45544434e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.94091797e-02,  -1.94396973e-02],
                        [ -2.70385742e-02,  -2.70080566e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -5.82580566e-02,  -5.82885742e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -4.31823730e-02,  -4.31518555e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -4.60510254e-02,  -4.60815430e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -3.68652344e-02,  -3.68347168e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.74047852e-02,  -2.74353027e-02],
                        [ -1.78833008e-02,  -1.78527832e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [  4.79125977e-03,   4.76074219e-03],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  3.93066406e-02,   3.93371582e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  3.91845703e-02,   3.91540527e-02],
                        [ -3.02124023e-03,  -3.05175781e-03],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -1.21643066e-01,  -1.21643066e-01],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.48956299e-01,  -1.48925781e-01],
                        [ -1.16363525e-01,  -1.16363525e-01],
                        [ -7.64160156e-02,  -7.64465332e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  8.56018066e-02,   8.55712891e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  2.56042480e-02,   2.56347656e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -1.48864746e-01,  -1.48864746e-01],
                        [ -2.18475342e-01,  -2.18444824e-01],
                        [ -2.41088867e-01,  -2.41088867e-01],
                        [ -2.13897705e-01,  -2.13897705e-01],
                        [ -1.57135010e-01,  -1.57104492e-01],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -6.57958984e-02,  -6.57653809e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -4.51660156e-02,  -4.51354980e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  4.42810059e-02,   4.43115234e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  9.03930664e-02,   9.03625488e-02],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.41906738e-01,   1.41937256e-01],
                        [  1.39984131e-01,   1.39984131e-01],
                        [  1.26831055e-01,   1.26800537e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  6.64672852e-02,   6.64367676e-02],
                        [  5.37414551e-02,   5.37719727e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.90948486e-01,   1.90948486e-01],
                        [  2.07885742e-01,   2.07885742e-01],
                        [  1.99615479e-01,   1.99615479e-01],
                        [  1.72363281e-01,   1.72363281e-01],
                        [  1.41967773e-01,   1.41967773e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  1.06597900e-01,   1.06597900e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  7.69653320e-02,   7.69348145e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  3.18908691e-02,   3.19213867e-02],
                        [  2.65808105e-02,   2.65502930e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -9.21630859e-03,  -9.24682617e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.46484375e-02,  -1.46179199e-02],
                        [ -1.49841309e-02,  -1.50146484e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -2.14843750e-02,  -2.14538574e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.19824219e-02,  -3.20129395e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.09643555e-02,  -5.09948730e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.97229004e-02,  -5.97534180e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -5.24291992e-02,  -5.24597168e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.36706543e-02,  -4.36401367e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -2.37426758e-02,  -2.37121582e-02],
                        [ -4.51660156e-03,  -4.54711914e-03],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -1.25915527e-01,  -1.25915527e-01],
                        [ -1.78344727e-01,  -1.78344727e-01],
                        [ -1.91711426e-01,  -1.91711426e-01],
                        [ -1.63146973e-01,  -1.63146973e-01],
                        [ -1.11602783e-01,  -1.11602783e-01],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  2.69470215e-02,   2.69775391e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  8.13598633e-02,   8.13293457e-02],
                        [  8.98132324e-02,   8.98437500e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -1.45568848e-01,  -1.45568848e-01],
                        [ -2.11334229e-01,  -2.11334229e-01],
                        [ -2.35900879e-01,  -2.35900879e-01],
                        [ -2.16186523e-01,  -2.16186523e-01],
                        [ -1.70867920e-01,  -1.70867920e-01],
                        [ -1.26617432e-01,  -1.26617432e-01],
                        [ -9.75646973e-02,  -9.75646973e-02],
                        [ -7.92846680e-02,  -7.92846680e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -4.57763672e-04,  -4.27246094e-04],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  4.11376953e-02,   4.11071777e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.14843750e-02,   2.15148926e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  3.14636230e-02,   3.14941406e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  1.34063721e-01,   1.34094238e-01],
                        [  1.54266357e-01,   1.54266357e-01],
                        [  1.55487061e-01,   1.55487061e-01],
                        [  1.37237549e-01,   1.37268066e-01],
                        [  1.05987549e-01,   1.06018066e-01],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  4.56237793e-02,   4.55932617e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.73522949e-01,   1.73522949e-01],
                        [  2.03491211e-01,   2.03521729e-01],
                        [  2.11822510e-01,   2.11822510e-01],
                        [  1.93878174e-01,   1.93878174e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  9.28955078e-02,   9.28649902e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  8.23059082e-02,   8.23364258e-02],
                        [  7.79113770e-02,   7.78808594e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  5.66711426e-02,   5.67016602e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -3.19519043e-02,  -3.19213867e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -4.82177734e-02,  -4.82482910e-02],
                        [ -5.21850586e-02,  -5.21545410e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -6.27441406e-02,  -6.27746582e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -5.24902344e-02,  -5.24597168e-02],
                        [ -5.65490723e-02,  -5.65795898e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.96923828e-02,  -5.96618652e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -5.05371094e-02,  -5.05065918e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.57055664e-02,  -3.57360840e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -1.91040039e-02,  -1.90734863e-02],
                        [ -1.61437988e-02,  -1.61743164e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  6.28356934e-02,   6.28051758e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -1.06231689e-01,  -1.06231689e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -2.02331543e-01,  -2.02331543e-01],
                        [ -1.86950684e-01,  -1.86950684e-01],
                        [ -1.34552002e-01,  -1.34552002e-01],
                        [ -7.56225586e-02,  -7.55920410e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  7.01599121e-02,   7.01293945e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -1.46972656e-01,  -1.46972656e-01],
                        [ -2.12066650e-01,  -2.12066650e-01],
                        [ -2.36236572e-01,  -2.36236572e-01],
                        [ -2.14447021e-01,  -2.14447021e-01],
                        [ -1.65985107e-01,  -1.65985107e-01],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -8.87756348e-02,  -8.87756348e-02],
                        [ -7.08007812e-02,  -7.08007812e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  2.77099609e-02,   2.76794434e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  4.00695801e-02,   4.01000977e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  7.18994141e-02,   7.18688965e-02],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  1.47521973e-01,   1.47521973e-01],
                        [  1.44775391e-01,   1.44775391e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.08367920e-01,   1.08367920e-01],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  7.06787109e-02,   7.06787109e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  1.39770508e-01,   1.39770508e-01],
                        [  1.78131104e-01,   1.78131104e-01],
                        [  1.97387695e-01,   1.97387695e-01],
                        [  1.90765381e-01,   1.90765381e-01],
                        [  1.65588379e-01,   1.65618896e-01],
                        [  1.37237549e-01,   1.37207031e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  9.14916992e-02,   9.14916992e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.98059082e-02,  -1.98364258e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -5.18493652e-02,  -5.18188477e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -7.02209473e-02,  -7.01904297e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.53076172e-02,  -6.53381348e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  5.73120117e-02,   5.73425293e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  7.65991211e-03,   7.69042969e-03],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -1.22619629e-01,  -1.22619629e-01],
                        [ -1.82098389e-01,  -1.82098389e-01],
                        [ -2.06420898e-01,  -2.06420898e-01],
                        [ -1.90582275e-01,  -1.90582275e-01],
                        [ -1.48376465e-01,  -1.48376465e-01],
                        [ -9.94873047e-02,  -9.94567871e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  1.02752686e-01,   1.02752686e-01],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  4.16564941e-02,   4.16870117e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -1.20330811e-01,  -1.20330811e-01],
                        [ -1.97631836e-01,  -1.97631836e-01],
                        [ -2.35565186e-01,  -2.35565186e-01],
                        [ -2.24151611e-01,  -2.24151611e-01],
                        [ -1.78466797e-01,  -1.78436279e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -8.72192383e-02,  -8.72497559e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -4.67529297e-02,  -4.67834473e-02],
                        [ -3.09753418e-02,  -3.09448242e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -8.72802734e-03,  -8.75854492e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.29089355e-01,   1.29089355e-01],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  1.21490479e-01,   1.21490479e-01],
                        [  1.10809326e-01,   1.10809326e-01],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.07922363e-02,   3.08227539e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  1.42761230e-01,   1.42761230e-01],
                        [  1.79168701e-01,   1.79168701e-01],
                        [  1.94702148e-01,   1.94702148e-01],
                        [  1.82556152e-01,   1.82556152e-01],
                        [  1.52893066e-01,   1.52893066e-01],
                        [  1.26129150e-01,   1.26129150e-01],
                        [  1.10748291e-01,   1.10717773e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  7.44628906e-02,   7.44628906e-02],
                        [  6.68334961e-02,   6.68640137e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -1.36352539e-01,  -1.36352539e-01],
                        [ -1.96594238e-01,  -1.96594238e-01],
                        [ -2.14019775e-01,  -2.14019775e-01],
                        [ -1.88049316e-01,  -1.88049316e-01],
                        [ -1.40838623e-01,  -1.40838623e-01],
                        [ -9.72290039e-02,  -9.72290039e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -1.35589600e-01,  -1.35589600e-01],
                        [ -2.07366943e-01,  -2.07366943e-01],
                        [ -2.33154297e-01,  -2.33154297e-01],
                        [ -2.10815430e-01,  -2.10815430e-01],
                        [ -1.61254883e-01,  -1.61254883e-01],
                        [ -1.14501953e-01,  -1.14501953e-01],
                        [ -8.82873535e-02,  -8.82873535e-02],
                        [ -7.77893066e-02,  -7.77893066e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  1.54937744e-01,   1.54937744e-01],
                        [  1.83624268e-01,   1.83624268e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.72668457e-01,   1.72668457e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  1.08825684e-01,   1.08825684e-01],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  7.73925781e-02,   7.73925781e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -5.38330078e-02,  -5.38635254e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -9.75646973e-02,  -9.75646973e-02],
                        [ -1.57287598e-01,  -1.57287598e-01],
                        [ -1.88385010e-01,  -1.88385010e-01],
                        [ -1.87530518e-01,  -1.87530518e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.28723145e-01,  -1.28723145e-01],
                        [ -9.28039551e-02,  -9.28039551e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  1.09252930e-01,   1.09252930e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  5.48095703e-02,   5.48095703e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -2.07183838e-01,  -2.07183838e-01],
                        [ -2.39471436e-01,  -2.39471436e-01],
                        [ -2.20611572e-01,  -2.20611572e-01],
                        [ -1.70349121e-01,  -1.70349121e-01],
                        [ -1.19201660e-01,  -1.19201660e-01],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.27148438e-02,   3.27453613e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.40258789e-01,   1.40258789e-01],
                        [  1.42120361e-01,   1.42120361e-01],
                        [  1.26525879e-01,   1.26525879e-01],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  8.00781250e-02,   8.00781250e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  1.35650635e-01,   1.35650635e-01],
                        [  1.69311523e-01,   1.69311523e-01],
                        [  1.80603027e-01,   1.80603027e-01],
                        [  1.67633057e-01,   1.67633057e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  7.47375488e-02,   7.47375488e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  4.37011719e-02,   4.37011719e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -8.07189941e-02,  -8.07189941e-02],
                        [ -8.31298828e-02,  -8.31298828e-02],
                        [ -8.27026367e-02,  -8.27026367e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -1.09191895e-01,  -1.09191895e-01],
                        [ -1.63330078e-01,  -1.63330078e-01],
                        [ -1.94976807e-01,  -1.94976807e-01],
                        [ -1.96899414e-01,  -1.96899414e-01],
                        [ -1.70684814e-01,  -1.70684814e-01],
                        [ -1.31469727e-01,  -1.31469727e-01],
                        [ -9.69543457e-02,  -9.69543457e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -9.72290039e-02,  -9.72290039e-02],
                        [ -1.92779541e-01,  -1.92779541e-01],
                        [ -2.47131348e-01,  -2.47131348e-01],
                        [ -2.44079590e-01,  -2.44079590e-01],
                        [ -1.94549561e-01,  -1.94549561e-01],
                        [ -1.30493164e-01,  -1.30493164e-01],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  1.24328613e-01,   1.24328613e-01],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.44897461e-01,   1.44897461e-01],
                        [  1.34918213e-01,   1.34918213e-01],
                        [  1.21704102e-01,   1.21704102e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  1.24816895e-01,   1.24816895e-01],
                        [  1.57379150e-01,   1.57379150e-01],
                        [  1.73217773e-01,   1.73217773e-01],
                        [  1.67968750e-01,   1.67968750e-01],
                        [  1.46728516e-01,   1.46728516e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -9.09423828e-02,  -9.09423828e-02],
                        [ -1.66076660e-01,  -1.66076660e-01],
                        [ -2.18658447e-01,  -2.18658447e-01],
                        [ -2.28820801e-01,  -2.28820801e-01],
                        [ -1.94793701e-01,  -1.94793701e-01],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  6.86950684e-02,   6.86950684e-02],
                        [  1.03118896e-01,   1.03118896e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  4.03442383e-02,   4.03442383e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -1.42395020e-01,  -1.42395020e-01],
                        [ -2.14141846e-01,  -2.14141846e-01],
                        [ -2.40936279e-01,  -2.40936279e-01],
                        [ -2.17895508e-01,  -2.17895508e-01],
                        [ -1.63848877e-01,  -1.63848877e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -7.53173828e-02,  -7.53173828e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  6.20117188e-02,   6.20117188e-02],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  1.32507324e-01,   1.32507324e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.11267090e-01,   1.11267090e-01],
                        [  9.69238281e-02,   9.69238281e-02],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  1.46240234e-01,   1.46240234e-01],
                        [  1.84051514e-01,   1.84051514e-01],
                        [  1.94763184e-01,   1.94763184e-01],
                        [  1.76330566e-01,   1.76330566e-01],
                        [  1.39984131e-01,   1.39984131e-01],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -1.36657715e-01,  -1.36657715e-01],
                        [ -1.97326660e-01,  -1.97326660e-01],
                        [ -2.23968506e-01,  -2.23968506e-01],
                        [ -2.08648682e-01,  -2.08648682e-01],
                        [ -1.67175293e-01,  -1.67175293e-01],
                        [ -1.25305176e-01,  -1.25305176e-01],
                        [ -9.68322754e-02,  -9.68322754e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  1.31286621e-01,   1.31286621e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  4.59289551e-02,   4.59289551e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -1.42456055e-01,  -1.42456055e-01],
                        [ -2.15606689e-01,  -2.15606689e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -2.12371826e-01,  -2.12371826e-01],
                        [ -1.58050537e-01,  -1.58050537e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  9.46044922e-02,   9.46044922e-02],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.22924805e-01,   1.22924805e-01],
                        [  1.02813721e-01,   1.02813721e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.70654297e-01,   1.70654297e-01],
                        [  1.71325684e-01,   1.71325684e-01],
                        [  1.49963379e-01,   1.49963379e-01],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -8.68835449e-02,  -8.68835449e-02],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -7.10144043e-02,  -7.10144043e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -1.45843506e-01,  -1.45843506e-01],
                        [ -2.09411621e-01,  -2.09411621e-01],
                        [ -2.36236572e-01,  -2.36236572e-01],
                        [ -2.21801758e-01,  -2.21801758e-01],
                        [ -1.78253174e-01,  -1.78253174e-01],
                        [ -1.27136230e-01,  -1.27136230e-01],
                        [ -8.81958008e-02,  -8.81958008e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  1.29638672e-01,   1.29638672e-01],
                        [  1.52770996e-01,   1.52770996e-01],
                        [  1.53137207e-01,   1.53137207e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  4.83093262e-02,   4.83093262e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -1.48193359e-01,  -1.48193359e-01],
                        [ -2.22961426e-01,  -2.22961426e-01],
                        [ -2.49542236e-01,  -2.49542236e-01],
                        [ -2.23083496e-01,  -2.23083496e-01],
                        [ -1.66229248e-01,  -1.66229248e-01],
                        [ -1.12396240e-01,  -1.12396240e-01],
                        [ -7.87048340e-02,  -7.87048340e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  1.46362305e-01,   1.46362305e-01],
                        [  1.36962891e-01,   1.36962891e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  9.61303711e-02,   9.61303711e-02],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  6.99768066e-02,   6.99768066e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  1.42150879e-01,   1.42150879e-01],
                        [  1.24176025e-01,   1.24176025e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  7.28759766e-02,   7.28759766e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.41479492e-02,  -6.41479492e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -1.62384033e-01,  -1.62384033e-01],
                        [ -2.23999023e-01,  -2.23999023e-01],
                        [ -2.49786377e-01,  -2.49786377e-01],
                        [ -2.29003906e-01,  -2.29003906e-01],
                        [ -1.77062988e-01,  -1.77062988e-01],
                        [ -1.25213623e-01,  -1.25213623e-01],
                        [ -9.20104980e-02,  -9.20104980e-02],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.41326904e-01,   1.41326904e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  8.00781250e-02,   8.00781250e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -1.84204102e-01,  -1.84204102e-01],
                        [ -2.38800049e-01,  -2.38800049e-01],
                        [ -2.39044189e-01,  -2.39044189e-01],
                        [ -1.95037842e-01,  -1.95037842e-01],
                        [ -1.38519287e-01,  -1.38519287e-01],
                        [ -9.64050293e-02,  -9.64050293e-02],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  1.04614258e-01,   1.04614258e-01],
                        [  1.31744385e-01,   1.31744385e-01],
                        [  1.48498535e-01,   1.48498535e-01],
                        [  1.48925781e-01,   1.48925781e-01],
                        [  1.40533447e-01,   1.40533447e-01],
                        [  1.32598877e-01,   1.32598877e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  1.56402588e-01,   1.56402588e-01],
                        [  1.59027100e-01,   1.59027100e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -1.28448486e-01,  -1.28448486e-01],
                        [ -1.97235107e-01,  -1.97235107e-01],
                        [ -2.36480713e-01,  -2.36480713e-01],
                        [ -2.30987549e-01,  -2.30987549e-01],
                        [ -1.90795898e-01,  -1.90795898e-01],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -8.72192383e-02,  -8.72192383e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  1.09161377e-01,   1.09161377e-01],
                        [  1.39099121e-01,   1.39099121e-01],
                        [  1.50634766e-01,   1.50634766e-01],
                        [  1.35650635e-01,   1.35650635e-01],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -9.89990234e-02,  -9.89990234e-02],
                        [ -1.87377930e-01,  -1.87377930e-01],
                        [ -2.34008789e-01,  -2.34008789e-01],
                        [ -2.29553223e-01,  -2.29553223e-01],
                        [ -1.84448242e-01,  -1.84448242e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  1.42883301e-01,   1.42883301e-01],
                        [  1.36932373e-01,   1.36932373e-01],
                        [  1.28875732e-01,   1.28875732e-01],
                        [  1.25915527e-01,   1.25915527e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.01135254e-01,   1.01135254e-01],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  1.27746582e-01,   1.27746582e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.68334961e-01,   1.68334961e-01],
                        [  1.49719238e-01,   1.49719238e-01],
                        [  1.22253418e-01,   1.22253418e-01],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  5.21545410e-02,   5.21545410e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -1.82373047e-01,  -1.82373047e-01],
                        [ -2.20184326e-01,  -2.20184326e-01],
                        [ -2.17102051e-01,  -2.17102051e-01],
                        [ -1.78100586e-01,  -1.78100586e-01],
                        [ -1.27044678e-01,  -1.27044678e-01],
                        [ -8.94165039e-02,  -8.94165039e-02],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -6.59179688e-02,  -6.59179688e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.28936768e-01,   1.28936768e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.23229980e-01,   1.23229980e-01],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -1.50329590e-01,  -1.50329590e-01],
                        [ -2.13500977e-01,  -2.13500977e-01],
                        [ -2.25555420e-01,  -2.25555420e-01],
                        [ -1.88201904e-01,  -1.88201904e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.37908936e-01,   1.37908936e-01],
                        [  1.40716553e-01,   1.40716553e-01],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.55761719e-01,   1.55761719e-01],
                        [  1.49200439e-01,   1.49200439e-01],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -1.14349365e-01,  -1.14349365e-01],
                        [ -1.81457520e-01,  -1.81457520e-01],
                        [ -2.23876953e-01,  -2.23876953e-01],
                        [ -2.25280762e-01,  -2.25280762e-01],
                        [ -1.87042236e-01,  -1.87042236e-01],
                        [ -1.29364014e-01,  -1.29364014e-01],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  8.56933594e-02,   8.56933594e-02],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -1.19781494e-01,  -1.19781494e-01],
                        [ -1.87225342e-01,  -1.87225342e-01],
                        [ -2.12738037e-01,  -2.12738037e-01],
                        [ -1.90826416e-01,  -1.90826416e-01],
                        [ -1.40594482e-01,  -1.40594482e-01],
                        [ -9.22241211e-02,  -9.22241211e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  1.56463623e-01,   1.56463623e-01],
                        [  1.65740967e-01,   1.65740967e-01],
                        [  1.52374268e-01,   1.52374268e-01],
                        [  1.30737305e-01,   1.30737305e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.09497070e-01,   1.09497070e-01],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  8.57849121e-02,   8.57849121e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.43096924e-01,   1.43096924e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -1.17767334e-01,  -1.17767334e-01],
                        [ -1.89666748e-01,  -1.89666748e-01],
                        [ -2.33734131e-01,  -2.33734131e-01],
                        [ -2.36022949e-01,  -2.36022949e-01],
                        [ -2.01324463e-01,  -2.01324463e-01],
                        [ -1.48223877e-01,  -1.48223877e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  7.57446289e-02,   7.57446289e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -1.06048584e-01,  -1.06048584e-01],
                        [ -1.87347412e-01,  -1.87347412e-01],
                        [ -2.27874756e-01,  -2.27874756e-01],
                        [ -2.18566895e-01,  -2.18566895e-01],
                        [ -1.73980713e-01,  -1.73980713e-01],
                        [ -1.21276855e-01,  -1.21276855e-01],
                        [ -7.97424316e-02,  -7.97424316e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.48895264e-01,   1.48895264e-01],
                        [  1.58050537e-01,   1.58050537e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.39190674e-01,   1.39190674e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.12335205e-01,   1.12335205e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  7.90405273e-02,   7.90405273e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  7.08312988e-02,   7.08312988e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  7.47375488e-02,   7.47375488e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -1.40563965e-01,  -1.40563965e-01],
                        [ -2.03399658e-01,  -2.03399658e-01],
                        [ -2.34252930e-01,  -2.34252930e-01],
                        [ -2.24578857e-01,  -2.24578857e-01],
                        [ -1.84753418e-01,  -1.84753418e-01],
                        [ -1.37481689e-01,  -1.37481689e-01],
                        [ -1.02844238e-01,  -1.02844238e-01],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -7.33337402e-02,  -7.33337402e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.44897461e-01,   1.44897461e-01],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  5.86242676e-02,   5.86242676e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -1.21765137e-01,  -1.21765137e-01],
                        [ -1.98760986e-01,  -1.98760986e-01],
                        [ -2.32910156e-01,  -2.32910156e-01],
                        [ -2.14965820e-01,  -2.14965820e-01],
                        [ -1.62292480e-01,  -1.62292480e-01],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -7.49511719e-02,  -7.49511719e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.74194336e-01,   1.74194336e-01],
                        [  1.72424316e-01,   1.72424316e-01],
                        [  1.60491943e-01,   1.60491943e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.66839600e-01,   1.66839600e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -8.64562988e-02,  -8.64562988e-02],
                        [ -8.38012695e-02,  -8.38012695e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  5.91430664e-02,   5.91430664e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -1.28021240e-01,  -1.28021240e-01],
                        [ -1.96197510e-01,  -1.96197510e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -2.40783691e-01,  -2.40783691e-01],
                        [ -2.04437256e-01,  -2.04437256e-01],
                        [ -1.53076172e-01,  -1.53076172e-01],
                        [ -1.10046387e-01,  -1.10046387e-01],
                        [ -8.32519531e-02,  -8.32519531e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.29089355e-01,   1.29089355e-01],
                        [  1.15631104e-01,   1.15631104e-01],
                        [  7.03735352e-02,   7.03735352e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.09893799e-01,  -1.09893799e-01],
                        [ -1.93481445e-01,  -1.93481445e-01],
                        [ -2.31353760e-01,  -2.31353760e-01],
                        [ -2.15972900e-01,  -2.15972900e-01],
                        [ -1.62414551e-01,  -1.62414551e-01],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  1.41357422e-01,   1.41357422e-01],
                        [  1.61010742e-01,   1.61010742e-01],
                        [  1.60552979e-01,   1.60552979e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.18713379e-01,   1.18713379e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  1.45782471e-01,   1.45782471e-01],
                        [  1.71203613e-01,   1.71203613e-01],
                        [  1.65191650e-01,   1.65191650e-01],
                        [  1.36718750e-01,   1.36718750e-01],
                        [  1.03942871e-01,   1.03942871e-01],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -1.04949951e-01,  -1.04949951e-01],
                        [ -1.76300049e-01,  -1.76300049e-01],
                        [ -2.18597412e-01,  -2.18597412e-01],
                        [ -2.16125488e-01,  -2.16125488e-01],
                        [ -1.78710938e-01,  -1.78710938e-01],
                        [ -1.33941650e-01,  -1.33941650e-01],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -8.92944336e-02,  -8.92944336e-02],
                        [ -8.26721191e-02,  -8.26721191e-02],
                        [ -7.65686035e-02,  -7.65686035e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  6.99462891e-02,   6.99462891e-02],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  1.40533447e-01,   1.40533447e-01],
                        [  1.55395508e-01,   1.55395508e-01],
                        [  1.44989014e-01,   1.44989014e-01],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [ -8.63952637e-02,  -8.63952637e-02],
                        [ -1.73675537e-01,  -1.73675537e-01],
                        [ -2.22564697e-01,  -2.22564697e-01],
                        [ -2.21893311e-01,  -2.21893311e-01],
                        [ -1.79504395e-01,  -1.79504395e-01],
                        [ -1.21612549e-01,  -1.21612549e-01],
                        [ -7.69653320e-02,  -7.69653320e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  1.41235352e-01,   1.41235352e-01],
                        [  1.43157959e-01,   1.43157959e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  1.19171143e-01,   1.19171143e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  1.01806641e-01,   1.01806641e-01],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.44409180e-01,   1.44409180e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -1.14807129e-01,  -1.14807129e-01],
                        [ -1.93664551e-01,  -1.93664551e-01],
                        [ -2.40417480e-01,  -2.40417480e-01],
                        [ -2.40692139e-01,  -2.40692139e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.61102295e-01,  -1.61102295e-01],
                        [ -1.24176025e-01,  -1.24176025e-01],
                        [ -1.00585938e-01,  -1.00585938e-01],
                        [ -8.45031738e-02,  -8.45031738e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.47766113e-01,   1.47766113e-01],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  3.50036621e-02,   3.50036621e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -1.58843994e-01,  -1.58843994e-01],
                        [ -2.17468262e-01,  -2.17468262e-01],
                        [ -2.24151611e-01,  -2.24151611e-01],
                        [ -1.87561035e-01,  -1.87561035e-01],
                        [ -1.31469727e-01,  -1.31469727e-01],
                        [ -8.07189941e-02,  -8.07189941e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  5.69152832e-02,   5.69152832e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.62994385e-01,   1.62994385e-01],
                        [  1.81884766e-01,   1.81884766e-01],
                        [  1.80358887e-01,   1.80358887e-01],
                        [  1.64978027e-01,   1.64978027e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.32476807e-01,   1.32476807e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.44226074e-01,   1.44226074e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.33544922e-01,   1.33544922e-01],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  7.76062012e-02,   7.76062012e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  4.95300293e-02,   4.95300293e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -1.63208008e-01,  -1.63208008e-01],
                        [ -2.19696045e-01,  -2.19696045e-01],
                        [ -2.38098145e-01,  -2.38098145e-01],
                        [ -2.14630127e-01,  -2.14630127e-01],
                        [ -1.66809082e-01,  -1.66809082e-01],
                        [ -1.22100830e-01,  -1.22100830e-01],
                        [ -9.56420898e-02,  -9.56420898e-02],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -7.88879395e-02,  -7.88879395e-02],
                        [ -7.07092285e-02,  -7.07092285e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.38702393e-01,   1.38702393e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  8.38317871e-02,   8.38317871e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.14685059e-01,  -1.14685059e-01],
                        [ -2.04345703e-01,  -2.04345703e-01],
                        [ -2.38464355e-01,  -2.38464355e-01],
                        [ -2.13500977e-01,  -2.13500977e-01],
                        [ -1.51733398e-01,  -1.51733398e-01],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  5.50231934e-02,   5.50231934e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.54235840e-01,   1.54235840e-01],
                        [  1.59973145e-01,   1.59973145e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.37298584e-01,   1.37298584e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  9.29565430e-02,   9.29565430e-02],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -7.01904297e-02,  -7.01904297e-02],
                        [ -1.44439697e-01,  -1.44439697e-01],
                        [ -2.02850342e-01,  -2.02850342e-01],
                        [ -2.26654053e-01,  -2.26654053e-01],
                        [ -2.11700439e-01,  -2.11700439e-01],
                        [ -1.74163818e-01,  -1.74163818e-01],
                        [ -1.38946533e-01,  -1.38946533e-01],
                        [ -1.18988037e-01,  -1.18988037e-01],
                        [ -1.08489990e-01,  -1.08489990e-01],
                        [ -9.50927734e-02,  -9.50927734e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.15509033e-01,   1.15509033e-01],
                        [  1.30432129e-01,   1.30432129e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -1.72729492e-01,  -1.72729492e-01],
                        [ -2.22961426e-01,  -2.22961426e-01],
                        [ -2.15728760e-01,  -2.15728760e-01],
                        [ -1.69952393e-01,  -1.69952393e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  4.37011719e-02,   4.37011719e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  1.10717773e-01,   1.10717773e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.72698975e-01,   1.72698975e-01],
                        [  1.72760010e-01,   1.72760010e-01],
                        [  1.63299561e-01,   1.63299561e-01],
                        [  1.55639648e-01,   1.55639648e-01],
                        [  1.50909424e-01,   1.50909424e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  6.85729980e-02,   6.85729980e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.44775391e-01,   1.44775391e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  8.01391602e-02,   8.01391602e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -1.87194824e-01,  -1.87194824e-01],
                        [ -2.35046387e-01,  -2.35046387e-01],
                        [ -2.38586426e-01,  -2.38586426e-01],
                        [ -2.06939697e-01,  -2.06939697e-01],
                        [ -1.63360596e-01,  -1.63360596e-01],
                        [ -1.28692627e-01,  -1.28692627e-01],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -9.46044922e-02,  -9.46044922e-02],
                        [ -8.08105469e-02,  -8.08105469e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.21185303e-01,   1.21185303e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.44836426e-01,   1.44836426e-01],
                        [  1.32659912e-01,   1.32659912e-01],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -1.01867676e-01,  -1.01867676e-01],
                        [ -1.94915771e-01,  -1.94915771e-01],
                        [ -2.39074707e-01,  -2.39074707e-01],
                        [ -2.23724365e-01,  -2.23724365e-01],
                        [ -1.68365479e-01,  -1.68365479e-01],
                        [ -1.07391357e-01,  -1.07391357e-01],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  1.30126953e-01,   1.30126953e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  1.89697266e-01,   1.89697266e-01],
                        [  1.75231934e-01,   1.75231934e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.42669678e-01,   1.42669678e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.08825684e-01,   1.08825684e-01],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.28326416e-01,   1.28326416e-01],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  6.13098145e-02,   6.13098145e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.22155762e-02,  -5.22155762e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -1.78649902e-01,  -1.78649902e-01],
                        [ -2.45483398e-01,  -2.45483398e-01],
                        [ -2.64770508e-01,  -2.64770508e-01],
                        [ -2.36968994e-01,  -2.36968994e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.43249512e-01,  -1.43249512e-01],
                        [ -1.19049072e-01,  -1.19049072e-01],
                        [ -1.04522705e-01,  -1.04522705e-01],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.32965088e-01,   1.32965088e-01],
                        [  1.34002686e-01,   1.34002686e-01],
                        [  1.15325928e-01,   1.15325928e-01],
                        [  6.79016113e-02,   6.79016113e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.15997314e-01,  -1.15997314e-01],
                        [ -2.02239990e-01,  -2.02239990e-01],
                        [ -2.34436035e-01,  -2.34436035e-01],
                        [ -2.06024170e-01,  -2.06024170e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -8.36181641e-02,  -8.36181641e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.78192139e-01,   1.78192139e-01],
                        [  1.86218262e-01,   1.86218262e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.50054932e-01,   1.50054932e-01],
                        [  1.29302979e-01,   1.29302979e-01],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  1.02691650e-01,   1.02691650e-01],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  1.42272949e-01,   1.42272949e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.06475830e-01,   1.06475830e-01],
                        [  7.40966797e-02,   7.40966797e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -1.19750977e-01,  -1.19750977e-01],
                        [ -1.98913574e-01,  -1.98913574e-01],
                        [ -2.48962402e-01,  -2.48962402e-01],
                        [ -2.50183105e-01,  -2.50183105e-01],
                        [ -2.10784912e-01,  -2.10784912e-01],
                        [ -1.60675049e-01,  -1.60675049e-01],
                        [ -1.24725342e-01,  -1.24725342e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -9.14611816e-02,  -9.14611816e-02],
                        [ -7.69958496e-02,  -7.69958496e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.43402100e-01,   1.43402100e-01],
                        [  1.40716553e-01,   1.40716553e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  4.24499512e-02,   4.24499512e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -1.59301758e-01,  -1.59301758e-01],
                        [ -2.25952148e-01,  -2.25952148e-01],
                        [ -2.33551025e-01,  -2.33551025e-01],
                        [ -1.89605713e-01,  -1.89605713e-01],
                        [ -1.26708984e-01,  -1.26708984e-01],
                        [ -7.80639648e-02,  -7.80639648e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.31744385e-01,   1.31744385e-01],
                        [  1.63269043e-01,   1.63269043e-01],
                        [  1.77551270e-01,   1.77551270e-01],
                        [  1.72790527e-01,   1.72790527e-01],
                        [  1.57653809e-01,   1.57653809e-01],
                        [  1.43463135e-01,   1.43463135e-01],
                        [  1.34246826e-01,   1.34246826e-01],
                        [  1.24450684e-01,   1.24450684e-01],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.24176025e-01,   1.24176025e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -6.78100586e-02,  -6.78100586e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -1.57287598e-01,  -1.57287598e-01],
                        [ -2.28240967e-01,  -2.28240967e-01],
                        [ -2.59521484e-01,  -2.59521484e-01],
                        [ -2.41577148e-01,  -2.41577148e-01],
                        [ -1.90765381e-01,  -1.90765381e-01],
                        [ -1.38488770e-01,  -1.38488770e-01],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -9.40551758e-02,  -9.40551758e-02],
                        [ -8.65783691e-02,  -8.65783691e-02],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  1.11663818e-01,   1.11663818e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.38916016e-01,   1.38916016e-01],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  1.07238770e-01,   1.07238770e-01],
                        [  5.27343750e-02,   5.27343750e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -1.33575439e-01,  -1.33575439e-01],
                        [ -2.09197998e-01,  -2.09197998e-01],
                        [ -2.27661133e-01,  -2.27661133e-01],
                        [ -1.89636230e-01,  -1.89636230e-01],
                        [ -1.28295898e-01,  -1.28295898e-01],
                        [ -8.01391602e-02,  -8.01391602e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  5.25512695e-02,   5.25512695e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  1.26525879e-01,   1.26525879e-01],
                        [  1.67907715e-01,   1.67907715e-01],
                        [  1.91253662e-01,   1.91253662e-01],
                        [  1.88873291e-01,   1.88873291e-01],
                        [  1.69952393e-01,   1.69952393e-01],
                        [  1.51153564e-01,   1.51153564e-01],
                        [  1.40533447e-01,   1.40533447e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  1.32598877e-01,   1.32598877e-01],
                        [  1.43066406e-01,   1.43066406e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -1.48986816e-01,  -1.48986816e-01],
                        [ -2.23968506e-01,  -2.23968506e-01],
                        [ -2.68066406e-01,  -2.68066406e-01],
                        [ -2.67517090e-01,  -2.67517090e-01],
                        [ -2.25799561e-01,  -2.25799561e-01],
                        [ -1.68395996e-01,  -1.68395996e-01],
                        [ -1.25396729e-01,  -1.25396729e-01],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -8.76770020e-02,  -8.76770020e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  1.31042480e-01,   1.31042480e-01],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.20300293e-01,   1.20300293e-01],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -1.31134033e-01,  -1.31134033e-01],
                        [ -1.92871094e-01,  -1.92871094e-01],
                        [ -2.05200195e-01,  -2.05200195e-01],
                        [ -1.68914795e-01,  -1.68914795e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -7.33337402e-02,  -7.33337402e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.77795410e-01,   1.77795410e-01],
                        [  1.93328857e-01,   1.93328857e-01],
                        [  1.79534912e-01,   1.79534912e-01],
                        [  1.52313232e-01,   1.52313232e-01],
                        [  1.31439209e-01,   1.31439209e-01],
                        [  1.21032715e-01,   1.21032715e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -1.22955322e-01,  -1.22955322e-01],
                        [ -1.99401855e-01,  -1.99401855e-01],
                        [ -2.51739502e-01,  -2.51739502e-01],
                        [ -2.61047363e-01,  -2.61047363e-01],
                        [ -2.27691650e-01,  -2.27691650e-01],
                        [ -1.73797607e-01,  -1.73797607e-01],
                        [ -1.27075195e-01,  -1.27075195e-01],
                        [ -1.00677490e-01,  -1.00677490e-01],
                        [ -8.89587402e-02,  -8.89587402e-02],
                        [ -8.03527832e-02,  -8.03527832e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  8.30688477e-02,   8.30688477e-02],
                        [  1.09558105e-01,   1.09558105e-01],
                        [  1.31683350e-01,   1.31683350e-01],
                        [  1.41632080e-01,   1.41632080e-01],
                        [  1.32446289e-01,   1.32446289e-01],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -1.35650635e-01,  -1.35650635e-01],
                        [ -1.97570801e-01,  -1.97570801e-01],
                        [ -2.10693359e-01,  -2.10693359e-01],
                        [ -1.74468994e-01,  -1.74468994e-01],
                        [ -1.14471436e-01,  -1.14471436e-01],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  1.43646240e-01,   1.43646240e-01],
                        [  1.77337646e-01,   1.77337646e-01],
                        [  1.91955566e-01,   1.91955566e-01],
                        [  1.86950684e-01,   1.86950684e-01],
                        [  1.71508789e-01,   1.71508789e-01],
                        [  1.56036377e-01,   1.56036377e-01],
                        [  1.43920898e-01,   1.43920898e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  8.04748535e-02,   8.04748535e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  1.46820068e-01,   1.46820068e-01],
                        [  1.34552002e-01,   1.34552002e-01],
                        [  1.02600098e-01,   1.02600098e-01],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -7.61718750e-02,  -7.61718750e-02],
                        [ -1.60461426e-01,  -1.60461426e-01],
                        [ -2.29736328e-01,  -2.29736328e-01],
                        [ -2.62512207e-01,  -2.62512207e-01],
                        [ -2.51068115e-01,  -2.51068115e-01],
                        [ -2.06634521e-01,  -2.06634521e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.18743896e-01,  -1.18743896e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -9.89990234e-02,  -9.89990234e-02],
                        [ -8.37097168e-02,  -8.37097168e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.96075439e-01,  -1.96075439e-01],
                        [ -1.98364258e-01,  -1.98364258e-01],
                        [ -1.52770996e-01,  -1.52770996e-01],
                        [ -9.48181152e-02,  -9.48181152e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.65374756e-01,   1.65374756e-01],
                        [  1.81915283e-01,   1.81915283e-01],
                        [  1.79138184e-01,   1.79138184e-01],
                        [  1.66534424e-01,   1.66534424e-01],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.39984131e-01,   1.39984131e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  5.24902344e-03,   5.24902344e-03],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  1.14624023e-01,   1.14624023e-01],
                        [  1.40838623e-01,   1.40838623e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.09771729e-01,   1.09771729e-01],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -1.44561768e-01,  -1.44561768e-01],
                        [ -2.18933105e-01,  -2.18933105e-01],
                        [ -2.55676270e-01,  -2.55676270e-01],
                        [ -2.45056152e-01,  -2.45056152e-01],
                        [ -2.01934814e-01,  -2.01934814e-01],
                        [ -1.52465820e-01,  -1.52465820e-01],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -1.01867676e-01,  -1.01867676e-01],
                        [ -9.52758789e-02,  -9.52758789e-02],
                        [ -8.67919922e-02,  -8.67919922e-02],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.09191895e-01,   1.09191895e-01],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  4.69970703e-03,   4.69970703e-03],
                        [ -9.02709961e-02,  -9.02709961e-02],
                        [ -1.71844482e-01,  -1.71844482e-01],
                        [ -2.07946777e-01,  -2.07946777e-01],
                        [ -1.92382812e-01,  -1.92382812e-01],
                        [ -1.44805908e-01,  -1.44805908e-01],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  3.28369141e-02,   3.28369141e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  1.27624512e-01,   1.27624512e-01],
                        [  1.61499023e-01,   1.61499023e-01],
                        [  1.76269531e-01,   1.76269531e-01],
                        [  1.73950195e-01,   1.73950195e-01],
                        [  1.62109375e-01,   1.62109375e-01],
                        [  1.48223877e-01,   1.48223877e-01],
                        [  1.37329102e-01,   1.37329102e-01],
                        [  1.30432129e-01,   1.30432129e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  9.04541016e-02,   9.04541016e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.76782227e-02,  -5.76782227e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -1.12701416e-01,  -1.12701416e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -2.41882324e-01,  -2.41882324e-01],
                        [ -2.58239746e-01,  -2.58239746e-01],
                        [ -2.33734131e-01,  -2.33734131e-01],
                        [ -1.86706543e-01,  -1.86706543e-01],
                        [ -1.43920898e-01,  -1.43920898e-01],
                        [ -1.17431641e-01,  -1.17431641e-01],
                        [ -1.01165771e-01,  -1.01165771e-01],
                        [ -8.69140625e-02,  -8.69140625e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  6.39953613e-02,   6.39953613e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.27166748e-01,   1.27166748e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  6.94274902e-02,   6.94274902e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -9.89379883e-02,  -9.89379883e-02],
                        [ -1.80206299e-01,  -1.80206299e-01],
                        [ -2.15454102e-01,  -2.15454102e-01],
                        [ -1.94274902e-01,  -1.94274902e-01],
                        [ -1.36871338e-01,  -1.36871338e-01],
                        [ -7.95898438e-02,  -7.95898438e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.80297852e-01,   1.80297852e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  1.80633545e-01,   1.80633545e-01],
                        [  1.58935547e-01,   1.58935547e-01],
                        [  1.39343262e-01,   1.39343262e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -1.53686523e-01,  -1.53686523e-01],
                        [ -2.33001709e-01,  -2.33001709e-01],
                        [ -2.75482178e-01,  -2.75482178e-01],
                        [ -2.71179199e-01,  -2.71179199e-01],
                        [ -2.29980469e-01,  -2.29980469e-01],
                        [ -1.74346924e-01,  -1.74346924e-01],
                        [ -1.28906250e-01,  -1.28906250e-01],
                        [ -1.04614258e-01,  -1.04614258e-01],
                        [ -9.15832520e-02,  -9.15832520e-02],
                        [ -7.48596191e-02,  -7.48596191e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  9.75036621e-02,   9.75036621e-02],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [ -7.07702637e-02,  -7.07702637e-02],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -2.01110840e-01,  -2.01110840e-01],
                        [ -1.97845459e-01,  -1.97845459e-01],
                        [ -1.56494141e-01,  -1.56494141e-01],
                        [ -1.05560303e-01,  -1.05560303e-01],
                        [ -6.68945312e-02,  -6.68945312e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  4.53796387e-02,   4.53796387e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.57318115e-01,   1.57318115e-01],
                        [  1.76757812e-01,   1.76757812e-01],
                        [  1.78680420e-01,   1.78680420e-01],
                        [  1.67602539e-01,   1.67602539e-01],
                        [  1.53259277e-01,   1.53259277e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  1.15325928e-01,   1.15325928e-01],
                        [  1.08856201e-01,   1.08856201e-01],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  4.63867188e-03,   4.63867188e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  9.20715332e-02,   9.20715332e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -1.63970947e-01,  -1.63970947e-01],
                        [ -2.33703613e-01,  -2.33703613e-01],
                        [ -2.63214111e-01,  -2.63214111e-01],
                        [ -2.42370605e-01,  -2.42370605e-01],
                        [ -1.90155029e-01,  -1.90155029e-01],
                        [ -1.40380859e-01,  -1.40380859e-01],
                        [ -1.13677979e-01,  -1.13677979e-01],
                        [ -1.06109619e-01,  -1.06109619e-01],
                        [ -1.02233887e-01,  -1.02233887e-01],
                        [ -9.22241211e-02,  -9.22241211e-02],
                        [ -7.79724121e-02,  -7.79724121e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -1.56677246e-01,  -1.56677246e-01],
                        [ -1.87774658e-01,  -1.87774658e-01],
                        [ -1.72821045e-01,  -1.72821045e-01],
                        [ -1.29974365e-01,  -1.29974365e-01],
                        [ -8.80432129e-02,  -8.80432129e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.50909424e-01,   1.50909424e-01],
                        [  1.74896240e-01,   1.74896240e-01],
                        [  1.77581787e-01,   1.77581787e-01],
                        [  1.65863037e-01,   1.65863037e-01],
                        [  1.49993896e-01,   1.49993896e-01],
                        [  1.37145996e-01,   1.37145996e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.19842529e-01,   1.19842529e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.08612061e-01,   1.08612061e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -7.74536133e-02,  -7.74536133e-02],
                        [ -1.52221680e-01,  -1.52221680e-01],
                        [ -2.18475342e-01,  -2.18475342e-01],
                        [ -2.55187988e-01,  -2.55187988e-01],
                        [ -2.47039795e-01,  -2.47039795e-01],
                        [ -2.01873779e-01,  -2.01873779e-01],
                        [ -1.51062012e-01,  -1.51062012e-01],
                        [ -1.21215820e-01,  -1.21215820e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -1.00585938e-01,  -1.00585938e-01],
                        [ -8.41674805e-02,  -8.41674805e-02],
                        [ -6.85729980e-02,  -6.85729980e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.32171631e-01,   1.32171631e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  7.07702637e-02,   7.07702637e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -2.15179443e-01,  -2.15179443e-01],
                        [ -1.87103271e-01,  -1.87103271e-01],
                        [ -1.28082275e-01,  -1.28082275e-01],
                        [ -7.47680664e-02,  -7.47680664e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  1.40289307e-01,   1.40289307e-01],
                        [  1.63635254e-01,   1.63635254e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.52465820e-01,   1.52465820e-01],
                        [  1.36657715e-01,   1.36657715e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.28723145e-01,   1.28692627e-01],
                        [  1.25854492e-01,   1.25854492e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.27716064e-01,   1.27716064e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -1.59423828e-01,  -1.59423828e-01],
                        [ -2.28454590e-01,  -2.28454590e-01],
                        [ -2.60681152e-01,  -2.60681152e-01],
                        [ -2.45208740e-01,  -2.45208740e-01],
                        [ -1.95739746e-01,  -1.95739746e-01],
                        [ -1.44836426e-01,  -1.44836426e-01],
                        [ -1.18103027e-01,  -1.18103027e-01],
                        [ -1.14074707e-01,  -1.14074707e-01],
                        [ -1.13677979e-01,  -1.13677979e-01],
                        [ -1.04278564e-01,  -1.04278564e-01],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -3.47290039e-02,  -3.46984863e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  1.10351562e-01,   1.10382080e-01],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  5.82275391e-02,   5.82275391e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.67083740e-01,  -1.67083740e-01],
                        [ -1.83258057e-01,  -1.83258057e-01],
                        [ -1.57592773e-01,  -1.57562256e-01],
                        [ -1.13830566e-01,  -1.13830566e-01],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -1.77001953e-02,  -1.76696777e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  1.08062744e-01,   1.08062744e-01],
                        [  1.46331787e-01,   1.46331787e-01],
                        [  1.68945312e-01,   1.68945312e-01],
                        [  1.69799805e-01,   1.69799805e-01],
                        [  1.54693604e-01,   1.54693604e-01],
                        [  1.36566162e-01,   1.36566162e-01],
                        [  1.25579834e-01,   1.25579834e-01],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.10321045e-01,   1.10321045e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  9.41772461e-02,   9.41772461e-02],
                        [  8.90808105e-02,   8.91113281e-02],
                        [  7.74536133e-02,   7.74536133e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -1.68151855e-02,  -1.67846680e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  6.47888184e-02,   6.47888184e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -1.37512207e-01,  -1.37512207e-01],
                        [ -2.26745605e-01,  -2.26745605e-01],
                        [ -2.83020020e-01,  -2.83020020e-01],
                        [ -2.85522461e-01,  -2.85522461e-01],
                        [ -2.42523193e-01,  -2.42523193e-01],
                        [ -1.83898926e-01,  -1.83898926e-01],
                        [ -1.36169434e-01,  -1.36169434e-01],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -7.24792480e-02,  -7.24792480e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -4.54711914e-03,  -4.51660156e-03],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  7.36083984e-02,   7.36083984e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -1.71447754e-01,  -1.71447754e-01],
                        [ -1.66900635e-01,  -1.66900635e-01],
                        [ -1.27960205e-01,  -1.27960205e-01],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.59912109e-01,   1.59912109e-01],
                        [  1.83868408e-01,   1.83868408e-01],
                        [  1.88995361e-01,   1.88995361e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  9.60388184e-02,   9.60388184e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  8.38623047e-02,   8.38623047e-02],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  1.61743164e-02,   1.61437988e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  8.69750977e-03,   8.72802734e-03],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -1.12152100e-01,  -1.12121582e-01],
                        [ -1.94641113e-01,  -1.94641113e-01],
                        [ -2.55310059e-01,  -2.55310059e-01],
                        [ -2.73925781e-01,  -2.73925781e-01],
                        [ -2.49023438e-01,  -2.49023438e-01],
                        [ -1.98242188e-01,  -1.98242188e-01],
                        [ -1.47155762e-01,  -1.47155762e-01],
                        [ -1.14410400e-01,  -1.14410400e-01],
                        [ -1.01379395e-01,  -1.01379395e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -7.62023926e-02,  -7.62023926e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  2.17285156e-02,   2.16979980e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  6.27746582e-02,   6.28051758e-02],
                        [  8.57849121e-02,   8.57849121e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.11877441e-01,   1.11877441e-01],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -1.00463867e-01,  -1.00463867e-01],
                        [ -1.48803711e-01,  -1.48803711e-01],
                        [ -1.61376953e-01,  -1.61376953e-01],
                        [ -1.38305664e-01,  -1.38305664e-01],
                        [ -9.56115723e-02,  -9.56115723e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  1.30889893e-01,   1.30889893e-01],
                        [  1.55242920e-01,   1.55242920e-01],
                        [  1.59912109e-01,   1.59912109e-01],
                        [  1.46942139e-01,   1.46942139e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  1.19537354e-01,   1.19537354e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  7.44628906e-02,   7.44323730e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.58691406e-02,  -1.58386230e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.46472168e-02,  -4.46166992e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  1.00189209e-01,   1.00189209e-01],
                        [  1.12915039e-01,   1.12915039e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -4.27246094e-04,  -3.96728516e-04],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -7.32421875e-04,  -7.62939453e-04],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.72827148e-02,  -2.72521973e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -2.82592773e-02,  -2.82287598e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  4.99572754e-02,   4.99572754e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  4.41894531e-02,   4.42199707e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -1.32904053e-01,  -1.32904053e-01],
                        [ -2.04986572e-01,  -2.04986572e-01],
                        [ -2.53173828e-01,  -2.53173828e-01],
                        [ -2.62542725e-01,  -2.62542725e-01],
                        [ -2.33947754e-01,  -2.33947754e-01],
                        [ -1.85150146e-01,  -1.85150146e-01],
                        [ -1.38488770e-01,  -1.38488770e-01],
                        [ -1.08123779e-01,  -1.08123779e-01],
                        [ -9.55200195e-02,  -9.55200195e-02],
                        [ -9.29260254e-02,  -9.29260254e-02],
                        [ -9.03015137e-02,  -9.03015137e-02],
                        [ -8.14208984e-02,  -8.14208984e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -3.45458984e-02,  -3.45153809e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  6.80541992e-02,   6.80236816e-02],
                        [  8.97216797e-02,   8.97216797e-02],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.35650635e-01,   1.35620117e-01],
                        [  1.39465332e-01,   1.39465332e-01],
                        [  1.14868164e-01,   1.14868164e-01],
                        [  5.42907715e-02,   5.42907715e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -1.23596191e-01,  -1.23596191e-01],
                        [ -1.79779053e-01,  -1.79779053e-01],
                        [ -1.85577393e-01,  -1.85577393e-01],
                        [ -1.50726318e-01,  -1.50726318e-01],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -4.03442383e-02,  -4.03137207e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  1.77124023e-01,   1.77124023e-01],
                        [  2.04406738e-01,   2.04406738e-01],
                        [  1.99798584e-01,   1.99798584e-01],
                        [  1.68701172e-01,   1.68701172e-01],
                        [  1.30432129e-01,   1.30432129e-01],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  5.94177246e-02,   5.94177246e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.14843750e-02,   2.15148926e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  1.19415283e-01,   1.19384766e-01],
                        [  1.23748779e-01,   1.23748779e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  4.78820801e-02,   4.78515625e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  3.57055664e-03,   3.54003906e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  7.38525391e-03,   7.35473633e-03],
                        [ -1.08032227e-02,  -1.08337402e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.76281738e-02,  -3.75976562e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -7.59887695e-03,  -7.62939453e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -1.25732422e-02,  -1.25427246e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -4.91638184e-02,  -4.91333008e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -7.41577148e-03,  -7.44628906e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -1.37237549e-01,  -1.37268066e-01],
                        [ -2.13806152e-01,  -2.13806152e-01],
                        [ -2.59704590e-01,  -2.59704590e-01],
                        [ -2.60986328e-01,  -2.60986328e-01],
                        [ -2.26928711e-01,  -2.26928711e-01],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -1.47766113e-01,  -1.47796631e-01],
                        [ -1.22100830e-01,  -1.22100830e-01],
                        [ -1.00311279e-01,  -1.00311279e-01],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -7.15637207e-02,  -7.15637207e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.29760742e-01,   1.29760742e-01],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.18408203e-01,   1.18408203e-01],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  1.64794922e-03,   1.67846680e-03],
                        [ -8.53576660e-02,  -8.53576660e-02],
                        [ -1.57104492e-01,  -1.57104492e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.70837402e-01,  -1.70806885e-01],
                        [ -1.30432129e-01,  -1.30432129e-01],
                        [ -9.15222168e-02,  -9.15222168e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.73217773e-01,   1.73217773e-01],
                        [  2.01202393e-01,   2.01202393e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  1.81091309e-01,   1.81091309e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  9.55200195e-02,   9.55200195e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  7.86743164e-02,   7.86743164e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -2.47192383e-02,  -2.47497559e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  4.34570312e-02,   4.34265137e-02],
                        [  3.17993164e-02,   3.18298340e-02],
                        [  2.52075195e-02,   2.52380371e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  1.62963867e-02,   1.63269043e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.17175293e-02,  -4.16870117e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  4.91333008e-03,   4.91333008e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -3.67736816e-02,  -3.67431641e-02],
                        [ -1.94396973e-02,  -1.94702148e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  5.02929688e-02,   5.02624512e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  2.15759277e-02,   2.16064453e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -9.88464355e-02,  -9.88769531e-02],
                        [ -1.76757812e-01,  -1.76757812e-01],
                        [ -2.33306885e-01,  -2.33306885e-01],
                        [ -2.48748779e-01,  -2.48748779e-01],
                        [ -2.26226807e-01,  -2.26226807e-01],
                        [ -1.87500000e-01,  -1.87469482e-01],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.32080078e-01,  -1.32080078e-01],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -9.83276367e-02,  -9.83276367e-02],
                        [ -7.85522461e-02,  -7.85827637e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  9.46044922e-02,   9.46044922e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.08154297e-01,   1.08154297e-01],
                        [  1.12365723e-01,   1.12396240e-01],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -1.48498535e-01,  -1.48498535e-01],
                        [ -1.90734863e-01,  -1.90734863e-01],
                        [ -1.83959961e-01,  -1.83959961e-01],
                        [ -1.45172119e-01,  -1.45141602e-01],
                        [ -1.02905273e-01,  -1.02905273e-01],
                        [ -7.26623535e-02,  -7.26928711e-02],
                        [ -5.30395508e-02,  -5.30090332e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.42407227e-02,  -3.42712402e-02],
                        [ -3.68347168e-02,  -3.68652344e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  4.54406738e-02,   4.54711914e-02],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.76513672e-01,   1.76513672e-01],
                        [  1.76086426e-01,   1.76086426e-01],
                        [  1.55731201e-01,   1.55700684e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.00921631e-01,   1.00952148e-01],
                        [  8.59375000e-02,   8.59069824e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  9.41162109e-02,   9.41162109e-02],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  1.08062744e-01,   1.08062744e-01],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  6.12792969e-02,   6.13098145e-02],
                        [  5.90820312e-02,   5.90515137e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  2.73742676e-02,   2.73437500e-02],
                        [  1.25732422e-02,   1.25427246e-02],
                        [ -6.10351562e-05,  -3.05175781e-05],
                        [ -1.42211914e-02,  -1.42517090e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.07849121e-01,   1.07879639e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -3.60107422e-03,  -3.63159180e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.29699707e-02,  -1.29394531e-02],
                        [ -2.12097168e-02,  -2.12402344e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.57055664e-02,  -3.56750488e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -4.03747559e-02,  -4.03442383e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.68139648e-02,  -4.68444824e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -3.71398926e-02,  -3.71093750e-02],
                        [ -2.49023438e-02,  -2.49328613e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -1.21734619e-01,  -1.21765137e-01],
                        [ -2.00439453e-01,  -2.00439453e-01],
                        [ -2.53509521e-01,  -2.53509521e-01],
                        [ -2.65716553e-01,  -2.65716553e-01],
                        [ -2.42828369e-01,  -2.42828369e-01],
                        [ -2.04681396e-01,  -2.04681396e-01],
                        [ -1.67297363e-01,  -1.67327881e-01],
                        [ -1.35742188e-01,  -1.35742188e-01],
                        [ -1.10168457e-01,  -1.10168457e-01],
                        [ -9.17968750e-02,  -9.17968750e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -7.69348145e-02,  -7.69348145e-02],
                        [ -6.97631836e-02,  -6.97326660e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.59912109e-02,   1.59606934e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  1.27899170e-01,   1.27899170e-01],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -1.52343750e-01,  -1.52343750e-01],
                        [ -1.91680908e-01,  -1.91680908e-01],
                        [ -1.80908203e-01,  -1.80908203e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -8.73718262e-02,  -8.73718262e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  7.97119141e-02,   7.97119141e-02],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.74163818e-01,   1.74163818e-01],
                        [  1.86096191e-01,   1.86096191e-01],
                        [  1.76696777e-01,   1.76696777e-01],
                        [  1.55914307e-01,   1.55883789e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  8.97216797e-02,   8.97216797e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -1.13220215e-02,  -1.12915039e-02],
                        [ -2.22167969e-02,  -2.21862793e-02],
                        [ -3.42712402e-02,  -3.43017578e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  1.19293213e-01,   1.19323730e-01],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.58081055e-02,   1.57775879e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  8.72802734e-03,   8.69750977e-03],
                        [ -1.52587891e-04,  -1.83105469e-04],
                        [ -1.06506348e-02,  -1.06201172e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.89306641e-02,  -2.89611816e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.23583984e-02,  -4.23278809e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  5.93872070e-02,   5.93872070e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  4.05578613e-02,   4.05273438e-02],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -1.59027100e-01,  -1.59027100e-01],
                        [ -2.35015869e-01,  -2.35015869e-01],
                        [ -2.76519775e-01,  -2.76519775e-01],
                        [ -2.72338867e-01,  -2.72338867e-01],
                        [ -2.33245850e-01,  -2.33245850e-01],
                        [ -1.83654785e-01,  -1.83654785e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -1.20819092e-01,  -1.20819092e-01],
                        [ -1.06201172e-01,  -1.06201172e-01],
                        [ -9.03625488e-02,  -9.03625488e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -2.13623047e-03,  -2.16674805e-03],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  9.88464355e-02,   9.88159180e-02],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.25183105e-01,   1.25183105e-01],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  3.66210938e-02,   3.66210938e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -1.17340088e-01,  -1.17340088e-01],
                        [ -1.63269043e-01,  -1.63269043e-01],
                        [ -1.68945312e-01,  -1.68945312e-01],
                        [ -1.44958496e-01,  -1.44958496e-01],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -7.39135742e-02,  -7.39135742e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.49621582e-02,  -5.49621582e-02],
                        [ -4.66003418e-02,  -4.65698242e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.55731201e-01,   1.55731201e-01],
                        [  1.72821045e-01,   1.72821045e-01],
                        [  1.71356201e-01,   1.71356201e-01],
                        [  1.58416748e-01,   1.58416748e-01],
                        [  1.42761230e-01,   1.42761230e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.16455078e-01,   1.16485596e-01],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  8.03833008e-02,   8.03833008e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  2.36816406e-02,   2.36511230e-02],
                        [  2.27661133e-02,   2.27966309e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -5.18493652e-02,  -5.18798828e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  1.06597900e-01,   1.06597900e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  9.50927734e-02,   9.51232910e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.35083008e-02,  -3.35388184e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  1.22985840e-02,   1.22680664e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -1.06719971e-01,  -1.06719971e-01],
                        [ -1.83898926e-01,  -1.83898926e-01],
                        [ -2.41241455e-01,  -2.41271973e-01],
                        [ -2.61779785e-01,  -2.61779785e-01],
                        [ -2.46978760e-01,  -2.46978760e-01],
                        [ -2.12890625e-01,  -2.12890625e-01],
                        [ -1.76544189e-01,  -1.76544189e-01],
                        [ -1.46301270e-01,  -1.46301270e-01],
                        [ -1.21887207e-01,  -1.21887207e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -4.33654785e-02,  -4.33959961e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -1.01928711e-02,  -1.01623535e-02],
                        [  1.12915039e-02,   1.12609863e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  3.88793945e-02,   3.89099121e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  5.37719727e-02,   5.37414551e-02],
                        [  7.08618164e-02,   7.08923340e-02],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.33819580e-01,   1.33819580e-01],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -1.62750244e-01,  -1.62750244e-01],
                        [ -2.05474854e-01,  -2.05474854e-01],
                        [ -1.95983887e-01,  -1.95983887e-01],
                        [ -1.52465820e-01,  -1.52465820e-01],
                        [ -1.06933594e-01,  -1.06933594e-01],
                        [ -7.90405273e-02,  -7.90405273e-02],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.19213867e-02,  -3.19519043e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  1.52648926e-01,   1.52679443e-01],
                        [  1.71142578e-01,   1.71142578e-01],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  1.57531738e-01,   1.57531738e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  9.43298340e-02,   9.43603516e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  5.59692383e-02,   5.59387207e-02],
                        [  5.80444336e-02,   5.80749512e-02],
                        [  6.17675781e-02,   6.17370605e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  6.28051758e-02,   6.28356934e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  3.47595215e-02,   3.47900391e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  8.17871094e-03,   8.14819336e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  5.78308105e-02,   5.78308105e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.97546387e-02,  -2.97851562e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.22070312e-02,  -1.22375488e-02],
                        [ -1.01928711e-02,  -1.02233887e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.66723633e-02,  -2.66418457e-02],
                        [ -2.06298828e-02,  -2.06604004e-02],
                        [ -1.08032227e-02,  -1.08337402e-02],
                        [  5.73730469e-03,   5.76782227e-03],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  6.99768066e-02,   6.99768066e-02],
                        [  3.67736816e-02,   3.67431641e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -1.88659668e-01,  -1.88659668e-01],
                        [ -2.54516602e-01,  -2.54516602e-01],
                        [ -2.82653809e-01,  -2.82653809e-01],
                        [ -2.64099121e-01,  -2.64099121e-01],
                        [ -2.11853027e-01,  -2.11883545e-01],
                        [ -1.57684326e-01,  -1.57714844e-01],
                        [ -1.27441406e-01,  -1.27441406e-01],
                        [ -1.19018555e-01,  -1.19018555e-01],
                        [ -1.11663818e-01,  -1.11663818e-01],
                        [ -9.46350098e-02,  -9.46350098e-02],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -2.70385742e-02,  -2.70080566e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  1.31072998e-01,   1.31042480e-01],
                        [  1.32781982e-01,   1.32781982e-01],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  5.12390137e-02,   5.12390137e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -1.05377197e-01,  -1.05346680e-01],
                        [ -1.59088135e-01,  -1.59088135e-01],
                        [ -1.74865723e-01,  -1.74865723e-01],
                        [ -1.57989502e-01,  -1.57989502e-01],
                        [ -1.28875732e-01,  -1.28875732e-01],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -1.02691650e-01,  -1.02691650e-01],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -8.00781250e-02,  -8.00781250e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  1.10473633e-01,   1.10504150e-01],
                        [  1.49627686e-01,   1.49627686e-01],
                        [  1.62536621e-01,   1.62536621e-01],
                        [  1.53747559e-01,   1.53747559e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.26281738e-01,   1.26281738e-01],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  8.68225098e-02,   8.68225098e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  7.45849609e-02,   7.46154785e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  4.09545898e-02,   4.09851074e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.91345215e-02,  -1.91650391e-02],
                        [ -3.23181152e-02,  -3.23486328e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  8.92944336e-02,   8.92944336e-02],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  9.17358398e-02,   9.17663574e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  2.70690918e-02,   2.70996094e-02],
                        [  2.18811035e-02,   2.19116211e-02],
                        [  1.71813965e-02,   1.71508789e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.36303711e-02,  -3.36608887e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -3.40576172e-02,  -3.40881348e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -3.27453613e-02,  -3.27148438e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -2.74291992e-01,  -2.74291992e-01],
                        [ -2.94647217e-01,  -2.94647217e-01],
                        [ -2.63763428e-01,  -2.63763428e-01],
                        [ -2.05780029e-01,  -2.05780029e-01],
                        [ -1.55090332e-01,  -1.55090332e-01],
                        [ -1.29913330e-01,  -1.29913330e-01],
                        [ -1.22467041e-01,  -1.22467041e-01],
                        [ -1.12701416e-01,  -1.12701416e-01],
                        [ -8.94470215e-02,  -8.94470215e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  2.85644531e-02,   2.85949707e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  1.40167236e-01,   1.40167236e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  7.37915039e-02,   7.37915039e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.18469238e-01,  -1.18499756e-01],
                        [ -1.88323975e-01,  -1.88293457e-01],
                        [ -2.10540771e-01,  -2.10540771e-01],
                        [ -1.89636230e-01,  -1.89666748e-01],
                        [ -1.47674561e-01,  -1.47674561e-01],
                        [ -1.10229492e-01,  -1.10229492e-01],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.50451660e-01,   1.50451660e-01],
                        [  1.52343750e-01,   1.52343750e-01],
                        [  1.41754150e-01,   1.41754150e-01],
                        [  1.26953125e-01,   1.26953125e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.01898193e-01,   1.01867676e-01],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  5.14526367e-02,   5.14526367e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  4.52880859e-02,   4.52575684e-02],
                        [  3.11584473e-02,   3.11279297e-02],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -2.76184082e-02,  -2.76489258e-02],
                        [  5.21850586e-03,   5.18798828e-03],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  9.04235840e-02,   9.04235840e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.56958008e-02,   2.57263184e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -4.88281250e-03,  -4.85229492e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.27758789e-02,  -3.28063965e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.21350098e-02,  -3.21044922e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.99682617e-02,  -2.99377441e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  3.19824219e-02,   3.19519043e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -1.25183105e-01,  -1.25183105e-01],
                        [ -2.13836670e-01,  -2.13836670e-01],
                        [ -2.72430420e-01,  -2.72430420e-01],
                        [ -2.84637451e-01,  -2.84637451e-01],
                        [ -2.54119873e-01,  -2.54150391e-01],
                        [ -2.01446533e-01,  -2.01446533e-01],
                        [ -1.50909424e-01,  -1.50909424e-01],
                        [ -1.16241455e-01,  -1.16241455e-01],
                        [ -9.73510742e-02,  -9.73510742e-02],
                        [ -8.86230469e-02,  -8.86230469e-02],
                        [ -8.41979980e-02,  -8.41979980e-02],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -6.39648438e-02,  -6.39343262e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -1.42822266e-02,  -1.42517090e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  3.00292969e-02,   3.00598145e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  4.29077148e-02,   4.28771973e-02],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.50268555e-01,   1.50268555e-01],
                        [  1.47430420e-01,   1.47430420e-01],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  4.11682129e-02,   4.11682129e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -1.52526855e-01,  -1.52526855e-01],
                        [ -2.12951660e-01,  -2.12951660e-01],
                        [ -2.20855713e-01,  -2.20855713e-01],
                        [ -1.84448242e-01,  -1.84478760e-01],
                        [ -1.29913330e-01,  -1.29913330e-01],
                        [ -7.97729492e-02,  -7.97729492e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.24969482e-01,   1.24969482e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  9.32617188e-02,   9.32617188e-02],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  9.41162109e-02,   9.41162109e-02],
                        [  9.24377441e-02,   9.24377441e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  7.84912109e-02,   7.84912109e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  5.62133789e-02,   5.62438965e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  5.65185547e-02,   5.65490723e-02],
                        [  5.69152832e-02,   5.69152832e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  5.11474609e-02,   5.11474609e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  1.94396973e-02,   1.94091797e-02],
                        [  9.39941406e-03,   9.42993164e-03],
                        [  5.21850586e-03,   5.24902344e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -1.44653320e-02,  -1.44958496e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  3.64379883e-02,   3.64074707e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -1.33789062e-01,  -1.33789062e-01],
                        [ -1.96594238e-01,  -1.96624756e-01],
                        [ -2.35900879e-01,  -2.35900879e-01],
                        [ -2.41760254e-01,  -2.41729736e-01],
                        [ -2.16094971e-01,  -2.16094971e-01],
                        [ -1.76879883e-01,  -1.76879883e-01],
                        [ -1.46881104e-01,  -1.46850586e-01],
                        [ -1.34033203e-01,  -1.34033203e-01],
                        [ -1.28997803e-01,  -1.28997803e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -1.04156494e-01,  -1.04156494e-01],
                        [ -8.30993652e-02,  -8.30993652e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.34582520e-01,   1.34582520e-01],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [ -7.82165527e-02,  -7.82470703e-02],
                        [ -1.67816162e-01,  -1.67816162e-01],
                        [ -2.11303711e-01,  -2.11303711e-01],
                        [ -1.91894531e-01,  -1.91925049e-01],
                        [ -1.27532959e-01,  -1.27532959e-01],
                        [ -5.77697754e-02,  -5.77697754e-02],
                        [ -1.08642578e-02,  -1.08947754e-02],
                        [  1.44042969e-02,   1.43737793e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  9.27429199e-02,   9.27429199e-02],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  8.43200684e-02,   8.43200684e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  1.76086426e-02,   1.76391602e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  3.66210938e-04,   3.35693359e-04],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.82189941e-02,   1.82495117e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -4.07409668e-02,  -4.07714844e-02],
                        [ -7.95898438e-02,  -7.95898438e-02],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -1.54815674e-01,  -1.54846191e-01],
                        [ -1.81640625e-01,  -1.81640625e-01],
                        [ -1.93206787e-01,  -1.93206787e-01],
                        [ -1.87072754e-01,  -1.87072754e-01],
                        [ -1.68701172e-01,  -1.68701172e-01],
                        [ -1.47766113e-01,  -1.47766113e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.20483398e-01,  -1.20483398e-01],
                        [ -1.10473633e-01,  -1.10473633e-01],
                        [ -9.87854004e-02,  -9.87854004e-02],
                        [ -8.61511230e-02,  -8.61511230e-02],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [  5.55419922e-03,   5.58471680e-03],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  9.15222168e-02,   9.14916992e-02],
                        [  1.13311768e-01,   1.13311768e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.23748779e-01,   1.23748779e-01],
                        [  9.82666016e-02,   9.82360840e-02],
                        [  4.81872559e-02,   4.82177734e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -9.97924805e-02,  -9.97924805e-02],
                        [ -1.57745361e-01,  -1.57745361e-01],
                        [ -1.71447754e-01,  -1.71447754e-01],
                        [ -1.36169434e-01,  -1.36199951e-01],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  4.77294922e-02,   4.77600098e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  3.34777832e-02,   3.34472656e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [ -2.22778320e-03,  -2.25830078e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -1.82189941e-02,  -1.82495117e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.07922363e-02,  -3.07617188e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.28479004e-02,  -1.28784180e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -1.18774414e-01,  -1.18774414e-01],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -1.92810059e-01,  -1.92810059e-01],
                        [ -2.05566406e-01,  -2.05566406e-01],
                        [ -1.99279785e-01,  -1.99279785e-01],
                        [ -1.83715820e-01,  -1.83685303e-01],
                        [ -1.66931152e-01,  -1.66931152e-01],
                        [ -1.49078369e-01,  -1.49078369e-01],
                        [ -1.27532959e-01,  -1.27532959e-01],
                        [ -1.04064941e-01,  -1.04064941e-01],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.62329102e-02,  -7.62329102e-02],
                        [ -7.33642578e-02,  -7.33642578e-02],
                        [ -6.70471191e-02,  -6.70166016e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  1.02844238e-02,   1.02539062e-02],
                        [  8.94165039e-03,   8.97216797e-03],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.57775879e-02,   1.58081055e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  1.09985352e-01,   1.09985352e-01],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [ -6.64367676e-02,  -6.64672852e-02],
                        [ -1.26190186e-01,  -1.26159668e-01],
                        [ -1.46850586e-01,  -1.46850586e-01],
                        [ -1.17828369e-01,  -1.17828369e-01],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  6.42089844e-02,   6.42089844e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  7.12280273e-02,   7.12280273e-02],
                        [  6.06079102e-02,   6.05773926e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  4.51660156e-02,   4.51965332e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  9.47570801e-02,   9.47875977e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  7.42492676e-02,   7.42797852e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  8.14819336e-03,   8.11767578e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.03247070e-02,  -2.02941895e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -1.32904053e-01,  -1.32904053e-01],
                        [ -2.10845947e-01,  -2.10845947e-01],
                        [ -2.64648438e-01,  -2.64648438e-01],
                        [ -2.80456543e-01,  -2.80456543e-01],
                        [ -2.56927490e-01,  -2.56927490e-01],
                        [ -2.09930420e-01,  -2.09930420e-01],
                        [ -1.63757324e-01,  -1.63757324e-01],
                        [ -1.33911133e-01,  -1.33941650e-01],
                        [ -1.19384766e-01,  -1.19384766e-01],
                        [ -1.09069824e-01,  -1.09069824e-01],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -7.95898438e-02,  -7.95898438e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.62854004e-02,  -3.63159180e-02],
                        [ -2.71911621e-02,  -2.71606445e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.87377930e-02,   1.87072754e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -4.54711914e-03,  -4.57763672e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  8.96606445e-02,   8.96911621e-02],
                        [  1.08947754e-01,   1.08947754e-01],
                        [  1.21643066e-01,   1.21612549e-01],
                        [  1.22467041e-01,   1.22497559e-01],
                        [  1.10961914e-01,   1.10961914e-01],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -1.08093262e-01,  -1.08093262e-01],
                        [ -9.43298340e-02,  -9.43298340e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  4.06799316e-02,   4.06494141e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  5.39550781e-02,   5.39245605e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.29687500e-02,   4.29382324e-02],
                        [  4.63256836e-02,   4.62951660e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.44335938e-02,   4.44335938e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -5.31616211e-02,  -5.31311035e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -5.51452637e-02,  -5.51757812e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.32110596e-01,   1.32141113e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.01196289e-01,   1.01165771e-01],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  4.35485840e-02,   4.35791016e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  3.20434570e-03,   3.20434570e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  6.46972656e-03,   6.43920898e-03],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  2.48107910e-02,   2.48413086e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [ -3.66210938e-03,  -3.69262695e-03],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.08020020e-02,   4.07714844e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  7.17163086e-02,   7.17468262e-02],
                        [  7.94982910e-02,   7.94677734e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -1.18133545e-01,  -1.18164062e-01],
                        [ -1.94396973e-01,  -1.94396973e-01],
                        [ -2.46551514e-01,  -2.46551514e-01],
                        [ -2.64770508e-01,  -2.64801025e-01],
                        [ -2.50274658e-01,  -2.50274658e-01],
                        [ -2.14874268e-01,  -2.14874268e-01],
                        [ -1.74316406e-01,  -1.74316406e-01],
                        [ -1.40075684e-01,  -1.40106201e-01],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -9.85717773e-02,  -9.85717773e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -4.61730957e-02,  -4.62036133e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -2.37121582e-02,  -2.36816406e-02],
                        [ -6.98852539e-03,  -7.01904297e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  2.53906250e-02,   2.54211426e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  2.91748047e-02,   2.92053223e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  7.54089355e-02,   7.53784180e-02],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  1.17370605e-01,   1.17401123e-01],
                        [  1.35406494e-01,   1.35406494e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  3.41491699e-02,   3.41186523e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -1.60827637e-02,  -1.60522461e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  4.62646484e-02,   4.62341309e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -3.80554199e-02,  -3.80249023e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.05529785e-01,   1.05529785e-01],
                        [  7.42187500e-02,   7.41882324e-02],
                        [  4.67834473e-02,   4.67529297e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.93481445e-02,   1.93176270e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.76086426e-02,   1.76391602e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  4.05578613e-02,   4.05273438e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -3.93981934e-02,  -3.93676758e-02],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -1.68060303e-01,  -1.68060303e-01],
                        [ -2.26776123e-01,  -2.26776123e-01],
                        [ -2.53204346e-01,  -2.53204346e-01],
                        [ -2.40997314e-01,  -2.40997314e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.70562744e-01,  -1.70562744e-01],
                        [ -1.44805908e-01,  -1.44805908e-01],
                        [ -1.27471924e-01,  -1.27471924e-01],
                        [ -1.11694336e-01,  -1.11694336e-01],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.15039062e-02,  -4.15344238e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.83911133e-02,  -3.83605957e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -1.89208984e-03,  -1.86157227e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -3.66210938e-04,  -3.96728516e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.27258301e-02,   1.27563477e-02],
                        [  3.01818848e-02,   3.02124023e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  1.41784668e-01,   1.41815186e-01],
                        [  1.53045654e-01,   1.53045654e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  6.43615723e-02,   6.43615723e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -8.12988281e-02,  -8.12988281e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  6.53076172e-03,   6.50024414e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  2.96020508e-03,   2.92968750e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -2.74658203e-04,  -2.44140625e-04],
                        [  1.43737793e-02,   1.43432617e-02],
                        [  3.34167480e-02,   3.33862305e-02],
                        [  4.90722656e-02,   4.91027832e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  6.38427734e-02,   6.38122559e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  5.67016602e-02,   5.67321777e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  9.79614258e-03,   9.76562500e-03],
                        [  1.62353516e-02,   1.62658691e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.22985840e-02,   1.22680664e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -3.22875977e-02,  -3.23181152e-02],
                        [ -4.84313965e-02,  -4.84619141e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.92346191e-02,  -5.92041016e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -5.18798828e-04,  -5.49316406e-04],
                        [  5.40771484e-02,   5.40466309e-02],
                        [  1.06475830e-01,   1.06506348e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.30310059e-01,   1.30279541e-01],
                        [  9.55200195e-02,   9.55200195e-02],
                        [  5.58166504e-02,   5.58471680e-02],
                        [  3.26232910e-02,   3.26538086e-02],
                        [  2.83813477e-02,   2.83508301e-02],
                        [  2.99377441e-02,   2.99072266e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.34277344e-02,   1.34582520e-02],
                        [  2.01416016e-03,   1.98364258e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  3.60107422e-03,   3.63159180e-03],
                        [  6.92749023e-03,   6.95800781e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.27258301e-02,  -1.26953125e-02],
                        [ -8.94165039e-03,  -8.91113281e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -3.99780273e-03,  -4.02832031e-03],
                        [ -5.67626953e-03,  -5.64575195e-03],
                        [ -5.55419922e-03,  -5.52368164e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  1.95312500e-03,   1.92260742e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  1.74865723e-02,   1.75170898e-02],
                        [  2.42004395e-02,   2.42309570e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  5.71594238e-02,   5.71899414e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  7.81860352e-02,   7.81250000e-02],
                        [  6.60095215e-02,   6.60400391e-02],
                        [  3.79943848e-02,   3.80554199e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -6.23168945e-02,  -6.23779297e-02],
                        [ -1.26007080e-01,  -1.25976562e-01],
                        [ -1.84387207e-01,  -1.84326172e-01],
                        [ -2.26287842e-01,  -2.26318359e-01],
                        [ -2.43408203e-01,  -2.43469238e-01],
                        [ -2.33306885e-01,  -2.33306885e-01],
                        [ -2.04101562e-01,  -2.04010010e-01],
                        [ -1.71325684e-01,  -1.71325684e-01],
                        [ -1.46118164e-01,  -1.46209717e-01],
                        [ -1.27349854e-01,  -1.27349854e-01],
                        [ -1.07238770e-01,  -1.07177734e-01],
                        [ -8.33740234e-02,  -8.33435059e-02],
                        [ -6.23474121e-02,  -6.24084473e-02],
                        [ -5.21545410e-02,  -5.21850586e-02],
                        [ -5.23071289e-02,  -5.22766113e-02],
                        [ -5.26733398e-02,  -5.26123047e-02],
                        [ -4.38842773e-02,  -4.39147949e-02],
                        [ -2.76794434e-02,  -2.77404785e-02],
                        [ -1.21154785e-02,  -1.20849609e-02],
                        [ -1.49536133e-03,  -1.43432617e-03],
                        [  4.91333008e-03,   4.88281250e-03],
                        [  1.01623535e-02,   1.01013184e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.49938965e-02,   2.50244141e-02],
                        [  2.73132324e-02,   2.72827148e-02],
                        [  2.16979980e-02,   2.16674805e-02],
                        [  1.37023926e-02,   1.37329102e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  5.95092773e-03,   5.98144531e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.04772949e-02,   2.04467773e-02],
                        [  3.73840332e-02,   3.74145508e-02],
                        [  6.01501465e-02,   6.01806641e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.80023193e-01,   1.79992676e-01],
                        [  2.17773438e-01,   2.17773438e-01],
                        [  2.27478027e-01,   2.27478027e-01],
                        [  1.92993164e-01,   1.92993164e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  1.22375488e-02,   1.22375488e-02],
                        [ -7.18383789e-02,  -7.18688965e-02],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -9.32617188e-02,  -9.32312012e-02],
                        [ -5.44433594e-02,  -5.44128418e-02],
                        [ -2.44140625e-02,  -2.44445801e-02],
                        [ -1.75170898e-02,  -1.75476074e-02],
                        [ -2.34985352e-02,  -2.34680176e-02],
                        [ -2.45056152e-02,  -2.44750977e-02],
                        [ -1.52587891e-02,  -1.52893066e-02],
                        [ -4.57763672e-03,  -4.63867188e-03],
                        [  2.44140625e-04,   2.13623047e-04],
                        [  3.29589844e-03,   3.32641602e-03],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  3.76892090e-02,   3.77197266e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  5.57556152e-02,   5.56945801e-02],
                        [  4.88891602e-02,   4.88281250e-02],
                        [  3.37219238e-02,   3.37524414e-02],
                        [  2.09350586e-02,   2.10266113e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.30310059e-02,   1.29394531e-02],
                        [  9.79614258e-03,   9.76562500e-03],
                        [  8.51440430e-03,   8.63647461e-03],
                        [  9.15527344e-03,   9.21630859e-03],
                        [  3.75366211e-03,   3.66210938e-03],
                        [ -1.15356445e-02,  -1.15966797e-02],
                        [ -2.82592773e-02,  -2.82287598e-02],
                        [ -3.74145508e-02,  -3.73535156e-02],
                        [ -4.07714844e-02,  -4.08020020e-02],
                        [ -4.42810059e-02,  -4.43420410e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.56140137e-02,  -3.55834961e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  1.14929199e-01,   1.14898682e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  9.58862305e-02,   9.59167480e-02],
                        [  6.90307617e-02,   6.90307617e-02],
                        [  5.20324707e-02,   5.20019531e-02],
                        [  4.59594727e-02,   4.59289551e-02],
                        [  4.23583984e-02,   4.23889160e-02],
                        [  3.56445312e-02,   3.56750488e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  1.90429688e-02,   1.90124512e-02],
                        [  1.28173828e-02,   1.28479004e-02],
                        [  7.14111328e-03,   7.17163086e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -7.04956055e-03,  -7.08007812e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.29797363e-02,  -2.30102539e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.89208984e-03,  -1.86157227e-03],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  2.50549316e-02,   2.50854492e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  1.66320801e-02,   1.66015625e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  7.93457031e-02,   7.93151855e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.02081299e-01,   1.02111816e-01],
                        [  8.85009766e-02,   8.85314941e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [ -2.39257812e-02,  -2.39868164e-02],
                        [ -1.08154297e-01,  -1.08154297e-01],
                        [ -1.89971924e-01,  -1.89910889e-01],
                        [ -2.50823975e-01,  -2.50823975e-01],
                        [ -2.73986816e-01,  -2.74047852e-01],
                        [ -2.54730225e-01,  -2.54760742e-01],
                        [ -2.09838867e-01,  -2.09808350e-01],
                        [ -1.68090820e-01,  -1.68029785e-01],
                        [ -1.45172119e-01,  -1.45202637e-01],
                        [ -1.34246826e-01,  -1.34277344e-01],
                        [ -1.22772217e-01,  -1.22772217e-01],
                        [ -1.08856201e-01,  -1.08856201e-01],
                        [ -9.63439941e-02,  -9.63134766e-02],
                        [ -8.54187012e-02,  -8.54187012e-02],
                        [ -7.50427246e-02,  -7.50732422e-02],
                        [ -6.60095215e-02,  -6.60400391e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -4.52880859e-02,  -4.52270508e-02],
                        [ -2.74963379e-02,  -2.74353027e-02],
                        [ -6.83593750e-03,  -6.89697266e-03],
                        [  1.16882324e-02,   1.16271973e-02],
                        [  2.52380371e-02,   2.52990723e-02],
                        [  3.21350098e-02,   3.22265625e-02],
                        [  3.07006836e-02,   3.06701660e-02],
                        [  2.31628418e-02,   2.31018066e-02],
                        [  1.69982910e-02,   1.70288086e-02],
                        [  1.54418945e-02,   1.55029297e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.55639648e-03,   1.52587891e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -2.16369629e-02,  -2.16064453e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [  3.26538086e-03,   3.23486328e-03],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  9.74426270e-02,   9.74731445e-02],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.97967529e-01,   1.97906494e-01],
                        [  2.46887207e-01,   2.46917725e-01],
                        [  2.69256592e-01,   2.69317627e-01],
                        [  2.47161865e-01,   2.47131348e-01],
                        [  1.72119141e-01,   1.72058105e-01],
                        [  5.95092773e-02,   5.95397949e-02],
                        [ -5.05371094e-02,  -5.04760742e-02],
                        [ -1.18469238e-01,  -1.18499756e-01],
                        [ -1.31866455e-01,  -1.31927490e-01],
                        [ -1.06689453e-01,  -1.06658936e-01],
                        [ -6.90307617e-02,  -6.90002441e-02],
                        [ -3.82995605e-02,  -3.83605957e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.24206543e-02,  -1.23596191e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.68457031e-02,  -1.69372559e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -4.58984375e-02,  -4.58068848e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -2.01110840e-02,  -2.02026367e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [  2.85949707e-02,   2.86865234e-02],
                        [  4.25109863e-02,   4.25720215e-02],
                        [  5.45959473e-02,   5.45043945e-02],
                        [  6.41479492e-02,   6.40869141e-02],
                        [  6.55822754e-02,   6.56433105e-02],
                        [  5.67932129e-02,   5.68847656e-02],
                        [  4.15954590e-02,   4.15649414e-02],
                        [  2.50549316e-02,   2.49938965e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [ -3.05175781e-03,  -3.02124023e-03],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.78222656e-02,  -1.78527832e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.50451660e-02,  -1.50146484e-02],
                        [ -1.72119141e-02,  -1.71813965e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -3.13110352e-02,  -3.13415527e-02],
                        [ -3.79943848e-02,  -3.80249023e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -1.66625977e-02,  -1.66015625e-02],
                        [  2.35290527e-02,   2.35595703e-02],
                        [  7.19909668e-02,   7.19299316e-02],
                        [  1.06231689e-01,   1.06170654e-01],
                        [  1.13220215e-01,   1.13311768e-01],
                        [  9.86633301e-02,   9.87548828e-02],
                        [  7.72094727e-02,   7.71484375e-02],
                        [  5.95703125e-02,   5.94787598e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  3.37219238e-02,   3.38134766e-02],
                        [  1.87072754e-02,   1.87377930e-02],
                        [  6.77490234e-03,   6.71386719e-03],
                        [  4.24194336e-03,   4.21142578e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  2.09655762e-02,   2.10266113e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  6.95800781e-03,   6.92749023e-03],
                        [ -1.49841309e-02,  -1.50146484e-02],
                        [ -3.18603516e-02,  -3.18298340e-02],
                        [ -3.54003906e-02,  -3.53698730e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.82287598e-02,   2.82592773e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  5.99670410e-02,   5.99365234e-02],
                        [  7.72094727e-02,   7.71789551e-02],
                        [  9.54589844e-02,   9.55200195e-02],
                        [  1.11480713e-01,   1.11511230e-01],
                        [  1.14959717e-01,   1.14898682e-01],
                        [  9.66491699e-02,   9.66186523e-02],
                        [  5.63354492e-02,   5.63964844e-02],
                        [ -3.08227539e-03,  -3.05175781e-03],
                        [ -8.23364258e-02,  -8.23669434e-02],
                        [ -1.74591064e-01,  -1.74621582e-01],
                        [ -2.53662109e-01,  -2.53631592e-01],
                        [ -2.88604736e-01,  -2.88604736e-01],
                        [ -2.71759033e-01,  -2.71820068e-01],
                        [ -2.23785400e-01,  -2.23785400e-01],
                        [ -1.74346924e-01,  -1.74285889e-01],
                        [ -1.42944336e-01,  -1.42974854e-01],
                        [ -1.30889893e-01,  -1.30920410e-01],
                        [ -1.24725342e-01,  -1.24694824e-01],
                        [ -1.11907959e-01,  -1.11907959e-01],
                        [ -9.29260254e-02,  -9.29565430e-02],
                        [ -7.54699707e-02,  -7.54394531e-02],
                        [ -6.32934570e-02,  -6.32629395e-02],
                        [ -5.48400879e-02,  -5.48706055e-02],
                        [ -4.73022461e-02,  -4.73327637e-02],
                        [ -3.86962891e-02,  -3.86657715e-02],
                        [ -2.96936035e-02,  -2.96630859e-02],
                        [ -2.27050781e-02,  -2.27661133e-02],
                        [ -1.62048340e-02,  -1.62658691e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  9.70458984e-03,   9.73510742e-03],
                        [  2.32238770e-02,   2.32543945e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  3.28979492e-02,   3.28674316e-02],
                        [  2.54516602e-02,   2.53906250e-02],
                        [  1.08642578e-02,   1.09252930e-02],
                        [ -2.47192383e-03,  -2.38037109e-03],
                        [ -8.60595703e-03,  -8.66699219e-03],
                        [ -9.88769531e-03,  -1.00097656e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -8.14819336e-03,  -8.02612305e-03],
                        [ -3.08227539e-03,  -3.05175781e-03],
                        [  6.50024414e-03,   6.43920898e-03],
                        [  2.74353027e-02,   2.73742676e-02],
                        [  7.02514648e-02,   7.02819824e-02],
                        [  1.36535645e-01,   1.36566162e-01],
                        [  2.11181641e-01,   2.11181641e-01],
                        [  2.72094727e-01,   2.72094727e-01],
                        [  3.04626465e-01,   3.04595947e-01],
                        [  3.02520752e-01,   3.02490234e-01],
                        [  2.60009766e-01,   2.60040283e-01],
                        [  1.73980713e-01,   1.74072266e-01],
                        [  5.57556152e-02,   5.57250977e-02],
                        [ -6.39648438e-02,  -6.40563965e-02],
                        [ -1.45812988e-01,  -1.45812988e-01],
                        [ -1.65344238e-01,  -1.65252686e-01],
                        [ -1.32446289e-01,  -1.32415771e-01],
                        [ -8.40759277e-02,  -8.41979980e-02],
                        [ -5.27038574e-02,  -5.27648926e-02],
                        [ -4.26635742e-02,  -4.26025391e-02],
                        [ -3.85131836e-02,  -3.84521484e-02],
                        [ -3.05786133e-02,  -3.06091309e-02],
                        [ -2.44140625e-02,  -2.44445801e-02],
                        [ -2.71606445e-02,  -2.71911621e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -2.80761719e-02,  -2.80151367e-02],
                        [ -4.36401367e-03,  -4.33349609e-03],
                        [  2.67944336e-02,   2.67639160e-02],
                        [  4.83703613e-02,   4.83093262e-02],
                        [  5.57556152e-02,   5.57861328e-02],
                        [  5.56945801e-02,   5.57250977e-02],
                        [  5.17578125e-02,   5.17272949e-02],
                        [  4.14733887e-02,   4.14428711e-02],
                        [  2.51770020e-02,   2.52075195e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -6.04248047e-03,  -6.01196289e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -5.06591797e-03,  -5.09643555e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -1.28173828e-03,  -1.25122070e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.72729492e-02,  -1.73339844e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -3.22875977e-02,  -3.22265625e-02],
                        [ -3.58581543e-02,  -3.58886719e-02],
                        [ -3.95812988e-02,  -3.96423340e-02],
                        [ -3.88488770e-02,  -3.88183594e-02],
                        [ -2.46582031e-02,  -2.45971680e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  5.62744141e-02,   5.61828613e-02],
                        [  1.02081299e-01,   1.02111816e-01],
                        [  1.27319336e-01,   1.27380371e-01],
                        [  1.24359131e-01,   1.24359131e-01],
                        [  1.00982666e-01,   1.00921631e-01],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  5.05371094e-02,   5.05676270e-02],
                        [  3.85742188e-02,   3.85437012e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  2.78320312e-02,   2.78625488e-02],
                        [  2.24609375e-02,   2.24304199e-02],
                        [  1.04064941e-02,   1.03759766e-02],
                        [ -8.23974609e-03,  -8.20922852e-03],
                        [ -2.78015137e-02,  -2.77404785e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.08325195e-02,  -4.08630371e-02],
                        [ -2.58483887e-02,  -2.58789062e-02],
                        [ -3.11279297e-03,  -3.08227539e-03],
                        [  1.41601562e-02,   1.42517090e-02],
                        [  1.91650391e-02,   1.91345215e-02],
                        [  1.70898438e-02,   1.69677734e-02],
                        [  1.84631348e-02,   1.84326172e-02],
                        [  2.85034180e-02,   2.86254883e-02],
                        [  4.28161621e-02,   4.29077148e-02],
                        [  5.31616211e-02,   5.30395508e-02],
                        [  5.85021973e-02,   5.84106445e-02],
                        [  6.80236816e-02,   6.81152344e-02],
                        [  8.74328613e-02,   8.75549316e-02],
                        [  1.06750488e-01,   1.06719971e-01],
                        [  1.08856201e-01,   1.08734131e-01],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  4.91333008e-02,   4.91943359e-02],
                        [  2.44140625e-04,   2.74658203e-04],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -1.42608643e-01,  -1.42608643e-01],
                        [ -2.29980469e-01,  -2.30041504e-01],
                        [ -2.91717529e-01,  -2.91717529e-01],
                        [ -2.96691895e-01,  -2.96630859e-01],
                        [ -2.46063232e-01,  -2.46032715e-01],
                        [ -1.75933838e-01,  -1.75964355e-01],
                        [ -1.26831055e-01,  -1.26861572e-01],
                        [ -1.13525391e-01,  -1.13525391e-01],
                        [ -1.21398926e-01,  -1.21368408e-01],
                        [ -1.25579834e-01,  -1.25488281e-01],
                        [ -1.12945557e-01,  -1.12915039e-01],
                        [ -9.05761719e-02,  -9.06982422e-02],
                        [ -7.30285645e-02,  -7.31201172e-02],
                        [ -6.31408691e-02,  -6.30187988e-02],
                        [ -4.98657227e-02,  -4.97131348e-02],
                        [ -2.52685547e-02,  -2.53906250e-02],
                        [  3.26538086e-03,   3.08227539e-03],
                        [  2.21862793e-02,   2.22473145e-02],
                        [  2.72216797e-02,   2.74047852e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.25732422e-02,   1.24206543e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.28173828e-02,  -1.26953125e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -1.69677734e-02,  -1.70593262e-02],
                        [ -2.02331543e-02,  -2.02026367e-02],
                        [ -2.77099609e-02,  -2.76794434e-02],
                        [ -3.40881348e-02,  -3.41186523e-02],
                        [ -3.50646973e-02,  -3.51257324e-02],
                        [ -3.08837891e-02,  -3.08227539e-02],
                        [ -2.14538574e-02,  -2.13928223e-02],
                        [ -5.27954102e-03,  -5.37109375e-03],
                        [  1.76696777e-02,   1.76086426e-02],
                        [  4.94384766e-02,   4.95300293e-02],
                        [  9.63439941e-02,   9.64050293e-02],
                        [  1.60614014e-01,   1.60522461e-01],
                        [  2.31231689e-01,   2.31170654e-01],
                        [  2.88391113e-01,   2.88452148e-01],
                        [  3.16802979e-01,   3.16833496e-01],
                        [  3.12042236e-01,   3.11981201e-01],
                        [  2.75329590e-01,   2.75299072e-01],
                        [  2.07275391e-01,   2.07305908e-01],
                        [  1.10473633e-01,   1.10504150e-01],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -1.06231689e-01,  -1.06262207e-01],
                        [ -1.73065186e-01,  -1.73095703e-01],
                        [ -1.84295654e-01,  -1.84265137e-01],
                        [ -1.43402100e-01,  -1.43310547e-01],
                        [ -7.99865723e-02,  -7.99865723e-02],
                        [ -3.28674316e-02,  -3.29895020e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.88696289e-02,  -2.87475586e-02],
                        [ -3.96423340e-02,  -3.95812988e-02],
                        [ -4.54711914e-02,  -4.56237793e-02],
                        [ -4.98657227e-02,  -4.99572754e-02],
                        [ -5.23376465e-02,  -5.22460938e-02],
                        [ -4.60205078e-02,  -4.59289551e-02],
                        [ -2.60009766e-02,  -2.60620117e-02],
                        [  5.79833984e-03,   5.67626953e-03],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  6.65588379e-02,   6.66198730e-02],
                        [  7.22351074e-02,   7.22656250e-02],
                        [  5.96618652e-02,   5.96313477e-02],
                        [  3.99780273e-02,   3.99169922e-02],
                        [  2.19726562e-02,   2.19421387e-02],
                        [  7.50732422e-03,   7.53784180e-03],
                        [ -2.59399414e-03,  -2.53295898e-03],
                        [ -6.10351562e-03,  -6.07299805e-03],
                        [ -5.43212891e-03,  -5.49316406e-03],
                        [ -7.84301758e-03,  -7.93457031e-03],
                        [ -1.43737793e-02,  -1.43127441e-02],
                        [ -1.80358887e-02,  -1.79138184e-02],
                        [ -1.73339844e-02,  -1.73645020e-02],
                        [ -2.10876465e-02,  -2.12097168e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -5.40771484e-02,  -5.39550781e-02],
                        [ -6.52770996e-02,  -6.52465820e-02],
                        [ -5.99670410e-02,  -6.00585938e-02],
                        [ -3.52478027e-02,  -3.53088379e-02],
                        [  5.76782227e-03,   5.79833984e-03],
                        [  5.32226562e-02,   5.32531738e-02],
                        [  9.44213867e-02,   9.44519043e-02],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.25579834e-01,   1.25518799e-01],
                        [  1.10321045e-01,   1.10321045e-01],
                        [  8.18481445e-02,   8.19091797e-02],
                        [  5.39855957e-02,   5.40466309e-02],
                        [  3.57666016e-02,   3.57360840e-02],
                        [  2.50549316e-02,   2.49938965e-02],
                        [  1.67236328e-02,   1.67541504e-02],
                        [  1.09558105e-02,   1.09863281e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  7.93457031e-03,   7.90405273e-03],
                        [  4.48608398e-03,   4.42504883e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -1.15966797e-02,  -1.15356445e-02],
                        [ -2.05078125e-02,  -2.04772949e-02],
                        [ -2.62451172e-02,  -2.63366699e-02],
                        [ -2.88391113e-02,  -2.89001465e-02],
                        [ -2.83203125e-02,  -2.82592773e-02],
                        [ -2.16979980e-02,  -2.16064453e-02],
                        [ -7.99560547e-03,  -8.08715820e-03],
                        [  8.78906250e-03,   8.69750977e-03],
                        [  2.57263184e-02,   2.57873535e-02],
                        [  4.25415039e-02,   4.26330566e-02],
                        [  5.72814941e-02,   5.72509766e-02],
                        [  6.90002441e-02,   6.89086914e-02],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  9.67102051e-02,   9.67712402e-02],
                        [  1.10961914e-01,   1.10992432e-01],
                        [  1.18377686e-01,   1.18408203e-01],
                        [  1.11145020e-01,   1.11083984e-01],
                        [  7.84606934e-02,   7.83386230e-02],
                        [  1.55334473e-02,   1.55639648e-02],
                        [ -6.97326660e-02,  -6.95495605e-02],
                        [ -1.62078857e-01,  -1.62048340e-01],
                        [ -2.44506836e-01,  -2.44750977e-01],
                        [ -2.97637939e-01,  -2.97760010e-01],
                        [ -3.04046631e-01,  -3.03833008e-01],
                        [ -2.64099121e-01,  -2.63885498e-01],
                        [ -2.05017090e-01,  -2.05169678e-01],
                        [ -1.60919189e-01,  -1.61193848e-01],
                        [ -1.41784668e-01,  -1.41723633e-01],
                        [ -1.31164551e-01,  -1.30828857e-01],
                        [ -1.12304688e-01,  -1.12274170e-01],
                        [ -8.64868164e-02,  -8.67614746e-02],
                        [ -6.57348633e-02,  -6.58874512e-02],
                        [ -5.58471680e-02,  -5.56335449e-02],
                        [ -5.10253906e-02,  -5.08422852e-02],
                        [ -4.34875488e-02,  -4.35791016e-02],
                        [ -3.06396484e-02,  -3.07922363e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [  1.49536133e-03,   1.55639648e-03],
                        [  9.61303711e-03,   9.67407227e-03],
                        [  9.70458984e-03,   9.73510742e-03],
                        [  6.16455078e-03,   6.10351562e-03],
                        [  8.54492188e-04,   7.32421875e-04],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -2.07214355e-02,  -2.05383301e-02],
                        [ -3.18298340e-02,  -3.17687988e-02],
                        [ -3.94897461e-02,  -3.96423340e-02],
                        [ -4.52270508e-02,  -4.53491211e-02],
                        [ -4.80651855e-02,  -4.79431152e-02],
                        [ -4.40063477e-02,  -4.38232422e-02],
                        [ -3.35693359e-02,  -3.36303711e-02],
                        [ -2.13317871e-02,  -2.14843750e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  2.25830078e-02,   2.27050781e-02],
                        [  6.86950684e-02,   6.87255859e-02],
                        [  1.28265381e-01,   1.28204346e-01],
                        [  1.90307617e-01,   1.90246582e-01],
                        [  2.41485596e-01,   2.41516113e-01],
                        [  2.70141602e-01,   2.70141602e-01],
                        [  2.72644043e-01,   2.72674561e-01],
                        [  2.57324219e-01,   2.57385254e-01],
                        [  2.37091064e-01,   2.37060547e-01],
                        [  2.14721680e-01,   2.14630127e-01],
                        [  1.77734375e-01,   1.77734375e-01],
                        [  1.12121582e-01,   1.12213135e-01],
                        [  2.10266113e-02,   2.10266113e-02],
                        [ -7.25097656e-02,  -7.26013184e-02],
                        [ -1.38458252e-01,  -1.38458252e-01],
                        [ -1.58630371e-01,  -1.58569336e-01],
                        [ -1.41265869e-01,  -1.41296387e-01],
                        [ -1.13647461e-01,  -1.13708496e-01],
                        [ -9.54589844e-02,  -9.53979492e-02],
                        [ -8.60900879e-02,  -8.60290527e-02],
                        [ -7.79113770e-02,  -7.80029297e-02],
                        [ -6.88171387e-02,  -6.88781738e-02],
                        [ -5.82885742e-02,  -5.81359863e-02],
                        [ -4.30297852e-02,  -4.29382324e-02],
                        [ -2.35900879e-02,  -2.37426758e-02],
                        [ -6.71386719e-03,  -6.86645508e-03],
                        [  4.42504883e-03,   4.60815430e-03],
                        [  1.46484375e-02,   1.48315430e-02],
                        [  2.59399414e-02,   2.57568359e-02],
                        [  3.41796875e-02,   3.39355469e-02],
                        [  3.86047363e-02,   3.87573242e-02],
                        [  4.22973633e-02,   4.25415039e-02],
                        [  4.18701172e-02,   4.17480469e-02],
                        [  2.97546387e-02,   2.94799805e-02],
                        [  8.45336914e-03,   8.54492188e-03],
                        [ -8.36181641e-03,  -8.08715820e-03],
                        [ -1.31530762e-02,  -1.31835938e-02],
                        [ -1.22070312e-02,  -1.25122070e-02],
                        [ -1.15661621e-02,  -1.15356445e-02],
                        [ -9.46044922e-03,  -9.15527344e-03],
                        [ -8.72802734e-03,  -8.69750977e-03],
                        [ -1.90734863e-02,  -1.93481445e-02],
                        [ -3.94897461e-02,  -3.95507812e-02],
                        [ -5.37719727e-02,  -5.34973145e-02],
                        [ -5.13000488e-02,  -5.12390137e-02],
                        [ -4.00695801e-02,  -4.03137207e-02],
                        [ -3.02124023e-02,  -3.03039551e-02],
                        [ -1.58996582e-02,  -1.56555176e-02],
                        [  1.46179199e-02,   1.46789551e-02],
                        [  5.70983887e-02,   5.68847656e-02],
                        [  9.34448242e-02,   9.33837891e-02],
                        [  1.11511230e-01,   1.11724854e-01],
                        [  1.11816406e-01,   1.11846924e-01],
                        [  9.88464355e-02,   9.86328125e-02],
                        [  7.88574219e-02,   7.88269043e-02],
                        [  6.11267090e-02,   6.13403320e-02],
                        [  4.92553711e-02,   4.92858887e-02],
                        [  3.65600586e-02,   3.63159180e-02],
                        [  1.87683105e-02,   1.87377930e-02],
                        [  2.92968750e-03,   3.17382812e-03],
                        [ -3.47900391e-03,  -3.41796875e-03],
                        [ -3.54003906e-03,  -3.72314453e-03],
                        [ -4.57763672e-03,  -4.63867188e-03],
                        [ -8.63647461e-03,  -8.48388672e-03],
                        [ -1.47399902e-02,  -1.46484375e-02],
                        [ -2.32238770e-02,  -2.33459473e-02],
                        [ -3.05175781e-02,  -3.05786133e-02],
                        [ -2.71911621e-02,  -2.70996094e-02],
                        [ -9.61303711e-03,  -9.58251953e-03],
                        [  1.19018555e-02,   1.18103027e-02],
                        [  2.32849121e-02,   2.32238770e-02],
                        [  2.31323242e-02,   2.32238770e-02],
                        [  2.56347656e-02,   2.56958008e-02],
                        [  4.42504883e-02,   4.41589355e-02],
                        [  7.57751465e-02,   7.56530762e-02],
                        [  1.06262207e-01,   1.06384277e-01],
                        [  1.27685547e-01,   1.27868652e-01],
                        [  1.40258789e-01,   1.40197754e-01],
                        [  1.43188477e-01,   1.43005371e-01],
                        [  1.29455566e-01,   1.29516602e-01],
                        [  8.85925293e-02,   8.87756348e-02],
                        [  1.39160156e-02,   1.39465332e-02],
                        [ -8.81042480e-02,  -8.82568359e-02],
                        [ -1.93695068e-01,  -1.93756104e-01],
                        [ -2.70629883e-01,  -2.70507812e-01],
                        [ -2.97393799e-01,  -2.97332764e-01],
                        [ -2.76092529e-01,  -2.76153564e-01],
                        [ -2.27752686e-01,  -2.27813721e-01],
                        [ -1.78314209e-01,  -1.78314209e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -1.24725342e-01,  -1.24664307e-01],
                        [ -1.09039307e-01,  -1.08947754e-01],
                        [ -9.09729004e-02,  -9.10034180e-02],
                        [ -7.65380859e-02,  -7.66601562e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -7.62939453e-02,  -7.61413574e-02],
                        [ -6.93969727e-02,  -6.93359375e-02],
                        [ -4.71191406e-02,  -4.72717285e-02],
                        [ -2.02941895e-02,  -2.03552246e-02],
                        [ -2.80761719e-03,  -2.68554688e-03],
                        [  1.09863281e-03,   1.15966797e-03],
                        [ -2.04467773e-03,  -2.13623047e-03],
                        [ -2.10571289e-03,  -2.16674805e-03],
                        [  3.57055664e-03,   3.60107422e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.15966797e-03,   1.12915039e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.06298828e-02,  -2.05993652e-02],
                        [ -2.81066895e-02,  -2.81372070e-02],
                        [ -3.69567871e-02,  -3.70178223e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.82788086e-02,  -4.82177734e-02],
                        [ -3.90930176e-02,  -3.90625000e-02],
                        [ -1.86767578e-02,  -1.87377930e-02],
                        [  1.31225586e-02,   1.30920410e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  1.24755859e-01,   1.24786377e-01],
                        [  1.92199707e-01,   1.92230225e-01],
                        [  2.41424561e-01,   2.41394043e-01],
                        [  2.57843018e-01,   2.57781982e-01],
                        [  2.46032715e-01,   2.46002197e-01],
                        [  2.26776123e-01,   2.26837158e-01],
                        [  2.18475342e-01,   2.18566895e-01],
                        [  2.20458984e-01,   2.20458984e-01],
                        [  2.16613770e-01,   2.16522217e-01],
                        [  1.90826416e-01,   1.90765381e-01],
                        [  1.36962891e-01,   1.37084961e-01],
                        [  6.00585938e-02,   6.01806641e-02],
                        [ -2.67639160e-02,  -2.68249512e-02],
                        [ -1.05224609e-01,  -1.05407715e-01],
                        [ -1.54968262e-01,  -1.54998779e-01],
                        [ -1.62994385e-01,  -1.62811279e-01],
                        [ -1.36688232e-01,  -1.36596680e-01],
                        [ -1.03485107e-01,  -1.03637695e-01],
                        [ -8.77685547e-02,  -8.79211426e-02],
                        [ -8.76464844e-02,  -8.75549316e-02],
                        [ -8.23974609e-02,  -8.22448730e-02],
                        [ -6.13708496e-02,  -6.13403320e-02],
                        [ -3.34777832e-02,  -3.35998535e-02],
                        [ -1.23291016e-02,  -1.23901367e-02],
                        [ -2.77709961e-03,  -2.71606445e-03],
                        [ -4.88281250e-04,  -3.66210938e-04],
                        [  2.19726562e-03,   2.22778320e-03],
                        [  8.69750977e-03,   8.57543945e-03],
                        [  1.65710449e-02,   1.64794922e-02],
                        [  2.33459473e-02,   2.34375000e-02],
                        [  2.95410156e-02,   2.96325684e-02],
                        [  3.58276367e-02,   3.57360840e-02],
                        [  4.14123535e-02,   4.13513184e-02],
                        [  4.38232422e-02,   4.38842773e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  1.68151855e-02,   1.67846680e-02],
                        [ -1.22375488e-02,  -1.21765137e-02],
                        [ -3.72619629e-02,  -3.72314453e-02],
                        [ -5.05065918e-02,  -5.06286621e-02],
                        [ -5.31921387e-02,  -5.32836914e-02],
                        [ -4.98657227e-02,  -4.97436523e-02],
                        [ -4.43115234e-02,  -4.41589355e-02],
                        [ -3.82080078e-02,  -3.83300781e-02],
                        [ -3.11889648e-02,  -3.13415527e-02],
                        [ -2.19726562e-02,  -2.19116211e-02],
                        [ -8.66699219e-03,  -8.48388672e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  3.70483398e-02,   3.68652344e-02],
                        [  6.72302246e-02,   6.71997070e-02],
                        [  9.59167480e-02,   9.60693359e-02],
                        [  1.13006592e-01,   1.13067627e-01],
                        [  1.09436035e-01,   1.09313965e-01],
                        [  8.81042480e-02,   8.79821777e-02],
                        [  6.36291504e-02,   6.36901855e-02],
                        [  4.87670898e-02,   4.88891602e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  3.65905762e-02,   3.64685059e-02],
                        [  2.27966309e-02,   2.27355957e-02],
                        [  6.25610352e-03,   6.34765625e-03],
                        [ -3.47900391e-03,  -3.38745117e-03],
                        [ -5.18798828e-03,  -5.24902344e-03],
                        [ -7.50732422e-03,  -7.59887695e-03],
                        [ -1.57165527e-02,  -1.56555176e-02],
                        [ -2.49023438e-02,  -2.48107910e-02],
                        [ -2.75573730e-02,  -2.76184082e-02],
                        [ -2.09655762e-02,  -2.10266113e-02],
                        [ -6.62231445e-03,  -6.56127930e-03],
                        [  1.07116699e-02,   1.07421875e-02],
                        [  2.39868164e-02,   2.38952637e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  2.85339355e-02,   2.86865234e-02],
                        [  3.17993164e-02,   3.17687988e-02],
                        [  4.26330566e-02,   4.23889160e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  9.30786133e-02,   9.33532715e-02],
                        [  1.35131836e-01,   1.35192871e-01],
                        [  1.67510986e-01,   1.67205811e-01],
                        [  1.65191650e-01,   1.65100098e-01],
                        [  1.23870850e-01,   1.24114990e-01],
                        [  5.66406250e-02,   5.67932129e-02],
                        [ -2.64282227e-02,  -2.65808105e-02],
                        [ -1.20635986e-01,  -1.20788574e-01],
                        [ -2.13562012e-01,  -2.13500977e-01],
                        [ -2.82012939e-01,  -2.81921387e-01],
                        [ -3.04229736e-01,  -3.04229736e-01],
                        [ -2.75238037e-01,  -2.75268555e-01],
                        [ -2.15087891e-01,  -2.15148926e-01],
                        [ -1.59057617e-01,  -1.59118652e-01],
                        [ -1.30065918e-01,  -1.30004883e-01],
                        [ -1.22772217e-01,  -1.22650146e-01],
                        [ -1.18164062e-01,  -1.18164062e-01],
                        [ -1.05133057e-01,  -1.05255127e-01],
                        [ -8.55102539e-02,  -8.55712891e-02],
                        [ -6.76269531e-02,  -6.75659180e-02],
                        [ -5.72814941e-02,  -5.71899414e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -4.32128906e-02,  -4.33044434e-02],
                        [ -3.01208496e-02,  -3.02429199e-02],
                        [ -1.59301758e-02,  -1.58691406e-02],
                        [ -2.86865234e-03,  -2.68554688e-03],
                        [  7.26318359e-03,   7.32421875e-03],
                        [  8.23974609e-03,   8.02612305e-03],
                        [ -5.37109375e-03,  -5.52368164e-03],
                        [ -2.71301270e-02,  -2.69470215e-02],
                        [ -4.19616699e-02,  -4.17175293e-02],
                        [ -4.27856445e-02,  -4.28771973e-02],
                        [ -3.76281738e-02,  -3.79028320e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -3.78417969e-02,  -3.75671387e-02],
                        [ -3.21044922e-02,  -3.20129395e-02],
                        [ -1.71508789e-02,  -1.73339844e-02],
                        [  3.75366211e-03,   3.63159180e-03],
                        [  2.99682617e-02,   3.00598145e-02],
                        [  6.29882812e-02,   6.30798340e-02],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  1.47247314e-01,   1.47186279e-01],
                        [  1.90124512e-01,   1.90124512e-01],
                        [  2.18933105e-01,   2.18933105e-01],
                        [  2.24182129e-01,   2.24182129e-01],
                        [  2.11578369e-01,   2.11608887e-01],
                        [  2.00012207e-01,   2.00042725e-01],
                        [  2.03613281e-01,   2.03552246e-01],
                        [  2.17407227e-01,   2.17376709e-01],
                        [  2.22351074e-01,   2.22412109e-01],
                        [  2.01416016e-01,   2.01446533e-01],
                        [  1.49627686e-01,   1.49597168e-01],
                        [  7.24792480e-02,   7.24487305e-02],
                        [ -1.84936523e-02,  -1.85241699e-02],
                        [ -1.06048584e-01,  -1.06048584e-01],
                        [ -1.69342041e-01,  -1.69342041e-01],
                        [ -1.93267822e-01,  -1.93237305e-01],
                        [ -1.77856445e-01,  -1.77795410e-01],
                        [ -1.40258789e-01,  -1.40319824e-01],
                        [ -1.05621338e-01,  -1.05682373e-01],
                        [ -8.64868164e-02,  -8.64562988e-02],
                        [ -7.39746094e-02,  -7.38525391e-02],
                        [ -5.43518066e-02,  -5.43823242e-02],
                        [ -2.76794434e-02,  -2.78320312e-02],
                        [ -3.93676758e-03,  -3.96728516e-03],
                        [  1.07421875e-02,   1.08947754e-02],
                        [  1.77612305e-02,   1.78222656e-02],
                        [  1.96838379e-02,   1.95312500e-02],
                        [  1.73950195e-02,   1.73034668e-02],
                        [  1.37023926e-02,   1.37939453e-02],
                        [  1.24511719e-02,   1.25427246e-02],
                        [  1.28173828e-02,   1.27563477e-02],
                        [  1.09558105e-02,   1.08947754e-02],
                        [  6.74438477e-03,   6.80541992e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -8.14819336e-03,  -8.20922852e-03],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -3.38134766e-02,  -3.37524414e-02],
                        [ -3.29895020e-02,  -3.30200195e-02],
                        [ -2.47802734e-02,  -2.48413086e-02],
                        [ -2.16064453e-02,  -2.15759277e-02],
                        [ -2.81982422e-02,  -2.81677246e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -4.23583984e-02,  -4.23889160e-02],
                        [ -4.06188965e-02,  -4.05883789e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.56958008e-02,  -2.57568359e-02],
                        [ -5.03540039e-03,  -5.00488281e-03],
                        [  3.07312012e-02,   3.07922363e-02],
                        [  7.51953125e-02,   7.51647949e-02],
                        [  1.11114502e-01,   1.11053467e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.10809326e-01,   1.10870361e-01],
                        [  8.93859863e-02,   8.94165039e-02],
                        [  7.14721680e-02,   7.14111328e-02],
                        [  5.76477051e-02,   5.75866699e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  1.76086426e-02,   1.77001953e-02],
                        [ -4.27246094e-03,  -4.24194336e-03],
                        [ -1.63269043e-02,  -1.63879395e-02],
                        [ -1.62353516e-02,  -1.63269043e-02],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [  1.52587891e-03,   1.67846680e-03],
                        [  4.60815430e-03,   4.63867188e-03],
                        [ -2.28881836e-03,  -2.47192383e-03],
                        [ -1.41906738e-02,  -1.42517090e-02],
                        [ -1.91345215e-02,  -1.89514160e-02],
                        [ -1.00708008e-02,  -9.91821289e-03],
                        [  5.67626953e-03,   5.52368164e-03],
                        [  1.65710449e-02,   1.64184570e-02],
                        [  2.41394043e-02,   2.42614746e-02],
                        [  3.83300781e-02,   3.85131836e-02],
                        [  5.95703125e-02,   5.95092773e-02],
                        [  7.89184570e-02,   7.87353516e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.10504150e-01,   1.10656738e-01],
                        [  1.31195068e-01,   1.31286621e-01],
                        [  1.45141602e-01,   1.45050049e-01],
                        [  1.34613037e-01,   1.34429932e-01],
                        [  8.88366699e-02,   8.88061523e-02],
                        [  1.41601562e-02,   1.43737793e-02],
                        [ -7.28759766e-02,  -7.27844238e-02],
                        [ -1.61712646e-01,  -1.61956787e-01],
                        [ -2.44628906e-01,  -2.44842529e-01],
                        [ -3.00872803e-01,  -3.00659180e-01],
                        [ -3.04748535e-01,  -3.04382324e-01],
                        [ -2.58209229e-01,  -2.58331299e-01],
                        [ -1.98394775e-01,  -1.98760986e-01],
                        [ -1.60156250e-01,  -1.60125732e-01],
                        [ -1.42822266e-01,  -1.42425537e-01],
                        [ -1.25793457e-01,  -1.25701904e-01],
                        [ -1.01806641e-01,  -1.02142334e-01],
                        [ -7.87353516e-02,  -7.89184570e-02],
                        [ -6.13098145e-02,  -6.11267090e-02],
                        [ -4.88586426e-02,  -4.87365723e-02],
                        [ -4.21447754e-02,  -4.23278809e-02],
                        [ -4.01000977e-02,  -4.03137207e-02],
                        [ -3.51257324e-02,  -3.50952148e-02],
                        [ -2.17590332e-02,  -2.16064453e-02],
                        [ -6.89697266e-03,  -6.83593750e-03],
                        [ -2.99072266e-03,  -2.96020508e-03],
                        [ -1.18713379e-02,  -1.18103027e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.86865234e-02,  -2.87170410e-02],
                        [ -2.67944336e-02,  -2.67333984e-02],
                        [ -2.13317871e-02,  -2.12097168e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.52380371e-02,  -2.53601074e-02],
                        [ -4.20227051e-02,  -4.20837402e-02],
                        [ -5.61828613e-02,  -5.61523438e-02],
                        [ -5.19104004e-02,  -5.19409180e-02],
                        [ -2.52075195e-02,  -2.53601074e-02],
                        [  1.56555176e-02,   1.54113770e-02],
                        [  6.15234375e-02,   6.13708496e-02],
                        [  1.09893799e-01,   1.09924316e-01],
                        [  1.60186768e-01,   1.60400391e-01],
                        [  2.03918457e-01,   2.04040527e-01],
                        [  2.24609375e-01,   2.24578857e-01],
                        [  2.14813232e-01,   2.14935303e-01],
                        [  1.89086914e-01,   1.89453125e-01],
                        [  1.71142578e-01,   1.71447754e-01],
                        [  1.70745850e-01,   1.70745850e-01],
                        [  1.79473877e-01,   1.79412842e-01],
                        [  1.86035156e-01,   1.86187744e-01],
                        [  1.85546875e-01,   1.85791016e-01],
                        [  1.74163818e-01,   1.74163818e-01],
                        [  1.43432617e-01,   1.43127441e-01],
                        [  8.40148926e-02,   8.35876465e-02],
                        [ -3.66210938e-03,  -3.90625000e-03],
                        [ -1.00555420e-01,  -1.00646973e-01],
                        [ -1.75994873e-01,  -1.76116943e-01],
                        [ -2.07824707e-01,  -2.08007812e-01],
                        [ -1.94793701e-01,  -1.94885254e-01],
                        [ -1.52923584e-01,  -1.52893066e-01],
                        [ -1.04858398e-01,  -1.04797363e-01],
                        [ -6.74133301e-02,  -6.73828125e-02],
                        [ -4.37927246e-02,  -4.36706543e-02],
                        [ -2.72216797e-02,  -2.69470215e-02],
                        [ -1.31530762e-02,  -1.27868652e-02],
                        [ -5.18798828e-03,  -4.88281250e-03],
                        [ -8.20922852e-03,  -7.96508789e-03],
                        [ -1.81579590e-02,  -1.79748535e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.93786621e-02,  -1.96228027e-02],
                        [ -6.71386719e-03,  -7.04956055e-03],
                        [  8.57543945e-03,   8.27026367e-03],
                        [  2.15759277e-02,   2.11486816e-02],
                        [  2.46276855e-02,   2.40173340e-02],
                        [  1.19628906e-02,   1.14746094e-02],
                        [ -9.00268555e-03,  -9.06372070e-03],
                        [ -2.23999023e-02,  -2.23083496e-02],
                        [ -2.41699219e-02,  -2.42614746e-02],
                        [ -2.45361328e-02,  -2.45666504e-02],
                        [ -2.93579102e-02,  -2.90527344e-02],
                        [ -3.27148438e-02,  -3.21044922e-02],
                        [ -2.84423828e-02,  -2.78625488e-02],
                        [ -1.97143555e-02,  -1.92260742e-02],
                        [ -1.44653320e-02,  -1.38854980e-02],
                        [ -1.63269043e-02,  -1.57470703e-02],
                        [ -2.39562988e-02,  -2.36816406e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.71093750e-02,  -3.71398926e-02],
                        [ -2.08129883e-02,  -2.08435059e-02],
                        [  2.07824707e-02,   2.05688477e-02],
                        [  7.44628906e-02,   7.40356445e-02],
                        [  1.15631104e-01,   1.15173340e-01],
                        [  1.26922607e-01,   1.26556396e-01],
                        [  1.09558105e-01,   1.09191895e-01],
                        [  8.02612305e-02,   7.98034668e-02],
                        [  5.74645996e-02,   5.70373535e-02],
                        [  4.68444824e-02,   4.65393066e-02],
                        [  3.95202637e-02,   3.93371582e-02],
                        [  2.61230469e-02,   2.59094238e-02],
                        [  8.05664062e-03,   7.75146484e-03],
                        [ -6.07299805e-03,  -6.22558594e-03],
                        [ -1.01928711e-02,  -9.88769531e-03],
                        [ -6.01196289e-03,  -5.46264648e-03],
                        [ -1.86157227e-03,  -1.40380859e-03],
                        [ -3.29589844e-03,  -2.80761719e-03],
                        [ -4.11987305e-03,  -3.38745117e-03],
                        [  6.07299805e-03,   6.68334961e-03],
                        [  2.36511230e-02,   2.36816406e-02],
                        [  3.20739746e-02,   3.17687988e-02],
                        [  2.62145996e-02,   2.61535645e-02],
                        [  2.05383301e-02,   2.05688477e-02],
                        [  2.60314941e-02,   2.57568359e-02],
                        [  3.78723145e-02,   3.75061035e-02],
                        [  5.20019531e-02,   5.19714355e-02],
                        [  7.36389160e-02,   7.36694336e-02],
                        [  1.04064941e-01,   1.03820801e-01],
                        [  1.34338379e-01,   1.34124756e-01],
                        [  1.53137207e-01,   1.53137207e-01],
                        [  1.48834229e-01,   1.48773193e-01],
                        [  1.08673096e-01,   1.08459473e-01],
                        [  2.91137695e-02,   2.92053223e-02],
                        [ -7.46154785e-02,  -7.41882324e-02],
                        [ -1.79016113e-01,  -1.78863525e-01],
                        [ -2.64404297e-01,  -2.64495850e-01],
                        [ -3.09936523e-01,  -3.09753418e-01],
                        [ -2.98980713e-01,  -2.98645020e-01],
                        [ -2.44415283e-01,  -2.44445801e-01],
                        [ -1.87225342e-01,  -1.87469482e-01],
                        [ -1.55456543e-01,  -1.55151367e-01],
                        [ -1.39282227e-01,  -1.38549805e-01],
                        [ -1.15997314e-01,  -1.15844727e-01],
                        [ -8.50524902e-02,  -8.57849121e-02],
                        [ -6.45141602e-02,  -6.53076172e-02],
                        [ -6.10961914e-02,  -6.13708496e-02],
                        [ -6.21032715e-02,  -6.22253418e-02],
                        [ -5.55114746e-02,  -5.57250977e-02],
                        [ -4.08020020e-02,  -4.08630371e-02],
                        [ -2.16369629e-02,  -2.15454102e-02],
                        [ -3.63159180e-03,  -3.87573242e-03],
                        [  4.51660156e-03,   3.90625000e-03],
                        [  3.05175781e-04,  -6.10351562e-05],
                        [ -9.00268555e-03,  -8.69750977e-03],
                        [ -1.77307129e-02,  -1.69067383e-02],
                        [ -2.74047852e-02,  -2.63671875e-02],
                        [ -3.90014648e-02,  -3.80249023e-02],
                        [ -5.02624512e-02,  -4.95605469e-02],
                        [ -5.85327148e-02,  -5.84106445e-02],
                        [ -6.07299805e-02,  -6.12487793e-02],
                        [ -5.46875000e-02,  -5.56335449e-02],
                        [ -4.06494141e-02,  -4.16870117e-02],
                        [ -1.84020996e-02,  -1.92871094e-02],
                        [  1.31530762e-02,   1.23596191e-02],
                        [  5.13916016e-02,   5.07812500e-02],
                        [  9.28039551e-02,   9.27429199e-02],
                        [  1.36779785e-01,   1.37237549e-01],
                        [  1.77978516e-01,   1.78497314e-01],
                        [  2.01293945e-01,   2.01629639e-01],
                        [  1.96289062e-01,   1.96746826e-01],
                        [  1.73095703e-01,   1.73919678e-01],
                        [  1.53167725e-01,   1.54357910e-01],
                        [  1.47003174e-01,   1.48376465e-01],
                        [  1.49139404e-01,   1.50390625e-01],
                        [  1.49841309e-01,   1.50421143e-01],
                        [  1.45935059e-01,   1.45629883e-01],
                        [  1.43707275e-01,   1.42761230e-01],
                        [  1.48864746e-01,   1.47613525e-01],
                        [  1.52618408e-01,   1.51184082e-01],
                        [  1.35070801e-01,   1.33819580e-01],
                        [  8.35876465e-02,   8.29162598e-02],
                        [  2.19726562e-03,   1.98364258e-03],
                        [ -9.13696289e-02,  -9.15222168e-02],
                        [ -1.69769287e-01,  -1.69952393e-01],
                        [ -2.04437256e-01,  -2.04376221e-01],
                        [ -1.83166504e-01,  -1.82891846e-01],
                        [ -1.26098633e-01,  -1.25823975e-01],
                        [ -7.41882324e-02,  -7.37609863e-02],
                        [ -5.16357422e-02,  -5.07202148e-02],
                        [ -4.78515625e-02,  -4.66308594e-02],
                        [ -4.38842773e-02,  -4.30297852e-02],
                        [ -4.04052734e-02,  -4.00390625e-02],
                        [ -4.70886230e-02,  -4.68139648e-02],
                        [ -5.91430664e-02,  -5.88684082e-02],
                        [ -6.04553223e-02,  -6.05773926e-02],
                        [ -4.37316895e-02,  -4.43420410e-02],
                        [ -1.61437988e-02,  -1.70898438e-02],
                        [  1.01928711e-02,   9.00268555e-03],
                        [  2.69470215e-02,   2.51770020e-02],
                        [  3.14025879e-02,   2.89611816e-02],
                        [  2.50854492e-02,   2.27050781e-02],
                        [  1.17797852e-02,   1.04064941e-02],
                        [ -3.96728516e-03,  -3.87573242e-03],
                        [ -1.77612305e-02,  -1.65405273e-02],
                        [ -2.73437500e-02,  -2.55126953e-02],
                        [ -3.23791504e-02,  -3.00292969e-02],
                        [ -3.14636230e-02,  -2.85034180e-02],
                        [ -2.23388672e-02,  -1.93176270e-02],
                        [ -8.36181641e-03,  -6.01196289e-03],
                        [ -2.74658203e-04,   1.12915039e-03],
                        [ -6.40869141e-03,  -5.67626953e-03],
                        [ -2.31933594e-02,  -2.30102539e-02],
                        [ -3.98254395e-02,  -4.03747559e-02],
                        [ -4.71801758e-02,  -4.84008789e-02],
                        [ -3.74145508e-02,  -3.90930176e-02],
                        [ -4.30297852e-03,  -6.37817383e-03],
                        [  4.69360352e-02,   4.43115234e-02],
                        [  9.42077637e-02,   9.13391113e-02],
                        [  1.13952637e-01,   1.11663818e-01],
                        [  1.02294922e-01,   1.01348877e-01],
                        [  7.49816895e-02,   7.53173828e-02],
                        [  4.83703613e-02,   4.95605469e-02],
                        [  2.89611816e-02,   3.04565430e-02],
                        [  1.82189941e-02,   1.95922852e-02],
                        [  1.73034668e-02,   1.81579590e-02],
                        [  2.40478516e-02,   2.44445801e-02],
                        [  3.13110352e-02,   3.16772461e-02],
                        [  3.37219238e-02,   3.42712402e-02],
                        [  3.23181152e-02,   3.27148438e-02],
                        [  2.79541016e-02,   2.78320312e-02],
                        [  1.78527832e-02,   1.74560547e-02],
                        [  4.36401367e-03,   4.15039062e-03],
                        [ -4.51660156e-03,  -4.57763672e-03],
                        [ -6.10351562e-03,  -6.25610352e-03],
                        [ -2.89916992e-03,  -3.20434570e-03],
                        [  6.34765625e-03,   5.85937500e-03],
                        [  2.39562988e-02,   2.31933594e-02],
                        [  4.57763672e-02,   4.50744629e-02],
                        [  6.67724609e-02,   6.67419434e-02],
                        [  8.84704590e-02,   8.92333984e-02],
                        [  1.12243652e-01,   1.13067627e-01],
                        [  1.30615234e-01,   1.31042480e-01],
                        [  1.36230469e-01,   1.36413574e-01],
                        [  1.30645752e-01,   1.30859375e-01],
                        [  1.12792969e-01,   1.13128662e-01],
                        [  6.86950684e-02,   6.94885254e-02],
                        [ -1.29089355e-02,  -1.13830566e-02],
                        [ -1.20666504e-01,  -1.18988037e-01],
                        [ -2.24822998e-01,  -2.24090576e-01],
                        [ -2.94738770e-01,  -2.95227051e-01],
                        [ -3.10546875e-01,  -3.11614990e-01],
                        [ -2.71759033e-01,  -2.72949219e-01],
                        [ -2.03918457e-01,  -2.05322266e-01],
                        [ -1.45019531e-01,  -1.46606445e-01],
                        [ -1.15356445e-01,  -1.16638184e-01],
                        [ -1.05499268e-01,  -1.06018066e-01],
                        [ -9.61303711e-02,  -9.59167480e-02],
                        [ -8.14514160e-02,  -8.08715820e-02],
                        [ -6.98242188e-02,  -6.91223145e-02],
                        [ -6.74438477e-02,  -6.67724609e-02],
                        [ -6.76879883e-02,  -6.72912598e-02],
                        [ -5.85632324e-02,  -5.87158203e-02],
                        [ -3.79333496e-02,  -3.87268066e-02],
                        [ -1.58996582e-02,  -1.68762207e-02],
                        [ -1.12915039e-03,  -1.77001953e-03],
                        [  7.32421875e-03,   7.08007812e-03],
                        [  1.17797852e-02,   1.16577148e-02],
                        [  8.60595703e-03,   8.66699219e-03],
                        [ -4.88281250e-03,  -4.39453125e-03],
                        [ -2.43530273e-02,  -2.34069824e-02],
                        [ -4.32739258e-02,  -4.20227051e-02],
                        [ -5.88378906e-02,  -5.74951172e-02],
                        [ -7.13195801e-02,  -7.00988770e-02],
                        [ -7.98950195e-02,  -7.89489746e-02],
                        [ -7.83691406e-02,  -7.78198242e-02],
                        [ -5.78613281e-02,  -5.78002930e-02],
                        [ -1.47705078e-02,  -1.54418945e-02],
                        [  4.53491211e-02,   4.38537598e-02],
                        [  1.11358643e-01,   1.09436035e-01],
                        [  1.71264648e-01,   1.69586182e-01],
                        [  2.13470459e-01,   2.12371826e-01],
                        [  2.27752686e-01,   2.27142334e-01],
                        [  2.11853027e-01,   2.11364746e-01],
                        [  1.76544189e-01,   1.76147461e-01],
                        [  1.39892578e-01,   1.39739990e-01],
                        [  1.14746094e-01,   1.15081787e-01],
                        [  1.03240967e-01,   1.04492188e-01],
                        [  1.01928711e-01,   1.04309082e-01],
                        [  1.08398438e-01,   1.11419678e-01],
                        [  1.20300293e-01,   1.22924805e-01],
                        [  1.32446289e-01,   1.33850098e-01],
                        [  1.41601562e-01,   1.41723633e-01],
                        [  1.49108887e-01,   1.48284912e-01],
                        [  1.50177002e-01,   1.48834229e-01],
                        [  1.26708984e-01,   1.25427246e-01],
                        [  6.17065430e-02,   6.10656738e-02],
                        [ -3.83605957e-02,  -3.81774902e-02],
                        [ -1.39099121e-01,  -1.38519287e-01],
                        [ -1.99584961e-01,  -1.99279785e-01],
                        [ -2.00866699e-01,  -2.01446533e-01],
                        [ -1.57531738e-01,  -1.59332275e-01],
                        [ -1.03759766e-01,  -1.07025146e-01],
                        [ -6.86645508e-02,  -7.31201172e-02],
                        [ -5.97229004e-02,  -6.40869141e-02],
                        [ -6.33850098e-02,  -6.57958984e-02],
                        [ -5.98754883e-02,  -5.91735840e-02],
                        [ -4.27246094e-02,  -3.93676758e-02],
                        [ -2.55432129e-02,  -2.11486816e-02],
                        [ -2.39868164e-02,  -2.01110840e-02],
                        [ -3.47290039e-02,  -3.22875977e-02],
                        [ -4.13818359e-02,  -4.04663086e-02],
                        [ -3.49731445e-02,  -3.48510742e-02],
                        [ -1.91040039e-02,  -1.88903809e-02],
                        [ -1.28173828e-03,  -7.32421875e-04],
                        [  1.15051270e-02,   1.19018555e-02],
                        [  1.40686035e-02,   1.39160156e-02],
                        [  6.46972656e-03,   5.76782227e-03],
                        [ -5.67626953e-03,  -6.74438477e-03],
                        [ -1.61132812e-02,  -1.72729492e-02],
                        [ -2.10571289e-02,  -2.20031738e-02],
                        [ -1.96228027e-02,  -2.02331543e-02],
                        [ -1.53198242e-02,  -1.56555176e-02],
                        [ -1.42822266e-02,  -1.42517090e-02],
                        [ -1.96228027e-02,  -1.88293457e-02],
                        [ -2.95715332e-02,  -2.78015137e-02],
                        [ -4.03137207e-02,  -3.81164551e-02],
                        [ -4.82177734e-02,  -4.64477539e-02],
                        [ -4.82788086e-02,  -4.75158691e-02],
                        [ -3.34167480e-02,  -3.38439941e-02],
                        [  0.00000000e+00,  -1.37329102e-03],
                        [  4.49523926e-02,   4.31518555e-02],
                        [  8.55407715e-02,   8.40148926e-02],
                        [  1.07269287e-01,   1.06231689e-01],
                        [  1.05010986e-01,   1.04217529e-01],
                        [  8.52050781e-02,   8.45031738e-02],
                        [  6.12792969e-02,   6.07604980e-02],
                        [  4.33349609e-02,   4.30297852e-02],
                        [  3.19824219e-02,   3.17077637e-02],
                        [  2.38342285e-02,   2.33764648e-02],
                        [  1.86157227e-02,   1.77917480e-02],
                        [  1.69372559e-02,   1.57165527e-02],
                        [  1.66320801e-02,   1.53808594e-02],
                        [  1.72119141e-02,   1.66931152e-02],
                        [  2.17285156e-02,   2.23083496e-02],
                        [  2.78320312e-02,   2.93579102e-02],
                        [  2.63977051e-02,   2.85339355e-02],
                        [  1.43432617e-02,   1.67846680e-02],
                        [  1.19018555e-03,   3.57055664e-03],
                        [ -6.10351562e-04,   9.46044922e-04],
                        [  1.19018555e-02,   1.22375488e-02],
                        [  3.25622559e-02,   3.19519043e-02],
                        [  5.67932129e-02,   5.57556152e-02],
                        [  8.48999023e-02,   8.35266113e-02],
                        [  1.11877441e-01,   1.10076904e-01],
                        [  1.27288818e-01,   1.25335693e-01],
                        [  1.30096436e-01,   1.28326416e-01],
                        [  1.28662109e-01,   1.27349854e-01],
                        [  1.21124268e-01,   1.20941162e-01],
                        [  9.03625488e-02,   9.21936035e-02],
                        [  2.35290527e-02,   2.77099609e-02],
                        [ -7.25708008e-02,  -6.69555664e-02],
                        [ -1.76116943e-01,  -1.70654297e-01],
                        [ -2.60040283e-01,  -2.56134033e-01],
                        [ -2.98736572e-01,  -2.97210693e-01],
                        [ -2.80731201e-01,  -2.81494141e-01],
                        [ -2.22656250e-01,  -2.24792480e-01],
                        [ -1.61956787e-01,  -1.64489746e-01],
                        [ -1.26617432e-01,  -1.29333496e-01],
                        [ -1.14471436e-01,  -1.17828369e-01],
                        [ -1.05438232e-01,  -1.09924316e-01],
                        [ -8.85314941e-02,  -9.39941406e-02],
                        [ -6.87561035e-02,  -7.45239258e-02],
                        [ -5.38635254e-02,  -5.89599609e-02],
                        [ -4.51354980e-02,  -4.87365723e-02],
                        [ -4.02221680e-02,  -4.19311523e-02],
                        [ -3.64990234e-02,  -3.64074707e-02],
                        [ -3.12500000e-02,  -2.96325684e-02],
                        [ -2.42004395e-02,  -2.12707520e-02],
                        [ -1.84020996e-02,  -1.42211914e-02],
                        [ -1.48315430e-02,  -9.61303711e-03],
                        [ -1.14440918e-02,  -5.70678711e-03],
                        [ -1.07116699e-02,  -5.12695312e-03],
                        [ -1.96533203e-02,  -1.44348145e-02],
                        [ -3.81164551e-02,  -3.31115723e-02],
                        [ -5.67932129e-02,  -5.23986816e-02],
                        [ -6.93054199e-02,  -6.66198730e-02],
                        [ -7.62634277e-02,  -7.64465332e-02],
                        [ -7.51342773e-02,  -7.85522461e-02],
                        [ -5.63354492e-02,  -6.23779297e-02],
                        [ -1.48620605e-02,  -2.19726562e-02],
                        [  4.12292480e-02,   3.50952148e-02],
                        [  1.00860596e-01,   9.68627930e-02],
                        [  1.58447266e-01,   1.55944824e-01],
                        [  2.05169678e-01,   2.02636719e-01],
                        [  2.25708008e-01,   2.22534180e-01],
                        [  2.14019775e-01,   2.10998535e-01],
                        [  1.81640625e-01,   1.80236816e-01],
                        [  1.45263672e-01,   1.47003174e-01],
                        [  1.15264893e-01,   1.20849609e-01],
                        [  9.66491699e-02,   1.05285645e-01],
                        [  9.10339355e-02,   1.00372314e-01],
                        [  9.56726074e-02,   1.03149414e-01],
                        [  1.05987549e-01,   1.10229492e-01],
                        [  1.20056152e-01,   1.20941162e-01],
                        [  1.36199951e-01,   1.34185791e-01],
                        [  1.48986816e-01,   1.45080566e-01],
                        [  1.53045654e-01,   1.48437500e-01],
                        [  1.44836426e-01,   1.40655518e-01],
                        [  1.16943359e-01,   1.13677979e-01],
                        [  5.87463379e-02,   5.64575195e-02],
                        [ -2.88696289e-02,  -3.07312012e-02],
                        [ -1.23046875e-01,  -1.25518799e-01],
                        [ -1.89331055e-01,  -1.93145752e-01],
                        [ -2.05871582e-01,  -2.10540771e-01],
                        [ -1.76971436e-01,  -1.81030273e-01],
                        [ -1.25885010e-01,  -1.28082275e-01],
                        [ -7.92846680e-02,  -7.91931152e-02],
                        [ -5.45959473e-02,  -5.24597168e-02],
                        [ -5.22766113e-02,  -4.87670898e-02],
                        [ -5.80749512e-02,  -5.39550781e-02],
                        [ -5.67016602e-02,  -5.24902344e-02],
                        [ -4.53796387e-02,  -4.11987305e-02],
                        [ -3.35998535e-02,  -2.92968750e-02],
                        [ -3.02734375e-02,  -2.57873535e-02],
                        [ -3.27453613e-02,  -2.84423828e-02],
                        [ -3.10363770e-02,  -2.76794434e-02],
                        [ -2.13012695e-02,  -1.95617676e-02],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -1.03759766e-03,  -2.53295898e-03],
                        [  2.71606445e-03,  -3.05175781e-05],
                        [  8.54492188e-04,  -2.71606445e-03],
                        [ -6.10351562e-03,  -9.79614258e-03],
                        [ -1.10778809e-02,  -1.44958496e-02],
                        [ -8.30078125e-03,  -1.19323730e-02],
                        [ -4.30297852e-03,  -8.63647461e-03],
                        [ -1.12304688e-02,  -1.56250000e-02],
                        [ -3.04260254e-02,  -3.33862305e-02],
                        [ -4.97131348e-02,  -4.98962402e-02],
                        [ -5.85937500e-02,  -5.52978516e-02],
                        [ -5.88378906e-02,  -5.23986816e-02],
                        [ -5.52062988e-02,  -4.73327637e-02],
                        [ -4.35791016e-02,  -3.72619629e-02],
                        [ -1.69067383e-02,  -1.46179199e-02],
                        [  2.42004395e-02,   2.21252441e-02],
                        [  7.00988770e-02,   6.53381348e-02],
                        [  1.05224609e-01,   1.00128174e-01],
                        [  1.15386963e-01,   1.11755371e-01],
                        [  1.00646973e-01,   9.89990234e-02],
                        [  7.83996582e-02,   7.80639648e-02],
                        [  6.66198730e-02,   6.64672852e-02],
                        [  6.62231445e-02,   6.54602051e-02],
                        [  6.52770996e-02,   6.38732910e-02],
                        [  5.61523438e-02,   5.44433594e-02],
                        [  4.03137207e-02,   3.88488770e-02],
                        [  2.20336914e-02,   2.16979980e-02],
                        [  5.76782227e-03,   7.38525391e-03],
                        [ -3.72314453e-03,   1.52587891e-04],
                        [ -4.88281250e-03,   3.66210938e-04],
                        [ -1.19018555e-03,   3.69262695e-03],
                        [  2.68554688e-03,   5.37109375e-03],
                        [  4.54711914e-03,   4.05883789e-03],
                        [  4.88281250e-03,   1.83105469e-03],
                        [  6.71386719e-03,   3.41796875e-03],
                        [  1.63879395e-02,   1.53198242e-02],
                        [  4.08935547e-02,   4.28161621e-02],
                        [  7.93457031e-02,   8.26416016e-02],
                        [  1.19415283e-01,   1.21276855e-01],
                        [  1.47735596e-01,   1.46209717e-01],
                        [  1.61346436e-01,   1.56524658e-01],
                        [  1.61682129e-01,   1.55548096e-01],
                        [  1.42089844e-01,   1.37512207e-01],
                        [  9.34143066e-02,   9.26208496e-02],
                        [  1.78833008e-02,   2.13317871e-02],
                        [ -7.36694336e-02,  -6.72302246e-02],
                        [ -1.70898438e-01,  -1.63208008e-01],
                        [ -2.58544922e-01,  -2.50885010e-01],
                        [ -3.09509277e-01,  -3.02795410e-01],
                        [ -2.99804688e-01,  -2.95318604e-01],
                        [ -2.35870361e-01,  -2.34893799e-01],
                        [ -1.58081055e-01,  -1.61010742e-01],
                        [ -1.07421875e-01,  -1.13433838e-01],
                        [ -9.12780762e-02,  -9.91821289e-02],
                        [ -9.00878906e-02,  -9.89990234e-02],
                        [ -8.87145996e-02,  -9.81750488e-02],
                        [ -8.76464844e-02,  -9.74426270e-02],
                        [ -8.88061523e-02,  -9.86022949e-02],
                        [ -8.65173340e-02,  -9.51843262e-02],
                        [ -7.45849609e-02,  -8.00781250e-02],
                        [ -5.45654297e-02,  -5.47180176e-02],
                        [ -3.30200195e-02,  -2.71606445e-02],
                        [ -1.43432617e-02,  -3.72314453e-03],
                        [  1.83105469e-04,   1.31225586e-02],
                        [  7.32421875e-03,   2.05688477e-02],
                        [  2.86865234e-03,   1.54418945e-02],
                        [ -1.12609863e-02,   1.22070312e-04],
                        [ -2.78930664e-02,  -1.84326172e-02],
                        [ -4.48608398e-02,  -3.85742188e-02],
                        [ -6.48498535e-02,  -6.31713867e-02],
                        [ -8.32214355e-02,  -8.70361328e-02],
                        [ -8.80432129e-02,  -9.70764160e-02],
                        [ -7.31506348e-02,  -8.56628418e-02],
                        [ -4.08935547e-02,  -5.43212891e-02],
                        [  5.00488281e-03,  -7.01904297e-03],
                        [  6.06079102e-02,   5.13610840e-02],
                        [  1.17950439e-01,   1.11785889e-01],
                        [  1.66503906e-01,   1.63055420e-01],
                        [  1.96594238e-01,   1.95434570e-01],
                        [  2.02117920e-01,   2.03155518e-01],
                        [  1.85638428e-01,   1.89147949e-01],
                        [  1.59576416e-01,   1.65954590e-01],
                        [  1.35955811e-01,   1.45416260e-01],
                        [  1.17370605e-01,   1.29547119e-01],
                        [  1.01867676e-01,   1.15539551e-01],
                        [  9.04846191e-02,   1.03393555e-01],
                        [  8.57543945e-02,   9.52453613e-02],
                        [  8.93859863e-02,   9.34448242e-02],
                        [  1.00952148e-01,   9.90600586e-02],
                        [  1.14288330e-01,   1.07513428e-01],
                        [  1.20513916e-01,   1.10565186e-01],
                        [  1.19018555e-01,   1.07147217e-01],
                        [  1.17767334e-01,   1.04370117e-01],
                        [  1.17736816e-01,   1.03302002e-01],
                        [  1.05072021e-01,   9.10644531e-02],
                        [  6.46057129e-02,   5.33142090e-02],
                        [ -2.86865234e-03,  -9.12475586e-03],
                        [ -8.12683105e-02,  -8.12377930e-02],
                        [ -1.50634766e-01,  -1.44805908e-01],
                        [ -1.92565918e-01,  -1.82891846e-01],
                        [ -1.94732666e-01,  -1.83624268e-01],
                        [ -1.61560059e-01,  -1.50695801e-01],
                        [ -1.16607666e-01,  -1.06262207e-01],
                        [ -8.34350586e-02,  -7.33642578e-02],
                        [ -6.61621094e-02,  -5.69458008e-02],
                        [ -5.49011230e-02,  -4.80651855e-02],
                        [ -4.32128906e-02,  -4.01611328e-02],
                        [ -3.24707031e-02,  -3.36303711e-02],
                        [ -2.59094238e-02,  -3.07922363e-02],
                        [ -2.56042480e-02,  -3.32641602e-02],
                        [ -3.16162109e-02,  -4.08325195e-02],
                        [ -3.95812988e-02,  -4.87365723e-02],
                        [ -4.10766602e-02,  -4.84313965e-02],
                        [ -3.12500000e-02,  -3.50952148e-02],
                        [ -1.52893066e-02,  -1.44958496e-02],
                        [ -3.11279297e-03,   2.10571289e-03],
                        [  1.95312500e-03,   9.36889648e-03],
                        [  3.35693359e-03,   9.36889648e-03],
                        [  2.44140625e-03,   4.27246094e-03],
                        [ -4.15039062e-03,  -6.59179688e-03],
                        [ -1.87683105e-02,  -2.27966309e-02],
                        [ -3.73840332e-02,  -3.96423340e-02],
                        [ -5.16052246e-02,  -5.02624512e-02],
                        [ -5.74035645e-02,  -5.34057617e-02],
                        [ -5.96313477e-02,  -5.58166504e-02],
                        [ -6.29272461e-02,  -6.21948242e-02],
                        [ -6.28967285e-02,  -6.63452148e-02],
                        [ -4.98657227e-02,  -5.62133789e-02],
                        [ -1.73034668e-02,  -2.39257812e-02],
                        [  3.33862305e-02,   2.86254883e-02],
                        [  8.89892578e-02,   8.68835449e-02],
                        [  1.27410889e-01,   1.27685547e-01],
                        [  1.33697510e-01,   1.35528564e-01],
                        [  1.13250732e-01,   1.15661621e-01],
                        [  8.42285156e-02,   8.61511230e-02],
                        [  5.99365234e-02,   6.08520508e-02],
                        [  4.28466797e-02,   4.29992676e-02],
                        [  3.04565430e-02,   3.09143066e-02],
                        [  2.26135254e-02,   2.48107910e-02],
                        [  2.19421387e-02,   2.68859863e-02],
                        [  2.83508301e-02,   3.53088379e-02],
                        [  3.55834961e-02,   4.19616699e-02],
                        [  3.53393555e-02,   3.79333496e-02],
                        [  2.51159668e-02,   2.19726562e-02],
                        [  1.22680664e-02,   3.87573242e-03],
                        [  7.08007812e-03,  -3.75366211e-03],
                        [  1.08642578e-02,   1.49536133e-03],
                        [  1.75170898e-02,   1.27868652e-02],
                        [  2.64892578e-02,   2.71606445e-02],
                        [  4.40368652e-02,   4.84313965e-02],
                        [  7.12585449e-02,   7.71179199e-02],
                        [  1.01928711e-01,   1.07788086e-01],
                        [  1.30767822e-01,   1.36291504e-01],
                        [  1.53961182e-01,   1.59179688e-01],
                        [  1.62322998e-01,   1.67388916e-01],
                        [  1.45233154e-01,   1.50177002e-01],
                        [  1.00524902e-01,   1.04736328e-01],
                        [  3.17382812e-02,   3.41796875e-02],
                        [ -5.85632324e-02,  -5.86853027e-02],
                        [ -1.61499023e-01,  -1.64276123e-01],
                        [ -2.52563477e-01,  -2.57446289e-01],
                        [ -2.99774170e-01,  -3.05999756e-01],
                        [ -2.85705566e-01,  -2.92510986e-01],
                        [ -2.24182129e-01,  -2.30895996e-01],
                        [ -1.54846191e-01,  -1.61224365e-01],
                        [ -1.12396240e-01,  -1.18652344e-01],
                        [ -9.89990234e-02,  -1.05194092e-01],
                        [ -9.25903320e-02,  -9.81445312e-02],
                        [ -8.02001953e-02,  -8.37097168e-02],
                        [ -7.00378418e-02,  -7.00988770e-02],
                        [ -7.14721680e-02,  -6.77185059e-02],
                        [ -7.85827637e-02,  -7.21740723e-02],
                        [ -7.87048340e-02,  -7.16247559e-02],
                        [ -6.57043457e-02,  -5.97229004e-02],
                        [ -4.17175293e-02,  -3.74755859e-02],
                        [ -1.39770508e-02,  -1.08337402e-02],
                        [  7.26318359e-03,   1.07727051e-02],
                        [  1.33666992e-02,   1.84936523e-02],
                        [  2.41088867e-03,   9.30786133e-03],
                        [ -2.04467773e-02,  -1.28784180e-02],
                        [ -4.55017090e-02,  -3.90319824e-02],
                        [ -6.25610352e-02,  -5.91735840e-02],
                        [ -6.72607422e-02,  -6.87255859e-02],
                        [ -6.35681152e-02,  -7.08923340e-02],
                        [ -5.68237305e-02,  -6.94274902e-02],
                        [ -4.57153320e-02,  -6.11877441e-02],
                        [ -2.34069824e-02,  -3.79943848e-02],
                        [  1.55944824e-02,   5.64575195e-03],
                        [  7.01904297e-02,   6.70166016e-02],
                        [  1.31072998e-01,   1.33819580e-01],
                        [  1.82708740e-01,   1.88262939e-01],
                        [  2.09381104e-01,   2.14630127e-01],
                        [  2.02972412e-01,   2.07153320e-01],
                        [  1.70379639e-01,   1.75048828e-01],
                        [  1.32019043e-01,   1.39373779e-01],
                        [  1.08337402e-01,   1.19110107e-01],
                        [  1.04675293e-01,   1.17309570e-01],
                        [  1.09954834e-01,   1.21063232e-01],
                        [  1.08673096e-01,   1.14898682e-01],
                        [  9.54895020e-02,   9.55810547e-02],
                        [  7.87048340e-02,   7.37915039e-02],
                        [  6.92443848e-02,   6.13708496e-02],
                        [  6.88781738e-02,   5.96008301e-02],
                        [  7.11364746e-02,   6.11267090e-02],
                        [  7.15942383e-02,   6.11267090e-02],
                        [  7.38220215e-02,   6.33239746e-02],
                        [  8.46862793e-02,   7.48596191e-02],
                        [  1.04431152e-01,   9.62524414e-02],
                        [  1.19842529e-01,   1.14074707e-01],
                        [  1.09222412e-01,   1.06231689e-01],
                        [  5.94177246e-02,   5.93872070e-02],
                        [ -2.23999023e-02,  -1.91040039e-02],
                        [ -1.12854004e-01,  -1.05957031e-01],
                        [ -1.82952881e-01,  -1.72973633e-01],
                        [ -2.08099365e-01,  -1.96594238e-01],
                        [ -1.84020996e-01,  -1.73126221e-01],
                        [ -1.36566162e-01,  -1.27716064e-01],
                        [ -1.00921631e-01,  -9.41772461e-02],
                        [ -8.71582031e-02,  -8.15734863e-02],
                        [ -7.84606934e-02,  -7.33032227e-02],
                        [ -6.25915527e-02,  -5.83496094e-02],
                        [ -4.64782715e-02,  -4.48913574e-02],
                        [ -3.75976562e-02,  -4.06494141e-02],
                        [ -3.27148438e-02,  -4.08935547e-02],
                        [ -2.92968750e-02,  -4.08935547e-02],
                        [ -3.04565430e-02,  -4.21447754e-02],
                        [ -3.43017578e-02,  -4.29382324e-02],
                        [ -3.36608887e-02,  -3.77197266e-02],
                        [ -2.69775391e-02,  -2.67333984e-02],
                        [ -1.75476074e-02,  -1.45568848e-02],
                        [ -5.82885742e-03,  -1.80053711e-03],
                        [  6.50024414e-03,   1.04980469e-02],
                        [  1.03149414e-02,   1.40075684e-02],
                        [ -7.32421875e-04,   2.65502930e-03],
                        [ -1.97753906e-02,  -1.72119141e-02],
                        [ -3.61938477e-02,  -3.52172852e-02],
                        [ -4.76684570e-02,  -4.87365723e-02],
                        [ -5.71594238e-02,  -6.03332520e-02],
                        [ -6.60400391e-02,  -7.09838867e-02],
                        [ -7.29064941e-02,  -7.87048340e-02],
                        [ -7.11059570e-02,  -7.63854980e-02],
                        [ -5.01403809e-02,  -5.36193848e-02],
                        [ -8.30078125e-03,  -9.30786133e-03],
                        [  4.01000977e-02,   4.13513184e-02],
                        [  7.74841309e-02,   8.01086426e-02],
                        [  9.73205566e-02,   1.00158691e-01],
                        [  1.01928711e-01,   1.04064941e-01],
                        [  9.57031250e-02,   9.68933105e-02],
                        [  8.42285156e-02,   8.48693848e-02],
                        [  7.14721680e-02,   7.22045898e-02],
                        [  5.68542480e-02,   5.79833984e-02],
                        [  4.01000977e-02,   4.16259766e-02],
                        [  2.68859863e-02,   2.89306641e-02],
                        [  2.41699219e-02,   2.69470215e-02],
                        [  3.05175781e-02,   3.42102051e-02],
                        [  3.75366211e-02,   4.17480469e-02],
                        [  4.08630371e-02,   4.44335938e-02],
                        [  4.32739258e-02,   4.45251465e-02],
                        [  4.44030762e-02,   4.23889160e-02],
                        [  3.85131836e-02,   3.37524414e-02],
                        [  2.74353027e-02,   2.18200684e-02],
                        [  2.59399414e-02,   2.14843750e-02],
                        [  4.52270508e-02,   4.29992676e-02],
                        [  7.94982910e-02,   7.93151855e-02],
                        [  1.14990234e-01,   1.16027832e-01],
                        [  1.44012451e-01,   1.45721436e-01],
                        [  1.62841797e-01,   1.65161133e-01],
                        [  1.64916992e-01,   1.67877197e-01],
                        [  1.43615723e-01,   1.46728516e-01],
                        [  9.51232910e-02,   9.72290039e-02],
                        [  1.77612305e-02,   1.80053711e-02],
                        [ -8.18786621e-02,  -8.30993652e-02],
                        [ -1.83410645e-01,  -1.84814453e-01],
                        [ -2.60681152e-01,  -2.61230469e-01],
                        [ -2.92877197e-01,  -2.93243408e-01],
                        [ -2.73162842e-01,  -2.75604248e-01],
                        [ -2.16491699e-01,  -2.23358154e-01],
                        [ -1.55548096e-01,  -1.66961670e-01],
                        [ -1.16577148e-01,  -1.29455566e-01],
                        [ -1.01043701e-01,  -1.10382080e-01],
                        [ -9.52758789e-02,  -9.69848633e-02],
                        [ -9.06982422e-02,  -8.40148926e-02],
                        [ -8.88366699e-02,  -7.64465332e-02],
                        [ -9.01794434e-02,  -7.67211914e-02],
                        [ -8.65783691e-02,  -7.62023926e-02],
                        [ -6.89392090e-02,  -6.35070801e-02],
                        [ -3.96423340e-02,  -3.85131836e-02],
                        [ -1.10473633e-02,  -1.21765137e-02],
                        [  7.81250000e-03,   6.50024414e-03],
                        [  1.68762207e-02,   1.67541504e-02],
                        [  1.72729492e-02,   1.90429688e-02],
                        [  6.28662109e-03,   9.82666016e-03],
                        [ -1.65405273e-02,  -1.22070312e-02],
                        [ -4.28161621e-02,  -3.97644043e-02],
                        [ -6.14929199e-02,  -6.18591309e-02],
                        [ -6.84204102e-02,  -7.33337402e-02],
                        [ -6.56433105e-02,  -7.41882324e-02],
                        [ -5.45959473e-02,  -6.42089844e-02],
                        [ -3.33557129e-02,  -4.11987305e-02],
                        [  2.89916992e-03,  -1.46484375e-03],
                        [  5.75256348e-02,   5.64575195e-02],
                        [  1.22955322e-01,   1.23687744e-01],
                        [  1.79473877e-01,   1.80603027e-01],
                        [  2.08282471e-01,   2.09564209e-01],
                        [  2.05291748e-01,   2.07611084e-01],
                        [  1.81732178e-01,   1.85852051e-01],
                        [  1.52496338e-01,   1.58325195e-01],
                        [  1.26220703e-01,   1.32507324e-01],
                        [  1.05682373e-01,   1.10839844e-01],
                        [  9.17053223e-02,   9.44519043e-02],
                        [  8.22143555e-02,   8.22753906e-02],
                        [  7.46765137e-02,   7.24792480e-02],
                        [  7.10754395e-02,   6.73217773e-02],
                        [  7.38830566e-02,   6.93054199e-02],
                        [  7.75756836e-02,   7.27539062e-02],
                        [  7.34558105e-02,   6.90612793e-02],
                        [  6.18896484e-02,   5.85327148e-02],
                        [  5.19714355e-02,   4.99572754e-02],
                        [  5.03234863e-02,   4.96826172e-02],
                        [  5.68847656e-02,   5.74951172e-02],
                        [  6.91833496e-02,   7.08618164e-02],
                        [  8.27026367e-02,   8.52355957e-02],
                        [  8.77685547e-02,   9.07897949e-02],
                        [  7.37304688e-02,   7.64770508e-02],
                        [  3.66821289e-02,   3.79943848e-02],
                        [ -1.86462402e-02,  -1.95922852e-02],
                        [ -7.96203613e-02,  -8.26416016e-02],
                        [ -1.26922607e-01,  -1.30584717e-01],
                        [ -1.43371582e-01,  -1.45782471e-01],
                        [ -1.28479004e-01,  -1.28448486e-01],
                        [ -1.00402832e-01,  -9.77783203e-02],
                        [ -7.93151855e-02,  -7.47375488e-02],
                        [ -7.09838867e-02,  -6.51550293e-02],
                        [ -6.70776367e-02,  -6.06079102e-02],
                        [ -5.92346191e-02,  -5.30395508e-02],
                        [ -4.91638184e-02,  -4.47998047e-02],
                        [ -4.30908203e-02,  -4.21752930e-02],
                        [ -4.15954590e-02,  -4.47082520e-02],
                        [ -3.88488770e-02,  -4.49829102e-02],
                        [ -2.92968750e-02,  -3.59802246e-02],
                        [ -1.31225586e-02,  -1.77917480e-02],
                        [  2.22778320e-03,   6.10351562e-04],
                        [  7.59887695e-03,   7.65991211e-03],
                        [  1.00708008e-03,   3.35693359e-04],
                        [ -1.09558105e-02,  -1.37023926e-02],
                        [ -2.08740234e-02,  -2.48107910e-02],
                        [ -2.60925293e-02,  -2.89306641e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.70690918e-02,  -2.42309570e-02],
                        [ -3.12805176e-02,  -2.74353027e-02],
                        [ -4.48913574e-02,  -4.20837402e-02],
                        [ -6.34765625e-02,  -6.24389648e-02],
                        [ -7.47375488e-02,  -7.44934082e-02],
                        [ -7.18994141e-02,  -7.11669922e-02],
                        [ -5.75866699e-02,  -5.60302734e-02],
                        [ -3.25317383e-02,  -3.11279297e-02],
                        [  6.86645508e-03,   6.98852539e-03],
                        [  5.46264648e-02,   5.31616211e-02],
                        [  9.14001465e-02,   8.90808105e-02],
                        [  1.02447510e-01,   1.00067139e-01],
                        [  9.20715332e-02,   8.94165039e-02],
                        [  7.47680664e-02,   7.05871582e-02],
                        [  5.90515137e-02,   5.23376465e-02],
                        [  4.46472168e-02,   3.62854004e-02],
                        [  3.03955078e-02,   2.34985352e-02],
                        [  2.01110840e-02,   1.84631348e-02],
                        [  1.94091797e-02,   2.52380371e-02],
                        [  2.78015137e-02,   4.01916504e-02],
                        [  3.72009277e-02,   5.29174805e-02],
                        [  4.15344238e-02,   5.68237305e-02],
                        [  4.28161621e-02,   5.53588867e-02],
                        [  4.50134277e-02,   5.42907715e-02],
                        [  4.73632812e-02,   5.38024902e-02],
                        [  4.83093262e-02,   5.20019531e-02],
                        [  5.14526367e-02,   5.15136719e-02],
                        [  6.25305176e-02,   5.77697754e-02],
                        [  8.28247070e-02,   7.28149414e-02],
                        [  1.07604980e-01,   9.32312012e-02],
                        [  1.30828857e-01,   1.13800049e-01],
                        [  1.48162842e-01,   1.30432129e-01],
                        [  1.52862549e-01,   1.36474609e-01],
                        [  1.31805420e-01,   1.19049072e-01],
                        [  7.39440918e-02,   6.71691895e-02],
                        [ -1.69982910e-02,  -1.61437988e-02],
                        [ -1.22741699e-01,  -1.14257812e-01],
                        [ -2.18902588e-01,  -2.04986572e-01],
                        [ -2.80517578e-01,  -2.64923096e-01],
                        [ -2.90557861e-01,  -2.77069092e-01],
                        [ -2.54333496e-01,  -2.45086670e-01],
                        [ -1.99615479e-01,  -1.94458008e-01],
                        [ -1.53411865e-01,  -1.50848389e-01],
                        [ -1.22314453e-01,  -1.21002197e-01],
                        [ -9.83276367e-02,  -9.81750488e-02],
                        [ -7.66601562e-02,  -7.85217285e-02],
                        [ -6.02416992e-02,  -6.47277832e-02],
                        [ -5.18493652e-02,  -5.84411621e-02],
                        [ -4.84619141e-02,  -5.57250977e-02],
                        [ -4.34875488e-02,  -4.98657227e-02],
                        [ -3.29589844e-02,  -3.74450684e-02],
                        [ -1.90429688e-02,  -2.15454102e-02],
                        [ -7.50732422e-03,  -8.60595703e-03],
                        [ -3.20434570e-03,  -3.54003906e-03],
                        [ -7.08007812e-03,  -6.83593750e-03],
                        [ -1.62658691e-02,  -1.50756836e-02],
                        [ -2.77404785e-02,  -2.48107910e-02],
                        [ -4.26940918e-02,  -3.70178223e-02],
                        [ -6.30187988e-02,  -5.41381836e-02],
                        [ -8.23974609e-02,  -7.09838867e-02],
                        [ -8.67309570e-02,  -7.51342773e-02],
                        [ -6.82678223e-02,  -6.00585938e-02],
                        [ -3.18603516e-02,  -2.99987793e-02],
                        [  1.64184570e-02,   1.11389160e-02],
                        [  7.54699707e-02,   6.49719238e-02],
                        [  1.38092041e-01,   1.26037598e-01],
                        [  1.86279297e-01,   1.76025391e-01],
                        [  2.05902100e-01,   1.98791504e-01],
                        [  1.97052002e-01,   1.92230225e-01],
                        [  1.68701172e-01,   1.64642334e-01],
                        [  1.33636475e-01,   1.29730225e-01],
                        [  1.06872559e-01,   1.04064941e-01],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  9.10034180e-02,   9.50927734e-02],
                        [  8.12683105e-02,   8.92639160e-02],
                        [  6.81457520e-02,   7.84606934e-02],
                        [  6.18896484e-02,   7.24182129e-02],
                        [  6.39343262e-02,   7.25402832e-02],
                        [  6.47888184e-02,   6.95190430e-02],
                        [  5.76782227e-02,   5.70373535e-02],
                        [  4.63562012e-02,   3.99169922e-02],
                        [  3.94287109e-02,   2.85949707e-02],
                        [  4.16870117e-02,   2.99072266e-02],
                        [  5.20019531e-02,   4.34875488e-02],
                        [  6.59484863e-02,   6.34460449e-02],
                        [  7.99865723e-02,   8.30993652e-02],
                        [  9.30480957e-02,   9.85412598e-02],
                        [  1.03912354e-01,   1.07940674e-01],
                        [  1.07025146e-01,   1.07666016e-01],
                        [  9.07287598e-02,   8.93859863e-02],
                        [  4.26025391e-02,   4.25720215e-02],
                        [ -3.72314453e-02,  -3.34472656e-02],
                        [ -1.25061035e-01,  -1.17858887e-01],
                        [ -1.84082031e-01,  -1.76666260e-01],
                        [ -1.93969727e-01,  -1.89819336e-01],
                        [ -1.67297363e-01,  -1.67907715e-01],
                        [ -1.34338379e-01,  -1.38244629e-01],
                        [ -1.13342285e-01,  -1.17645264e-01],
                        [ -1.01074219e-01,  -1.03454590e-01],
                        [ -8.76159668e-02,  -8.78601074e-02],
                        [ -6.94274902e-02,  -6.91528320e-02],
                        [ -4.67529297e-02,  -4.78210449e-02],
                        [ -2.18505859e-02,  -2.47192383e-02],
                        [ -3.35693359e-03,  -6.98852539e-03],
                        [ -3.66210938e-04,  -3.14331055e-03],
                        [ -9.55200195e-03,  -1.05895996e-02],
                        [ -1.88598633e-02,  -1.82189941e-02],
                        [ -2.25219727e-02,  -2.09655762e-02],
                        [ -2.40783691e-02,  -2.22167969e-02],
                        [ -2.65197754e-02,  -2.45971680e-02],
                        [ -2.79846191e-02,  -2.59704590e-02],
                        [ -2.57568359e-02,  -2.36816406e-02],
                        [ -2.06298828e-02,  -1.85241699e-02],
                        [ -1.71813965e-02,  -1.49841309e-02],
                        [ -2.17285156e-02,  -1.90734863e-02],
                        [ -3.72924805e-02,  -3.41186523e-02],
                        [ -5.88989258e-02,  -5.59387207e-02],
                        [ -7.47680664e-02,  -7.36999512e-02],
                        [ -7.48596191e-02,  -7.74841309e-02],
                        [ -5.74035645e-02,  -6.45751953e-02],
                        [ -2.60620117e-02,  -3.70178223e-02],
                        [  1.51672363e-02,   2.74658203e-03],
                        [  6.02722168e-02,   4.92858887e-02],
                        [  9.81750488e-02,   9.07592773e-02],
                        [  1.17767334e-01,   1.14746094e-01],
                        [  1.16729736e-01,   1.17614746e-01],
                        [  1.02050781e-01,   1.05743408e-01],
                        [  8.35571289e-02,   8.88366699e-02],
                        [  6.85729980e-02,   7.47070312e-02],
                        [  5.88684082e-02,   6.55212402e-02],
                        [  4.92248535e-02,   5.66406250e-02],
                        [  3.50341797e-02,   4.35791016e-02],
                        [  2.22167969e-02,   3.19824219e-02],
                        [  2.12097168e-02,   3.16772461e-02],
                        [  3.11279297e-02,   4.11071777e-02],
                        [  4.11376953e-02,   4.93469238e-02],
                        [  4.55627441e-02,   5.11474609e-02],
                        [  4.68750000e-02,   4.96215820e-02],
                        [  4.82482910e-02,   4.81872559e-02],
                        [  5.39855957e-02,   5.08422852e-02],
                        [  7.15942383e-02,   6.45446777e-02],
                        [  1.01684570e-01,   9.00573730e-02],
                        [  1.32324219e-01,   1.16607666e-01],
                        [  1.51153564e-01,   1.33483887e-01],
                        [  1.54693604e-01,   1.38214111e-01],
                        [  1.39495850e-01,   1.26770020e-01],
                        [  9.63134766e-02,   8.83789062e-02],
                        [  2.13928223e-02,   1.76696777e-02],
                        [ -7.55004883e-02,  -7.59582520e-02],
                        [ -1.75201416e-01,  -1.72546387e-01],
                        [ -2.51861572e-01,  -2.45269775e-01],
                        [ -2.79296875e-01,  -2.68066406e-01],
                        [ -2.51373291e-01,  -2.36114502e-01],
                        [ -1.93725586e-01,  -1.76818848e-01],
                        [ -1.43280029e-01,  -1.27929688e-01],
                        [ -1.17706299e-01,  -1.06658936e-01],
                        [ -1.09161377e-01,  -1.03668213e-01],
                        [ -1.02416992e-01,  -1.02539062e-01],
                        [ -9.22851562e-02,  -9.75341797e-02],
                        [ -8.20617676e-02,  -9.17053223e-02],
                        [ -7.23571777e-02,  -8.51440430e-02],
                        [ -5.94482422e-02,  -7.31506348e-02],
                        [ -4.28466797e-02,  -5.45043945e-02],
                        [ -2.57873535e-02,  -3.30810547e-02],
                        [ -9.85717773e-03,  -1.22985840e-02],
                        [  3.87573242e-03,   4.66918945e-03],
                        [  1.16882324e-02,   1.35192871e-02],
                        [  1.09558105e-02,   1.28173828e-02],
                        [  1.49536133e-03,   4.69970703e-03],
                        [ -1.84631348e-02,  -1.14440918e-02],
                        [ -4.88281250e-02,  -3.65600586e-02],
                        [ -7.83996582e-02,  -6.24389648e-02],
                        [ -9.01489258e-02,  -7.46459961e-02],
                        [ -7.80944824e-02,  -6.75964355e-02],
                        [ -4.88891602e-02,  -4.58068848e-02],
                        [ -6.74438477e-03,  -1.01318359e-02],
                        [  5.07507324e-02,   4.38232422e-02],
                        [  1.19934082e-01,   1.12182617e-01],
                        [  1.84387207e-01,   1.76513672e-01],
                        [  2.23846436e-01,   2.14691162e-01],
                        [  2.27020264e-01,   2.15393066e-01],
                        [  1.98974609e-01,   1.85211182e-01],
                        [  1.57836914e-01,   1.44287109e-01],
                        [  1.21978760e-01,   1.11907959e-01],
                        [  9.90295410e-02,   9.48486328e-02],
                        [  8.60595703e-02,   8.85009766e-02],
                        [  7.68432617e-02,   8.48388672e-02],
                        [  6.72607422e-02,   7.86743164e-02],
                        [  5.67932129e-02,   6.91833496e-02],
                        [  4.66308594e-02,   5.76171875e-02],
                        [  3.71398926e-02,   4.49218750e-02],
                        [  2.78015137e-02,   3.15856934e-02],
                        [  1.85852051e-02,   1.89514160e-02],
                        [  1.14135742e-02,   9.91821289e-03],
                        [  1.11999512e-02,   9.55200195e-03],
                        [  2.30712891e-02,   2.19421387e-02],
                        [  4.58679199e-02,   4.44946289e-02],
                        [  7.23571777e-02,   6.92443848e-02],
                        [  9.66796875e-02,   9.09423828e-02],
                        [  1.16638184e-01,   1.09069824e-01],
                        [  1.28875732e-01,   1.21948242e-01],
                        [  1.28112793e-01,   1.24603271e-01],
                        [  1.09313965e-01,   1.10931396e-01],
                        [  6.62536621e-02,   7.28149414e-02],
                        [ -6.46972656e-03,   3.20434570e-03],
                        [ -9.98535156e-02,  -8.97216797e-02],
                        [ -1.82830811e-01,  -1.74652100e-01],
                        [ -2.20306396e-01,  -2.15606689e-01],
                        [ -2.02423096e-01,  -2.01660156e-01],
                        [ -1.51123047e-01,  -1.53625488e-01],
                        [ -9.86022949e-02,  -1.03149414e-01],
                        [ -6.46362305e-02,  -7.01293945e-02],
                        [ -5.07812500e-02,  -5.68542480e-02],
                        [ -4.76379395e-02,  -5.45349121e-02],
                        [ -4.63256836e-02,  -5.42907715e-02],
                        [ -4.69360352e-02,  -5.51452637e-02],
                        [ -5.32531738e-02,  -5.94787598e-02],
                        [ -5.99670410e-02,  -6.15844727e-02],
                        [ -5.54504395e-02,  -5.11169434e-02],
                        [ -3.75061035e-02,  -2.83813477e-02],
                        [ -1.61132812e-02,  -5.55419922e-03],
                        [ -8.85009766e-04,   7.35473633e-03],
                        [  4.60815430e-03,   8.81958008e-03],
                        [  4.27246094e-04,   1.67846680e-03],
                        [ -9.73510742e-03,  -8.60595703e-03],
                        [ -1.98059082e-02,  -1.66320801e-02],
                        [ -2.77099609e-02,  -2.24609375e-02],
                        [ -3.61022949e-02,  -3.10974121e-02],
                        [ -4.80651855e-02,  -4.63562012e-02],
                        [ -6.43920898e-02,  -6.79321289e-02],
                        [ -8.05053711e-02,  -8.95080566e-02],
                        [ -8.53576660e-02,  -9.84497070e-02],
                        [ -6.96716309e-02,  -8.46557617e-02],
                        [ -3.56140137e-02,  -5.01403809e-02],
                        [  7.11059570e-03,  -4.57763672e-03],
                        [  5.05065918e-02,   4.37316895e-02],
                        [  8.88671875e-02,   8.80737305e-02],
                        [  1.14837646e-01,   1.19476318e-01],
                        [  1.20483398e-01,   1.28479004e-01],
                        [  1.04431152e-01,   1.13281250e-01],
                        [  7.73315430e-02,   8.57849121e-02],
                        [  5.50537109e-02,   6.38427734e-02],
                        [  4.33959961e-02,   5.41687012e-02],
                        [  3.60717773e-02,   4.97131348e-02],
                        [  3.11584473e-02,   4.61120605e-02],
                        [  3.63464355e-02,   4.91333008e-02],
                        [  5.34057617e-02,   6.04248047e-02],
                        [  6.97021484e-02,   6.97631836e-02],
                        [  7.40661621e-02,   6.86950684e-02],
                        [  7.05566406e-02,   6.28967285e-02],
                        [  7.01599121e-02,   6.24389648e-02],
                        [  7.56835938e-02,   6.79321289e-02],
                        [  8.24890137e-02,   7.31201172e-02],
                        [  9.00573730e-02,   7.78198242e-02],
                        [  1.03820801e-01,   8.94775391e-02],
                        [  1.24511719e-01,   1.10717773e-01],
                        [  1.40777588e-01,   1.30767822e-01],
                        [  1.35131836e-01,   1.30767822e-01],
                        [  9.48486328e-02,   9.59472656e-02],
                        [  1.88598633e-02,   2.38952637e-02],
                        [ -8.12988281e-02,  -7.40661621e-02],
                        [ -1.84265137e-01,  -1.76055908e-01],
                        [ -2.62542725e-01,  -2.54150391e-01],
                        [ -2.91534424e-01,  -2.83721924e-01],
                        [ -2.65563965e-01,  -2.59033203e-01],
                        [ -2.05780029e-01,  -2.00836182e-01],
                        [ -1.45111084e-01,  -1.41235352e-01],
                        [ -1.04309082e-01,  -1.00708008e-01],
                        [ -8.50830078e-02,  -8.16650391e-02],
                        [ -7.96203613e-02,  -7.75146484e-02],
                        [ -7.87353516e-02,  -7.99560547e-02],
                        [ -7.71484375e-02,  -8.29162598e-02],
                        [ -7.52563477e-02,  -8.48083496e-02],
                        [ -7.30895996e-02,  -8.36486816e-02],
                        [ -6.47277832e-02,  -7.27539062e-02],
                        [ -4.62341309e-02,  -4.94079590e-02],
                        [ -2.38952637e-02,  -2.21862793e-02],
                        [ -5.58471680e-03,  -9.15527344e-04],
                        [  8.75854492e-03,   1.38549805e-02],
                        [  1.87988281e-02,   2.26135254e-02],
                        [  1.51367188e-02,   1.73339844e-02],
                        [ -9.06372070e-03,  -7.72094727e-03],
                        [ -4.44641113e-02,  -4.29077148e-02],
                        [ -7.23571777e-02,  -6.98242188e-02],
                        [ -8.12072754e-02,  -7.77587891e-02],
                        [ -7.05261230e-02,  -6.68945312e-02],
                        [ -4.14428711e-02,  -3.89099121e-02],
                        [  8.23974609e-03,   8.51440430e-03],
                        [  7.62023926e-02,   7.39746094e-02],
                        [  1.46301270e-01,   1.42395020e-01],
                        [  1.94488525e-01,   1.90429688e-01],
                        [  2.06512451e-01,   2.03643799e-01],
                        [  1.87927246e-01,   1.86492920e-01],
                        [  1.57196045e-01,   1.56341553e-01],
                        [  1.31835938e-01,   1.30523682e-01],
                        [  1.17553711e-01,   1.15570068e-01],
                        [  1.07360840e-01,   1.05468750e-01],
                        [  9.35058594e-02,   9.25598145e-02],
                        [  7.84912109e-02,   7.83691406e-02],
                        [  6.79321289e-02,   6.73217773e-02],
                        [  5.77697754e-02,   5.51147461e-02],
                        [  4.07104492e-02,   3.58886719e-02],
                        [  2.09045410e-02,   1.58386230e-02],
                        [  7.20214844e-03,   4.82177734e-03],
                        [ -1.83105469e-03,   4.27246094e-04],
                        [ -1.01318359e-02,  -3.84521484e-03],
                        [ -9.30786133e-03,  -1.73950195e-03],
                        [  9.36889648e-03,   1.53198242e-02],
                        [  3.56750488e-02,   3.89709473e-02],
                        [  5.17578125e-02,   5.35888672e-02],
                        [  5.66101074e-02,   5.91430664e-02],
                        [  6.36901855e-02,   6.80236816e-02],
                        [  8.06274414e-02,   8.57849121e-02],
                        [  1.04431152e-01,   1.08215332e-01],
                        [  1.27563477e-01,   1.28234863e-01],
                        [  1.34826660e-01,   1.32324219e-01],
                        [  1.03912354e-01,   9.95788574e-02],
                        [  2.58178711e-02,   2.10266113e-02],
                        [ -7.85827637e-02,  -8.32824707e-02],
                        [ -1.70379639e-01,  -1.75476074e-01],
                        [ -2.18231201e-01,  -2.24090576e-01],
                        [ -2.12951660e-01,  -2.19085693e-01],
                        [ -1.69555664e-01,  -1.74865723e-01],
                        [ -1.17675781e-01,  -1.21246338e-01],
                        [ -8.16040039e-02,  -8.34045410e-02],
                        [ -6.65283203e-02,  -6.69860840e-02],
                        [ -6.48498535e-02,  -6.37512207e-02],
                        [ -6.95800781e-02,  -6.55822754e-02],
                        [ -7.73010254e-02,  -6.87866211e-02],
                        [ -8.36181641e-02,  -7.05566406e-02],
                        [ -8.35571289e-02,  -6.86645508e-02],
                        [ -7.58972168e-02,  -6.39953613e-02],
                        [ -6.15234375e-02,  -5.70678711e-02],
                        [ -3.98559570e-02,  -4.42199707e-02],
                        [ -1.36718750e-02,  -2.42919922e-02],
                        [  5.61523438e-03,  -6.25610352e-03],
                        [  7.78198242e-03,  -8.54492188e-04],
                        [ -3.81469727e-03,  -7.50732422e-03],
                        [ -1.78833008e-02,  -1.79748535e-02],
                        [ -2.87780762e-02,  -2.81372070e-02],
                        [ -3.75366211e-02,  -3.84826660e-02],
                        [ -4.66613770e-02,  -4.96826172e-02],
                        [ -5.87158203e-02,  -6.28356934e-02],
                        [ -7.46765137e-02,  -7.82165527e-02],
                        [ -8.68530273e-02,  -8.85620117e-02],
                        [ -7.97424316e-02,  -7.91320801e-02],
                        [ -4.47692871e-02,  -4.21142578e-02],
                        [  8.14819336e-03,   1.17492676e-02],
                        [  5.99060059e-02,   6.30187988e-02],
                        [  9.83581543e-02,   9.97314453e-02],
                        [  1.18286133e-01,   1.17523193e-01],
                        [  1.15875244e-01,   1.13952637e-01],
                        [  9.61914062e-02,   9.50927734e-02],
                        [  7.67822266e-02,   7.82775879e-02],
                        [  6.91223145e-02,   7.36083984e-02],
                        [  6.59179688e-02,   7.20825195e-02],
                        [  5.83801270e-02,   6.39953613e-02],
                        [  5.34667969e-02,   5.68542480e-02],
                        [  5.99670410e-02,   6.10961914e-02],
                        [  6.96716309e-02,   7.00988770e-02],
                        [  6.86035156e-02,   7.04345703e-02],
                        [  5.89599609e-02,   6.34155273e-02],
                        [  5.44128418e-02,   6.08825684e-02],
                        [  5.99365234e-02,   6.61621094e-02],
                        [  7.10449219e-02,   7.38220215e-02],
                        [  8.74633789e-02,   8.40759277e-02],
                        [  1.13098145e-01,   1.02600098e-01],
                        [  1.42303467e-01,   1.26312256e-01],
                        [  1.57897949e-01,   1.40228271e-01],
                        [  1.45233154e-01,   1.30432129e-01],
                        [  1.00402832e-01,   9.18273926e-02],
                        [  2.49633789e-02,   2.32849121e-02],
                        [ -7.63244629e-02,  -7.31506348e-02],
                        [ -1.87072754e-01,  -1.82434082e-01],
                        [ -2.76214600e-01,  -2.72552490e-01],
                        [ -3.12377930e-01,  -3.09875488e-01],
                        [ -2.86468506e-01,  -2.83325195e-01],
                        [ -2.21252441e-01,  -2.15301514e-01],
                        [ -1.55212402e-01,  -1.45782471e-01],
                        [ -1.13525391e-01,  -1.02111816e-01],
                        [ -9.63439941e-02,  -8.59069824e-02],
                        [ -9.10949707e-02,  -8.44726562e-02],
                        [ -8.58459473e-02,  -8.45336914e-02],
                        [ -7.37609863e-02,  -7.75756836e-02],
                        [ -5.64270020e-02,  -6.38122559e-02],
                        [ -4.23278809e-02,  -5.10253906e-02],
                        [ -3.65600586e-02,  -4.40368652e-02],
                        [ -3.38745117e-02,  -3.79638672e-02],
                        [ -2.58789062e-02,  -2.53906250e-02],
                        [ -1.17187500e-02,  -7.23266602e-03],
                        [  2.13623047e-04,   6.34765625e-03],
                        [  1.49536133e-03,   6.10351562e-03],
                        [ -8.97216797e-03,  -8.08715820e-03],
                        [ -2.72827148e-02,  -3.00598145e-02],
                        [ -4.76379395e-02,  -5.19409180e-02],
                        [ -5.97229004e-02,  -6.28967285e-02],
                        [ -5.32226562e-02,  -5.40161133e-02],
                        [ -2.79846191e-02,  -2.74353027e-02],
                        [  1.00097656e-02,   9.67407227e-03],
                        [  6.10046387e-02,   5.84411621e-02],
                        [  1.24053955e-01,   1.20086670e-01],
                        [  1.81060791e-01,   1.78161621e-01],
                        [  2.07550049e-01,   2.07977295e-01],
                        [  1.99127197e-01,   2.03186035e-01],
                        [  1.71966553e-01,   1.77825928e-01],
                        [  1.40930176e-01,   1.46087646e-01],
                        [  1.11724854e-01,   1.14959717e-01],
                        [  8.89892578e-02,   9.07897949e-02],
                        [  7.57751465e-02,   7.73315430e-02],
                        [  6.83288574e-02,   6.99768066e-02],
                        [  6.22558594e-02,   6.27441406e-02],
                        [  5.94787598e-02,   5.67626953e-02],
                        [  6.10961914e-02,   5.42602539e-02],
                        [  5.99975586e-02,   5.01708984e-02],
                        [  4.71801758e-02,   3.72009277e-02],
                        [  2.38952637e-02,   1.66625977e-02],
                        [  1.98364258e-03,  -1.12915039e-03],
                        [ -7.50732422e-03,  -6.86645508e-03],
                        [ -2.92968750e-03,   6.10351562e-05],
                        [  1.08947754e-02,   1.51062012e-02],
                        [  2.90832520e-02,   3.39660645e-02],
                        [  4.66003418e-02,   5.20935059e-02],
                        [  5.82275391e-02,   6.42395020e-02],
                        [  6.31103516e-02,   6.92749023e-02],
                        [  6.61926270e-02,   7.22351074e-02],
                        [  7.29370117e-02,   7.86743164e-02],
                        [  8.35876465e-02,   8.88366699e-02],
                        [  9.24987793e-02,   9.66491699e-02],
                        [  8.94775391e-02,   9.14001465e-02],
                        [  6.33544922e-02,   6.18591309e-02],
                        [  8.94165039e-03,   3.26538086e-03],
                        [ -6.63146973e-02,  -7.58972168e-02],
                        [ -1.40838623e-01,  -1.53167725e-01],
                        [ -1.87286377e-01,  -2.00592041e-01],
                        [ -1.89331055e-01,  -2.01507568e-01],
                        [ -1.55090332e-01,  -1.63818359e-01],
                        [ -1.10778809e-01,  -1.13769531e-01],
                        [ -7.83996582e-02,  -7.40051270e-02],
                        [ -6.21032715e-02,  -5.02014160e-02],
                        [ -5.62438965e-02,  -3.87573242e-02],
                        [ -5.71594238e-02,  -3.77502441e-02],
                        [ -6.27746582e-02,  -4.55627441e-02],
                        [ -6.84204102e-02,  -5.67321777e-02],
                        [ -6.97021484e-02,  -6.51550293e-02],
                        [ -6.63146973e-02,  -6.88781738e-02],
                        [ -5.93261719e-02,  -6.79321289e-02],
                        [ -4.74853516e-02,  -6.04248047e-02],
                        [ -2.89306641e-02,  -4.41284180e-02],
                        [ -6.25610352e-03,  -2.14843750e-02],
                        [  1.17187500e-02,  -1.61743164e-03],
                        [  1.55944824e-02,   5.09643555e-03],
                        [  3.11279297e-03,  -4.63867188e-03],
                        [ -1.96838379e-02,  -2.51159668e-02],
                        [ -4.55322266e-02,  -4.85534668e-02],
                        [ -7.11364746e-02,  -7.05566406e-02],
                        [ -9.37194824e-02,  -8.79211426e-02],
                        [ -1.06170654e-01,  -9.47265625e-02],
                        [ -9.96093750e-02,  -8.44116211e-02],
                        [ -6.96716309e-02,  -5.44738770e-02],
                        [ -2.01110840e-02,  -8.60595703e-03],
                        [  3.77197266e-02,   4.39758301e-02],
                        [  8.84399414e-02,   9.07287598e-02],
                        [  1.18408203e-01,   1.19476318e-01],
                        [  1.21856689e-01,   1.23718262e-01],
                        [  1.04461670e-01,   1.06842041e-01],
                        [  8.06579590e-02,   8.14208984e-02],
                        [  6.37817383e-02,   6.08520508e-02],
                        [  5.78002930e-02,   5.08728027e-02],
                        [  5.86547852e-02,   4.94384766e-02],
                        [  6.09130859e-02,   5.17883301e-02],
                        [  6.20727539e-02,   5.46264648e-02],
                        [  6.29882812e-02,   5.76171875e-02],
                        [  6.52465820e-02,   6.19201660e-02],
                        [  6.83288574e-02,   6.77185059e-02],
                        [  7.06787109e-02,   7.40661621e-02],
                        [  7.30895996e-02,   8.12683105e-02],
                        [  7.91015625e-02,   9.09118652e-02],
                        [  9.19799805e-02,   1.04125977e-01],
                        [  1.11419678e-01,   1.19964600e-01],
                        [  1.31988525e-01,   1.34399414e-01],
                        [  1.44500732e-01,   1.40686035e-01],
                        [  1.38610840e-01,   1.30340576e-01],
                        [  1.02813721e-01,   9.22241211e-02],
                        [  2.82897949e-02,   1.67541504e-02],
                        [ -7.97424316e-02,  -9.14916992e-02],
                        [ -1.95007324e-01,  -2.06024170e-01],
                        [ -2.81402588e-01,  -2.89947510e-01],
                        [ -3.13354492e-01,  -3.17565918e-01],
                        [ -2.88726807e-01,  -2.87841797e-01],
                        [ -2.28271484e-01,  -2.23297119e-01],
                        [ -1.64123535e-01,  -1.57165527e-01],
                        [ -1.19964600e-01,  -1.12640381e-01],
                        [ -9.87854004e-02,  -9.12780762e-02],
                        [ -9.09729004e-02,  -8.24890137e-02],
                        [ -8.86840820e-02,  -7.87353516e-02],
                        [ -8.64562988e-02,  -7.61108398e-02],
                        [ -7.69653320e-02,  -6.86340332e-02],
                        [ -5.53283691e-02,  -5.12084961e-02],
                        [ -2.42309570e-02,  -2.48718262e-02],
                        [  6.83593750e-03,   2.89916992e-03],
                        [  2.62756348e-02,   2.14843750e-02],
                        [  2.82592773e-02,   2.44750977e-02],
                        [  1.58386230e-02,   1.37634277e-02],
                        [ -7.53784180e-03,  -8.39233398e-03],
                        [ -4.26635742e-02,  -4.31213379e-02],
                        [ -8.21228027e-02,  -8.29467773e-02],
                        [ -1.05499268e-01,  -1.07482910e-01],
                        [ -9.75341797e-02,  -1.01531982e-01],
                        [ -6.25610352e-02,  -6.91223145e-02],
                        [ -1.33056641e-02,  -2.19116211e-02],
                        [  4.45861816e-02,   3.58276367e-02],
                        [  1.08825684e-01,   1.02630615e-01],
                        [  1.68060303e-01,   1.66687012e-01],
                        [  2.04650879e-01,   2.08648682e-01],
                        [  2.10906982e-01,   2.18841553e-01],
                        [  1.94488525e-01,   2.03826904e-01],
                        [  1.69036865e-01,   1.77398682e-01],
                        [  1.44348145e-01,   1.50451660e-01],
                        [  1.23870850e-01,   1.27410889e-01],
                        [  1.05255127e-01,   1.06597900e-01],
                        [  8.47473145e-02,   8.42895508e-02],
                        [  6.32019043e-02,   6.11267090e-02],
                        [  4.66308594e-02,   4.29992676e-02],
                        [  3.91235352e-02,   3.39050293e-02],
                        [  3.59497070e-02,   2.92968750e-02],
                        [  2.72216797e-02,   1.95617676e-02],
                        [  9.88769531e-03,   2.50244141e-03],
                        [ -6.89697266e-03,  -1.19628906e-02],
                        [ -1.22985840e-02,  -1.27868652e-02],
                        [ -6.34765625e-03,  -1.03759766e-03],
                        [  1.70898438e-03,   1.19628906e-02],
                        [  6.19506836e-03,   1.83715820e-02],
                        [  1.02539062e-02,   2.03857422e-02],
                        [  1.86767578e-02,   2.37426758e-02],
                        [  3.25622559e-02,   3.19213867e-02],
                        [  5.24597168e-02,   4.77905273e-02],
                        [  7.69653320e-02,   7.08312988e-02],
                        [  9.72290039e-02,   9.17663574e-02],
                        [  1.04919434e-01,   1.00891113e-01],
                        [  1.04003906e-01,   1.01440430e-01],
                        [  1.03149414e-01,   1.01837158e-01],
                        [  9.72290039e-02,   9.71679688e-02],
                        [  6.72912598e-02,   6.82373047e-02],
                        [  3.05175781e-05,   1.06811523e-03],
                        [ -9.39025879e-02,  -9.40856934e-02],
                        [ -1.80694580e-01,  -1.82708740e-01],
                        [ -2.25463867e-01,  -2.28332520e-01],
                        [ -2.17803955e-01,  -2.19085693e-01],
                        [ -1.76574707e-01,  -1.73767090e-01],
                        [ -1.32446289e-01,  -1.24816895e-01],
                        [ -1.05346680e-01,  -9.46350098e-02],
                        [ -9.44824219e-02,  -8.38928223e-02],
                        [ -8.72802734e-02,  -7.96508789e-02],
                        [ -7.65686035e-02,  -7.29675293e-02],
                        [ -6.47888184e-02,  -6.46667480e-02],
                        [ -5.56945801e-02,  -5.81359863e-02],
                        [ -4.90112305e-02,  -5.38940430e-02],
                        [ -4.31518555e-02,  -5.10864258e-02],
                        [ -3.66210938e-02,  -4.76684570e-02],
                        [ -2.65808105e-02,  -3.95507812e-02],
                        [ -1.16882324e-02,  -2.41088867e-02],
                        [  2.80761719e-03,  -6.86645508e-03],
                        [  6.92749023e-03,   8.85009766e-04],
                        [ -3.99780273e-03,  -7.08007812e-03],
                        [ -2.63366699e-02,  -2.74963379e-02],
                        [ -5.47790527e-02,  -5.41381836e-02],
                        [ -8.48083496e-02,  -8.14819336e-02],
                        [ -1.09222412e-01,  -1.02355957e-01],
                        [ -1.18560791e-01,  -1.08581543e-01],
                        [ -1.06903076e-01,  -9.58251953e-02],
                        [ -7.42187500e-02,  -6.45751953e-02],
                        [ -2.55432129e-02,  -1.88903809e-02],
                        [  3.06396484e-02,   3.44543457e-02],
                        [  8.42895508e-02,   8.64868164e-02],
                        [  1.24938965e-01,   1.26464844e-01],
                        [  1.43188477e-01,   1.44042969e-01],
                        [  1.35284424e-01,   1.34948730e-01],
                        [  1.07727051e-01,   1.06292725e-01],
                        [  7.59277344e-02,   7.46459961e-02],
                        [  5.49621582e-02,   5.56945801e-02],
                        [  4.97131348e-02,   5.33752441e-02],
                        [  5.34667969e-02,   5.89904785e-02],
                        [  5.71594238e-02,   6.16760254e-02],
                        [  5.88073730e-02,   5.89599609e-02],
                        [  6.32019043e-02,   5.71289062e-02],
                        [  7.45849609e-02,   6.31103516e-02],
                        [  9.08203125e-02,   7.69958496e-02],
                        [  1.04888916e-01,   9.27734375e-02],
                        [  1.12274170e-01,   1.05041504e-01],
                        [  1.14837646e-01,   1.13464355e-01],
                        [  1.17767334e-01,   1.20880127e-01],
                        [  1.23840332e-01,   1.28540039e-01],
                        [  1.27655029e-01,   1.31134033e-01],
                        [  1.13494873e-01,   1.14440918e-01],
                        [  6.40869141e-02,   6.33239746e-02],
                        [ -2.42919922e-02,  -2.44445801e-02],
                        [ -1.34765625e-01,  -1.32232666e-01],
                        [ -2.35412598e-01,  -2.29827881e-01],
                        [ -2.91992188e-01,  -2.85308838e-01],
                        [ -2.87139893e-01,  -2.82653809e-01],
                        [ -2.36450195e-01,  -2.36938477e-01],
                        [ -1.79656982e-01,  -1.85607910e-01],
                        [ -1.46087646e-01,  -1.55364990e-01],
                        [ -1.32171631e-01,  -1.41052246e-01],
                        [ -1.17370605e-01,  -1.22406006e-01],
                        [ -9.33227539e-02,  -9.27734375e-02],
                        [ -6.79016113e-02,  -6.21032715e-02],
                        [ -4.91027832e-02,  -4.00390625e-02],
                        [ -3.77502441e-02,  -2.79541016e-02],
                        [ -3.10974121e-02,  -2.27966309e-02],
                        [ -2.50549316e-02,  -1.95312500e-02],
                        [ -1.62353516e-02,  -1.36413574e-02],
                        [ -7.14111328e-03,  -6.65283203e-03],
                        [ -5.00488281e-03,  -5.21850586e-03],
                        [ -1.33056641e-02,  -1.30310059e-02],
                        [ -2.93884277e-02,  -2.84729004e-02],
                        [ -4.84313965e-02,  -4.79736328e-02],
                        [ -6.39953613e-02,  -6.56433105e-02],
                        [ -6.64672852e-02,  -7.13500977e-02],
                        [ -4.94689941e-02,  -5.71594238e-02],
                        [ -1.53198242e-02,  -2.40478516e-02],
                        [  3.18298340e-02,   2.42004395e-02],
                        [  9.19189453e-02,   8.65478516e-02],
                        [  1.57104492e-01,   1.53778076e-01],
                        [  2.03277588e-01,   2.00958252e-01],
                        [  2.08679199e-01,   2.06817627e-01],
                        [  1.79748535e-01,   1.78985596e-01],
                        [  1.45751953e-01,   1.47583008e-01],
                        [  1.27716064e-01,   1.33178711e-01],
                        [  1.20971680e-01,   1.29760742e-01],
                        [  1.09893799e-01,   1.20208740e-01],
                        [  9.06372070e-02,   1.00128174e-01],
                        [  7.37609863e-02,   8.06884766e-02],
                        [  6.73522949e-02,   7.08007812e-02],
                        [  6.53991699e-02,   6.50939941e-02],
                        [  5.56945801e-02,   5.16052246e-02],
                        [  3.47595215e-02,   2.71301270e-02],
                        [  1.12304688e-02,   1.06811523e-03],
                        [ -3.90625000e-03,  -1.44653320e-02],
                        [ -7.41577148e-03,  -1.57470703e-02],
                        [ -4.36401367e-03,  -8.54492188e-03],
                        [ -1.22070312e-04,   1.22070312e-04],
                        [  5.27954102e-03,   8.75854492e-03],
                        [  1.28173828e-02,   1.79138184e-02],
                        [  1.94702148e-02,   2.52075195e-02],
                        [  2.16674805e-02,   2.78625488e-02],
                        [  2.09960938e-02,   2.74963379e-02],
                        [  2.27355957e-02,   2.85644531e-02],
                        [  3.16467285e-02,   3.49731445e-02],
                        [  4.90417480e-02,   4.81567383e-02],
                        [  7.08923340e-02,   6.57348633e-02],
                        [  9.05151367e-02,   8.29467773e-02],
                        [  1.02935791e-01,   9.59167480e-02],
                        [  1.04553223e-01,   1.00433350e-01],
                        [  8.91723633e-02,   8.86230469e-02],
                        [  4.79431152e-02,   4.99572754e-02],
                        [ -2.37426758e-02,  -2.07519531e-02],
                        [ -1.14135742e-01,  -1.11114502e-01],
                        [ -1.91192627e-01,  -1.88079834e-01],
                        [ -2.22259521e-01,  -2.18444824e-01],
                        [ -2.02514648e-01,  -1.97601318e-01],
                        [ -1.57653809e-01,  -1.51916504e-01],
                        [ -1.17980957e-01,  -1.12243652e-01],
                        [ -9.55200195e-02,  -9.09118652e-02],
                        [ -8.41979980e-02,  -8.17565918e-02],
                        [ -7.36694336e-02,  -7.42797852e-02],
                        [ -6.04553223e-02,  -6.46057129e-02],
                        [ -4.94079590e-02,  -5.69152832e-02],
                        [ -4.66308594e-02,  -5.65185547e-02],
                        [ -5.04150391e-02,  -6.09436035e-02],
                        [ -5.09948730e-02,  -6.03332520e-02],
                        [ -4.23889160e-02,  -4.91027832e-02],
                        [ -3.03039551e-02,  -3.39050293e-02],
                        [ -2.38342285e-02,  -2.47192383e-02],
                        [ -2.37426758e-02,  -2.29187012e-02],
                        [ -2.58178711e-02,  -2.42919922e-02],
                        [ -2.99377441e-02,  -2.85949707e-02],
                        [ -3.96423340e-02,  -3.86962891e-02],
                        [ -5.52368164e-02,  -5.43823242e-02],
                        [ -7.35168457e-02,  -7.18383789e-02],
                        [ -9.03015137e-02,  -8.68835449e-02],
                        [ -9.92126465e-02,  -9.34753418e-02],
                        [ -8.99658203e-02,  -8.24279785e-02],
                        [ -5.40466309e-02,  -4.62036133e-02],
                        [  5.85937500e-03,   1.21459961e-02],
                        [  7.17773438e-02,   7.51953125e-02],
                        [  1.18621826e-01,   1.18957520e-01],
                        [  1.31256104e-01,   1.29486084e-01],
                        [  1.14807129e-01,   1.12365723e-01],
                        [  8.71582031e-02,   8.52661133e-02],
                        [  6.52465820e-02,   6.46362305e-02],
                        [  5.77087402e-02,   5.88684082e-02],
                        [  6.22863770e-02,   6.53991699e-02],
                        [  6.77795410e-02,   7.26318359e-02],
                        [  6.68640137e-02,   7.22656250e-02],
                        [  6.64062500e-02,   7.01599121e-02],
                        [  7.73925781e-02,   7.72094727e-02],
                        [  9.70764160e-02,   9.17968750e-02],
                        [  1.11114502e-01,   1.01837158e-01],
                        [  1.12976074e-01,   1.02600098e-01],
                        [  1.11877441e-01,   1.03424072e-01],
                        [  1.20697021e-01,   1.15386963e-01],
                        [  1.40655518e-01,   1.37237549e-01],
                        [  1.55853271e-01,   1.51885986e-01],
                        [  1.42547607e-01,   1.36657715e-01],
                        [  8.77990723e-02,   8.10852051e-02],
                        [ -8.54492188e-04,  -5.31005859e-03],
                        [ -1.05468750e-01,  -1.04644775e-01],
                        [ -2.05780029e-01,  -1.98913574e-01],
                        [ -2.75238037e-01,  -2.64465332e-01],
                        [ -2.89001465e-01,  -2.77893066e-01],
                        [ -2.48168945e-01,  -2.39746094e-01],
                        [ -1.85058594e-01,  -1.80389404e-01],
                        [ -1.36077881e-01,  -1.34552002e-01],
                        [ -1.15600586e-01,  -1.15966797e-01],
                        [ -1.14349365e-01,  -1.15722656e-01],
                        [ -1.14044189e-01,  -1.15997314e-01],
                        [ -1.03424072e-01,  -1.05499268e-01],
                        [ -8.40454102e-02,  -8.54492188e-02],
                        [ -6.28356934e-02,  -6.27746582e-02],
                        [ -4.33349609e-02,  -4.16870117e-02],
                        [ -2.76184082e-02,  -2.49328613e-02],
                        [ -2.02941895e-02,  -1.73034668e-02],
                        [ -2.35900879e-02,  -2.07214355e-02],
                        [ -3.21960449e-02,  -2.93884277e-02],
                        [ -3.92761230e-02,  -3.66210938e-02],
                        [ -4.51660156e-02,  -4.34265137e-02],
                        [ -5.31616211e-02,  -5.37719727e-02],
                        [ -5.90820312e-02,  -6.29272461e-02],
                        [ -5.24291992e-02,  -5.89904785e-02],
                        [ -2.86865234e-02,  -3.57971191e-02],
                        [  7.20214844e-03,   2.16674805e-03],
                        [  5.01708984e-02,   4.85534668e-02],
                        [  1.00372314e-01,   1.01379395e-01],
                        [  1.54144287e-01,   1.55395508e-01],
                        [  1.94213867e-01,   1.93450928e-01],
                        [  2.00897217e-01,   1.97448730e-01],
                        [  1.75201416e-01,   1.70379639e-01],
                        [  1.41662598e-01,   1.37634277e-01],
                        [  1.23138428e-01,   1.21704102e-01],
                        [  1.20544434e-01,   1.22192383e-01],
                        [  1.19293213e-01,   1.23291016e-01],
                        [  1.08001709e-01,   1.13067627e-01],
                        [  8.81652832e-02,   9.29870605e-02],
                        [  6.93969727e-02,   7.30895996e-02],
                        [  5.66406250e-02,   5.88378906e-02],
                        [  4.48608398e-02,   4.58374023e-02],
                        [  2.95104980e-02,   3.01513672e-02],
                        [  1.35192871e-02,   1.48315430e-02],
                        [ -4.88281250e-04,   2.04467773e-03],
                        [ -1.28479004e-02,  -9.76562500e-03],
                        [ -1.91345215e-02,  -1.72729492e-02],
                        [ -1.37329102e-02,  -1.49230957e-02],
                        [ -1.55639648e-03,  -6.50024414e-03],
                        [  8.05664062e-03,   5.49316406e-04],
                        [  1.51062012e-02,   7.59887695e-03],
                        [  2.29187012e-02,   1.80053711e-02],
                        [  2.53601074e-02,   2.42004395e-02],
                        [  1.57775879e-02,   1.76086426e-02],
                        [  2.96020508e-03,   5.95092773e-03],
                        [  3.60107422e-03,   6.04248047e-03],
                        [  2.23693848e-02,   2.36511230e-02],
                        [  5.00183105e-02,   5.06286621e-02],
                        [  7.64770508e-02,   7.73925781e-02],
                        [  9.64355469e-02,   9.85412598e-02],
                        [  1.05773926e-01,   1.09283447e-01],
                        [  9.84191895e-02,   1.02996826e-01],
                        [  6.44836426e-02,   6.92443848e-02],
                        [ -4.60815430e-03,  -8.54492188e-04],
                        [ -9.89685059e-02,  -9.74426270e-02],
                        [ -1.82800293e-01,  -1.84143066e-01],
                        [ -2.18811035e-01,  -2.22534180e-01],
                        [ -2.00927734e-01,  -2.05352783e-01],
                        [ -1.55395508e-01,  -1.58538818e-01],
                        [ -1.14074707e-01,  -1.14746094e-01],
                        [ -9.27734375e-02,  -9.16137695e-02],
                        [ -8.79821777e-02,  -8.70666504e-02],
                        [ -8.46557617e-02,  -8.61206055e-02],
                        [ -7.13195801e-02,  -7.58361816e-02],
                        [ -5.22460938e-02,  -5.85632324e-02],
                        [ -4.09545898e-02,  -4.67834473e-02],
                        [ -4.16564941e-02,  -4.50744629e-02],
                        [ -4.56848145e-02,  -4.62036133e-02],
                        [ -4.66308594e-02,  -4.51049805e-02],
                        [ -4.77600098e-02,  -4.54406738e-02],
                        [ -5.14526367e-02,  -4.90417480e-02],
                        [ -5.27343750e-02,  -5.02929688e-02],
                        [ -4.88891602e-02,  -4.63562012e-02],
                        [ -4.58374023e-02,  -4.35485840e-02],
                        [ -5.02319336e-02,  -4.88586426e-02],
                        [ -6.23168945e-02,  -6.22863770e-02],
                        [ -7.86132812e-02,  -7.97729492e-02],
                        [ -9.37500000e-02,  -9.54589844e-02],
                        [ -9.88159180e-02,  -1.00433350e-01],
                        [ -8.44726562e-02,  -8.56018066e-02],
                        [ -4.82177734e-02,  -4.84924316e-02],
                        [  2.86865234e-03,   4.15039062e-03],
                        [  5.53894043e-02,   5.92041016e-02],
                        [  9.49401855e-02,   1.01745605e-01],
                        [  1.12548828e-01,   1.21490479e-01],
                        [  1.10137939e-01,   1.18804932e-01],
                        [  9.94262695e-02,   1.04888916e-01],
                        [  9.26513672e-02,   9.33227539e-02],
                        [  9.39025879e-02,   9.03930664e-02],
                        [  9.85412598e-02,   9.32617188e-02],
                        [  9.98229980e-02,   9.51843262e-02],
                        [  9.68933105e-02,   9.38110352e-02],
                        [  9.70153809e-02,   9.43603516e-02],
                        [  1.06323242e-01,   1.02233887e-01],
                        [  1.20178223e-01,   1.13708496e-01],
                        [  1.27807617e-01,   1.19873047e-01],
                        [  1.26312256e-01,   1.19232178e-01],
                        [  1.23596191e-01,   1.19567871e-01],
                        [  1.26312256e-01,   1.26159668e-01],
                        [  1.27807617e-01,   1.30615234e-01],
                        [  1.10015869e-01,   1.14044189e-01],
                        [  6.11572266e-02,   6.47583008e-02],
                        [ -1.13525391e-02,  -9.03320312e-03],
                        [ -9.09118652e-02,  -9.00573730e-02],
                        [ -1.67785645e-01,  -1.68212891e-01],
                        [ -2.33886719e-01,  -2.35290527e-01],
                        [ -2.69470215e-01,  -2.71240234e-01],
                        [ -2.55279541e-01,  -2.56561279e-01],
                        [ -2.02087402e-01,  -2.01812744e-01],
                        [ -1.49383545e-01,  -1.46942139e-01],
                        [ -1.25701904e-01,  -1.21246338e-01],
                        [ -1.22619629e-01,  -1.17095947e-01],
                        [ -1.16760254e-01,  -1.11480713e-01],
                        [ -1.02050781e-01,  -9.80529785e-02],
                        [ -8.79211426e-02,  -8.55407715e-02],
                        [ -7.88879395e-02,  -7.77587891e-02],
                        [ -6.91223145e-02,  -6.85119629e-02],
                        [ -5.26123047e-02,  -5.19714355e-02],
                        [ -3.13110352e-02,  -3.03955078e-02],
                        [ -1.39770508e-02,  -1.29699707e-02],
                        [ -8.69750977e-03,  -8.11767578e-03],
                        [ -1.53808594e-02,  -1.59912109e-02],
                        [ -2.65197754e-02,  -2.89306641e-02],
                        [ -3.45764160e-02,  -3.90319824e-02],
                        [ -3.56750488e-02,  -4.18701172e-02],
                        [ -2.71301270e-02,  -3.40576172e-02],
                        [ -5.70678711e-03,  -1.21459961e-02],
                        [  3.00598145e-02,   2.51770020e-02],
                        [  7.87353516e-02,   7.60498047e-02],
                        [  1.34368896e-01,   1.33941650e-01],
                        [  1.83898926e-01,   1.85455322e-01],
                        [  2.10906982e-01,   2.13836670e-01],
                        [  2.06298828e-01,   2.09930420e-01],
                        [  1.76422119e-01,   1.80053711e-01],
                        [  1.40228271e-01,   1.43280029e-01],
                        [  1.15783691e-01,   1.18164062e-01],
                        [  1.06536865e-01,   1.08459473e-01],
                        [  1.01806641e-01,   1.03698730e-01],
                        [  9.21936035e-02,   9.40246582e-02],
                        [  7.92846680e-02,   8.05053711e-02],
                        [  6.94580078e-02,   6.91528320e-02],
                        [  6.27746582e-02,   6.02722168e-02],
                        [  5.28869629e-02,   4.86450195e-02],
                        [  3.58581543e-02,   3.13415527e-02],
                        [  1.38854980e-02,   1.08032227e-02],
                        [ -8.81958008e-03,  -9.33837891e-03],
                        [ -2.81066895e-02,  -2.61535645e-02],
                        [ -3.91540527e-02,  -3.57055664e-02],
                        [ -3.87573242e-02,  -3.49731445e-02],
                        [ -2.80456543e-02,  -2.44750977e-02],
                        [ -1.11694336e-02,  -7.87353516e-03],
                        [  6.04248047e-03,   8.97216797e-03],
                        [  1.85546875e-02,   2.05383301e-02],
                        [  2.55126953e-02,   2.56347656e-02],
                        [  2.87475586e-02,   2.63671875e-02],
                        [  2.96630859e-02,   2.49938965e-02],
                        [  3.07312012e-02,   2.48107910e-02],
                        [  3.52783203e-02,   2.96325684e-02],
                        [  4.37316895e-02,   3.94897461e-02],
                        [  5.41687012e-02,   5.19104004e-02],
                        [  6.75354004e-02,   6.73828125e-02],
                        [  8.55102539e-02,   8.73718262e-02],
                        [  1.02722168e-01,   1.06475830e-01],
                        [  1.04309082e-01,   1.09436035e-01],
                        [  7.31201172e-02,   7.86437988e-02],
                        [  2.80761719e-03,   7.47680664e-03],
                        [ -9.07897949e-02,  -8.78906250e-02],
                        [ -1.71630859e-01,  -1.70654297e-01],
                        [ -2.05139160e-01,  -2.05566406e-01],
                        [ -1.85760498e-01,  -1.86737061e-01],
                        [ -1.41571045e-01,  -1.42791748e-01],
                        [ -1.07971191e-01,  -1.09680176e-01],
                        [ -9.70764160e-02,  -9.98229980e-02],
                        [ -9.47570801e-02,  -9.86633301e-02],
                        [ -8.32214355e-02,  -8.76770020e-02],
                        [ -6.24389648e-02,  -6.63146973e-02],
                        [ -4.73022461e-02,  -4.97436523e-02],
                        [ -4.65393066e-02,  -4.73632812e-02],
                        [ -5.29174805e-02,  -5.26733398e-02],
                        [ -5.59387207e-02,  -5.54809570e-02],
                        [ -5.30700684e-02,  -5.29174805e-02],
                        [ -4.64477539e-02,  -4.65393066e-02],
                        [ -4.01000977e-02,  -3.98559570e-02],
                        [ -3.99780273e-02,  -3.87268066e-02],
                        [ -4.77600098e-02,  -4.51049805e-02],
                        [ -5.86853027e-02,  -5.46875000e-02],
                        [ -7.08923340e-02,  -6.62536621e-02],
                        [ -8.64257812e-02,  -8.21228027e-02],
                        [ -9.91516113e-02,  -9.64355469e-02],
                        [ -9.63745117e-02,  -9.61303711e-02],
                        [ -7.39440918e-02,  -7.62939453e-02],
                        [ -3.77197266e-02,  -4.18090820e-02],
                        [  8.88061523e-03,   4.60815430e-03],
                        [  6.43005371e-02,   6.15844727e-02],
                        [  1.16302490e-01,   1.16088867e-01],
                        [  1.44226074e-01,   1.46240234e-01],
                        [  1.39556885e-01,   1.42547607e-01],
                        [  1.15997314e-01,   1.18499756e-01],
                        [  9.33227539e-02,   9.44519043e-02],
                        [  7.94677734e-02,   7.94067383e-02],
                        [  7.35168457e-02,   7.31811523e-02],
                        [  7.48901367e-02,   7.53173828e-02],
                        [  8.23364258e-02,   8.38317871e-02],
                        [  9.10644531e-02,   9.30786133e-02],
                        [  9.85412598e-02,   9.98535156e-02],
                        [  1.08306885e-01,   1.07696533e-01],
                        [  1.24755859e-01,   1.21673584e-01],
                        [  1.45263672e-01,   1.40167236e-01],
                        [  1.60858154e-01,   1.55059814e-01],
                        [  1.64276123e-01,   1.59484863e-01],
                        [  1.53564453e-01,   1.51031494e-01],
                        [  1.25762939e-01,   1.25793457e-01],
                        [  7.36389160e-02,   7.54699707e-02],
                        [ -6.34765625e-03,  -4.08935547e-03],
                        [ -1.05224609e-01,  -1.03759766e-01],
                        [ -2.03460693e-01,  -2.03186035e-01],
                        [ -2.77221680e-01,  -2.77740479e-01],
                        [ -3.04351807e-01,  -3.04931641e-01],
                        [ -2.77404785e-01,  -2.77526855e-01],
                        [ -2.17376709e-01,  -2.17041016e-01],
                        [ -1.62109375e-01,  -1.61529541e-01],
                        [ -1.31195068e-01,  -1.30340576e-01],
                        [ -1.14715576e-01,  -1.13250732e-01],
                        [ -1.00036621e-01,  -9.74731445e-02],
                        [ -8.99963379e-02,  -8.63342285e-02],
                        [ -8.83789062e-02,  -8.41674805e-02],
                        [ -8.68835449e-02,  -8.31298828e-02],
                        [ -7.71179199e-02,  -7.45544434e-02],
                        [ -6.12792969e-02,  -6.00280762e-02],
                        [ -4.43420410e-02,  -4.40979004e-02],
                        [ -2.68554688e-02,  -2.72827148e-02],
                        [ -1.07727051e-02,  -1.19018555e-02],
                        [ -2.89916992e-03,  -5.09643555e-03],
                        [ -6.71386719e-03,  -1.01928711e-02],
                        [ -1.69677734e-02,  -2.14233398e-02],
                        [ -2.43225098e-02,  -2.89611816e-02],
                        [ -1.90734863e-02,  -2.29797363e-02],
                        [  6.83593750e-03,   4.02832031e-03],
                        [  5.32531738e-02,   5.15441895e-02],
                        [  1.09344482e-01,   1.08489990e-01],
                        [  1.60583496e-01,   1.60644531e-01],
                        [  1.94305420e-01,   1.95526123e-01],
                        [  2.01385498e-01,   2.03979492e-01],
                        [  1.84631348e-01,   1.88201904e-01],
                        [  1.61682129e-01,   1.65283203e-01],
                        [  1.45904541e-01,   1.48468018e-01],
                        [  1.30554199e-01,   1.31469727e-01],
                        [  1.05865479e-01,   1.05468750e-01],
                        [  8.04443359e-02,   7.95288086e-02],
                        [  6.75354004e-02,   6.68640137e-02],
                        [  6.35986328e-02,   6.35375977e-02],
                        [  5.76782227e-02,   5.80139160e-02],
                        [  4.80957031e-02,   4.84008789e-02],
                        [  3.79638672e-02,   3.79333496e-02],
                        [  2.60620117e-02,   2.56347656e-02],
                        [  1.07727051e-02,   9.97924805e-03],
                        [ -5.00488281e-03,  -6.25610352e-03],
                        [ -1.64489746e-02,  -1.81579590e-02],
                        [ -2.10571289e-02,  -2.29187012e-02],
                        [ -1.97753906e-02,  -2.12097168e-02],
                        [ -1.39770508e-02,  -1.41601562e-02],
                        [ -3.47900391e-03,  -1.95312500e-03],
                        [  8.17871094e-03,   1.11999512e-02],
                        [  1.34582520e-02,   1.70898438e-02],
                        [  1.22070312e-02,   1.52282715e-02],
                        [  1.47094727e-02,   1.62658691e-02],
                        [  2.53295898e-02,   2.51770020e-02],
                        [  3.41491699e-02,   3.27148438e-02],
                        [  3.40576172e-02,   3.19519043e-02],
                        [  3.32946777e-02,   3.11279297e-02],
                        [  4.21447754e-02,   4.02526855e-02],
                        [  5.84716797e-02,   5.70373535e-02],
                        [  7.40661621e-02,   7.30590820e-02],
                        [  8.42285156e-02,   8.36486816e-02],
                        [  8.61206055e-02,   8.59985352e-02],
                        [  7.43713379e-02,   7.47375488e-02],
                        [  4.07714844e-02,   4.17480469e-02],
                        [ -2.04772949e-02,  -1.88293457e-02],
                        [ -1.00616455e-01,  -9.83581543e-02],
                        [ -1.70806885e-01,  -1.68334961e-01],
                        [ -1.99188232e-01,  -1.97082520e-01],
                        [ -1.77124023e-01,  -1.76086426e-01],
                        [ -1.27258301e-01,  -1.27624512e-01],
                        [ -8.54492188e-02,  -8.70361328e-02],
                        [ -7.13806152e-02,  -7.36083984e-02],
                        [ -7.47070312e-02,  -7.68737793e-02],
                        [ -7.39440918e-02,  -7.55920410e-02],
                        [ -6.57043457e-02,  -6.67114258e-02],
                        [ -6.43615723e-02,  -6.48498535e-02],
                        [ -7.66601562e-02,  -7.68737793e-02],
                        [ -9.29870605e-02,  -9.31091309e-02],
                        [ -1.02844238e-01,  -1.03057861e-01],
                        [ -1.02874756e-01,  -1.03393555e-01],
                        [ -9.01489258e-02,  -9.10339355e-02],
                        [ -6.60400391e-02,  -6.71691895e-02],
                        [ -4.51354980e-02,  -4.60510254e-02],
                        [ -4.23889160e-02,  -4.25415039e-02],
                        [ -5.44738770e-02,  -5.34973145e-02],
                        [ -6.69860840e-02,  -6.50634766e-02],
                        [ -7.30895996e-02,  -7.07397461e-02],
                        [ -7.24182129e-02,  -7.01599121e-02],
                        [ -6.12487793e-02,  -5.93261719e-02],
                        [ -3.52783203e-02,  -3.35998535e-02],
                        [  2.04467773e-03,   3.66210938e-03],
                        [  4.15039062e-02,   4.30297852e-02],
                        [  7.62329102e-02,   7.73315430e-02],
                        [  1.02813721e-01,   1.03027344e-01],
                        [  1.16394043e-01,   1.15478516e-01],
                        [  1.12060547e-01,   1.10260010e-01],
                        [  9.41772461e-02,   9.18579102e-02],
                        [  7.74536133e-02,   7.50122070e-02],
                        [  7.46154785e-02,   7.22351074e-02],
                        [  8.50524902e-02,   8.28857422e-02],
                        [  9.88159180e-02,   9.71374512e-02],
                        [  1.08001709e-01,   1.07238770e-01],
                        [  1.13128662e-01,   1.13616943e-01],
                        [  1.21368408e-01,   1.23046875e-01],
                        [  1.39984131e-01,   1.42364502e-01],
                        [  1.67755127e-01,   1.70074463e-01],
                        [  1.91345215e-01,   1.92932129e-01],
                        [  1.94396973e-01,   1.95068359e-01],
                        [  1.70410156e-01,   1.70288086e-01],
                        [  1.22467041e-01,   1.21856689e-01],
                        [  5.28259277e-02,   5.18188477e-02],
                        [ -3.98254395e-02,  -4.11987305e-02],
                        [ -1.49047852e-01,  -1.50726318e-01],
                        [ -2.51556396e-01,  -2.53234863e-01],
                        [ -3.15551758e-01,  -3.16802979e-01],
                        [ -3.22265625e-01,  -3.22784424e-01],
                        [ -2.79266357e-01,  -2.79113770e-01],
                        [ -2.15087891e-01,  -2.14660645e-01],
                        [ -1.59973145e-01,  -1.59637451e-01],
                        [ -1.26190186e-01,  -1.26007080e-01],
                        [ -1.04858398e-01,  -1.04461670e-01],
                        [ -8.37402344e-02,  -8.26721191e-02],
                        [ -6.39038086e-02,  -6.19812012e-02],
                        [ -5.37414551e-02,  -5.12084961e-02],
                        [ -5.30700684e-02,  -5.05676270e-02],
                        [ -5.33142090e-02,  -5.14526367e-02],
                        [ -4.91943359e-02,  -4.82482910e-02],
                        [ -4.24194336e-02,  -4.23278809e-02],
                        [ -3.63159180e-02,  -3.68041992e-02],
                        [ -3.27453613e-02,  -3.35998535e-02],
                        [ -3.32336426e-02,  -3.44543457e-02],
                        [ -3.69567871e-02,  -3.86047363e-02],
                        [ -3.65600586e-02,  -3.86047363e-02],
                        [ -1.92565918e-02,  -2.15759277e-02],
                        [  2.29797363e-02,   2.06909180e-02],
                        [  8.34045410e-02,   8.14819336e-02],
                        [  1.43432617e-01,   1.42150879e-01],
                        [  1.87438965e-01,   1.87072754e-01],
                        [  2.10754395e-01,   2.11425781e-01],
                        [  2.13592529e-01,   2.15270996e-01],
                        [  1.97296143e-01,   1.99768066e-01],
                        [  1.69097900e-01,   1.71844482e-01],
                        [  1.42181396e-01,   1.44622803e-01],
                        [  1.25213623e-01,   1.26861572e-01],
                        [  1.15295410e-01,   1.15905762e-01],
                        [  1.03759766e-01,   1.03363037e-01],
                        [  8.70361328e-02,   8.58764648e-02],
                        [  6.96105957e-02,   6.80236816e-02],
                        [  5.57861328e-02,   5.40466309e-02],
                        [  4.31518555e-02,   4.15344238e-02],
                        [  2.93884277e-02,   2.81677246e-02],
                        [  1.95922852e-02,   1.88903809e-02],
                        [  1.75170898e-02,   1.73034668e-02],
                        [  1.60522461e-02,   1.62963867e-02],
                        [  7.72094727e-03,   8.20922852e-03],
                        [ -3.75366211e-03,  -3.11279297e-03],
                        [ -1.19018555e-02,  -1.11999512e-02],
                        [ -1.80664062e-02,  -1.73339844e-02],
                        [ -2.36206055e-02,  -2.29187012e-02],
                        [ -2.38342285e-02,  -2.31323242e-02],
                        [ -1.65405273e-02,  -1.58996582e-02],
                        [ -7.90405273e-03,  -7.35473633e-03],
                        [ -3.87573242e-03,  -3.38745117e-03],
                        [ -2.07519531e-03,  -1.73950195e-03],
                        [  3.38745117e-03,   3.44848633e-03],
                        [  1.35498047e-02,   1.32141113e-02],
                        [  2.52685547e-02,   2.44750977e-02],
                        [  3.81774902e-02,   3.71093750e-02],
                        [  5.54504395e-02,   5.44128418e-02],
                        [  7.59582520e-02,   7.52563477e-02],
                        [  9.25598145e-02,   9.22851562e-02],
                        [  1.01196289e-01,   1.01257324e-01],
                        [  1.05224609e-01,   1.05377197e-01],
                        [  1.04980469e-01,   1.05133057e-01],
                        [  8.88977051e-02,   8.90808105e-02],
                        [  4.22973633e-02,   4.26025391e-02],
                        [ -3.46069336e-02,  -3.40881348e-02],
                        [ -1.20635986e-01,  -1.20086670e-01],
                        [ -1.85028076e-01,  -1.84661865e-01],
                        [ -2.05169678e-01,  -2.05139160e-01],
                        [ -1.80694580e-01,  -1.80938721e-01],
                        [ -1.34155273e-01,  -1.34490967e-01],
                        [ -9.52453613e-02,  -9.54895020e-02],
                        [ -7.89184570e-02,  -7.89489746e-02],
                        [ -7.74230957e-02,  -7.73925781e-02],
                        [ -7.51953125e-02,  -7.52563477e-02],
                        [ -6.95190430e-02,  -6.97937012e-02],
                        [ -7.06176758e-02,  -7.09838867e-02],
                        [ -8.31604004e-02,  -8.33740234e-02],
                        [ -9.83886719e-02,  -9.83276367e-02],
                        [ -1.04339600e-01,  -1.03973389e-01],
                        [ -9.54284668e-02,  -9.49707031e-02],
                        [ -7.51037598e-02,  -7.47680664e-02],
                        [ -5.51147461e-02,  -5.50842285e-02],
                        [ -4.76989746e-02,  -4.80041504e-02],
                        [ -5.34973145e-02,  -5.40466309e-02],
                        [ -6.13098145e-02,  -6.19506836e-02],
                        [ -6.14929199e-02,  -6.20422363e-02],
                        [ -5.51452637e-02,  -5.54199219e-02],
                        [ -4.71496582e-02,  -4.70581055e-02],
                        [ -3.46679688e-02,  -3.42102051e-02],
                        [ -9.42993164e-03,  -8.69750977e-03],
                        [  2.88696289e-02,   2.96325684e-02],
                        [  6.89697266e-02,   6.96105957e-02],
                        [  9.94873047e-02,   9.98840332e-02],
                        [  1.16729736e-01,   1.16943359e-01],
                        [  1.21063232e-01,   1.21215820e-01],
                        [  1.13677979e-01,   1.13891602e-01],
                        [  1.00158691e-01,   1.00433350e-01],
                        [  9.02709961e-02,   9.04846191e-02],
                        [  9.00573730e-02,   8.99353027e-02],
                        [  9.72290039e-02,   9.67102051e-02],
                        [  1.06445312e-01,   1.05560303e-01],
                        [  1.15905762e-01,   1.14898682e-01],
                        [  1.28814697e-01,   1.27899170e-01],
                        [  1.49047852e-01,   1.48468018e-01],
                        [  1.73522949e-01,   1.73339844e-01],
                        [  1.90002441e-01,   1.90155029e-01],
                        [  1.85852051e-01,   1.86187744e-01],
                        [  1.55090332e-01,   1.55426025e-01],
                        [  9.40246582e-02,   9.42382812e-02],
                        [  1.43432617e-03,   1.52587891e-03],
                        [ -1.11450195e-01,  -1.11419678e-01],
                        [ -2.19024658e-01,  -2.18963623e-01],
                        [ -2.93792725e-01,  -2.93609619e-01],
                        [ -3.15643311e-01,  -3.15368652e-01],
                        [ -2.78564453e-01,  -2.78259277e-01],
                        [ -2.04223633e-01,  -2.04040527e-01],
                        [ -1.39038086e-01,  -1.38977051e-01],
                        [ -1.14654541e-01,  -1.14685059e-01],
                        [ -1.17065430e-01,  -1.17156982e-01],
                        [ -1.13159180e-01,  -1.13189697e-01],
                        [ -9.52758789e-02,  -9.52148438e-02],
                        [ -7.93762207e-02,  -7.92236328e-02],
                        [ -7.42797852e-02,  -7.41271973e-02],
                        [ -7.35168457e-02,  -7.34252930e-02],
                        [ -6.79016113e-02,  -6.78710938e-02],
                        [ -5.27038574e-02,  -5.27648926e-02],
                        [ -3.08227539e-02,  -3.09448242e-02],
                        [ -1.37329102e-02,  -1.38854980e-02],
                        [ -1.16577148e-02,  -1.17492676e-02],
                        [ -2.01110840e-02,  -2.01416016e-02],
                        [ -2.24609375e-02,  -2.24304199e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  2.96325684e-02,   2.95104980e-02],
                        [  7.79724121e-02,   7.76977539e-02],
                        [  1.30523682e-01,   1.30157471e-01],
                        [  1.76361084e-01,   1.76025391e-01],
                        [  2.01324463e-01,   2.01202393e-01],
                        [  1.95373535e-01,   1.95526123e-01],
                        [  1.64886475e-01,   1.65222168e-01],
                        [  1.32537842e-01,   1.32965088e-01],
                        [  1.16241455e-01,   1.16607666e-01],
                        [  1.12915039e-01,   1.13159180e-01],
                        [  1.09741211e-01,   1.09832764e-01],
                        [  1.01776123e-01,   1.01806641e-01],
                        [  9.11254883e-02,   9.11254883e-02],
                        [  7.91931152e-02,   7.91625977e-02],
                        [  6.70776367e-02,   6.69860840e-02],
                        [  5.51452637e-02,   5.50231934e-02],
                        [  4.05273438e-02,   4.03747559e-02],
                        [  2.16064453e-02,   2.14843750e-02],
                        [  4.05883789e-03,   3.96728516e-03],
                        [ -5.03540039e-03,  -5.12695312e-03],
                        [ -6.98852539e-03,  -7.08007812e-03],
                        [ -9.21630859e-03,  -9.30786133e-03],
                        [ -1.58081055e-02,  -1.58386230e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.40576172e-02,  -3.39965820e-02],
                        [ -3.54309082e-02,  -3.53393555e-02],
                        [ -2.57873535e-02,  -2.56958008e-02],
                        [ -1.11694336e-02,  -1.11389160e-02],
                        [ -1.70898438e-03,  -1.67846680e-03],
                        [  3.66210938e-04,   3.96728516e-04],
                        [  2.44140625e-04,   3.35693359e-04],
                        [  2.96020508e-03,   3.05175781e-03],
                        [  8.57543945e-03,   8.66699219e-03],
                        [  1.28173828e-02,   1.28479004e-02],
                        [  1.48315430e-02,   1.48010254e-02],
                        [  2.26745605e-02,   2.26135254e-02],
                        [  4.19311523e-02,   4.18701172e-02],
                        [  6.43615723e-02,   6.43310547e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  9.48181152e-02,   9.48181152e-02],
                        [  8.67309570e-02,   8.67004395e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -7.70263672e-02,  -7.70263672e-02],
                        [ -1.47033691e-01,  -1.47064209e-01],
                        [ -1.90917969e-01,  -1.90948486e-01],
                        [ -1.94763184e-01,  -1.94793701e-01],
                        [ -1.68334961e-01,  -1.68365479e-01],
                        [ -1.36444092e-01,  -1.36474609e-01],
                        [ -1.15051270e-01,  -1.15051270e-01],
                        [ -1.03332520e-01,  -1.03302002e-01],
                        [ -9.46350098e-02,  -9.46044922e-02],
                        [ -8.58459473e-02,  -8.58154297e-02],
                        [ -7.80944824e-02,  -7.80639648e-02],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -7.83081055e-02,  -7.82775879e-02],
                        [ -7.97424316e-02,  -7.97119141e-02],
                        [ -7.05871582e-02,  -7.05566406e-02],
                        [ -5.44738770e-02,  -5.44433594e-02],
                        [ -4.44946289e-02,  -4.44641113e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -5.40466309e-02,  -5.40771484e-02],
                        [ -6.05163574e-02,  -6.05468750e-02],
                        [ -6.47277832e-02,  -6.47583008e-02],
                        [ -6.80847168e-02,  -6.81152344e-02],
                        [ -6.89392090e-02,  -6.89697266e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [  3.81469727e-03,   3.84521484e-03],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.10351562e-01,   1.10382080e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.27227783e-01,   1.27258301e-01],
                        [  1.28601074e-01,   1.28631592e-01],
                        [  1.21704102e-01,   1.21734619e-01],
                        [  1.13311768e-01,   1.13311768e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.21185303e-01,   1.21185303e-01],
                        [  1.42456055e-01,   1.42425537e-01],
                        [  1.65008545e-01,   1.65008545e-01],
                        [  1.76361084e-01,   1.76361084e-01],
                        [  1.69250488e-01,   1.69250488e-01],
                        [  1.37451172e-01,   1.37451172e-01],
                        [  7.23571777e-02,   7.23571777e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -1.43432617e-01,  -1.43432617e-01],
                        [ -2.48779297e-01,  -2.48779297e-01],
                        [ -3.10760498e-01,  -3.10760498e-01],
                        [ -3.07678223e-01,  -3.07678223e-01],
                        [ -2.47955322e-01,  -2.47955322e-01],
                        [ -1.73492432e-01,  -1.73492432e-01],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -1.18194580e-01,  -1.18194580e-01],
                        [ -1.21398926e-01,  -1.21398926e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.01867676e-01,  -1.01867676e-01],
                        [ -8.71276855e-02,  -8.71276855e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.52343750e-01,   1.52343750e-01],
                        [  1.99554443e-01,   1.99554443e-01],
                        [  2.18292236e-01,   2.18292236e-01],
                        [  2.11059570e-01,   2.11059570e-01],
                        [  1.91467285e-01,   1.91467285e-01],
                        [  1.67999268e-01,   1.67999268e-01],
                        [  1.42456055e-01,   1.42456055e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  7.26318359e-03,   7.29370117e-03],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  9.30480957e-02,   9.30786133e-02],
                        [  1.06048584e-01,   1.06048584e-01],
                        [  1.09619141e-01,   1.09619141e-01],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -1.36016846e-01,  -1.36016846e-01],
                        [ -1.96075439e-01,  -1.96075439e-01],
                        [ -2.13714600e-01,  -2.13714600e-01],
                        [ -1.93237305e-01,  -1.93237305e-01],
                        [ -1.55303955e-01,  -1.55303955e-01],
                        [ -1.21032715e-01,  -1.21032715e-01],
                        [ -9.83886719e-02,  -9.83886719e-02],
                        [ -8.37097168e-02,  -8.37097168e-02],
                        [ -7.26013184e-02,  -7.26318359e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -7.52258301e-02,  -7.52258301e-02],
                        [ -7.67211914e-02,  -7.67211914e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -7.27539062e-02,  -7.27539062e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -7.19909668e-02,  -7.20214844e-02],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.21490479e-01,   1.21490479e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.48681641e-01,   1.48681641e-01],
                        [  1.67022705e-01,   1.67022705e-01],
                        [  1.81701660e-01,   1.81701660e-01],
                        [  1.87530518e-01,   1.87530518e-01],
                        [  1.78283691e-01,   1.78283691e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  6.69555664e-02,   6.69555664e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -1.56158447e-01,  -1.56158447e-01],
                        [ -2.53997803e-01,  -2.53997803e-01],
                        [ -3.11676025e-01,  -3.11676025e-01],
                        [ -3.14605713e-01,  -3.14605713e-01],
                        [ -2.65563965e-01,  -2.65563965e-01],
                        [ -1.92565918e-01,  -1.92565918e-01],
                        [ -1.32476807e-01,  -1.32476807e-01],
                        [ -1.02935791e-01,  -1.02935791e-01],
                        [ -9.49401855e-02,  -9.49401855e-02],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -7.84301758e-02,  -7.84301758e-02],
                        [ -7.51037598e-02,  -7.51037598e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -7.39746094e-02,  -7.39746094e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -8.33129883e-02,  -8.33129883e-02],
                        [ -7.67517090e-02,  -7.67517090e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  7.61413574e-02,   7.61413574e-02],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.76147461e-01,   1.76147461e-01],
                        [  2.01599121e-01,   2.01599121e-01],
                        [  1.98577881e-01,   1.98577881e-01],
                        [  1.74011230e-01,   1.74011230e-01],
                        [  1.47705078e-01,   1.47705078e-01],
                        [  1.31500244e-01,   1.31500244e-01],
                        [  1.21459961e-01,   1.21429443e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.05590820e-01,   1.05590820e-01],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  5.64575195e-03,   5.67626953e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  8.17565918e-02,   8.17260742e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -1.08245850e-01,  -1.08215332e-01],
                        [ -1.64733887e-01,  -1.64703369e-01],
                        [ -1.85882568e-01,  -1.85882568e-01],
                        [ -1.69464111e-01,  -1.69464111e-01],
                        [ -1.32598877e-01,  -1.32598877e-01],
                        [ -1.01989746e-01,  -1.01989746e-01],
                        [ -9.17663574e-02,  -9.17663574e-02],
                        [ -9.47265625e-02,  -9.47265625e-02],
                        [ -9.66796875e-02,  -9.66796875e-02],
                        [ -9.16137695e-02,  -9.16442871e-02],
                        [ -8.41674805e-02,  -8.41674805e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -9.14001465e-02,  -9.14001465e-02],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -8.60900879e-02,  -8.60900879e-02],
                        [ -6.87255859e-02,  -6.87255859e-02],
                        [ -5.80749512e-02,  -5.81054688e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -5.42602539e-02,  -5.42907715e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  5.60913086e-02,   5.61218262e-02],
                        [  8.66088867e-02,   8.66394043e-02],
                        [  1.07177734e-01,   1.07147217e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.18713379e-01,   1.18713379e-01],
                        [  1.30004883e-01,   1.29974365e-01],
                        [  1.46636963e-01,   1.46636963e-01],
                        [  1.67175293e-01,   1.67175293e-01],
                        [  1.84265137e-01,   1.84265137e-01],
                        [  1.91925049e-01,   1.91925049e-01],
                        [  1.87194824e-01,   1.87194824e-01],
                        [  1.62902832e-01,   1.62902832e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  2.23693848e-02,   2.23693848e-02],
                        [ -8.62426758e-02,  -8.62121582e-02],
                        [ -1.97723389e-01,  -1.97723389e-01],
                        [ -2.83935547e-01,  -2.83935547e-01],
                        [ -3.16009521e-01,  -3.16009521e-01],
                        [ -2.86529541e-01,  -2.86560059e-01],
                        [ -2.19757080e-01,  -2.19757080e-01],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -1.12213135e-01,  -1.12213135e-01],
                        [ -9.56115723e-02,  -9.56115723e-02],
                        [ -8.79821777e-02,  -8.79821777e-02],
                        [ -7.69042969e-02,  -7.69042969e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -4.25720215e-02,  -4.26025391e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  1.05834961e-01,   1.05804443e-01],
                        [  1.57867432e-01,   1.57867432e-01],
                        [  1.89941406e-01,   1.89941406e-01],
                        [  1.93389893e-01,   1.93389893e-01],
                        [  1.76422119e-01,   1.76422119e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.37878418e-01,   1.37878418e-01],
                        [  1.25061035e-01,   1.25030518e-01],
                        [  1.13891602e-01,   1.13922119e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  9.95178223e-02,   9.94873047e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.40551758e-02,   9.40856934e-02],
                        [  8.62426758e-02,   8.62121582e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -7.69042969e-03,  -7.72094727e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -8.39233398e-03,  -8.42285156e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.43432617e-03,  -1.40380859e-03],
                        [  4.27246094e-03,   4.24194336e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.31835938e-02,   1.31530762e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -8.26110840e-02,  -8.26110840e-02],
                        [ -1.47033691e-01,  -1.47033691e-01],
                        [ -1.79809570e-01,  -1.79779053e-01],
                        [ -1.74865723e-01,  -1.74865723e-01],
                        [ -1.49627686e-01,  -1.49658203e-01],
                        [ -1.25244141e-01,  -1.25244141e-01],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -1.11511230e-01,  -1.11541748e-01],
                        [ -1.18774414e-01,  -1.18774414e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -1.09222412e-01,  -1.09222412e-01],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -9.74731445e-02,  -9.74731445e-02],
                        [ -1.03698730e-01,  -1.03698730e-01],
                        [ -9.94262695e-02,  -9.94567871e-02],
                        [ -7.99560547e-02,  -7.99255371e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.07006836e-02,  -3.07312012e-02],
                        [ -2.92053223e-02,  -2.91748047e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.21862793e-02,  -2.21557617e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  5.24291992e-02,   5.23986816e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  1.00891113e-01,   1.00921631e-01],
                        [  1.03546143e-01,   1.03546143e-01],
                        [  1.03759766e-01,   1.03729248e-01],
                        [  1.02203369e-01,   1.02233887e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  1.10382080e-01,   1.10351562e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  1.49047852e-01,   1.49078369e-01],
                        [  1.71356201e-01,   1.71325684e-01],
                        [  1.97204590e-01,   1.97204590e-01],
                        [  2.19818115e-01,   2.19848633e-01],
                        [  2.22625732e-01,   2.22625732e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  2.58178711e-02,   2.58178711e-02],
                        [ -8.36486816e-02,  -8.36791992e-02],
                        [ -1.93298340e-01,  -1.93298340e-01],
                        [ -2.85125732e-01,  -2.85125732e-01],
                        [ -3.31054688e-01,  -3.31054688e-01],
                        [ -3.10882568e-01,  -3.10913086e-01],
                        [ -2.41119385e-01,  -2.41119385e-01],
                        [ -1.68853760e-01,  -1.68823242e-01],
                        [ -1.28204346e-01,  -1.28204346e-01],
                        [ -1.14990234e-01,  -1.14990234e-01],
                        [ -1.07116699e-01,  -1.07086182e-01],
                        [ -9.38415527e-02,  -9.38415527e-02],
                        [ -7.99560547e-02,  -7.99865723e-02],
                        [ -7.37915039e-02,  -7.37915039e-02],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -8.48693848e-02,  -8.48693848e-02],
                        [ -8.67004395e-02,  -8.67004395e-02],
                        [ -7.98645020e-02,  -7.98339844e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [  2.47497559e-02,   2.47802734e-02],
                        [  7.68127441e-02,   7.67822266e-02],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.79260254e-01,   1.79290771e-01],
                        [  2.08282471e-01,   2.08282471e-01],
                        [  2.08343506e-01,   2.08312988e-01],
                        [  1.84906006e-01,   1.84936523e-01],
                        [  1.56951904e-01,   1.56951904e-01],
                        [  1.38977051e-01,   1.38977051e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.22406006e-01,   1.22436523e-01],
                        [  1.07757568e-01,   1.07727051e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  8.01696777e-02,   8.02001953e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  5.99670410e-02,   5.99975586e-02],
                        [  4.28466797e-02,   4.28771973e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  6.56127930e-03,   6.59179688e-03],
                        [ -1.37329102e-03,  -1.40380859e-03],
                        [ -1.23291016e-02,  -1.23596191e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.83508301e-02,  -2.83813477e-02],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -1.40075684e-02,  -1.39770508e-02],
                        [ -7.56835938e-03,  -7.59887695e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.12915039e-03,  -1.09863281e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -1.43432617e-02,  -1.43737793e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.79235840e-02,  -2.79541016e-02],
                        [ -1.50451660e-02,  -1.50756836e-02],
                        [ -1.52587891e-03,  -1.49536133e-03],
                        [  9.46044922e-03,   9.42993164e-03],
                        [  1.92565918e-02,   1.92260742e-02],
                        [  2.74658203e-02,   2.74963379e-02],
                        [  3.68957520e-02,   3.69262695e-02],
                        [  5.57556152e-02,   5.57250977e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  1.05682373e-01,   1.05712891e-01],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.10290527e-01,   1.10260010e-01],
                        [  9.26818848e-02,   9.27124023e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [ -2.56347656e-02,  -2.56652832e-02],
                        [ -1.11541748e-01,  -1.11541748e-01],
                        [ -1.83380127e-01,  -1.83380127e-01],
                        [ -2.20642090e-01,  -2.20672607e-01],
                        [ -2.16247559e-01,  -2.16247559e-01],
                        [ -1.81457520e-01,  -1.81457520e-01],
                        [ -1.40167236e-01,  -1.40167236e-01],
                        [ -1.11206055e-01,  -1.11236572e-01],
                        [ -9.74121094e-02,  -9.73815918e-02],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -9.62829590e-02,  -9.63134766e-02],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.15234375e-01,  -1.15203857e-01],
                        [ -1.19873047e-01,  -1.19873047e-01],
                        [ -1.15173340e-01,  -1.15203857e-01],
                        [ -9.87548828e-02,  -9.87243652e-02],
                        [ -7.18688965e-02,  -7.18383789e-02],
                        [ -4.06799316e-02,  -4.07104492e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.96533203e-02,  -1.96228027e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  1.07238770e-01,   1.07269287e-01],
                        [  1.09680176e-01,   1.09649658e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.15905762e-01,   1.15875244e-01],
                        [  1.36749268e-01,   1.36749268e-01],
                        [  1.65252686e-01,   1.65252686e-01],
                        [  1.91833496e-01,   1.91802979e-01],
                        [  2.10906982e-01,   2.10906982e-01],
                        [  2.20397949e-01,   2.20397949e-01],
                        [  2.12585449e-01,   2.12554932e-01],
                        [  1.77032471e-01,   1.77032471e-01],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  2.05993652e-02,   2.05993652e-02],
                        [ -8.94470215e-02,  -8.94775391e-02],
                        [ -2.04040527e-01,  -2.04010010e-01],
                        [ -2.92083740e-01,  -2.92083740e-01],
                        [ -3.21685791e-01,  -3.21685791e-01],
                        [ -2.86987305e-01,  -2.86987305e-01],
                        [ -2.16674805e-01,  -2.16644287e-01],
                        [ -1.53167725e-01,  -1.53167725e-01],
                        [ -1.21276855e-01,  -1.21307373e-01],
                        [ -1.15264893e-01,  -1.15234375e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.14685059e-01,  -1.14685059e-01],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -1.10473633e-01,  -1.10443115e-01],
                        [ -1.02264404e-01,  -1.02294922e-01],
                        [ -8.79821777e-02,  -8.79821777e-02],
                        [ -7.38830566e-02,  -7.38525391e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -5.21545410e-02,  -5.21850586e-02],
                        [ -2.94799805e-02,  -2.94494629e-02],
                        [  1.06201172e-02,   1.06506348e-02],
                        [  6.64672852e-02,   6.64367676e-02],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.85852051e-01,   1.85882568e-01],
                        [  2.21130371e-01,   2.21130371e-01],
                        [  2.26898193e-01,   2.26867676e-01],
                        [  2.06176758e-01,   2.06207275e-01],
                        [  1.71173096e-01,   1.71173096e-01],
                        [  1.38183594e-01,   1.38153076e-01],
                        [  1.19842529e-01,   1.19842529e-01],
                        [  1.15600586e-01,   1.15631104e-01],
                        [  1.12670898e-01,   1.12640381e-01],
                        [  1.02081299e-01,   1.02050781e-01],
                        [  8.95690918e-02,   8.95996094e-02],
                        [  8.46557617e-02,   8.46862793e-02],
                        [  8.56018066e-02,   8.55712891e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  7.55310059e-02,   7.55615234e-02],
                        [  5.93872070e-02,   5.93566895e-02],
                        [  3.39965820e-02,   3.39660645e-02],
                        [  6.50024414e-03,   6.53076172e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.07421875e-02,  -1.07727051e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.91955566e-02,  -1.91650391e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.73229980e-02,  -3.73535156e-02],
                        [ -3.36608887e-02,  -3.36303711e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -2.25524902e-02,  -2.25219727e-02],
                        [ -1.66320801e-02,  -1.66015625e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -8.08715820e-03,  -8.05664062e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -5.15747070e-03,  -5.18798828e-03],
                        [  1.25122070e-03,   1.28173828e-03],
                        [  1.01928711e-02,   1.02233887e-02],
                        [  2.67639160e-02,   2.67333984e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  8.06274414e-02,   8.06579590e-02],
                        [  1.00616455e-01,   1.00585938e-01],
                        [  1.10290527e-01,   1.10260010e-01],
                        [  1.10656738e-01,   1.10687256e-01],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  6.07299805e-02,   6.06994629e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -7.43713379e-02,  -7.43408203e-02],
                        [ -1.45568848e-01,  -1.45599365e-01],
                        [ -1.93634033e-01,  -1.93664551e-01],
                        [ -2.05444336e-01,  -2.05413818e-01],
                        [ -1.84143066e-01,  -1.84143066e-01],
                        [ -1.49688721e-01,  -1.49719238e-01],
                        [ -1.23931885e-01,  -1.23901367e-01],
                        [ -1.14410400e-01,  -1.14379883e-01],
                        [ -1.13708496e-01,  -1.13708496e-01],
                        [ -1.13311768e-01,  -1.13342285e-01],
                        [ -1.12487793e-01,  -1.12457275e-01],
                        [ -1.11938477e-01,  -1.11968994e-01],
                        [ -1.06994629e-01,  -1.07025146e-01],
                        [ -9.20715332e-02,  -9.20410156e-02],
                        [ -6.97326660e-02,  -6.97021484e-02],
                        [ -5.10253906e-02,  -5.10559082e-02],
                        [ -4.40673828e-02,  -4.40979004e-02],
                        [ -4.58679199e-02,  -4.58374023e-02],
                        [ -4.86450195e-02,  -4.86755371e-02],
                        [ -4.75158691e-02,  -4.75463867e-02],
                        [ -3.81164551e-02,  -3.80859375e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [  2.19726562e-02,   2.19421387e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  9.70153809e-02,   9.70458984e-02],
                        [  1.09344482e-01,   1.09313965e-01],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  9.34143066e-02,   9.34448242e-02],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  9.93652344e-02,   9.93347168e-02],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.38946533e-01,   1.38977051e-01],
                        [  1.58325195e-01,   1.58294678e-01],
                        [  1.80816650e-01,   1.80816650e-01],
                        [  2.09869385e-01,   2.09899902e-01],
                        [  2.33520508e-01,   2.33520508e-01],
                        [  2.28057861e-01,   2.28027344e-01],
                        [  1.81793213e-01,   1.81823730e-01],
                        [  1.05102539e-01,   1.05133057e-01],
                        [  1.26342773e-02,   1.26037598e-02],
                        [ -8.99658203e-02,  -8.99658203e-02],
                        [ -1.93969727e-01,  -1.93939209e-01],
                        [ -2.75024414e-01,  -2.75054932e-01],
                        [ -3.04473877e-01,  -3.04504395e-01],
                        [ -2.74780273e-01,  -2.74749756e-01],
                        [ -2.11547852e-01,  -2.11547852e-01],
                        [ -1.55883789e-01,  -1.55914307e-01],
                        [ -1.29333496e-01,  -1.29333496e-01],
                        [ -1.21551514e-01,  -1.21520996e-01],
                        [ -1.15112305e-01,  -1.15142822e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.05438232e-01,  -1.05407715e-01],
                        [ -1.04248047e-01,  -1.04248047e-01],
                        [ -9.99755859e-02,  -1.00006104e-01],
                        [ -9.25292969e-02,  -9.24987793e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -7.33032227e-02,  -7.33337402e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -2.14538574e-02,  -2.14233398e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  7.96203613e-02,   7.95898438e-02],
                        [  1.41601562e-01,   1.41632080e-01],
                        [  2.03674316e-01,   2.03704834e-01],
                        [  2.42706299e-01,   2.42675781e-01],
                        [  2.37030029e-01,   2.37030029e-01],
                        [  1.95800781e-01,   1.95831299e-01],
                        [  1.52282715e-01,   1.52252197e-01],
                        [  1.27502441e-01,   1.27502441e-01],
                        [  1.16851807e-01,   1.16912842e-01],
                        [  1.10107422e-01,   1.10137939e-01],
                        [  1.06353760e-01,   1.06323242e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  1.02416992e-01,   1.02447510e-01],
                        [  9.28039551e-02,   9.27734375e-02],
                        [  8.16040039e-02,   8.15734863e-02],
                        [  7.07092285e-02,   7.07702637e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  3.82080078e-02,   3.81774902e-02],
                        [  2.37426758e-02,   2.37731934e-02],
                        [  1.31835938e-02,   1.32141113e-02],
                        [  1.37329102e-03,   1.34277344e-03],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.52282715e-02,  -1.51977539e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [  2.74658203e-04,   2.44140625e-04],
                        [  1.43432617e-03,   1.46484375e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.87268066e-02,  -3.86962891e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.44335938e-02,  -4.44641113e-02],
                        [ -4.24194336e-02,  -4.23889160e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  2.55432129e-02,   2.55126953e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  4.40979004e-02,   4.41284180e-02],
                        [  5.79528809e-02,   5.79223633e-02],
                        [  7.22045898e-02,   7.21740723e-02],
                        [  8.56323242e-02,   8.56628418e-02],
                        [  9.79003906e-02,   9.79309082e-02],
                        [  1.00372314e-01,   1.00341797e-01],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  2.62451172e-02,   2.62756348e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -1.17187500e-01,  -1.17218018e-01],
                        [ -1.76239014e-01,  -1.76208496e-01],
                        [ -2.04010010e-01,  -2.04010010e-01],
                        [ -1.94946289e-01,  -1.94976807e-01],
                        [ -1.66198730e-01,  -1.66168213e-01],
                        [ -1.41479492e-01,  -1.41448975e-01],
                        [ -1.26892090e-01,  -1.26922607e-01],
                        [ -1.13555908e-01,  -1.13586426e-01],
                        [ -9.78393555e-02,  -9.77783203e-02],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -8.72192383e-02,  -8.72497559e-02],
                        [ -9.33837891e-02,  -9.33532715e-02],
                        [ -9.63745117e-02,  -9.63439941e-02],
                        [ -9.28649902e-02,  -9.28955078e-02],
                        [ -8.59069824e-02,  -8.59069824e-02],
                        [ -7.95593262e-02,  -7.94982910e-02],
                        [ -7.59277344e-02,  -7.59582520e-02],
                        [ -7.52563477e-02,  -7.53173828e-02],
                        [ -7.37304688e-02,  -7.36999512e-02],
                        [ -6.04858398e-02,  -6.04553223e-02],
                        [ -2.45971680e-02,  -2.46582031e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  8.62121582e-02,   8.62731934e-02],
                        [  1.22833252e-01,   1.22802734e-01],
                        [  1.34582520e-01,   1.34521484e-01],
                        [  1.27380371e-01,   1.27441406e-01],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  9.59167480e-02,   9.58557129e-02],
                        [  9.50927734e-02,   9.51232910e-02],
                        [  1.13098145e-01,   1.13159180e-01],
                        [  1.38763428e-01,   1.38732910e-01],
                        [  1.59881592e-01,   1.59851074e-01],
                        [  1.80358887e-01,   1.80419922e-01],
                        [  2.07366943e-01,   2.07366943e-01],
                        [  2.29003906e-01,   2.28942871e-01],
                        [  2.22717285e-01,   2.22717285e-01],
                        [  1.80206299e-01,   1.80267334e-01],
                        [  1.07208252e-01,   1.07177734e-01],
                        [  6.98852539e-03,   6.98852539e-03],
                        [ -1.14532471e-01,  -1.14471436e-01],
                        [ -2.33154297e-01,  -2.33154297e-01],
                        [ -3.13018799e-01,  -3.13079834e-01],
                        [ -3.29315186e-01,  -3.29284668e-01],
                        [ -2.84729004e-01,  -2.84698486e-01],
                        [ -2.11425781e-01,  -2.11486816e-01],
                        [ -1.51306152e-01,  -1.51306152e-01],
                        [ -1.23107910e-01,  -1.23077393e-01],
                        [ -1.13433838e-01,  -1.13433838e-01],
                        [ -1.03607178e-01,  -1.03637695e-01],
                        [ -9.41467285e-02,  -9.41162109e-02],
                        [ -9.33532715e-02,  -9.33227539e-02],
                        [ -9.79309082e-02,  -9.79614258e-02],
                        [ -9.89379883e-02,  -9.89379883e-02],
                        [ -9.49707031e-02,  -9.49401855e-02],
                        [ -8.72802734e-02,  -8.72802734e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -4.21752930e-02,  -4.21447754e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  5.26733398e-02,   5.26428223e-02],
                        [  1.14959717e-01,   1.14990234e-01],
                        [  1.76116943e-01,   1.76116943e-01],
                        [  2.16369629e-01,   2.16308594e-01],
                        [  2.23022461e-01,   2.23022461e-01],
                        [  2.02178955e-01,   2.02209473e-01],
                        [  1.70379639e-01,   1.70379639e-01],
                        [  1.41723633e-01,   1.41693115e-01],
                        [  1.23474121e-01,   1.23504639e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  1.11846924e-01,   1.11816406e-01],
                        [  1.04522705e-01,   1.04553223e-01],
                        [  9.38415527e-02,   9.39025879e-02],
                        [  8.44726562e-02,   8.44421387e-02],
                        [  7.70874023e-02,   7.70874023e-02],
                        [  6.97631836e-02,   6.97937012e-02],
                        [  6.17370605e-02,   6.17675781e-02],
                        [  4.97131348e-02,   4.96826172e-02],
                        [  2.96325684e-02,   2.96630859e-02],
                        [  6.74438477e-03,   6.80541992e-03],
                        [ -7.17163086e-03,  -7.20214844e-03],
                        [ -8.66699219e-03,  -8.69750977e-03],
                        [ -6.56127930e-03,  -6.50024414e-03],
                        [ -8.45336914e-03,  -8.48388672e-03],
                        [ -1.08337402e-02,  -1.08947754e-02],
                        [ -7.78198242e-03,  -7.75146484e-03],
                        [ -2.92968750e-03,  -2.89916992e-03],
                        [ -3.75366211e-03,  -3.81469727e-03],
                        [ -1.08947754e-02,  -1.09252930e-02],
                        [ -2.08740234e-02,  -2.08129883e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -4.27246094e-02,  -4.27856445e-02],
                        [ -4.43115234e-02,  -4.42810059e-02],
                        [ -3.46679688e-02,  -3.46374512e-02],
                        [ -2.11181641e-02,  -2.11486816e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -2.01416016e-03,  -1.95312500e-03],
                        [  4.08935547e-03,   4.05883789e-03],
                        [  7.69042969e-03,   7.62939453e-03],
                        [  1.24816895e-02,   1.25427246e-02],
                        [  2.11791992e-02,   2.12097168e-02],
                        [  2.87475586e-02,   2.86865234e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  3.02734375e-02,   3.03344727e-02],
                        [  4.04357910e-02,   4.04052734e-02],
                        [  6.28051758e-02,   6.27746582e-02],
                        [  8.66088867e-02,   8.66699219e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  9.60388184e-02,   9.59777832e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  3.64074707e-02,   3.64379883e-02],
                        [ -3.42407227e-02,  -3.42712402e-02],
                        [ -1.23016357e-01,  -1.23016357e-01],
                        [ -1.94335938e-01,  -1.94274902e-01],
                        [ -2.17498779e-01,  -2.17498779e-01],
                        [ -1.93786621e-01,  -1.93817139e-01],
                        [ -1.51062012e-01,  -1.51000977e-01],
                        [ -1.18530273e-01,  -1.18530273e-01],
                        [ -1.08367920e-01,  -1.08398438e-01],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -1.16485596e-01,  -1.16455078e-01],
                        [ -1.07910156e-01,  -1.07940674e-01],
                        [ -9.14306641e-02,  -9.14611816e-02],
                        [ -7.82470703e-02,  -7.82165527e-02],
                        [ -7.38220215e-02,  -7.38220215e-02],
                        [ -7.71789551e-02,  -7.72399902e-02],
                        [ -8.59069824e-02,  -8.58764648e-02],
                        [ -9.40856934e-02,  -9.40551758e-02],
                        [ -9.23767090e-02,  -9.24377441e-02],
                        [ -7.72705078e-02,  -7.73010254e-02],
                        [ -5.33752441e-02,  -5.33142090e-02],
                        [ -2.35595703e-02,  -2.35900879e-02],
                        [  1.41601562e-02,   1.41296387e-02],
                        [  5.62744141e-02,   5.63049316e-02],
                        [  9.01489258e-02,   9.01489258e-02],
                        [  1.06994629e-01,   1.06933594e-01],
                        [  1.08520508e-01,   1.08551025e-01],
                        [  1.01409912e-01,   1.01440430e-01],
                        [  9.58251953e-02,   9.57641602e-02],
                        [  1.04797363e-01,   1.04766846e-01],
                        [  1.31927490e-01,   1.31988525e-01],
                        [  1.63604736e-01,   1.63574219e-01],
                        [  1.81884766e-01,   1.81823730e-01],
                        [  1.84448242e-01,   1.84478760e-01],
                        [  1.84478760e-01,   1.84509277e-01],
                        [  1.91223145e-01,   1.91162109e-01],
                        [  1.96197510e-01,   1.96166992e-01],
                        [  1.79199219e-01,   1.79260254e-01],
                        [  1.24298096e-01,   1.24267578e-01],
                        [  3.17382812e-02,   3.17077637e-02],
                        [ -8.15124512e-02,  -8.14819336e-02],
                        [ -1.91802979e-01,  -1.91772461e-01],
                        [ -2.76428223e-01,  -2.76489258e-01],
                        [ -3.15582275e-01,  -3.15582275e-01],
                        [ -2.98126221e-01,  -2.98065186e-01],
                        [ -2.35473633e-01,  -2.35504150e-01],
                        [ -1.64123535e-01,  -1.64154053e-01],
                        [ -1.19812012e-01,  -1.19750977e-01],
                        [ -1.07421875e-01,  -1.07391357e-01],
                        [ -1.06994629e-01,  -1.07055664e-01],
                        [ -1.03942871e-01,  -1.03912354e-01],
                        [ -9.94262695e-02,  -9.93652344e-02],
                        [ -9.81140137e-02,  -9.81750488e-02],
                        [ -9.89990234e-02,  -9.90295410e-02],
                        [ -9.64660645e-02,  -9.64050293e-02],
                        [ -8.49304199e-02,  -8.49304199e-02],
                        [ -6.27136230e-02,  -6.27746582e-02],
                        [ -3.19213867e-02,  -3.18603516e-02],
                        [  7.84301758e-03,   7.90405273e-03],
                        [  6.12487793e-02,   6.12182617e-02],
                        [  1.26403809e-01,   1.26373291e-01],
                        [  1.85577393e-01,   1.85638428e-01],
                        [  2.15850830e-01,   2.15850830e-01],
                        [  2.08312988e-01,   2.08251953e-01],
                        [  1.73950195e-01,   1.73980713e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.07788086e-01,   1.07727051e-01],
                        [  1.02355957e-01,   1.02386475e-01],
                        [  1.12854004e-01,   1.12915039e-01],
                        [  1.24084473e-01,   1.24053955e-01],
                        [  1.24908447e-01,   1.24877930e-01],
                        [  1.19567871e-01,   1.19628906e-01],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  1.09405518e-01,   1.09375000e-01],
                        [  8.77075195e-02,   8.77380371e-02],
                        [  5.37414551e-02,   5.37719727e-02],
                        [  2.31018066e-02,   2.30712891e-02],
                        [  6.25610352e-03,   6.22558594e-03],
                        [  7.62939453e-04,   7.93457031e-04],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  4.57763672e-04,   4.27246094e-04],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -6.56127930e-03,  -6.59179688e-03],
                        [ -1.13220215e-02,  -1.13525391e-02],
                        [ -1.11389160e-02,  -1.11083984e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -3.47900391e-03,  -3.50952148e-03],
                        [ -7.41577148e-03,  -7.38525391e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.46887207e-02,  -2.47192383e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.64990234e-02,  -3.64685059e-02],
                        [ -3.64379883e-02,  -3.64685059e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -1.32141113e-02,  -1.31835938e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  2.86865234e-03,   2.80761719e-03],
                        [ -1.00708008e-03,  -9.76562500e-04],
                        [  1.25122070e-03,   1.28173828e-03],
                        [  1.69982910e-02,   1.69372559e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.62341309e-02,   4.62951660e-02],
                        [  4.45556641e-02,   4.45251465e-02],
                        [  4.25720215e-02,   4.25415039e-02],
                        [  4.98046875e-02,   4.98352051e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  8.93859863e-02,   8.93554688e-02],
                        [  9.97314453e-02,   9.97619629e-02],
                        [  8.05664062e-02,   8.06274414e-02],
                        [  2.48413086e-02,   2.48107910e-02],
                        [ -5.64270020e-02,  -5.64575195e-02],
                        [ -1.38854980e-01,  -1.38824463e-01],
                        [ -1.93420410e-01,  -1.93420410e-01],
                        [ -2.01354980e-01,  -2.01416016e-01],
                        [ -1.70288086e-01,  -1.70257568e-01],
                        [ -1.29516602e-01,  -1.29486084e-01],
                        [ -1.05804443e-01,  -1.05834961e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -1.16180420e-01,  -1.16119385e-01],
                        [ -1.21093750e-01,  -1.21093750e-01],
                        [ -1.13555908e-01,  -1.13616943e-01],
                        [ -1.01806641e-01,  -1.01776123e-01],
                        [ -9.77172852e-02,  -9.77172852e-02],
                        [ -1.00769043e-01,  -1.00830078e-01],
                        [ -9.88769531e-02,  -9.88769531e-02],
                        [ -8.74023438e-02,  -8.73413086e-02],
                        [ -7.49816895e-02,  -7.50122070e-02],
                        [ -6.58874512e-02,  -6.59484863e-02],
                        [ -5.09643555e-02,  -5.09338379e-02],
                        [ -2.29797363e-02,  -2.29492188e-02],
                        [  1.12915039e-02,   1.12609863e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  6.58874512e-02,   6.59484863e-02],
                        [  8.48083496e-02,   8.47778320e-02],
                        [  9.48486328e-02,   9.48181152e-02],
                        [  9.55200195e-02,   9.55810547e-02],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  1.03790283e-01,   1.03729248e-01],
                        [  1.20727539e-01,   1.20758057e-01],
                        [  1.37359619e-01,   1.37420654e-01],
                        [  1.49719238e-01,   1.49688721e-01],
                        [  1.64184570e-01,   1.64154053e-01],
                        [  1.84326172e-01,   1.84387207e-01],
                        [  2.02087402e-01,   2.02087402e-01],
                        [  2.07305908e-01,   2.07244873e-01],
                        [  1.93450928e-01,   1.93481445e-01],
                        [  1.52191162e-01,   1.52252197e-01],
                        [  7.57446289e-02,   7.56835938e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -1.51336670e-01,  -1.51275635e-01],
                        [ -2.55889893e-01,  -2.55920410e-01],
                        [ -3.16101074e-01,  -3.16162109e-01],
                        [ -3.12286377e-01,  -3.12255859e-01],
                        [ -2.53631592e-01,  -2.53631592e-01],
                        [ -1.80328369e-01,  -1.80389404e-01],
                        [ -1.33575439e-01,  -1.33544922e-01],
                        [ -1.22802734e-01,  -1.22741699e-01],
                        [ -1.27502441e-01,  -1.27532959e-01],
                        [ -1.27258301e-01,  -1.27288818e-01],
                        [ -1.21215820e-01,  -1.21154785e-01],
                        [ -1.16485596e-01,  -1.16485596e-01],
                        [ -1.11785889e-01,  -1.11816406e-01],
                        [ -1.02386475e-01,  -1.02355957e-01],
                        [ -8.76159668e-02,  -8.75854492e-02],
                        [ -6.46667480e-02,  -6.47277832e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [  2.54211426e-02,   2.54821777e-02],
                        [  8.29772949e-02,   8.29467773e-02],
                        [  1.36383057e-01,   1.36352539e-01],
                        [  1.80297852e-01,   1.80328369e-01],
                        [  2.06451416e-01,   2.06451416e-01],
                        [  2.04956055e-01,   2.04895020e-01],
                        [  1.76940918e-01,   1.76971436e-01],
                        [  1.39282227e-01,   1.39312744e-01],
                        [  1.13372803e-01,   1.13311768e-01],
                        [  1.08947754e-01,   1.08947754e-01],
                        [  1.17279053e-01,   1.17340088e-01],
                        [  1.22711182e-01,   1.22680664e-01],
                        [  1.19842529e-01,   1.19781494e-01],
                        [  1.13372803e-01,   1.13433838e-01],
                        [  1.06079102e-01,   1.06109619e-01],
                        [  9.60388184e-02,   9.59777832e-02],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  5.97839355e-02,   5.98449707e-02],
                        [  3.36608887e-02,   3.36303711e-02],
                        [  1.23291016e-02,   1.22680664e-02],
                        [  6.74438477e-03,   6.80541992e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.85852051e-02,   1.85241699e-02],
                        [  1.38549805e-02,   1.38854980e-02],
                        [  7.93457031e-03,   7.96508789e-03],
                        [  5.03540039e-03,   4.97436523e-03],
                        [ -2.10571289e-03,  -2.13623047e-03],
                        [ -1.59606934e-02,  -1.58996582e-02],
                        [ -2.62451172e-02,  -2.62756348e-02],
                        [ -2.74047852e-02,  -2.74658203e-02],
                        [ -2.79541016e-02,  -2.78930664e-02],
                        [ -3.35083008e-02,  -3.34777832e-02],
                        [ -3.70788574e-02,  -3.71398926e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.88696289e-02,  -2.88085938e-02],
                        [ -2.21252441e-02,  -2.21557617e-02],
                        [ -1.22375488e-02,  -1.22985840e-02],
                        [ -3.93676758e-03,  -3.87573242e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -3.11279297e-03,  -3.17382812e-03],
                        [  1.98364258e-03,   2.01416016e-03],
                        [  9.94873047e-03,   9.97924805e-03],
                        [  1.13220215e-02,   1.12915039e-02],
                        [  7.11059570e-03,   7.08007812e-03],
                        [  1.01928711e-02,   1.02233887e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  5.13610840e-02,   5.13305664e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  7.19299316e-02,   7.19909668e-02],
                        [  7.75146484e-02,   7.74841309e-02],
                        [  9.09729004e-02,   9.09423828e-02],
                        [  1.00433350e-01,   1.00494385e-01],
                        [  8.07495117e-02,   8.07800293e-02],
                        [  1.69982910e-02,   1.69372559e-02],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -1.68609619e-01,  -1.68579102e-01],
                        [ -2.20245361e-01,  -2.20275879e-01],
                        [ -2.19146729e-01,  -2.19177246e-01],
                        [ -1.82800293e-01,  -1.82739258e-01],
                        [ -1.44561768e-01,  -1.44561768e-01],
                        [ -1.23229980e-01,  -1.23291016e-01],
                        [ -1.14074707e-01,  -1.14044189e-01],
                        [ -1.06781006e-01,  -1.06750488e-01],
                        [ -9.87243652e-02,  -9.87854004e-02],
                        [ -9.40551758e-02,  -9.40856934e-02],
                        [ -9.89685059e-02,  -9.89074707e-02],
                        [ -1.12640381e-01,  -1.12670898e-01],
                        [ -1.22039795e-01,  -1.22100830e-01],
                        [ -1.15264893e-01,  -1.15203857e-01],
                        [ -9.71679688e-02,  -9.71374512e-02],
                        [ -7.93457031e-02,  -7.94067383e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -2.99987793e-02,  -2.99377441e-02],
                        [  1.30004883e-02,   1.29699707e-02],
                        [  6.10351562e-02,   6.10046387e-02],
                        [  1.04187012e-01,   1.04217529e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.27532959e-01,   1.27502441e-01],
                        [  1.04705811e-01,   1.04736328e-01],
                        [  8.10241699e-02,   8.10852051e-02],
                        [  7.22961426e-02,   7.22656250e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  1.01562500e-01,   1.01623535e-01],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.49169922e-01,   1.49139404e-01],
                        [  1.75048828e-01,   1.75079346e-01],
                        [  2.06634521e-01,   2.06665039e-01],
                        [  2.31994629e-01,   2.31933594e-01],
                        [  2.29400635e-01,   2.29400635e-01],
                        [  1.88140869e-01,   1.88201904e-01],
                        [  1.12213135e-01,   1.12182617e-01],
                        [  8.63647461e-03,   8.63647461e-03],
                        [ -1.14379883e-01,  -1.14318848e-01],
                        [ -2.38311768e-01,  -2.38311768e-01],
                        [ -3.29406738e-01,  -3.29467773e-01],
                        [ -3.52935791e-01,  -3.52935791e-01],
                        [ -3.02886963e-01,  -3.02856445e-01],
                        [ -2.16613770e-01,  -2.16674805e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.21337891e-01,  -1.21276855e-01],
                        [ -1.21887207e-01,  -1.21917725e-01],
                        [ -1.24938965e-01,  -1.25000000e-01],
                        [ -1.22253418e-01,  -1.22192383e-01],
                        [ -1.17553711e-01,  -1.17523193e-01],
                        [ -1.14715576e-01,  -1.14776611e-01],
                        [ -1.14379883e-01,  -1.14379883e-01],
                        [ -1.11755371e-01,  -1.11694336e-01],
                        [ -9.41772461e-02,  -9.42077637e-02],
                        [ -4.86755371e-02,  -4.87060547e-02],
                        [  2.27966309e-02,   2.28576660e-02],
                        [  1.02050781e-01,   1.02081299e-01],
                        [  1.70959473e-01,   1.70898438e-01],
                        [  2.20245361e-01,   2.20275879e-01],
                        [  2.42706299e-01,   2.42736816e-01],
                        [  2.33154297e-01,   2.33123779e-01],
                        [  1.98669434e-01,   1.98638916e-01],
                        [  1.57470703e-01,   1.57531738e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.07574463e-01,   1.07513428e-01],
                        [  9.93652344e-02,   9.93957520e-02],
                        [  9.38110352e-02,   9.38415527e-02],
                        [  8.74023438e-02,   8.73413086e-02],
                        [  8.29772949e-02,   8.29772949e-02],
                        [  8.19396973e-02,   8.20007324e-02],
                        [  7.65075684e-02,   7.64770508e-02],
                        [  6.07604980e-02,   6.06994629e-02],
                        [  4.33654785e-02,   4.33959961e-02],
                        [  3.61022949e-02,   3.61328125e-02],
                        [  3.74145508e-02,   3.73840332e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  3.42712402e-02,   3.43322754e-02],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  1.75476074e-02,   1.75170898e-02],
                        [  3.99780273e-03,   4.02832031e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.87683105e-02,  -1.87988281e-02],
                        [ -1.86767578e-02,  -1.86462402e-02],
                        [ -1.00097656e-02,  -9.97924805e-03],
                        [ -1.55639648e-03,  -1.58691406e-03],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [ -1.69067383e-02,  -1.68762207e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -4.29382324e-02,  -4.29687500e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.93981934e-02,  -3.93676758e-02],
                        [ -3.03649902e-02,  -3.03955078e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -4.79125977e-03,  -4.76074219e-03],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.04370117e-02,   1.04675293e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  8.08715820e-03,   8.05664062e-03],
                        [  8.23974609e-03,   8.27026367e-03],
                        [  1.53198242e-02,   1.53503418e-02],
                        [  3.27758789e-02,   3.27148438e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  7.23571777e-02,   7.23876953e-02],
                        [  8.97827148e-02,   8.97521973e-02],
                        [  1.04980469e-01,   1.04949951e-01],
                        [  1.06933594e-01,   1.06964111e-01],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  2.84118652e-02,   2.83508301e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -1.25183105e-01,  -1.25122070e-01],
                        [ -1.87683105e-01,  -1.87713623e-01],
                        [ -2.18017578e-01,  -2.18048096e-01],
                        [ -2.12097168e-01,  -2.12036133e-01],
                        [ -1.83959961e-01,  -1.83959961e-01],
                        [ -1.56311035e-01,  -1.56372070e-01],
                        [ -1.38977051e-01,  -1.38977051e-01],
                        [ -1.24359131e-01,  -1.24328613e-01],
                        [ -1.06597900e-01,  -1.06628418e-01],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -8.30078125e-02,  -8.29467773e-02],
                        [ -8.03222656e-02,  -8.03222656e-02],
                        [ -8.01696777e-02,  -8.02307129e-02],
                        [ -8.13903809e-02,  -8.13598633e-02],
                        [ -8.30078125e-02,  -8.29467773e-02],
                        [ -8.34045410e-02,  -8.34350586e-02],
                        [ -7.79724121e-02,  -7.80029297e-02],
                        [ -5.89599609e-02,  -5.89294434e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [  3.16162109e-02,   3.15551758e-02],
                        [  8.47473145e-02,   8.47778320e-02],
                        [  1.20727539e-01,   1.20758057e-01],
                        [  1.31347656e-01,   1.31286621e-01],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  1.09954834e-01,   1.10015869e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  9.26818848e-02,   9.26208496e-02],
                        [  9.38720703e-02,   9.39025879e-02],
                        [  1.05346680e-01,   1.05377197e-01],
                        [  1.29913330e-01,   1.29882812e-01],
                        [  1.69250488e-01,   1.69219971e-01],
                        [  2.14569092e-01,   2.14630127e-01],
                        [  2.43438721e-01,   2.43408203e-01],
                        [  2.32910156e-01,   2.32879639e-01],
                        [  1.74011230e-01,   1.74041748e-01],
                        [  7.39746094e-02,   7.40051270e-02],
                        [ -4.82788086e-02,  -4.83093262e-02],
                        [ -1.68579102e-01,  -1.68579102e-01],
                        [ -2.62908936e-01,  -2.62878418e-01],
                        [ -3.08898926e-01,  -3.08929443e-01],
                        [ -2.92785645e-01,  -2.92816162e-01],
                        [ -2.28363037e-01,  -2.28363037e-01],
                        [ -1.61193848e-01,  -1.61193848e-01],
                        [ -1.31591797e-01,  -1.31622314e-01],
                        [ -1.36840820e-01,  -1.36810303e-01],
                        [ -1.46514893e-01,  -1.46484375e-01],
                        [ -1.43859863e-01,  -1.43859863e-01],
                        [ -1.34826660e-01,  -1.34857178e-01],
                        [ -1.29516602e-01,  -1.29486084e-01],
                        [ -1.29486084e-01,  -1.29486084e-01],
                        [ -1.26800537e-01,  -1.26831055e-01],
                        [ -1.08093262e-01,  -1.08062744e-01],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  1.55242920e-01,   1.55273438e-01],
                        [  2.05169678e-01,   2.05169678e-01],
                        [  2.27355957e-01,   2.27325439e-01],
                        [  2.23815918e-01,   2.23846436e-01],
                        [  1.99951172e-01,   1.99951172e-01],
                        [  1.66534424e-01,   1.66534424e-01],
                        [  1.38549805e-01,   1.38580322e-01],
                        [  1.20819092e-01,   1.20849609e-01],
                        [  1.06079102e-01,   1.06048584e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  8.87145996e-02,   8.87451172e-02],
                        [  9.21630859e-02,   9.21325684e-02],
                        [  9.42077637e-02,   9.41772461e-02],
                        [  9.20715332e-02,   9.21020508e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  7.41577148e-02,   7.41271973e-02],
                        [  5.17883301e-02,   5.18188477e-02],
                        [  2.72216797e-02,   2.72521973e-02],
                        [  9.24682617e-03,   9.21630859e-03],
                        [  8.23974609e-04,   7.93457031e-04],
                        [  2.47192383e-03,   2.53295898e-03],
                        [  1.07421875e-02,   1.07727051e-02],
                        [  1.66320801e-02,   1.65710449e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  8.81958008e-03,   8.88061523e-03],
                        [  3.26538086e-03,   3.23486328e-03],
                        [  1.86157227e-03,   1.83105469e-03],
                        [  4.30297852e-03,   4.33349609e-03],
                        [  2.83813477e-03,   2.86865234e-03],
                        [ -1.02233887e-02,  -1.02539062e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -4.41284180e-02,  -4.40979004e-02],
                        [ -4.42504883e-02,  -4.43115234e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.05786133e-02,  -3.05480957e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.49938965e-02,  -2.50244141e-02],
                        [ -1.58996582e-02,  -1.58691406e-02],
                        [ -9.91821289e-03,  -9.88769531e-03],
                        [ -1.22680664e-02,  -1.23291016e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -9.79614258e-03,  -9.76562500e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  2.07214355e-02,   2.06604004e-02],
                        [  4.09240723e-02,   4.09545898e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  6.01196289e-02,   6.00585938e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  8.75549316e-02,   8.75854492e-02],
                        [  1.02783203e-01,   1.02752686e-01],
                        [  1.02966309e-01,   1.02935791e-01],
                        [  8.62731934e-02,   8.63342285e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [ -1.26342773e-02,  -1.26647949e-02],
                        [ -9.80224609e-02,  -9.79919434e-02],
                        [ -1.79992676e-01,  -1.79992676e-01],
                        [ -2.26989746e-01,  -2.27020264e-01],
                        [ -2.26593018e-01,  -2.26562500e-01],
                        [ -1.94061279e-01,  -1.94030762e-01],
                        [ -1.57287598e-01,  -1.57318115e-01],
                        [ -1.33666992e-01,  -1.33697510e-01],
                        [ -1.21124268e-01,  -1.21093750e-01],
                        [ -1.07727051e-01,  -1.07727051e-01],
                        [ -8.71276855e-02,  -8.71582031e-02],
                        [ -6.68640137e-02,  -6.68334961e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -7.46765137e-02,  -7.47070312e-02],
                        [ -9.41467285e-02,  -9.41162109e-02],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -9.53979492e-02,  -9.54284668e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -5.35583496e-02,  -5.35278320e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [  3.08532715e-02,   3.08227539e-02],
                        [  7.84606934e-02,   7.84912109e-02],
                        [  1.16149902e-01,   1.16180420e-01],
                        [  1.33972168e-01,   1.33941650e-01],
                        [  1.28540039e-01,   1.28540039e-01],
                        [  1.09771729e-01,   1.09832764e-01],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  8.91418457e-02,   8.91113281e-02],
                        [  9.93652344e-02,   9.93957520e-02],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.57897949e-01,   1.57867432e-01],
                        [  1.92169189e-01,   1.92169189e-01],
                        [  2.16308594e-01,   2.16369629e-01],
                        [  2.19085693e-01,   2.19055176e-01],
                        [  1.87133789e-01,   1.87103271e-01],
                        [  1.14013672e-01,   1.14074707e-01],
                        [  8.30078125e-03,   8.30078125e-03],
                        [ -1.11694336e-01,  -1.11755371e-01],
                        [ -2.22869873e-01,  -2.22869873e-01],
                        [ -2.97363281e-01,  -2.97302246e-01],
                        [ -3.12347412e-01,  -3.12377930e-01],
                        [ -2.70050049e-01,  -2.70080566e-01],
                        [ -2.03247070e-01,  -2.03186035e-01],
                        [ -1.51885986e-01,  -1.51916504e-01],
                        [ -1.32659912e-01,  -1.32690430e-01],
                        [ -1.33758545e-01,  -1.33728027e-01],
                        [ -1.36444092e-01,  -1.36413574e-01],
                        [ -1.34918213e-01,  -1.34979248e-01],
                        [ -1.35437012e-01,  -1.35437012e-01],
                        [ -1.39251709e-01,  -1.39190674e-01],
                        [ -1.35284424e-01,  -1.35314941e-01],
                        [ -1.11480713e-01,  -1.11511230e-01],
                        [ -6.46057129e-02,  -6.45751953e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  7.89184570e-02,   7.88879395e-02],
                        [  1.54174805e-01,   1.54205322e-01],
                        [  2.10601807e-01,   2.10632324e-01],
                        [  2.32910156e-01,   2.32879639e-01],
                        [  2.16552734e-01,   2.16552734e-01],
                        [  1.75048828e-01,   1.75109863e-01],
                        [  1.34216309e-01,   1.34216309e-01],
                        [  1.13342285e-01,   1.13311768e-01],
                        [  1.12426758e-01,   1.12457275e-01],
                        [  1.19720459e-01,   1.19750977e-01],
                        [  1.26251221e-01,   1.26190186e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.24816895e-01,   1.24877930e-01],
                        [  1.11419678e-01,   1.11389160e-01],
                        [  8.86840820e-02,   8.86230469e-02],
                        [  6.26525879e-02,   6.27136230e-02],
                        [  4.20837402e-02,   4.21142578e-02],
                        [  3.05175781e-02,   3.04565430e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.96228027e-02,   1.96838379e-02],
                        [  1.46484375e-02,   1.46179199e-02],
                        [  1.12304688e-02,   1.11999512e-02],
                        [  9.79614258e-03,   9.85717773e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  4.39453125e-03,   4.33349609e-03],
                        [ -3.66210938e-03,  -3.63159180e-03],
                        [ -1.46484375e-02,  -1.45874023e-02],
                        [ -2.45056152e-02,  -2.45971680e-02],
                        [ -3.15551758e-02,  -3.15856934e-02],
                        [ -3.67736816e-02,  -3.66821289e-02],
                        [ -3.82385254e-02,  -3.82690430e-02],
                        [ -3.37829590e-02,  -3.38439941e-02],
                        [ -2.65808105e-02,  -2.65197754e-02],
                        [ -1.94702148e-02,  -1.94396973e-02],
                        [ -1.09863281e-02,  -1.10778809e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -5.03540039e-03,  -4.94384766e-03],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -1.87072754e-02,  -1.87683105e-02],
                        [ -1.67236328e-02,  -1.66320801e-02],
                        [ -1.32446289e-02,  -1.32141113e-02],
                        [ -1.13220215e-02,  -1.14135742e-02],
                        [ -9.39941406e-03,  -9.36889648e-03],
                        [ -7.11059570e-03,  -7.04956055e-03],
                        [ -2.80761719e-03,  -2.83813477e-03],
                        [  9.00268555e-03,   8.97216797e-03],
                        [  3.08227539e-02,   3.08837891e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  7.96813965e-02,   7.96203613e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.00646973e-01,   1.00677490e-01],
                        [  9.75341797e-02,   9.75036621e-02],
                        [  8.06884766e-02,   8.06579590e-02],
                        [  5.05981445e-02,   5.06286621e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [ -5.31005859e-02,  -5.31311035e-02],
                        [ -1.25030518e-01,  -1.25000000e-01],
                        [ -1.85363770e-01,  -1.85333252e-01],
                        [ -2.10296631e-01,  -2.10327148e-01],
                        [ -1.97723389e-01,  -1.97723389e-01],
                        [ -1.66381836e-01,  -1.66320801e-01],
                        [ -1.37603760e-01,  -1.37603760e-01],
                        [ -1.21917725e-01,  -1.21948242e-01],
                        [ -1.17065430e-01,  -1.17034912e-01],
                        [ -1.14227295e-01,  -1.14196777e-01],
                        [ -1.07727051e-01,  -1.07757568e-01],
                        [ -9.97314453e-02,  -9.97314453e-02],
                        [ -9.62219238e-02,  -9.61914062e-02],
                        [ -9.91821289e-02,  -9.91821289e-02],
                        [ -1.02172852e-01,  -1.02172852e-01],
                        [ -9.62219238e-02,  -9.61914062e-02],
                        [ -7.99255371e-02,  -7.99255371e-02],
                        [ -5.61218262e-02,  -5.61523438e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [  2.38342285e-02,   2.38647461e-02],
                        [  7.73620605e-02,   7.73315430e-02],
                        [  1.21704102e-01,   1.21704102e-01],
                        [  1.40502930e-01,   1.40533447e-01],
                        [  1.29730225e-01,   1.29699707e-01],
                        [  1.03454590e-01,   1.03424072e-01],
                        [  8.43505859e-02,   8.43811035e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.59149170e-01,   1.59179688e-01],
                        [  1.95770264e-01,   1.95739746e-01],
                        [  2.19390869e-01,   2.19360352e-01],
                        [  2.19818115e-01,   2.19848633e-01],
                        [  1.89880371e-01,   1.89880371e-01],
                        [  1.18957520e-01,   1.18927002e-01],
                        [  5.79833984e-03,   5.82885742e-03],
                        [ -1.28082275e-01,  -1.28051758e-01],
                        [ -2.47100830e-01,  -2.47161865e-01],
                        [ -3.18328857e-01,  -3.18328857e-01],
                        [ -3.23577881e-01,  -3.23547363e-01],
                        [ -2.71911621e-01,  -2.71911621e-01],
                        [ -2.01416016e-01,  -2.01477051e-01],
                        [ -1.52893066e-01,  -1.52862549e-01],
                        [ -1.36871338e-01,  -1.36840820e-01],
                        [ -1.36260986e-01,  -1.36322021e-01],
                        [ -1.36322021e-01,  -1.36352539e-01],
                        [ -1.37786865e-01,  -1.37725830e-01],
                        [ -1.41906738e-01,  -1.41906738e-01],
                        [ -1.39526367e-01,  -1.39556885e-01],
                        [ -1.21795654e-01,  -1.21765137e-01],
                        [ -8.94165039e-02,  -8.93859863e-02],
                        [ -4.26025391e-02,  -4.26635742e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.04522705e-01,   1.04583740e-01],
                        [  1.76574707e-01,   1.76513672e-01],
                        [  2.17193604e-01,   2.17163086e-01],
                        [  2.21740723e-01,   2.21801758e-01],
                        [  2.02026367e-01,   2.02026367e-01],
                        [  1.73370361e-01,   1.73309326e-01],
                        [  1.46301270e-01,   1.46331787e-01],
                        [  1.26037598e-01,   1.26098633e-01],
                        [  1.13708496e-01,   1.13647461e-01],
                        [  1.07116699e-01,   1.07116699e-01],
                        [  1.03820801e-01,   1.03851318e-01],
                        [  1.03027344e-01,   1.02996826e-01],
                        [  1.04278564e-01,   1.04217529e-01],
                        [  1.04248047e-01,   1.04278564e-01],
                        [  9.56420898e-02,   9.56726074e-02],
                        [  7.26318359e-02,   7.26013184e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  1.52587891e-02,   1.52893066e-02],
                        [  9.33837891e-03,   9.30786133e-03],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  2.38952637e-02,   2.39257812e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  8.91113281e-03,   8.88061523e-03],
                        [  4.30297852e-03,   4.33349609e-03],
                        [  8.72802734e-03,   8.75854492e-03],
                        [  1.25427246e-02,   1.25122070e-02],
                        [  4.24194336e-03,   4.27246094e-03],
                        [ -1.35192871e-02,  -1.34887695e-02],
                        [ -2.92968750e-02,  -2.93273926e-02],
                        [ -3.89099121e-02,  -3.89404297e-02],
                        [ -4.40673828e-02,  -4.40368652e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.57775879e-02,  -1.57470703e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -7.41577148e-03,  -7.44628906e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.23999023e-02,   2.23693848e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  2.19726562e-02,   2.20031738e-02],
                        [  2.60925293e-02,   2.60620117e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  3.07006836e-02,   3.07312012e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  5.13000488e-02,   5.12695312e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  6.28967285e-02,   6.29272461e-02],
                        [  6.58874512e-02,   6.58569336e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  4.26635742e-02,   4.26940918e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -6.64367676e-02,  -6.64672852e-02],
                        [ -1.43402100e-01,  -1.43371582e-01],
                        [ -2.02636719e-01,  -2.02606201e-01],
                        [ -2.20153809e-01,  -2.20184326e-01],
                        [ -1.99554443e-01,  -1.99554443e-01],
                        [ -1.64855957e-01,  -1.64825439e-01],
                        [ -1.37634277e-01,  -1.37634277e-01],
                        [ -1.24969482e-01,  -1.25030518e-01],
                        [ -1.19720459e-01,  -1.19689941e-01],
                        [ -1.11053467e-01,  -1.11022949e-01],
                        [ -9.85107422e-02,  -9.85412598e-02],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -8.84094238e-02,  -8.83789062e-02],
                        [ -8.65783691e-02,  -8.66088867e-02],
                        [ -8.08715820e-02,  -8.09020996e-02],
                        [ -7.26013184e-02,  -7.25708008e-02],
                        [ -5.99975586e-02,  -5.99670410e-02],
                        [ -3.79333496e-02,  -3.79943848e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  3.70178223e-02,   3.70483398e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  1.14288330e-01,   1.14257812e-01],
                        [  1.27105713e-01,   1.27136230e-01],
                        [  1.23718262e-01,   1.23748779e-01],
                        [  1.18713379e-01,   1.18682861e-01],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.36505127e-01,   1.36535645e-01],
                        [  1.56127930e-01,   1.56097412e-01],
                        [  1.78710938e-01,   1.78710938e-01],
                        [  2.01049805e-01,   2.01080322e-01],
                        [  2.15270996e-01,   2.15270996e-01],
                        [  2.08831787e-01,   2.08801270e-01],
                        [  1.69006348e-01,   1.69036865e-01],
                        [  9.04846191e-02,   9.04846191e-02],
                        [ -1.99584961e-02,  -1.99890137e-02],
                        [ -1.43859863e-01,  -1.43829346e-01],
                        [ -2.53326416e-01,  -2.53326416e-01],
                        [ -3.18115234e-01,  -3.18145752e-01],
                        [ -3.19274902e-01,  -3.19274902e-01],
                        [ -2.63702393e-01,  -2.63671875e-01],
                        [ -1.87591553e-01,  -1.87622070e-01],
                        [ -1.35040283e-01,  -1.35070801e-01],
                        [ -1.22650146e-01,  -1.22650146e-01],
                        [ -1.32934570e-01,  -1.32934570e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -1.50787354e-01,  -1.50787354e-01],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.38153076e-01,  -1.38153076e-01],
                        [ -1.10351562e-01,  -1.10351562e-01],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  5.97534180e-02,   5.97229004e-02],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.85089111e-01,   1.85089111e-01],
                        [  2.20642090e-01,   2.20642090e-01],
                        [  2.22442627e-01,   2.22412109e-01],
                        [  1.94305420e-01,   1.94305420e-01],
                        [  1.58691406e-01,   1.58691406e-01],
                        [  1.33239746e-01,   1.33209229e-01],
                        [  1.18011475e-01,   1.17980957e-01],
                        [  1.07543945e-01,   1.07574463e-01],
                        [  1.01135254e-01,   1.01104736e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.01745605e-01,   1.01776123e-01],
                        [  1.02416992e-01,   1.02447510e-01],
                        [  9.68322754e-02,   9.68017578e-02],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  6.28051758e-02,   6.28662109e-02],
                        [  4.40368652e-02,   4.40063477e-02],
                        [  3.13110352e-02,   3.12805176e-02],
                        [  2.50854492e-02,   2.51464844e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  3.25622559e-02,   3.25927734e-02],
                        [  3.22265625e-02,   3.22570801e-02],
                        [  2.39562988e-02,   2.38952637e-02],
                        [  1.55639648e-02,   1.55334473e-02],
                        [  1.21459961e-02,   1.22070312e-02],
                        [  4.82177734e-03,   4.79125977e-03],
                        [ -1.38244629e-02,  -1.38549805e-02],
                        [ -3.26538086e-02,  -3.26232910e-02],
                        [ -3.70178223e-02,  -3.69873047e-02],
                        [ -3.12194824e-02,  -3.12805176e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.68041992e-02,  -3.67431641e-02],
                        [ -3.94592285e-02,  -3.94897461e-02],
                        [ -3.60107422e-02,  -3.60717773e-02],
                        [ -3.24096680e-02,  -3.23791504e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.77917480e-02,  -1.78527832e-02],
                        [ -6.28662109e-03,  -6.25610352e-03],
                        [  1.15966797e-03,   1.19018555e-03],
                        [  7.29370117e-03,   7.23266602e-03],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  2.23083496e-02,   2.23693848e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.93884277e-02,   2.93273926e-02],
                        [  3.46679688e-02,   3.47290039e-02],
                        [  3.67736816e-02,   3.68041992e-02],
                        [  3.54919434e-02,   3.54309082e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  4.60205078e-02,   4.60815430e-02],
                        [  6.07299805e-02,   6.06994629e-02],
                        [  7.40356445e-02,   7.40051270e-02],
                        [  7.75146484e-02,   7.75756836e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  4.94689941e-02,   4.94384766e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [ -2.74047852e-02,  -2.73742676e-02],
                        [ -9.29870605e-02,  -9.30175781e-02],
                        [ -1.63024902e-01,  -1.63024902e-01],
                        [ -2.15179443e-01,  -2.15148926e-01],
                        [ -2.32116699e-01,  -2.32116699e-01],
                        [ -2.11486816e-01,  -2.11517334e-01],
                        [ -1.69738770e-01,  -1.69708252e-01],
                        [ -1.32324219e-01,  -1.32324219e-01],
                        [ -1.13647461e-01,  -1.13677979e-01],
                        [ -1.08154297e-01,  -1.08123779e-01],
                        [ -1.02447510e-01,  -1.02416992e-01],
                        [ -9.24682617e-02,  -9.24987793e-02],
                        [ -8.61206055e-02,  -8.61511230e-02],
                        [ -8.84094238e-02,  -8.83483887e-02],
                        [ -9.10949707e-02,  -9.10949707e-02],
                        [ -8.37402344e-02,  -8.37707520e-02],
                        [ -6.57348633e-02,  -6.57043457e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -6.07299805e-03,  -6.10351562e-03],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  8.44116211e-02,   8.44421387e-02],
                        [  1.21612549e-01,   1.21582031e-01],
                        [  1.39221191e-01,   1.39190674e-01],
                        [  1.39495850e-01,   1.39526367e-01],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.30981445e-01,   1.30950928e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.46240234e-01,   1.46270752e-01],
                        [  1.71264648e-01,   1.71234131e-01],
                        [  1.99707031e-01,   1.99707031e-01],
                        [  2.15057373e-01,   2.15087891e-01],
                        [  2.06237793e-01,   2.06237793e-01],
                        [  1.67327881e-01,   1.67297363e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [ -2.01110840e-02,  -2.00805664e-02],
                        [ -1.50756836e-01,  -1.50787354e-01],
                        [ -2.66448975e-01,  -2.66448975e-01],
                        [ -3.29803467e-01,  -3.29772949e-01],
                        [ -3.20526123e-01,  -3.20526123e-01],
                        [ -2.54028320e-01,  -2.54058838e-01],
                        [ -1.77490234e-01,  -1.77459717e-01],
                        [ -1.33850098e-01,  -1.33819580e-01],
                        [ -1.27655029e-01,  -1.27685547e-01],
                        [ -1.33728027e-01,  -1.33728027e-01],
                        [ -1.33636475e-01,  -1.33575439e-01],
                        [ -1.29486084e-01,  -1.29516602e-01],
                        [ -1.27868652e-01,  -1.27929688e-01],
                        [ -1.23046875e-01,  -1.23016357e-01],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -4.65698242e-02,  -4.66003418e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  9.93652344e-02,   9.94262695e-02],
                        [  1.63116455e-01,   1.63085938e-01],
                        [  2.11395264e-01,   2.11364746e-01],
                        [  2.32147217e-01,   2.32177734e-01],
                        [  2.14508057e-01,   2.14508057e-01],
                        [  1.70166016e-01,   1.70104980e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.03698730e-01,   1.03729248e-01],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  8.46557617e-02,   8.46252441e-02],
                        [  8.20617676e-02,   8.20922852e-02],
                        [  8.52661133e-02,   8.52661133e-02],
                        [  9.08813477e-02,   9.08203125e-02],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  9.69848633e-02,   9.70458984e-02],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  6.95800781e-02,   6.95495605e-02],
                        [  5.06591797e-02,   5.06896973e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  3.89404297e-02,   3.89099121e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.44543457e-02,   3.44848633e-02],
                        [  2.80456543e-02,   2.80151367e-02],
                        [  1.89819336e-02,   1.89514160e-02],
                        [  9.30786133e-03,   9.33837891e-03],
                        [  2.53295898e-03,   2.56347656e-03],
                        [  2.13623047e-04,   1.52587891e-04],
                        [ -2.53295898e-03,  -2.50244141e-03],
                        [ -1.29394531e-02,  -1.29089355e-02],
                        [ -2.93273926e-02,  -2.93579102e-02],
                        [ -4.07714844e-02,  -4.08020020e-02],
                        [ -4.20837402e-02,  -4.20532227e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.88183594e-02,  -3.88488770e-02],
                        [ -3.66821289e-02,  -3.66516113e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -1.62353516e-02,  -1.62963867e-02],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [  6.53076172e-03,   6.59179688e-03],
                        [  2.59399414e-03,   2.56347656e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -9.76562500e-03,  -9.73510742e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  5.37109375e-03,   5.31005859e-03],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  2.48413086e-02,   2.48107910e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  3.07617188e-02,   3.07922363e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  5.49621582e-02,   5.49926758e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  5.94787598e-02,   5.94482422e-02],
                        [  5.65185547e-02,   5.65490723e-02],
                        [  5.08728027e-02,   5.09033203e-02],
                        [  3.59191895e-02,   3.58886719e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -5.33142090e-02,  -5.32836914e-02],
                        [ -1.24786377e-01,  -1.24816895e-01],
                        [ -1.91314697e-01,  -1.91345215e-01],
                        [ -2.29553223e-01,  -2.29553223e-01],
                        [ -2.27447510e-01,  -2.27447510e-01],
                        [ -1.92169189e-01,  -1.92199707e-01],
                        [ -1.46240234e-01,  -1.46240234e-01],
                        [ -1.12091064e-01,  -1.12060547e-01],
                        [ -9.76257324e-02,  -9.76562500e-02],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -9.66491699e-02,  -9.66491699e-02],
                        [ -9.64660645e-02,  -9.64660645e-02],
                        [ -9.63745117e-02,  -9.64050293e-02],
                        [ -9.41162109e-02,  -9.41162109e-02],
                        [ -8.47473145e-02,  -8.47167969e-02],
                        [ -6.53381348e-02,  -6.53686523e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [  6.83593750e-03,   6.86645508e-03],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  9.64660645e-02,   9.64355469e-02],
                        [  1.26342773e-01,   1.26373291e-01],
                        [  1.39556885e-01,   1.39587402e-01],
                        [  1.39221191e-01,   1.39190674e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.30279541e-01,   1.30310059e-01],
                        [  1.37420654e-01,   1.37390137e-01],
                        [  1.57287598e-01,   1.57257080e-01],
                        [  1.84478760e-01,   1.84509277e-01],
                        [  2.05535889e-01,   2.05566406e-01],
                        [  2.06359863e-01,   2.06329346e-01],
                        [  1.78009033e-01,   1.78009033e-01],
                        [  1.14837646e-01,   1.14898682e-01],
                        [  1.46179199e-02,   1.45874023e-02],
                        [ -1.12457275e-01,  -1.12457275e-01],
                        [ -2.36816406e-01,  -2.36785889e-01],
                        [ -3.18481445e-01,  -3.18450928e-01],
                        [ -3.28735352e-01,  -3.28796387e-01],
                        [ -2.72827148e-01,  -2.72796631e-01],
                        [ -1.91253662e-01,  -1.91223145e-01],
                        [ -1.31195068e-01,  -1.31225586e-01],
                        [ -1.11114502e-01,  -1.11145020e-01],
                        [ -1.16271973e-01,  -1.16241455e-01],
                        [ -1.23901367e-01,  -1.23870850e-01],
                        [ -1.23992920e-01,  -1.24023438e-01],
                        [ -1.17492676e-01,  -1.17462158e-01],
                        [ -1.06567383e-01,  -1.06567383e-01],
                        [ -8.89892578e-02,  -8.90197754e-02],
                        [ -5.63659668e-02,  -5.63964844e-02],
                        [  3.66210938e-04,   3.96728516e-04],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  1.64306641e-01,   1.64276123e-01],
                        [  2.24548340e-01,   2.24578857e-01],
                        [  2.38830566e-01,   2.38830566e-01],
                        [  2.09838867e-01,   2.09808350e-01],
                        [  1.62933350e-01,   1.62933350e-01],
                        [  1.24206543e-01,   1.24237061e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  8.38928223e-02,   8.39233398e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  8.60900879e-02,   8.60595703e-02],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.36901855e-02,   6.37207031e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  6.07299805e-02,   6.06994629e-02],
                        [  5.98754883e-02,   5.99060059e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.21447754e-02,   4.21142578e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  1.81579590e-02,   1.81884766e-02],
                        [  1.13830566e-02,   1.13525391e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.55639648e-03,   1.58691406e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.74255371e-02,  -1.73950195e-02],
                        [ -2.58789062e-02,  -2.58483887e-02],
                        [ -3.22875977e-02,  -3.23181152e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.92150879e-02,  -3.92456055e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  1.11389160e-02,   1.11694336e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -2.77709961e-03,  -2.74658203e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  3.37829590e-02,   3.37524414e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.55432129e-02,   2.55737305e-02],
                        [  1.75476074e-02,   1.75170898e-02],
                        [  1.71203613e-02,   1.70898438e-02],
                        [  2.93273926e-02,   2.93579102e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.43725586e-02,   4.44030762e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [ -1.63574219e-02,  -1.63879395e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -1.43341064e-01,  -1.43310547e-01],
                        [ -1.96044922e-01,  -1.96075439e-01],
                        [ -2.12219238e-01,  -2.12219238e-01],
                        [ -1.89392090e-01,  -1.89361572e-01],
                        [ -1.49963379e-01,  -1.49932861e-01],
                        [ -1.19903564e-01,  -1.19934082e-01],
                        [ -1.05468750e-01,  -1.05468750e-01],
                        [ -9.86328125e-02,  -9.86022949e-02],
                        [ -9.49401855e-02,  -9.49707031e-02],
                        [ -9.53674316e-02,  -9.53979492e-02],
                        [ -9.83886719e-02,  -9.83581543e-02],
                        [ -9.92431641e-02,  -9.92431641e-02],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -3.96728516e-04,  -4.27246094e-04],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.46820068e-01,   1.46820068e-01],
                        [  1.60186768e-01,   1.60186768e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  1.70410156e-01,   1.70410156e-01],
                        [  1.99249268e-01,   1.99249268e-01],
                        [  2.08892822e-01,   2.08892822e-01],
                        [  1.99859619e-01,   1.99859619e-01],
                        [  1.72363281e-01,   1.72393799e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.94396973e-02,   1.94396973e-02],
                        [ -9.99450684e-02,  -9.99145508e-02],
                        [ -2.17132568e-01,  -2.17132568e-01],
                        [ -3.02185059e-01,  -3.02185059e-01],
                        [ -3.27331543e-01,  -3.27331543e-01],
                        [ -2.84454346e-01,  -2.84454346e-01],
                        [ -2.03887939e-01,  -2.03887939e-01],
                        [ -1.37359619e-01,  -1.37329102e-01],
                        [ -1.12243652e-01,  -1.12213135e-01],
                        [ -1.14959717e-01,  -1.14990234e-01],
                        [ -1.21704102e-01,  -1.21704102e-01],
                        [ -1.24847412e-01,  -1.24847412e-01],
                        [ -1.24359131e-01,  -1.24359131e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -3.41796875e-02,  -3.41491699e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  1.16363525e-01,   1.16333008e-01],
                        [  1.83898926e-01,   1.83898926e-01],
                        [  2.14660645e-01,   2.14660645e-01],
                        [  2.06726074e-01,   2.06726074e-01],
                        [  1.78436279e-01,   1.78436279e-01],
                        [  1.45874023e-01,   1.45904541e-01],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  7.82470703e-02,   7.82470703e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  7.73315430e-02,   7.73010254e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  8.25500488e-02,   8.25805664e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  8.36791992e-02,   8.36486816e-02],
                        [  7.97119141e-02,   7.97424316e-02],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -2.73742676e-02,  -2.74047852e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.59399414e-02,  -2.59094238e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  6.92749023e-03,   6.95800781e-03],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  6.10351562e-03,   6.13403320e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  6.09741211e-02,   6.09436035e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  2.43835449e-02,   2.44140625e-02],
                        [ -2.50244141e-02,  -2.50549316e-02],
                        [ -9.25903320e-02,  -9.26208496e-02],
                        [ -1.61865234e-01,  -1.61834717e-01],
                        [ -2.07946777e-01,  -2.07946777e-01],
                        [ -2.15148926e-01,  -2.15179443e-01],
                        [ -1.90765381e-01,  -1.90765381e-01],
                        [ -1.58477783e-01,  -1.58447266e-01],
                        [ -1.36993408e-01,  -1.36993408e-01],
                        [ -1.26617432e-01,  -1.26617432e-01],
                        [ -1.16149902e-01,  -1.16149902e-01],
                        [ -9.92126465e-02,  -9.92126465e-02],
                        [ -8.14819336e-02,  -8.15124512e-02],
                        [ -7.24792480e-02,  -7.24487305e-02],
                        [ -7.12585449e-02,  -7.12280273e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  1.49444580e-01,   1.49444580e-01],
                        [  1.63482666e-01,   1.63482666e-01],
                        [  1.78527832e-01,   1.78527832e-01],
                        [  1.90643311e-01,   1.90643311e-01],
                        [  1.95709229e-01,   1.95678711e-01],
                        [  1.95739746e-01,   1.95739746e-01],
                        [  1.89910889e-01,   1.89941406e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  1.82495117e-02,   1.82495117e-02],
                        [ -9.57031250e-02,  -9.57031250e-02],
                        [ -2.06939697e-01,  -2.06939697e-01],
                        [ -2.86468506e-01,  -2.86468506e-01],
                        [ -3.12591553e-01,  -3.12561035e-01],
                        [ -2.84637451e-01,  -2.84637451e-01],
                        [ -2.26593018e-01,  -2.26623535e-01],
                        [ -1.73522949e-01,  -1.73522949e-01],
                        [ -1.48895264e-01,  -1.48864746e-01],
                        [ -1.49566650e-01,  -1.49566650e-01],
                        [ -1.53930664e-01,  -1.53930664e-01],
                        [ -1.46911621e-01,  -1.46911621e-01],
                        [ -1.31256104e-01,  -1.31256104e-01],
                        [ -1.12548828e-01,  -1.12579346e-01],
                        [ -8.32519531e-02,  -8.32519531e-02],
                        [ -2.98767090e-02,  -2.98461914e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  1.34613037e-01,   1.34613037e-01],
                        [  2.02392578e-01,   2.02392578e-01],
                        [  2.30926514e-01,   2.30926514e-01],
                        [  2.15820312e-01,   2.15820312e-01],
                        [  1.73828125e-01,   1.73828125e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  9.03930664e-02,   9.03930664e-02],
                        [  7.87963867e-02,   7.87963867e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  7.21435547e-02,   7.21435547e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  6.17370605e-02,   6.17675781e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  6.59484863e-02,   6.59179688e-02],
                        [  7.08312988e-02,   7.08618164e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  3.93676758e-03,   3.96728516e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.04260254e-02,  -3.04565430e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.61230469e-02,  -2.60925293e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.84631348e-02,   1.84326172e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  2.07824707e-02,   2.07519531e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  2.28881836e-03,   2.31933594e-03],
                        [  1.38854980e-02,   1.39160156e-02],
                        [  2.79541016e-02,   2.79235840e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -1.06689453e-01,  -1.06689453e-01],
                        [ -1.71051025e-01,  -1.71051025e-01],
                        [ -2.04101562e-01,  -2.04101562e-01],
                        [ -1.95495605e-01,  -1.95495605e-01],
                        [ -1.59698486e-01,  -1.59698486e-01],
                        [ -1.25549316e-01,  -1.25518799e-01],
                        [ -1.09405518e-01,  -1.09405518e-01],
                        [ -1.03393555e-01,  -1.03424072e-01],
                        [ -9.45434570e-02,  -9.45129395e-02],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -7.77587891e-02,  -7.77587891e-02],
                        [ -7.89794922e-02,  -7.89794922e-02],
                        [ -8.09020996e-02,  -8.09020996e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  3.87573242e-02,   3.87268066e-02],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  1.24084473e-01,   1.24114990e-01],
                        [  1.48101807e-01,   1.48101807e-01],
                        [  1.61041260e-01,   1.61010742e-01],
                        [  1.71844482e-01,   1.71844482e-01],
                        [  1.89086914e-01,   1.89086914e-01],
                        [  2.13226318e-01,   2.13226318e-01],
                        [  2.33001709e-01,   2.33001709e-01],
                        [  2.28942871e-01,   2.28973389e-01],
                        [  1.83807373e-01,   1.83807373e-01],
                        [  9.40856934e-02,   9.40551758e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.59362793e-01,  -1.59332275e-01],
                        [ -2.72003174e-01,  -2.72003174e-01],
                        [ -3.35205078e-01,  -3.35205078e-01],
                        [ -3.30535889e-01,  -3.30505371e-01],
                        [ -2.70202637e-01,  -2.70202637e-01],
                        [ -1.97113037e-01,  -1.97113037e-01],
                        [ -1.53503418e-01,  -1.53503418e-01],
                        [ -1.47125244e-01,  -1.47094727e-01],
                        [ -1.53961182e-01,  -1.53961182e-01],
                        [ -1.52709961e-01,  -1.52709961e-01],
                        [ -1.42852783e-01,  -1.42822266e-01],
                        [ -1.28601074e-01,  -1.28601074e-01],
                        [ -1.02264404e-01,  -1.02264404e-01],
                        [ -5.17272949e-02,  -5.16967773e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  1.88751221e-01,   1.88751221e-01],
                        [  2.29461670e-01,   2.29461670e-01],
                        [  2.29888916e-01,   2.29888916e-01],
                        [  2.04559326e-01,   2.04559326e-01],
                        [  1.70074463e-01,   1.70074463e-01],
                        [  1.32568359e-01,   1.32598877e-01],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  6.37817383e-02,   6.37512207e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  7.88574219e-02,   7.88269043e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  8.58459473e-02,   8.58459473e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.42712402e-02,   3.42407227e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -6.04248047e-03,  -6.07299805e-03],
                        [ -1.64794922e-02,  -1.65100098e-02],
                        [ -2.76794434e-02,  -2.76489258e-02],
                        [ -3.81774902e-02,  -3.81469727e-02],
                        [ -4.35485840e-02,  -4.35791016e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -3.92456055e-02,  -3.92150879e-02],
                        [ -3.61022949e-02,  -3.61328125e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  9.85717773e-03,   9.82666016e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -9.45739746e-02,  -9.45739746e-02],
                        [ -1.52313232e-01,  -1.52343750e-01],
                        [ -1.88598633e-01,  -1.88598633e-01],
                        [ -1.88018799e-01,  -1.88018799e-01],
                        [ -1.62506104e-01,  -1.62506104e-01],
                        [ -1.34826660e-01,  -1.34826660e-01],
                        [ -1.14318848e-01,  -1.14318848e-01],
                        [ -9.72900391e-02,  -9.72900391e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -7.20214844e-02,  -7.20520020e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  1.19384766e-01,   1.19354248e-01],
                        [  1.67114258e-01,   1.67114258e-01],
                        [  1.94885254e-01,   1.94885254e-01],
                        [  2.10144043e-01,   2.10144043e-01],
                        [  2.21862793e-01,   2.21862793e-01],
                        [  2.30377197e-01,   2.30377197e-01],
                        [  2.26104736e-01,   2.26104736e-01],
                        [  1.95098877e-01,   1.95098877e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  2.56958008e-02,   2.57263184e-02],
                        [ -9.67712402e-02,  -9.67712402e-02],
                        [ -2.18536377e-01,  -2.18536377e-01],
                        [ -3.12469482e-01,  -3.12438965e-01],
                        [ -3.47351074e-01,  -3.47351074e-01],
                        [ -3.09967041e-01,  -3.09967041e-01],
                        [ -2.30804443e-01,  -2.30773926e-01],
                        [ -1.66992188e-01,  -1.66961670e-01],
                        [ -1.48559570e-01,  -1.48559570e-01],
                        [ -1.57196045e-01,  -1.57196045e-01],
                        [ -1.60919189e-01,  -1.60919189e-01],
                        [ -1.49078369e-01,  -1.49078369e-01],
                        [ -1.26708984e-01,  -1.26739502e-01],
                        [ -9.50012207e-02,  -9.49707031e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [  1.82495117e-02,   1.82189941e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  1.73980713e-01,   1.73980713e-01],
                        [  2.16735840e-01,   2.16735840e-01],
                        [  2.14263916e-01,   2.14263916e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  1.48986816e-01,   1.48986816e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -4.45251465e-02,  -4.45556641e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.80151367e-02,   2.80456543e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  4.33959961e-02,   4.33654785e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -8.48083496e-02,  -8.48083496e-02],
                        [ -1.44317627e-01,  -1.44317627e-01],
                        [ -1.87072754e-01,  -1.87072754e-01],
                        [ -1.98547363e-01,  -1.98547363e-01],
                        [ -1.76879883e-01,  -1.76879883e-01],
                        [ -1.37054443e-01,  -1.37054443e-01],
                        [ -1.00250244e-01,  -1.00250244e-01],
                        [ -7.98645020e-02,  -7.98645020e-02],
                        [ -7.63244629e-02,  -7.63549805e-02],
                        [ -8.09020996e-02,  -8.09020996e-02],
                        [ -8.29467773e-02,  -8.29467773e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -4.46472168e-02,  -4.46166992e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.70532227e-01,   1.70532227e-01],
                        [  1.98211670e-01,   1.98211670e-01],
                        [  2.17956543e-01,   2.17987061e-01],
                        [  2.26165771e-01,   2.26165771e-01],
                        [  2.22045898e-01,   2.22045898e-01],
                        [  2.02484131e-01,   2.02514648e-01],
                        [  1.55700684e-01,   1.55700684e-01],
                        [  7.15942383e-02,   7.15637207e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -1.67480469e-01,  -1.67449951e-01],
                        [ -2.70874023e-01,  -2.70904541e-01],
                        [ -3.27972412e-01,  -3.28002930e-01],
                        [ -3.25958252e-01,  -3.25927734e-01],
                        [ -2.74505615e-01,  -2.74505615e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.58203125e-01,  -1.58172607e-01],
                        [ -1.44104004e-01,  -1.44104004e-01],
                        [ -1.45629883e-01,  -1.45660400e-01],
                        [ -1.37390137e-01,  -1.37390137e-01],
                        [ -1.13494873e-01,  -1.13464355e-01],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  7.70874023e-02,   7.71179199e-02],
                        [  1.46850586e-01,   1.46850586e-01],
                        [  1.96807861e-01,   1.96807861e-01],
                        [  2.12097168e-01,   2.12097168e-01],
                        [  1.93756104e-01,   1.93756104e-01],
                        [  1.60186768e-01,   1.60156250e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  8.26721191e-02,   8.26416016e-02],
                        [  6.86950684e-02,   6.87255859e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  7.40966797e-02,   7.41271973e-02],
                        [  6.94885254e-02,   6.94580078e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.05065918e-02,   5.04760742e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  3.79028320e-02,   3.79333496e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  2.89001465e-02,   2.88696289e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.42517090e-02,   1.42822266e-02],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -2.08435059e-02,  -2.08740234e-02],
                        [ -3.43017578e-02,  -3.42712402e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.22265625e-02,  -3.21960449e-02],
                        [ -3.32641602e-02,  -3.32946777e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.27966309e-02,  -2.27661133e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  1.69372559e-02,   1.69677734e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.74560547e-02,   1.74255371e-02],
                        [  1.39160156e-02,   1.39465332e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.98059082e-02,  -1.97753906e-02],
                        [ -2.27050781e-02,  -2.27355957e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [  3.05175781e-03,   3.08227539e-03],
                        [  9.03320312e-03,   9.00268555e-03],
                        [  9.79614258e-03,   9.82666016e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [ -1.46484375e-03,  -1.49536133e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  9.42993164e-03,   9.39941406e-03],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -1.67419434e-01,  -1.67419434e-01],
                        [ -1.93267822e-01,  -1.93298340e-01],
                        [ -1.81030273e-01,  -1.81030273e-01],
                        [ -1.44500732e-01,  -1.44500732e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -9.62219238e-02,  -9.62219238e-02],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -8.83178711e-02,  -8.83178711e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -8.02307129e-02,  -8.02307129e-02],
                        [ -6.33850098e-02,  -6.34155273e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  1.53686523e-01,   1.53686523e-01],
                        [  1.91192627e-01,   1.91192627e-01],
                        [  2.14447021e-01,   2.14447021e-01],
                        [  2.30377197e-01,   2.30377197e-01],
                        [  2.39105225e-01,   2.39105225e-01],
                        [  2.30926514e-01,   2.30957031e-01],
                        [  1.93359375e-01,   1.93359375e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  1.58081055e-02,   1.58386230e-02],
                        [ -1.05651855e-01,  -1.05651855e-01],
                        [ -2.21710205e-01,  -2.21710205e-01],
                        [ -3.05480957e-01,  -3.05480957e-01],
                        [ -3.34899902e-01,  -3.34899902e-01],
                        [ -3.07678223e-01,  -3.07708740e-01],
                        [ -2.49206543e-01,  -2.49206543e-01],
                        [ -1.96289062e-01,  -1.96289062e-01],
                        [ -1.68090820e-01,  -1.68090820e-01],
                        [ -1.56066895e-01,  -1.56066895e-01],
                        [ -1.41540527e-01,  -1.41540527e-01],
                        [ -1.17187500e-01,  -1.17187500e-01],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.86492920e-01,   1.86492920e-01],
                        [  2.16766357e-01,   2.16766357e-01],
                        [  2.13928223e-01,   2.13928223e-01],
                        [  1.85913086e-01,   1.85913086e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  8.03222656e-02,   8.03222656e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  4.72106934e-02,   4.71801758e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  7.84301758e-02,   7.83996582e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  7.05566406e-02,   7.05871582e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  1.83410645e-02,   1.83715820e-02],
                        [  7.93457031e-03,   7.90405273e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -9.09423828e-03,  -9.06372070e-03],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -3.09448242e-02,  -3.09753418e-02],
                        [ -3.32031250e-02,  -3.31726074e-02],
                        [ -3.07312012e-02,  -3.07006836e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.30310059e-02,   1.30615234e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  1.95922852e-02,   1.95617676e-02],
                        [  2.05383301e-02,   2.05688477e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  5.06591797e-03,   5.03540039e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  6.59179688e-03,   6.56127930e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -1.84631348e-02,  -1.84326172e-02],
                        [ -2.22778320e-02,  -2.22473145e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  1.11083984e-02,   1.11389160e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  4.15039062e-02,   4.14733887e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  4.35180664e-02,   4.35485840e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -1.13952637e-01,  -1.13922119e-01],
                        [ -1.71295166e-01,  -1.71295166e-01],
                        [ -1.95617676e-01,  -1.95648193e-01],
                        [ -1.82098389e-01,  -1.82067871e-01],
                        [ -1.48956299e-01,  -1.48956299e-01],
                        [ -1.20971680e-01,  -1.20971680e-01],
                        [ -1.09405518e-01,  -1.09405518e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -9.43603516e-02,  -9.43908691e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  1.09771729e-01,   1.09771729e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.98822021e-01,   1.98791504e-01],
                        [  2.20642090e-01,   2.20642090e-01],
                        [  2.33642578e-01,   2.33642578e-01],
                        [  2.36358643e-01,   2.36358643e-01],
                        [  2.15667725e-01,   2.15667725e-01],
                        [  1.56341553e-01,   1.56372070e-01],
                        [  5.62133789e-02,   5.62133789e-02],
                        [ -6.98242188e-02,  -6.98242188e-02],
                        [ -1.97265625e-01,  -1.97235107e-01],
                        [ -2.97454834e-01,  -2.97454834e-01],
                        [ -3.42010498e-01,  -3.42041016e-01],
                        [ -3.20983887e-01,  -3.20983887e-01],
                        [ -2.58636475e-01,  -2.58636475e-01],
                        [ -1.97692871e-01,  -1.97692871e-01],
                        [ -1.64154053e-01,  -1.64184570e-01],
                        [ -1.53656006e-01,  -1.53625488e-01],
                        [ -1.47155762e-01,  -1.47155762e-01],
                        [ -1.30889893e-01,  -1.30889893e-01],
                        [ -1.01501465e-01,  -1.01501465e-01],
                        [ -6.06994629e-02,  -6.06689453e-02],
                        [ -9.27734375e-03,  -9.30786133e-03],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  1.17858887e-01,   1.17889404e-01],
                        [  1.73797607e-01,   1.73797607e-01],
                        [  2.04101562e-01,   2.04101562e-01],
                        [  2.01782227e-01,   2.01782227e-01],
                        [  1.75048828e-01,   1.75048828e-01],
                        [  1.40045166e-01,   1.40045166e-01],
                        [  1.08520508e-01,   1.08551025e-01],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  7.58666992e-02,   7.58666992e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  7.36389160e-02,   7.36389160e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  5.71289062e-02,   5.70983887e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  7.78198242e-03,   7.75146484e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [ -1.83105469e-04,  -1.52587891e-04],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [  3.75366211e-03,   3.72314453e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.63574219e-02,  -1.63879395e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -7.93457031e-03,  -7.90405273e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [  4.76074219e-03,   4.73022461e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -1.19750977e-01,  -1.19750977e-01],
                        [ -1.73400879e-01,  -1.73431396e-01],
                        [ -1.97113037e-01,  -1.97113037e-01],
                        [ -1.87133789e-01,  -1.87103271e-01],
                        [ -1.57226562e-01,  -1.57226562e-01],
                        [ -1.26861572e-01,  -1.26861572e-01],
                        [ -1.06719971e-01,  -1.06689453e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.83807373e-01,   1.83837891e-01],
                        [  2.25006104e-01,   2.25006104e-01],
                        [  2.40783691e-01,   2.40783691e-01],
                        [  2.31597900e-01,   2.31597900e-01],
                        [  2.00744629e-01,   2.00775146e-01],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  5.22155762e-02,   5.22155762e-02],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -1.95678711e-01,  -1.95648193e-01],
                        [ -2.93548584e-01,  -2.93579102e-01],
                        [ -3.35266113e-01,  -3.35266113e-01],
                        [ -3.15948486e-01,  -3.15948486e-01],
                        [ -2.58422852e-01,  -2.58453369e-01],
                        [ -2.01538086e-01,  -2.01538086e-01],
                        [ -1.71600342e-01,  -1.71569824e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.46057129e-01,  -1.46057129e-01],
                        [ -1.12701416e-01,  -1.12701416e-01],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.89025879e-01,   1.89025879e-01],
                        [  1.97937012e-01,   1.97937012e-01],
                        [  1.82891846e-01,   1.82891846e-01],
                        [  1.56250000e-01,   1.56280518e-01],
                        [  1.27624512e-01,   1.27624512e-01],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  6.14013672e-02,   6.13708496e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  4.10461426e-02,   4.10156250e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  8.73718262e-02,   8.74023438e-02],
                        [  7.76977539e-02,   7.76977539e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  2.56347656e-02,   2.56042480e-02],
                        [  8.33129883e-03,   8.30078125e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -2.80761719e-03,  -2.83813477e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.70593262e-02,  -1.70898438e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.96630859e-02,  -2.96325684e-02],
                        [ -2.48718262e-02,  -2.49023438e-02],
                        [ -1.49536133e-02,  -1.49841309e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  1.66931152e-02,   1.67236328e-02],
                        [  1.79748535e-02,   1.79443359e-02],
                        [  2.04162598e-02,   2.03857422e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -5.89904785e-02,  -5.89599609e-02],
                        [ -1.09985352e-01,  -1.10015869e-01],
                        [ -1.51977539e-01,  -1.51977539e-01],
                        [ -1.62780762e-01,  -1.62750244e-01],
                        [ -1.42669678e-01,  -1.42669678e-01],
                        [ -1.13525391e-01,  -1.13525391e-01],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -8.96606445e-02,  -8.96606445e-02],
                        [ -8.51745605e-02,  -8.51745605e-02],
                        [ -7.38830566e-02,  -7.38830566e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  5.65185547e-02,   5.65185547e-02],
                        [  1.12121582e-01,   1.12121582e-01],
                        [  1.65924072e-01,   1.65924072e-01],
                        [  2.10632324e-01,   2.10632324e-01],
                        [  2.38311768e-01,   2.38311768e-01],
                        [  2.38220215e-01,   2.38220215e-01],
                        [  2.02819824e-01,   2.02819824e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  2.68249512e-02,   2.68249512e-02],
                        [ -1.03576660e-01,  -1.03576660e-01],
                        [ -2.34863281e-01,  -2.34863281e-01],
                        [ -3.26477051e-01,  -3.26477051e-01],
                        [ -3.48510742e-01,  -3.48510742e-01],
                        [ -3.06304932e-01,  -3.06304932e-01],
                        [ -2.37121582e-01,  -2.37121582e-01],
                        [ -1.83288574e-01,  -1.83288574e-01],
                        [ -1.64093018e-01,  -1.64093018e-01],
                        [ -1.65252686e-01,  -1.65252686e-01],
                        [ -1.56433105e-01,  -1.56433105e-01],
                        [ -1.20910645e-01,  -1.20910645e-01],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  1.28723145e-01,   1.28753662e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  2.08526611e-01,   2.08526611e-01],
                        [  2.06115723e-01,   2.06115723e-01],
                        [  1.84692383e-01,   1.84692383e-01],
                        [  1.57135010e-01,   1.57135010e-01],
                        [  1.28387451e-01,   1.28417969e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  5.15747070e-02,   5.16052246e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  3.51867676e-02,   3.52172852e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  6.58874512e-02,   6.58874512e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.67114258e-02,   6.67114258e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -2.11181641e-02,  -2.11486816e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -5.15747070e-03,  -5.18798828e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  8.39233398e-03,   8.42285156e-03],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.66015625e-02,   1.66320801e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [ -5.49316406e-04,  -5.79833984e-04],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.49536133e-03,   1.52587891e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -3.10363770e-02,  -3.10668945e-02],
                        [ -3.25622559e-02,  -3.25317383e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -6.10351562e-04,  -5.79833984e-04],
                        [  8.23974609e-03,   8.20922852e-03],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  2.63061523e-02,   2.63366699e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -8.43811035e-02,  -8.43811035e-02],
                        [ -1.30401611e-01,  -1.30432129e-01],
                        [ -1.53594971e-01,  -1.53594971e-01],
                        [ -1.49841309e-01,  -1.49841309e-01],
                        [ -1.29333496e-01,  -1.29333496e-01],
                        [ -1.05529785e-01,  -1.05560303e-01],
                        [ -8.60900879e-02,  -8.61206055e-02],
                        [ -7.30285645e-02,  -7.30285645e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  1.07238770e-01,   1.07238770e-01],
                        [  1.69525146e-01,   1.69494629e-01],
                        [  2.21099854e-01,   2.21099854e-01],
                        [  2.40692139e-01,   2.40692139e-01],
                        [  2.20092773e-01,   2.20092773e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  6.71997070e-02,   6.71997070e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -2.86315918e-01,  -2.86315918e-01],
                        [ -3.33709717e-01,  -3.33709717e-01],
                        [ -3.17504883e-01,  -3.17504883e-01],
                        [ -2.61352539e-01,  -2.61352539e-01],
                        [ -2.05230713e-01,  -2.05230713e-01],
                        [ -1.74804688e-01,  -1.74804688e-01],
                        [ -1.64672852e-01,  -1.64672852e-01],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -1.21978760e-01,  -1.21978760e-01],
                        [ -7.67211914e-02,  -7.67211914e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  1.44073486e-01,   1.44073486e-01],
                        [  1.83410645e-01,   1.83410645e-01],
                        [  1.97753906e-01,   1.97753906e-01],
                        [  1.89880371e-01,   1.89880371e-01],
                        [  1.70257568e-01,   1.70257568e-01],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  5.34973145e-02,   5.35278320e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.74645996e-02,   5.74340820e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.28051758e-02,   6.28356934e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  4.46777344e-02,   4.46472168e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.12915039e-03,   1.09863281e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  8.97216797e-03,   8.97216797e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.20239258e-02,  -1.20544434e-02],
                        [ -1.44042969e-02,  -1.43737793e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -1.34277344e-02,  -1.33972168e-02],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  1.97143555e-02,   1.96838379e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -1.09039307e-01,  -1.09069824e-01],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -1.51275635e-01,  -1.51275635e-01],
                        [ -1.34338379e-01,  -1.34338379e-01],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -7.16247559e-02,  -7.16247559e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -2.62756348e-02,  -2.62451172e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  1.50543213e-01,   1.50543213e-01],
                        [  2.01873779e-01,   2.01873779e-01],
                        [  2.21923828e-01,   2.21923828e-01],
                        [  1.95312500e-01,   1.95312500e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  2.30712891e-02,   2.31018066e-02],
                        [ -9.60693359e-02,  -9.60693359e-02],
                        [ -2.15240479e-01,  -2.15240479e-01],
                        [ -3.06579590e-01,  -3.06579590e-01],
                        [ -3.41949463e-01,  -3.41949463e-01],
                        [ -3.16375732e-01,  -3.16375732e-01],
                        [ -2.57720947e-01,  -2.57720947e-01],
                        [ -2.04589844e-01,  -2.04559326e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -1.49017334e-01,  -1.49017334e-01],
                        [ -1.17523193e-01,  -1.17523193e-01],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -3.60717773e-02,  -3.61022949e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.56585693e-01,   1.56585693e-01],
                        [  1.75842285e-01,   1.75872803e-01],
                        [  1.75048828e-01,   1.75048828e-01],
                        [  1.67388916e-01,   1.67388916e-01],
                        [  1.58477783e-01,   1.58477783e-01],
                        [  1.43768311e-01,   1.43768311e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  7.70874023e-02,   7.70874023e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  5.51452637e-02,   5.51452637e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  4.98962402e-02,   4.98962402e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  5.84411621e-02,   5.84411621e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  5.02929688e-02,   5.03234863e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.95312500e-03,   1.92260742e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [  6.10351562e-04,   6.40869141e-04],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -8.19396973e-02,  -8.19396973e-02],
                        [ -1.28509521e-01,  -1.28509521e-01],
                        [ -1.51641846e-01,  -1.51641846e-01],
                        [ -1.45599365e-01,  -1.45599365e-01],
                        [ -1.17248535e-01,  -1.17248535e-01],
                        [ -7.92236328e-02,  -7.92236328e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  1.27716064e-01,   1.27716064e-01],
                        [  1.92993164e-01,   1.92993164e-01],
                        [  2.33154297e-01,   2.33154297e-01],
                        [  2.28576660e-01,   2.28576660e-01],
                        [  1.77795410e-01,   1.77795410e-01],
                        [  8.97216797e-02,   8.97216797e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.56860352e-01,  -1.56860352e-01],
                        [ -2.77435303e-01,  -2.77435303e-01],
                        [ -3.51043701e-01,  -3.51043701e-01],
                        [ -3.54064941e-01,  -3.54064941e-01],
                        [ -3.01269531e-01,  -3.01269531e-01],
                        [ -2.37518311e-01,  -2.37518311e-01],
                        [ -1.99157715e-01,  -1.99157715e-01],
                        [ -1.85821533e-01,  -1.85821533e-01],
                        [ -1.70715332e-01,  -1.70715332e-01],
                        [ -1.34094238e-01,  -1.34094238e-01],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [  4.64782715e-02,   4.65087891e-02],
                        [  1.12548828e-01,   1.12548828e-01],
                        [  1.67816162e-01,   1.67816162e-01],
                        [  1.98699951e-01,   1.98699951e-01],
                        [  2.03918457e-01,   2.03918457e-01],
                        [  1.93572998e-01,   1.93572998e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  5.13916016e-02,   5.13610840e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.59912109e-02,   1.59606934e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  4.97436523e-03,   4.94384766e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -1.05407715e-01,  -1.05407715e-01],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -1.33789062e-01,  -1.33789062e-01],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -9.36889648e-02,  -9.36889648e-02],
                        [ -7.40356445e-02,  -7.40356445e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  1.29241943e-01,   1.29272461e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  2.38555908e-01,   2.38555908e-01],
                        [  2.51983643e-01,   2.51983643e-01],
                        [  2.13745117e-01,   2.13745117e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -1.27319336e-01,  -1.27319336e-01],
                        [ -2.60589600e-01,  -2.60589600e-01],
                        [ -3.51989746e-01,  -3.51989746e-01],
                        [ -3.73107910e-01,  -3.73107910e-01],
                        [ -3.33526611e-01,  -3.33526611e-01],
                        [ -2.73468018e-01,  -2.73468018e-01],
                        [ -2.25708008e-01,  -2.25708008e-01],
                        [ -1.93695068e-01,  -1.93695068e-01],
                        [ -1.65222168e-01,  -1.65222168e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -8.49609375e-02,  -8.49609375e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.72302246e-01,   1.72302246e-01],
                        [  1.94458008e-01,   1.94458008e-01],
                        [  1.95587158e-01,   1.95587158e-01],
                        [  1.82189941e-01,   1.82189941e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  7.42797852e-02,   7.42797852e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.88391113e-02,  -2.88085938e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -1.11389160e-01,  -1.11389160e-01],
                        [ -1.39251709e-01,  -1.39251709e-01],
                        [ -1.36566162e-01,  -1.36566162e-01],
                        [ -1.10748291e-01,  -1.10748291e-01],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  7.84912109e-02,   7.84912109e-02],
                        [  1.34887695e-01,   1.34887695e-01],
                        [  1.94030762e-01,   1.94030762e-01],
                        [  2.30438232e-01,   2.30438232e-01],
                        [  2.22290039e-01,   2.22290039e-01],
                        [  1.62872314e-01,   1.62872314e-01],
                        [  5.89294434e-02,   5.89294434e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -2.06115723e-01,  -2.06115723e-01],
                        [ -3.11004639e-01,  -3.11004639e-01],
                        [ -3.60321045e-01,  -3.60321045e-01],
                        [ -3.47320557e-01,  -3.47320557e-01],
                        [ -2.93792725e-01,  -2.93792725e-01],
                        [ -2.35778809e-01,  -2.35778809e-01],
                        [ -1.96807861e-01,  -1.96807861e-01],
                        [ -1.73431396e-01,  -1.73431396e-01],
                        [ -1.45019531e-01,  -1.45019531e-01],
                        [ -9.69238281e-02,  -9.69238281e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  1.47125244e-01,   1.47125244e-01],
                        [  1.76574707e-01,   1.76574707e-01],
                        [  1.83929443e-01,   1.83929443e-01],
                        [  1.79046631e-01,   1.79016113e-01],
                        [  1.72149658e-01,   1.72149658e-01],
                        [  1.62017822e-01,   1.62017822e-01],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -1.00189209e-01,  -1.00189209e-01],
                        [ -1.33850098e-01,  -1.33850098e-01],
                        [ -1.36108398e-01,  -1.36108398e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -6.67724609e-02,  -6.67724609e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  8.54492188e-02,   8.54492188e-02],
                        [  1.46148682e-01,   1.46148682e-01],
                        [  2.02056885e-01,   2.02056885e-01],
                        [  2.36785889e-01,   2.36785889e-01],
                        [  2.33276367e-01,   2.33276367e-01],
                        [  1.83105469e-01,   1.83105469e-01],
                        [  8.85620117e-02,   8.85620117e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -1.77642822e-01,  -1.77642822e-01],
                        [ -2.93945312e-01,  -2.93945312e-01],
                        [ -3.54980469e-01,  -3.54980469e-01],
                        [ -3.49700928e-01,  -3.49700928e-01],
                        [ -2.98889160e-01,  -2.98889160e-01],
                        [ -2.40661621e-01,  -2.40661621e-01],
                        [ -2.02514648e-01,  -2.02514648e-01],
                        [ -1.82739258e-01,  -1.82739258e-01],
                        [ -1.58416748e-01,  -1.58416748e-01],
                        [ -1.11206055e-01,  -1.11206055e-01],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  1.44195557e-01,   1.44226074e-01],
                        [  1.67083740e-01,   1.67083740e-01],
                        [  1.67083740e-01,   1.67083740e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.54632568e-01,   1.54632568e-01],
                        [  1.56951904e-01,   1.56951904e-01],
                        [  1.49566650e-01,   1.49566650e-01],
                        [  1.25885010e-01,   1.25885010e-01],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  1.95617676e-02,   1.95922852e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  4.36401367e-02,   4.36401367e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  2.26135254e-02,   2.25830078e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -9.61914062e-02,  -9.61914062e-02],
                        [ -1.31195068e-01,  -1.31195068e-01],
                        [ -1.38031006e-01,  -1.38000488e-01],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  2.19177246e-01,   2.19177246e-01],
                        [  2.22442627e-01,   2.22442627e-01],
                        [  1.74163818e-01,   1.74163818e-01],
                        [  7.38525391e-02,   7.38525391e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -1.98120117e-01,  -1.98120117e-01],
                        [ -3.09997559e-01,  -3.09997559e-01],
                        [ -3.65386963e-01,  -3.65386963e-01],
                        [ -3.50463867e-01,  -3.50463867e-01],
                        [ -2.85461426e-01,  -2.85461426e-01],
                        [ -2.17132568e-01,  -2.17132568e-01],
                        [ -1.79779053e-01,  -1.79779053e-01],
                        [ -1.66809082e-01,  -1.66839600e-01],
                        [ -1.47033691e-01,  -1.47033691e-01],
                        [ -1.00982666e-01,  -1.00982666e-01],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.43096924e-01,   1.43096924e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.57867432e-01,   1.57867432e-01],
                        [  1.57684326e-01,   1.57684326e-01],
                        [  1.61315918e-01,   1.61315918e-01],
                        [  1.59362793e-01,   1.59362793e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.13403320e-01,   1.13433838e-01],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  6.00280762e-02,   6.00280762e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  4.91333008e-02,   4.91333008e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -6.10351562e-05,  -9.15527344e-05],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.75061035e-02,  -3.75366211e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.56250000e-02,  -1.55944824e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -1.45721436e-01,  -1.45721436e-01],
                        [ -1.24114990e-01,  -1.24114990e-01],
                        [ -8.87756348e-02,  -8.87756348e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  1.44500732e-01,   1.44500732e-01],
                        [  1.85272217e-01,   1.85272217e-01],
                        [  2.03338623e-01,   2.03338623e-01],
                        [  1.88415527e-01,   1.88415527e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  2.03247070e-02,   2.03247070e-02],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -2.40295410e-01,  -2.40295410e-01],
                        [ -3.29589844e-01,  -3.29589844e-01],
                        [ -3.56719971e-01,  -3.56719971e-01],
                        [ -3.21319580e-01,  -3.21319580e-01],
                        [ -2.54394531e-01,  -2.54394531e-01],
                        [ -1.98242188e-01,  -1.98242188e-01],
                        [ -1.72210693e-01,  -1.72210693e-01],
                        [ -1.59454346e-01,  -1.59454346e-01],
                        [ -1.29394531e-01,  -1.29394531e-01],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.43524170e-01,   1.43524170e-01],
                        [  1.40899658e-01,   1.40899658e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.44989014e-01,   1.44989014e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -1.34185791e-01,  -1.34185791e-01],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -3.68652344e-02,  -3.68652344e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  6.58874512e-02,   6.58874512e-02],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.50756836e-01,   1.50756836e-01],
                        [  1.82678223e-01,   1.82678223e-01],
                        [  1.89086914e-01,   1.89086914e-01],
                        [  1.51092529e-01,   1.51092529e-01],
                        [  6.53381348e-02,   6.53381348e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -1.81518555e-01,  -1.81518555e-01],
                        [ -2.91534424e-01,  -2.91534424e-01],
                        [ -3.52600098e-01,  -3.52600098e-01],
                        [ -3.49517822e-01,  -3.49517822e-01],
                        [ -2.97698975e-01,  -2.97698975e-01],
                        [ -2.32696533e-01,  -2.32696533e-01],
                        [ -1.83380127e-01,  -1.83380127e-01],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -8.21838379e-02,  -8.21838379e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.33331299e-01,   1.33331299e-01],
                        [  1.40136719e-01,   1.40136719e-01],
                        [  1.45568848e-01,   1.45568848e-01],
                        [  1.49322510e-01,   1.49322510e-01],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.26708984e-01,   1.26708984e-01],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  8.02307129e-02,   8.02307129e-02],
                        [  6.62231445e-02,   6.62231445e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -9.57946777e-02,  -9.57946777e-02],
                        [ -1.22589111e-01,  -1.22589111e-01],
                        [ -1.21429443e-01,  -1.21429443e-01],
                        [ -9.88464355e-02,  -9.88464355e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.63482666e-01,   1.63482666e-01],
                        [  1.91711426e-01,   1.91711426e-01],
                        [  1.85943604e-01,   1.85943604e-01],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  4.91333008e-02,   4.91333008e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -2.05841064e-01,  -2.05841064e-01],
                        [ -3.13262939e-01,  -3.13262939e-01],
                        [ -3.67462158e-01,  -3.67462158e-01],
                        [ -3.59802246e-01,  -3.59802246e-01],
                        [ -3.08044434e-01,  -3.08044434e-01],
                        [ -2.48352051e-01,  -2.48352051e-01],
                        [ -2.07336426e-01,  -2.07336426e-01],
                        [ -1.78588867e-01,  -1.78588867e-01],
                        [ -1.35620117e-01,  -1.35620117e-01],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.24450684e-01,   1.24450684e-01],
                        [  1.28021240e-01,   1.28021240e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  1.00128174e-01,   1.00128174e-01],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -8.39233398e-03,  -8.36181641e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  6.22558594e-03,   6.22558594e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -7.04650879e-02,  -7.04650879e-02],
                        [ -1.13250732e-01,  -1.13250732e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -8.31298828e-02,  -8.31298828e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  7.92236328e-02,   7.92236328e-02],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.67541504e-01,   1.67541504e-01],
                        [  1.74041748e-01,   1.74041748e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  5.72204590e-02,   5.72204590e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -1.89086914e-01,  -1.89086914e-01],
                        [ -2.99499512e-01,  -2.99499512e-01],
                        [ -3.58581543e-01,  -3.58581543e-01],
                        [ -3.53027344e-01,  -3.53027344e-01],
                        [ -2.98583984e-01,  -2.98583984e-01],
                        [ -2.31964111e-01,  -2.31964111e-01],
                        [ -1.84844971e-01,  -1.84844971e-01],
                        [ -1.59393311e-01,  -1.59393311e-01],
                        [ -1.30340576e-01,  -1.30340576e-01],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  1.33178711e-01,   1.33178711e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.48864746e-01,   1.48864746e-01],
                        [  1.61132812e-01,   1.61132812e-01],
                        [  1.64550781e-01,   1.64550781e-01],
                        [  1.49230957e-01,   1.49230957e-01],
                        [  1.19201660e-01,   1.19201660e-01],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  9.01489258e-02,   9.01489258e-02],
                        [  9.80834961e-02,   9.80834961e-02],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  6.36596680e-02,   6.36596680e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.86767578e-02,  -1.87072754e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -7.98645020e-02,  -7.98645020e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.59179688e-01,   1.59179688e-01],
                        [  1.62994385e-01,   1.62994385e-01],
                        [  1.24755859e-01,   1.24755859e-01],
                        [  3.94287109e-02,   3.94287109e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -2.10266113e-01,  -2.10266113e-01],
                        [ -3.09020996e-01,  -3.09020996e-01],
                        [ -3.51867676e-01,  -3.51867676e-01],
                        [ -3.36059570e-01,  -3.36059570e-01],
                        [ -2.81768799e-01,  -2.81768799e-01],
                        [ -2.21099854e-01,  -2.21099854e-01],
                        [ -1.77215576e-01,  -1.77215576e-01],
                        [ -1.48162842e-01,  -1.48162842e-01],
                        [ -1.14166260e-01,  -1.14166260e-01],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  6.06079102e-02,   6.06079102e-02],
                        [  9.36279297e-02,   9.36279297e-02],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.57531738e-01,   1.57531738e-01],
                        [  1.68182373e-01,   1.68182373e-01],
                        [  1.62902832e-01,   1.62902832e-01],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  4.18701172e-02,   4.18701172e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.42913818e-01,   1.42913818e-01],
                        [  1.67907715e-01,   1.67907715e-01],
                        [  1.57409668e-01,   1.57409668e-01],
                        [  9.82666016e-02,   9.82666016e-02],
                        [ -5.27954102e-03,  -5.31005859e-03],
                        [ -1.33300781e-01,  -1.33300781e-01],
                        [ -2.57690430e-01,  -2.57690430e-01],
                        [ -3.48846436e-01,  -3.48846436e-01],
                        [ -3.85406494e-01,  -3.85406494e-01],
                        [ -3.66607666e-01,  -3.66607666e-01],
                        [ -3.12835693e-01,  -3.12835693e-01],
                        [ -2.49603271e-01,  -2.49603271e-01],
                        [ -1.90856934e-01,  -1.90856934e-01],
                        [ -1.35131836e-01,  -1.35131836e-01],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  1.30096436e-01,   1.30096436e-01],
                        [  1.52587891e-01,   1.52587891e-01],
                        [  1.48101807e-01,   1.48101807e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.29211426e-01,   1.29211426e-01],
                        [  1.34033203e-01,   1.34033203e-01],
                        [  1.37329102e-01,   1.37329102e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  8.27636719e-02,   8.27636719e-02],
                        [  7.60498047e-02,   7.60498047e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  4.95300293e-02,   4.95300293e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  3.50952148e-03,   3.50952148e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.54174805e-01,   1.54174805e-01],
                        [  1.44592285e-01,   1.44592285e-01],
                        [  9.20104980e-02,   9.20104980e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -1.36230469e-01,  -1.36230469e-01],
                        [ -2.66937256e-01,  -2.66937256e-01],
                        [ -3.56170654e-01,  -3.56170654e-01],
                        [ -3.81042480e-01,  -3.81042480e-01],
                        [ -3.47442627e-01,  -3.47442627e-01],
                        [ -2.82501221e-01,  -2.82501221e-01],
                        [ -2.18414307e-01,  -2.18414307e-01],
                        [ -1.71203613e-01,  -1.71203613e-01],
                        [ -1.30279541e-01,  -1.30279541e-01],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  1.32843018e-01,   1.32843018e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  1.27105713e-01,   1.27105713e-01],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  6.14624023e-02,   6.14624023e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -8.09631348e-02,  -8.09631348e-02],
                        [ -9.86938477e-02,  -9.86938477e-02],
                        [ -8.87756348e-02,  -8.87756348e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  1.03790283e-01,   1.03790283e-01],
                        [  1.43585205e-01,   1.43585205e-01],
                        [  1.68823242e-01,   1.68823242e-01],
                        [  1.68914795e-01,   1.68914795e-01],
                        [  1.31378174e-01,   1.31378174e-01],
                        [  4.52880859e-02,   4.52880859e-02],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -2.29827881e-01,  -2.29827881e-01],
                        [ -3.46527100e-01,  -3.46527100e-01],
                        [ -3.99261475e-01,  -3.99261475e-01],
                        [ -3.80981445e-01,  -3.80981445e-01],
                        [ -3.15704346e-01,  -3.15704346e-01],
                        [ -2.41088867e-01,  -2.41088867e-01],
                        [ -1.82189941e-01,  -1.82189941e-01],
                        [ -1.35772705e-01,  -1.35772705e-01],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  1.18652344e-01,   1.18652344e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  1.03912354e-01,   1.03912354e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  9.52758789e-02,   9.52758789e-02],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.13739014e-01,   1.13739014e-01],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  1.09863281e-03,   1.09863281e-03],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  2.28881836e-03,   2.28881836e-03],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.31988525e-01,   1.31988525e-01],
                        [  1.37298584e-01,   1.37298584e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  4.56237793e-02,   4.56237793e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -2.04895020e-01,  -2.04895020e-01],
                        [ -3.18786621e-01,  -3.18786621e-01],
                        [ -3.66180420e-01,  -3.66180420e-01],
                        [ -3.41339111e-01,  -3.41339111e-01],
                        [ -2.74963379e-01,  -2.74963379e-01],
                        [ -2.06085205e-01,  -2.06085205e-01],
                        [ -1.57196045e-01,  -1.57196045e-01],
                        [ -1.24755859e-01,  -1.24755859e-01],
                        [ -8.83178711e-02,  -8.83178711e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  8.50524902e-02,   8.50524902e-02],
                        [  7.98339844e-02,   7.98339844e-02],
                        [  7.61413574e-02,   7.61413574e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  1.04949951e-01,   1.04949951e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  7.05261230e-02,   7.05261230e-02],
                        [  8.57238770e-02,   8.57238770e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  1.23596191e-01,   1.23596191e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  9.93957520e-02,   9.93957520e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  6.79321289e-02,   6.79321289e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  7.68737793e-02,   7.68737793e-02],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.58142090e-01,   1.58142090e-01],
                        [  1.81945801e-01,   1.81945801e-01],
                        [  1.84417725e-01,   1.84417725e-01],
                        [  1.51092529e-01,   1.51092529e-01],
                        [  6.64672852e-02,   6.64672852e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -2.33764648e-01,  -2.33764648e-01],
                        [ -3.74725342e-01,  -3.74725342e-01],
                        [ -4.48150635e-01,  -4.48150635e-01],
                        [ -4.38568115e-01,  -4.38568115e-01],
                        [ -3.69171143e-01,  -3.69171143e-01],
                        [ -2.84088135e-01,  -2.84088135e-01],
                        [ -2.15728760e-01,  -2.15728760e-01],
                        [ -1.63574219e-01,  -1.63574219e-01],
                        [ -1.04125977e-01,  -1.04125977e-01],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.42608643e-01,   1.42608643e-01],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.26129150e-01,   1.26129150e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  8.77990723e-02,   8.77990723e-02],
                        [  9.28649902e-02,   9.28649902e-02],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  2.88391113e-02,   2.88391113e-02],
                        [ -1.04705811e-01,  -1.04705811e-01],
                        [ -2.53570557e-01,  -2.53570557e-01],
                        [ -3.67950439e-01,  -3.67950439e-01],
                        [ -4.13330078e-01,  -4.13330078e-01],
                        [ -3.85742188e-01,  -3.85742188e-01],
                        [ -3.10119629e-01,  -3.10119629e-01],
                        [ -2.26593018e-01,  -2.26593018e-01],
                        [ -1.63116455e-01,  -1.63116455e-01],
                        [ -1.15295410e-01,  -1.15295410e-01],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  8.92944336e-02,   8.92944336e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.15509033e-01,   1.15509033e-01],
                        [  1.18133545e-01,   1.18133545e-01],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.03607178e-01,   1.03607178e-01],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.07696533e-01,  -1.07696533e-01],
                        [ -2.25097656e-01,  -2.25097656e-01],
                        [ -3.14666748e-01,  -3.14666748e-01],
                        [ -3.44451904e-01,  -3.44451904e-01],
                        [ -3.13201904e-01,  -3.13201904e-01],
                        [ -2.49145508e-01,  -2.49145508e-01],
                        [ -1.87713623e-01,  -1.87713623e-01],
                        [ -1.45233154e-01,  -1.45233154e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.20910645e-01,   1.20910645e-01],
                        [  1.23413086e-01,   1.23413086e-01],
                        [  1.19537354e-01,   1.19537354e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  6.70166016e-02,   6.70166016e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  4.46472168e-02,   4.46472168e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [ -1.05590820e-01,  -1.05590820e-01],
                        [ -2.28515625e-01,  -2.28515625e-01],
                        [ -3.17199707e-01,  -3.17199707e-01],
                        [ -3.40179443e-01,  -3.40179443e-01],
                        [ -3.02337646e-01,  -3.02337646e-01],
                        [ -2.36267090e-01,  -2.36267090e-01],
                        [ -1.75781250e-01,  -1.75781250e-01],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -1.06719971e-01,  -1.06719971e-01],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  1.04339600e-01,   1.04339600e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.24816895e-01,   1.24816895e-01],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  7.87963867e-02,   7.87963867e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  5.30395508e-02,   5.30395508e-02],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.39068604e-01,   1.39068604e-01],
                        [  1.27441406e-01,   1.27441406e-01],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -1.74621582e-01,  -1.74621582e-01],
                        [ -2.78472900e-01,  -2.78472900e-01],
                        [ -3.37677002e-01,  -3.37677002e-01],
                        [ -3.36181641e-01,  -3.36181641e-01],
                        [ -2.87384033e-01,  -2.87384033e-01],
                        [ -2.21862793e-01,  -2.21862793e-01],
                        [ -1.63574219e-01,  -1.63574219e-01],
                        [ -1.15356445e-01,  -1.15356445e-01],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  7.93151855e-02,   7.93151855e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.46679688e-02,   3.46679688e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  4.61425781e-02,   4.61425781e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.46301270e-01,   1.46301270e-01],
                        [  1.70135498e-01,   1.70135498e-01],
                        [  1.82250977e-01,   1.82250977e-01],
                        [  1.72485352e-01,   1.72485352e-01],
                        [  1.27838135e-01,   1.27838135e-01],
                        [  4.04968262e-02,   4.04968262e-02],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -2.14599609e-01,  -2.14599609e-01],
                        [ -3.25531006e-01,  -3.25531006e-01],
                        [ -3.85253906e-01,  -3.85253906e-01],
                        [ -3.81866455e-01,  -3.81866455e-01],
                        [ -3.30902100e-01,  -3.30902100e-01],
                        [ -2.64434814e-01,  -2.64434814e-01],
                        [ -2.03674316e-01,  -2.03674316e-01],
                        [ -1.46514893e-01,  -1.46514893e-01],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  9.61914062e-02,   9.61914062e-02],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  8.92333984e-02,   8.92333984e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  7.33642578e-02,   7.33642578e-02],
                        [  6.13708496e-02,   6.13708496e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.93164062e-02,   4.93164062e-02],
                        [  4.68750000e-02,   4.68750000e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -6.79931641e-02,  -6.79931641e-02],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  4.08935547e-03,   4.08935547e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.26220703e-01,   1.26220703e-01],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -9.66796875e-02,  -9.66796875e-02],
                        [ -2.06481934e-01,  -2.06481934e-01],
                        [ -2.99987793e-01,  -2.99987793e-01],
                        [ -3.53424072e-01,  -3.53424072e-01],
                        [ -3.54766846e-01,  -3.54766846e-01],
                        [ -3.11798096e-01,  -3.11798096e-01],
                        [ -2.48382568e-01,  -2.48382568e-01],
                        [ -1.87530518e-01,  -1.87530518e-01],
                        [ -1.35162354e-01,  -1.35162354e-01],
                        [ -8.12988281e-02,  -8.12988281e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  6.28356934e-02,   6.28356934e-02],
                        [  4.10766602e-02,   4.10766602e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -5.25207520e-02,  -5.25207520e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  1.29302979e-01,   1.29302979e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.53320312e-01,   1.53320312e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  7.21130371e-02,   7.21130371e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.33728027e-01,  -1.33728027e-01],
                        [ -2.46704102e-01,  -2.46704102e-01],
                        [ -3.24554443e-01,  -3.24554443e-01],
                        [ -3.49670410e-01,  -3.49670410e-01],
                        [ -3.29193115e-01,  -3.29193115e-01],
                        [ -2.85278320e-01,  -2.85278320e-01],
                        [ -2.37518311e-01,  -2.37518311e-01],
                        [ -1.91802979e-01,  -1.91802979e-01],
                        [ -1.42639160e-01,  -1.42639160e-01],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  1.19812012e-01,   1.19812012e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.43646240e-01,   1.43615723e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  7.39746094e-02,   7.39440918e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  6.30493164e-02,   6.30493164e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  2.04467773e-03,   2.07519531e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -2.07824707e-02,  -2.07519531e-02],
                        [ -2.32543945e-02,  -2.32238770e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -3.05175781e-04,  -2.74658203e-04],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.99987793e-02,  -2.99682617e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -5.26123047e-02,  -5.25817871e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -4.74853516e-02,  -4.74548340e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.98364258e-03,  -1.95312500e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  6.83593750e-03,   6.86645508e-03],
                        [  1.15051270e-02,   1.15356445e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  1.91345215e-02,   1.91650391e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -2.10571289e-03,  -2.07519531e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -4.24194336e-03,  -4.21142578e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  7.08312988e-02,   7.08312988e-02],
                        [  9.59472656e-02,   9.59777832e-02],
                        [  1.17584229e-01,   1.17614746e-01],
                        [  1.33148193e-01,   1.33178711e-01],
                        [  1.42395020e-01,   1.42395020e-01],
                        [  1.39190674e-01,   1.39190674e-01],
                        [  1.07330322e-01,   1.07330322e-01],
                        [  3.24096680e-02,   3.24096680e-02],
                        [ -8.06884766e-02,  -8.06884766e-02],
                        [ -2.04040527e-01,  -2.04040527e-01],
                        [ -3.00750732e-01,  -3.00750732e-01],
                        [ -3.44635010e-01,  -3.44635010e-01],
                        [ -3.33404541e-01,  -3.33404541e-01],
                        [ -2.87872314e-01,  -2.87872314e-01],
                        [ -2.36083984e-01,  -2.36053467e-01],
                        [ -1.93450928e-01,  -1.93420410e-01],
                        [ -1.56951904e-01,  -1.56951904e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -6.27746582e-02,  -6.27746582e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  7.31811523e-02,   7.32116699e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  9.50317383e-02,   9.50317383e-02],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  7.08618164e-02,   7.08312988e-02],
                        [  5.35278320e-02,   5.34973145e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -1.76696777e-02,  -1.77001953e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -5.46264648e-03,  -5.49316406e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.32641602e-02,   3.32336426e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.02624512e-02,   5.02319336e-02],
                        [  4.41894531e-02,   4.41894531e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.68859863e-02,   2.68554688e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  1.44958496e-02,   1.44653320e-02],
                        [  8.33129883e-03,   8.30078125e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -5.85937500e-03,  -5.88989258e-03],
                        [ -6.46972656e-03,  -6.50024414e-03],
                        [ -5.06591797e-03,  -5.09643555e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  5.73730469e-03,   5.70678711e-03],
                        [  1.40991211e-02,   1.40686035e-02],
                        [  1.73645020e-02,   1.73339844e-02],
                        [  1.28479004e-02,   1.28173828e-02],
                        [  6.01196289e-03,   5.98144531e-03],
                        [  3.99780273e-03,   3.96728516e-03],
                        [  8.48388672e-03,   8.45336914e-03],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.96838379e-02,   1.96533203e-02],
                        [  1.70898438e-02,   1.70593262e-02],
                        [  8.33129883e-03,   8.30078125e-03],
                        [  0.00000000e+00,  -3.05175781e-05],
                        [ -4.27246094e-04,  -4.57763672e-04],
                        [  6.37817383e-03,   6.34765625e-03],
                        [  1.20544434e-02,   1.20239258e-02],
                        [  1.18103027e-02,   1.17797852e-02],
                        [  9.91821289e-03,   9.88769531e-03],
                        [  1.21154785e-02,   1.20544434e-02],
                        [  1.83105469e-02,   1.82800293e-02],
                        [  2.39868164e-02,   2.39562988e-02],
                        [  2.35595703e-02,   2.35290527e-02],
                        [  1.49230957e-02,   1.48925781e-02],
                        [  2.19726562e-03,   2.16674805e-03],
                        [ -8.94165039e-03,  -8.97216797e-03],
                        [ -1.68457031e-02,  -1.68762207e-02],
                        [ -2.30102539e-02,  -2.30407715e-02],
                        [ -2.80761719e-02,  -2.81066895e-02],
                        [ -3.06396484e-02,  -3.06701660e-02],
                        [ -3.03344727e-02,  -3.03649902e-02],
                        [ -2.95104980e-02,  -2.95410156e-02],
                        [ -3.14025879e-02,  -3.14331055e-02],
                        [ -3.74755859e-02,  -3.75366211e-02],
                        [ -4.59289551e-02,  -4.59594727e-02],
                        [ -5.14831543e-02,  -5.15136719e-02],
                        [ -4.88281250e-02,  -4.88586426e-02],
                        [ -3.79028320e-02,  -3.79333496e-02],
                        [ -2.55737305e-02,  -2.56042480e-02],
                        [ -1.87683105e-02,  -1.87988281e-02],
                        [ -1.67541504e-02,  -1.67846680e-02],
                        [ -1.40991211e-02,  -1.41296387e-02],
                        [ -8.91113281e-03,  -8.94165039e-03],
                        [ -5.24902344e-03,  -5.27954102e-03],
                        [ -6.80541992e-03,  -6.83593750e-03],
                        [ -1.27868652e-02,  -1.28173828e-02],
                        [ -2.09350586e-02,  -2.09655762e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.33557129e-02,  -3.33862305e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -4.97436523e-03,  -5.00488281e-03],
                        [  6.50024414e-03,   6.46972656e-03],
                        [  1.34277344e-02,   1.33972168e-02],
                        [  1.51977539e-02,   1.51672363e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  1.28173828e-03,   1.25122070e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  9.33227539e-02,   9.33532715e-02],
                        [  1.13983154e-01,   1.13983154e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.45751953e-01,   1.45751953e-01],
                        [  1.47033691e-01,   1.47064209e-01],
                        [  1.30554199e-01,   1.30584717e-01],
                        [  8.86840820e-02,   8.87145996e-02],
                        [  1.58691406e-02,   1.58996582e-02],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -1.89514160e-01,  -1.89483643e-01],
                        [ -2.73101807e-01,  -2.73101807e-01],
                        [ -3.14270020e-01,  -3.14239502e-01],
                        [ -3.11859131e-01,  -3.11828613e-01],
                        [ -2.80853271e-01,  -2.80822754e-01],
                        [ -2.42156982e-01,  -2.42126465e-01],
                        [ -2.10662842e-01,  -2.10632324e-01],
                        [ -1.86126709e-01,  -1.86096191e-01],
                        [ -1.54296875e-01,  -1.54266357e-01],
                        [ -1.00830078e-01,  -1.00769043e-01],
                        [ -2.80456543e-02,  -2.79846191e-02],
                        [  4.33349609e-02,   4.33654785e-02],
                        [  9.16137695e-02,   9.16442871e-02],
                        [  1.11816406e-01,   1.11846924e-01],
                        [  1.16424561e-01,   1.16485596e-01],
                        [  1.20697021e-01,   1.20758057e-01],
                        [  1.28326416e-01,   1.28387451e-01],
                        [  1.30798340e-01,   1.30859375e-01],
                        [  1.18377686e-01,   1.18408203e-01],
                        [  9.10034180e-02,   9.10644531e-02],
                        [  5.94482422e-02,   5.95092773e-02],
                        [  3.54003906e-02,   3.54614258e-02],
                        [  2.13928223e-02,   2.14538574e-02],
                        [  9.76562500e-03,   9.82666016e-03],
                        [ -5.85937500e-03,  -5.79833984e-03],
                        [ -2.02636719e-02,  -2.02026367e-02],
                        [ -2.35900879e-02,  -2.35290527e-02],
                        [ -1.37023926e-02,  -1.36413574e-02],
                        [  3.60107422e-03,   3.66210938e-03],
                        [  2.17895508e-02,   2.18505859e-02],
                        [  3.78417969e-02,   3.79028320e-02],
                        [  5.14221191e-02,   5.14831543e-02],
                        [  6.35375977e-02,   6.36291504e-02],
                        [  7.55920410e-02,   7.56530762e-02],
                        [  8.50219727e-02,   8.50830078e-02],
                        [  8.68835449e-02,   8.69445801e-02],
                        [  8.09936523e-02,   8.10546875e-02],
                        [  7.05566406e-02,   7.06481934e-02],
                        [  5.66406250e-02,   5.67321777e-02],
                        [  3.96423340e-02,   3.97033691e-02],
                        [  2.23999023e-02,   2.24609375e-02],
                        [  9.49096680e-03,   9.55200195e-03],
                        [  2.13623047e-03,   2.19726562e-03],
                        [ -3.02124023e-03,  -2.96020508e-03],
                        [ -8.11767578e-03,  -8.05664062e-03],
                        [ -1.22070312e-02,  -1.21459961e-02],
                        [ -1.44958496e-02,  -1.44348145e-02],
                        [ -1.48925781e-02,  -1.48315430e-02],
                        [ -1.25427246e-02,  -1.24511719e-02],
                        [ -5.31005859e-03,  -5.24902344e-03],
                        [  6.50024414e-03,   6.56127930e-03],
                        [  1.79748535e-02,   1.80358887e-02],
                        [  2.46887207e-02,   2.47497559e-02],
                        [  2.72521973e-02,   2.73132324e-02],
                        [  2.82897949e-02,   2.83508301e-02],
                        [  2.83508301e-02,   2.84118652e-02],
                        [  2.52685547e-02,   2.52990723e-02],
                        [  1.72729492e-02,   1.73339844e-02],
                        [  6.74438477e-03,   6.77490234e-03],
                        [  2.13623047e-04,   2.74658203e-04],
                        [  3.32641602e-03,   3.35693359e-03],
                        [  1.29394531e-02,   1.30004883e-02],
                        [  2.16369629e-02,   2.16674805e-02],
                        [  2.81677246e-02,   2.81982422e-02],
                        [  3.45764160e-02,   3.46069336e-02],
                        [  3.82995605e-02,   3.83300781e-02],
                        [  3.49731445e-02,   3.50036621e-02],
                        [  2.45056152e-02,   2.45361328e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -4.15954590e-02,  -4.15649414e-02],
                        [ -4.72412109e-02,  -4.72106934e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.12500000e-02,  -3.12194824e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.17187500e-02,  -1.17492676e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -3.53698730e-02,  -3.54003906e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.58776855e-02,  -5.59082031e-02],
                        [ -5.64880371e-02,  -5.65185547e-02],
                        [ -4.84924316e-02,  -4.85229492e-02],
                        [ -3.50952148e-02,  -3.51257324e-02],
                        [ -2.36816406e-02,  -2.37121582e-02],
                        [ -1.66625977e-02,  -1.67236328e-02],
                        [ -1.11999512e-02,  -1.12304688e-02],
                        [ -5.49316406e-03,  -5.55419922e-03],
                        [ -3.66210938e-04,  -4.27246094e-04],
                        [  4.76074219e-03,   4.69970703e-03],
                        [  1.04064941e-02,   1.03454590e-02],
                        [  1.38549805e-02,   1.37939453e-02],
                        [  1.32446289e-02,   1.31835938e-02],
                        [  1.18103027e-02,   1.17492676e-02],
                        [  1.41296387e-02,   1.40380859e-02],
                        [  1.97143555e-02,   1.96533203e-02],
                        [  2.32238770e-02,   2.31323242e-02],
                        [  2.16369629e-02,   2.15454102e-02],
                        [  1.69677734e-02,   1.68762207e-02],
                        [  1.22985840e-02,   1.22070312e-02],
                        [  1.01928711e-02,   1.01013184e-02],
                        [  1.20239258e-02,   1.19323730e-02],
                        [  1.70898438e-02,   1.69982910e-02],
                        [  2.44750977e-02,   2.43835449e-02],
                        [  3.39050293e-02,   3.38134766e-02],
                        [  4.58679199e-02,   4.57763672e-02],
                        [  6.18896484e-02,   6.17980957e-02],
                        [  8.18176270e-02,   8.17260742e-02],
                        [  1.02203369e-01,   1.02081299e-01],
                        [  1.16973877e-01,   1.16851807e-01],
                        [  1.16577148e-01,   1.16485596e-01],
                        [  8.72802734e-02,   8.71887207e-02],
                        [  1.79138184e-02,   1.78222656e-02],
                        [ -8.68530273e-02,  -8.69445801e-02],
                        [ -2.00195312e-01,  -2.00317383e-01],
                        [ -2.85552979e-01,  -2.85675049e-01],
                        [ -3.20037842e-01,  -3.20159912e-01],
                        [ -3.08319092e-01,  -3.08441162e-01],
                        [ -2.74963379e-01,  -2.75054932e-01],
                        [ -2.42645264e-01,  -2.42767334e-01],
                        [ -2.17132568e-01,  -2.17254639e-01],
                        [ -1.88568115e-01,  -1.88659668e-01],
                        [ -1.43585205e-01,  -1.43676758e-01],
                        [ -7.90405273e-02,  -7.91320801e-02],
                        [ -6.13403320e-03,  -6.25610352e-03],
                        [  5.78308105e-02,   5.77087402e-02],
                        [  1.01562500e-01,   1.01440430e-01],
                        [  1.24511719e-01,   1.24420166e-01],
                        [  1.32629395e-01,   1.32537842e-01],
                        [  1.32415771e-01,   1.32293701e-01],
                        [  1.29638672e-01,   1.29547119e-01],
                        [  1.28204346e-01,   1.28112793e-01],
                        [  1.27227783e-01,   1.27136230e-01],
                        [  1.21490479e-01,   1.21398926e-01],
                        [  1.05773926e-01,   1.05682373e-01],
                        [  8.02307129e-02,   8.01391602e-02],
                        [  5.07812500e-02,   5.06896973e-02],
                        [  2.35595703e-02,   2.34680176e-02],
                        [  1.52587891e-03,   1.43432617e-03],
                        [ -1.42822266e-02,  -1.43737793e-02],
                        [ -2.27661133e-02,  -2.28271484e-02],
                        [ -2.25830078e-02,  -2.26745605e-02],
                        [ -1.46484375e-02,  -1.47399902e-02],
                        [ -2.25830078e-03,  -2.31933594e-03],
                        [  1.22680664e-02,   1.22070312e-02],
                        [  2.77709961e-02,   2.77099609e-02],
                        [  4.15039062e-02,   4.14428711e-02],
                        [  4.86145020e-02,   4.85534668e-02],
                        [  4.74853516e-02,   4.74243164e-02],
                        [  4.32434082e-02,   4.31823730e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [  3.87878418e-02,   3.87573242e-02],
                        [  3.27148438e-02,   3.26843262e-02],
                        [  2.49938965e-02,   2.49633789e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  2.02636719e-02,   2.02331543e-02],
                        [  2.22473145e-02,   2.22167969e-02],
                        [  2.53295898e-02,   2.52990723e-02],
                        [  2.71911621e-02,   2.71606445e-02],
                        [  2.52380371e-02,   2.52075195e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.46484375e-03,   1.49536133e-03],
                        [ -1.09863281e-03,  -1.06811523e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [  8.23974609e-04,   8.54492188e-04],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [ -3.23486328e-03,  -3.20434570e-03],
                        [ -1.67846680e-03,  -1.61743164e-03],
                        [  7.41577148e-03,   7.47680664e-03],
                        [  2.06604004e-02,   2.07214355e-02],
                        [  3.06091309e-02,   3.06701660e-02],
                        [  3.27453613e-02,   3.28063965e-02],
                        [  2.82287598e-02,   2.82897949e-02],
                        [  2.21252441e-02,   2.21862793e-02],
                        [  1.92260742e-02,   1.93176270e-02],
                        [  2.11791992e-02,   2.12707520e-02],
                        [  2.58483887e-02,   2.59399414e-02],
                        [  2.87780762e-02,   2.88696289e-02],
                        [  2.73742676e-02,   2.74658203e-02],
                        [  2.17590332e-02,   2.18505859e-02],
                        [  1.23901367e-02,   1.24816895e-02],
                        [  3.96728516e-04,   4.88281250e-04],
                        [ -1.23291016e-02,  -1.22375488e-02],
                        [ -2.35900879e-02,  -2.34680176e-02],
                        [ -3.00903320e-02,  -2.99987793e-02],
                        [ -3.07312012e-02,  -3.06091309e-02],
                        [ -2.94189453e-02,  -2.92968750e-02],
                        [ -3.17993164e-02,  -3.16772461e-02],
                        [ -3.86352539e-02,  -3.85131836e-02],
                        [ -4.49829102e-02,  -4.48608398e-02],
                        [ -4.66003418e-02,  -4.64477539e-02],
                        [ -4.47082520e-02,  -4.45861816e-02],
                        [ -4.38232422e-02,  -4.37011719e-02],
                        [ -4.61120605e-02,  -4.59594727e-02],
                        [ -4.87670898e-02,  -4.86450195e-02],
                        [ -4.71496582e-02,  -4.69970703e-02],
                        [ -3.83911133e-02,  -3.82385254e-02],
                        [ -2.31018066e-02,  -2.29492188e-02],
                        [ -7.44628906e-03,  -7.29370117e-03],
                        [  7.62939453e-04,   9.15527344e-04],
                        [  9.15527344e-04,   1.03759766e-03],
                        [ -3.05175781e-05,   1.22070312e-04],
                        [  3.81469727e-03,   3.96728516e-03],
                        [  8.27026367e-03,   8.42285156e-03],
                        [  4.94384766e-03,   5.09643555e-03],
                        [ -4.48608398e-03,  -4.33349609e-03],
                        [ -1.17492676e-02,  -1.15966797e-02],
                        [ -1.48620605e-02,  -1.47399902e-02],
                        [ -1.63574219e-02,  -1.62048340e-02],
                        [ -1.56860352e-02,  -1.55334473e-02],
                        [ -9.67407227e-03,  -9.52148438e-03],
                        [  1.52587891e-03,   1.67846680e-03],
                        [  1.26342773e-02,   1.27563477e-02],
                        [  1.91040039e-02,   1.92260742e-02],
                        [  2.01721191e-02,   2.02941895e-02],
                        [  1.79443359e-02,   1.80664062e-02],
                        [  1.68762207e-02,   1.69982910e-02],
                        [  2.07824707e-02,   2.09350586e-02],
                        [  3.13720703e-02,   3.15246582e-02],
                        [  4.84619141e-02,   4.85839844e-02],
                        [  6.95190430e-02,   6.96411133e-02],
                        [  9.20410156e-02,   9.21630859e-02],
                        [  1.13311768e-01,   1.13403320e-01],
                        [  1.28723145e-01,   1.28845215e-01],
                        [  1.35101318e-01,   1.35192871e-01],
                        [  1.31164551e-01,   1.31286621e-01],
                        [  1.14288330e-01,   1.14379883e-01],
                        [  7.76367188e-02,   7.77282715e-02],
                        [  1.25122070e-02,   1.26037598e-02],
                        [ -8.18786621e-02,  -8.17871094e-02],
                        [ -1.90185547e-01,  -1.90093994e-01],
                        [ -2.83996582e-01,  -2.83905029e-01],
                        [ -3.36425781e-01,  -3.36334229e-01],
                        [ -3.39874268e-01,  -3.39813232e-01],
                        [ -3.08685303e-01,  -3.08624268e-01],
                        [ -2.65838623e-01,  -2.65777588e-01],
                        [ -2.28820801e-01,  -2.28759766e-01],
                        [ -1.98394775e-01,  -1.98333740e-01],
                        [ -1.59057617e-01,  -1.58996582e-01],
                        [ -9.73205566e-02,  -9.72900391e-02],
                        [ -1.90429688e-02,  -1.90124512e-02],
                        [  5.29479980e-02,   5.29785156e-02],
                        [  9.96093750e-02,   9.96398926e-02],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.26342773e-01,   1.26373291e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.27166748e-01,   1.27166748e-01],
                        [  1.23443604e-01,   1.23413086e-01],
                        [  1.12701416e-01,   1.12670898e-01],
                        [  9.61608887e-02,   9.61303711e-02],
                        [  7.89489746e-02,   7.89184570e-02],
                        [  6.25915527e-02,   6.25610352e-02],
                        [  4.31213379e-02,   4.30603027e-02],
                        [  1.83410645e-02,   1.82800293e-02],
                        [ -5.70678711e-03,  -5.76782227e-03],
                        [ -1.97448730e-02,  -1.97753906e-02],
                        [ -2.14843750e-02,  -2.15454102e-02],
                        [ -1.43432617e-02,  -1.44042969e-02],
                        [ -1.49536133e-03,  -1.58691406e-03],
                        [  1.21154785e-02,   1.20239258e-02],
                        [  2.26440430e-02,   2.25524902e-02],
                        [  3.15246582e-02,   3.14331055e-02],
                        [  4.10156250e-02,   4.09240723e-02],
                        [  5.02624512e-02,   5.01708984e-02],
                        [  5.64575195e-02,   5.63659668e-02],
                        [  5.88989258e-02,   5.87768555e-02],
                        [  6.02416992e-02,   6.01196289e-02],
                        [  6.13403320e-02,   6.12182617e-02],
                        [  5.95397949e-02,   5.94177246e-02],
                        [  5.15747070e-02,   5.14526367e-02],
                        [  3.74145508e-02,   3.72924805e-02],
                        [  2.13623047e-02,   2.12402344e-02],
                        [  6.89697266e-03,   6.74438477e-03],
                        [ -4.85229492e-03,  -5.00488281e-03],
                        [ -1.14440918e-02,  -1.15966797e-02],
                        [ -1.27868652e-02,  -1.29394531e-02],
                        [ -1.28173828e-02,  -1.30004883e-02],
                        [ -1.51062012e-02,  -1.52893066e-02],
                        [ -2.03247070e-02,  -2.04772949e-02],
                        [ -2.41699219e-02,  -2.43225098e-02],
                        [ -2.01416016e-02,  -2.03247070e-02],
                        [ -6.19506836e-03,  -6.37817383e-03],
                        [  1.40075684e-02,   1.38244629e-02],
                        [  3.30810547e-02,   3.29284668e-02],
                        [  4.57763672e-02,   4.56237793e-02],
                        [  5.12084961e-02,   5.10253906e-02],
                        [  4.93164062e-02,   4.91333008e-02],
                        [  4.29992676e-02,   4.28466797e-02],
                        [  3.78417969e-02,   3.76892090e-02],
                        [  3.49121094e-02,   3.47290039e-02],
                        [  2.99987793e-02,   2.98156738e-02],
                        [  2.00195312e-02,   1.98364258e-02],
                        [  7.96508789e-03,   7.78198242e-03],
                        [ -1.70898438e-03,  -1.86157227e-03],
                        [ -1.06506348e-02,  -1.08337402e-02],
                        [ -1.92260742e-02,  -1.94091797e-02],
                        [ -2.16979980e-02,  -2.18811035e-02],
                        [ -1.58081055e-02,  -1.59912109e-02],
                        [ -5.09643555e-03,  -5.27954102e-03],
                        [  3.63159180e-03,   3.44848633e-03],
                        [  3.81469727e-03,   3.63159180e-03],
                        [ -5.18798828e-03,  -5.34057617e-03],
                        [ -1.94702148e-02,  -1.96228027e-02],
                        [ -3.26232910e-02,  -3.28063965e-02],
                        [ -3.82995605e-02,  -3.84826660e-02],
                        [ -3.84826660e-02,  -3.86352539e-02],
                        [ -3.86352539e-02,  -3.87878418e-02],
                        [ -3.65905762e-02,  -3.67431641e-02],
                        [ -2.86254883e-02,  -2.87780762e-02],
                        [ -1.78833008e-02,  -1.80053711e-02],
                        [ -1.03454590e-02,  -1.04980469e-02],
                        [ -8.27026367e-03,  -8.39233398e-03],
                        [ -1.05590820e-02,  -1.07116699e-02],
                        [ -1.67846680e-02,  -1.69067383e-02],
                        [ -2.24609375e-02,  -2.25830078e-02],
                        [ -1.90429688e-02,  -1.91650391e-02],
                        [ -6.50024414e-03,  -6.62231445e-03],
                        [  4.39453125e-03,   4.30297852e-03],
                        [  5.43212891e-03,   5.31005859e-03],
                        [ -7.62939453e-04,  -8.54492188e-04],
                        [ -6.16455078e-03,  -6.25610352e-03],
                        [ -7.53784180e-03,  -7.62939453e-03],
                        [ -6.37817383e-03,  -6.43920898e-03],
                        [ -4.05883789e-03,  -4.11987305e-03],
                        [ -3.84521484e-03,  -3.90625000e-03],
                        [ -8.20922852e-03,  -8.27026367e-03],
                        [ -1.19934082e-02,  -1.20544434e-02],
                        [ -7.59887695e-03,  -7.62939453e-03],
                        [  4.76074219e-03,   4.73022461e-03],
                        [  1.75170898e-02,   1.74560547e-02],
                        [  2.51770020e-02,   2.51464844e-02],
                        [  2.90222168e-02,   2.89916992e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  7.15332031e-02,   7.15637207e-02],
                        [  8.57238770e-02,   8.57543945e-02],
                        [  1.02966309e-01,   1.02996826e-01],
                        [  1.20452881e-01,   1.20483398e-01],
                        [  1.33148193e-01,   1.33178711e-01],
                        [  1.35040283e-01,   1.35070801e-01],
                        [  1.12915039e-01,   1.12945557e-01],
                        [  4.88891602e-02,   4.89501953e-02],
                        [ -5.84411621e-02,  -5.83801270e-02],
                        [ -1.82006836e-01,  -1.81915283e-01],
                        [ -2.82501221e-01,  -2.82440186e-01],
                        [ -3.32550049e-01,  -3.32458496e-01],
                        [ -3.28369141e-01,  -3.28277588e-01],
                        [ -2.90405273e-01,  -2.90313721e-01],
                        [ -2.48901367e-01,  -2.48809814e-01],
                        [ -2.18475342e-01,  -2.18383789e-01],
                        [ -1.89880371e-01,  -1.89788818e-01],
                        [ -1.47521973e-01,  -1.47399902e-01],
                        [ -8.79821777e-02,  -8.78601074e-02],
                        [ -2.17590332e-02,  -2.16369629e-02],
                        [  3.56750488e-02,   3.58276367e-02],
                        [  7.31506348e-02,   7.33032227e-02],
                        [  8.97827148e-02,   8.99353027e-02],
                        [  9.56420898e-02,   9.57946777e-02],
                        [  1.02142334e-01,   1.02294922e-01],
                        [  1.10137939e-01,   1.10321045e-01],
                        [  1.12243652e-01,   1.12396240e-01],
                        [  1.05590820e-01,   1.05773926e-01],
                        [  9.51843262e-02,   9.53674316e-02],
                        [  8.48388672e-02,   8.50219727e-02],
                        [  7.27539062e-02,   7.29370117e-02],
                        [  5.77087402e-02,   5.78918457e-02],
                        [  4.37316895e-02,   4.39147949e-02],
                        [  3.58581543e-02,   3.60412598e-02],
                        [  3.40881348e-02,   3.42712402e-02],
                        [  3.44543457e-02,   3.46374512e-02],
                        [  3.50036621e-02,   3.51867676e-02],
                        [  3.71398926e-02,   3.73535156e-02],
                        [  4.20227051e-02,   4.22363281e-02],
                        [  4.97741699e-02,   4.99572754e-02],
                        [  5.80749512e-02,   5.82885742e-02],
                        [  6.10961914e-02,   6.13098145e-02],
                        [  5.66101074e-02,   5.68237305e-02],
                        [  5.03234863e-02,   5.05371094e-02],
                        [  4.63867188e-02,   4.66003418e-02],
                        [  3.88488770e-02,   3.90625000e-02],
                        [  1.93481445e-02,   1.95617676e-02],
                        [ -9.73510742e-03,  -9.52148438e-03],
                        [ -3.46679688e-02,  -3.44848633e-02],
                        [ -4.27856445e-02,  -4.26025391e-02],
                        [ -3.33862305e-02,  -3.31726074e-02],
                        [ -1.89819336e-02,  -1.87988281e-02],
                        [ -1.42517090e-02,  -1.40380859e-02],
                        [ -2.05688477e-02,  -2.03857422e-02],
                        [ -2.56958008e-02,  -2.55126953e-02],
                        [ -1.98669434e-02,  -1.96838379e-02],
                        [ -7.29370117e-03,  -7.08007812e-03],
                        [  1.95312500e-03,   2.13623047e-03],
                        [  3.84521484e-03,   4.02832031e-03],
                        [  1.09863281e-03,   1.28173828e-03],
                        [  2.13623047e-04,   3.96728516e-04],
                        [  8.39233398e-03,   8.57543945e-03],
                        [  2.47192383e-02,   2.48718262e-02],
                        [  3.86047363e-02,   3.87878418e-02],
                        [  4.27551270e-02,   4.29077148e-02],
                        [  4.04357910e-02,   4.05578613e-02],
                        [  3.93676758e-02,   3.95202637e-02],
                        [  4.31823730e-02,   4.33349609e-02],
                        [  4.89807129e-02,   4.91027832e-02],
                        [  5.06286621e-02,   5.07812500e-02],
                        [  4.48303223e-02,   4.49523926e-02],
                        [  3.52172852e-02,   3.53088379e-02],
                        [  2.90222168e-02,   2.91137695e-02],
                        [  2.76184082e-02,   2.77099609e-02],
                        [  2.40478516e-02,   2.41394043e-02],
                        [  1.18713379e-02,   1.19628906e-02],
                        [ -6.16455078e-03,  -6.07299805e-03],
                        [ -2.09655762e-02,  -2.08740234e-02],
                        [ -2.64587402e-02,  -2.63977051e-02],
                        [ -2.28881836e-02,  -2.28271484e-02],
                        [ -1.50146484e-02,  -1.49841309e-02],
                        [ -9.76562500e-03,  -9.70458984e-03],
                        [ -1.03759766e-02,  -1.03454590e-02],
                        [ -1.50756836e-02,  -1.50451660e-02],
                        [ -2.17590332e-02,  -2.17285156e-02],
                        [ -2.82592773e-02,  -2.82287598e-02],
                        [ -3.13720703e-02,  -3.13415527e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.50341797e-02,  -3.50646973e-02],
                        [ -4.27856445e-02,  -4.28161621e-02],
                        [ -4.30603027e-02,  -4.31213379e-02],
                        [ -3.57971191e-02,  -3.58276367e-02],
                        [ -2.54821777e-02,  -2.55432129e-02],
                        [ -1.44348145e-02,  -1.44958496e-02],
                        [ -2.89916992e-03,  -2.96020508e-03],
                        [  5.21850586e-03,   5.15747070e-03],
                        [  6.68334961e-03,   6.62231445e-03],
                        [  5.37109375e-03,   5.27954102e-03],
                        [  4.21142578e-03,   4.11987305e-03],
                        [ -4.27246094e-04,  -5.18798828e-04],
                        [ -9.97924805e-03,  -1.01013184e-02],
                        [ -1.93481445e-02,  -1.94702148e-02],
                        [ -2.38952637e-02,  -2.39868164e-02],
                        [ -2.50854492e-02,  -2.52075195e-02],
                        [ -2.46887207e-02,  -2.48107910e-02],
                        [ -1.96533203e-02,  -1.98059082e-02],
                        [ -1.01623535e-02,  -1.02844238e-02],
                        [ -2.19726562e-03,  -2.34985352e-03],
                        [  1.95312500e-03,   1.80053711e-03],
                        [  5.27954102e-03,   5.09643555e-03],
                        [  8.45336914e-03,   8.27026367e-03],
                        [  9.61303711e-03,   9.42993164e-03],
                        [  9.70458984e-03,   9.52148438e-03],
                        [  1.30615234e-02,   1.28784180e-02],
                        [  2.16979980e-02,   2.15148926e-02],
                        [  3.24401855e-02,   3.22570801e-02],
                        [  4.25720215e-02,   4.23889160e-02],
                        [  5.37109375e-02,   5.34973145e-02],
                        [  6.86645508e-02,   6.84814453e-02],
                        [  8.82873535e-02,   8.81042480e-02],
                        [  1.11419678e-01,   1.11206055e-01],
                        [  1.33728027e-01,   1.33514404e-01],
                        [  1.45568848e-01,   1.45355225e-01],
                        [  1.35528564e-01,   1.35314941e-01],
                        [  9.50012207e-02,   9.47875977e-02],
                        [  1.86767578e-02,   1.84631348e-02],
                        [ -8.87145996e-02,  -8.89587402e-02],
                        [ -2.04986572e-01,  -2.05200195e-01],
                        [ -2.97912598e-01,  -2.98126221e-01],
                        [ -3.43536377e-01,  -3.43750000e-01],
                        [ -3.38043213e-01,  -3.38256836e-01],
                        [ -2.95928955e-01,  -2.96142578e-01],
                        [ -2.40020752e-01,  -2.40234375e-01],
                        [ -1.90765381e-01,  -1.90979004e-01],
                        [ -1.53900146e-01,  -1.54144287e-01],
                        [ -1.16088867e-01,  -1.16333008e-01],
                        [ -6.23474121e-02,  -6.25610352e-02],
                        [  2.38037109e-03,   2.16674805e-03],
                        [  5.69152832e-02,   5.67016602e-02],
                        [  8.71276855e-02,   8.69140625e-02],
                        [  9.66491699e-02,   9.64355469e-02],
                        [  9.48791504e-02,   9.46655273e-02],
                        [  8.84399414e-02,   8.82263184e-02],
                        [  8.37097168e-02,   8.35266113e-02],
                        [  8.30688477e-02,   8.28857422e-02],
                        [  8.09326172e-02,   8.07495117e-02],
                        [  7.27844238e-02,   7.26013184e-02],
                        [  6.22863770e-02,   6.21032715e-02],
                        [  5.47180176e-02,   5.45349121e-02],
                        [  4.85839844e-02,   4.84008789e-02],
                        [  3.89404297e-02,   3.87573242e-02],
                        [  2.64892578e-02,   2.63366699e-02],
                        [  1.81884766e-02,   1.80358887e-02],
                        [  2.00805664e-02,   1.99279785e-02],
                        [  3.20434570e-02,   3.18908691e-02],
                        [  4.78210449e-02,   4.76989746e-02],
                        [  6.12792969e-02,   6.11572266e-02],
                        [  7.13195801e-02,   7.11975098e-02],
                        [  7.94067383e-02,   7.92846680e-02],
                        [  8.47778320e-02,   8.46862793e-02],
                        [  8.34350586e-02,   8.33129883e-02],
                        [  7.24487305e-02,   7.23571777e-02],
                        [  5.36804199e-02,   5.35888672e-02],
                        [  3.02429199e-02,   3.01513672e-02],
                        [  4.88281250e-03,   4.79125977e-03],
                        [ -1.74255371e-02,  -1.75170898e-02],
                        [ -3.09143066e-02,  -3.09753418e-02],
                        [ -3.42407227e-02,  -3.43017578e-02],
                        [ -3.22875977e-02,  -3.23181152e-02],
                        [ -3.18603516e-02,  -3.19213867e-02],
                        [ -3.45764160e-02,  -3.46374512e-02],
                        [ -3.68347168e-02,  -3.68652344e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.89208984e-03,  -1.86157227e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  2.09045410e-02,   2.09350586e-02],
                        [  2.58789062e-02,   2.59094238e-02],
                        [  3.34472656e-02,   3.34777832e-02],
                        [  4.40979004e-02,   4.41284180e-02],
                        [  5.20019531e-02,   5.20324707e-02],
                        [  5.36499023e-02,   5.37109375e-02],
                        [  5.07812500e-02,   5.08728027e-02],
                        [  4.50744629e-02,   4.51354980e-02],
                        [  3.79028320e-02,   3.79638672e-02],
                        [  3.27758789e-02,   3.28674316e-02],
                        [  3.13415527e-02,   3.14331055e-02],
                        [  3.08227539e-02,   3.09143066e-02],
                        [  2.84729004e-02,   2.85949707e-02],
                        [  2.60314941e-02,   2.61230469e-02],
                        [  2.59094238e-02,   2.60314941e-02],
                        [  2.49938965e-02,   2.51159668e-02],
                        [  1.74865723e-02,   1.76086426e-02],
                        [  3.87573242e-03,   4.02832031e-03],
                        [ -9.67407227e-03,  -9.55200195e-03],
                        [ -1.98669434e-02,  -1.97143555e-02],
                        [ -2.79235840e-02,  -2.77709961e-02],
                        [ -3.41186523e-02,  -3.39660645e-02],
                        [ -3.64379883e-02,  -3.62548828e-02],
                        [ -3.56140137e-02,  -3.54614258e-02],
                        [ -3.39965820e-02,  -3.38134766e-02],
                        [ -3.05786133e-02,  -3.03955078e-02],
                        [ -2.44750977e-02,  -2.42919922e-02],
                        [ -1.93481445e-02,  -1.91650391e-02],
                        [ -1.86157227e-02,  -1.84326172e-02],
                        [ -2.00500488e-02,  -1.98364258e-02],
                        [ -1.98974609e-02,  -1.97143555e-02],
                        [ -1.96838379e-02,  -1.94702148e-02],
                        [ -2.26745605e-02,  -2.24609375e-02],
                        [ -2.74353027e-02,  -2.71911621e-02],
                        [ -2.97546387e-02,  -2.95410156e-02],
                        [ -2.82592773e-02,  -2.80456543e-02],
                        [ -2.42309570e-02,  -2.40173340e-02],
                        [ -1.91650391e-02,  -1.89514160e-02],
                        [ -1.46179199e-02,  -1.43737793e-02],
                        [ -1.20239258e-02,  -1.18103027e-02],
                        [ -1.01318359e-02,  -9.88769531e-03],
                        [ -5.76782227e-03,  -5.55419922e-03],
                        [  1.31225586e-03,   1.52587891e-03],
                        [  8.27026367e-03,   8.48388672e-03],
                        [  1.16882324e-02,   1.19018555e-02],
                        [  8.66699219e-03,   8.91113281e-03],
                        [ -1.06811523e-03,  -8.54492188e-04],
                        [ -1.40991211e-02,  -1.38854980e-02],
                        [ -2.57263184e-02,  -2.54821777e-02],
                        [ -3.25622559e-02,  -3.23486328e-02],
                        [ -3.27148438e-02,  -3.25012207e-02],
                        [ -2.47192383e-02,  -2.45056152e-02],
                        [ -9.36889648e-03,  -9.15527344e-03],
                        [  8.85009766e-03,   9.06372070e-03],
                        [  2.48718262e-02,   2.50854492e-02],
                        [  3.66210938e-02,   3.68347168e-02],
                        [  4.51354980e-02,   4.53491211e-02],
                        [  5.24291992e-02,   5.26123047e-02],
                        [  5.89294434e-02,   5.91430664e-02],
                        [  6.39038086e-02,   6.40869141e-02],
                        [  6.69250488e-02,   6.71081543e-02],
                        [  6.80236816e-02,   6.82067871e-02],
                        [  6.86340332e-02,   6.88171387e-02],
                        [  7.16247559e-02,   7.17773438e-02],
                        [  7.85522461e-02,   7.87048340e-02],
                        [  8.72192383e-02,   8.73718262e-02],
                        [  8.96911621e-02,   8.98437500e-02],
                        [  7.12585449e-02,   7.14111328e-02],
                        [  1.65710449e-02,   1.67236328e-02],
                        [ -7.74230957e-02,  -7.72705078e-02],
                        [ -1.92413330e-01,  -1.92291260e-01],
                        [ -2.94067383e-01,  -2.93945312e-01],
                        [ -3.48876953e-01,  -3.48785400e-01],
                        [ -3.43963623e-01,  -3.43872070e-01],
                        [ -2.96417236e-01,  -2.96325684e-01],
                        [ -2.39044189e-01,  -2.38952637e-01],
                        [ -1.94274902e-01,  -1.94183350e-01],
                        [ -1.61376953e-01,  -1.61285400e-01],
                        [ -1.25549316e-01,  -1.25457764e-01],
                        [ -7.53784180e-02,  -7.53173828e-02],
                        [ -1.28479004e-02,  -1.27868652e-02],
                        [  4.83703613e-02,   4.84313965e-02],
                        [  9.18273926e-02,   9.18884277e-02],
                        [  1.11358643e-01,   1.11389160e-01],
                        [  1.15356445e-01,   1.15386963e-01],
                        [  1.17309570e-01,   1.17340088e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.30432129e-01,   1.30432129e-01],
                        [  1.27746582e-01,   1.27716064e-01],
                        [  1.13586426e-01,   1.13555908e-01],
                        [  9.22851562e-02,   9.22546387e-02],
                        [  6.89392090e-02,   6.88781738e-02],
                        [  4.80346680e-02,   4.80041504e-02],
                        [  3.14025879e-02,   3.13415527e-02],
                        [  1.82800293e-02,   1.82495117e-02],
                        [  9.06372070e-03,   9.00268555e-03],
                        [  5.55419922e-03,   5.46264648e-03],
                        [  8.66699219e-03,   8.57543945e-03],
                        [  1.63574219e-02,   1.62658691e-02],
                        [  2.63366699e-02,   2.62451172e-02],
                        [  3.80859375e-02,   3.79638672e-02],
                        [  4.92553711e-02,   4.91333008e-02],
                        [  5.73425293e-02,   5.72204590e-02],
                        [  6.21948242e-02,   6.20727539e-02],
                        [  6.10046387e-02,   6.08825684e-02],
                        [  4.97131348e-02,   4.95910645e-02],
                        [  2.98767090e-02,   2.97241211e-02],
                        [  7.96508789e-03,   7.81250000e-03],
                        [ -9.49096680e-03,  -9.64355469e-03],
                        [ -1.95617676e-02,  -1.97448730e-02],
                        [ -2.31933594e-02,  -2.33459473e-02],
                        [ -2.28881836e-02,  -2.30712891e-02],
                        [ -2.34680176e-02,  -2.36511230e-02],
                        [ -2.88696289e-02,  -2.90527344e-02],
                        [ -3.66821289e-02,  -3.68652344e-02],
                        [ -3.99780273e-02,  -4.01611328e-02],
                        [ -3.28979492e-02,  -3.31115723e-02],
                        [ -1.53808594e-02,  -1.55944824e-02],
                        [  6.62231445e-03,   6.40869141e-03],
                        [  2.63366699e-02,   2.61230469e-02],
                        [  3.87878418e-02,   3.85742188e-02],
                        [  4.24804688e-02,   4.22668457e-02],
                        [  4.26025391e-02,   4.23889160e-02],
                        [  4.63562012e-02,   4.61425781e-02],
                        [  5.45959473e-02,   5.43518066e-02],
                        [  6.04248047e-02,   6.02111816e-02],
                        [  5.60913086e-02,   5.58776855e-02],
                        [  4.26940918e-02,   4.24499512e-02],
                        [  2.98767090e-02,   2.96325684e-02],
                        [  2.42614746e-02,   2.40478516e-02],
                        [  2.41394043e-02,   2.38952637e-02],
                        [  2.54516602e-02,   2.52380371e-02],
                        [  2.68249512e-02,   2.65808105e-02],
                        [  2.64587402e-02,   2.62145996e-02],
                        [  2.14843750e-02,   2.12707520e-02],
                        [  1.30004883e-02,   1.27868652e-02],
                        [  4.88281250e-03,   4.66918945e-03],
                        [ -2.65502930e-03,  -2.89916992e-03],
                        [ -1.08337402e-02,  -1.10778809e-02],
                        [ -1.78527832e-02,  -1.80664062e-02],
                        [ -2.20031738e-02,  -2.22167969e-02],
                        [ -2.42004395e-02,  -2.44140625e-02],
                        [ -2.60314941e-02,  -2.62451172e-02],
                        [ -2.85949707e-02,  -2.88085938e-02],
                        [ -3.17993164e-02,  -3.20129395e-02],
                        [ -3.41491699e-02,  -3.43322754e-02],
                        [ -3.39660645e-02,  -3.41491699e-02],
                        [ -2.88085938e-02,  -2.89916992e-02],
                        [ -1.64489746e-02,  -1.66625977e-02],
                        [ -1.15966797e-03,  -1.34277344e-03],
                        [  8.20922852e-03,   8.02612305e-03],
                        [  8.78906250e-03,   8.60595703e-03],
                        [  3.78417969e-03,   3.60107422e-03],
                        [ -4.97436523e-03,  -5.12695312e-03],
                        [ -1.62048340e-02,  -1.63574219e-02],
                        [ -2.55432129e-02,  -2.56958008e-02],
                        [ -2.85949707e-02,  -2.87475586e-02],
                        [ -2.68249512e-02,  -2.69470215e-02],
                        [ -2.52685547e-02,  -2.53906250e-02],
                        [ -2.49633789e-02,  -2.51159668e-02],
                        [ -2.43835449e-02,  -2.45056152e-02],
                        [ -2.41394043e-02,  -2.42309570e-02],
                        [ -2.39868164e-02,  -2.41088867e-02],
                        [ -2.12097168e-02,  -2.13012695e-02],
                        [ -1.45568848e-02,  -1.46484375e-02],
                        [ -5.52368164e-03,  -5.61523438e-03],
                        [  3.50952148e-03,   3.41796875e-03],
                        [  8.42285156e-03,   8.36181641e-03],
                        [  5.09643555e-03,   5.03540039e-03],
                        [ -4.45556641e-03,  -4.51660156e-03],
                        [ -1.16882324e-02,  -1.17492676e-02],
                        [ -1.07727051e-02,  -1.08032227e-02],
                        [ -3.41796875e-03,  -3.44848633e-03],
                        [  5.76782227e-03,   5.73730469e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.89819336e-02,   1.90124512e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  1.95922852e-02,   1.96228027e-02],
                        [  2.75573730e-02,   2.75878906e-02],
                        [  4.04052734e-02,   4.04357910e-02],
                        [  5.72204590e-02,   5.72509766e-02],
                        [  7.69958496e-02,   7.70263672e-02],
                        [  9.95483398e-02,   9.96093750e-02],
                        [  1.24328613e-01,   1.24389648e-01],
                        [  1.42639160e-01,   1.42700195e-01],
                        [  1.39160156e-01,   1.39221191e-01],
                        [  1.03179932e-01,   1.03271484e-01],
                        [  3.37524414e-02,   3.38439941e-02],
                        [ -6.38427734e-02,  -6.37512207e-02],
                        [ -1.76849365e-01,  -1.76727295e-01],
                        [ -2.78228760e-01,  -2.78106689e-01],
                        [ -3.35784912e-01,  -3.35662842e-01],
                        [ -3.37432861e-01,  -3.37310791e-01],
                        [ -3.00323486e-01,  -3.00170898e-01],
                        [ -2.53265381e-01,  -2.53112793e-01],
                        [ -2.14447021e-01,  -2.14294434e-01],
                        [ -1.81701660e-01,  -1.81549072e-01],
                        [ -1.40930176e-01,  -1.40777588e-01],
                        [ -8.23669434e-02,  -8.22143555e-02],
                        [ -1.17492676e-02,  -1.15966797e-02],
                        [  5.14221191e-02,   5.15747070e-02],
                        [  9.00573730e-02,   9.02404785e-02],
                        [  1.04431152e-01,   1.04614258e-01],
                        [  1.06506348e-01,   1.06719971e-01],
                        [  1.06140137e-01,   1.06323242e-01],
                        [  1.07391357e-01,   1.07604980e-01],
                        [  1.10473633e-01,   1.10656738e-01],
                        [  1.11022949e-01,   1.11236572e-01],
                        [  1.02508545e-01,   1.02722168e-01],
                        [  8.26721191e-02,   8.28857422e-02],
                        [  5.70068359e-02,   5.72509766e-02],
                        [  3.39355469e-02,   3.41491699e-02],
                        [  1.69677734e-02,   1.72119141e-02],
                        [  4.11987305e-03,   4.33349609e-03],
                        [ -4.39453125e-03,  -4.15039062e-03],
                        [ -2.80761719e-03,  -2.59399414e-03],
                        [  1.08947754e-02,   1.11389160e-02],
                        [  2.99377441e-02,   3.01818848e-02],
                        [  4.79125977e-02,   4.81262207e-02],
                        [  6.47277832e-02,   6.49414062e-02],
                        [  7.93762207e-02,   7.95898438e-02],
                        [  8.57543945e-02,   8.59985352e-02],
                        [  7.99560547e-02,   8.02001953e-02],
                        [  6.45751953e-02,   6.47888184e-02],
                        [  4.42810059e-02,   4.45251465e-02],
                        [  2.27050781e-02,   2.29492188e-02],
                        [  3.75366211e-03,   3.96728516e-03],
                        [ -9.85717773e-03,  -9.61303711e-03],
                        [ -1.95617676e-02,  -1.93176270e-02],
                        [ -2.84118652e-02,  -2.81677246e-02],
                        [ -3.59191895e-02,  -3.57055664e-02],
                        [ -3.99475098e-02,  -3.97338867e-02],
                        [ -3.87878418e-02,  -3.86047363e-02],
                        [ -3.02734375e-02,  -3.00598145e-02],
                        [ -1.46179199e-02,  -1.44348145e-02],
                        [  3.23486328e-03,   3.44848633e-03],
                        [  1.87683105e-02,   1.89819336e-02],
                        [  3.02734375e-02,   3.04565430e-02],
                        [  3.69873047e-02,   3.71704102e-02],
                        [  3.81164551e-02,   3.82995605e-02],
                        [  3.33862305e-02,   3.35693359e-02],
                        [  2.45666504e-02,   2.47192383e-02],
                        [  1.46789551e-02,   1.48315430e-02],
                        [  7.41577148e-03,   7.56835938e-03],
                        [  6.98852539e-03,   7.14111328e-03],
                        [  1.24206543e-02,   1.25427246e-02],
                        [  1.77612305e-02,   1.78833008e-02],
                        [  2.25219727e-02,   2.26440430e-02],
                        [  3.10668945e-02,   3.11889648e-02],
                        [  4.17175293e-02,   4.18395996e-02],
                        [  4.68444824e-02,   4.69360352e-02],
                        [  4.33959961e-02,   4.34875488e-02],
                        [  3.58581543e-02,   3.59497070e-02],
                        [  2.86560059e-02,   2.87475586e-02],
                        [  2.28271484e-02,   2.28881836e-02],
                        [  1.82800293e-02,   1.83410645e-02],
                        [  1.37634277e-02,   1.38244629e-02],
                        [  8.97216797e-03,   9.03320312e-03],
                        [  6.59179688e-03,   6.65283203e-03],
                        [  5.95092773e-03,   5.98144531e-03],
                        [  2.28881836e-03,   2.31933594e-03],
                        [ -4.51660156e-03,  -4.48608398e-03],
                        [ -1.08947754e-02,  -1.08642578e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.70898438e-02,  -1.71203613e-02],
                        [ -2.00195312e-02,  -2.00805664e-02],
                        [ -2.71911621e-02,  -2.72521973e-02],
                        [ -3.57055664e-02,  -3.57666016e-02],
                        [ -4.21752930e-02,  -4.22363281e-02],
                        [ -4.37316895e-02,  -4.38232422e-02],
                        [ -3.93371582e-02,  -3.94287109e-02],
                        [ -3.08227539e-02,  -3.09143066e-02],
                        [ -2.21862793e-02,  -2.22778320e-02],
                        [ -1.70593262e-02,  -1.71508789e-02],
                        [ -1.48010254e-02,  -1.48925781e-02],
                        [ -1.04675293e-02,  -1.05895996e-02],
                        [ -3.05175781e-03,  -3.17382812e-03],
                        [  1.80053711e-03,   1.64794922e-03],
                        [  1.06811523e-03,   9.15527344e-04],
                        [ -1.19018555e-03,  -1.34277344e-03],
                        [ -9.15527344e-05,  -2.13623047e-04],
                        [  5.55419922e-03,   5.40161133e-03],
                        [  1.41906738e-02,   1.40075684e-02],
                        [  2.19421387e-02,   2.17590332e-02],
                        [  2.31018066e-02,   2.29187012e-02],
                        [  1.54113770e-02,   1.52282715e-02],
                        [  4.82177734e-03,   4.63867188e-03],
                        [ -1.37329102e-03,  -1.55639648e-03],
                        [ -3.41796875e-03,  -3.60107422e-03],
                        [ -4.82177734e-03,  -5.00488281e-03],
                        [ -3.23486328e-03,  -3.44848633e-03],
                        [  5.27954102e-03,   5.06591797e-03],
                        [  1.76391602e-02,   1.74560547e-02],
                        [  2.78930664e-02,   2.76794434e-02],
                        [  3.56750488e-02,   3.54614258e-02],
                        [  4.47387695e-02,   4.45251465e-02],
                        [  5.76171875e-02,   5.74035645e-02],
                        [  7.47070312e-02,   7.44934082e-02],
                        [  9.49096680e-02,   9.46960449e-02],
                        [  1.15722656e-01,   1.15509033e-01],
                        [  1.31988525e-01,   1.31744385e-01],
                        [  1.33758545e-01,   1.33514404e-01],
                        [  1.08276367e-01,   1.08062744e-01],
                        [  4.66613770e-02,   4.64172363e-02],
                        [ -4.90112305e-02,  -4.92248535e-02],
                        [ -1.62902832e-01,  -1.63116455e-01],
                        [ -2.68829346e-01,  -2.69042969e-01],
                        [ -3.37249756e-01,  -3.37463379e-01],
                        [ -3.48541260e-01,  -3.48785400e-01],
                        [ -3.10394287e-01,  -3.10638428e-01],
                        [ -2.57263184e-01,  -2.57476807e-01],
                        [ -2.18872070e-01,  -2.19085693e-01],
                        [ -1.92230225e-01,  -1.92443848e-01],
                        [ -1.55395508e-01,  -1.55609131e-01],
                        [ -9.85412598e-02,  -9.87548828e-02],
                        [ -2.98461914e-02,  -3.00598145e-02],
                        [  3.47900391e-02,   3.46069336e-02],
                        [  7.97119141e-02,   7.95288086e-02],
                        [  9.97619629e-02,   9.95483398e-02],
                        [  1.04858398e-01,   1.04675293e-01],
                        [  1.08459473e-01,   1.08276367e-01],
                        [  1.13403320e-01,   1.13220215e-01],
                        [  1.14166260e-01,   1.13983154e-01],
                        [  1.08489990e-01,   1.08306885e-01],
                        [  9.87854004e-02,   9.86022949e-02],
                        [  8.58459473e-02,   8.56628418e-02],
                        [  6.98852539e-02,   6.97326660e-02],
                        [  5.28259277e-02,   5.26733398e-02],
                        [  3.54614258e-02,   3.53088379e-02],
                        [  1.84326172e-02,   1.82800293e-02],
                        [  6.68334961e-03,   6.56127930e-03],
                        [  8.27026367e-03,   8.14819336e-03],
                        [  2.56347656e-02,   2.55126953e-02],
                        [  5.09643555e-02,   5.08422852e-02],
                        [  7.34558105e-02,   7.33642578e-02],
                        [  8.76770020e-02,   8.75854492e-02],
                        [  9.32006836e-02,   9.31091309e-02],
                        [  9.00268555e-02,   8.99353027e-02],
                        [  7.51953125e-02,   7.51037598e-02],
                        [  4.72106934e-02,   4.71191406e-02],
                        [  1.23291016e-02,   1.22680664e-02],
                        [ -1.84936523e-02,  -1.85546875e-02],
                        [ -3.84216309e-02,  -3.84826660e-02],
                        [ -4.84619141e-02,  -4.84924316e-02],
                        [ -5.43823242e-02,  -5.44128418e-02],
                        [ -6.05163574e-02,  -6.05468750e-02],
                        [ -6.59179688e-02,  -6.59484863e-02],
                        [ -6.60705566e-02,  -6.61010742e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -4.77905273e-02,  -4.77600098e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  1.96533203e-02,   1.96838379e-02],
                        [  3.77502441e-02,   3.77807617e-02],
                        [  4.82482910e-02,   4.82788086e-02],
                        [  5.54504395e-02,   5.55114746e-02],
                        [  5.89294434e-02,   5.89599609e-02],
                        [  5.68542480e-02,   5.69458008e-02],
                        [  5.34057617e-02,   5.34667969e-02],
                        [  5.20324707e-02,   5.20935059e-02],
                        [  4.84313965e-02,   4.85229492e-02],
                        [  3.93371582e-02,   3.94287109e-02],
                        [  2.94494629e-02,   2.95410156e-02],
                        [  2.39257812e-02,   2.40173340e-02],
                        [  2.23388672e-02,   2.24304199e-02],
                        [  2.16674805e-02,   2.17895508e-02],
                        [  1.95617676e-02,   1.96838379e-02],
                        [  1.48315430e-02,   1.49536133e-02],
                        [  8.63647461e-03,   8.78906250e-03],
                        [  4.66918945e-03,   4.82177734e-03],
                        [  4.82177734e-03,   5.00488281e-03],
                        [  7.38525391e-03,   7.53784180e-03],
                        [  1.00708008e-02,   1.02233887e-02],
                        [  1.16271973e-02,   1.18103027e-02],
                        [  1.14135742e-02,   1.15966797e-02],
                        [  7.84301758e-03,   8.02612305e-03],
                        [ -9.76562500e-04,  -7.93457031e-04],
                        [ -1.23901367e-02,  -1.21765137e-02],
                        [ -2.06298828e-02,  -2.04162598e-02],
                        [ -2.39868164e-02,  -2.37731934e-02],
                        [ -2.45056152e-02,  -2.43225098e-02],
                        [ -2.59094238e-02,  -2.56958008e-02],
                        [ -3.09753418e-02,  -3.07617188e-02],
                        [ -3.73229980e-02,  -3.71093750e-02],
                        [ -4.04968262e-02,  -4.02832031e-02],
                        [ -3.97949219e-02,  -3.95812988e-02],
                        [ -3.62243652e-02,  -3.60107422e-02],
                        [ -2.97546387e-02,  -2.95104980e-02],
                        [ -2.26135254e-02,  -2.23693848e-02],
                        [ -2.01721191e-02,  -1.99584961e-02],
                        [ -2.31018066e-02,  -2.28576660e-02],
                        [ -2.32849121e-02,  -2.30712891e-02],
                        [ -1.60522461e-02,  -1.58081055e-02],
                        [ -8.57543945e-03,  -8.36181641e-03],
                        [ -8.42285156e-03,  -8.20922852e-03],
                        [ -1.22375488e-02,  -1.19934082e-02],
                        [ -1.19323730e-02,  -1.16882324e-02],
                        [ -6.40869141e-03,  -6.19506836e-03],
                        [ -1.28173828e-03,  -1.06811523e-03],
                        [  1.09863281e-03,   1.31225586e-03],
                        [  4.69970703e-03,   4.94384766e-03],
                        [  1.12915039e-02,   1.15051270e-02],
                        [  1.56250000e-02,   1.58386230e-02],
                        [  1.23596191e-02,   1.25732422e-02],
                        [  3.35693359e-03,   3.57055664e-03],
                        [ -5.03540039e-03,  -4.85229492e-03],
                        [ -8.85009766e-03,  -8.63647461e-03],
                        [ -8.27026367e-03,  -8.08715820e-03],
                        [ -4.45556641e-03,  -4.24194336e-03],
                        [  2.62451172e-03,   2.80761719e-03],
                        [  1.09252930e-02,   1.11083984e-02],
                        [  1.64794922e-02,   1.66625977e-02],
                        [  1.95617676e-02,   1.97448730e-02],
                        [  2.42309570e-02,   2.44140625e-02],
                        [  3.21655273e-02,   3.23486328e-02],
                        [  4.37622070e-02,   4.39453125e-02],
                        [  6.12792969e-02,   6.14318848e-02],
                        [  8.54187012e-02,   8.55712891e-02],
                        [  1.11755371e-01,   1.11907959e-01],
                        [  1.32171631e-01,   1.32324219e-01],
                        [  1.38824463e-01,   1.38946533e-01],
                        [  1.23870850e-01,   1.23992920e-01],
                        [  8.12377930e-02,   8.13598633e-02],
                        [  1.14440918e-02,   1.15661621e-02],
                        [ -7.95288086e-02,  -7.94372559e-02],
                        [ -1.81793213e-01,  -1.81701660e-01],
                        [ -2.74841309e-01,  -2.74749756e-01],
                        [ -3.31909180e-01,  -3.31817627e-01],
                        [ -3.38500977e-01,  -3.38439941e-01],
                        [ -3.02581787e-01,  -3.02520752e-01],
                        [ -2.47772217e-01,  -2.47711182e-01],
                        [ -1.98028564e-01,  -1.97967529e-01],
                        [ -1.62811279e-01,  -1.62780762e-01],
                        [ -1.31744385e-01,  -1.31713867e-01],
                        [ -8.75854492e-02,  -8.75854492e-02],
                        [ -2.86254883e-02,  -2.85949707e-02],
                        [  2.99377441e-02,   2.99682617e-02],
                        [  7.53784180e-02,   7.54089355e-02],
                        [  1.05529785e-01,   1.05499268e-01],
                        [  1.21459961e-01,   1.21429443e-01],
                        [  1.24542236e-01,   1.24572754e-01],
                        [  1.20178223e-01,   1.20147705e-01],
                        [  1.15295410e-01,   1.15234375e-01],
                        [  1.09893799e-01,   1.09832764e-01],
                        [  9.60998535e-02,   9.60693359e-02],
                        [  7.10449219e-02,   7.09838867e-02],
                        [  4.41894531e-02,   4.41284180e-02],
                        [  2.85339355e-02,   2.84423828e-02],
                        [  2.72216797e-02,   2.71606445e-02],
                        [  3.19519043e-02,   3.18603516e-02],
                        [  3.38439941e-02,   3.37524414e-02],
                        [  3.20434570e-02,   3.19824219e-02],
                        [  3.14636230e-02,   3.13720703e-02],
                        [  3.67126465e-02,   3.65905762e-02],
                        [  4.78210449e-02,   4.76989746e-02],
                        [  5.93261719e-02,   5.92346191e-02],
                        [  6.41784668e-02,   6.40258789e-02],
                        [  5.78308105e-02,   5.76782227e-02],
                        [  4.22668457e-02,   4.21142578e-02],
                        [  2.49023438e-02,   2.47497559e-02],
                        [  1.16577148e-02,   1.14746094e-02],
                        [  4.76074219e-03,   4.57763672e-03],
                        [  5.52368164e-03,   5.34057617e-03],
                        [  1.05285645e-02,   1.03454590e-02],
                        [  9.97924805e-03,   9.79614258e-03],
                        [ -1.92260742e-03,  -2.10571289e-03],
                        [ -1.92565918e-02,  -1.94396973e-02],
                        [ -3.18908691e-02,  -3.20739746e-02],
                        [ -3.56140137e-02,  -3.58276367e-02],
                        [ -3.19824219e-02,  -3.21960449e-02],
                        [ -2.36206055e-02,  -2.38342285e-02],
                        [ -1.39465332e-02,  -1.41601562e-02],
                        [ -6.13403320e-03,  -6.31713867e-03],
                        [  1.70898438e-03,   1.49536133e-03],
                        [  1.34582520e-02,   1.32141113e-02],
                        [  2.68859863e-02,   2.66723633e-02],
                        [  3.66210938e-02,   3.64074707e-02],
                        [  4.27246094e-02,   4.25109863e-02],
                        [  4.83398438e-02,   4.81262207e-02],
                        [  5.26123047e-02,   5.23986816e-02],
                        [  5.25207520e-02,   5.23071289e-02],
                        [  4.78210449e-02,   4.75769043e-02],
                        [  3.92150879e-02,   3.89709473e-02],
                        [  2.75573730e-02,   2.73437500e-02],
                        [  1.71508789e-02,   1.69372559e-02],
                        [  1.34277344e-02,   1.32141113e-02],
                        [  1.58386230e-02,   1.55944824e-02],
                        [  1.88598633e-02,   1.86462402e-02],
                        [  2.07519531e-02,   2.05383301e-02],
                        [  2.52075195e-02,   2.49938965e-02],
                        [  3.35083008e-02,   3.32946777e-02],
                        [  4.08020020e-02,   4.05883789e-02],
                        [  4.21447754e-02,   4.19616699e-02],
                        [  3.64990234e-02,   3.63159180e-02],
                        [  2.52685547e-02,   2.50854492e-02],
                        [  1.12915039e-02,   1.10778809e-02],
                        [ -3.11279297e-03,  -3.32641602e-03],
                        [ -1.58386230e-02,  -1.60217285e-02],
                        [ -2.41088867e-02,  -2.42919922e-02],
                        [ -2.95104980e-02,  -2.96936035e-02],
                        [ -3.72619629e-02,  -3.74755859e-02],
                        [ -4.68444824e-02,  -4.70275879e-02],
                        [ -5.19409180e-02,  -5.20935059e-02],
                        [ -5.09948730e-02,  -5.11474609e-02],
                        [ -4.86145020e-02,  -4.88281250e-02],
                        [ -4.55017090e-02,  -4.56848145e-02],
                        [ -3.67431641e-02,  -3.68652344e-02],
                        [ -2.47802734e-02,  -2.49023438e-02],
                        [ -1.89208984e-02,  -1.90734863e-02],
                        [ -1.89819336e-02,  -1.91040039e-02],
                        [ -1.64184570e-02,  -1.65405273e-02],
                        [ -9.52148438e-03,  -9.64355469e-03],
                        [ -3.35693359e-03,  -3.47900391e-03],
                        [  8.23974609e-04,   7.32421875e-04],
                        [  5.70678711e-03,   5.61523438e-03],
                        [  9.49096680e-03,   9.36889648e-03],
                        [  7.59887695e-03,   7.50732422e-03],
                        [  1.77001953e-03,   1.73950195e-03],
                        [ -2.04467773e-03,  -2.10571289e-03],
                        [ -1.00708008e-03,  -1.09863281e-03],
                        [  6.07299805e-03,   6.04248047e-03],
                        [  1.84326172e-02,   1.84020996e-02],
                        [  2.99377441e-02,   2.99072266e-02],
                        [  3.19213867e-02,   3.18603516e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  4.30297852e-03,   4.30297852e-03],
                        [ -8.88061523e-03,  -8.91113281e-03],
                        [ -1.85546875e-02,  -1.85852051e-02],
                        [ -2.72521973e-02,  -2.71911621e-02],
                        [ -2.98767090e-02,  -2.98461914e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -6.37817383e-03,  -6.34765625e-03],
                        [  6.07299805e-03,   6.16455078e-03],
                        [  1.62048340e-02,   1.62963867e-02],
                        [  2.94189453e-02,   2.94494629e-02],
                        [  4.40368652e-02,   4.40979004e-02],
                        [  5.57556152e-02,   5.58471680e-02],
                        [  6.89392090e-02,   6.90307617e-02],
                        [  9.06982422e-02,   9.07592773e-02],
                        [  1.17218018e-01,   1.17279053e-01],
                        [  1.36535645e-01,   1.36657715e-01],
                        [  1.39190674e-01,   1.39312744e-01],
                        [  1.17736816e-01,   1.17858887e-01],
                        [  6.39038086e-02,   6.39648438e-02],
                        [ -2.45971680e-02,  -2.44750977e-02],
                        [ -1.35253906e-01,  -1.35070801e-01],
                        [ -2.41546631e-01,  -2.41363525e-01],
                        [ -3.13385010e-01,  -3.13293457e-01],
                        [ -3.31787109e-01,  -3.31695557e-01],
                        [ -3.00598145e-01,  -3.00384521e-01],
                        [ -2.48809814e-01,  -2.48596191e-01],
                        [ -2.11090088e-01,  -2.10937500e-01],
                        [ -1.96838379e-01,  -1.96746826e-01],
                        [ -1.84020996e-01,  -1.83837891e-01],
                        [ -1.46759033e-01,  -1.46545410e-01],
                        [ -8.33435059e-02,  -8.31298828e-02],
                        [ -1.25732422e-02,  -1.24511719e-02],
                        [  4.94995117e-02,   4.96520996e-02],
                        [  9.78698730e-02,   9.80834961e-02],
                        [  1.29547119e-01,   1.29760742e-01],
                        [  1.41784668e-01,   1.41967773e-01],
                        [  1.36932373e-01,   1.37145996e-01],
                        [  1.23748779e-01,   1.23931885e-01],
                        [  1.11755371e-01,   1.11938477e-01],
                        [  1.02630615e-01,   1.02844238e-01],
                        [  9.17053223e-02,   9.19494629e-02],
                        [  7.70263672e-02,   7.72399902e-02],
                        [  6.14929199e-02,   6.16455078e-02],
                        [  4.78210449e-02,   4.80041504e-02],
                        [  3.56445312e-02,   3.58886719e-02],
                        [  2.51159668e-02,   2.53601074e-02],
                        [  2.07214355e-02,   2.09045410e-02],
                        [  2.60620117e-02,   2.62451172e-02],
                        [  4.06799316e-02,   4.09240723e-02],
                        [  6.06994629e-02,   6.09436035e-02],
                        [  7.60803223e-02,   7.62939453e-02],
                        [  7.54089355e-02,   7.55920410e-02],
                        [  5.56335449e-02,   5.58166504e-02],
                        [  2.33764648e-02,   2.35595703e-02],
                        [ -9.24682617e-03,  -9.00268555e-03],
                        [ -3.04565430e-02,  -3.02124023e-02],
                        [ -3.50036621e-02,  -3.48510742e-02],
                        [ -2.72521973e-02,  -2.70996094e-02],
                        [ -1.88598633e-02,  -1.86157227e-02],
                        [ -1.77307129e-02,  -1.74865723e-02],
                        [ -2.26135254e-02,  -2.24304199e-02],
                        [ -3.08227539e-02,  -3.07006836e-02],
                        [ -4.05273438e-02,  -4.03442383e-02],
                        [ -4.52880859e-02,  -4.50744629e-02],
                        [ -3.63769531e-02,  -3.61938477e-02],
                        [ -1.15051270e-02,  -1.13525391e-02],
                        [  1.98059082e-02,   1.99890137e-02],
                        [  4.26940918e-02,   4.28466797e-02],
                        [  4.94079590e-02,   4.95605469e-02],
                        [  4.30908203e-02,   4.32434082e-02],
                        [  3.28063965e-02,   3.29589844e-02],
                        [  2.62756348e-02,   2.63977051e-02],
                        [  2.33764648e-02,   2.34680176e-02],
                        [  2.02941895e-02,   2.04467773e-02],
                        [  1.68762207e-02,   1.70288086e-02],
                        [  1.63269043e-02,   1.64184570e-02],
                        [  2.01416016e-02,   2.02331543e-02],
                        [  2.59704590e-02,   2.60620117e-02],
                        [  3.13110352e-02,   3.14025879e-02],
                        [  3.65600586e-02,   3.66210938e-02],
                        [  4.24804688e-02,   4.26025391e-02],
                        [  4.79736328e-02,   4.80651855e-02],
                        [  4.96826172e-02,   4.97131348e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  3.48205566e-02,   3.49121094e-02],
                        [  2.60314941e-02,   2.61230469e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  3.87573242e-03,   3.93676758e-03],
                        [ -4.15039062e-03,  -4.11987305e-03],
                        [ -1.09558105e-02,  -1.09863281e-02],
                        [ -1.73034668e-02,  -1.73645020e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -3.28063965e-02,  -3.27758789e-02],
                        [ -4.14733887e-02,  -4.15039062e-02],
                        [ -4.58068848e-02,  -4.58374023e-02],
                        [ -4.37316895e-02,  -4.37927246e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -2.98156738e-02,  -2.98461914e-02],
                        [ -2.18811035e-02,  -2.19726562e-02],
                        [ -1.73950195e-02,  -1.74865723e-02],
                        [ -1.67236328e-02,  -1.67846680e-02],
                        [ -1.71508789e-02,  -1.72119141e-02],
                        [ -1.77612305e-02,  -1.78833008e-02],
                        [ -1.96838379e-02,  -1.98059082e-02],
                        [ -2.12707520e-02,  -2.13317871e-02],
                        [ -1.88903809e-02,  -1.89514160e-02],
                        [ -1.36718750e-02,  -1.38244629e-02],
                        [ -1.08337402e-02,  -1.09863281e-02],
                        [ -1.14440918e-02,  -1.15356445e-02],
                        [ -1.33666992e-02,  -1.34582520e-02],
                        [ -1.68762207e-02,  -1.70288086e-02],
                        [ -2.21557617e-02,  -2.23388672e-02],
                        [ -2.44140625e-02,  -2.45361328e-02],
                        [ -1.78833008e-02,  -1.79748535e-02],
                        [ -3.75366211e-03,  -3.93676758e-03],
                        [  1.00402832e-02,   9.85717773e-03],
                        [  1.85546875e-02,   1.84020996e-02],
                        [  2.27966309e-02,   2.26745605e-02],
                        [  2.30407715e-02,   2.28271484e-02],
                        [  1.77917480e-02,   1.75781250e-02],
                        [  9.42993164e-03,   9.30786133e-03],
                        [  2.65502930e-03,   2.53295898e-03],
                        [ -1.46484375e-03,  -1.70898438e-03],
                        [ -5.64575195e-03,  -5.88989258e-03],
                        [ -1.03759766e-02,  -1.04980469e-02],
                        [ -1.17187500e-02,  -1.18408203e-02],
                        [ -7.72094727e-03,  -7.96508789e-03],
                        [ -1.92260742e-03,  -2.16674805e-03],
                        [  4.27246094e-03,   4.15039062e-03],
                        [  1.53808594e-02,   1.52282715e-02],
                        [  3.48510742e-02,   3.46069336e-02],
                        [  6.14624023e-02,   6.12182617e-02],
                        [  9.16748047e-02,   9.15527344e-02],
                        [  1.21063232e-01,   1.20941162e-01],
                        [  1.43127441e-01,   1.42913818e-01],
                        [  1.48712158e-01,   1.48468018e-01],
                        [  1.28723145e-01,   1.28540039e-01],
                        [  7.76367188e-02,   7.74536133e-02],
                        [ -6.71386719e-03,  -6.92749023e-03],
                        [ -1.19262695e-01,  -1.19445801e-01],
                        [ -2.37335205e-01,  -2.37487793e-01],
                        [ -3.23425293e-01,  -3.23638916e-01],
                        [ -3.49700928e-01,  -3.49945068e-01],
                        [ -3.20312500e-01,  -3.20495605e-01],
                        [ -2.65380859e-01,  -2.65502930e-01],
                        [ -2.15301514e-01,  -2.15454102e-01],
                        [ -1.81396484e-01,  -1.81640625e-01],
                        [ -1.55700684e-01,  -1.55914307e-01],
                        [ -1.23809814e-01,  -1.23901367e-01],
                        [ -7.81250000e-02,  -7.82165527e-02],
                        [ -2.26135254e-02,  -2.28576660e-02],
                        [  3.31115723e-02,   3.28369141e-02],
                        [  8.14514160e-02,   8.13293457e-02],
                        [  1.17950439e-01,   1.17919922e-01],
                        [  1.38549805e-01,   1.38427734e-01],
                        [  1.40960693e-01,   1.40747070e-01],
                        [  1.29608154e-01,   1.29394531e-01],
                        [  1.14440918e-01,   1.14379883e-01],
                        [  1.02783203e-01,   1.02752686e-01],
                        [  9.32312012e-02,   9.30480957e-02],
                        [  8.06274414e-02,   8.04138184e-02],
                        [  6.60400391e-02,   6.59484863e-02],
                        [  5.56945801e-02,   5.56640625e-02],
                        [  5.10253906e-02,   5.09338379e-02],
                        [  4.78515625e-02,   4.77294922e-02],
                        [  4.47082520e-02,   4.46166992e-02],
                        [  4.30297852e-02,   4.29687500e-02],
                        [  4.29077148e-02,   4.28161621e-02],
                        [  4.33654785e-02,   4.33044434e-02],
                        [  4.14123535e-02,   4.13818359e-02],
                        [  3.21044922e-02,   3.20434570e-02],
                        [  1.55334473e-02,   1.54418945e-02],
                        [ -9.15527344e-04,  -9.76562500e-04],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -2.16674805e-03,  -2.22778320e-03],
                        [  3.99780273e-03,   3.90625000e-03],
                        [  6.04248047e-03,   6.01196289e-03],
                        [  1.64794922e-03,   1.73950195e-03],
                        [ -7.53784180e-03,  -7.50732422e-03],
                        [ -1.70593262e-02,  -1.71508789e-02],
                        [ -2.26440430e-02,  -2.27050781e-02],
                        [ -2.21862793e-02,  -2.20947266e-02],
                        [ -1.68151855e-02,  -1.66931152e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  1.43432617e-03,   1.40380859e-03],
                        [  1.31530762e-02,   1.32141113e-02],
                        [  2.51770020e-02,   2.53295898e-02],
                        [  3.41491699e-02,   3.42102051e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.65600586e-02,   3.66210938e-02],
                        [  3.88793945e-02,   3.90014648e-02],
                        [  4.38842773e-02,   4.39758301e-02],
                        [  4.72106934e-02,   4.72717285e-02],
                        [  4.62036133e-02,   4.62951660e-02],
                        [  4.16259766e-02,   4.17480469e-02],
                        [  3.53088379e-02,   3.53698730e-02],
                        [  2.81677246e-02,   2.82897949e-02],
                        [  2.16674805e-02,   2.17895508e-02],
                        [  1.76391602e-02,   1.77612305e-02],
                        [  1.69067383e-02,   1.69677734e-02],
                        [  1.90734863e-02,   1.92260742e-02],
                        [  2.27355957e-02,   2.29187012e-02],
                        [  2.64892578e-02,   2.66113281e-02],
                        [  3.06091309e-02,   3.07006836e-02],
                        [  3.54614258e-02,   3.56445312e-02],
                        [  3.91845703e-02,   3.93676758e-02],
                        [  3.78112793e-02,   3.79028320e-02],
                        [  2.89916992e-02,   2.90832520e-02],
                        [  1.52587891e-02,   1.54113770e-02],
                        [  8.23974609e-04,   1.00708008e-03],
                        [ -1.23291016e-02,  -1.21765137e-02],
                        [ -2.46582031e-02,  -2.45361328e-02],
                        [ -3.62854004e-02,  -3.61633301e-02],
                        [ -4.50439453e-02,  -4.48913574e-02],
                        [ -4.93469238e-02,  -4.91638184e-02],
                        [ -5.01098633e-02,  -4.99267578e-02],
                        [ -4.81567383e-02,  -4.80041504e-02],
                        [ -4.35180664e-02,  -4.33959961e-02],
                        [ -3.55529785e-02,  -3.53698730e-02],
                        [ -2.37121582e-02,  -2.34985352e-02],
                        [ -1.15966797e-02,  -1.14135742e-02],
                        [ -4.42504883e-03,  -4.30297852e-03],
                        [ -2.89916992e-03,  -2.77709961e-03],
                        [ -4.02832031e-03,  -3.84521484e-03],
                        [ -4.60815430e-03,  -4.39453125e-03],
                        [ -3.75366211e-03,  -3.60107422e-03],
                        [ -3.66210938e-03,  -3.54003906e-03],
                        [ -6.37817383e-03,  -6.22558594e-03],
                        [ -1.11999512e-02,  -1.09863281e-02],
                        [ -1.54724121e-02,  -1.52893066e-02],
                        [ -1.79443359e-02,  -1.78222656e-02],
                        [ -1.87988281e-02,  -1.86767578e-02],
                        [ -1.63574219e-02,  -1.62353516e-02],
                        [ -9.94873047e-03,  -9.79614258e-03],
                        [ -3.08227539e-03,  -2.89916992e-03],
                        [  1.95312500e-03,   2.10571289e-03],
                        [  6.37817383e-03,   6.46972656e-03],
                        [  1.07421875e-02,   1.08337402e-02],
                        [  1.43737793e-02,   1.45568848e-02],
                        [  1.66931152e-02,   1.68762207e-02],
                        [  1.67846680e-02,   1.68762207e-02],
                        [  1.37634277e-02,   1.38244629e-02],
                        [  7.99560547e-03,   8.14819336e-03],
                        [  1.61743164e-03,   1.77001953e-03],
                        [ -3.90625000e-03,  -3.84521484e-03],
                        [ -6.62231445e-03,  -6.53076172e-03],
                        [ -1.28173828e-03,  -1.15966797e-03],
                        [  1.40380859e-02,   1.41296387e-02],
                        [  3.33862305e-02,   3.34472656e-02],
                        [  5.09643555e-02,   5.10559082e-02],
                        [  6.72302246e-02,   6.73217773e-02],
                        [  8.55102539e-02,   8.56018066e-02],
                        [  1.06201172e-01,   1.06262207e-01],
                        [  1.24511719e-01,   1.24603271e-01],
                        [  1.31591797e-01,   1.31652832e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  6.89697266e-02,   6.90307617e-02],
                        [ -1.33361816e-02,  -1.32141113e-02],
                        [ -1.22619629e-01,  -1.22589111e-01],
                        [ -2.35748291e-01,  -2.35809326e-01],
                        [ -3.16558838e-01,  -3.16558838e-01],
                        [ -3.35937500e-01,  -3.35815430e-01],
                        [ -2.96875000e-01,  -2.96813965e-01],
                        [ -2.35809326e-01,  -2.35870361e-01],
                        [ -1.91802979e-01,  -1.91864014e-01],
                        [ -1.74285889e-01,  -1.74194336e-01],
                        [ -1.64123535e-01,  -1.64031982e-01],
                        [ -1.40197754e-01,  -1.40228271e-01],
                        [ -9.76562500e-02,  -9.77783203e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [  1.24816895e-02,   1.25732422e-02],
                        [  6.70471191e-02,   6.70471191e-02],
                        [  1.12457275e-01,   1.12365723e-01],
                        [  1.41479492e-01,   1.41418457e-01],
                        [  1.52221680e-01,   1.52191162e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.36016846e-01,   1.35986328e-01],
                        [  1.19506836e-01,   1.19445801e-01],
                        [  1.02416992e-01,   1.02355957e-01],
                        [  8.56323242e-02,   8.56018066e-02],
                        [  6.79626465e-02,   6.79016113e-02],
                        [  5.14831543e-02,   5.14221191e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.09240723e-02,   4.08630371e-02],
                        [  4.37927246e-02,   4.36401367e-02],
                        [  4.50744629e-02,   4.49523926e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  3.69262695e-02,   3.68957520e-02],
                        [  2.53295898e-02,   2.51464844e-02],
                        [  8.54492188e-03,   8.36181641e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -1.37634277e-02,  -1.37329102e-02],
                        [ -8.60595703e-03,  -8.72802734e-03],
                        [  2.80761719e-03,   2.53295898e-03],
                        [  1.09252930e-02,   1.07727051e-02],
                        [  1.08337402e-02,   1.08642578e-02],
                        [  5.09643555e-03,   5.06591797e-03],
                        [ -2.80761719e-03,  -3.02124023e-03],
                        [ -1.31835938e-02,  -1.34277344e-02],
                        [ -2.43835449e-02,  -2.44445801e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.37731934e-02,  -2.38952637e-02],
                        [ -1.07421875e-02,  -1.09558105e-02],
                        [  3.26538086e-03,   3.14331055e-03],
                        [  1.40991211e-02,   1.40380859e-02],
                        [  1.99279785e-02,   1.98059082e-02],
                        [  2.09655762e-02,   2.07824707e-02],
                        [  2.07519531e-02,   2.06298828e-02],
                        [  2.45666504e-02,   2.44750977e-02],
                        [  3.35998535e-02,   3.34472656e-02],
                        [  4.15954590e-02,   4.14123535e-02],
                        [  4.27246094e-02,   4.26330566e-02],
                        [  3.97644043e-02,   3.96728516e-02],
                        [  3.83605957e-02,   3.81469727e-02],
                        [  3.79943848e-02,   3.77807617e-02],
                        [  3.47290039e-02,   3.46984863e-02],
                        [  2.86254883e-02,   2.85949707e-02],
                        [  2.34680176e-02,   2.32543945e-02],
                        [  2.19116211e-02,   2.16674805e-02],
                        [  2.40783691e-02,   2.40478516e-02],
                        [  2.81066895e-02,   2.80761719e-02],
                        [  2.95715332e-02,   2.93884277e-02],
                        [  2.49633789e-02,   2.47802734e-02],
                        [  1.74865723e-02,   1.74560547e-02],
                        [  1.23291016e-02,   1.22985840e-02],
                        [  8.11767578e-03,   7.93457031e-03],
                        [  1.80053711e-03,   1.64794922e-03],
                        [ -3.17382812e-03,  -3.20434570e-03],
                        [ -2.71606445e-03,  -2.77709961e-03],
                        [  6.71386719e-04,   5.18798828e-04],
                        [  1.46484375e-03,   1.31225586e-03],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [ -1.27563477e-02,  -1.28173828e-02],
                        [ -2.45361328e-02,  -2.46887207e-02],
                        [ -3.54003906e-02,  -3.55224609e-02],
                        [ -4.26025391e-02,  -4.26330566e-02],
                        [ -4.55932617e-02,  -4.56542969e-02],
                        [ -4.54101562e-02,  -4.55322266e-02],
                        [ -4.26635742e-02,  -4.27856445e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -2.91137695e-02,  -2.92358398e-02],
                        [ -2.53601074e-02,  -2.54516602e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.16271973e-02,  -1.17187500e-02],
                        [ -8.57543945e-03,  -8.66699219e-03],
                        [ -9.09423828e-03,  -9.06372070e-03],
                        [ -1.09863281e-02,  -1.09558105e-02],
                        [ -1.25732422e-02,  -1.26342773e-02],
                        [ -1.29089355e-02,  -1.29699707e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -4.42504883e-03,  -4.39453125e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -2.19726562e-03,  -2.25830078e-03],
                        [ -1.09558105e-02,  -1.09863281e-02],
                        [ -1.76391602e-02,  -1.75781250e-02],
                        [ -1.43737793e-02,  -1.43432617e-02],
                        [ -4.42504883e-03,  -4.48608398e-03],
                        [  1.43432617e-03,   1.37329102e-03],
                        [ -6.10351562e-05,   3.05175781e-05],
                        [ -1.52587891e-03,  -1.43432617e-03],
                        [  1.61743164e-03,   1.55639648e-03],
                        [  5.98144531e-03,   5.92041016e-03],
                        [  9.27734375e-03,   9.36889648e-03],
                        [  1.34887695e-02,   1.35803223e-02],
                        [  1.93481445e-02,   1.93176270e-02],
                        [  2.51770020e-02,   2.51464844e-02],
                        [  3.17687988e-02,   3.18603516e-02],
                        [  4.24804688e-02,   4.25415039e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  8.39233398e-02,   8.39843750e-02],
                        [  1.13952637e-01,   1.14044189e-01],
                        [  1.39831543e-01,   1.39862061e-01],
                        [  1.46575928e-01,   1.46575928e-01],
                        [  1.22528076e-01,   1.22650146e-01],
                        [  6.27136230e-02,   6.28356934e-02],
                        [ -3.11889648e-02,  -3.11584473e-02],
                        [ -1.47155762e-01,  -1.47125244e-01],
                        [ -2.57995605e-01,  -2.57873535e-01],
                        [ -3.28735352e-01,  -3.28643799e-01],
                        [ -3.39508057e-01,  -3.39477539e-01],
                        [ -3.00231934e-01,  -3.00140381e-01],
                        [ -2.41912842e-01,  -2.41821289e-01],
                        [ -1.96380615e-01,  -1.96380615e-01],
                        [ -1.75415039e-01,  -1.75384521e-01],
                        [ -1.64001465e-01,  -1.63848877e-01],
                        [ -1.39038086e-01,  -1.38885498e-01],
                        [ -9.45434570e-02,  -9.45739746e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [  8.20922852e-03,   8.39233398e-03],
                        [  5.77697754e-02,   5.79833984e-02],
                        [  1.01715088e-01,   1.01745605e-01],
                        [  1.29180908e-01,   1.29180908e-01],
                        [  1.37329102e-01,   1.37420654e-01],
                        [  1.33544922e-01,   1.33697510e-01],
                        [  1.26495361e-01,   1.26617432e-01],
                        [  1.19781494e-01,   1.19842529e-01],
                        [  1.09832764e-01,   1.09832764e-01],
                        [  9.21020508e-02,   9.21630859e-02],
                        [  7.26013184e-02,   7.27844238e-02],
                        [  6.47583008e-02,   6.49414062e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  7.88879395e-02,   7.88269043e-02],
                        [  7.37915039e-02,   7.39135742e-02],
                        [  5.58166504e-02,   5.60302734e-02],
                        [  3.13110352e-02,   3.14025879e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -2.12402344e-02,  -2.11791992e-02],
                        [ -3.82385254e-02,  -3.81164551e-02],
                        [ -3.94287109e-02,  -3.93371582e-02],
                        [ -2.49633789e-02,  -2.49023438e-02],
                        [ -3.93676758e-03,  -3.84521484e-03],
                        [  1.11999512e-02,   1.12304688e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  7.44628906e-03,   7.53784180e-03],
                        [  2.38037109e-03,   2.59399414e-03],
                        [  1.25122070e-03,   1.28173828e-03],
                        [ -8.85009766e-04,  -1.00708008e-03],
                        [ -5.85937500e-03,  -5.82885742e-03],
                        [ -7.11059570e-03,  -6.86645508e-03],
                        [  6.10351562e-04,   7.32421875e-04],
                        [  1.13220215e-02,   1.11999512e-02],
                        [  1.56860352e-02,   1.55944824e-02],
                        [  1.38244629e-02,   1.40075684e-02],
                        [  1.28173828e-02,   1.30004883e-02],
                        [  1.58081055e-02,   1.57775879e-02],
                        [  2.03857422e-02,   2.02941895e-02],
                        [  2.40478516e-02,   2.41088867e-02],
                        [  2.65197754e-02,   2.67028809e-02],
                        [  2.79846191e-02,   2.80456543e-02],
                        [  2.79235840e-02,   2.78320312e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.89001465e-02,   2.90222168e-02],
                        [  3.57971191e-02,   3.58886719e-02],
                        [  4.51660156e-02,   4.51049805e-02],
                        [  5.10559082e-02,   5.09948730e-02],
                        [  5.11169434e-02,   5.12390137e-02],
                        [  4.72717285e-02,   4.73632812e-02],
                        [  4.00695801e-02,   4.00085449e-02],
                        [  2.77099609e-02,   2.76489258e-02],
                        [  1.16882324e-02,   1.17797852e-02],
                        [ -5.18798828e-04,  -4.27246094e-04],
                        [ -4.18090820e-03,  -4.24194336e-03],
                        [ -3.69262695e-03,  -3.78417969e-03],
                        [ -4.51660156e-03,  -4.42504883e-03],
                        [ -5.24902344e-03,  -5.18798828e-03],
                        [ -3.72314453e-03,  -3.81469727e-03],
                        [ -2.25830078e-03,  -2.31933594e-03],
                        [ -2.96020508e-03,  -2.86865234e-03],
                        [ -4.97436523e-03,  -4.94384766e-03],
                        [ -9.36889648e-03,  -9.52148438e-03],
                        [ -1.82800293e-02,  -1.83105469e-02],
                        [ -2.79235840e-02,  -2.77709961e-02],
                        [ -3.21350098e-02,  -3.21655273e-02],
                        [ -3.11889648e-02,  -3.13720703e-02],
                        [ -2.81066895e-02,  -2.81372070e-02],
                        [ -2.23083496e-02,  -2.21862793e-02],
                        [ -1.57165527e-02,  -1.57470703e-02],
                        [ -1.60217285e-02,  -1.61743164e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.59497070e-02,  -3.58886719e-02],
                        [ -4.10461426e-02,  -4.11376953e-02],
                        [ -4.05883789e-02,  -4.06494141e-02],
                        [ -3.61328125e-02,  -3.61022949e-02],
                        [ -3.01513672e-02,  -3.02429199e-02],
                        [ -2.60009766e-02,  -2.61535645e-02],
                        [ -2.27661133e-02,  -2.27355957e-02],
                        [ -1.61437988e-02,  -1.60522461e-02],
                        [ -7.26318359e-03,  -7.35473633e-03],
                        [ -2.10571289e-03,  -2.28881836e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -9.15527344e-05,  -3.05175781e-05],
                        [  1.25122070e-03,   1.22070312e-03],
                        [ -6.40869141e-04,  -7.62939453e-04],
                        [ -4.69970703e-03,  -4.79125977e-03],
                        [ -7.08007812e-03,  -7.11059570e-03],
                        [ -6.34765625e-03,  -6.31713867e-03],
                        [ -3.96728516e-03,  -3.99780273e-03],
                        [ -2.41088867e-03,  -2.56347656e-03],
                        [ -2.59399414e-03,  -2.68554688e-03],
                        [ -1.12915039e-03,  -1.09863281e-03],
                        [  6.01196289e-03,   6.04248047e-03],
                        [  1.67846680e-02,   1.66931152e-02],
                        [  2.46887207e-02,   2.45666504e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.28576660e-02,   2.27966309e-02],
                        [  2.33154297e-02,   2.32238770e-02],
                        [  3.33862305e-02,   3.33557129e-02],
                        [  5.70068359e-02,   5.69458008e-02],
                        [  9.06982422e-02,   9.06372070e-02],
                        [  1.24511719e-01,   1.24481201e-01],
                        [  1.45568848e-01,   1.45538330e-01],
                        [  1.43920898e-01,   1.43890381e-01],
                        [  1.14349365e-01,   1.14288330e-01],
                        [  5.15136719e-02,   5.14526367e-02],
                        [ -4.73022461e-02,  -4.73632812e-02],
                        [ -1.68273926e-01,  -1.68273926e-01],
                        [ -2.77130127e-01,  -2.77160645e-01],
                        [ -3.38043213e-01,  -3.38134766e-01],
                        [ -3.35937500e-01,  -3.35998535e-01],
                        [ -2.85339355e-01,  -2.85339355e-01],
                        [ -2.22930908e-01,  -2.22991943e-01],
                        [ -1.82952881e-01,  -1.83044434e-01],
                        [ -1.71508789e-01,  -1.71539307e-01],
                        [ -1.68395996e-01,  -1.68395996e-01],
                        [ -1.51947021e-01,  -1.51947021e-01],
                        [ -1.15173340e-01,  -1.15234375e-01],
                        [ -6.35375977e-02,  -6.35986328e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  5.68847656e-02,   5.69458008e-02],
                        [  1.14410400e-01,   1.14379883e-01],
                        [  1.54296875e-01,   1.54144287e-01],
                        [  1.65985107e-01,   1.65985107e-01],
                        [  1.55364990e-01,   1.55517578e-01],
                        [  1.38031006e-01,   1.38000488e-01],
                        [  1.21490479e-01,   1.21246338e-01],
                        [  1.05438232e-01,   1.05407715e-01],
                        [  9.35668945e-02,   9.37500000e-02],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  9.23767090e-02,   9.21936035e-02],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  9.32006836e-02,   9.32617188e-02],
                        [  7.91320801e-02,   7.91015625e-02],
                        [  4.59289551e-02,   4.58984375e-02],
                        [  8.54492188e-04,   8.85009766e-04],
                        [ -3.92150879e-02,  -3.92761230e-02],
                        [ -6.03637695e-02,  -6.04858398e-02],
                        [ -5.70983887e-02,  -5.69763184e-02],
                        [ -3.36303711e-02,  -3.35083008e-02],
                        [ -5.24902344e-03,  -5.37109375e-03],
                        [  1.07116699e-02,   1.05285645e-02],
                        [  1.09558105e-02,   1.10778809e-02],
                        [  6.77490234e-03,   6.95800781e-03],
                        [  5.85937500e-03,   5.76782227e-03],
                        [  4.79125977e-03,   4.63867188e-03],
                        [  3.96728516e-04,   4.27246094e-04],
                        [ -3.72314453e-03,  -3.60107422e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  5.21850586e-03,   5.18798828e-03],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.96936035e-02,   2.97241211e-02],
                        [  3.58886719e-02,   3.59191895e-02],
                        [  3.68347168e-02,   3.68652344e-02],
                        [  3.49121094e-02,   3.48815918e-02],
                        [  3.00598145e-02,   3.00292969e-02],
                        [  2.20336914e-02,   2.20642090e-02],
                        [  1.32141113e-02,   1.32446289e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.10778809e-02,   1.11083984e-02],
                        [  2.41394043e-02,   2.41699219e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  4.90417480e-02,   4.90112305e-02],
                        [  4.69360352e-02,   4.69970703e-02],
                        [  3.97644043e-02,   3.98559570e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.20739746e-02,   3.20129395e-02],
                        [  3.24707031e-02,   3.25012207e-02],
                        [  3.20739746e-02,   3.21655273e-02],
                        [  2.89306641e-02,   2.89611816e-02],
                        [  2.41088867e-02,   2.40173340e-02],
                        [  1.90124512e-02,   1.89819336e-02],
                        [  1.38244629e-02,   1.39465332e-02],
                        [  9.36889648e-03,   9.46044922e-03],
                        [  5.52368164e-03,   5.43212891e-03],
                        [ -6.40869141e-04,  -7.01904297e-04],
                        [ -1.00097656e-02,  -9.88769531e-03],
                        [ -1.89514160e-02,  -1.88598633e-02],
                        [ -2.53295898e-02,  -2.53601074e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.92663574e-02,  -2.92053223e-02],
                        [ -2.50854492e-02,  -2.50549316e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.07519531e-02,  -2.07214355e-02],
                        [ -2.22473145e-02,  -2.22167969e-02],
                        [ -2.37426758e-02,  -2.37731934e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.75878906e-02,  -2.74963379e-02],
                        [ -2.96630859e-02,  -2.96325684e-02],
                        [ -3.26538086e-02,  -3.27148438e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.28063965e-02,  -3.27453613e-02],
                        [ -2.54211426e-02,  -2.53906250e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.20031738e-02,  -2.19726562e-02],
                        [ -2.64282227e-02,  -2.63366699e-02],
                        [ -2.59094238e-02,  -2.58789062e-02],
                        [ -1.95312500e-02,  -1.96228027e-02],
                        [ -1.10778809e-02,  -1.11389160e-02],
                        [ -3.35693359e-03,  -3.23486328e-03],
                        [  2.89916992e-03,   2.99072266e-03],
                        [  4.82177734e-03,   4.73022461e-03],
                        [  5.18798828e-04,   4.88281250e-04],
                        [ -5.09643555e-03,  -5.00488281e-03],
                        [ -6.34765625e-03,  -6.28662109e-03],
                        [ -4.57763672e-03,  -4.66918945e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.80053711e-03,  -1.70898438e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  4.33349609e-03,   4.27246094e-03],
                        [  5.34057617e-03,   5.40161133e-03],
                        [  4.94384766e-03,   5.00488281e-03],
                        [  5.49316406e-03,   5.46264648e-03],
                        [  9.61303711e-03,   9.55200195e-03],
                        [  1.92260742e-02,   1.92871094e-02],
                        [  3.48815918e-02,   3.49731445e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  7.64465332e-02,   7.63549805e-02],
                        [  9.76257324e-02,   9.75952148e-02],
                        [  1.16607666e-01,   1.16699219e-01],
                        [  1.28906250e-01,   1.28936768e-01],
                        [  1.25762939e-01,   1.25701904e-01],
                        [  9.67712402e-02,   9.67102051e-02],
                        [  3.57971191e-02,   3.58581543e-02],
                        [ -5.32531738e-02,  -5.31616211e-02],
                        [ -1.56097412e-01,  -1.56127930e-01],
                        [ -2.50183105e-01,  -2.50274658e-01],
                        [ -3.09448242e-01,  -3.09417725e-01],
                        [ -3.17291260e-01,  -3.17199707e-01],
                        [ -2.82135010e-01,  -2.82135010e-01],
                        [ -2.34466553e-01,  -2.34558105e-01],
                        [ -2.01019287e-01,  -2.01019287e-01],
                        [ -1.83319092e-01,  -1.83227539e-01],
                        [ -1.65618896e-01,  -1.65618896e-01],
                        [ -1.36871338e-01,  -1.36932373e-01],
                        [ -9.83581543e-02,  -9.83886719e-02],
                        [ -5.48706055e-02,  -5.48095703e-02],
                        [ -6.37817383e-03,  -6.34765625e-03],
                        [  4.82482910e-02,   4.82177734e-02],
                        [  1.02600098e-01,   1.02539062e-01],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.59271240e-01,   1.59332275e-01],
                        [  1.55914307e-01,   1.55914307e-01],
                        [  1.45690918e-01,   1.45629883e-01],
                        [  1.37847900e-01,   1.37786865e-01],
                        [  1.32324219e-01,   1.32354736e-01],
                        [  1.24542236e-01,   1.24572754e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.00463867e-01,   1.00433350e-01],
                        [  9.14916992e-02,   9.14306641e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  6.08520508e-02,   6.09130859e-02],
                        [  2.89916992e-02,   2.90222168e-02],
                        [ -8.57543945e-03,  -8.60595703e-03],
                        [ -4.16564941e-02,  -4.16870117e-02],
                        [ -6.14013672e-02,  -6.14318848e-02],
                        [ -6.52465820e-02,  -6.52160645e-02],
                        [ -5.45959473e-02,  -5.45349121e-02],
                        [ -3.25622559e-02,  -3.25927734e-02],
                        [ -7.96508789e-03,  -8.08715820e-03],
                        [  6.83593750e-03,   6.80541992e-03],
                        [  8.27026367e-03,   8.42285156e-03],
                        [  3.32641602e-03,   3.38745117e-03],
                        [ -2.16674805e-03,  -2.28881836e-03],
                        [ -7.41577148e-03,  -7.50732422e-03],
                        [ -1.01928711e-02,  -1.01013184e-02],
                        [ -5.64575195e-03,  -5.58471680e-03],
                        [  7.32421875e-03,   7.29370117e-03],
                        [  2.55737305e-02,   2.55432129e-02],
                        [  4.34570312e-02,   4.34265137e-02],
                        [  5.31921387e-02,   5.31616211e-02],
                        [  5.09033203e-02,   5.09643555e-02],
                        [  4.25109863e-02,   4.26025391e-02],
                        [  3.57360840e-02,   3.56140137e-02],
                        [  3.11279297e-02,   3.09753418e-02],
                        [  2.70996094e-02,   2.71911621e-02],
                        [  2.52990723e-02,   2.54516602e-02],
                        [  2.64282227e-02,   2.63671875e-02],
                        [  2.81372070e-02,   2.79541016e-02],
                        [  2.90527344e-02,   2.90832520e-02],
                        [  2.99377441e-02,   3.00292969e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  3.14025879e-02,   3.13110352e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.94287109e-02,   3.94592285e-02],
                        [  4.30908203e-02,   4.30603027e-02],
                        [  4.14123535e-02,   4.14428711e-02],
                        [  3.61022949e-02,   3.61633301e-02],
                        [  3.09448242e-02,   3.09143066e-02],
                        [  2.66113281e-02,   2.65197754e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  1.52282715e-02,   1.53198242e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -1.83105469e-03,  -1.92260742e-03],
                        [ -1.39465332e-02,  -1.40075684e-02],
                        [ -2.39257812e-02,  -2.38342285e-02],
                        [ -2.81066895e-02,  -2.80456543e-02],
                        [ -2.80761719e-02,  -2.81372070e-02],
                        [ -2.69775391e-02,  -2.70385742e-02],
                        [ -2.52075195e-02,  -2.51770020e-02],
                        [ -2.19116211e-02,  -2.18505859e-02],
                        [ -1.80969238e-02,  -1.81274414e-02],
                        [ -1.55944824e-02,  -1.56555176e-02],
                        [ -1.48010254e-02,  -1.47705078e-02],
                        [ -1.55334473e-02,  -1.54724121e-02],
                        [ -1.82495117e-02,  -1.82800293e-02],
                        [ -2.24609375e-02,  -2.24914551e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.43835449e-02,  -2.43225098e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.77001953e-02,  -1.77307129e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.13012695e-02,  -2.12707520e-02],
                        [ -1.42517090e-02,  -1.42211914e-02],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -1.19018555e-03,  -1.22070312e-03],
                        [  2.89916992e-03,   2.99072266e-03],
                        [  7.87353516e-03,   7.93457031e-03],
                        [  1.13830566e-02,   1.13220215e-02],
                        [  7.29370117e-03,   7.20214844e-03],
                        [ -4.15039062e-03,  -4.08935547e-03],
                        [ -1.47094727e-02,  -1.46484375e-02],
                        [ -1.96838379e-02,  -1.97448730e-02],
                        [ -2.04162598e-02,  -2.04772949e-02],
                        [ -1.74560547e-02,  -1.74255371e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  7.81250000e-03,   7.84301758e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.21252441e-02,   2.20336914e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  2.36206055e-02,   2.37121582e-02],
                        [  3.04565430e-02,   3.04870605e-02],
                        [  3.96118164e-02,   3.94897461e-02],
                        [  4.74243164e-02,   4.73937988e-02],
                        [  5.85327148e-02,   5.85937500e-02],
                        [  7.85522461e-02,   7.85827637e-02],
                        [  1.04248047e-01,   1.04217529e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.01379395e-01,   1.01318359e-01],
                        [  3.77197266e-02,   3.77502441e-02],
                        [ -5.53894043e-02,  -5.52978516e-02],
                        [ -1.60644531e-01,  -1.60675049e-01],
                        [ -2.54058838e-01,  -2.54211426e-01],
                        [ -3.09051514e-01,  -3.09051514e-01],
                        [ -3.09570312e-01,  -3.09417725e-01],
                        [ -2.66082764e-01,  -2.66052246e-01],
                        [ -2.12158203e-01,  -2.12341309e-01],
                        [ -1.77398682e-01,  -1.77459717e-01],
                        [ -1.65008545e-01,  -1.64886475e-01],
                        [ -1.58905029e-01,  -1.58813477e-01],
                        [ -1.45263672e-01,  -1.45355225e-01],
                        [ -1.21643066e-01,  -1.21704102e-01],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -4.51049805e-02,  -4.50134277e-02],
                        [  1.36108398e-02,   1.36718750e-02],
                        [  8.11462402e-02,   8.10852051e-02],
                        [  1.40472412e-01,   1.40380859e-01],
                        [  1.75109863e-01,   1.75140381e-01],
                        [  1.82403564e-01,   1.82495117e-01],
                        [  1.71905518e-01,   1.71875000e-01],
                        [  1.54418945e-01,   1.54327393e-01],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.24267578e-01,   1.24359131e-01],
                        [  1.14898682e-01,   1.14868164e-01],
                        [  1.03698730e-01,   1.03607178e-01],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  5.85327148e-02,   5.85937500e-02],
                        [  2.36206055e-02,   2.35900879e-02],
                        [ -1.51977539e-02,  -1.52587891e-02],
                        [ -4.80651855e-02,  -4.80041504e-02],
                        [ -6.32324219e-02,  -6.31713867e-02],
                        [ -5.84716797e-02,  -5.85632324e-02],
                        [ -4.24804688e-02,  -4.25109863e-02],
                        [ -2.38647461e-02,  -2.37426758e-02],
                        [ -6.95800781e-03,  -6.92749023e-03],
                        [  4.11987305e-03,   3.99780273e-03],
                        [  6.56127930e-03,   6.53076172e-03],
                        [  3.08227539e-03,   3.23486328e-03],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -4.97436523e-03,  -5.09643555e-03],
                        [ -7.04956055e-03,  -7.01904297e-03],
                        [ -2.38037109e-03,  -2.25830078e-03],
                        [  1.22070312e-02,   1.21765137e-02],
                        [  3.14636230e-02,   3.13720703e-02],
                        [  4.79125977e-02,   4.80041504e-02],
                        [  5.73425293e-02,   5.74035645e-02],
                        [  5.56030273e-02,   5.54504395e-02],
                        [  4.22363281e-02,   4.22058105e-02],
                        [  2.79235840e-02,   2.81066895e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  2.70080566e-02,   2.67944336e-02],
                        [  2.58178711e-02,   2.58483887e-02],
                        [  2.05078125e-02,   2.07214355e-02],
                        [  1.78527832e-02,   1.78222656e-02],
                        [  1.88903809e-02,   1.86767578e-02],
                        [  2.32238770e-02,   2.32543945e-02],
                        [  3.33557129e-02,   3.35083008e-02],
                        [  4.47387695e-02,   4.47082520e-02],
                        [  4.75158691e-02,   4.74243164e-02],
                        [  4.18701172e-02,   4.19006348e-02],
                        [  3.57360840e-02,   3.57666016e-02],
                        [  3.15856934e-02,   3.15246582e-02],
                        [  2.78015137e-02,   2.78625488e-02],
                        [  2.59094238e-02,   2.59704590e-02],
                        [  2.63061523e-02,   2.61840820e-02],
                        [  2.60314941e-02,   2.59704590e-02],
                        [  2.49633789e-02,   2.50854492e-02],
                        [  2.48413086e-02,   2.49023438e-02],
                        [  2.23388672e-02,   2.21862793e-02],
                        [  1.30920410e-02,   1.30310059e-02],
                        [ -2.74658203e-04,  -1.52587891e-04],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -2.45056152e-02,  -2.46276855e-02],
                        [ -3.34472656e-02,  -3.34167480e-02],
                        [ -3.57360840e-02,  -3.56445312e-02],
                        [ -3.19213867e-02,  -3.19824219e-02],
                        [ -2.86560059e-02,  -2.87475586e-02],
                        [ -2.92663574e-02,  -2.91748047e-02],
                        [ -2.98156738e-02,  -2.97241211e-02],
                        [ -2.70080566e-02,  -2.71301270e-02],
                        [ -2.42004395e-02,  -2.42919922e-02],
                        [ -2.43835449e-02,  -2.42309570e-02],
                        [ -2.49938965e-02,  -2.48718262e-02],
                        [ -2.46582031e-02,  -2.48107910e-02],
                        [ -2.61230469e-02,  -2.62451172e-02],
                        [ -2.82592773e-02,  -2.81372070e-02],
                        [ -2.65197754e-02,  -2.64282227e-02],
                        [ -2.18505859e-02,  -2.19421387e-02],
                        [ -1.79443359e-02,  -1.80358887e-02],
                        [ -1.29089355e-02,  -1.28479004e-02],
                        [ -4.82177734e-03,  -4.76074219e-03],
                        [  7.32421875e-04,   7.01904297e-04],
                        [ -1.70898438e-03,  -1.73950195e-03],
                        [ -9.33837891e-03,  -9.39941406e-03],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.78527832e-02,  -1.77612305e-02],
                        [ -1.58691406e-02,  -1.58386230e-02],
                        [ -1.60217285e-02,  -1.61437988e-02],
                        [ -2.10266113e-02,  -2.11181641e-02],
                        [ -2.28576660e-02,  -2.27050781e-02],
                        [ -1.28784180e-02,  -1.27563477e-02],
                        [  3.11279297e-03,   2.99072266e-03],
                        [  1.14135742e-02,   1.12609863e-02],
                        [  8.78906250e-03,   8.88061523e-03],
                        [  3.69262695e-03,   3.81469727e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  8.54492188e-04,   7.62939453e-04],
                        [ -1.83105469e-04,  -2.44140625e-04],
                        [  1.52587891e-04,   1.83105469e-04],
                        [  5.43212891e-03,   5.49316406e-03],
                        [  1.78222656e-02,   1.78527832e-02],
                        [  3.39965820e-02,   3.39050293e-02],
                        [  4.86755371e-02,   4.85839844e-02],
                        [  6.32019043e-02,   6.32324219e-02],
                        [  8.36181641e-02,   8.37097168e-02],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.34063721e-01,   1.33941650e-01],
                        [  1.39068604e-01,   1.39007568e-01],
                        [  1.12182617e-01,   1.12274170e-01],
                        [  4.85229492e-02,   4.86145020e-02],
                        [ -4.66308594e-02,  -4.66613770e-02],
                        [ -1.57318115e-01,  -1.57440186e-01],
                        [ -2.56927490e-01,  -2.56988525e-01],
                        [ -3.14819336e-01,  -3.14727783e-01],
                        [ -3.13842773e-01,  -3.13751221e-01],
                        [ -2.66754150e-01,  -2.66845703e-01],
                        [ -2.09411621e-01,  -2.09533691e-01],
                        [ -1.71752930e-01,  -1.71722412e-01],
                        [ -1.58081055e-01,  -1.57989502e-01],
                        [ -1.53900146e-01,  -1.53869629e-01],
                        [ -1.43859863e-01,  -1.43920898e-01],
                        [ -1.22619629e-01,  -1.22650146e-01],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -5.06896973e-02,  -5.06286621e-02],
                        [  4.30297852e-03,   4.36401367e-03],
                        [  6.97631836e-02,   6.97021484e-02],
                        [  1.29760742e-01,   1.29699707e-01],
                        [  1.67938232e-01,   1.67968750e-01],
                        [  1.81335449e-01,   1.81427002e-01],
                        [  1.78588867e-01,   1.78588867e-01],
                        [  1.68884277e-01,   1.68792725e-01],
                        [  1.56188965e-01,   1.56158447e-01],
                        [  1.40258789e-01,   1.40350342e-01],
                        [  1.19964600e-01,   1.20025635e-01],
                        [  9.55200195e-02,   9.54589844e-02],
                        [  6.73217773e-02,   6.72302246e-02],
                        [  3.43322754e-02,   3.43627930e-02],
                        [ -2.80761719e-03,  -2.68554688e-03],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -6.02722168e-02,  -6.03942871e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -4.14428711e-02,  -4.12902832e-02],
                        [ -1.63879395e-02,  -1.63574219e-02],
                        [ -2.53295898e-03,  -2.68554688e-03],
                        [ -1.86157227e-03,  -1.89208984e-03],
                        [ -2.28881836e-03,  -2.16674805e-03],
                        [  2.96020508e-03,   2.99072266e-03],
                        [  7.56835938e-03,   7.47680664e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  5.21850586e-03,   5.27954102e-03],
                        [  1.11083984e-02,   1.10778809e-02],
                        [  2.35595703e-02,   2.34985352e-02],
                        [  3.65295410e-02,   3.65600586e-02],
                        [  4.55627441e-02,   4.56237793e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  5.00793457e-02,   4.99877930e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  3.36608887e-02,   3.37829590e-02],
                        [  2.16674805e-02,   2.16979980e-02],
                        [  1.24206543e-02,   1.22680664e-02],
                        [  7.41577148e-03,   7.32421875e-03],
                        [  8.08715820e-03,   8.20922852e-03],
                        [  1.55334473e-02,   1.56555176e-02],
                        [  2.51159668e-02,   2.49938965e-02],
                        [  2.95104980e-02,   2.93273926e-02],
                        [  2.92663574e-02,   2.93273926e-02],
                        [  3.06091309e-02,   3.07922363e-02],
                        [  3.41186523e-02,   3.40881348e-02],
                        [  3.49121094e-02,   3.47900391e-02],
                        [  3.21960449e-02,   3.21350098e-02],
                        [  3.04870605e-02,   3.05480957e-02],
                        [  3.33862305e-02,   3.34777832e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  4.55932617e-02,   4.55017090e-02],
                        [  4.70886230e-02,   4.70275879e-02],
                        [  4.19616699e-02,   4.19921875e-02],
                        [  3.14331055e-02,   3.15551758e-02],
                        [  1.98059082e-02,   1.97753906e-02],
                        [  1.00402832e-02,   9.94873047e-03],
                        [  3.11279297e-03,   3.08227539e-03],
                        [ -1.40380859e-03,  -1.34277344e-03],
                        [ -6.22558594e-03,  -6.19506836e-03],
                        [ -1.33056641e-02,  -1.32751465e-02],
                        [ -2.02636719e-02,  -2.02941895e-02],
                        [ -2.52685547e-02,  -2.53601074e-02],
                        [ -3.08837891e-02,  -3.09143066e-02],
                        [ -3.78723145e-02,  -3.77197266e-02],
                        [ -4.20837402e-02,  -4.19921875e-02],
                        [ -4.18395996e-02,  -4.20227051e-02],
                        [ -4.05578613e-02,  -4.07104492e-02],
                        [ -3.85437012e-02,  -3.83605957e-02],
                        [ -3.22875977e-02,  -3.20739746e-02],
                        [ -2.47497559e-02,  -2.49023438e-02],
                        [ -2.39562988e-02,  -2.41699219e-02],
                        [ -2.90527344e-02,  -2.89611816e-02],
                        [ -3.15856934e-02,  -3.14025879e-02],
                        [ -2.93884277e-02,  -2.94494629e-02],
                        [ -2.59399414e-02,  -2.60925293e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.35803223e-02,  -1.34887695e-02],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -3.87573242e-03,  -3.93676758e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.40380859e-02,  -1.40075684e-02],
                        [ -1.61132812e-02,  -1.60827637e-02],
                        [ -1.33056641e-02,  -1.33361816e-02],
                        [ -9.58251953e-03,  -9.61303711e-03],
                        [ -7.81250000e-03,  -7.78198242e-03],
                        [ -6.89697266e-03,  -6.86645508e-03],
                        [ -5.95092773e-03,  -5.98144531e-03],
                        [ -5.61523438e-03,  -5.64575195e-03],
                        [ -6.13403320e-03,  -6.10351562e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -6.43920898e-03,  -6.46972656e-03],
                        [ -3.17382812e-03,  -3.20434570e-03],
                        [  2.53295898e-03,   2.59399414e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  7.44628906e-03,   7.38525391e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  7.53784180e-03,   7.59887695e-03],
                        [  1.67846680e-02,   1.67541504e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  6.16455078e-02,   6.16760254e-02],
                        [  8.46557617e-02,   8.46557617e-02],
                        [  1.13189697e-01,   1.13159180e-01],
                        [  1.37054443e-01,   1.36993408e-01],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.12121582e-01,   1.12182617e-01],
                        [  4.94689941e-02,   4.95300293e-02],
                        [ -4.26940918e-02,  -4.27856445e-02],
                        [ -1.51916504e-01,  -1.52008057e-01],
                        [ -2.53265381e-01,  -2.53173828e-01],
                        [ -3.15002441e-01,  -3.14910889e-01],
                        [ -3.18908691e-01,  -3.18969727e-01],
                        [ -2.75604248e-01,  -2.75726318e-01],
                        [ -2.15667725e-01,  -2.15637207e-01],
                        [ -1.67694092e-01,  -1.67633057e-01],
                        [ -1.43310547e-01,  -1.43310547e-01],
                        [ -1.35131836e-01,  -1.35162354e-01],
                        [ -1.27990723e-01,  -1.28021240e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -9.18579102e-02,  -9.17968750e-02],
                        [ -6.10046387e-02,  -6.09436035e-02],
                        [ -1.59301758e-02,  -1.59912109e-02],
                        [  4.35791016e-02,   4.34875488e-02],
                        [  1.07696533e-01,   1.07757568e-01],
                        [  1.60308838e-01,   1.60400391e-01],
                        [  1.88293457e-01,   1.88232422e-01],
                        [  1.90979004e-01,   1.90917969e-01],
                        [  1.80908203e-01,   1.80938721e-01],
                        [  1.69952393e-01,   1.70013428e-01],
                        [  1.56372070e-01,   1.56341553e-01],
                        [  1.30706787e-01,   1.30676270e-01],
                        [  9.04846191e-02,   9.05456543e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [ -5.00488281e-03,  -5.09643555e-03],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -5.66711426e-02,  -5.65490723e-02],
                        [ -4.90112305e-02,  -4.89501953e-02],
                        [ -3.17687988e-02,  -3.19213867e-02],
                        [ -2.13928223e-02,  -2.14538574e-02],
                        [ -2.00805664e-02,  -1.99584961e-02],
                        [ -1.80358887e-02,  -1.79443359e-02],
                        [ -9.30786133e-03,  -9.39941406e-03],
                        [  2.65502930e-03,   2.50244141e-03],
                        [  1.30615234e-02,   1.30920410e-02],
                        [  2.08740234e-02,   2.09960938e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.22875977e-02,   3.21655273e-02],
                        [  3.76892090e-02,   3.76281738e-02],
                        [  4.29687500e-02,   4.30603027e-02],
                        [  4.60815430e-02,   4.61425781e-02],
                        [  4.47387695e-02,   4.47082520e-02],
                        [  3.90625000e-02,   3.90014648e-02],
                        [  3.10974121e-02,   3.10668945e-02],
                        [  2.28881836e-02,   2.29187012e-02],
                        [  1.68457031e-02,   1.69372559e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.57775879e-02,   1.56250000e-02],
                        [  1.49536133e-02,   1.48620605e-02],
                        [  1.41296387e-02,   1.43127441e-02],
                        [  1.91650391e-02,   1.92871094e-02],
                        [  2.92358398e-02,   2.90527344e-02],
                        [  3.66821289e-02,   3.65295410e-02],
                        [  3.83605957e-02,   3.84826660e-02],
                        [  3.81774902e-02,   3.83300781e-02],
                        [  3.92150879e-02,   3.91845703e-02],
                        [  3.98559570e-02,   3.97644043e-02],
                        [  3.80249023e-02,   3.79943848e-02],
                        [  3.58581543e-02,   3.58886719e-02],
                        [  3.75976562e-02,   3.77197266e-02],
                        [  4.32739258e-02,   4.33044434e-02],
                        [  4.63867188e-02,   4.62646484e-02],
                        [  4.07104492e-02,   4.05883789e-02],
                        [  2.96020508e-02,   2.97241211e-02],
                        [  2.29797363e-02,   2.31323242e-02],
                        [  2.27661133e-02,   2.27050781e-02],
                        [  2.02941895e-02,   2.01110840e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  2.44140625e-04,   3.96728516e-04],
                        [ -6.74438477e-03,  -6.71386719e-03],
                        [ -1.19018555e-02,  -1.19934082e-02],
                        [ -1.94091797e-02,  -1.94702148e-02],
                        [ -3.08532715e-02,  -3.07922363e-02],
                        [ -4.42504883e-02,  -4.41894531e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.42297363e-02,  -5.42602539e-02],
                        [ -4.21752930e-02,  -4.22363281e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.71508789e-02,  -1.70898438e-02],
                        [ -1.73950195e-02,  -1.73645020e-02],
                        [ -2.42614746e-02,  -2.42919922e-02],
                        [ -3.25012207e-02,  -3.25622559e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -2.95410156e-02,  -2.94494629e-02],
                        [ -1.93481445e-02,  -1.93176270e-02],
                        [ -1.25122070e-02,  -1.25732422e-02],
                        [ -1.27258301e-02,  -1.27563477e-02],
                        [ -1.66625977e-02,  -1.66320801e-02],
                        [ -1.69677734e-02,  -1.69067383e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  7.32421875e-04,   6.40869141e-04],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  6.71386719e-03,   6.74438477e-03],
                        [  2.80761719e-03,   2.83813477e-03],
                        [ -2.28881836e-03,  -2.31933594e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.51367188e-02,   1.51062012e-02],
                        [  1.51367188e-02,   1.51062012e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [ -6.71386719e-04,  -6.10351562e-04],
                        [ -1.25122070e-03,  -1.22070312e-03],
                        [  6.86645508e-03,   6.83593750e-03],
                        [  1.94702148e-02,   1.94396973e-02],
                        [  3.51867676e-02,   3.52172852e-02],
                        [  5.68237305e-02,   5.68847656e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  1.14685059e-01,   1.14593506e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.33361816e-01,   1.33453369e-01],
                        [  1.05499268e-01,   1.05560303e-01],
                        [  4.82788086e-02,   4.81872559e-02],
                        [ -3.71398926e-02,  -3.72009277e-02],
                        [ -1.40625000e-01,  -1.40563965e-01],
                        [ -2.37518311e-01,  -2.37457275e-01],
                        [ -2.96203613e-01,  -2.96264648e-01],
                        [ -2.99560547e-01,  -2.99621582e-01],
                        [ -2.58209229e-01,  -2.58148193e-01],
                        [ -2.02606201e-01,  -2.02575684e-01],
                        [ -1.63055420e-01,  -1.63085938e-01],
                        [ -1.50115967e-01,  -1.50085449e-01],
                        [ -1.50115967e-01,  -1.50024414e-01],
                        [ -1.42974854e-01,  -1.43005371e-01],
                        [ -1.22314453e-01,  -1.22406006e-01],
                        [ -9.32922363e-02,  -9.32617188e-02],
                        [ -5.77087402e-02,  -5.76171875e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [  4.86755371e-02,   4.85534668e-02],
                        [  1.12457275e-01,   1.12426758e-01],
                        [  1.66564941e-01,   1.66656494e-01],
                        [  1.98059082e-01,   1.98089600e-01],
                        [  2.03063965e-01,   2.03002930e-01],
                        [  1.90795898e-01,   1.90734863e-01],
                        [  1.73095703e-01,   1.73126221e-01],
                        [  1.50512695e-01,   1.50573730e-01],
                        [  1.14654541e-01,   1.14685059e-01],
                        [  6.27441406e-02,   6.27136230e-02],
                        [  5.98144531e-03,   5.95092773e-03],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -4.52880859e-02,  -4.52575684e-02],
                        [ -2.98156738e-02,  -2.98767090e-02],
                        [ -1.92565918e-02,  -1.93176270e-02],
                        [ -1.85852051e-02,  -1.85546875e-02],
                        [ -2.07214355e-02,  -2.06604004e-02],
                        [ -1.69372559e-02,  -1.69982910e-02],
                        [ -7.38525391e-03,  -7.44628906e-03],
                        [  3.14331055e-03,   3.17382812e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.79748535e-02,   1.79138184e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.42004395e-02,   2.42614746e-02],
                        [  3.24096680e-02,   3.23486328e-02],
                        [  4.44641113e-02,   4.44030762e-02],
                        [  5.48095703e-02,   5.48706055e-02],
                        [  5.93872070e-02,   5.94482422e-02],
                        [  5.67932129e-02,   5.67016602e-02],
                        [  4.77600098e-02,   4.76684570e-02],
                        [  3.72924805e-02,   3.73840332e-02],
                        [  3.02429199e-02,   3.03344727e-02],
                        [  2.41394043e-02,   2.40478516e-02],
                        [  1.47094727e-02,   1.45874023e-02],
                        [  6.25610352e-03,   6.31713867e-03],
                        [  7.56835938e-03,   7.69042969e-03],
                        [  1.90124512e-02,   1.89819336e-02],
                        [  3.12805176e-02,   3.11279297e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.79333496e-02,   3.80859375e-02],
                        [  3.96118164e-02,   3.96423340e-02],
                        [  4.25720215e-02,   4.24499512e-02],
                        [  4.26940918e-02,   4.26025391e-02],
                        [  3.88488770e-02,   3.89404297e-02],
                        [  3.59497070e-02,   3.60717773e-02],
                        [  3.75976562e-02,   3.75671387e-02],
                        [  4.08020020e-02,   4.06799316e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  3.63769531e-02,   3.64990234e-02],
                        [  2.99377441e-02,   2.99987793e-02],
                        [  2.33459473e-02,   2.32543945e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  9.58251953e-03,   9.61303711e-03],
                        [  2.92968750e-03,   2.96020508e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -1.52893066e-02,  -1.53198242e-02],
                        [ -2.67639160e-02,  -2.67944336e-02],
                        [ -3.45153809e-02,  -3.45458984e-02],
                        [ -3.79333496e-02,  -3.78723145e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.71911621e-02,  -2.72216797e-02],
                        [ -2.09655762e-02,  -2.09350586e-02],
                        [ -1.62353516e-02,  -1.61437988e-02],
                        [ -1.46179199e-02,  -1.46789551e-02],
                        [ -1.80358887e-02,  -1.81579590e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.05688477e-02,  -2.04162598e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -2.77709961e-03,  -2.96020508e-03],
                        [ -7.62939453e-04,  -8.23974609e-04],
                        [ -2.44140625e-04,  -1.22070312e-04],
                        [  4.21142578e-03,   4.33349609e-03],
                        [  8.63647461e-03,   8.51440430e-03],
                        [  4.69970703e-03,   4.60815430e-03],
                        [ -8.45336914e-03,  -8.39233398e-03],
                        [ -2.27355957e-02,  -2.26745605e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.13317871e-02,  -2.13012695e-02],
                        [ -1.20849609e-02,  -1.21154785e-02],
                        [ -4.24194336e-03,  -4.27246094e-03],
                        [ -4.88281250e-04,  -3.96728516e-04],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [ -1.25122070e-03,  -1.34277344e-03],
                        [ -3.81469727e-03,  -3.87573242e-03],
                        [ -7.78198242e-03,  -7.72094727e-03],
                        [ -1.03759766e-02,  -1.02844238e-02],
                        [ -1.01013184e-02,  -1.01623535e-02],
                        [ -8.36181641e-03,  -8.48388672e-03],
                        [ -2.92968750e-03,  -2.89916992e-03],
                        [  1.04675293e-02,   1.05590820e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  4.19311523e-02,   4.18395996e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  6.50329590e-02,   6.50634766e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.23901367e-01,   1.23931885e-01],
                        [  1.32415771e-01,   1.32385254e-01],
                        [  1.14196777e-01,   1.14166260e-01],
                        [  5.71899414e-02,   5.71899414e-02],
                        [ -3.56750488e-02,  -3.56445312e-02],
                        [ -1.44775391e-01,  -1.44775391e-01],
                        [ -2.41607666e-01,  -2.41638184e-01],
                        [ -2.99316406e-01,  -2.99346924e-01],
                        [ -3.03344727e-01,  -3.03314209e-01],
                        [ -2.61627197e-01,  -2.61566162e-01],
                        [ -2.03674316e-01,  -2.03704834e-01],
                        [ -1.60522461e-01,  -1.60614014e-01],
                        [ -1.41510010e-01,  -1.41510010e-01],
                        [ -1.33605957e-01,  -1.33483887e-01],
                        [ -1.22436523e-01,  -1.22436523e-01],
                        [ -1.06933594e-01,  -1.07025146e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -7.25097656e-02,  -7.24487305e-02],
                        [ -3.75366211e-02,  -3.75061035e-02],
                        [  2.09045410e-02,   2.08435059e-02],
                        [  9.70153809e-02,   9.69848633e-02],
                        [  1.70837402e-01,   1.70867920e-01],
                        [  2.18048096e-01,   2.18078613e-01],
                        [  2.27813721e-01,   2.27813721e-01],
                        [  2.08831787e-01,   2.08801270e-01],
                        [  1.75384521e-01,   1.75384521e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  8.10241699e-02,   8.10546875e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [ -2.70080566e-02,  -2.70690918e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.16967773e-02,  -5.16662598e-02],
                        [ -3.63464355e-02,  -3.63159180e-02],
                        [ -1.98059082e-02,  -1.98364258e-02],
                        [ -9.12475586e-03,  -9.15527344e-03],
                        [ -2.80761719e-03,  -2.77709961e-03],
                        [  3.29589844e-03,   3.32641602e-03],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  9.46044922e-03,   9.42993164e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  1.52587891e-04,   1.83105469e-04],
                        [  2.31933594e-03,   2.34985352e-03],
                        [  1.39465332e-02,   1.39160156e-02],
                        [  3.26538086e-02,   3.26232910e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  7.28759766e-02,   7.29064941e-02],
                        [  8.53881836e-02,   8.54187012e-02],
                        [  8.72802734e-02,   8.72497559e-02],
                        [  7.69042969e-02,   7.68432617e-02],
                        [  5.86242676e-02,   5.86242676e-02],
                        [  3.96728516e-02,   3.97644043e-02],
                        [  2.28271484e-02,   2.27966309e-02],
                        [  6.83593750e-03,   6.74438477e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -4.39453125e-03,  -4.30297852e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.57873535e-02,   2.57263184e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.23889160e-02,   4.24499512e-02],
                        [  4.62341309e-02,   4.62646484e-02],
                        [  4.88281250e-02,   4.87976074e-02],
                        [  5.02014160e-02,   5.01708984e-02],
                        [  4.90112305e-02,   4.90417480e-02],
                        [  4.31823730e-02,   4.32128906e-02],
                        [  3.57055664e-02,   3.57360840e-02],
                        [  3.34167480e-02,   3.33862305e-02],
                        [  3.69262695e-02,   3.68957520e-02],
                        [  3.86047363e-02,   3.86352539e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  2.04467773e-02,   2.04162598e-02],
                        [  7.75146484e-03,   7.78198242e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -8.36181641e-03,  -8.42285156e-03],
                        [ -1.16577148e-02,  -1.16882324e-02],
                        [ -1.43737793e-02,  -1.42822266e-02],
                        [ -1.85241699e-02,  -1.84936523e-02],
                        [ -2.43225098e-02,  -2.44445801e-02],
                        [ -2.97851562e-02,  -2.98461914e-02],
                        [ -3.21655273e-02,  -3.20434570e-02],
                        [ -3.05175781e-02,  -3.04260254e-02],
                        [ -2.67639160e-02,  -2.68554688e-02],
                        [ -2.40478516e-02,  -2.41088867e-02],
                        [ -2.38037109e-02,  -2.37426758e-02],
                        [ -2.47497559e-02,  -2.47192383e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -1.12915039e-02,  -1.13220215e-02],
                        [ -4.36401367e-03,  -4.39453125e-03],
                        [ -2.86865234e-03,  -2.80761719e-03],
                        [ -6.62231445e-03,  -6.59179688e-03],
                        [ -1.29089355e-02,  -1.29699707e-02],
                        [ -1.94702148e-02,  -1.95312500e-02],
                        [ -2.47192383e-02,  -2.46582031e-02],
                        [ -2.78320312e-02,  -2.77404785e-02],
                        [ -2.99072266e-02,  -2.99682617e-02],
                        [ -3.20434570e-02,  -3.21350098e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -2.74658203e-02,  -2.73742676e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -1.54724121e-02,  -1.55334473e-02],
                        [ -1.50756836e-02,  -1.51062012e-02],
                        [ -1.72119141e-02,  -1.71508789e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [  4.21142578e-03,   4.24194336e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.38854980e-02,   1.39160156e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  5.18798828e-03,   5.12695312e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  1.47399902e-02,   1.48010254e-02],
                        [  3.12805176e-02,   3.12500000e-02],
                        [  5.27954102e-02,   5.27648926e-02],
                        [  7.62939453e-02,   7.62634277e-02],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  1.17919922e-01,   1.17980957e-01],
                        [  1.29974365e-01,   1.30004883e-01],
                        [  1.26892090e-01,   1.26800537e-01],
                        [  9.98229980e-02,   9.97619629e-02],
                        [  4.48913574e-02,   4.49829102e-02],
                        [ -3.44543457e-02,  -3.43933105e-02],
                        [ -1.28784180e-01,  -1.28845215e-01],
                        [ -2.20794678e-01,  -2.20855713e-01],
                        [ -2.83111572e-01,  -2.83081055e-01],
                        [ -2.92144775e-01,  -2.92083740e-01],
                        [ -2.51831055e-01,  -2.51831055e-01],
                        [ -1.95220947e-01,  -1.95281982e-01],
                        [ -1.56341553e-01,  -1.56372070e-01],
                        [ -1.44042969e-01,  -1.43981934e-01],
                        [ -1.44653320e-01,  -1.44592285e-01],
                        [ -1.42669678e-01,  -1.42730713e-01],
                        [ -1.32873535e-01,  -1.32934570e-01],
                        [ -1.16058350e-01,  -1.15997314e-01],
                        [ -9.02404785e-02,  -9.01794434e-02],
                        [ -4.84924316e-02,  -4.85534668e-02],
                        [  1.42822266e-02,   1.42211914e-02],
                        [  9.29565430e-02,   9.29870605e-02],
                        [  1.70745850e-01,   1.70776367e-01],
                        [  2.26806641e-01,   2.26776123e-01],
                        [  2.46612549e-01,   2.46582031e-01],
                        [  2.27722168e-01,   2.27752686e-01],
                        [  1.77215576e-01,   1.77215576e-01],
                        [  1.06262207e-01,   1.06262207e-01],
                        [  3.13110352e-02,   3.13110352e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -5.05065918e-02,  -5.05371094e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -2.60009766e-02,  -2.59704590e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  1.07421875e-02,   1.07116699e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  6.59179688e-03,   6.62231445e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  6.34765625e-03,   6.31713867e-03],
                        [  4.88281250e-03,   4.85229492e-03],
                        [  5.24902344e-03,   5.27954102e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  7.38525391e-02,   7.38220215e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  9.70764160e-02,   9.71374512e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  7.35778809e-02,   7.35168457e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  3.96423340e-02,   3.97033691e-02],
                        [  2.91442871e-02,   2.91748047e-02],
                        [  2.27050781e-02,   2.26440430e-02],
                        [  1.76391602e-02,   1.76086426e-02],
                        [  1.38854980e-02,   1.39160156e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.50451660e-02,   1.50146484e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.55432129e-02,   2.55737305e-02],
                        [  3.26232910e-02,   3.25927734e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.16467285e-02,   3.16772461e-02],
                        [  2.89306641e-02,   2.89611816e-02],
                        [  3.11584473e-02,   3.11279297e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  3.18908691e-02,   3.18603516e-02],
                        [  2.34680176e-02,   2.34985352e-02],
                        [  1.55029297e-02,   1.55334473e-02],
                        [  4.48608398e-03,   4.45556641e-03],
                        [ -9.67407227e-03,  -9.70458984e-03],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.04260254e-02,  -3.03955078e-02],
                        [ -3.27758789e-02,  -3.28063965e-02],
                        [ -2.89306641e-02,  -2.89611816e-02],
                        [ -2.07214355e-02,  -2.06909180e-02],
                        [ -1.22375488e-02,  -1.22070312e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -2.50549316e-02,  -2.50854492e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -3.34472656e-02,  -3.34167480e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -1.88598633e-02,  -1.88903809e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.70593262e-02,  -1.70288086e-02],
                        [ -2.21862793e-02,  -2.22167969e-02],
                        [ -2.37731934e-02,  -2.38037109e-02],
                        [ -2.13623047e-02,  -2.13317871e-02],
                        [ -1.89208984e-02,  -1.88903809e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.92053223e-02,  -2.91748047e-02],
                        [ -3.00903320e-02,  -3.00598145e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  2.44140625e-03,   2.41088867e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -3.47900391e-03,  -3.44848633e-03],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  1.10778809e-02,   1.10473633e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.95410156e-02,   2.95715332e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.26025391e-02,   4.25415039e-02],
                        [  5.31921387e-02,   5.31616211e-02],
                        [  7.15026855e-02,   7.15637207e-02],
                        [  9.45129395e-02,   9.45434570e-02],
                        [  1.14044189e-01,   1.13983154e-01],
                        [  1.24542236e-01,   1.24511719e-01],
                        [  1.23565674e-01,   1.23596191e-01],
                        [  1.04095459e-01,   1.04125977e-01],
                        [  5.52978516e-02,   5.53283691e-02],
                        [ -2.60925293e-02,  -2.61230469e-02],
                        [ -1.29333496e-01,  -1.29364014e-01],
                        [ -2.30926514e-01,  -2.30926514e-01],
                        [ -2.99133301e-01,  -2.99072266e-01],
                        [ -3.08746338e-01,  -3.08715820e-01],
                        [ -2.64556885e-01,  -2.64587402e-01],
                        [ -2.02056885e-01,  -2.02087402e-01],
                        [ -1.55426025e-01,  -1.55426025e-01],
                        [ -1.31286621e-01,  -1.31225586e-01],
                        [ -1.18072510e-01,  -1.18072510e-01],
                        [ -1.07818604e-01,  -1.07879639e-01],
                        [ -1.00402832e-01,  -1.00433350e-01],
                        [ -9.45739746e-02,  -9.45434570e-02],
                        [ -8.11767578e-02,  -8.11462402e-02],
                        [ -4.66308594e-02,  -4.66613770e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  1.70715332e-01,   1.70715332e-01],
                        [  2.20489502e-01,   2.20520020e-01],
                        [  2.31628418e-01,   2.31628418e-01],
                        [  2.02972412e-01,   2.02941895e-01],
                        [  1.44714355e-01,   1.44683838e-01],
                        [  7.41577148e-02,   7.42187500e-02],
                        [  9.70458984e-03,   9.73510742e-03],
                        [ -3.41186523e-02,  -3.41796875e-02],
                        [ -5.11779785e-02,  -5.12084961e-02],
                        [ -4.70581055e-02,  -4.69970703e-02],
                        [ -3.32641602e-02,  -3.32336426e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -6.10351562e-04,  -6.40869141e-04],
                        [  1.49536133e-02,   1.49841309e-02],
                        [  2.37121582e-02,   2.37426758e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  1.71813965e-02,   1.71508789e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  7.79724121e-02,   7.79418945e-02],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  9.54284668e-02,   9.54589844e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  7.34863281e-02,   7.34558105e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  2.63671875e-02,   2.63977051e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.48010254e-02,   1.47705078e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.76794434e-02,   2.76489258e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.07006836e-02,   3.07312012e-02],
                        [  3.31420898e-02,   3.31726074e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  8.60595703e-03,   8.63647461e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -8.14819336e-03,  -8.17871094e-03],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -2.24914551e-02,  -2.24609375e-02],
                        [ -2.71606445e-02,  -2.71301270e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -1.59301758e-02,  -1.59606934e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.73742676e-02,  -2.74047852e-02],
                        [ -2.60009766e-02,  -2.60314941e-02],
                        [ -2.27050781e-02,  -2.26745605e-02],
                        [ -1.84326172e-02,  -1.84020996e-02],
                        [ -1.60217285e-02,  -1.60522461e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.52990723e-02,  -2.53295898e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -4.48608398e-03,  -4.51660156e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.15966797e-02,  -1.15661621e-02],
                        [ -1.86157227e-02,  -1.85852051e-02],
                        [ -2.35900879e-02,  -2.36206055e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.74255371e-02,  -1.73645020e-02],
                        [ -1.14746094e-02,  -1.14440918e-02],
                        [ -8.94165039e-03,  -8.97216797e-03],
                        [ -9.06372070e-03,  -9.09423828e-03],
                        [ -8.42285156e-03,  -8.39233398e-03],
                        [ -4.97436523e-03,  -4.94384766e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  2.80761719e-03,   2.77709961e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  9.07287598e-02,   9.07592773e-02],
                        [  1.12060547e-01,   1.12030029e-01],
                        [  1.22406006e-01,   1.22375488e-01],
                        [  1.13952637e-01,   1.13952637e-01],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [ -6.39953613e-02,  -6.40258789e-02],
                        [ -1.61010742e-01,  -1.61041260e-01],
                        [ -2.45391846e-01,  -2.45391846e-01],
                        [ -2.89245605e-01,  -2.89215088e-01],
                        [ -2.77465820e-01,  -2.77465820e-01],
                        [ -2.23388672e-01,  -2.23419189e-01],
                        [ -1.62841797e-01,  -1.62841797e-01],
                        [ -1.26312256e-01,  -1.26312256e-01],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -1.21704102e-01,  -1.21673584e-01],
                        [ -1.22375488e-01,  -1.22375488e-01],
                        [ -1.15051270e-01,  -1.15051270e-01],
                        [ -1.01806641e-01,  -1.01776123e-01],
                        [ -8.38928223e-02,  -8.38928223e-02],
                        [ -5.60913086e-02,  -5.61218262e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  1.43280029e-01,   1.43280029e-01],
                        [  2.08831787e-01,   2.08801270e-01],
                        [  2.28973389e-01,   2.29003906e-01],
                        [  1.91253662e-01,   1.91253662e-01],
                        [  1.12121582e-01,   1.12121582e-01],
                        [  2.87475586e-02,   2.87475586e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.82080078e-02,  -3.81774902e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -1.48315430e-02,  -1.48620605e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  3.41186523e-02,   3.41491699e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  3.31115723e-02,   3.31420898e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  8.21228027e-02,   8.20922852e-02],
                        [  9.58862305e-02,   9.58557129e-02],
                        [  9.69848633e-02,   9.70153809e-02],
                        [  8.47778320e-02,   8.48083496e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  5.21240234e-02,   5.20935059e-02],
                        [  4.51660156e-02,   4.51965332e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.41186523e-02,   3.40881348e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.45666504e-02,   2.45361328e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.53601074e-02,   2.53906250e-02],
                        [  2.11181641e-02,   2.10876465e-02],
                        [  1.96533203e-02,   1.96228027e-02],
                        [  2.18811035e-02,   2.19116211e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  3.46984863e-02,   3.47290039e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  2.92968750e-02,   2.92663574e-02],
                        [  2.64282227e-02,   2.64587402e-02],
                        [  2.38647461e-02,   2.38952637e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.56958008e-02,  -2.56652832e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -4.35180664e-02,  -4.34875488e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -3.35388184e-02,  -3.35693359e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.53906250e-02,  -2.53601074e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -5.88989258e-03,  -5.85937500e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.53601074e-02,  -2.53295898e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.50952148e-02,   3.51257324e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  6.77795410e-02,   6.77795410e-02],
                        [  7.99255371e-02,   7.99560547e-02],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  9.86022949e-02,   9.85717773e-02],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  1.08734131e-01,   1.08734131e-01],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  4.89196777e-02,   4.88891602e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -1.30706787e-01,  -1.30706787e-01],
                        [ -2.33367920e-01,  -2.33398438e-01],
                        [ -2.99407959e-01,  -2.99407959e-01],
                        [ -3.02093506e-01,  -3.02093506e-01],
                        [ -2.50274658e-01,  -2.50305176e-01],
                        [ -1.83380127e-01,  -1.83380127e-01],
                        [ -1.36962891e-01,  -1.36932373e-01],
                        [ -1.17767334e-01,  -1.17767334e-01],
                        [ -1.11877441e-01,  -1.11907959e-01],
                        [ -1.06201172e-01,  -1.06201172e-01],
                        [ -9.60388184e-02,  -9.60388184e-02],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [  2.71606445e-03,   2.74658203e-03],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  1.13861084e-01,   1.13861084e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.77978516e-01,   1.77978516e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  8.79516602e-02,   8.79516602e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  1.70898438e-03,   1.73950195e-03],
                        [  7.41577148e-03,   7.38525391e-03],
                        [  1.61437988e-02,   1.61743164e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  3.79333496e-02,   3.79028320e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  1.01928711e-02,   1.02233887e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  7.37609863e-02,   7.37609863e-02],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  3.06091309e-02,   3.05786133e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  4.24499512e-02,   4.24804688e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  5.76782227e-03,   5.79833984e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -9.97924805e-03,  -1.00097656e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.66418457e-02,  -2.66723633e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.31420898e-02,  -3.31115723e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.19311523e-02,  -4.19616699e-02],
                        [ -3.69262695e-02,  -3.68957520e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.29699707e-02,  -1.30004883e-02],
                        [ -3.72314453e-03,  -3.69262695e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  6.10351562e-05,   3.05175781e-05],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  3.32031250e-02,   3.32336426e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  8.77380371e-02,   8.77685547e-02],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.23840332e-01,   1.23840332e-01],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  4.97131348e-02,   4.97131348e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -1.31042480e-01,  -1.31042480e-01],
                        [ -2.28546143e-01,  -2.28576660e-01],
                        [ -2.92266846e-01,  -2.92266846e-01],
                        [ -2.98370361e-01,  -2.98370361e-01],
                        [ -2.52990723e-01,  -2.53021240e-01],
                        [ -1.90063477e-01,  -1.90032959e-01],
                        [ -1.42242432e-01,  -1.42242432e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.04278564e-01,  -1.04278564e-01],
                        [ -9.43298340e-02,  -9.43298340e-02],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.51953125e-02,  -7.51647949e-02],
                        [ -6.13708496e-02,  -6.13403320e-02],
                        [ -4.29687500e-02,  -4.29992676e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [  1.62353516e-02,   1.62658691e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  9.44824219e-02,   9.44824219e-02],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  1.02264404e-01,   1.02264404e-01],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  4.91333008e-02,   4.91333008e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.01416016e-02,   2.01110840e-02],
                        [  2.94494629e-02,   2.94799805e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.03912354e-01,   1.03912354e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.65795898e-02,   5.66101074e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.37426758e-02,   2.37121582e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -2.74658203e-04,  -2.44140625e-04],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -2.80761719e-02,  -2.80456543e-02],
                        [ -3.16772461e-02,  -3.16467285e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.63464355e-02,  -3.63769531e-02],
                        [ -4.06188965e-02,  -4.06494141e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.24096680e-02,  -3.24401855e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -2.34680176e-02,  -2.34375000e-02],
                        [ -2.70690918e-02,  -2.70996094e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.35900879e-02,  -2.35595703e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.49023438e-02,  -2.49328613e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.25732422e-02,  -1.25427246e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -3.08227539e-03,  -3.11279297e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  5.91430664e-02,   5.91430664e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  7.87963867e-02,   7.88269043e-02],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  1.06140137e-01,   1.06109619e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  1.22680664e-01,   1.22680664e-01],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  5.67932129e-02,   5.67932129e-02],
                        [ -2.27355957e-02,  -2.27050781e-02],
                        [ -1.27166748e-01,  -1.27166748e-01],
                        [ -2.27478027e-01,  -2.27508545e-01],
                        [ -2.89398193e-01,  -2.89398193e-01],
                        [ -2.94738770e-01,  -2.94738770e-01],
                        [ -2.52471924e-01,  -2.52471924e-01],
                        [ -1.92901611e-01,  -1.92901611e-01],
                        [ -1.46575928e-01,  -1.46575928e-01],
                        [ -1.22070312e-01,  -1.22070312e-01],
                        [ -1.06781006e-01,  -1.06781006e-01],
                        [ -8.95996094e-02,  -8.95996094e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  3.68041992e-02,   3.68347168e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  3.44238281e-02,   3.43933105e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  2.88085938e-02,   2.87780762e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  1.12426758e-01,   1.12457275e-01],
                        [  1.26281738e-01,   1.26281738e-01],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  9.49401855e-02,   9.49401855e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.54003906e-02,   3.53698730e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  3.28063965e-02,   3.27758789e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -1.54418945e-02,  -1.54113770e-02],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -2.46887207e-02,  -2.46582031e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.04980469e-02,  -1.05285645e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -5.70678711e-03,  -5.73730469e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  1.72119141e-02,   1.71813965e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  1.18835449e-01,   1.18835449e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -1.32171631e-01,  -1.32171631e-01],
                        [ -2.22808838e-01,  -2.22808838e-01],
                        [ -2.77496338e-01,  -2.77496338e-01],
                        [ -2.78991699e-01,  -2.78991699e-01],
                        [ -2.34466553e-01,  -2.34466553e-01],
                        [ -1.75567627e-01,  -1.75567627e-01],
                        [ -1.33422852e-01,  -1.33422852e-01],
                        [ -1.11877441e-01,  -1.11846924e-01],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  9.60388184e-02,   9.60388184e-02],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  8.02307129e-02,   8.02307129e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  3.84826660e-02,   3.85131836e-02],
                        [  3.39660645e-02,   3.39355469e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  3.80859375e-02,   3.81164551e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  7.71484375e-02,   7.71484375e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  1.02111816e-01,   1.02111816e-01],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  4.54711914e-02,   4.54406738e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  3.75671387e-02,   3.75976562e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  3.97338867e-02,   3.97644043e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  3.41491699e-02,   3.41796875e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -6.74438477e-03,  -6.77490234e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -2.99377441e-02,  -2.99072266e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.53906250e-02,  -2.54211426e-02],
                        [ -2.93579102e-02,  -2.93273926e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -4.04663086e-02,  -4.04968262e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -3.39660645e-02,  -3.39355469e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.10974121e-02,  -3.11279297e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  2.10266113e-02,   2.09960938e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.18988037e-01,   1.18988037e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.21185303e-01,   1.21154785e-01],
                        [  8.99658203e-02,   8.99963379e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -2.21405029e-01,  -2.21374512e-01],
                        [ -2.81829834e-01,  -2.81860352e-01],
                        [ -2.83477783e-01,  -2.83477783e-01],
                        [ -2.30316162e-01,  -2.30316162e-01],
                        [ -1.58477783e-01,  -1.58477783e-01],
                        [ -1.04797363e-01,  -1.04797363e-01],
                        [ -7.99255371e-02,  -7.98950195e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -4.67529297e-02,  -4.67834473e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -7.83996582e-02,  -7.83996582e-02],
                        [ -9.45129395e-02,  -9.44824219e-02],
                        [ -9.80224609e-02,  -9.80224609e-02],
                        [ -8.12072754e-02,  -8.12072754e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  7.67517090e-02,   7.67211914e-02],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  1.02966309e-01,   1.02966309e-01],
                        [  8.42285156e-02,   8.41979980e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  6.32934570e-02,   6.33239746e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.26800537e-01,   1.26800537e-01],
                        [  1.22375488e-01,   1.22344971e-01],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  3.19824219e-02,   3.19519043e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -4.25109863e-02,  -4.24804688e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -4.00390625e-02,  -4.00695801e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -3.31420898e-02,  -3.31726074e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  1.28936768e-01,   1.28906250e-01],
                        [  1.26434326e-01,   1.26434326e-01],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -1.36596680e-01,  -1.36596680e-01],
                        [ -2.13531494e-01,  -2.13531494e-01],
                        [ -2.56469727e-01,  -2.56469727e-01],
                        [ -2.52716064e-01,  -2.52716064e-01],
                        [ -2.07458496e-01,  -2.07427979e-01],
                        [ -1.47583008e-01,  -1.47583008e-01],
                        [ -1.03729248e-01,  -1.03759766e-01],
                        [ -8.48693848e-02,  -8.48693848e-02],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -4.07409668e-02,  -4.07714844e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -1.10473633e-01,  -1.10443115e-01],
                        [ -1.40777588e-01,  -1.40747070e-01],
                        [ -1.47094727e-01,  -1.47094727e-01],
                        [ -1.23199463e-01,  -1.23199463e-01],
                        [ -7.13195801e-02,  -7.12890625e-02],
                        [ -2.13623047e-03,  -2.16674805e-03],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.06201172e-01,   1.06170654e-01],
                        [  9.34753418e-02,   9.34448242e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  5.25817871e-02,   5.25817871e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  6.28967285e-02,   6.29272461e-02],
                        [  6.20117188e-02,   6.20117188e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  7.58666992e-02,   7.58666992e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  8.85314941e-02,   8.85620117e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  5.32531738e-02,   5.32531738e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  5.02929688e-02,   5.02624512e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.87573242e-02,   3.87268066e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  2.40783691e-02,   2.40478516e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  6.59179688e-03,   6.62231445e-03],
                        [  9.55200195e-03,   9.58251953e-03],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  2.27355957e-02,   2.27050781e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.85852051e-02,  -1.86157227e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -4.18090820e-02,  -4.17785645e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.72412109e-02,  -4.72717285e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -3.06091309e-02,  -3.05786133e-02],
                        [ -3.10058594e-02,  -3.10363770e-02],
                        [ -3.18603516e-02,  -3.18908691e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -1.62963867e-02,  -1.63269043e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -5.49316406e-04,  -5.18798828e-04],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  8.23974609e-04,   8.23974609e-04],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  3.57666016e-02,   3.57971191e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  6.13098145e-02,   6.13098145e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.16668701e-01,  -1.16668701e-01],
                        [ -2.05413818e-01,  -2.05413818e-01],
                        [ -2.63275146e-01,  -2.63275146e-01],
                        [ -2.73620605e-01,  -2.73620605e-01],
                        [ -2.36907959e-01,  -2.36907959e-01],
                        [ -1.75964355e-01,  -1.75964355e-01],
                        [ -1.21154785e-01,  -1.21154785e-01],
                        [ -8.56933594e-02,  -8.56933594e-02],
                        [ -6.21643066e-02,  -6.21337891e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -1.05621338e-01,  -1.05651855e-01],
                        [ -1.47430420e-01,  -1.47430420e-01],
                        [ -1.73645020e-01,  -1.73645020e-01],
                        [ -1.70196533e-01,  -1.70196533e-01],
                        [ -1.31439209e-01,  -1.31439209e-01],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.39434814e-01,   1.39434814e-01],
                        [  1.26586914e-01,   1.26586914e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  6.97631836e-02,   6.97631836e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  4.69665527e-02,   4.69665527e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.17523193e-01,   1.17523193e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  6.54296875e-02,   6.54602051e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.40063477e-02,  -4.40368652e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.35009766e-01,   1.35009766e-01],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  6.29577637e-02,   6.29577637e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -2.06542969e-01,  -2.06542969e-01],
                        [ -2.71514893e-01,  -2.71514893e-01],
                        [ -2.82562256e-01,  -2.82562256e-01],
                        [ -2.41455078e-01,  -2.41455078e-01],
                        [ -1.77368164e-01,  -1.77368164e-01],
                        [ -1.23199463e-01,  -1.23199463e-01],
                        [ -9.00878906e-02,  -9.00878906e-02],
                        [ -6.86950684e-02,  -6.86950684e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -1.12976074e-01,  -1.12976074e-01],
                        [ -1.65069580e-01,  -1.65069580e-01],
                        [ -1.98425293e-01,  -1.98425293e-01],
                        [ -1.99523926e-01,  -1.99523926e-01],
                        [ -1.70379639e-01,  -1.70379639e-01],
                        [ -1.21154785e-01,  -1.21154785e-01],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  9.98535156e-02,   9.98535156e-02],
                        [  1.31988525e-01,   1.31988525e-01],
                        [  1.42547607e-01,   1.42547607e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  7.54089355e-02,   7.53784180e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  7.37609863e-02,   7.37609863e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  1.13739014e-01,   1.13739014e-01],
                        [  1.31835938e-01,   1.31835938e-01],
                        [  1.38153076e-01,   1.38153076e-01],
                        [  1.30950928e-01,   1.30950928e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  6.19812012e-02,   6.19812012e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -4.69970703e-03,  -4.73022461e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.60620117e-02,  -2.60925293e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  3.87573242e-03,   3.90625000e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  9.66186523e-02,   9.66186523e-02],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  1.39678955e-01,   1.39678955e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -1.94976807e-01,  -1.94976807e-01],
                        [ -2.66601562e-01,  -2.66601562e-01],
                        [ -2.81097412e-01,  -2.81097412e-01],
                        [ -2.39196777e-01,  -2.39196777e-01],
                        [ -1.68823242e-01,  -1.68823242e-01],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -1.51245117e-01,  -1.51245117e-01],
                        [ -1.98364258e-01,  -1.98364258e-01],
                        [ -2.20489502e-01,  -2.20489502e-01],
                        [ -2.06390381e-01,  -2.06390381e-01],
                        [ -1.62384033e-01,  -1.62384033e-01],
                        [ -1.09313965e-01,  -1.09313965e-01],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.38092041e-01,   1.38092041e-01],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  8.73413086e-02,   8.73413086e-02],
                        [  8.44726562e-02,   8.44726562e-02],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  1.24694824e-01,   1.24694824e-01],
                        [  1.43646240e-01,   1.43646240e-01],
                        [  1.50878906e-01,   1.50909424e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.26892090e-01,   1.26892090e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  8.33435059e-02,   8.33435059e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  2.07519531e-03,   2.07519531e-03],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  1.02600098e-01,   1.02600098e-01],
                        [  1.27441406e-01,   1.27441406e-01],
                        [  1.47277832e-01,   1.47277832e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -1.81488037e-01,  -1.81488037e-01],
                        [ -2.52593994e-01,  -2.52593994e-01],
                        [ -2.69042969e-01,  -2.69042969e-01],
                        [ -2.31201172e-01,  -2.31201172e-01],
                        [ -1.64306641e-01,  -1.64306641e-01],
                        [ -1.00799561e-01,  -1.00799561e-01],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -9.86938477e-02,  -9.86938477e-02],
                        [ -1.52099609e-01,  -1.52099609e-01],
                        [ -1.97967529e-01,  -1.97967529e-01],
                        [ -2.17041016e-01,  -2.17041016e-01],
                        [ -2.04315186e-01,  -2.04315186e-01],
                        [ -1.69677734e-01,  -1.69677734e-01],
                        [ -1.29241943e-01,  -1.29241943e-01],
                        [ -9.26208496e-02,  -9.26208496e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.47949219e-01,   1.47949219e-01],
                        [  1.62353516e-01,   1.62353516e-01],
                        [  1.49780273e-01,   1.49780273e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.19812012e-01,   1.19812012e-01],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.45263672e-01,   1.45263672e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  8.19396973e-02,   8.19396973e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  7.39440918e-02,   7.39440918e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.49444580e-01,   1.49444580e-01],
                        [  1.49566650e-01,   1.49566650e-01],
                        [  1.23077393e-01,   1.23077393e-01],
                        [  6.99157715e-02,   6.99157715e-02],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -9.78393555e-02,  -9.78393555e-02],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -2.47955322e-01,  -2.47955322e-01],
                        [ -2.55828857e-01,  -2.55828857e-01],
                        [ -2.11853027e-01,  -2.11853027e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -9.07897949e-02,  -9.07897949e-02],
                        [ -1.17156982e-01,  -1.17156982e-01],
                        [ -1.47125244e-01,  -1.47125244e-01],
                        [ -1.74255371e-01,  -1.74255371e-01],
                        [ -1.87744141e-01,  -1.87744141e-01],
                        [ -1.81732178e-01,  -1.81732178e-01],
                        [ -1.61621094e-01,  -1.61621094e-01],
                        [ -1.37817383e-01,  -1.37817383e-01],
                        [ -1.14654541e-01,  -1.14654541e-01],
                        [ -8.88061523e-02,  -8.88061523e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [  3.64379883e-02,   3.64074707e-02],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  1.26007080e-01,   1.25976562e-01],
                        [  1.45782471e-01,   1.45782471e-01],
                        [  1.44836426e-01,   1.44836426e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  9.53979492e-02,   9.53979492e-02],
                        [  1.01226807e-01,   1.01196289e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  1.25671387e-01,   1.25671387e-01],
                        [  1.38427734e-01,   1.38427734e-01],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.30859375e-01,   1.30859375e-01],
                        [  1.12762451e-01,   1.12731934e-01],
                        [  9.31396484e-02,   9.31396484e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  6.10961914e-02,   6.10961914e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  2.38647461e-02,   2.38342285e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.22680664e-02,   1.22375488e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -1.06201172e-02,  -1.06506348e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -5.92041016e-03,  -5.95092773e-03],
                        [ -7.93457031e-03,  -7.96508789e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.75476074e-02,  -1.75781250e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  7.34863281e-02,   7.34558105e-02],
                        [  1.00891113e-01,   1.00860596e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.58691406e-01,   1.58660889e-01],
                        [  1.27105713e-01,   1.27105713e-01],
                        [  7.05566406e-02,   7.05566406e-02],
                        [ -7.78198242e-03,  -7.81250000e-03],
                        [ -1.01684570e-01,  -1.01715088e-01],
                        [ -1.91894531e-01,  -1.91894531e-01],
                        [ -2.48260498e-01,  -2.48291016e-01],
                        [ -2.47741699e-01,  -2.47772217e-01],
                        [ -1.94335938e-01,  -1.94335938e-01],
                        [ -1.21765137e-01,  -1.21765137e-01],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -1.29943848e-01,  -1.29974365e-01],
                        [ -1.67816162e-01,  -1.67846680e-01],
                        [ -1.91192627e-01,  -1.91192627e-01],
                        [ -1.91986084e-01,  -1.91986084e-01],
                        [ -1.70593262e-01,  -1.70593262e-01],
                        [ -1.39099121e-01,  -1.39099121e-01],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -1.00311279e-01,  -1.00311279e-01],
                        [ -9.46960449e-02,  -9.47265625e-02],
                        [ -8.56018066e-02,  -8.56323242e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -3.13415527e-02,  -3.13720703e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.46820068e-01,   1.46789551e-01],
                        [  1.54388428e-01,   1.54388428e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  9.26513672e-02,   9.26208496e-02],
                        [  9.25292969e-02,   9.24987793e-02],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  1.43066406e-01,   1.43035889e-01],
                        [  1.58020020e-01,   1.58020020e-01],
                        [  1.61682129e-01,   1.61682129e-01],
                        [  1.52404785e-01,   1.52374268e-01],
                        [  1.30401611e-01,   1.30401611e-01],
                        [  1.02508545e-01,   1.02478027e-01],
                        [  7.96813965e-02,   7.96508789e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  6.03332520e-02,   6.03027344e-02],
                        [  5.54504395e-02,   5.54199219e-02],
                        [  5.24291992e-02,   5.23986816e-02],
                        [  5.26733398e-02,   5.26428223e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  5.36499023e-02,   5.36193848e-02],
                        [  4.67224121e-02,   4.66918945e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  1.80969238e-02,   1.80664062e-02],
                        [  7.53784180e-03,   7.50732422e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  5.92041016e-03,   5.88989258e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.62451172e-02,   2.62145996e-02],
                        [  2.64282227e-02,   2.63977051e-02],
                        [  2.31323242e-02,   2.31018066e-02],
                        [  1.78527832e-02,   1.78222656e-02],
                        [  1.26342773e-02,   1.26037598e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  5.09643555e-03,   5.06591797e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.80053711e-03,  -1.83105469e-03],
                        [ -5.49316406e-04,  -5.79833984e-04],
                        [  2.34985352e-03,   2.31933594e-03],
                        [  1.49536133e-03,   1.46484375e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -9.94873047e-03,  -9.97924805e-03],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -3.47900391e-02,  -3.48205566e-02],
                        [ -3.97644043e-02,  -3.97949219e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.59997559e-02,  -5.60302734e-02],
                        [ -6.26525879e-02,  -6.26831055e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.32019043e-02,  -6.32324219e-02],
                        [ -6.29882812e-02,  -6.30187988e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -4.96520996e-02,  -4.96826172e-02],
                        [ -3.82995605e-02,  -3.83300781e-02],
                        [ -2.94189453e-02,  -2.94494629e-02],
                        [ -2.87780762e-02,  -2.88085938e-02],
                        [ -3.53393555e-02,  -3.53698730e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.99169922e-02,  -3.99475098e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -2.63366699e-02,  -2.63671875e-02],
                        [ -2.11486816e-02,  -2.11791992e-02],
                        [ -1.62658691e-02,  -1.62963867e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.48925781e-02,  -1.49230957e-02],
                        [ -1.60827637e-02,  -1.61132812e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  1.22375488e-02,   1.22070312e-02],
                        [  1.92871094e-02,   1.92565918e-02],
                        [  2.95715332e-02,   2.95410156e-02],
                        [  4.31213379e-02,   4.30908203e-02],
                        [  5.33752441e-02,   5.33447266e-02],
                        [  6.03637695e-02,   6.03332520e-02],
                        [  7.28454590e-02,   7.28149414e-02],
                        [  9.57336426e-02,   9.57031250e-02],
                        [  1.23809814e-01,   1.23779297e-01],
                        [  1.46545410e-01,   1.46514893e-01],
                        [  1.52343750e-01,   1.52343750e-01],
                        [  1.31072998e-01,   1.31042480e-01],
                        [  7.95288086e-02,   7.94982910e-02],
                        [  3.47900391e-03,   3.44848633e-03],
                        [ -8.59375000e-02,  -8.59680176e-02],
                        [ -1.71691895e-01,  -1.71722412e-01],
                        [ -2.29278564e-01,  -2.29309082e-01],
                        [ -2.37213135e-01,  -2.37243652e-01],
                        [ -1.96014404e-01,  -1.96044922e-01],
                        [ -1.34582520e-01,  -1.34613037e-01],
                        [ -9.25292969e-02,  -9.25598145e-02],
                        [ -9.06982422e-02,  -9.06982422e-02],
                        [ -1.18652344e-01,  -1.18682861e-01],
                        [ -1.51977539e-01,  -1.52008057e-01],
                        [ -1.75476074e-01,  -1.75476074e-01],
                        [ -1.85363770e-01,  -1.85394287e-01],
                        [ -1.81030273e-01,  -1.81060791e-01],
                        [ -1.64764404e-01,  -1.64764404e-01],
                        [ -1.43524170e-01,  -1.43554688e-01],
                        [ -1.23748779e-01,  -1.23779297e-01],
                        [ -1.06781006e-01,  -1.06811523e-01],
                        [ -9.18273926e-02,  -9.18579102e-02],
                        [ -7.79724121e-02,  -7.80029297e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -4.16564941e-02,  -4.16870117e-02],
                        [ -8.30078125e-03,  -8.33129883e-03],
                        [  3.97644043e-02,   3.97338867e-02],
                        [  9.50927734e-02,   9.50622559e-02],
                        [  1.39892578e-01,   1.39892578e-01],
                        [  1.58172607e-01,   1.58142090e-01],
                        [  1.49841309e-01,   1.49810791e-01],
                        [  1.30493164e-01,   1.30493164e-01],
                        [  1.16485596e-01,   1.16455078e-01],
                        [  1.12976074e-01,   1.12945557e-01],
                        [  1.16088867e-01,   1.16058350e-01],
                        [  1.22070312e-01,   1.22039795e-01],
                        [  1.31317139e-01,   1.31286621e-01],
                        [  1.44653320e-01,   1.44622803e-01],
                        [  1.57836914e-01,   1.57806396e-01],
                        [  1.63574219e-01,   1.63543701e-01],
                        [  1.58935547e-01,   1.58905029e-01],
                        [  1.46575928e-01,   1.46545410e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.07482910e-01,   1.07452393e-01],
                        [  8.46557617e-02,   8.46252441e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  5.28564453e-02,   5.28259277e-02],
                        [  4.60510254e-02,   4.60205078e-02],
                        [  4.41894531e-02,   4.41589355e-02],
                        [  4.55322266e-02,   4.55017090e-02],
                        [  4.70886230e-02,   4.70581055e-02],
                        [  4.62951660e-02,   4.62646484e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  3.37219238e-02,   3.36914062e-02],
                        [  2.33154297e-02,   2.32849121e-02],
                        [  1.50756836e-02,   1.50451660e-02],
                        [  1.23901367e-02,   1.23596191e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  8.85009766e-03,   8.81958008e-03],
                        [  2.59399414e-03,   2.56347656e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  6.98852539e-03,   6.95800781e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.18713379e-02,   1.18408203e-02],
                        [  1.40075684e-02,   1.39770508e-02],
                        [  1.95922852e-02,   1.95617676e-02],
                        [  2.56958008e-02,   2.56652832e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.46679688e-02,   3.46374512e-02],
                        [  2.91137695e-02,   2.90832520e-02],
                        [  1.51062012e-02,   1.50756836e-02],
                        [  2.92968750e-03,   2.86865234e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  4.27246094e-04,   3.96728516e-04],
                        [ -2.65502930e-03,  -2.68554688e-03],
                        [ -8.27026367e-03,  -8.30078125e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.93481445e-02,  -1.93786621e-02],
                        [ -2.70690918e-02,  -2.70996094e-02],
                        [ -3.23181152e-02,  -3.23486328e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.67224121e-02,  -4.67529297e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -5.67016602e-02,  -5.67321777e-02],
                        [ -6.25305176e-02,  -6.25610352e-02],
                        [ -6.80236816e-02,  -6.80541992e-02],
                        [ -6.77795410e-02,  -6.78100586e-02],
                        [ -6.06689453e-02,  -6.06994629e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.26330566e-02,  -4.26635742e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.81469727e-02,  -3.81774902e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.15246582e-02,  -3.15551758e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.63464355e-02,  -3.63769531e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -2.81066895e-02,  -2.81372070e-02],
                        [ -2.24914551e-02,  -2.25219727e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.68762207e-02,  -1.69067383e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -2.74658203e-03,  -2.77709961e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  6.71386719e-03,   6.68334961e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.05480957e-02,   3.05175781e-02],
                        [  3.89709473e-02,   3.89404297e-02],
                        [  4.64477539e-02,   4.64172363e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  8.57543945e-02,   8.57238770e-02],
                        [  1.14624023e-01,   1.14593506e-01],
                        [  1.41326904e-01,   1.41296387e-01],
                        [  1.59423828e-01,   1.59423828e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.33666992e-01,   1.33636475e-01],
                        [  7.74230957e-02,   7.74230957e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -9.39025879e-02,  -9.39331055e-02],
                        [ -1.75811768e-01,  -1.75842285e-01],
                        [ -2.24945068e-01,  -2.24945068e-01],
                        [ -2.24395752e-01,  -2.24395752e-01],
                        [ -1.81427002e-01,  -1.81427002e-01],
                        [ -1.29791260e-01,  -1.29791260e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -1.19110107e-01,  -1.19140625e-01],
                        [ -1.54815674e-01,  -1.54846191e-01],
                        [ -1.88537598e-01,  -1.88537598e-01],
                        [ -2.03399658e-01,  -2.03399658e-01],
                        [ -1.94793701e-01,  -1.94793701e-01],
                        [ -1.68792725e-01,  -1.68792725e-01],
                        [ -1.36962891e-01,  -1.36962891e-01],
                        [ -1.10076904e-01,  -1.10107422e-01],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -8.80737305e-02,  -8.81042480e-02],
                        [ -8.35266113e-02,  -8.35571289e-02],
                        [ -7.18078613e-02,  -7.18078613e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  1.38427734e-01,   1.38397217e-01],
                        [  1.68609619e-01,   1.68609619e-01],
                        [  1.72119141e-01,   1.72149658e-01],
                        [  1.57257080e-01,   1.57226562e-01],
                        [  1.38031006e-01,   1.38000488e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.29455566e-01,   1.29425049e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.73400879e-01,   1.73400879e-01],
                        [  1.73858643e-01,   1.73858643e-01],
                        [  1.61041260e-01,   1.61071777e-01],
                        [  1.38885498e-01,   1.38854980e-01],
                        [  1.16790771e-01,   1.16790771e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  4.26025391e-02,   4.26330566e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  2.80456543e-02,   2.80761719e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.47290039e-02,   3.47595215e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -2.44140625e-03,  -2.41088867e-03],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [ -8.14819336e-03,  -8.11767578e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.46484375e-03,   1.49536133e-03],
                        [ -2.96020508e-03,  -2.92968750e-03],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.64990234e-02,  -3.64685059e-02],
                        [ -4.24499512e-02,  -4.24194336e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -6.76879883e-02,  -6.76574707e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.01000977e-02,  -4.00695801e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.88586426e-02,  -4.88281250e-02],
                        [ -5.74951172e-02,  -5.74645996e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.36193848e-02,  -5.35888672e-02],
                        [ -4.88281250e-02,  -4.87976074e-02],
                        [ -3.96423340e-02,  -3.96118164e-02],
                        [ -2.42919922e-02,  -2.42614746e-02],
                        [ -1.24511719e-02,  -1.24206543e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.51672363e-02,  -1.51367188e-02],
                        [ -1.83715820e-02,  -1.83410645e-02],
                        [ -2.05383301e-02,  -2.05078125e-02],
                        [ -2.16979980e-02,  -2.16674805e-02],
                        [ -1.87377930e-02,  -1.86767578e-02],
                        [ -1.05895996e-02,  -1.05590820e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  5.40161133e-03,   5.43212891e-03],
                        [  9.70458984e-03,   9.73510742e-03],
                        [  1.81884766e-02,   1.82189941e-02],
                        [  3.49121094e-02,   3.49426270e-02],
                        [  5.61828613e-02,   5.62133789e-02],
                        [  7.57446289e-02,   7.57751465e-02],
                        [  9.35668945e-02,   9.35974121e-02],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  1.36230469e-01,   1.36291504e-01],
                        [  1.51580811e-01,   1.51641846e-01],
                        [  1.50024414e-01,   1.50024414e-01],
                        [  1.24542236e-01,   1.24572754e-01],
                        [  7.13195801e-02,   7.13806152e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [ -9.38415527e-02,  -9.38415527e-02],
                        [ -1.70806885e-01,  -1.70776367e-01],
                        [ -2.17376709e-01,  -2.17315674e-01],
                        [ -2.20764160e-01,  -2.20764160e-01],
                        [ -1.88354492e-01,  -1.88293457e-01],
                        [ -1.52587891e-01,  -1.52526855e-01],
                        [ -1.47613525e-01,  -1.47613525e-01],
                        [ -1.77764893e-01,  -1.77764893e-01],
                        [ -2.16705322e-01,  -2.16644287e-01],
                        [ -2.34710693e-01,  -2.34680176e-01],
                        [ -2.22076416e-01,  -2.22076416e-01],
                        [ -1.90277100e-01,  -1.90216064e-01],
                        [ -1.57409668e-01,  -1.57379150e-01],
                        [ -1.33392334e-01,  -1.33392334e-01],
                        [ -1.15600586e-01,  -1.15539551e-01],
                        [ -9.54895020e-02,  -9.54284668e-02],
                        [ -7.04650879e-02,  -7.04345703e-02],
                        [ -4.97131348e-02,  -4.96826172e-02],
                        [ -4.36096191e-02,  -4.35791016e-02],
                        [ -4.74853516e-02,  -4.74243164e-02],
                        [ -4.40368652e-02,  -4.40063477e-02],
                        [ -2.13317871e-02,  -2.13012695e-02],
                        [  1.99890137e-02,   2.00195312e-02],
                        [  7.20214844e-02,   7.20825195e-02],
                        [  1.22985840e-01,   1.23046875e-01],
                        [  1.58416748e-01,   1.58447266e-01],
                        [  1.68609619e-01,   1.68670654e-01],
                        [  1.55883789e-01,   1.55944824e-01],
                        [  1.32751465e-01,   1.32781982e-01],
                        [  1.13830566e-01,   1.13861084e-01],
                        [  1.08886719e-01,   1.08947754e-01],
                        [  1.19995117e-01,   1.20025635e-01],
                        [  1.42242432e-01,   1.42272949e-01],
                        [  1.66229248e-01,   1.66290283e-01],
                        [  1.82769775e-01,   1.82830811e-01],
                        [  1.87286377e-01,   1.87316895e-01],
                        [  1.79199219e-01,   1.79229736e-01],
                        [  1.59179688e-01,   1.59240723e-01],
                        [  1.29638672e-01,   1.29699707e-01],
                        [  9.67102051e-02,   9.67407227e-02],
                        [  6.81762695e-02,   6.82373047e-02],
                        [  5.07202148e-02,   5.07812500e-02],
                        [  4.67529297e-02,   4.67834473e-02],
                        [  5.00183105e-02,   5.00488281e-02],
                        [  4.85534668e-02,   4.86145020e-02],
                        [  3.80249023e-02,   3.80859375e-02],
                        [  2.65197754e-02,   2.65502930e-02],
                        [  2.19726562e-02,   2.20336914e-02],
                        [  2.27661133e-02,   2.27966309e-02],
                        [  2.41394043e-02,   2.41699219e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  2.29797363e-02,   2.30407715e-02],
                        [  1.78527832e-02,   1.78833008e-02],
                        [  1.07116699e-02,   1.07421875e-02],
                        [  4.69970703e-03,   4.73022461e-03],
                        [  1.03759766e-03,   1.09863281e-03],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [ -1.55639648e-03,  -1.52587891e-03],
                        [ -1.61743164e-03,  -1.55639648e-03],
                        [  9.15527344e-04,   9.76562500e-04],
                        [  8.69750977e-03,   8.72802734e-03],
                        [  2.05383301e-02,   2.05688477e-02],
                        [  3.04260254e-02,   3.04870605e-02],
                        [  3.33557129e-02,   3.33862305e-02],
                        [  2.84118652e-02,   2.84729004e-02],
                        [  1.76086426e-02,   1.76696777e-02],
                        [  4.69970703e-03,   4.73022461e-03],
                        [ -5.49316406e-03,  -5.46264648e-03],
                        [ -1.03149414e-02,  -1.02539062e-02],
                        [ -1.03454590e-02,  -1.02844238e-02],
                        [ -7.75146484e-03,  -7.72094727e-03],
                        [ -6.43920898e-03,  -6.40869141e-03],
                        [ -1.06811523e-02,  -1.06201172e-02],
                        [ -1.91345215e-02,  -1.90734863e-02],
                        [ -2.55432129e-02,  -2.54821777e-02],
                        [ -2.83508301e-02,  -2.82897949e-02],
                        [ -3.20739746e-02,  -3.20434570e-02],
                        [ -3.86962891e-02,  -3.86352539e-02],
                        [ -4.67529297e-02,  -4.66918945e-02],
                        [ -5.62438965e-02,  -5.61828613e-02],
                        [ -6.51550293e-02,  -6.51245117e-02],
                        [ -6.76574707e-02,  -6.75964355e-02],
                        [ -6.34765625e-02,  -6.34155273e-02],
                        [ -6.06689453e-02,  -6.06384277e-02],
                        [ -6.27746582e-02,  -6.27136230e-02],
                        [ -6.38122559e-02,  -6.37817383e-02],
                        [ -6.07299805e-02,  -6.06689453e-02],
                        [ -5.81359863e-02,  -5.80749512e-02],
                        [ -5.81970215e-02,  -5.81665039e-02],
                        [ -5.77392578e-02,  -5.76782227e-02],
                        [ -5.64880371e-02,  -5.64270020e-02],
                        [ -5.75866699e-02,  -5.75256348e-02],
                        [ -5.95703125e-02,  -5.95092773e-02],
                        [ -5.74951172e-02,  -5.74340820e-02],
                        [ -5.06286621e-02,  -5.05676270e-02],
                        [ -4.20837402e-02,  -4.20227051e-02],
                        [ -3.40881348e-02,  -3.40576172e-02],
                        [ -2.77404785e-02,  -2.76794434e-02],
                        [ -2.29187012e-02,  -2.28881836e-02],
                        [ -1.78527832e-02,  -1.78222656e-02],
                        [ -1.23291016e-02,  -1.22680664e-02],
                        [ -9.03320312e-03,  -8.97216797e-03],
                        [ -7.81250000e-03,  -7.78198242e-03],
                        [ -4.27246094e-03,  -4.21142578e-03],
                        [  3.05175781e-03,   3.14331055e-03],
                        [  1.06506348e-02,   1.07116699e-02],
                        [  1.67846680e-02,   1.68457031e-02],
                        [  2.29492188e-02,   2.30102539e-02],
                        [  2.92663574e-02,   2.93273926e-02],
                        [  3.55224609e-02,   3.55529785e-02],
                        [  4.36096191e-02,   4.36706543e-02],
                        [  5.56945801e-02,   5.57556152e-02],
                        [  7.28454590e-02,   7.28759766e-02],
                        [  9.62829590e-02,   9.63439941e-02],
                        [  1.24053955e-01,   1.24114990e-01],
                        [  1.47155762e-01,   1.47186279e-01],
                        [  1.54357910e-01,   1.54388428e-01],
                        [  1.39129639e-01,   1.39190674e-01],
                        [  1.00616455e-01,   1.00677490e-01],
                        [  4.05883789e-02,   4.06188965e-02],
                        [ -3.74450684e-02,  -3.73840332e-02],
                        [ -1.23016357e-01,  -1.22955322e-01],
                        [ -1.94427490e-01,  -1.94366455e-01],
                        [ -2.30163574e-01,  -2.30102539e-01],
                        [ -2.30865479e-01,  -2.30804443e-01],
                        [ -2.21099854e-01,  -2.21038818e-01],
                        [ -2.23083496e-01,  -2.23052979e-01],
                        [ -2.34863281e-01,  -2.34802246e-01],
                        [ -2.37426758e-01,  -2.37365723e-01],
                        [ -2.18200684e-01,  -2.18139648e-01],
                        [ -1.82952881e-01,  -1.82891846e-01],
                        [ -1.48620605e-01,  -1.48559570e-01],
                        [ -1.28021240e-01,  -1.27960205e-01],
                        [ -1.21246338e-01,  -1.21185303e-01],
                        [ -1.16668701e-01,  -1.16607666e-01],
                        [ -1.01318359e-01,  -1.01287842e-01],
                        [ -7.44628906e-02,  -7.44018555e-02],
                        [ -4.87365723e-02,  -4.86755371e-02],
                        [ -3.43627930e-02,  -3.43322754e-02],
                        [ -2.84729004e-02,  -2.84118652e-02],
                        [ -2.27355957e-02,  -2.26745605e-02],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [  6.43920898e-03,   6.50024414e-03],
                        [  3.87268066e-02,   3.87878418e-02],
                        [  8.21533203e-02,   8.22143555e-02],
                        [  1.23535156e-01,   1.23596191e-01],
                        [  1.47949219e-01,   1.48010254e-01],
                        [  1.51306152e-01,   1.51367188e-01],
                        [  1.42547607e-01,   1.42578125e-01],
                        [  1.36169434e-01,   1.36230469e-01],
                        [  1.43585205e-01,   1.43646240e-01],
                        [  1.66717529e-01,   1.66748047e-01],
                        [  1.95617676e-01,   1.95678711e-01],
                        [  2.14538574e-01,   2.14599609e-01],
                        [  2.14355469e-01,   2.14416504e-01],
                        [  1.97753906e-01,   1.97784424e-01],
                        [  1.72515869e-01,   1.72576904e-01],
                        [  1.44927979e-01,   1.44958496e-01],
                        [  1.18316650e-01,   1.18347168e-01],
                        [  9.36279297e-02,   9.36889648e-02],
                        [  7.13500977e-02,   7.13806152e-02],
                        [  5.43212891e-02,   5.43518066e-02],
                        [  4.64477539e-02,   4.65087891e-02],
                        [  4.75463867e-02,   4.76074219e-02],
                        [  5.19409180e-02,   5.19714355e-02],
                        [  5.25207520e-02,   5.25817871e-02],
                        [  4.55322266e-02,   4.55932617e-02],
                        [  3.21044922e-02,   3.21655273e-02],
                        [  1.70898438e-02,   1.71508789e-02],
                        [  6.31713867e-03,   6.37817383e-03],
                        [  4.15039062e-03,   4.18090820e-03],
                        [  1.06811523e-02,   1.07116699e-02],
                        [  2.05993652e-02,   2.06604004e-02],
                        [  2.67028809e-02,   2.67333984e-02],
                        [  2.53906250e-02,   2.54211426e-02],
                        [  1.85852051e-02,   1.86462402e-02],
                        [  1.10778809e-02,   1.11083984e-02],
                        [  6.59179688e-03,   6.65283203e-03],
                        [  5.00488281e-03,   5.03540039e-03],
                        [  3.81469727e-03,   3.84521484e-03],
                        [  3.99780273e-03,   4.05883789e-03],
                        [  1.02539062e-02,   1.03149414e-02],
                        [  2.22473145e-02,   2.23083496e-02],
                        [  3.03039551e-02,   3.03649902e-02],
                        [  2.60925293e-02,   2.61230469e-02],
                        [  1.35803223e-02,   1.36108398e-02],
                        [  3.47900391e-03,   3.54003906e-03],
                        [  8.54492188e-04,   8.85009766e-04],
                        [  4.48608398e-03,   4.54711914e-03],
                        [  1.22680664e-02,   1.22985840e-02],
                        [  1.93481445e-02,   1.94091797e-02],
                        [  1.76696777e-02,   1.77307129e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -1.60522461e-02,  -1.59912109e-02],
                        [ -3.22570801e-02,  -3.21960449e-02],
                        [ -4.13513184e-02,  -4.13208008e-02],
                        [ -4.59594727e-02,  -4.59289551e-02],
                        [ -4.89501953e-02,  -4.88891602e-02],
                        [ -4.96826172e-02,  -4.96520996e-02],
                        [ -4.70275879e-02,  -4.69970703e-02],
                        [ -4.36401367e-02,  -4.35791016e-02],
                        [ -4.34265137e-02,  -4.33959961e-02],
                        [ -4.69360352e-02,  -4.69055176e-02],
                        [ -5.27648926e-02,  -5.27343750e-02],
                        [ -6.03637695e-02,  -6.03027344e-02],
                        [ -6.77185059e-02,  -6.76574707e-02],
                        [ -6.99462891e-02,  -6.99157715e-02],
                        [ -6.40258789e-02,  -6.39953613e-02],
                        [ -5.29785156e-02,  -5.29479980e-02],
                        [ -4.38842773e-02,  -4.38232422e-02],
                        [ -4.24804688e-02,  -4.24499512e-02],
                        [ -4.94689941e-02,  -4.94384766e-02],
                        [ -5.96313477e-02,  -5.96008301e-02],
                        [ -6.50939941e-02,  -6.50634766e-02],
                        [ -6.21337891e-02,  -6.21032715e-02],
                        [ -5.45043945e-02,  -5.44433594e-02],
                        [ -4.70581055e-02,  -4.70275879e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -2.75573730e-02,  -2.75268555e-02],
                        [ -1.37634277e-02,  -1.37023926e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -3.47900391e-03,  -3.44848633e-03],
                        [ -7.65991211e-03,  -7.62939453e-03],
                        [ -6.40869141e-03,  -6.37817383e-03],
                        [ -1.40380859e-03,  -1.37329102e-03],
                        [  2.19726562e-03,   2.22778320e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.19323730e-02,   1.19934082e-02],
                        [  2.49023438e-02,   2.49328613e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  6.11267090e-02,   6.11572266e-02],
                        [  8.45336914e-02,   8.45642090e-02],
                        [  1.14562988e-01,   1.14593506e-01],
                        [  1.48315430e-01,   1.48345947e-01],
                        [  1.74865723e-01,   1.74896240e-01],
                        [  1.82067871e-01,   1.82098389e-01],
                        [  1.63116455e-01,   1.63146973e-01],
                        [  1.15600586e-01,   1.15661621e-01],
                        [  4.11987305e-02,   4.12292480e-02],
                        [ -5.02929688e-02,  -5.02624512e-02],
                        [ -1.41418457e-01,  -1.41387939e-01],
                        [ -2.14355469e-01,  -2.14324951e-01],
                        [ -2.57995605e-01,  -2.57965088e-01],
                        [ -2.71911621e-01,  -2.71881104e-01],
                        [ -2.66204834e-01,  -2.66174316e-01],
                        [ -2.54852295e-01,  -2.54852295e-01],
                        [ -2.45239258e-01,  -2.45208740e-01],
                        [ -2.32482910e-01,  -2.32421875e-01],
                        [ -2.07000732e-01,  -2.07000732e-01],
                        [ -1.69921875e-01,  -1.69921875e-01],
                        [ -1.35864258e-01,  -1.35833740e-01],
                        [ -1.15173340e-01,  -1.15142822e-01],
                        [ -1.00067139e-01,  -1.00067139e-01],
                        [ -7.87353516e-02,  -7.87048340e-02],
                        [ -5.59387207e-02,  -5.58776855e-02],
                        [ -4.56237793e-02,  -4.55932617e-02],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -5.22155762e-02,  -5.21850586e-02],
                        [ -4.88891602e-02,  -4.88586426e-02],
                        [ -4.20837402e-02,  -4.20532227e-02],
                        [ -3.26843262e-02,  -3.26538086e-02],
                        [ -1.34887695e-02,  -1.34582520e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  5.78308105e-02,   5.78613281e-02],
                        [  9.44824219e-02,   9.45129395e-02],
                        [  1.26861572e-01,   1.26892090e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.67144775e-01,   1.67175293e-01],
                        [  1.70074463e-01,   1.70104980e-01],
                        [  1.71722412e-01,   1.71722412e-01],
                        [  1.80969238e-01,   1.80969238e-01],
                        [  1.94702148e-01,   1.94732666e-01],
                        [  2.02331543e-01,   2.02331543e-01],
                        [  1.97753906e-01,   1.97753906e-01],
                        [  1.83105469e-01,   1.83105469e-01],
                        [  1.62689209e-01,   1.62719727e-01],
                        [  1.39923096e-01,   1.39953613e-01],
                        [  1.18621826e-01,   1.18652344e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  8.32214355e-02,   8.32519531e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.24914551e-02,   2.25219727e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  6.56127930e-03,   6.59179688e-03],
                        [  9.97924805e-03,   1.00097656e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  3.66821289e-02,   3.67126465e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.36511230e-02,   2.36816406e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  8.63647461e-03,   8.66699219e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  2.53295898e-03,   2.56347656e-03],
                        [ -1.34277344e-03,  -1.31225586e-03],
                        [ -2.01416016e-03,  -1.98364258e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  1.64794922e-03,   1.67846680e-03],
                        [ -8.57543945e-03,  -8.54492188e-03],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -1.98974609e-02,  -1.98669434e-02],
                        [ -1.60827637e-02,  -1.60522461e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -4.22973633e-02,  -4.22668457e-02],
                        [ -4.32128906e-02,  -4.31823730e-02],
                        [ -4.59594727e-02,  -4.59899902e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -6.09741211e-02,  -6.09436035e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.05773926e-02,  -6.06079102e-02],
                        [ -6.39953613e-02,  -6.39648438e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.68334961e-02,  -6.68640137e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  1.06811523e-03,   1.03759766e-03],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.15356445e-02,   1.15051270e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  6.19201660e-02,   6.19506836e-02],
                        [  7.44628906e-02,   7.44323730e-02],
                        [  9.81750488e-02,   9.81445312e-02],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.59912109e-01,   1.59912109e-01],
                        [  1.81121826e-01,   1.81121826e-01],
                        [  1.84204102e-01,   1.84204102e-01],
                        [  1.57379150e-01,   1.57379150e-01],
                        [  9.39331055e-02,   9.39025879e-02],
                        [ -2.04467773e-03,  -2.07519531e-03],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -2.26196289e-01,  -2.26196289e-01],
                        [ -3.05664062e-01,  -3.05694580e-01],
                        [ -3.38806152e-01,  -3.38836670e-01],
                        [ -3.29803467e-01,  -3.29803467e-01],
                        [ -2.96722412e-01,  -2.96722412e-01],
                        [ -2.55706787e-01,  -2.55737305e-01],
                        [ -2.13043213e-01,  -2.13043213e-01],
                        [ -1.70379639e-01,  -1.70379639e-01],
                        [ -1.32751465e-01,  -1.32781982e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -9.21630859e-02,  -9.21936035e-02],
                        [ -8.02001953e-02,  -8.02307129e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -3.63464355e-02,  -3.63769531e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  6.26220703e-02,   6.25915527e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  1.70135498e-01,   1.70104980e-01],
                        [  1.83319092e-01,   1.83319092e-01],
                        [  1.90216064e-01,   1.90216064e-01],
                        [  1.99249268e-01,   1.99218750e-01],
                        [  2.09716797e-01,   2.09686279e-01],
                        [  2.13195801e-01,   2.13165283e-01],
                        [  2.04315186e-01,   2.04315186e-01],
                        [  1.87988281e-01,   1.87957764e-01],
                        [  1.72119141e-01,   1.72088623e-01],
                        [  1.57714844e-01,   1.57714844e-01],
                        [  1.41174316e-01,   1.41143799e-01],
                        [  1.22070312e-01,   1.22039795e-01],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  6.14624023e-02,   6.14318848e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  2.79235840e-02,   2.78930664e-02],
                        [  1.48315430e-02,   1.48010254e-02],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -5.52368164e-03,  -5.55419922e-03],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [  4.54711914e-03,   4.51660156e-03],
                        [  1.34887695e-02,   1.34582520e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.07824707e-02,   2.07519531e-02],
                        [  1.30004883e-02,   1.29699707e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  1.11694336e-02,   1.11389160e-02],
                        [  1.84020996e-02,   1.83715820e-02],
                        [  2.35900879e-02,   2.35595703e-02],
                        [  2.60620117e-02,   2.60314941e-02],
                        [  2.92663574e-02,   2.92358398e-02],
                        [  3.35083008e-02,   3.34777832e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  2.20336914e-02,   2.20031738e-02],
                        [  1.06811523e-02,   1.06506348e-02],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [ -1.72119141e-02,  -1.72424316e-02],
                        [ -2.18505859e-02,  -2.18811035e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -5.95092773e-03,  -6.01196289e-03],
                        [ -1.06506348e-02,  -1.06811523e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -2.02636719e-02,  -2.02941895e-02],
                        [ -2.89611816e-02,  -2.89916992e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -5.14526367e-02,  -5.15136719e-02],
                        [ -5.06591797e-02,  -5.06896973e-02],
                        [ -5.02014160e-02,  -5.02319336e-02],
                        [ -4.91027832e-02,  -4.91333008e-02],
                        [ -4.73937988e-02,  -4.74243164e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.31921387e-02,  -5.32226562e-02],
                        [ -5.89599609e-02,  -5.89904785e-02],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -7.17468262e-02,  -7.17773438e-02],
                        [ -7.68127441e-02,  -7.68432617e-02],
                        [ -7.69348145e-02,  -7.69653320e-02],
                        [ -7.21130371e-02,  -7.21435547e-02],
                        [ -6.49719238e-02,  -6.50024414e-02],
                        [ -5.80444336e-02,  -5.80749512e-02],
                        [ -5.22155762e-02,  -5.22460938e-02],
                        [ -4.65698242e-02,  -4.66308594e-02],
                        [ -4.05883789e-02,  -4.06188965e-02],
                        [ -3.53088379e-02,  -3.53393555e-02],
                        [ -3.13720703e-02,  -3.14025879e-02],
                        [ -2.67944336e-02,  -2.68249512e-02],
                        [ -1.99279785e-02,  -1.99890137e-02],
                        [ -1.36108398e-02,  -1.36413574e-02],
                        [ -1.11999512e-02,  -1.12304688e-02],
                        [ -1.04675293e-02,  -1.04980469e-02],
                        [ -6.40869141e-03,  -6.43920898e-03],
                        [  1.46484375e-03,   1.43432617e-03],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  1.59606934e-02,   1.59301758e-02],
                        [  1.90734863e-02,   1.90429688e-02],
                        [  1.99279785e-02,   1.98974609e-02],
                        [  2.29187012e-02,   2.28881836e-02],
                        [  3.20739746e-02,   3.20434570e-02],
                        [  4.61730957e-02,   4.61425781e-02],
                        [  6.37207031e-02,   6.36901855e-02],
                        [  8.91113281e-02,   8.90808105e-02],
                        [  1.26922607e-01,   1.26892090e-01],
                        [  1.70745850e-01,   1.70715332e-01],
                        [  2.04040527e-01,   2.04010010e-01],
                        [  2.11273193e-01,   2.11212158e-01],
                        [  1.83349609e-01,   1.83288574e-01],
                        [  1.15875244e-01,   1.15814209e-01],
                        [  9.91821289e-03,   9.88769531e-03],
                        [ -1.22772217e-01,  -1.22802734e-01],
                        [ -2.56591797e-01,  -2.56622314e-01],
                        [ -3.56445312e-01,  -3.56506348e-01],
                        [ -3.94531250e-01,  -3.94592285e-01],
                        [ -3.70269775e-01,  -3.70300293e-01],
                        [ -3.10424805e-01,  -3.10485840e-01],
                        [ -2.46856689e-01,  -2.46917725e-01],
                        [ -1.97662354e-01,  -1.97692871e-01],
                        [ -1.65557861e-01,  -1.65588379e-01],
                        [ -1.44134521e-01,  -1.44195557e-01],
                        [ -1.24816895e-01,  -1.24847412e-01],
                        [ -1.03973389e-01,  -1.04034424e-01],
                        [ -8.52661133e-02,  -8.53271484e-02],
                        [ -7.25097656e-02,  -7.25708008e-02],
                        [ -6.14929199e-02,  -6.15234375e-02],
                        [ -4.35180664e-02,  -4.35791016e-02],
                        [ -1.95922852e-02,  -1.96533203e-02],
                        [ -3.08227539e-03,  -3.11279297e-03],
                        [ -3.90625000e-03,  -3.96728516e-03],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -3.13110352e-02,  -3.13415527e-02],
                        [ -3.87268066e-02,  -3.87878418e-02],
                        [ -3.71398926e-02,  -3.72009277e-02],
                        [ -2.27661133e-02,  -2.28271484e-02],
                        [  1.05285645e-02,   1.04675293e-02],
                        [  6.32629395e-02,   6.32019043e-02],
                        [  1.25000000e-01,   1.24969482e-01],
                        [  1.81976318e-01,   1.81915283e-01],
                        [  2.25402832e-01,   2.25341797e-01],
                        [  2.50549316e-01,   2.50518799e-01],
                        [  2.56622314e-01,   2.56591797e-01],
                        [  2.49206543e-01,   2.49145508e-01],
                        [  2.35595703e-01,   2.35565186e-01],
                        [  2.18261719e-01,   2.18231201e-01],
                        [  1.97326660e-01,   1.97265625e-01],
                        [  1.75415039e-01,   1.75384521e-01],
                        [  1.56311035e-01,   1.56280518e-01],
                        [  1.40502930e-01,   1.40441895e-01],
                        [  1.24176025e-01,   1.24114990e-01],
                        [  1.03393555e-01,   1.03363037e-01],
                        [  7.89794922e-02,   7.89184570e-02],
                        [  5.48706055e-02,   5.48400879e-02],
                        [  3.34472656e-02,   3.34167480e-02],
                        [  1.58691406e-02,   1.58081055e-02],
                        [  4.18090820e-03,   4.11987305e-03],
                        [ -7.32421875e-04,  -7.93457031e-04],
                        [ -5.49316406e-04,  -5.79833984e-04],
                        [  3.44848633e-03,   3.41796875e-03],
                        [  1.13525391e-02,   1.13220215e-02],
                        [  2.27050781e-02,   2.26440430e-02],
                        [  3.46679688e-02,   3.46069336e-02],
                        [  4.30908203e-02,   4.30603027e-02],
                        [  4.57153320e-02,   4.56542969e-02],
                        [  4.33349609e-02,   4.32739258e-02],
                        [  3.74450684e-02,   3.73840332e-02],
                        [  2.78625488e-02,   2.78015137e-02],
                        [  1.53808594e-02,   1.53198242e-02],
                        [  4.97436523e-03,   4.91333008e-03],
                        [  2.19726562e-03,   2.16674805e-03],
                        [  6.22558594e-03,   6.16455078e-03],
                        [  1.15966797e-02,   1.15356445e-02],
                        [  1.64794922e-02,   1.64184570e-02],
                        [  2.15148926e-02,   2.14843750e-02],
                        [  2.30407715e-02,   2.29797363e-02],
                        [  1.68762207e-02,   1.68151855e-02],
                        [  6.40869141e-03,   6.34765625e-03],
                        [ -1.89208984e-03,  -1.95312500e-03],
                        [ -7.75146484e-03,  -7.81250000e-03],
                        [ -1.37023926e-02,  -1.37634277e-02],
                        [ -1.77917480e-02,  -1.78527832e-02],
                        [ -1.63879395e-02,  -1.64489746e-02],
                        [ -1.21765137e-02,  -1.22680664e-02],
                        [ -1.33666992e-02,  -1.33972168e-02],
                        [ -2.31628418e-02,  -2.32238770e-02],
                        [ -3.47900391e-02,  -3.48510742e-02],
                        [ -3.95202637e-02,  -3.95812988e-02],
                        [ -3.80249023e-02,  -3.80554199e-02],
                        [ -3.79638672e-02,  -3.80249023e-02],
                        [ -4.26025391e-02,  -4.26635742e-02],
                        [ -4.74548340e-02,  -4.75158691e-02],
                        [ -4.95300293e-02,  -4.95910645e-02],
                        [ -5.23376465e-02,  -5.23986816e-02],
                        [ -5.92346191e-02,  -5.92956543e-02],
                        [ -6.75354004e-02,  -6.75659180e-02],
                        [ -7.22045898e-02,  -7.22656250e-02],
                        [ -7.15637207e-02,  -7.16247559e-02],
                        [ -6.65893555e-02,  -6.66503906e-02],
                        [ -5.92956543e-02,  -5.93566895e-02],
                        [ -5.29174805e-02,  -5.29785156e-02],
                        [ -5.00793457e-02,  -5.01403809e-02],
                        [ -4.89196777e-02,  -4.89807129e-02],
                        [ -4.47998047e-02,  -4.48608398e-02],
                        [ -3.77197266e-02,  -3.77807617e-02],
                        [ -3.30200195e-02,  -3.30505371e-02],
                        [ -3.28369141e-02,  -3.28979492e-02],
                        [ -3.33862305e-02,  -3.34472656e-02],
                        [ -3.18298340e-02,  -3.18603516e-02],
                        [ -2.90832520e-02,  -2.91442871e-02],
                        [ -2.67028809e-02,  -2.67639160e-02],
                        [ -2.51770020e-02,  -2.52075195e-02],
                        [ -2.36511230e-02,  -2.37121582e-02],
                        [ -2.06604004e-02,  -2.07214355e-02],
                        [ -1.73645020e-02,  -1.73950195e-02],
                        [ -1.50451660e-02,  -1.51062012e-02],
                        [ -8.30078125e-03,  -8.39233398e-03],
                        [  8.39233398e-03,   8.36181641e-03],
                        [  2.95104980e-02,   2.94799805e-02],
                        [  4.52575684e-02,   4.51965332e-02],
                        [  5.48400879e-02,   5.47790527e-02],
                        [  6.27136230e-02,   6.26831055e-02],
                        [  7.08923340e-02,   7.08618164e-02],
                        [  8.18481445e-02,   8.17565918e-02],
                        [  1.00433350e-01,   1.00372314e-01],
                        [  1.29028320e-01,   1.28967285e-01],
                        [  1.63543701e-01,   1.63452148e-01],
                        [  1.93298340e-01,   1.93206787e-01],
                        [  2.02362061e-01,   2.02331543e-01],
                        [  1.74652100e-01,   1.74591064e-01],
                        [  1.00280762e-01,   1.00189209e-01],
                        [ -2.01110840e-02,  -2.01416016e-02],
                        [ -1.69433594e-01,  -1.69464111e-01],
                        [ -3.10668945e-01,  -3.10729980e-01],
                        [ -3.99475098e-01,  -3.99536133e-01],
                        [ -4.11895752e-01,  -4.11956787e-01],
                        [ -3.59680176e-01,  -3.59710693e-01],
                        [ -2.78625488e-01,  -2.78717041e-01],
                        [ -2.06115723e-01,  -2.06176758e-01],
                        [ -1.62780762e-01,  -1.62811279e-01],
                        [ -1.43432617e-01,  -1.43493652e-01],
                        [ -1.26464844e-01,  -1.26525879e-01],
                        [ -9.88159180e-02,  -9.88464355e-02],
                        [ -6.79626465e-02,  -6.80236816e-02],
                        [ -4.76989746e-02,  -4.77905273e-02],
                        [ -4.00390625e-02,  -4.00695801e-02],
                        [ -3.47290039e-02,  -3.47595215e-02],
                        [ -2.26440430e-02,  -2.27355957e-02],
                        [ -6.62231445e-03,  -6.68334961e-03],
                        [  2.07519531e-03,   2.01416016e-03],
                        [ -3.20434570e-03,  -3.26538086e-03],
                        [ -1.95922852e-02,  -1.96838379e-02],
                        [ -4.05578613e-02,  -4.06188965e-02],
                        [ -5.85327148e-02,  -5.85632324e-02],
                        [ -6.47277832e-02,  -6.47888184e-02],
                        [ -5.26428223e-02,  -5.26733398e-02],
                        [ -2.05993652e-02,  -2.06604004e-02],
                        [  3.03955078e-02,   3.03344727e-02],
                        [  9.79003906e-02,   9.78393555e-02],
                        [  1.74011230e-01,   1.73950195e-01],
                        [  2.41271973e-01,   2.41241455e-01],
                        [  2.79632568e-01,   2.79602051e-01],
                        [  2.83630371e-01,   2.83569336e-01],
                        [  2.67120361e-01,   2.67059326e-01],
                        [  2.45666504e-01,   2.45605469e-01],
                        [  2.22564697e-01,   2.22503662e-01],
                        [  1.97143555e-01,   1.97113037e-01],
                        [  1.73583984e-01,   1.73553467e-01],
                        [  1.54144287e-01,   1.54083252e-01],
                        [  1.34185791e-01,   1.34124756e-01],
                        [  1.10870361e-01,   1.10839844e-01],
                        [  8.81652832e-02,   8.81042480e-02],
                        [  6.92749023e-02,   6.92138672e-02],
                        [  5.28869629e-02,   5.28259277e-02],
                        [  3.87878418e-02,   3.87268066e-02],
                        [  2.81982422e-02,   2.81372070e-02],
                        [  1.82800293e-02,   1.82495117e-02],
                        [  6.46972656e-03,   6.40869141e-03],
                        [ -1.92260742e-03,  -1.95312500e-03],
                        [  9.15527344e-04,   8.54492188e-04],
                        [  1.41601562e-02,   1.40991211e-02],
                        [  2.94494629e-02,   2.93884277e-02],
                        [  3.92761230e-02,   3.92456055e-02],
                        [  4.09240723e-02,   4.08630371e-02],
                        [  3.49426270e-02,   3.49121094e-02],
                        [  2.38647461e-02,   2.38037109e-02],
                        [  1.17187500e-02,   1.16577148e-02],
                        [  3.14331055e-03,   3.08227539e-03],
                        [  5.79833984e-04,   5.18798828e-04],
                        [  2.92968750e-03,   2.86865234e-03],
                        [  7.53784180e-03,   7.47680664e-03],
                        [  1.29089355e-02,   1.28479004e-02],
                        [  1.89208984e-02,   1.88903809e-02],
                        [  2.38952637e-02,   2.38342285e-02],
                        [  2.27050781e-02,   2.26745605e-02],
                        [  1.21765137e-02,   1.21459961e-02],
                        [ -2.92968750e-03,  -2.99072266e-03],
                        [ -1.45568848e-02,  -1.45874023e-02],
                        [ -2.01721191e-02,  -2.02026367e-02],
                        [ -2.16064453e-02,  -2.16369629e-02],
                        [ -1.87072754e-02,  -1.87683105e-02],
                        [ -1.11083984e-02,  -1.11389160e-02],
                        [ -2.77709961e-03,  -2.83813477e-03],
                        [ -3.66210938e-04,  -4.27246094e-04],
                        [ -7.01904297e-03,  -7.08007812e-03],
                        [ -1.97448730e-02,  -1.98059082e-02],
                        [ -3.26843262e-02,  -3.27453613e-02],
                        [ -4.24499512e-02,  -4.24804688e-02],
                        [ -4.92248535e-02,  -4.92553711e-02],
                        [ -5.33142090e-02,  -5.33752441e-02],
                        [ -5.38940430e-02,  -5.39245605e-02],
                        [ -5.20019531e-02,  -5.20629883e-02],
                        [ -5.21850586e-02,  -5.22155762e-02],
                        [ -5.77697754e-02,  -5.78308105e-02],
                        [ -6.61926270e-02,  -6.62231445e-02],
                        [ -7.18994141e-02,  -7.19299316e-02],
                        [ -7.36999512e-02,  -7.37304688e-02],
                        [ -7.47070312e-02,  -7.47375488e-02],
                        [ -7.58056641e-02,  -7.58666992e-02],
                        [ -7.38220215e-02,  -7.38525391e-02],
                        [ -6.61315918e-02,  -6.61621094e-02],
                        [ -5.49621582e-02,  -5.49926758e-02],
                        [ -4.57458496e-02,  -4.57763672e-02],
                        [ -4.19616699e-02,  -4.19921875e-02],
                        [ -4.13818359e-02,  -4.14123535e-02],
                        [ -3.89709473e-02,  -3.90014648e-02],
                        [ -3.27148438e-02,  -3.27453613e-02],
                        [ -2.63671875e-02,  -2.63977051e-02],
                        [ -2.54211426e-02,  -2.54516602e-02],
                        [ -2.99072266e-02,  -2.99377441e-02],
                        [ -3.31420898e-02,  -3.31726074e-02],
                        [ -3.01208496e-02,  -3.01513672e-02],
                        [ -2.35900879e-02,  -2.36206055e-02],
                        [ -1.84936523e-02,  -1.85546875e-02],
                        [ -1.42517090e-02,  -1.42822266e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  4.39453125e-03,   4.36401367e-03],
                        [  1.49536133e-02,   1.49230957e-02],
                        [  2.31628418e-02,   2.31323242e-02],
                        [  3.25927734e-02,   3.25317383e-02],
                        [  4.45861816e-02,   4.45556641e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  6.48803711e-02,   6.48498535e-02],
                        [  8.16650391e-02,   8.16345215e-02],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  1.42883301e-01,   1.42852783e-01],
                        [  1.70013428e-01,   1.69982910e-01],
                        [  1.81518555e-01,   1.81488037e-01],
                        [  1.65679932e-01,   1.65649414e-01],
                        [  1.11846924e-01,   1.11816406e-01],
                        [  1.77917480e-02,   1.77612305e-02],
                        [ -1.08367920e-01,  -1.08398438e-01],
                        [ -2.46582031e-01,  -2.46582031e-01],
                        [ -3.60290527e-01,  -3.60290527e-01],
                        [ -4.08081055e-01,  -4.08111572e-01],
                        [ -3.76190186e-01,  -3.76220703e-01],
                        [ -2.95837402e-01,  -2.95837402e-01],
                        [ -2.18292236e-01,  -2.18322754e-01],
                        [ -1.73675537e-01,  -1.73675537e-01],
                        [ -1.56280518e-01,  -1.56280518e-01],
                        [ -1.43646240e-01,  -1.43646240e-01],
                        [ -1.22802734e-01,  -1.22802734e-01],
                        [ -9.82055664e-02,  -9.82055664e-02],
                        [ -7.86743164e-02,  -7.87048340e-02],
                        [ -6.42089844e-02,  -6.42395020e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.60107422e-03,  -3.63159180e-03],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  2.96020508e-03,   2.96020508e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -2.97851562e-02,  -2.98156738e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -3.86352539e-02,  -3.86657715e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  1.70898438e-01,   1.70867920e-01],
                        [  2.34924316e-01,   2.34924316e-01],
                        [  2.74200439e-01,   2.74230957e-01],
                        [  2.80487061e-01,   2.80456543e-01],
                        [  2.62725830e-01,   2.62695312e-01],
                        [  2.35870361e-01,   2.35870361e-01],
                        [  2.08892822e-01,   2.08892822e-01],
                        [  1.84112549e-01,   1.84112549e-01],
                        [  1.61926270e-01,   1.61956787e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  1.31500244e-01,   1.31500244e-01],
                        [  1.21856689e-01,   1.21856689e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  2.20947266e-02,   2.21252441e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -6.89697266e-03,  -6.86645508e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.94702148e-02,   1.95007324e-02],
                        [  3.00292969e-02,   3.00598145e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  3.54919434e-02,   3.55224609e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  1.52282715e-02,   1.52587891e-02],
                        [  4.69970703e-03,   4.69970703e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.73950195e-03,  -1.70898438e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -2.83813477e-03,  -2.80761719e-03],
                        [ -7.93457031e-04,  -7.62939453e-04],
                        [ -4.57763672e-04,  -4.27246094e-04],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.52587891e-04,  -1.22070312e-04],
                        [  1.25122070e-03,   1.28173828e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -4.54711914e-03,  -4.51660156e-03],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -4.16870117e-02,  -4.16564941e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -3.99169922e-02,  -3.98864746e-02],
                        [ -3.91845703e-02,  -3.91540527e-02],
                        [ -4.09545898e-02,  -4.09240723e-02],
                        [ -4.68139648e-02,  -4.67834473e-02],
                        [ -5.68847656e-02,  -5.68542480e-02],
                        [ -6.54602051e-02,  -6.54296875e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -5.88378906e-02,  -5.88073730e-02],
                        [ -5.30090332e-02,  -5.29785156e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.28564453e-02,  -5.28259277e-02],
                        [ -5.51452637e-02,  -5.50842285e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -5.53283691e-02,  -5.52673340e-02],
                        [ -6.20422363e-02,  -6.20117188e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -5.88073730e-02,  -5.87768555e-02],
                        [ -4.54711914e-02,  -4.54101562e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -2.70690918e-02,  -2.70385742e-02],
                        [ -2.21252441e-02,  -2.20642090e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -8.05664062e-03,  -8.02612305e-03],
                        [  3.05175781e-04,   3.35693359e-04],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  1.89208984e-02,   1.89819336e-02],
                        [  2.67639160e-02,   2.68249512e-02],
                        [  2.99072266e-02,   2.99377441e-02],
                        [  3.06091309e-02,   3.06396484e-02],
                        [  3.60412598e-02,   3.61022949e-02],
                        [  5.05981445e-02,   5.06286621e-02],
                        [  7.11364746e-02,   7.11669922e-02],
                        [  9.18273926e-02,   9.18579102e-02],
                        [  1.11938477e-01,   1.11968994e-01],
                        [  1.35833740e-01,   1.35864258e-01],
                        [  1.63848877e-01,   1.63879395e-01],
                        [  1.85333252e-01,   1.85363770e-01],
                        [  1.83959961e-01,   1.83990479e-01],
                        [  1.48406982e-01,   1.48437500e-01],
                        [  7.42187500e-02,   7.42492676e-02],
                        [ -3.75061035e-02,  -3.74755859e-02],
                        [ -1.72912598e-01,  -1.72882080e-01],
                        [ -2.99804688e-01,  -2.99774170e-01],
                        [ -3.79547119e-01,  -3.79516602e-01],
                        [ -3.90777588e-01,  -3.90747070e-01],
                        [ -3.43261719e-01,  -3.43200684e-01],
                        [ -2.70507812e-01,  -2.70477295e-01],
                        [ -2.07366943e-01,  -2.07336426e-01],
                        [ -1.69219971e-01,  -1.69189453e-01],
                        [ -1.48742676e-01,  -1.48712158e-01],
                        [ -1.30554199e-01,  -1.30493164e-01],
                        [ -1.09039307e-01,  -1.09008789e-01],
                        [ -9.05456543e-02,  -9.04846191e-02],
                        [ -7.85522461e-02,  -7.84912109e-02],
                        [ -6.53991699e-02,  -6.53686523e-02],
                        [ -4.34875488e-02,  -4.34265137e-02],
                        [ -1.66931152e-02,  -1.66320801e-02],
                        [  5.24902344e-03,   5.27954102e-03],
                        [  1.73339844e-02,   1.73645020e-02],
                        [  1.88598633e-02,   1.89208984e-02],
                        [  1.08947754e-02,   1.09252930e-02],
                        [ -2.53295898e-03,  -2.50244141e-03],
                        [ -1.70898438e-02,  -1.70288086e-02],
                        [ -3.20739746e-02,  -3.20129395e-02],
                        [ -4.53186035e-02,  -4.52880859e-02],
                        [ -4.76684570e-02,  -4.76074219e-02],
                        [ -2.69775391e-02,  -2.69165039e-02],
                        [  2.33459473e-02,   2.33764648e-02],
                        [  9.88464355e-02,   9.88769531e-02],
                        [  1.83166504e-01,   1.83227539e-01],
                        [  2.53906250e-01,   2.53936768e-01],
                        [  2.92907715e-01,   2.92938232e-01],
                        [  2.93945312e-01,   2.94006348e-01],
                        [  2.66387939e-01,   2.66448975e-01],
                        [  2.31170654e-01,   2.31201172e-01],
                        [  2.04711914e-01,   2.04772949e-01],
                        [  1.86767578e-01,   1.86828613e-01],
                        [  1.69403076e-01,   1.69433594e-01],
                        [  1.51611328e-01,   1.51672363e-01],
                        [  1.36657715e-01,   1.36718750e-01],
                        [  1.22314453e-01,   1.22344971e-01],
                        [  1.03607178e-01,   1.03637695e-01],
                        [  7.98339844e-02,   7.98950195e-02],
                        [  5.34057617e-02,   5.34667969e-02],
                        [  2.74047852e-02,   2.74658203e-02],
                        [  7.56835938e-03,   7.62939453e-03],
                        [ -5.79833984e-04,  -5.18798828e-04],
                        [  1.00708008e-03,   1.06811523e-03],
                        [  4.39453125e-03,   4.42504883e-03],
                        [  5.98144531e-03,   6.04248047e-03],
                        [  1.06506348e-02,   1.07116699e-02],
                        [  2.27355957e-02,   2.27966309e-02],
                        [  3.77502441e-02,   3.78112793e-02],
                        [  4.68444824e-02,   4.69055176e-02],
                        [  4.57763672e-02,   4.58374023e-02],
                        [  3.61633301e-02,   3.61938477e-02],
                        [  2.26135254e-02,   2.26745605e-02],
                        [  1.03149414e-02,   1.03759766e-02],
                        [  2.50244141e-03,   2.56347656e-03],
                        [ -4.57763672e-04,  -3.96728516e-04],
                        [  6.40869141e-04,   7.01904297e-04],
                        [  4.11987305e-03,   4.15039062e-03],
                        [  6.89697266e-03,   6.92749023e-03],
                        [  6.28662109e-03,   6.31713867e-03],
                        [  2.96020508e-03,   3.02124023e-03],
                        [  7.32421875e-04,   7.93457031e-04],
                        [  1.40380859e-03,   1.46484375e-03],
                        [  5.49316406e-04,   6.10351562e-04],
                        [ -6.56127930e-03,  -6.50024414e-03],
                        [ -1.67541504e-02,  -1.67236328e-02],
                        [ -2.27966309e-02,  -2.27661133e-02],
                        [ -2.21557617e-02,  -2.20947266e-02],
                        [ -1.73645020e-02,  -1.73034668e-02],
                        [ -1.24206543e-02,  -1.23596191e-02],
                        [ -1.23901367e-02,  -1.23291016e-02],
                        [ -2.02636719e-02,  -2.02026367e-02],
                        [ -3.09753418e-02,  -3.09143066e-02],
                        [ -3.61022949e-02,  -3.60717773e-02],
                        [ -3.61022949e-02,  -3.60412598e-02],
                        [ -3.92761230e-02,  -3.92150879e-02],
                        [ -4.92858887e-02,  -4.92553711e-02],
                        [ -6.22253418e-02,  -6.21948242e-02],
                        [ -7.39746094e-02,  -7.39135742e-02],
                        [ -8.16650391e-02,  -8.16345215e-02],
                        [ -8.23364258e-02,  -8.23059082e-02],
                        [ -7.72705078e-02,  -7.72094727e-02],
                        [ -7.22961426e-02,  -7.22351074e-02],
                        [ -6.93969727e-02,  -6.93664551e-02],
                        [ -6.43615723e-02,  -6.43310547e-02],
                        [ -5.50537109e-02,  -5.49621582e-02],
                        [ -4.63256836e-02,  -4.62646484e-02],
                        [ -4.50744629e-02,  -4.50439453e-02],
                        [ -5.22460938e-02,  -5.21850586e-02],
                        [ -6.12792969e-02,  -6.12182617e-02],
                        [ -6.51855469e-02,  -6.51550293e-02],
                        [ -6.25915527e-02,  -6.25305176e-02],
                        [ -5.47180176e-02,  -5.46569824e-02],
                        [ -4.21447754e-02,  -4.20837402e-02],
                        [ -2.78930664e-02,  -2.78320312e-02],
                        [ -1.78833008e-02,  -1.78527832e-02],
                        [ -1.36413574e-02,  -1.35803223e-02],
                        [ -1.15356445e-02,  -1.14746094e-02],
                        [ -9.79614258e-03,  -9.76562500e-03],
                        [ -8.08715820e-03,  -8.02612305e-03],
                        [ -3.17382812e-03,  -3.11279297e-03],
                        [  7.04956055e-03,   7.11059570e-03],
                        [  1.92871094e-02,   1.93176270e-02],
                        [  2.90527344e-02,   2.91137695e-02],
                        [  3.61022949e-02,   3.61633301e-02],
                        [  4.39758301e-02,   4.40063477e-02],
                        [  5.61828613e-02,   5.62438965e-02],
                        [  7.31811523e-02,   7.32421875e-02],
                        [  9.31091309e-02,   9.31396484e-02],
                        [  1.15325928e-01,   1.15356445e-01],
                        [  1.41021729e-01,   1.41082764e-01],
                        [  1.68518066e-01,   1.68579102e-01],
                        [  1.88507080e-01,   1.88537598e-01],
                        [  1.85363770e-01,   1.85424805e-01],
                        [  1.45660400e-01,   1.45721436e-01],
                        [  6.47277832e-02,   6.47583008e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -1.86920166e-01,  -1.86859131e-01],
                        [ -3.09173584e-01,  -3.09112549e-01],
                        [ -3.83453369e-01,  -3.83422852e-01],
                        [ -3.90960693e-01,  -3.90899658e-01],
                        [ -3.42102051e-01,  -3.42041016e-01],
                        [ -2.69653320e-01,  -2.69622803e-01],
                        [ -2.06573486e-01,  -2.06512451e-01],
                        [ -1.66076660e-01,  -1.66015625e-01],
                        [ -1.40228271e-01,  -1.40197754e-01],
                        [ -1.15447998e-01,  -1.15417480e-01],
                        [ -8.78295898e-02,  -8.77685547e-02],
                        [ -6.37207031e-02,  -6.36901855e-02],
                        [ -4.82482910e-02,  -4.82177734e-02],
                        [ -3.66516113e-02,  -3.66210938e-02],
                        [ -2.09045410e-02,  -2.08740234e-02],
                        [ -2.77709961e-03,  -2.71606445e-03],
                        [  6.92749023e-03,   6.95800781e-03],
                        [  3.47900391e-03,   3.54003906e-03],
                        [ -6.01196289e-03,  -5.95092773e-03],
                        [ -1.54724121e-02,  -1.54418945e-02],
                        [ -2.74963379e-02,  -2.74353027e-02],
                        [ -4.40673828e-02,  -4.40368652e-02],
                        [ -5.95092773e-02,  -5.94787598e-02],
                        [ -6.51550293e-02,  -6.51245117e-02],
                        [ -5.52673340e-02,  -5.52368164e-02],
                        [ -2.71911621e-02,  -2.71301270e-02],
                        [  2.05993652e-02,   2.06604004e-02],
                        [  8.88061523e-02,   8.88671875e-02],
                        [  1.72576904e-01,   1.72637939e-01],
                        [  2.55279541e-01,   2.55310059e-01],
                        [  3.12469482e-01,   3.12530518e-01],
                        [  3.27850342e-01,   3.27880859e-01],
                        [  3.05053711e-01,   3.05084229e-01],
                        [  2.62969971e-01,   2.63031006e-01],
                        [  2.20123291e-01,   2.20184326e-01],
                        [  1.84143066e-01,   1.84173584e-01],
                        [  1.53717041e-01,   1.53778076e-01],
                        [  1.27532959e-01,   1.27563477e-01],
                        [  1.08764648e-01,   1.08795166e-01],
                        [  1.00433350e-01,   1.00463867e-01],
                        [  9.84191895e-02,   9.84802246e-02],
                        [  9.30175781e-02,   9.30480957e-02],
                        [  7.76062012e-02,   7.76367188e-02],
                        [  5.47180176e-02,   5.47790527e-02],
                        [  3.31726074e-02,   3.32031250e-02],
                        [  1.94396973e-02,   1.94702148e-02],
                        [  1.32446289e-02,   1.32751465e-02],
                        [  1.12304688e-02,   1.12609863e-02],
                        [  1.22680664e-02,   1.22985840e-02],
                        [  1.70288086e-02,   1.70898438e-02],
                        [  2.44445801e-02,   2.44750977e-02],
                        [  3.07617188e-02,   3.07922363e-02],
                        [  3.20434570e-02,   3.20739746e-02],
                        [  2.70080566e-02,   2.70690918e-02],
                        [  1.83410645e-02,   1.83715820e-02],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  1.45568848e-02,   1.46179199e-02],
                        [  2.23388672e-02,   2.23693848e-02],
                        [  2.62145996e-02,   2.62451172e-02],
                        [  2.18811035e-02,   2.19421387e-02],
                        [  1.54418945e-02,   1.55029297e-02],
                        [  1.34887695e-02,   1.35192871e-02],
                        [  1.38549805e-02,   1.38854980e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  3.96728516e-03,   3.99780273e-03],
                        [ -1.55639648e-03,  -1.52587891e-03],
                        [ -5.09643555e-03,  -5.06591797e-03],
                        [ -9.58251953e-03,  -9.55200195e-03],
                        [ -1.48010254e-02,  -1.47705078e-02],
                        [ -1.88598633e-02,  -1.88293457e-02],
                        [ -2.35290527e-02,  -2.34985352e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.37524414e-02,  -3.37219238e-02],
                        [ -3.18908691e-02,  -3.18603516e-02],
                        [ -2.94799805e-02,  -2.94494629e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.92456055e-02,  -3.92150879e-02],
                        [ -4.55627441e-02,  -4.55322266e-02],
                        [ -4.95300293e-02,  -4.94995117e-02],
                        [ -5.21850586e-02,  -5.21545410e-02],
                        [ -5.56030273e-02,  -5.55725098e-02],
                        [ -6.12487793e-02,  -6.12182617e-02],
                        [ -6.70166016e-02,  -6.69860840e-02],
                        [ -6.91223145e-02,  -6.90917969e-02],
                        [ -6.82067871e-02,  -6.81762695e-02],
                        [ -6.78405762e-02,  -6.78100586e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -6.50024414e-02,  -6.49719238e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.89294434e-02,  -5.88989258e-02],
                        [ -5.71289062e-02,  -5.70983887e-02],
                        [ -5.27648926e-02,  -5.27343750e-02],
                        [ -4.70581055e-02,  -4.70275879e-02],
                        [ -4.32128906e-02,  -4.31823730e-02],
                        [ -4.02832031e-02,  -4.02526855e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.03955078e-02,  -3.03649902e-02],
                        [ -3.04260254e-02,  -3.03955078e-02],
                        [ -3.50952148e-02,  -3.50646973e-02],
                        [ -3.71704102e-02,  -3.71398926e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  6.28662109e-03,   6.31713867e-03],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  3.17687988e-02,   3.17993164e-02],
                        [  4.32434082e-02,   4.32739258e-02],
                        [  5.29479980e-02,   5.29785156e-02],
                        [  6.19812012e-02,   6.20117188e-02],
                        [  7.43713379e-02,   7.44018555e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.23046875e-01,   1.23046875e-01],
                        [  1.54266357e-01,   1.54296875e-01],
                        [  1.74163818e-01,   1.74163818e-01],
                        [  1.69769287e-01,   1.69769287e-01],
                        [  1.35437012e-01,   1.35467529e-01],
                        [  7.25708008e-02,   7.26013184e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.08642578e-01,  -1.08642578e-01],
                        [ -2.06756592e-01,  -2.06756592e-01],
                        [ -2.92266846e-01,  -2.92266846e-01],
                        [ -3.46893311e-01,  -3.46893311e-01],
                        [ -3.57055664e-01,  -3.57025146e-01],
                        [ -3.24279785e-01,  -3.24279785e-01],
                        [ -2.65655518e-01,  -2.65655518e-01],
                        [ -2.04010010e-01,  -2.03979492e-01],
                        [ -1.55548096e-01,  -1.55517578e-01],
                        [ -1.21765137e-01,  -1.21734619e-01],
                        [ -9.39636230e-02,  -9.39331055e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -5.09948730e-02,  -5.09643555e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.86047363e-02,  -3.85742188e-02],
                        [ -2.67333984e-02,  -2.67028809e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  1.83410645e-01,   1.83410645e-01],
                        [  2.53204346e-01,   2.53204346e-01],
                        [  2.94982910e-01,   2.94982910e-01],
                        [  3.00567627e-01,   3.00567627e-01],
                        [  2.77130127e-01,   2.77130127e-01],
                        [  2.40844727e-01,   2.40844727e-01],
                        [  2.04986572e-01,   2.05017090e-01],
                        [  1.74682617e-01,   1.74682617e-01],
                        [  1.49017334e-01,   1.49017334e-01],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  7.74841309e-02,   7.74841309e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.72729492e-02,   1.72424316e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -2.56347656e-03,  -2.59399414e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -1.44653320e-02,  -1.44958496e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -3.67431641e-02,  -3.67736816e-02],
                        [ -3.93066406e-02,  -3.93371582e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.00695801e-02,  -4.01000977e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.24597168e-02,  -5.24902344e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -5.88073730e-02,  -5.88378906e-02],
                        [ -5.57250977e-02,  -5.57556152e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -4.15344238e-02,  -4.15649414e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.06701660e-02,  -3.07006836e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.72729492e-02,  -1.73034668e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.32751465e-02,  -1.33056641e-02],
                        [ -3.69262695e-03,  -3.72314453e-03],
                        [  1.13220215e-02,   1.12915039e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  5.15747070e-02,   5.15441895e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  1.09741211e-01,   1.09741211e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.51641846e-01,   1.51611328e-01],
                        [  1.61437988e-01,   1.61437988e-01],
                        [  1.54083252e-01,   1.54083252e-01],
                        [  1.25457764e-01,   1.25457764e-01],
                        [  7.72094727e-02,   7.71789551e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -2.36999512e-01,  -2.37030029e-01],
                        [ -3.11859131e-01,  -3.11859131e-01],
                        [ -3.55926514e-01,  -3.55926514e-01],
                        [ -3.53454590e-01,  -3.53454590e-01],
                        [ -3.06823730e-01,  -3.06854248e-01],
                        [ -2.38769531e-01,  -2.38800049e-01],
                        [ -1.78039551e-01,  -1.78039551e-01],
                        [ -1.39831543e-01,  -1.39831543e-01],
                        [ -1.16638184e-01,  -1.16638184e-01],
                        [ -9.14916992e-02,  -9.15222168e-02],
                        [ -6.17980957e-02,  -6.18286133e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -3.47900391e-02,  -3.48205566e-02],
                        [ -3.14636230e-02,  -3.14941406e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -6.12487793e-02,  -6.12792969e-02],
                        [ -6.45446777e-02,  -6.45751953e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  1.12579346e-01,   1.12579346e-01],
                        [  1.91833496e-01,   1.91833496e-01],
                        [  2.60040283e-01,   2.60040283e-01],
                        [  3.00994873e-01,   3.00994873e-01],
                        [  3.09539795e-01,   3.09539795e-01],
                        [  2.90435791e-01,   2.90435791e-01],
                        [  2.53479004e-01,   2.53448486e-01],
                        [  2.10601807e-01,   2.10601807e-01],
                        [  1.72027588e-01,   1.72027588e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  1.72729492e-02,   1.72424316e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  3.13110352e-02,   3.12805176e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  3.71093750e-02,   3.70788574e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  6.04248047e-03,   6.01196289e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -7.99560547e-03,  -8.02612305e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -3.38745117e-03,  -3.41796875e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -8.27026367e-03,  -8.30078125e-03],
                        [ -1.26037598e-02,  -1.26342773e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -2.80761719e-02,  -2.81066895e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -4.97131348e-02,  -4.97436523e-02],
                        [ -5.94177246e-02,  -5.94482422e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -6.95190430e-02,  -6.95190430e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.97937012e-02,  -6.98242188e-02],
                        [ -6.93359375e-02,  -6.93664551e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -3.86962891e-02,  -3.87268066e-02],
                        [ -4.07714844e-02,  -4.08020020e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.25415039e-02,  -4.25720215e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  4.16259766e-02,   4.15954590e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  1.01898193e-01,   1.01898193e-01],
                        [  1.23260498e-01,   1.23229980e-01],
                        [  1.40655518e-01,   1.40655518e-01],
                        [  1.49963379e-01,   1.49963379e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  9.09729004e-02,   9.09423828e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -8.77685547e-02,  -8.77685547e-02],
                        [ -1.58508301e-01,  -1.58508301e-01],
                        [ -2.30468750e-01,  -2.30468750e-01],
                        [ -2.96936035e-01,  -2.96966553e-01],
                        [ -3.40606689e-01,  -3.40606689e-01],
                        [ -3.40209961e-01,  -3.40209961e-01],
                        [ -2.91442871e-01,  -2.91442871e-01],
                        [ -2.18780518e-01,  -2.18780518e-01],
                        [ -1.57958984e-01,  -1.57958984e-01],
                        [ -1.24114990e-01,  -1.24114990e-01],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  4.69970703e-03,   4.69970703e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  4.28161621e-02,   4.28161621e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  2.18750000e-01,   2.18750000e-01],
                        [  2.68676758e-01,   2.68676758e-01],
                        [  2.94860840e-01,   2.94860840e-01],
                        [  2.90802002e-01,   2.90771484e-01],
                        [  2.60070801e-01,   2.60070801e-01],
                        [  2.19024658e-01,   2.19024658e-01],
                        [  1.85791016e-01,   1.85791016e-01],
                        [  1.65466309e-01,   1.65466309e-01],
                        [  1.51000977e-01,   1.51000977e-01],
                        [  1.34735107e-01,   1.34735107e-01],
                        [  1.15509033e-01,   1.15509033e-01],
                        [  9.67102051e-02,   9.67102051e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.22375488e-02,  -1.22680664e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -7.48901367e-02,  -7.48901367e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -7.83996582e-02,  -7.83996582e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  1.06292725e-01,   1.06292725e-01],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -8.38623047e-02,  -8.38623047e-02],
                        [ -1.15875244e-01,  -1.15875244e-01],
                        [ -1.73553467e-01,  -1.73553467e-01],
                        [ -2.50549316e-01,  -2.50549316e-01],
                        [ -3.10028076e-01,  -3.10028076e-01],
                        [ -3.16314697e-01,  -3.16314697e-01],
                        [ -2.69012451e-01,  -2.69012451e-01],
                        [ -2.00744629e-01,  -2.00744629e-01],
                        [ -1.47949219e-01,  -1.47949219e-01],
                        [ -1.23809814e-01,  -1.23809814e-01],
                        [ -1.13098145e-01,  -1.13098145e-01],
                        [ -9.37194824e-02,  -9.37194824e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.01928711e-02,   1.01928711e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  1.54235840e-01,   1.54235840e-01],
                        [  2.02270508e-01,   2.02270508e-01],
                        [  2.44964600e-01,   2.44964600e-01],
                        [  2.76245117e-01,   2.76245117e-01],
                        [  2.84637451e-01,   2.84637451e-01],
                        [  2.64770508e-01,   2.64770508e-01],
                        [  2.28088379e-01,   2.28088379e-01],
                        [  1.91680908e-01,   1.91680908e-01],
                        [  1.61956787e-01,   1.61956787e-01],
                        [  1.37512207e-01,   1.37512207e-01],
                        [  1.18011475e-01,   1.18011475e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -1.04705811e-01,  -1.04705811e-01],
                        [ -1.85363770e-01,  -1.85363770e-01],
                        [ -2.71942139e-01,  -2.71942139e-01],
                        [ -3.24890137e-01,  -3.24890137e-01],
                        [ -3.17993164e-01,  -3.17993164e-01],
                        [ -2.60772705e-01,  -2.60772705e-01],
                        [ -1.90856934e-01,  -1.90856934e-01],
                        [ -1.40136719e-01,  -1.40136719e-01],
                        [ -1.11938477e-01,  -1.11938477e-01],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.84387207e-01,   1.84387207e-01],
                        [  2.21435547e-01,   2.21435547e-01],
                        [  2.57873535e-01,   2.57873535e-01],
                        [  2.82012939e-01,   2.82012939e-01],
                        [  2.76580811e-01,   2.76580811e-01],
                        [  2.39715576e-01,   2.39715576e-01],
                        [  1.90460205e-01,   1.90460205e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  6.69860840e-02,   6.69860840e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.08947754e-01,   1.08947754e-01],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.92077637e-01,  -1.92077637e-01],
                        [ -2.73315430e-01,  -2.73315430e-01],
                        [ -3.12408447e-01,  -3.12408447e-01],
                        [ -2.96295166e-01,  -2.96295166e-01],
                        [ -2.42218018e-01,  -2.42218018e-01],
                        [ -1.82373047e-01,  -1.82373047e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -1.17309570e-01,  -1.17309570e-01],
                        [ -9.62829590e-02,  -9.62829590e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.34185791e-01,   1.34185791e-01],
                        [  1.59423828e-01,   1.59423828e-01],
                        [  1.91619873e-01,   1.91619873e-01],
                        [  2.27081299e-01,   2.27081299e-01],
                        [  2.52838135e-01,   2.52838135e-01],
                        [  2.56652832e-01,   2.56652832e-01],
                        [  2.38983154e-01,   2.38983154e-01],
                        [  2.10723877e-01,   2.10723877e-01],
                        [  1.80572510e-01,   1.80572510e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.24908447e-01,   1.24908447e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  2.55126953e-02,   2.55126953e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -6.58569336e-02,  -6.58569336e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  2.48107910e-02,   2.48107910e-02],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -1.67785645e-01,  -1.67785645e-01],
                        [ -2.53479004e-01,  -2.53479004e-01],
                        [ -3.03894043e-01,  -3.03894043e-01],
                        [ -3.00476074e-01,  -3.00476074e-01],
                        [ -2.50274658e-01,  -2.50274658e-01],
                        [ -1.82281494e-01,  -1.82281494e-01],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -6.53686523e-02,  -6.53686523e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  1.00372314e-01,   1.00372314e-01],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  1.70074463e-01,   1.70074463e-01],
                        [  2.10845947e-01,   2.10845947e-01],
                        [  2.32971191e-01,   2.32971191e-01],
                        [  2.26165771e-01,   2.26165771e-01],
                        [  1.97540283e-01,   1.97540283e-01],
                        [  1.63696289e-01,   1.63696289e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -7.04650879e-02,  -7.04650879e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.01989746e-01,   1.01989746e-01],
                        [  9.48181152e-02,   9.48181152e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -1.00219727e-01,  -1.00219727e-01],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -1.42059326e-01,  -1.42059326e-01],
                        [ -2.16949463e-01,  -2.16949463e-01],
                        [ -2.66845703e-01,  -2.66845703e-01],
                        [ -2.72460938e-01,  -2.72460938e-01],
                        [ -2.34008789e-01,  -2.34008789e-01],
                        [ -1.74896240e-01,  -1.74896240e-01],
                        [ -1.22711182e-01,  -1.22711182e-01],
                        [ -8.92333984e-02,  -8.92333984e-02],
                        [ -7.03735352e-02,  -7.03735352e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.46759033e-01,   1.46759033e-01],
                        [  1.87500000e-01,   1.87500000e-01],
                        [  2.20794678e-01,   2.20794678e-01],
                        [  2.32940674e-01,   2.32940674e-01],
                        [  2.22320557e-01,   2.22320557e-01],
                        [  1.94793701e-01,   1.94793701e-01],
                        [  1.60858154e-01,   1.60858154e-01],
                        [  1.31713867e-01,   1.31713867e-01],
                        [  1.10717773e-01,   1.10717773e-01],
                        [  9.30175781e-02,   9.30175781e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -6.73828125e-02,  -6.73828125e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -7.09838867e-02,  -7.09838867e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -8.98437500e-02,  -8.98437500e-02],
                        [ -9.90600586e-02,  -9.90600586e-02],
                        [ -7.29064941e-02,  -7.29064941e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -1.87438965e-01,  -1.87438965e-01],
                        [ -2.67913818e-01,  -2.67913818e-01],
                        [ -3.03131104e-01,  -3.03131104e-01],
                        [ -2.79479980e-01,  -2.79479980e-01],
                        [ -2.14965820e-01,  -2.14965820e-01],
                        [ -1.43127441e-01,  -1.43127441e-01],
                        [ -9.07897949e-02,  -9.07897949e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  9.24377441e-02,   9.24377441e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.94000244e-01,   1.94000244e-01],
                        [  2.25280762e-01,   2.25280762e-01],
                        [  2.34039307e-01,   2.34039307e-01],
                        [  2.19207764e-01,   2.19207764e-01],
                        [  1.91558838e-01,   1.91558838e-01],
                        [  1.63421631e-01,   1.63421631e-01],
                        [  1.40991211e-01,   1.40991211e-01],
                        [  1.23504639e-01,   1.23504639e-01],
                        [  1.06018066e-01,   1.06018066e-01],
                        [  8.54797363e-02,   8.54797363e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -7.44628906e-02,  -7.44628906e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -7.69348145e-02,  -7.69348145e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  8.52966309e-02,   8.52966309e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -7.61108398e-02,  -7.61108398e-02],
                        [ -1.06781006e-01,  -1.06781006e-01],
                        [ -1.00891113e-01,  -1.00891113e-01],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -1.07299805e-01,  -1.07299805e-01],
                        [ -1.84875488e-01,  -1.84875488e-01],
                        [ -2.44323730e-01,  -2.44323730e-01],
                        [ -2.61474609e-01,  -2.61474609e-01],
                        [ -2.31781006e-01,  -2.31781006e-01],
                        [ -1.76574707e-01,  -1.76574707e-01],
                        [ -1.25915527e-01,  -1.25915527e-01],
                        [ -9.56115723e-02,  -9.56115723e-02],
                        [ -8.13293457e-02,  -8.13293457e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  1.04034424e-01,   1.04034424e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.87652588e-01,   1.87652588e-01],
                        [  2.22961426e-01,   2.22961426e-01],
                        [  2.30377197e-01,   2.30377197e-01],
                        [  2.11700439e-01,   2.11700439e-01],
                        [  1.79626465e-01,   1.79626465e-01],
                        [  1.47186279e-01,   1.47186279e-01],
                        [  1.22344971e-01,   1.22344971e-01],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  5.82885742e-02,   5.82885742e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -6.94580078e-02,  -6.94580078e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.25305176e-01,  -1.25305176e-01],
                        [ -7.69348145e-02,  -7.69348145e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -1.28387451e-01,  -1.28387451e-01],
                        [ -2.11090088e-01,  -2.11090088e-01],
                        [ -2.62115479e-01,  -2.62115479e-01],
                        [ -2.60589600e-01,  -2.60589600e-01],
                        [ -2.13134766e-01,  -2.13134766e-01],
                        [ -1.46209717e-01,  -1.46209717e-01],
                        [ -8.96911621e-02,  -8.96911621e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  1.09771729e-01,   1.09771729e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.48132324e-01,   1.48132324e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  6.92749023e-02,   6.92749023e-02],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.54754639e-01,   1.54754639e-01],
                        [  1.96166992e-01,   1.96166992e-01],
                        [  2.20489502e-01,   2.20489502e-01],
                        [  2.22351074e-01,   2.22351074e-01],
                        [  2.01507568e-01,   2.01507568e-01],
                        [  1.68395996e-01,   1.68395996e-01],
                        [  1.39343262e-01,   1.39343262e-01],
                        [  1.19232178e-01,   1.19232178e-01],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  8.37097168e-02,   8.37097168e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -7.37609863e-02,  -7.37609863e-02],
                        [ -7.45849609e-02,  -7.45849609e-02],
                        [ -7.28759766e-02,  -7.28759766e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  9.38415527e-02,   9.38415527e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -1.39739990e-01,  -1.39739990e-01],
                        [ -9.85412598e-02,  -9.85412598e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [ -7.74536133e-02,  -7.74536133e-02],
                        [ -1.74468994e-01,  -1.74468994e-01],
                        [ -2.53051758e-01,  -2.53051758e-01],
                        [ -2.81829834e-01,  -2.81829834e-01],
                        [ -2.51678467e-01,  -2.51678467e-01],
                        [ -1.86492920e-01,  -1.86492920e-01],
                        [ -1.26464844e-01,  -1.26464844e-01],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -8.38928223e-02,  -8.38928223e-02],
                        [ -6.91528320e-02,  -6.91528320e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  1.17614746e-01,   1.17614746e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.19445801e-01,   1.19445801e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.41937256e-01,   1.41937256e-01],
                        [  1.82830811e-01,   1.82830811e-01],
                        [  2.14172363e-01,   2.14172363e-01],
                        [  2.26898193e-01,   2.26898193e-01],
                        [  2.17163086e-01,   2.17163086e-01],
                        [  1.87713623e-01,   1.87713623e-01],
                        [  1.50604248e-01,   1.50604248e-01],
                        [  1.21032715e-01,   1.21032715e-01],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -8.50219727e-02,  -8.50219727e-02],
                        [ -1.33331299e-01,  -1.33331299e-01],
                        [ -1.44409180e-01,  -1.44409180e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -1.39129639e-01,  -1.39129639e-01],
                        [ -2.30285645e-01,  -2.30285645e-01],
                        [ -2.82043457e-01,  -2.82043457e-01],
                        [ -2.75543213e-01,  -2.75543213e-01],
                        [ -2.21130371e-01,  -2.21130371e-01],
                        [ -1.51000977e-01,  -1.51000977e-01],
                        [ -9.70764160e-02,  -9.70764160e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  7.26928711e-02,   7.26928711e-02],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  9.20715332e-02,   9.20715332e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  1.37512207e-01,   1.37512207e-01],
                        [  1.77429199e-01,   1.77429199e-01],
                        [  2.10815430e-01,   2.10815430e-01],
                        [  2.25982666e-01,   2.25982666e-01],
                        [  2.15362549e-01,   2.15362549e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.12762451e-01,   1.12762451e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -6.60400391e-02,  -6.60400391e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -5.66101074e-02,  -5.66101074e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [  1.80053711e-03,   1.80053711e-03],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  6.79321289e-02,   6.79321289e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -1.28417969e-01,  -1.28417969e-01],
                        [ -1.62384033e-01,  -1.62384033e-01],
                        [ -1.54022217e-01,  -1.54022217e-01],
                        [ -1.07147217e-01,  -1.07147217e-01],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -1.31866455e-01,  -1.31866455e-01],
                        [ -2.23754883e-01,  -2.23754883e-01],
                        [ -2.75146484e-01,  -2.75146484e-01],
                        [ -2.65930176e-01,  -2.65930176e-01],
                        [ -2.07550049e-01,  -2.07550049e-01],
                        [ -1.36840820e-01,  -1.36840820e-01],
                        [ -8.67919922e-02,  -8.67919922e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.61218262e-02,  -5.61218262e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.40380859e-01,   1.40380859e-01],
                        [  1.11358643e-01,   1.11358643e-01],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.75323486e-01,   1.75323486e-01],
                        [  2.13104248e-01,   2.13104248e-01],
                        [  2.29278564e-01,   2.29278564e-01],
                        [  2.19421387e-01,   2.19421387e-01],
                        [  1.88934326e-01,   1.88934326e-01],
                        [  1.50177002e-01,   1.50177002e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -7.14111328e-02,  -7.14111328e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -1.36474609e-01,  -1.36474609e-01],
                        [ -1.69952393e-01,  -1.69952393e-01],
                        [ -1.55822754e-01,  -1.55822754e-01],
                        [ -1.06994629e-01,  -1.06994629e-01],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -1.45050049e-01,  -1.45050049e-01],
                        [ -2.16888428e-01,  -2.16888428e-01],
                        [ -2.43774414e-01,  -2.43774414e-01],
                        [ -2.23205566e-01,  -2.23205566e-01],
                        [ -1.74896240e-01,  -1.74896240e-01],
                        [ -1.22589111e-01,  -1.22589111e-01],
                        [ -8.29162598e-02,  -8.29162598e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  1.47857666e-01,   1.47857666e-01],
                        [  1.46362305e-01,   1.46362305e-01],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.54327393e-01,   1.54327393e-01],
                        [  1.90460205e-01,   1.90460205e-01],
                        [  2.10906982e-01,   2.10906982e-01],
                        [  2.11486816e-01,   2.11486816e-01],
                        [  1.92108154e-01,   1.92108154e-01],
                        [  1.60308838e-01,   1.60308838e-01],
                        [  1.30615234e-01,   1.30615234e-01],
                        [  1.11816406e-01,   1.11816406e-01],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -6.92443848e-02,  -6.92443848e-02],
                        [ -7.65686035e-02,  -7.65686035e-02],
                        [ -7.29064941e-02,  -7.29064941e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -7.42797852e-02,  -7.42797852e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -1.11633301e-01,  -1.11633301e-01],
                        [ -1.68273926e-01,  -1.68273926e-01],
                        [ -1.79321289e-01,  -1.79321289e-01],
                        [ -1.45690918e-01,  -1.45690918e-01],
                        [ -8.69750977e-02,  -8.69750977e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.07635498e-01,  -1.07635498e-01],
                        [ -1.89270020e-01,  -1.89270020e-01],
                        [ -2.44384766e-01,  -2.44384766e-01],
                        [ -2.56317139e-01,  -2.56317139e-01],
                        [ -2.23907471e-01,  -2.23907471e-01],
                        [ -1.66046143e-01,  -1.66046143e-01],
                        [ -1.12060547e-01,  -1.12060547e-01],
                        [ -8.07189941e-02,  -8.07189941e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  1.39465332e-01,   1.39465332e-01],
                        [  1.53137207e-01,   1.53137207e-01],
                        [  1.42120361e-01,   1.42120361e-01],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.65466309e-01,   1.65466309e-01],
                        [  2.00439453e-01,   2.00439453e-01],
                        [  2.16400146e-01,   2.16400146e-01],
                        [  2.07550049e-01,   2.07550049e-01],
                        [  1.80358887e-01,   1.80358887e-01],
                        [  1.49322510e-01,   1.49322510e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  5.55114746e-02,   5.55114746e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  3.53393555e-02,   3.53393555e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -6.91833496e-02,  -6.91833496e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -7.10449219e-02,  -7.10449219e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -7.41882324e-02,  -7.41882324e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  7.76367188e-02,   7.76367188e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -8.18176270e-02,  -8.18176270e-02],
                        [ -1.45629883e-01,  -1.45629883e-01],
                        [ -1.76513672e-01,  -1.76513672e-01],
                        [ -1.60095215e-01,  -1.60095215e-01],
                        [ -1.04827881e-01,  -1.04827881e-01],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  7.99255371e-02,   7.99255371e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -1.33117676e-01,  -1.33117676e-01],
                        [ -2.22625732e-01,  -2.22625732e-01],
                        [ -2.68554688e-01,  -2.68554688e-01],
                        [ -2.60955811e-01,  -2.60955811e-01],
                        [ -2.13012695e-01,  -2.13012695e-01],
                        [ -1.51428223e-01,  -1.51428223e-01],
                        [ -1.03607178e-01,  -1.03607178e-01],
                        [ -8.14819336e-02,  -8.14819336e-02],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  1.07391357e-01,   1.07391357e-01],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.26861572e-01,   1.26861572e-01],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  5.98449707e-02,   5.98449707e-02],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.90582275e-01,   1.90582275e-01],
                        [  2.23907471e-01,   2.23907471e-01],
                        [  2.30010986e-01,   2.30010986e-01],
                        [  2.08312988e-01,   2.08312988e-01],
                        [  1.73645020e-01,   1.73645020e-01],
                        [  1.42517090e-01,   1.42517090e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -1.30096436e-01,  -1.30096436e-01],
                        [ -1.67968750e-01,  -1.67968750e-01],
                        [ -1.67938232e-01,  -1.67938232e-01],
                        [ -1.33209229e-01,  -1.33209229e-01],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -1.32049561e-01,  -1.32049561e-01],
                        [ -2.02148438e-01,  -2.02148438e-01],
                        [ -2.34588623e-01,  -2.34588623e-01],
                        [ -2.18505859e-01,  -2.18505859e-01],
                        [ -1.69189453e-01,  -1.69189453e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -9.03015137e-02,  -9.03015137e-02],
                        [ -8.15124512e-02,  -8.15124512e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  1.11633301e-01,   1.11633301e-01],
                        [  1.27014160e-01,   1.27014160e-01],
                        [  1.26556396e-01,   1.26556396e-01],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  1.10351562e-01,   1.10351562e-01],
                        [  1.59759521e-01,   1.59759521e-01],
                        [  2.04956055e-01,   2.04956055e-01],
                        [  2.32788086e-01,   2.32788086e-01],
                        [  2.34436035e-01,   2.34436035e-01],
                        [  2.09991455e-01,   2.09991455e-01],
                        [  1.68457031e-01,   1.68457031e-01],
                        [  1.23046875e-01,   1.23046875e-01],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -1.22222900e-01,  -1.22222900e-01],
                        [ -1.64459229e-01,  -1.64459229e-01],
                        [ -1.64520264e-01,  -1.64520264e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -8.23364258e-02,  -8.23364258e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -1.51519775e-01,  -1.51519775e-01],
                        [ -2.16064453e-01,  -2.16064453e-01],
                        [ -2.38067627e-01,  -2.38067627e-01],
                        [ -2.14599609e-01,  -2.14599609e-01],
                        [ -1.63208008e-01,  -1.63208008e-01],
                        [ -1.12060547e-01,  -1.12060547e-01],
                        [ -8.20007324e-02,  -8.20007324e-02],
                        [ -7.30590820e-02,  -7.30590820e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  1.23413086e-01,   1.23413086e-01],
                        [  1.41326904e-01,   1.41326904e-01],
                        [  1.42578125e-01,   1.42578125e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  2.14080811e-01,   2.14080811e-01],
                        [  2.09869385e-01,   2.09869385e-01],
                        [  1.82037354e-01,   1.82037354e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  8.06274414e-02,   8.06274414e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.44836426e-02,  -6.44836426e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  7.50427246e-02,   7.50427246e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -1.27807617e-01,  -1.27807617e-01],
                        [ -1.76910400e-01,  -1.76910400e-01],
                        [ -1.88751221e-01,  -1.88751221e-01],
                        [ -1.59393311e-01,  -1.59393311e-01],
                        [ -1.07055664e-01,  -1.07055664e-01],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  5.52673340e-02,   5.52673340e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -2.15179443e-01,  -2.15179443e-01],
                        [ -2.35900879e-01,  -2.35900879e-01],
                        [ -2.14324951e-01,  -2.14324951e-01],
                        [ -1.69097900e-01,  -1.69097900e-01],
                        [ -1.25640869e-01,  -1.25640869e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -8.07495117e-02,  -8.07495117e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  1.31561279e-01,   1.31561279e-01],
                        [  1.50939941e-01,   1.50939941e-01],
                        [  1.51000977e-01,   1.51000977e-01],
                        [  1.36627197e-01,   1.36627197e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  8.70056152e-02,   8.70056152e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.62841797e-01,   1.62841797e-01],
                        [  1.96075439e-01,   1.96075439e-01],
                        [  2.05993652e-01,   2.05993652e-01],
                        [  1.90185547e-01,   1.90185547e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  9.90905762e-02,   9.90905762e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  6.14624023e-02,   6.14624023e-02],
                        [  6.05163574e-02,   6.05163574e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  4.36401367e-03,   4.36401367e-03],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -1.07543945e-01,  -1.07543945e-01],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -1.87377930e-01,  -1.87377930e-01],
                        [ -1.73736572e-01,  -1.73736572e-01],
                        [ -1.29821777e-01,  -1.29821777e-01],
                        [ -8.01391602e-02,  -8.01391602e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -1.41601562e-01,  -1.41601562e-01],
                        [ -2.03063965e-01,  -2.03063965e-01],
                        [ -2.25860596e-01,  -2.25860596e-01],
                        [ -2.05627441e-01,  -2.05627441e-01],
                        [ -1.61621094e-01,  -1.61621094e-01],
                        [ -1.20178223e-01,  -1.20178223e-01],
                        [ -9.23156738e-02,  -9.23156738e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.22802734e-01,   1.22802734e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.24938965e-01,   1.24938965e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  9.65576172e-02,   9.65576172e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  6.14624023e-02,   6.14624023e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  1.18927002e-01,   1.18927002e-01],
                        [  1.57196045e-01,   1.57196045e-01],
                        [  1.84875488e-01,   1.84875488e-01],
                        [  1.88262939e-01,   1.88262939e-01],
                        [  1.67449951e-01,   1.67449951e-01],
                        [  1.37725830e-01,   1.37725830e-01],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.67614746e-02,   8.67614746e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.44335938e-02,   4.44335938e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -1.28540039e-01,  -1.28540039e-01],
                        [ -1.86004639e-01,  -1.86004639e-01],
                        [ -2.09289551e-01,  -2.09289551e-01],
                        [ -1.92596436e-01,  -1.92596436e-01],
                        [ -1.49108887e-01,  -1.49108887e-01],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -1.23229980e-01,  -1.23229980e-01],
                        [ -2.00317383e-01,  -2.00317383e-01],
                        [ -2.38006592e-01,  -2.38006592e-01],
                        [ -2.27264404e-01,  -2.27264404e-01],
                        [ -1.83319092e-01,  -1.83319092e-01],
                        [ -1.31011963e-01,  -1.31011963e-01],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.21002197e-01,   1.21002197e-01],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  8.43200684e-02,   8.43200684e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  1.30645752e-01,   1.30645752e-01],
                        [  1.71234131e-01,   1.71234131e-01],
                        [  1.91894531e-01,   1.91894531e-01],
                        [  1.82434082e-01,   1.82434082e-01],
                        [  1.53686523e-01,   1.53686523e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -7.17163086e-02,  -7.17163086e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.89910889e-01,  -1.89910889e-01],
                        [ -2.14813232e-01,  -2.14813232e-01],
                        [ -1.95495605e-01,  -1.95495605e-01],
                        [ -1.51275635e-01,  -1.51275635e-01],
                        [ -1.07543945e-01,  -1.07543945e-01],
                        [ -7.58361816e-02,  -7.58361816e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  4.04052734e-02,   4.04052734e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -1.47491455e-01,  -1.47491455e-01],
                        [ -2.16339111e-01,  -2.16339111e-01],
                        [ -2.35992432e-01,  -2.35992432e-01],
                        [ -2.07427979e-01,  -2.07427979e-01],
                        [ -1.55578613e-01,  -1.55578613e-01],
                        [ -1.12152100e-01,  -1.12152100e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -7.51037598e-02,  -7.51037598e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.81030273e-01,   1.81030273e-01],
                        [  1.92810059e-01,   1.92810059e-01],
                        [  1.79382324e-01,   1.79382324e-01],
                        [  1.49627686e-01,   1.49627686e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  8.25500488e-02,   8.25500488e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  5.31005859e-03,   5.31005859e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -1.05682373e-01,  -1.05682373e-01],
                        [ -1.63421631e-01,  -1.63421631e-01],
                        [ -1.92932129e-01,  -1.92932129e-01],
                        [ -1.88903809e-01,  -1.88903809e-01],
                        [ -1.60186768e-01,  -1.60186768e-01],
                        [ -1.22589111e-01,  -1.22589111e-01],
                        [ -8.99963379e-02,  -8.99963379e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  1.11785889e-01,   1.11785889e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -1.33148193e-01,  -1.33148193e-01],
                        [ -2.08557129e-01,  -2.08557129e-01],
                        [ -2.37335205e-01,  -2.37335205e-01],
                        [ -2.15393066e-01,  -2.15393066e-01],
                        [ -1.62353516e-01,  -1.62353516e-01],
                        [ -1.10290527e-01,  -1.10290527e-01],
                        [ -7.93762207e-02,  -7.93762207e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.36932373e-01,   1.36932373e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.59179688e-01,   1.59179688e-01],
                        [  1.78436279e-01,   1.78436279e-01],
                        [  1.72515869e-01,   1.72515869e-01],
                        [  1.46911621e-01,   1.46911621e-01],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  5.24291992e-02,   5.24291992e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -1.66717529e-01,  -1.66717529e-01],
                        [ -1.93756104e-01,  -1.93756104e-01],
                        [ -1.89147949e-01,  -1.89147949e-01],
                        [ -1.58020020e-01,  -1.58020020e-01],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.35803223e-01,   1.35803223e-01],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  2.07519531e-02,   2.07519531e-02],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -1.91436768e-01,  -1.91436768e-01],
                        [ -2.52166748e-01,  -2.52166748e-01],
                        [ -2.53936768e-01,  -2.53936768e-01],
                        [ -2.05505371e-01,  -2.05505371e-01],
                        [ -1.38763428e-01,  -1.38763428e-01],
                        [ -8.83483887e-02,  -8.83483887e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  7.30285645e-02,   7.30285645e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.09893799e-01,   1.09893799e-01],
                        [  9.81750488e-02,   9.81750488e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  8.01086426e-02,   8.01086426e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.58020020e-01,   1.58020020e-01],
                        [  1.72241211e-01,   1.72241211e-01],
                        [  1.63696289e-01,   1.63696289e-01],
                        [  1.38977051e-01,   1.38977051e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  7.72399902e-02,   7.72399902e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  3.50646973e-02,   3.50646973e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -8.83483887e-02,  -8.83483887e-02],
                        [ -1.58966064e-01,  -1.58966064e-01],
                        [ -2.08618164e-01,  -2.08618164e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -1.88842773e-01,  -1.88842773e-01],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -9.78088379e-02,  -9.78088379e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  1.26525879e-01,   1.26525879e-01],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  4.43420410e-02,   4.43420410e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -1.43218994e-01,  -1.43218994e-01],
                        [ -2.10052490e-01,  -2.10052490e-01],
                        [ -2.29309082e-01,  -2.29309082e-01],
                        [ -2.03369141e-01,  -2.03369141e-01],
                        [ -1.53717041e-01,  -1.53717041e-01],
                        [ -1.06414795e-01,  -1.06414795e-01],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [  4.08935547e-03,   4.08935547e-03],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  9.60998535e-02,   9.60998535e-02],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.37908936e-01,   1.37908936e-01],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  9.68017578e-02,   9.68017578e-02],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.78527832e-01,   1.78527832e-01],
                        [  1.92169189e-01,   1.92169189e-01],
                        [  1.75659180e-01,   1.75659180e-01],
                        [  1.40899658e-01,   1.40899658e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.44335938e-02,  -4.44335938e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -1.25518799e-01,  -1.25518799e-01],
                        [ -1.87133789e-01,  -1.87133789e-01],
                        [ -2.19116211e-01,  -2.19116211e-01],
                        [ -2.10357666e-01,  -2.10357666e-01],
                        [ -1.71600342e-01,  -1.71600342e-01],
                        [ -1.27471924e-01,  -1.27471924e-01],
                        [ -9.49707031e-02,  -9.49707031e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  1.08764648e-01,   1.08764648e-01],
                        [  1.29791260e-01,   1.29791260e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.05590820e-01,   1.05590820e-01],
                        [  4.49218750e-02,   4.49218750e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -1.46209717e-01,  -1.46209717e-01],
                        [ -2.19360352e-01,  -2.19360352e-01],
                        [ -2.40966797e-01,  -2.40966797e-01],
                        [ -2.10266113e-01,  -2.10266113e-01],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.26940918e-02,   4.26940918e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  1.35131836e-01,   1.35131836e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  1.15203857e-01,   1.15203857e-01],
                        [  1.15814209e-01,   1.15814209e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  8.38623047e-02,   8.38623047e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  1.45843506e-01,   1.45843506e-01],
                        [  1.69616699e-01,   1.69616699e-01],
                        [  1.69494629e-01,   1.69494629e-01],
                        [  1.49719238e-01,   1.49719238e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  8.00781250e-02,   8.00781250e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -7.87048340e-02,  -7.87048340e-02],
                        [ -7.51037598e-02,  -7.51037598e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -1.49383545e-01,  -1.49383545e-01],
                        [ -2.15362549e-01,  -2.15362549e-01],
                        [ -2.40905762e-01,  -2.40905762e-01],
                        [ -2.23846436e-01,  -2.23846436e-01],
                        [ -1.79779053e-01,  -1.79779053e-01],
                        [ -1.31225586e-01,  -1.31225586e-01],
                        [ -9.50622559e-02,  -9.50622559e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.47857666e-01,   1.47857666e-01],
                        [  1.57226562e-01,   1.57226562e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  5.69458008e-02,   5.69458008e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -1.54602051e-01,  -1.54602051e-01],
                        [ -2.31658936e-01,  -2.31658936e-01],
                        [ -2.57049561e-01,  -2.57049561e-01],
                        [ -2.27630615e-01,  -2.27630615e-01],
                        [ -1.65313721e-01,  -1.65313721e-01],
                        [ -1.03668213e-01,  -1.03668213e-01],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.53930664e-01,   1.53930664e-01],
                        [  1.44226074e-01,   1.44226074e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  1.54174805e-01,   1.54174805e-01],
                        [  1.72607422e-01,   1.72607422e-01],
                        [  1.64337158e-01,   1.64337158e-01],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  7.28454590e-02,   7.28454590e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.77697754e-02,  -5.77697754e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -8.15429688e-02,  -8.15429688e-02],
                        [ -1.62322998e-01,  -1.62322998e-01],
                        [ -2.27203369e-01,  -2.27203369e-01],
                        [ -2.53845215e-01,  -2.53845215e-01],
                        [ -2.32574463e-01,  -2.32574463e-01],
                        [ -1.79687500e-01,  -1.79687500e-01],
                        [ -1.26556396e-01,  -1.26556396e-01],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -6.55212402e-02,  -6.55212402e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -9.14001465e-02,  -9.14001465e-02],
                        [ -1.79901123e-01,  -1.79901123e-01],
                        [ -2.29248047e-01,  -2.29248047e-01],
                        [ -2.24700928e-01,  -2.24700928e-01],
                        [ -1.80938721e-01,  -1.80938721e-01],
                        [ -1.29638672e-01,  -1.29638672e-01],
                        [ -9.41772461e-02,  -9.41772461e-02],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -5.50537109e-02,  -5.50537109e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.40899658e-01,   1.40899658e-01],
                        [  1.51367188e-01,   1.51367188e-01],
                        [  1.44958496e-01,   1.44958496e-01],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  9.23461914e-02,   9.23461914e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.69281006e-01,   1.69281006e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.30493164e-01,   1.30493164e-01],
                        [  9.60083008e-02,   9.60083008e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -1.93420410e-01,  -1.93420410e-01],
                        [ -2.32269287e-01,  -2.32269287e-01],
                        [ -2.25982666e-01,  -2.25982666e-01],
                        [ -1.87347412e-01,  -1.87347412e-01],
                        [ -1.41632080e-01,  -1.41632080e-01],
                        [ -1.07757568e-01,  -1.07757568e-01],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  6.06079102e-02,   6.06079102e-02],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.60705566e-01,   1.60705566e-01],
                        [  1.55181885e-01,   1.55181885e-01],
                        [  1.13342285e-01,   1.13342285e-01],
                        [  3.00598145e-02,   3.00598145e-02],
                        [ -7.97424316e-02,  -7.97424316e-02],
                        [ -1.81549072e-01,  -1.81549072e-01],
                        [ -2.40631104e-01,  -2.40631104e-01],
                        [ -2.41821289e-01,  -2.41821289e-01],
                        [ -1.95281982e-01,  -1.95281982e-01],
                        [ -1.30004883e-01,  -1.30004883e-01],
                        [ -7.75756836e-02,  -7.75756836e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.23443604e-01,   1.23443604e-01],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  8.08715820e-02,   8.08715820e-02],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.65344238e-01,   1.65344238e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.41143799e-01,   1.41143799e-01],
                        [  1.08551025e-01,   1.08551025e-01],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  5.35888672e-02,   5.35888672e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.29785156e-02,   5.29785156e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -1.16119385e-01,  -1.16119385e-01],
                        [ -1.82128906e-01,  -1.82128906e-01],
                        [ -2.20306396e-01,  -2.20306396e-01],
                        [ -2.17010498e-01,  -2.17010498e-01],
                        [ -1.77978516e-01,  -1.77978516e-01],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -9.20104980e-02,  -9.20104980e-02],
                        [ -7.60498047e-02,  -7.60498047e-02],
                        [ -7.03430176e-02,  -7.03430176e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.26098633e-01,   1.26098633e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  4.62951660e-02,   4.62951660e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -1.36718750e-01,  -1.36718750e-01],
                        [ -2.08251953e-01,  -2.08251953e-01],
                        [ -2.28820801e-01,  -2.28820801e-01],
                        [ -1.97418213e-01,  -1.97418213e-01],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -9.04541016e-02,  -9.04541016e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.49658203e-01,   1.49658203e-01],
                        [  1.50085449e-01,   1.50085449e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.22344971e-01,   1.22344971e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.59332275e-01,   1.59332275e-01],
                        [  1.52709961e-01,   1.52709961e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -1.78100586e-01,  -1.78100586e-01],
                        [ -2.24456787e-01,  -2.24456787e-01],
                        [ -2.31414795e-01,  -2.31414795e-01],
                        [ -1.97052002e-01,  -1.97052002e-01],
                        [ -1.39007568e-01,  -1.39007568e-01],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  1.13464355e-01,   1.13464355e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.91223145e-01,  -1.91223145e-01],
                        [ -2.21343994e-01,  -2.21343994e-01],
                        [ -1.98913574e-01,  -1.98913574e-01],
                        [ -1.43402100e-01,  -1.43402100e-01],
                        [ -8.88671875e-02,  -8.88671875e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.51153564e-01,   1.51153564e-01],
                        [  1.70684814e-01,   1.70684814e-01],
                        [  1.63940430e-01,   1.63940430e-01],
                        [  1.44744873e-01,   1.44744873e-01],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.18255615e-01,   1.18255615e-01],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.02294922e-01,   1.02294922e-01],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  3.23486328e-03,   3.23486328e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.41784668e-01,   1.41784668e-01],
                        [  1.41357422e-01,   1.41357422e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  4.21142578e-03,   4.21142578e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -7.15637207e-02,  -7.15637207e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -1.24328613e-01,  -1.24328613e-01],
                        [ -1.89758301e-01,  -1.89758301e-01],
                        [ -2.27020264e-01,  -2.27020264e-01],
                        [ -2.22961426e-01,  -2.22961426e-01],
                        [ -1.84875488e-01,  -1.84875488e-01],
                        [ -1.35742188e-01,  -1.35742188e-01],
                        [ -9.82971191e-02,  -9.82971191e-02],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -7.05871582e-02,  -7.05871582e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  7.00378418e-02,   7.00378418e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.22863770e-01,   1.22863770e-01],
                        [  1.32141113e-01,   1.32141113e-01],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  6.35070801e-02,   6.35070801e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -9.67407227e-02,  -9.67407227e-02],
                        [ -1.75079346e-01,  -1.75079346e-01],
                        [ -2.21343994e-01,  -2.21343994e-01],
                        [ -2.19757080e-01,  -2.19757080e-01],
                        [ -1.78253174e-01,  -1.78253174e-01],
                        [ -1.24237061e-01,  -1.24237061e-01],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  1.28906250e-01,   1.28906250e-01],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  1.56005859e-01,   1.56005859e-01],
                        [  1.47796631e-01,   1.47796631e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  1.13159180e-01,   1.13159180e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  7.83386230e-02,   7.83386230e-02],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.38275146e-01,   1.38275146e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -1.34979248e-01,  -1.34979248e-01],
                        [ -2.01507568e-01,  -2.01507568e-01],
                        [ -2.39868164e-01,  -2.39868164e-01],
                        [ -2.36480713e-01,  -2.36480713e-01],
                        [ -1.97387695e-01,  -1.97387695e-01],
                        [ -1.46362305e-01,  -1.46362305e-01],
                        [ -1.07604980e-01,  -1.07604980e-01],
                        [ -8.70971680e-02,  -8.70971680e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  1.35589600e-01,   1.35589600e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  5.76477051e-02,   5.76477051e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.95953369e-01,  -1.95953369e-01],
                        [ -2.30987549e-01,  -2.30987549e-01],
                        [ -2.13623047e-01,  -2.13623047e-01],
                        [ -1.60736084e-01,  -1.60736084e-01],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  1.25946045e-01,   1.25946045e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.77368164e-01,   1.77368164e-01],
                        [  1.75781250e-01,   1.75781250e-01],
                        [  1.62139893e-01,   1.62139893e-01],
                        [  1.43981934e-01,   1.43981934e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.56433105e-01,   1.56433105e-01],
                        [  1.64245605e-01,   1.64245605e-01],
                        [  1.47491455e-01,   1.47491455e-01],
                        [  1.19262695e-01,   1.19262695e-01],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -7.47375488e-02,  -7.47375488e-02],
                        [ -8.13293457e-02,  -8.13293457e-02],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -1.30035400e-01,  -1.30035400e-01],
                        [ -2.02545166e-01,  -2.02545166e-01],
                        [ -2.47314453e-01,  -2.47314453e-01],
                        [ -2.49572754e-01,  -2.49572754e-01],
                        [ -2.14233398e-01,  -2.14233398e-01],
                        [ -1.62322998e-01,  -1.62322998e-01],
                        [ -1.15783691e-01,  -1.15783691e-01],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  1.28143311e-01,   1.28143311e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.19262695e-01,   1.19262695e-01],
                        [  6.80847168e-02,   6.80847168e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -2.10723877e-01,  -2.10723877e-01],
                        [ -2.46826172e-01,  -2.46826172e-01],
                        [ -2.26196289e-01,  -2.26196289e-01],
                        [ -1.65710449e-01,  -1.65710449e-01],
                        [ -9.72595215e-02,  -9.72595215e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.58203125e-01,   1.58203125e-01],
                        [  1.63818359e-01,   1.63818359e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.44897461e-01,   1.44897461e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.13220215e-01,   1.13220215e-01],
                        [  1.00036621e-01,   1.00036621e-01],
                        [  8.03833008e-02,   8.03833008e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.75842285e-01,   1.75842285e-01],
                        [  1.78405762e-01,   1.78405762e-01],
                        [  1.53564453e-01,   1.53564453e-01],
                        [  1.18316650e-01,   1.18316650e-01],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -7.08007812e-02,  -7.08007812e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -1.72851562e-01,  -1.72851562e-01],
                        [ -2.12707520e-01,  -2.12707520e-01],
                        [ -2.13378906e-01,  -2.13378906e-01],
                        [ -1.82128906e-01,  -1.82128906e-01],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -1.15478516e-01,  -1.15478516e-01],
                        [ -1.01074219e-01,  -1.01074219e-01],
                        [ -9.02709961e-02,  -9.02709961e-02],
                        [ -7.60498047e-02,  -7.60498047e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.47918701e-01,   1.47918701e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -8.76770020e-02,  -8.76770020e-02],
                        [ -1.71600342e-01,  -1.71600342e-01],
                        [ -2.16583252e-01,  -2.16583252e-01],
                        [ -2.13134766e-01,  -2.13134766e-01],
                        [ -1.70166016e-01,  -1.70166016e-01],
                        [ -1.12884521e-01,  -1.12884521e-01],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  4.69665527e-02,   4.69665527e-02],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.49444580e-01,   1.49444580e-01],
                        [  1.54602051e-01,   1.54602051e-01],
                        [  1.43371582e-01,   1.43371582e-01],
                        [  1.29272461e-01,   1.29272461e-01],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.24298096e-01,   1.24298096e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.24908447e-01,   1.24908447e-01],
                        [  1.17218018e-01,   1.17218018e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.58355713e-01,   1.58355713e-01],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  5.63659668e-02,   5.63659668e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  4.08935547e-03,   4.08935547e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.47082520e-02,  -4.47082520e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  6.70166016e-02,   6.70166016e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -1.29394531e-01,  -1.29394531e-01],
                        [ -2.12005615e-01,  -2.12005615e-01],
                        [ -2.58666992e-01,  -2.58666992e-01],
                        [ -2.54791260e-01,  -2.54791260e-01],
                        [ -2.14660645e-01,  -2.14660645e-01],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -1.29638672e-01,  -1.29638672e-01],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -9.10339355e-02,  -9.10339355e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.38366699e-01,   1.38366699e-01],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [ -7.78808594e-02,  -7.78808594e-02],
                        [ -1.72149658e-01,  -1.72149658e-01],
                        [ -2.26165771e-01,  -2.26165771e-01],
                        [ -2.25769043e-01,  -2.25769043e-01],
                        [ -1.83013916e-01,  -1.83013916e-01],
                        [ -1.24053955e-01,  -1.24053955e-01],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  2.41088867e-03,   2.41088867e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.66473389e-01,   1.66473389e-01],
                        [  1.83349609e-01,   1.83349609e-01],
                        [  1.77947998e-01,   1.77947998e-01],
                        [  1.58416748e-01,   1.58416748e-01],
                        [  1.38488770e-01,   1.38488770e-01],
                        [  1.26617432e-01,   1.26617432e-01],
                        [  1.19476318e-01,   1.19476318e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  8.05664062e-02,   8.05664062e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  7.80334473e-02,   7.80334473e-02],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  1.52679443e-01,   1.52679443e-01],
                        [  1.53228760e-01,   1.53228760e-01],
                        [  1.29241943e-01,   1.29241943e-01],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  6.97326660e-02,   6.97326660e-02],
                        [  4.91333008e-02,   4.91333008e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -8.09631348e-02,  -8.09631348e-02],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -2.14172363e-01,  -2.14172363e-01],
                        [ -2.34710693e-01,  -2.34710693e-01],
                        [ -2.14324951e-01,  -2.14324951e-01],
                        [ -1.71325684e-01,  -1.71325684e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -1.09222412e-01,  -1.09222412e-01],
                        [ -9.84497070e-02,  -9.84497070e-02],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.50634766e-01,   1.50634766e-01],
                        [  1.36688232e-01,   1.36688232e-01],
                        [  8.52966309e-02,   8.52966309e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -1.16638184e-01,  -1.16638184e-01],
                        [ -2.07397461e-01,  -2.07397461e-01],
                        [ -2.45147705e-01,  -2.45147705e-01],
                        [ -2.23541260e-01,  -2.23541260e-01],
                        [ -1.63421631e-01,  -1.63421631e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  1.24328613e-01,   1.24328613e-01],
                        [  1.56494141e-01,   1.56494141e-01],
                        [  1.68365479e-01,   1.68365479e-01],
                        [  1.62078857e-01,   1.62078857e-01],
                        [  1.49200439e-01,   1.49200439e-01],
                        [  1.38610840e-01,   1.38610840e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.32507324e-01,   1.32507324e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  9.29260254e-02,   9.29260254e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.88281250e-02,  -4.88281250e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  5.34362793e-02,   5.34362793e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -7.46459961e-02,  -7.46459961e-02],
                        [ -1.49810791e-01,  -1.49810791e-01],
                        [ -2.07580566e-01,  -2.07580566e-01],
                        [ -2.32086182e-01,  -2.32086182e-01],
                        [ -2.18841553e-01,  -2.18841553e-01],
                        [ -1.82189941e-01,  -1.82189941e-01],
                        [ -1.46697998e-01,  -1.46697998e-01],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.12304688e-01,  -1.12304688e-01],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  5.93261719e-02,   5.93261719e-02],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  3.28674316e-02,   3.28674316e-02],
                        [ -7.33947754e-02,  -7.33947754e-02],
                        [ -1.75567627e-01,  -1.75567627e-01],
                        [ -2.31048584e-01,  -2.31048584e-01],
                        [ -2.22137451e-01,  -2.22137451e-01],
                        [ -1.70074463e-01,  -1.70074463e-01],
                        [ -1.13189697e-01,  -1.13189697e-01],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.45263672e-01,   1.45263672e-01],
                        [  1.63726807e-01,   1.63726807e-01],
                        [  1.65832520e-01,   1.65832520e-01],
                        [  1.61376953e-01,   1.61376953e-01],
                        [  1.58172607e-01,   1.58172607e-01],
                        [  1.56341553e-01,   1.56341553e-01],
                        [  1.51550293e-01,   1.51550293e-01],
                        [  1.39984131e-01,   1.39984131e-01],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  9.62524414e-02,   9.62524414e-02],
                        [  7.20214844e-02,   7.20214844e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  1.64184570e-02,   1.64184570e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.40441895e-01,   1.40441895e-01],
                        [  1.40289307e-01,   1.40289307e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  8.89282227e-02,   8.89282227e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -1.05682373e-01,  -1.05682373e-01],
                        [ -1.90032959e-01,  -1.90032959e-01],
                        [ -2.42614746e-01,  -2.42614746e-01],
                        [ -2.49511719e-01,  -2.49511719e-01],
                        [ -2.19696045e-01,  -2.19696045e-01],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -1.39801025e-01,  -1.39801025e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -9.81445312e-02,  -9.81445312e-02],
                        [ -7.92236328e-02,  -7.92236328e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  6.28356934e-02,   6.28356934e-02],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.40441895e-01,   1.40441895e-01],
                        [  1.29516602e-01,   1.29516602e-01],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [ -9.59777832e-02,  -9.59777832e-02],
                        [ -1.89025879e-01,  -1.89025879e-01],
                        [ -2.34802246e-01,  -2.34802246e-01],
                        [ -2.21801758e-01,  -2.21801758e-01],
                        [ -1.68334961e-01,  -1.68334961e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  8.85620117e-02,   8.85620117e-02],
                        [  1.41601562e-01,   1.41601562e-01],
                        [  1.80358887e-01,   1.80358887e-01],
                        [  1.96380615e-01,   1.96380615e-01],
                        [  1.89971924e-01,   1.89971924e-01],
                        [  1.69647217e-01,   1.69647217e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.41967773e-01,   1.41967773e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.30090332e-02,   5.30090332e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  4.19311523e-02,   4.19311523e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -9.50012207e-02,  -9.50012207e-02],
                        [ -1.80145264e-01,  -1.80145264e-01],
                        [ -2.41577148e-01,  -2.41577148e-01],
                        [ -2.58728027e-01,  -2.58728027e-01],
                        [ -2.31018066e-01,  -2.31018066e-01],
                        [ -1.79351807e-01,  -1.79351807e-01],
                        [ -1.31774902e-01,  -1.31774902e-01],
                        [ -1.03668213e-01,  -1.03668213e-01],
                        [ -9.01184082e-02,  -9.01184082e-02],
                        [ -7.83386230e-02,  -7.83386230e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  1.15325928e-01,   1.15325928e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.32110596e-01,   1.32110596e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  7.65686035e-02,   7.65686035e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -9.97314453e-02,  -9.97314453e-02],
                        [ -1.86706543e-01,  -1.86706543e-01],
                        [ -2.22290039e-01,  -2.22290039e-01],
                        [ -1.97723389e-01,  -1.97723389e-01],
                        [ -1.39373779e-01,  -1.39373779e-01],
                        [ -8.22753906e-02,  -8.22753906e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.45629883e-01,   1.45629883e-01],
                        [  1.81427002e-01,   1.81427002e-01],
                        [  1.94183350e-01,   1.94183350e-01],
                        [  1.83044434e-01,   1.83044434e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.39648438e-01,   1.39648438e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  8.64257812e-02,   8.64257812e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.41204834e-01,   1.41204834e-01],
                        [  1.34033203e-01,   1.34033203e-01],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -1.88232422e-01,  -1.88232422e-01],
                        [ -2.32574463e-01,  -2.32574463e-01],
                        [ -2.34313965e-01,  -2.34313965e-01],
                        [ -1.98089600e-01,  -1.98089600e-01],
                        [ -1.51855469e-01,  -1.51855469e-01],
                        [ -1.22375488e-01,  -1.22375488e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -1.02905273e-01,  -1.02905273e-01],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -6.87561035e-02,  -6.87561035e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.37908936e-01,   1.37908936e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  4.10156250e-02,   4.10156250e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -2.06268311e-01,  -2.06268311e-01],
                        [ -2.14874268e-01,  -2.14874268e-01],
                        [ -1.75170898e-01,  -1.75170898e-01],
                        [ -1.15905762e-01,  -1.15905762e-01],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.77703857e-01,   1.77703857e-01],
                        [  1.90185547e-01,   1.90185547e-01],
                        [  1.80938721e-01,   1.80938721e-01],
                        [  1.60308838e-01,   1.60308838e-01],
                        [  1.41479492e-01,   1.41479492e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.13006592e-01,   1.13006592e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  9.98229980e-02,   9.98229980e-02],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  1.37176514e-01,   1.37176514e-01],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  3.23486328e-03,   3.23486328e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.91528320e-02,  -6.91528320e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  7.33032227e-02,   7.33032227e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -1.56219482e-01,  -1.56219482e-01],
                        [ -2.22503662e-01,  -2.22503662e-01],
                        [ -2.48199463e-01,  -2.48199463e-01],
                        [ -2.28576660e-01,  -2.28576660e-01],
                        [ -1.83044434e-01,  -1.83044434e-01],
                        [ -1.39251709e-01,  -1.39251709e-01],
                        [ -1.11907959e-01,  -1.11907959e-01],
                        [ -9.58557129e-02,  -9.58557129e-02],
                        [ -7.97424316e-02,  -7.97424316e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.35223389e-01,   1.35223389e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  4.71191406e-02,   4.71191406e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -1.32629395e-01,  -1.32629395e-01],
                        [ -2.00225830e-01,  -2.00225830e-01],
                        [ -2.15637207e-01,  -2.15637207e-01],
                        [ -1.80938721e-01,  -1.80938721e-01],
                        [ -1.25579834e-01,  -1.25579834e-01],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -3.50036621e-02,  -3.50036621e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  5.41076660e-02,   5.41076660e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  1.80145264e-01,   1.80145264e-01],
                        [  1.78253174e-01,   1.78253174e-01],
                        [  1.61712646e-01,   1.61712646e-01],
                        [  1.44104004e-01,   1.44104004e-01],
                        [  1.33636475e-01,   1.33636475e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -3.40270996e-02,  -3.40270996e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.44104004e-01,   1.44104004e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  9.29565430e-02,   9.29565430e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  7.84301758e-03,   7.84301758e-03],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -1.36840820e-01,  -1.36840820e-01],
                        [ -2.09625244e-01,  -2.09625244e-01],
                        [ -2.56591797e-01,  -2.56591797e-01],
                        [ -2.60711670e-01,  -2.60711670e-01],
                        [ -2.23602295e-01,  -2.23602295e-01],
                        [ -1.70410156e-01,  -1.70410156e-01],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -1.10870361e-01,  -1.10870361e-01],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -8.32519531e-02,  -8.32519531e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  1.11877441e-01,   1.11877441e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -1.32995605e-01,  -1.32995605e-01],
                        [ -1.93603516e-01,  -1.93603516e-01],
                        [ -2.05261230e-01,  -2.05261230e-01],
                        [ -1.70288086e-01,  -1.70288086e-01],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.83197021e-01,   1.83197021e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  1.73889160e-01,   1.73889160e-01],
                        [  1.48803711e-01,   1.48803711e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.19812012e-01,   1.19812012e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  5.82885742e-02,   5.82885742e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -1.22039795e-01,  -1.22039795e-01],
                        [ -1.97113037e-01,  -1.97113037e-01],
                        [ -2.49023438e-01,  -2.49023438e-01],
                        [ -2.59155273e-01,  -2.59155273e-01],
                        [ -2.26715088e-01,  -2.26715088e-01],
                        [ -1.73370361e-01,  -1.73370361e-01],
                        [ -1.27655029e-01,  -1.27655029e-01],
                        [ -1.03759766e-01,  -1.03759766e-01],
                        [ -9.46350098e-02,  -9.46350098e-02],
                        [ -8.49914551e-02,  -8.49914551e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -4.84008789e-02,  -4.84008789e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.29913330e-01,   1.29913330e-01],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  4.43420410e-02,   4.43420410e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -1.36291504e-01,  -1.36291504e-01],
                        [ -2.02056885e-01,  -2.02056885e-01],
                        [ -2.14111328e-01,  -2.14111328e-01],
                        [ -1.75445557e-01,  -1.75445557e-01],
                        [ -1.14562988e-01,  -1.14562988e-01],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.07421875e-02,  -1.07421875e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.54418945e-01,   1.54418945e-01],
                        [  1.68975830e-01,   1.68975830e-01],
                        [  1.71478271e-01,   1.71478271e-01],
                        [  1.68731689e-01,   1.68731689e-01],
                        [  1.66168213e-01,   1.66168213e-01],
                        [  1.62689209e-01,   1.62689209e-01],
                        [  1.52832031e-01,   1.52832031e-01],
                        [  1.34155273e-01,   1.34155273e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  8.71276855e-02,   8.71276855e-02],
                        [  1.32995605e-01,   1.32995605e-01],
                        [  1.49932861e-01,   1.49932861e-01],
                        [  1.34063721e-01,   1.34063721e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -9.37805176e-02,  -9.37805176e-02],
                        [ -1.70196533e-01,  -1.70196533e-01],
                        [ -2.33978271e-01,  -2.33978271e-01],
                        [ -2.63519287e-01,  -2.63519287e-01],
                        [ -2.49389648e-01,  -2.49389648e-01],
                        [ -2.02056885e-01,  -2.02056885e-01],
                        [ -1.47125244e-01,  -1.47125244e-01],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -1.01043701e-01,  -1.01043701e-01],
                        [ -1.03057861e-01,  -1.03057861e-01],
                        [ -9.62524414e-02,  -9.62524414e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -1.39617920e-01,  -1.39617920e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -2.16094971e-01,  -2.16094971e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.11968994e-01,  -1.11968994e-01],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.75384521e-01,   1.75384521e-01],
                        [  1.84387207e-01,   1.84387207e-01],
                        [  1.73583984e-01,   1.73583984e-01],
                        [  1.56616211e-01,   1.56616211e-01],
                        [  1.43341064e-01,   1.43341064e-01],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.00646973e-01,   1.00646973e-01],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -5.95397949e-02,  -5.95397949e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.38092041e-01,   1.38092041e-01],
                        [  1.34490967e-01,   1.34490967e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  8.57849121e-02,   8.57849121e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -1.53656006e-01,  -1.53656006e-01],
                        [ -2.29766846e-01,  -2.29766846e-01],
                        [ -2.65716553e-01,  -2.65716553e-01],
                        [ -2.54821777e-01,  -2.54821777e-01],
                        [ -2.10754395e-01,  -2.10754395e-01],
                        [ -1.57073975e-01,  -1.57073975e-01],
                        [ -1.14593506e-01,  -1.14593506e-01],
                        [ -8.99963379e-02,  -8.99963379e-02],
                        [ -7.75146484e-02,  -7.75146484e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -6.57043457e-02,  -6.57043457e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  6.76879883e-02,   6.76879883e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -9.88159180e-02,  -9.88159180e-02],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -2.08160400e-01,  -2.08160400e-01],
                        [ -1.89117432e-01,  -1.89117432e-01],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.79656982e-01,   1.79656982e-01],
                        [  1.82647705e-01,   1.82647705e-01],
                        [  1.73583984e-01,   1.73583984e-01],
                        [  1.59332275e-01,   1.59332275e-01],
                        [  1.45782471e-01,   1.45782471e-01],
                        [  1.35314941e-01,   1.35314941e-01],
                        [  1.26220703e-01,   1.26220703e-01],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.03057861e-01,   1.03057861e-01],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  8.35876465e-02,   8.35876465e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.06597900e-01,  -1.06597900e-01],
                        [ -1.93267822e-01,  -1.93267822e-01],
                        [ -2.56134033e-01,  -2.56134033e-01],
                        [ -2.75024414e-01,  -2.75024414e-01],
                        [ -2.48077393e-01,  -2.48077393e-01],
                        [ -1.96502686e-01,  -1.96502686e-01],
                        [ -1.49261475e-01,  -1.49261475e-01],
                        [ -1.19384766e-01,  -1.19384766e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.21215820e-01,   1.21215820e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  6.68640137e-02,   6.68640137e-02],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -8.80126953e-02,  -8.80126953e-02],
                        [ -1.68151855e-01,  -1.68151855e-01],
                        [ -2.09533691e-01,  -2.09533691e-01],
                        [ -1.97326660e-01,  -1.97326660e-01],
                        [ -1.46148682e-01,  -1.46148682e-01],
                        [ -9.11865234e-02,  -9.11865234e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  5.55725098e-02,   5.55725098e-02],
                        [  9.62524414e-02,   9.62524414e-02],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.65191650e-01,   1.65191650e-01],
                        [  1.75872803e-01,   1.75872803e-01],
                        [  1.71234131e-01,   1.71234131e-01],
                        [  1.58569336e-01,   1.58569336e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.38183594e-01,   1.38183594e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  1.12670898e-01,   1.12670898e-01],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  6.24389648e-02,   6.24389648e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -6.93664551e-02,  -6.93664551e-02],
                        [ -1.55181885e-01,  -1.55181885e-01],
                        [ -2.31079102e-01,  -2.31079102e-01],
                        [ -2.70507812e-01,  -2.70507812e-01],
                        [ -2.64038086e-01,  -2.64038086e-01],
                        [ -2.23388672e-01,  -2.23388672e-01],
                        [ -1.73034668e-01,  -1.73034668e-01],
                        [ -1.35894775e-01,  -1.35894775e-01],
                        [ -1.17828369e-01,  -1.17828369e-01],
                        [ -1.05163574e-01,  -1.05163574e-01],
                        [ -8.34655762e-02,  -8.34655762e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  4.53491211e-02,   4.53491211e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  7.78198242e-02,   7.78198242e-02],
                        [  8.97216797e-02,   8.97216797e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -1.34948730e-01,  -1.34948730e-01],
                        [ -1.84600830e-01,  -1.84600830e-01],
                        [ -1.90032959e-01,  -1.90032959e-01],
                        [ -1.58142090e-01,  -1.58142090e-01],
                        [ -1.13098145e-01,  -1.13098145e-01],
                        [ -7.65380859e-02,  -7.65380859e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.61682129e-01,   1.61682129e-01],
                        [  1.80358887e-01,   1.80358887e-01],
                        [  1.78924561e-01,   1.78924561e-01],
                        [  1.61071777e-01,   1.61071777e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  7.32116699e-02,   7.32116699e-02],
                        [  5.25817871e-02,   5.25817871e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -1.58813477e-01,  -1.58813477e-01],
                        [ -2.30621338e-01,  -2.30621338e-01],
                        [ -2.66265869e-01,  -2.66265869e-01],
                        [ -2.51556396e-01,  -2.51556396e-01],
                        [ -2.00378418e-01,  -2.00378418e-01],
                        [ -1.45477295e-01,  -1.45477295e-01],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -9.70458984e-02,  -9.70458984e-02],
                        [ -8.77990723e-02,  -8.77990723e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  1.11938477e-01,   1.11938477e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  7.29064941e-02,   7.29064941e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -1.74804688e-01,  -1.74804688e-01],
                        [ -2.02850342e-01,  -2.02850342e-01],
                        [ -1.79473877e-01,  -1.79473877e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.52679443e-01,   1.52679443e-01],
                        [  1.81793213e-01,   1.81793213e-01],
                        [  1.84112549e-01,   1.84112549e-01],
                        [  1.66107178e-01,   1.66107178e-01],
                        [  1.44256592e-01,   1.44256592e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.25579834e-01,   1.25579834e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -1.56280518e-01,  -1.56280518e-01],
                        [ -2.22473145e-01,  -2.22473145e-01],
                        [ -2.58483887e-01,  -2.58483887e-01],
                        [ -2.50793457e-01,  -2.50793457e-01],
                        [ -2.06115723e-01,  -2.06115723e-01],
                        [ -1.53381348e-01,  -1.53381348e-01],
                        [ -1.20483398e-01,  -1.20483398e-01],
                        [ -1.08795166e-01,  -1.08795166e-01],
                        [ -1.00585938e-01,  -1.00585938e-01],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -7.39135742e-02,  -7.39135742e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  5.56030273e-02,   5.56030273e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  8.03527832e-02,   8.03527832e-02],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.30004883e-01,   1.30004883e-01],
                        [  1.13677979e-01,   1.13677979e-01],
                        [  6.82678223e-02,   6.82678223e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.01104736e-01,  -1.01104736e-01],
                        [ -1.78863525e-01,  -1.78863525e-01],
                        [ -2.07763672e-01,  -2.07763672e-01],
                        [ -1.79443359e-01,  -1.79443359e-01],
                        [ -1.19201660e-01,  -1.19201660e-01],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.43707275e-01,   1.43707275e-01],
                        [  1.64367676e-01,   1.64367676e-01],
                        [  1.65893555e-01,   1.65893555e-01],
                        [  1.55212402e-01,   1.55212402e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.40441895e-01,   1.40441895e-01],
                        [  1.36810303e-01,   1.36810303e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  1.16577148e-01,   1.16577148e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.17980957e-01,   1.17980957e-01],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -2.63061523e-02,  -2.63061523e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -2.16064453e-02,  -2.16064453e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -8.41369629e-02,  -8.41369629e-02],
                        [ -1.63696289e-01,  -1.63696289e-01],
                        [ -2.30651855e-01,  -2.30651855e-01],
                        [ -2.59643555e-01,  -2.59643555e-01],
                        [ -2.39898682e-01,  -2.39898682e-01],
                        [ -1.86340332e-01,  -1.86340332e-01],
                        [ -1.32629395e-01,  -1.32629395e-01],
                        [ -1.05590820e-01,  -1.05590820e-01],
                        [ -1.04370117e-01,  -1.04370117e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -8.93554688e-02,  -8.93554688e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  9.95788574e-02,   9.95788574e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -1.62200928e-01,  -1.62200928e-01],
                        [ -1.74316406e-01,  -1.74316406e-01],
                        [ -1.42852783e-01,  -1.42852783e-01],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.58233643e-01,   1.58233643e-01],
                        [  1.79138184e-01,   1.79138184e-01],
                        [  1.74530029e-01,   1.74530029e-01],
                        [  1.53350830e-01,   1.53350830e-01],
                        [  1.30798340e-01,   1.30798340e-01],
                        [  1.19445801e-01,   1.19445801e-01],
                        [  1.20880127e-01,   1.20880127e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.19842529e-01,   1.19842529e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  9.92431641e-02,   9.92431641e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  9.04235840e-02,   9.04235840e-02],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  7.00683594e-02,   7.00683594e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -1.44866943e-01,  -1.44866943e-01],
                        [ -2.25921631e-01,  -2.25921631e-01],
                        [ -2.75451660e-01,  -2.75451660e-01],
                        [ -2.76519775e-01,  -2.76519775e-01],
                        [ -2.37030029e-01,  -2.37030029e-01],
                        [ -1.84967041e-01,  -1.84967041e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -1.18194580e-01,  -1.18194580e-01],
                        [ -9.72595215e-02,  -9.72595215e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -1.20941162e-01,  -1.20941162e-01],
                        [ -1.66198730e-01,  -1.66198730e-01],
                        [ -1.63848877e-01,  -1.63848877e-01],
                        [ -1.29058838e-01,  -1.29058838e-01],
                        [ -9.07897949e-02,  -9.07897949e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  1.62902832e-01,   1.62902832e-01],
                        [  1.91406250e-01,   1.91406250e-01],
                        [  1.98272705e-01,   1.98272705e-01],
                        [  1.81518555e-01,   1.81518555e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.02569580e-01,   1.02569580e-01],
                        [  8.74023438e-02,   8.74023438e-02],
                        [  7.21435547e-02,   7.21435547e-02],
                        [  5.84106445e-02,   5.84106445e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -6.87866211e-02,  -6.87866211e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  1.14624023e-01,   1.14624023e-01],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -1.18896484e-01,  -1.18896484e-01],
                        [ -2.01416016e-01,  -2.01416016e-01],
                        [ -2.60498047e-01,  -2.60498047e-01],
                        [ -2.75970459e-01,  -2.75970459e-01],
                        [ -2.47406006e-01,  -2.47406006e-01],
                        [ -1.94610596e-01,  -1.94610596e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -1.12792969e-01,  -1.12792969e-01],
                        [ -9.78393555e-02,  -9.78393555e-02],
                        [ -8.84094238e-02,  -8.84094238e-02],
                        [ -7.90100098e-02,  -7.90100098e-02],
                        [ -7.18078613e-02,  -7.18078613e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.00860596e-01,  -1.00860596e-01],
                        [ -1.55883789e-01,  -1.55883789e-01],
                        [ -1.70043945e-01,  -1.70043945e-01],
                        [ -1.43310547e-01,  -1.43310547e-01],
                        [ -9.65881348e-02,  -9.65881348e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  1.42456055e-01,   1.42456055e-01],
                        [  1.70257568e-01,   1.70257568e-01],
                        [  1.75262451e-01,   1.75262451e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.08734131e-01,   1.08734131e-01],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  9.36279297e-02,   9.36279297e-02],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  1.08123779e-01,   1.08123779e-01],
                        [  1.15905762e-01,   1.15905762e-01],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -1.42303467e-01,  -1.42303467e-01],
                        [ -2.17437744e-01,  -2.17437744e-01],
                        [ -2.65441895e-01,  -2.65441895e-01],
                        [ -2.70843506e-01,  -2.70843506e-01],
                        [ -2.35443115e-01,  -2.35443115e-01],
                        [ -1.80084229e-01,  -1.80084229e-01],
                        [ -1.31042480e-01,  -1.31042480e-01],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -9.51538086e-02,  -9.51538086e-02],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -8.83178711e-02,  -8.83178711e-02],
                        [ -7.72094727e-02,  -7.72094727e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  6.84814453e-02,   6.84814453e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.21215820e-01,   1.21215820e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -1.22375488e-01,  -1.22375488e-01],
                        [ -1.71234131e-01,  -1.71234131e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -9.44824219e-02,  -9.44824219e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  1.19934082e-01,   1.19934082e-01],
                        [  1.72058105e-01,   1.72058105e-01],
                        [  2.03155518e-01,   2.03155518e-01],
                        [  2.01202393e-01,   2.01202393e-01],
                        [  1.70806885e-01,   1.70806885e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  8.64868164e-02,   8.64868164e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  1.19537354e-01,   1.19537354e-01],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  4.78515625e-02,   4.78515625e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -5.98449707e-02,  -5.98449707e-02],
                        [ -1.36962891e-01,  -1.36962891e-01],
                        [ -2.11242676e-01,  -2.11242676e-01],
                        [ -2.58361816e-01,  -2.58361816e-01],
                        [ -2.64038086e-01,  -2.64038086e-01],
                        [ -2.34558105e-01,  -2.34558105e-01],
                        [ -1.91619873e-01,  -1.91619873e-01],
                        [ -1.53503418e-01,  -1.53503418e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -9.97009277e-02,  -9.97009277e-02],
                        [ -8.10852051e-02,  -8.10852051e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -6.06994629e-02,  -6.07299805e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  7.39746094e-02,   7.39746094e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  1.17553711e-01,   1.17553711e-01],
                        [  1.10321045e-01,   1.10321045e-01],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -1.50329590e-01,  -1.50329590e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.64398193e-01,  -1.64398193e-01],
                        [ -1.21765137e-01,  -1.21765137e-01],
                        [ -8.28247070e-02,  -8.28247070e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  1.13250732e-01,   1.13250732e-01],
                        [  1.62322998e-01,   1.62322998e-01],
                        [  1.92871094e-01,   1.92871094e-01],
                        [  1.97174072e-01,   1.97174072e-01],
                        [  1.78588867e-01,   1.78558350e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.16760254e-01,   1.16790771e-01],
                        [  8.95385742e-02,   8.95385742e-02],
                        [  7.04956055e-02,   7.04650879e-02],
                        [  6.19506836e-02,   6.19201660e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  6.11572266e-02,   6.11877441e-02],
                        [  4.43725586e-02,   4.43420410e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [  1.81274414e-02,   1.81579590e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [  8.05664062e-03,   8.02612305e-03],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  9.97619629e-02,   9.97924805e-02],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -1.93176270e-02,  -1.92871094e-02],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -2.86254883e-02,  -2.86560059e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  2.81982422e-02,   2.81677246e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  4.46472168e-02,   4.46472168e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [ -2.68859863e-02,  -2.69165039e-02],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -1.67083740e-01,  -1.67083740e-01],
                        [ -2.26654053e-01,  -2.26654053e-01],
                        [ -2.47924805e-01,  -2.47955322e-01],
                        [ -2.30682373e-01,  -2.30682373e-01],
                        [ -1.93969727e-01,  -1.93969727e-01],
                        [ -1.57440186e-01,  -1.57440186e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -1.12213135e-01,  -1.12213135e-01],
                        [ -9.66796875e-02,  -9.66796875e-02],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -3.32031250e-02,  -3.32336426e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.98364258e-03,  -1.95312500e-03],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  7.94372559e-02,   7.94677734e-02],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  1.15234375e-01,   1.15234375e-01],
                        [  1.31439209e-01,   1.31439209e-01],
                        [  1.30340576e-01,   1.30371094e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [ -8.12683105e-02,  -8.12683105e-02],
                        [ -1.62506104e-01,  -1.62506104e-01],
                        [ -1.98944092e-01,  -1.98944092e-01],
                        [ -1.84936523e-01,  -1.84936523e-01],
                        [ -1.42791748e-01,  -1.42791748e-01],
                        [ -1.00402832e-01,  -1.00402832e-01],
                        [ -7.00988770e-02,  -7.00683594e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.59594727e-02,  -4.59289551e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.52160645e-01,   1.52160645e-01],
                        [  1.72241211e-01,   1.72241211e-01],
                        [  1.67907715e-01,   1.67877197e-01],
                        [  1.46331787e-01,   1.46331787e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  9.60388184e-02,   9.60388184e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  9.02709961e-02,   9.02404785e-02],
                        [  7.93762207e-02,   7.93457031e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  5.78002930e-02,   5.77697754e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.88183594e-02,   3.88488770e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  2.76489258e-02,   2.76794434e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -1.89208984e-02,  -1.89514160e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.90625000e-02,  -3.90319824e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.04663086e-02,  -4.04968262e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.60107422e-02,  -3.59802246e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.06799316e-02,  -4.07104492e-02],
                        [ -4.21752930e-02,  -4.22058105e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [  1.00708008e-03,   1.03759766e-03],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  4.69055176e-02,   4.68750000e-02],
                        [  5.69458008e-02,   5.69152832e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  1.29089355e-02,   1.29394531e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -1.22741699e-01,  -1.22741699e-01],
                        [ -1.97082520e-01,  -1.97113037e-01],
                        [ -2.47833252e-01,  -2.47833252e-01],
                        [ -2.62207031e-01,  -2.62176514e-01],
                        [ -2.43682861e-01,  -2.43682861e-01],
                        [ -2.07733154e-01,  -2.07794189e-01],
                        [ -1.69769287e-01,  -1.69799805e-01],
                        [ -1.36505127e-01,  -1.36474609e-01],
                        [ -1.08886719e-01,  -1.08856201e-01],
                        [ -8.85009766e-02,  -8.85314941e-02],
                        [ -7.72399902e-02,  -7.72705078e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -3.57971191e-02,  -3.57666016e-02],
                        [ -1.80053711e-02,  -1.80358887e-02],
                        [  7.62939453e-04,   7.01904297e-04],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  2.58483887e-02,   2.59094238e-02],
                        [  2.94799805e-02,   2.95104980e-02],
                        [  3.31726074e-02,   3.31420898e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  5.47485352e-02,   5.47790527e-02],
                        [  7.68127441e-02,   7.68432617e-02],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.30584717e-01,   1.30584717e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  8.51135254e-02,   8.51440430e-02],
                        [  1.02539062e-02,   1.02844238e-02],
                        [ -7.98950195e-02,  -7.99255371e-02],
                        [ -1.57958984e-01,  -1.58020020e-01],
                        [ -1.95434570e-01,  -1.95434570e-01],
                        [ -1.82067871e-01,  -1.82006836e-01],
                        [ -1.35314941e-01,  -1.35314941e-01],
                        [ -8.75244141e-02,  -8.75854492e-02],
                        [ -6.28662109e-02,  -6.28967285e-02],
                        [ -6.27746582e-02,  -6.27441406e-02],
                        [ -7.07092285e-02,  -7.06787109e-02],
                        [ -7.13806152e-02,  -7.14111328e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -1.71203613e-02,  -1.70898438e-02],
                        [  3.13415527e-02,   3.13720703e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  1.49536133e-01,   1.49505615e-01],
                        [  1.83258057e-01,   1.83227539e-01],
                        [  1.88995361e-01,   1.89025879e-01],
                        [  1.72607422e-01,   1.72668457e-01],
                        [  1.47094727e-01,   1.47064209e-01],
                        [  1.23535156e-01,   1.23474121e-01],
                        [  1.05316162e-01,   1.05346680e-01],
                        [  9.18273926e-02,   9.18579102e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  8.43811035e-02,   8.43505859e-02],
                        [  8.97216797e-02,   8.96911621e-02],
                        [  9.34448242e-02,   9.34753418e-02],
                        [  9.10339355e-02,   9.10644531e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  7.77893066e-02,   7.77893066e-02],
                        [  7.32421875e-02,   7.32116699e-02],
                        [  6.67724609e-02,   6.67419434e-02],
                        [  5.67932129e-02,   5.68237305e-02],
                        [  4.71496582e-02,   4.72106934e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  3.12805176e-02,   3.11889648e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  5.15747070e-03,   5.24902344e-03],
                        [ -1.98364258e-03,  -1.92260742e-03],
                        [ -7.96508789e-03,  -8.02612305e-03],
                        [ -1.81884766e-02,  -1.82495117e-02],
                        [ -2.89611816e-02,  -2.89306641e-02],
                        [ -3.43017578e-02,  -3.42407227e-02],
                        [ -3.17687988e-02,  -3.17993164e-02],
                        [ -1.75781250e-02,  -1.76086426e-02],
                        [  1.29699707e-02,   1.29394531e-02],
                        [  5.58471680e-02,   5.58471680e-02],
                        [  9.51843262e-02,   9.52148438e-02],
                        [  1.12915039e-01,   1.12945557e-01],
                        [  1.03088379e-01,   1.03057861e-01],
                        [  7.69348145e-02,   7.68737793e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  3.86047363e-02,   3.86657715e-02],
                        [  3.16772461e-02,   3.17077637e-02],
                        [  2.51770020e-02,   2.51159668e-02],
                        [  1.98364258e-02,   1.98059082e-02],
                        [  1.90734863e-02,   1.91345215e-02],
                        [  2.04467773e-02,   2.05383301e-02],
                        [  1.84936523e-02,   1.84631348e-02],
                        [  1.20849609e-02,   1.19934082e-02],
                        [  4.30297852e-03,   4.27246094e-03],
                        [ -2.83813477e-03,  -2.77709961e-03],
                        [ -9.70458984e-03,  -9.67407227e-03],
                        [ -1.73339844e-02,  -1.73645020e-02],
                        [ -2.60620117e-02,  -2.60925293e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -4.13208008e-02,  -4.12902832e-02],
                        [ -4.28161621e-02,  -4.27856445e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.15246582e-02,  -3.15551758e-02],
                        [ -2.56042480e-02,  -2.56347656e-02],
                        [ -2.21557617e-02,  -2.20947266e-02],
                        [ -1.95617676e-02,  -1.95312500e-02],
                        [ -1.92260742e-02,  -1.92871094e-02],
                        [ -2.46276855e-02,  -2.46887207e-02],
                        [ -3.44543457e-02,  -3.44238281e-02],
                        [ -4.11376953e-02,  -4.11071777e-02],
                        [ -3.78723145e-02,  -3.79028320e-02],
                        [ -2.50854492e-02,  -2.51159668e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  1.27563477e-02,   1.27868652e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  5.45349121e-02,   5.45043945e-02],
                        [  6.82373047e-02,   6.82678223e-02],
                        [  6.91528320e-02,   6.91833496e-02],
                        [  4.90722656e-02,   4.90112305e-02],
                        [  1.98364258e-03,   1.95312500e-03],
                        [ -7.04345703e-02,  -7.03735352e-02],
                        [ -1.55120850e-01,  -1.55090332e-01],
                        [ -2.28393555e-01,  -2.28485107e-01],
                        [ -2.66998291e-01,  -2.67059326e-01],
                        [ -2.62878418e-01,  -2.62817383e-01],
                        [ -2.27630615e-01,  -2.27569580e-01],
                        [ -1.83013916e-01,  -1.83044434e-01],
                        [ -1.46209717e-01,  -1.46270752e-01],
                        [ -1.21795654e-01,  -1.21795654e-01],
                        [ -1.05255127e-01,  -1.05224609e-01],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -7.33032227e-02,  -7.33337402e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -4.13818359e-02,  -4.14123535e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -1.84631348e-02,  -1.84326172e-02],
                        [  2.50244141e-03,   2.53295898e-03],
                        [  2.76184082e-02,   2.75878906e-02],
                        [  4.41894531e-02,   4.41284180e-02],
                        [  4.69360352e-02,   4.69665527e-02],
                        [  4.32434082e-02,   4.33044434e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  4.48608398e-02,   4.47998047e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  6.51550293e-02,   6.52160645e-02],
                        [  8.60595703e-02,   8.60900879e-02],
                        [  1.10046387e-01,   1.10015869e-01],
                        [  1.28051758e-01,   1.28021240e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  9.86938477e-02,   9.87548828e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [ -5.06896973e-02,  -5.07202148e-02],
                        [ -1.27777100e-01,  -1.27807617e-01],
                        [ -1.69952393e-01,  -1.69891357e-01],
                        [ -1.69281006e-01,  -1.69250488e-01],
                        [ -1.40472412e-01,  -1.40502930e-01],
                        [ -1.07543945e-01,  -1.07604980e-01],
                        [ -8.56933594e-02,  -8.56933594e-02],
                        [ -7.49206543e-02,  -7.48596191e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -6.31713867e-02,  -6.32324219e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -4.22363281e-02,  -4.21752930e-02],
                        [ -1.24816895e-02,  -1.24206543e-02],
                        [  3.36303711e-02,   3.35693359e-02],
                        [  8.56018066e-02,   8.55407715e-02],
                        [  1.29425049e-01,   1.29486084e-01],
                        [  1.56890869e-01,   1.56951904e-01],
                        [  1.66595459e-01,   1.66564941e-01],
                        [  1.61956787e-01,   1.61865234e-01],
                        [  1.50115967e-01,   1.50146484e-01],
                        [  1.38549805e-01,   1.38610840e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.19262695e-01,   1.19232178e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.58459473e-02,   8.58459473e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  8.01086426e-02,   8.01391602e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  6.46057129e-02,   6.45751953e-02],
                        [  5.63964844e-02,   5.63659668e-02],
                        [  5.22460938e-02,   5.23071289e-02],
                        [  4.70275879e-02,   4.70581055e-02],
                        [  3.60107422e-02,   3.59497070e-02],
                        [  2.39562988e-02,   2.38952637e-02],
                        [  1.94091797e-02,   1.94396973e-02],
                        [  2.36816406e-02,   2.37121582e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.62145996e-02,   2.61535645e-02],
                        [  1.25732422e-02,   1.25427246e-02],
                        [ -8.85009766e-03,  -8.81958008e-03],
                        [ -2.85644531e-02,  -2.85034180e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -2.49633789e-02,  -2.49938965e-02],
                        [ -3.78417969e-03,  -3.81469727e-03],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  5.38330078e-02,   5.38635254e-02],
                        [  7.76672363e-02,   7.76977539e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  6.84814453e-02,   6.84509277e-02],
                        [  4.43725586e-02,   4.43420410e-02],
                        [  2.75268555e-02,   2.75573730e-02],
                        [  2.46887207e-02,   2.47497559e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  3.29895020e-02,   3.29284668e-02],
                        [  2.99072266e-02,   2.98767090e-02],
                        [  2.37426758e-02,   2.37731934e-02],
                        [  2.02941895e-02,   2.03552246e-02],
                        [  2.04772949e-02,   2.05078125e-02],
                        [  1.90734863e-02,   1.90124512e-02],
                        [  9.97924805e-03,   9.91821289e-03],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -2.87475586e-02,  -2.86865234e-02],
                        [ -4.48303223e-02,  -4.47998047e-02],
                        [ -5.10559082e-02,  -5.11169434e-02],
                        [ -4.84924316e-02,  -4.86145020e-02],
                        [ -4.16259766e-02,  -4.15954590e-02],
                        [ -3.43627930e-02,  -3.42102051e-02],
                        [ -2.80761719e-02,  -2.80456543e-02],
                        [ -2.26135254e-02,  -2.27355957e-02],
                        [ -1.84326172e-02,  -1.85241699e-02],
                        [ -1.61743164e-02,  -1.60827637e-02],
                        [ -1.54418945e-02,  -1.52893066e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.52685547e-02,  -2.53906250e-02],
                        [ -3.72314453e-02,  -3.73229980e-02],
                        [ -4.65393066e-02,  -4.64477539e-02],
                        [ -4.72412109e-02,  -4.71191406e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -2.17590332e-02,  -2.19116211e-02],
                        [ -4.51660156e-03,  -4.60815430e-03],
                        [  1.10168457e-02,   1.11083984e-02],
                        [  2.67028809e-02,   2.68249512e-02],
                        [  4.38842773e-02,   4.38537598e-02],
                        [  5.72204590e-02,   5.70678711e-02],
                        [  5.55419922e-02,   5.55114746e-02],
                        [  2.96630859e-02,   2.97851562e-02],
                        [ -2.28271484e-02,  -2.27355957e-02],
                        [ -9.74731445e-02,  -9.75036621e-02],
                        [ -1.79382324e-01,  -1.79473877e-01],
                        [ -2.43804932e-01,  -2.43835449e-01],
                        [ -2.70629883e-01,  -2.70568848e-01],
                        [ -2.58209229e-01,  -2.58178711e-01],
                        [ -2.21618652e-01,  -2.21618652e-01],
                        [ -1.80541992e-01,  -1.80603027e-01],
                        [ -1.47277832e-01,  -1.47338867e-01],
                        [ -1.22680664e-01,  -1.22650146e-01],
                        [ -1.01928711e-01,  -1.01867676e-01],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -6.25305176e-02,  -6.25915527e-02],
                        [ -4.55322266e-02,  -4.55627441e-02],
                        [ -3.02124023e-02,  -3.01818848e-02],
                        [ -1.47094727e-02,  -1.46789551e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [  1.36108398e-02,   1.35803223e-02],
                        [  2.22473145e-02,   2.22167969e-02],
                        [  2.65502930e-02,   2.65197754e-02],
                        [  2.83813477e-02,   2.84118652e-02],
                        [  3.11584473e-02,   3.11889648e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.62646484e-02,   4.62036133e-02],
                        [  5.40466309e-02,   5.40161133e-02],
                        [  6.28662109e-02,   6.28967285e-02],
                        [  8.12683105e-02,   8.13293457e-02],
                        [  1.10748291e-01,   1.10717773e-01],
                        [  1.36138916e-01,   1.36077881e-01],
                        [  1.35711670e-01,   1.35681152e-01],
                        [  9.69543457e-02,   9.69848633e-02],
                        [  2.23083496e-02,   2.23693848e-02],
                        [ -7.08618164e-02,  -7.08923340e-02],
                        [ -1.52618408e-01,  -1.52709961e-01],
                        [ -1.93481445e-01,  -1.93481445e-01],
                        [ -1.84387207e-01,  -1.84326172e-01],
                        [ -1.43829346e-01,  -1.43829346e-01],
                        [ -1.01959229e-01,  -1.01989746e-01],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -3.06091309e-02,  -3.05786133e-02],
                        [ -7.62939453e-03,  -7.59887695e-03],
                        [  2.50549316e-02,   2.49938965e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  1.12945557e-01,   1.13037109e-01],
                        [  1.50878906e-01,   1.50939941e-01],
                        [  1.67968750e-01,   1.67877197e-01],
                        [  1.60339355e-01,   1.60278320e-01],
                        [  1.39343262e-01,   1.39434814e-01],
                        [  1.21856689e-01,   1.21948242e-01],
                        [  1.14288330e-01,   1.14227295e-01],
                        [  1.10900879e-01,   1.10809326e-01],
                        [  1.04125977e-01,   1.04156494e-01],
                        [  9.28649902e-02,   9.29565430e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  7.52258301e-02,   7.51342773e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  7.00988770e-02,   7.01599121e-02],
                        [  6.75354004e-02,   6.75659180e-02],
                        [  6.21337891e-02,   6.21032715e-02],
                        [  5.38024902e-02,   5.37719727e-02],
                        [  4.65698242e-02,   4.66003418e-02],
                        [  4.44030762e-02,   4.44641113e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.66918945e-02,   4.66003418e-02],
                        [  4.23583984e-02,   4.23278809e-02],
                        [  3.54003906e-02,   3.54614258e-02],
                        [  2.77099609e-02,   2.78015137e-02],
                        [  1.55944824e-02,   1.55334473e-02],
                        [ -5.09643555e-03,  -5.18798828e-03],
                        [ -2.98461914e-02,  -2.98156738e-02],
                        [ -4.63562012e-02,  -4.62646484e-02],
                        [ -4.48913574e-02,  -4.48608398e-02],
                        [ -2.49328613e-02,  -2.50549316e-02],
                        [  7.69042969e-03,   7.62939453e-03],
                        [  4.51354980e-02,   4.52270508e-02],
                        [  7.71789551e-02,   7.72399902e-02],
                        [  9.39025879e-02,   9.38720703e-02],
                        [  9.24987793e-02,   9.24377441e-02],
                        [  7.73315430e-02,   7.73315430e-02],
                        [  5.57250977e-02,   5.57556152e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.69470215e-02,   2.68859863e-02],
                        [  2.13928223e-02,   2.13623047e-02],
                        [  1.40380859e-02,   1.41296387e-02],
                        [  1.29089355e-02,   1.29699707e-02],
                        [  1.71508789e-02,   1.70593262e-02],
                        [  1.65100098e-02,   1.64184570e-02],
                        [  4.91333008e-03,   5.00488281e-03],
                        [ -1.22375488e-02,  -1.21154785e-02],
                        [ -2.63366699e-02,  -2.63977051e-02],
                        [ -3.40270996e-02,  -3.41491699e-02],
                        [ -3.45153809e-02,  -3.44543457e-02],
                        [ -2.83813477e-02,  -2.82897949e-02],
                        [ -2.20336914e-02,  -2.20642090e-02],
                        [ -2.35595703e-02,  -2.36511230e-02],
                        [ -3.04565430e-02,  -3.04260254e-02],
                        [ -3.11279297e-02,  -3.10974121e-02],
                        [ -2.25830078e-02,  -2.26440430e-02],
                        [ -1.50451660e-02,  -1.50756836e-02],
                        [ -1.61132812e-02,  -1.60522461e-02],
                        [ -2.34680176e-02,  -2.34375000e-02],
                        [ -3.34167480e-02,  -3.35083008e-02],
                        [ -4.39758301e-02,  -4.40368652e-02],
                        [ -5.08728027e-02,  -5.07507324e-02],
                        [ -4.88586426e-02,  -4.87976074e-02],
                        [ -3.63159180e-02,  -3.64074707e-02],
                        [ -1.52282715e-02,  -1.53198242e-02],
                        [  1.11694336e-02,   1.11999512e-02],
                        [  3.98864746e-02,   3.99780273e-02],
                        [  6.66809082e-02,   6.67114258e-02],
                        [  8.36791992e-02,   8.36181641e-02],
                        [  8.06884766e-02,   8.06274414e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [ -1.23291016e-02,  -1.22375488e-02],
                        [ -9.69543457e-02,  -9.69238281e-02],
                        [ -1.87347412e-01,  -1.87377930e-01],
                        [ -2.59582520e-01,  -2.59704590e-01],
                        [ -2.90618896e-01,  -2.90618896e-01],
                        [ -2.70660400e-01,  -2.70538330e-01],
                        [ -2.14263916e-01,  -2.14202881e-01],
                        [ -1.55273438e-01,  -1.55426025e-01],
                        [ -1.21246338e-01,  -1.21368408e-01],
                        [ -1.10595703e-01,  -1.10504150e-01],
                        [ -1.02020264e-01,  -1.01867676e-01],
                        [ -8.38012695e-02,  -8.38623047e-02],
                        [ -6.32019043e-02,  -6.33544922e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -4.29992676e-02,  -4.28771973e-02],
                        [ -3.64685059e-02,  -3.64379883e-02],
                        [ -2.53295898e-02,  -2.53906250e-02],
                        [ -8.54492188e-03,  -8.60595703e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  2.77709961e-02,   2.78320312e-02],
                        [  3.95812988e-02,   3.96728516e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  4.33654785e-02,   4.32128906e-02],
                        [  3.75976562e-02,   3.75061035e-02],
                        [  3.66210938e-02,   3.67736816e-02],
                        [  4.92858887e-02,   4.94079590e-02],
                        [  7.51647949e-02,   7.50732422e-02],
                        [  1.04736328e-01,   1.04583740e-01],
                        [  1.26678467e-01,   1.26708984e-01],
                        [  1.30859375e-01,   1.31042480e-01],
                        [  1.07482910e-01,   1.07513428e-01],
                        [  5.26733398e-02,   5.25207520e-02],
                        [ -2.41699219e-02,  -2.42309570e-02],
                        [ -1.01501465e-01,  -1.01440430e-01],
                        [ -1.55426025e-01,  -1.55364990e-01],
                        [ -1.72576904e-01,  -1.72576904e-01],
                        [ -1.57928467e-01,  -1.57958984e-01],
                        [ -1.30187988e-01,  -1.30249023e-01],
                        [ -1.08276367e-01,  -1.08306885e-01],
                        [ -9.90600586e-02,  -9.89990234e-02],
                        [ -9.39941406e-02,  -9.39025879e-02],
                        [ -7.90710449e-02,  -7.91015625e-02],
                        [ -4.73327637e-02,  -4.74548340e-02],
                        [ -3.66210938e-04,  -3.96728516e-04],
                        [  5.63049316e-02,   5.64270020e-02],
                        [  1.12579346e-01,   1.12640381e-01],
                        [  1.53137207e-01,   1.53076172e-01],
                        [  1.66320801e-01,   1.66229248e-01],
                        [  1.55944824e-01,   1.55975342e-01],
                        [  1.38183594e-01,   1.38275146e-01],
                        [  1.24725342e-01,   1.24755859e-01],
                        [  1.15783691e-01,   1.15692139e-01],
                        [  1.08093262e-01,   1.08062744e-01],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  9.19799805e-02,   9.20104980e-02],
                        [  8.34655762e-02,   8.34960938e-02],
                        [  7.67211914e-02,   7.67822266e-02],
                        [  7.22045898e-02,   7.21435547e-02],
                        [  6.75354004e-02,   6.74133301e-02],
                        [  6.12182617e-02,   6.12792969e-02],
                        [  5.52062988e-02,   5.53588867e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  4.67529297e-02,   4.65698242e-02],
                        [  4.11987305e-02,   4.11682129e-02],
                        [  3.99780273e-02,   4.01306152e-02],
                        [  4.68139648e-02,   4.69055176e-02],
                        [  5.48400879e-02,   5.47180176e-02],
                        [  5.37719727e-02,   5.36804199e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  2.38037109e-02,   2.38647461e-02],
                        [  3.38745117e-03,   3.44848633e-03],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -3.21655273e-02,  -3.22265625e-02],
                        [ -4.22058105e-02,  -4.22973633e-02],
                        [ -4.35485840e-02,  -4.34875488e-02],
                        [ -2.96325684e-02,  -2.95104980e-02],
                        [  2.56347656e-03,   2.53295898e-03],
                        [  4.34265137e-02,   4.32739258e-02],
                        [  7.61108398e-02,   7.61108398e-02],
                        [  8.91418457e-02,   8.92639160e-02],
                        [  7.99865723e-02,   8.00476074e-02],
                        [  5.49011230e-02,   5.48400879e-02],
                        [  2.92358398e-02,   2.91748047e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  2.40783691e-02,   2.41088867e-02],
                        [  3.65600586e-02,   3.66210938e-02],
                        [  4.45251465e-02,   4.45556641e-02],
                        [  4.21142578e-02,   4.20532227e-02],
                        [  3.09448242e-02,   3.08532715e-02],
                        [  1.80053711e-02,   1.80664062e-02],
                        [  9.09423828e-03,   9.24682617e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  1.40380859e-03,   1.25122070e-03],
                        [ -3.60107422e-03,  -3.66210938e-03],
                        [ -1.06811523e-02,  -1.05285645e-02],
                        [ -1.88293457e-02,  -1.87377930e-02],
                        [ -2.74353027e-02,  -2.75268555e-02],
                        [ -3.60107422e-02,  -3.61328125e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -4.40368652e-02,  -4.39147949e-02],
                        [ -3.90014648e-02,  -3.89709473e-02],
                        [ -3.17993164e-02,  -3.18908691e-02],
                        [ -2.71911621e-02,  -2.72521973e-02],
                        [ -2.64282227e-02,  -2.63671875e-02],
                        [ -2.92053223e-02,  -2.91748047e-02],
                        [ -3.38439941e-02,  -3.38745117e-02],
                        [ -3.57055664e-02,  -3.57360840e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -1.94396973e-02,  -1.94091797e-02],
                        [ -6.65283203e-03,  -6.62231445e-03],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  1.53503418e-02,   1.53198242e-02],
                        [  2.77709961e-02,   2.77099609e-02],
                        [  4.22058105e-02,   4.22363281e-02],
                        [  5.69152832e-02,   5.69458008e-02],
                        [  6.69250488e-02,   6.68945312e-02],
                        [  6.25000000e-02,   6.24389648e-02],
                        [  3.17993164e-02,   3.18298340e-02],
                        [ -3.19519043e-02,  -3.18603516e-02],
                        [ -1.23168945e-01,  -1.23199463e-01],
                        [ -2.20245361e-01,  -2.20306396e-01],
                        [ -2.90008545e-01,  -2.90008545e-01],
                        [ -3.05603027e-01,  -3.05541992e-01],
                        [ -2.66601562e-01,  -2.66571045e-01],
                        [ -2.01324463e-01,  -2.01354980e-01],
                        [ -1.45751953e-01,  -1.45782471e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -1.14440918e-01,  -1.14410400e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -6.89392090e-02,  -6.89697266e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.13110352e-02,  -3.12805176e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -1.16271973e-02,  -1.16577148e-02],
                        [  5.00488281e-03,   4.97436523e-03],
                        [  2.26440430e-02,   2.26745605e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.32031250e-02,   3.31726074e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  3.01513672e-02,   3.01818848e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  7.55004883e-02,   7.54394531e-02],
                        [  1.05987549e-01,   1.05987549e-01],
                        [  1.32904053e-01,   1.32965088e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.28723145e-01,   1.28692627e-01],
                        [  7.39135742e-02,   7.38830566e-02],
                        [ -1.27258301e-02,  -1.26647949e-02],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -1.72698975e-01,  -1.72729492e-01],
                        [ -1.95373535e-01,  -1.95404053e-01],
                        [ -1.76635742e-01,  -1.76635742e-01],
                        [ -1.39221191e-01,  -1.39160156e-01],
                        [ -1.08428955e-01,  -1.08459473e-01],
                        [ -9.39636230e-02,  -9.39636230e-02],
                        [ -8.46862793e-02,  -8.46862793e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -1.73339844e-02,  -1.73034668e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  9.17358398e-02,   9.17358398e-02],
                        [  1.28051758e-01,   1.28021240e-01],
                        [  1.44042969e-01,   1.44042969e-01],
                        [  1.43859863e-01,   1.43890381e-01],
                        [  1.35498047e-01,   1.35498047e-01],
                        [  1.25793457e-01,   1.25762939e-01],
                        [  1.18194580e-01,   1.18164062e-01],
                        [  1.12091064e-01,   1.12121582e-01],
                        [  1.04736328e-01,   1.04766846e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  8.48083496e-02,   8.47778320e-02],
                        [  7.44018555e-02,   7.43408203e-02],
                        [  6.24084473e-02,   6.23779297e-02],
                        [  4.80041504e-02,   4.80346680e-02],
                        [  3.50646973e-02,   3.51257324e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  3.42102051e-02,   3.41186523e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  4.99267578e-02,   5.00488281e-02],
                        [  5.34362793e-02,   5.34973145e-02],
                        [  5.41687012e-02,   5.40771484e-02],
                        [  5.54199219e-02,   5.53283691e-02],
                        [  5.96923828e-02,   5.97229004e-02],
                        [  6.39648438e-02,   6.40869141e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  4.26025391e-02,   4.25109863e-02],
                        [  1.11694336e-02,   1.11083984e-02],
                        [ -2.44750977e-02,  -2.44140625e-02],
                        [ -5.10864258e-02,  -5.09948730e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -5.61218262e-02,  -5.62133789e-02],
                        [ -3.72314453e-02,  -3.72924805e-02],
                        [ -3.47900391e-03,  -3.44848633e-03],
                        [  4.08020020e-02,   4.08935547e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  9.86633301e-02,   9.86022949e-02],
                        [  9.03015137e-02,   9.02404785e-02],
                        [  6.61926270e-02,   6.62231445e-02],
                        [  4.39147949e-02,   4.39758301e-02],
                        [  3.48815918e-02,   3.49121094e-02],
                        [  3.68957520e-02,   3.68347168e-02],
                        [  4.00390625e-02,   3.99780273e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.38745117e-02,   3.39355469e-02],
                        [  2.54821777e-02,   2.55126953e-02],
                        [  1.30920410e-02,   1.30615234e-02],
                        [ -1.15966797e-03,  -1.22070312e-03],
                        [ -1.15661621e-02,  -1.15966797e-02],
                        [ -1.25122070e-02,  -1.24206543e-02],
                        [ -4.33349609e-03,  -4.24194336e-03],
                        [  3.44848633e-03,   3.38745117e-03],
                        [ -3.35693359e-04,  -4.88281250e-04],
                        [ -1.56860352e-02,  -1.56555176e-02],
                        [ -3.05786133e-02,  -3.03955078e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -3.87878418e-02,  -3.89404297e-02],
                        [ -4.33959961e-02,  -4.34570312e-02],
                        [ -4.78515625e-02,  -4.76989746e-02],
                        [ -4.66613770e-02,  -4.66003418e-02],
                        [ -4.08630371e-02,  -4.09545898e-02],
                        [ -3.44848633e-02,  -3.45153809e-02],
                        [ -2.74963379e-02,  -2.74047852e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -6.50024414e-03,  -6.59179688e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  1.92565918e-02,   1.93481445e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  5.52978516e-02,   5.51757812e-02],
                        [  6.60705566e-02,   6.60400391e-02],
                        [  6.98852539e-02,   7.00073242e-02],
                        [  6.72912598e-02,   6.73522949e-02],
                        [  5.20629883e-02,   5.19714355e-02],
                        [  1.30310059e-02,   1.29394531e-02],
                        [ -5.47180176e-02,  -5.46875000e-02],
                        [ -1.41143799e-01,  -1.41052246e-01],
                        [ -2.23205566e-01,  -2.23205566e-01],
                        [ -2.75665283e-01,  -2.75756836e-01],
                        [ -2.85186768e-01,  -2.85186768e-01],
                        [ -2.56561279e-01,  -2.56500244e-01],
                        [ -2.07977295e-01,  -2.07977295e-01],
                        [ -1.60247803e-01,  -1.60278320e-01],
                        [ -1.26281738e-01,  -1.26251221e-01],
                        [ -1.06018066e-01,  -1.05957031e-01],
                        [ -9.22241211e-02,  -9.22851562e-02],
                        [ -7.98339844e-02,  -7.98950195e-02],
                        [ -6.64978027e-02,  -6.64367676e-02],
                        [ -5.01403809e-02,  -5.00183105e-02],
                        [ -3.21350098e-02,  -3.21655273e-02],
                        [ -1.73645020e-02,  -1.74865723e-02],
                        [ -6.77490234e-03,  -6.80541992e-03],
                        [  4.21142578e-03,   4.36401367e-03],
                        [  1.69677734e-02,   1.70288086e-02],
                        [  2.56652832e-02,   2.55432129e-02],
                        [  2.56958008e-02,   2.55737305e-02],
                        [  2.09655762e-02,   2.10266113e-02],
                        [  1.95007324e-02,   1.96228027e-02],
                        [  2.42309570e-02,   2.42919922e-02],
                        [  3.17687988e-02,   3.16772461e-02],
                        [  3.93981934e-02,   3.93066406e-02],
                        [  5.07812500e-02,   5.08117676e-02],
                        [  7.15332031e-02,   7.16552734e-02],
                        [  1.01104736e-01,   1.01165771e-01],
                        [  1.30828857e-01,   1.30767822e-01],
                        [  1.49475098e-01,   1.49353027e-01],
                        [  1.46911621e-01,   1.46911621e-01],
                        [  1.13647461e-01,   1.13769531e-01],
                        [  4.44946289e-02,   4.45861816e-02],
                        [ -5.14221191e-02,  -5.15136719e-02],
                        [ -1.47064209e-01,  -1.47186279e-01],
                        [ -2.08618164e-01,  -2.08648682e-01],
                        [ -2.16583252e-01,  -2.16461182e-01],
                        [ -1.79473877e-01,  -1.79351807e-01],
                        [ -1.25549316e-01,  -1.25640869e-01],
                        [ -7.79418945e-02,  -7.80944824e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [  2.71606445e-03,   2.89916992e-03],
                        [  5.09033203e-02,   5.09643555e-02],
                        [  9.42687988e-02,   9.41467285e-02],
                        [  1.18377686e-01,   1.18286133e-01],
                        [  1.20819092e-01,   1.20880127e-01],
                        [  1.11114502e-01,   1.11236572e-01],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  9.53979492e-02,   9.53369141e-02],
                        [  9.38415527e-02,   9.37805176e-02],
                        [  9.20104980e-02,   9.19799805e-02],
                        [  8.77990723e-02,   8.78601074e-02],
                        [  8.25500488e-02,   8.26416016e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  7.49511719e-02,   7.48291016e-02],
                        [  6.89086914e-02,   6.88476562e-02],
                        [  6.14624023e-02,   6.15844727e-02],
                        [  5.70678711e-02,   5.71899414e-02],
                        [  5.60913086e-02,   5.60302734e-02],
                        [  5.38024902e-02,   5.36499023e-02],
                        [  4.71496582e-02,   4.71496582e-02],
                        [  3.90930176e-02,   3.92456055e-02],
                        [  3.43933105e-02,   3.44543457e-02],
                        [  3.43017578e-02,   3.41796875e-02],
                        [  3.75671387e-02,   3.74755859e-02],
                        [  4.29077148e-02,   4.29687500e-02],
                        [  4.84313965e-02,   4.85229492e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  4.32128906e-02,   4.31213379e-02],
                        [  2.32238770e-02,   2.31933594e-02],
                        [ -6.53076172e-03,  -6.50024414e-03],
                        [ -3.67126465e-02,  -3.66821289e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.46667480e-02,  -6.46667480e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -2.81677246e-02,  -2.81982422e-02],
                        [  1.22070312e-02,   1.21765137e-02],
                        [  5.91735840e-02,   5.92346191e-02],
                        [  9.89685059e-02,   9.89990234e-02],
                        [  1.15203857e-01,   1.15081787e-01],
                        [  1.00830078e-01,   1.00738525e-01],
                        [  6.76879883e-02,   6.77795410e-02],
                        [  3.80554199e-02,   3.81469727e-02],
                        [  2.40478516e-02,   2.39868164e-02],
                        [  2.03552246e-02,   2.02331543e-02],
                        [  1.70898438e-02,   1.71203613e-02],
                        [  1.18713379e-02,   1.19628906e-02],
                        [  7.90405273e-03,   7.87353516e-03],
                        [  7.11059570e-03,   7.04956055e-03],
                        [  8.54492188e-03,   8.51440430e-03],
                        [  1.02539062e-02,   1.03149414e-02],
                        [  1.07116699e-02,   1.07421875e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -6.98852539e-03,  -7.01904297e-03],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.86962891e-02,  -3.86352539e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -5.06896973e-02,  -5.07202148e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -3.24401855e-02,  -3.23791504e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -1.88598633e-02,  -1.89208984e-02],
                        [ -1.98974609e-02,  -1.99279785e-02],
                        [ -2.07824707e-02,  -2.07214355e-02],
                        [ -1.71203613e-02,  -1.70898438e-02],
                        [ -9.70458984e-03,  -9.73510742e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  6.56127930e-03,   6.59179688e-03],
                        [  1.81274414e-02,   1.81579590e-02],
                        [  3.17687988e-02,   3.17382812e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  4.24194336e-02,   4.24804688e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  1.95007324e-02,   1.94396973e-02],
                        [ -1.32141113e-02,  -1.32446289e-02],
                        [ -6.40563965e-02,  -6.39648438e-02],
                        [ -1.25976562e-01,  -1.25915527e-01],
                        [ -1.85272217e-01,  -1.85394287e-01],
                        [ -2.27508545e-01,  -2.27600098e-01],
                        [ -2.41546631e-01,  -2.41424561e-01],
                        [ -2.25311279e-01,  -2.25189209e-01],
                        [ -1.92199707e-01,  -1.92321777e-01],
                        [ -1.63330078e-01,  -1.63482666e-01],
                        [ -1.47491455e-01,  -1.47430420e-01],
                        [ -1.36566162e-01,  -1.36413574e-01],
                        [ -1.21124268e-01,  -1.21154785e-01],
                        [ -1.00769043e-01,  -1.00891113e-01],
                        [ -7.89184570e-02,  -7.89489746e-02],
                        [ -5.69152832e-02,  -5.68237305e-02],
                        [ -3.62854004e-02,  -3.62243652e-02],
                        [ -2.02026367e-02,  -2.02331543e-02],
                        [ -9.42993164e-03,  -9.52148438e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.77001953e-03,   1.86157227e-03],
                        [  8.23974609e-04,   9.15527344e-04],
                        [ -4.27246094e-03,  -4.30297852e-03],
                        [ -8.85009766e-03,  -8.97216797e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  5.85937500e-03,   5.95092773e-03],
                        [  2.48718262e-02,   2.49328613e-02],
                        [  4.58374023e-02,   4.57763672e-02],
                        [  6.71997070e-02,   6.71386719e-02],
                        [  8.89587402e-02,   8.89892578e-02],
                        [  1.08856201e-01,   1.08917236e-01],
                        [  1.23229980e-01,   1.23229980e-01],
                        [  1.30401611e-01,   1.30401611e-01],
                        [  1.30737305e-01,   1.30676270e-01],
                        [  1.20300293e-01,   1.20239258e-01],
                        [  8.72802734e-02,   8.73413086e-02],
                        [  2.10571289e-02,   2.11486816e-02],
                        [ -7.18688965e-02,  -7.18994141e-02],
                        [ -1.62567139e-01,  -1.62719727e-01],
                        [ -2.14050293e-01,  -2.14050293e-01],
                        [ -2.04498291e-01,  -2.04345703e-01],
                        [ -1.43676758e-01,  -1.43615723e-01],
                        [ -6.70776367e-02,  -6.71997070e-02],
                        [ -8.23974609e-03,  -8.36181641e-03],
                        [  2.55432129e-02,   2.56347656e-02],
                        [  4.77600098e-02,   4.78820801e-02],
                        [  6.83898926e-02,   6.83593750e-02],
                        [  8.38928223e-02,   8.37402344e-02],
                        [  8.71887207e-02,   8.71582031e-02],
                        [  7.94372559e-02,   7.95288086e-02],
                        [  6.92749023e-02,   6.93054199e-02],
                        [  6.47583008e-02,   6.46972656e-02],
                        [  6.80541992e-02,   6.79931641e-02],
                        [  7.65686035e-02,   7.65380859e-02],
                        [  8.68835449e-02,   8.69140625e-02],
                        [  9.62524414e-02,   9.63134766e-02],
                        [  1.01593018e-01,   1.01623535e-01],
                        [  9.92431641e-02,   9.91516113e-02],
                        [  8.69445801e-02,   8.68530273e-02],
                        [  6.82678223e-02,   6.83288574e-02],
                        [  5.34667969e-02,   5.36193848e-02],
                        [  5.02624512e-02,   5.02319336e-02],
                        [  5.43212891e-02,   5.41381836e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.08422852e-02,   5.10253906e-02],
                        [  4.27551270e-02,   4.28161621e-02],
                        [  3.31726074e-02,   3.30505371e-02],
                        [  2.32238770e-02,   2.31628418e-02],
                        [  1.73339844e-02,   1.73950195e-02],
                        [  1.94702148e-02,   1.95312500e-02],
                        [  2.66418457e-02,   2.66113281e-02],
                        [  3.19824219e-02,   3.19213867e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.43225098e-02,   2.43530273e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.66918945e-03,  -4.69970703e-03],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  9.60388184e-02,   9.60998535e-02],
                        [  1.17218018e-01,   1.17279053e-01],
                        [  1.10778809e-01,   1.10656738e-01],
                        [  8.52966309e-02,   8.52050781e-02],
                        [  5.67016602e-02,   5.67932129e-02],
                        [  3.90930176e-02,   3.92761230e-02],
                        [  3.47595215e-02,   3.46984863e-02],
                        [  3.42102051e-02,   3.39965820e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.38037109e-02,   2.40173340e-02],
                        [  1.95922852e-02,   1.96838379e-02],
                        [  1.51062012e-02,   1.49230957e-02],
                        [  6.68334961e-03,   6.53076172e-03],
                        [ -4.97436523e-03,  -4.88281250e-03],
                        [ -1.58386230e-02,  -1.56555176e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.99377441e-02,  -3.00903320e-02],
                        [ -3.35388184e-02,  -3.36303711e-02],
                        [ -3.11889648e-02,  -3.10974121e-02],
                        [ -2.12707520e-02,  -2.11181641e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -2.07519531e-03,  -2.25830078e-03],
                        [ -5.49316406e-03,  -5.55419922e-03],
                        [ -1.24816895e-02,  -1.23901367e-02],
                        [ -1.54113770e-02,  -1.52893066e-02],
                        [ -1.45263672e-02,  -1.45874023e-02],
                        [ -1.36108398e-02,  -1.37329102e-02],
                        [ -1.23901367e-02,  -1.24511719e-02],
                        [ -8.54492188e-03,  -8.48388672e-03],
                        [ -1.89208984e-03,  -1.80053711e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  8.39233398e-03,   8.27026367e-03],
                        [  7.08007812e-03,   7.01904297e-03],
                        [  6.37817383e-03,   6.46972656e-03],
                        [  1.11083984e-02,   1.12304688e-02],
                        [  1.60827637e-02,   1.59912109e-02],
                        [  8.02612305e-03,   7.90405273e-03],
                        [ -2.13317871e-02,  -2.13012695e-02],
                        [ -6.70776367e-02,  -6.69555664e-02],
                        [ -1.16088867e-01,  -1.16058350e-01],
                        [ -1.57409668e-01,  -1.57501221e-01],
                        [ -1.85333252e-01,  -1.85363770e-01],
                        [ -1.97174072e-01,  -1.97113037e-01],
                        [ -1.93542480e-01,  -1.93481445e-01],
                        [ -1.78649902e-01,  -1.78680420e-01],
                        [ -1.58874512e-01,  -1.58935547e-01],
                        [ -1.39465332e-01,  -1.39465332e-01],
                        [ -1.21795654e-01,  -1.21734619e-01],
                        [ -1.05316162e-01,  -1.05285645e-01],
                        [ -9.10034180e-02,  -9.10949707e-02],
                        [ -7.96813965e-02,  -7.97424316e-02],
                        [ -6.99462891e-02,  -6.98852539e-02],
                        [ -5.96008301e-02,  -5.95397949e-02],
                        [ -4.73632812e-02,  -4.74243164e-02],
                        [ -3.34472656e-02,  -3.35388184e-02],
                        [ -1.84326172e-02,  -1.84020996e-02],
                        [ -2.34985352e-03,  -2.25830078e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  2.07214355e-02,   2.06604004e-02],
                        [  2.28576660e-02,   2.28271484e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.49023438e-02,   2.49328613e-02],
                        [  2.98156738e-02,   2.98461914e-02],
                        [  3.88488770e-02,   3.88183594e-02],
                        [  5.10253906e-02,   5.09643555e-02],
                        [  6.44836426e-02,   6.44531250e-02],
                        [  7.88269043e-02,   7.89184570e-02],
                        [  9.53674316e-02,   9.54589844e-02],
                        [  1.13250732e-01,   1.13220215e-01],
                        [  1.26037598e-01,   1.25885010e-01],
                        [  1.23779297e-01,   1.23779297e-01],
                        [  9.83886719e-02,   9.85107422e-02],
                        [  4.60815430e-02,   4.61425781e-02],
                        [ -2.83813477e-02,  -2.85034180e-02],
                        [ -1.07696533e-01,  -1.07818604e-01],
                        [ -1.65649414e-01,  -1.65618896e-01],
                        [ -1.80145264e-01,  -1.79992676e-01],
                        [ -1.48345947e-01,  -1.48284912e-01],
                        [ -9.11560059e-02,  -9.13391113e-02],
                        [ -3.69262695e-02,  -3.70788574e-02],
                        [  1.00708008e-03,   1.09863281e-03],
                        [  2.83203125e-02,   2.85339355e-02],
                        [  5.37414551e-02,   5.37109375e-02],
                        [  7.40051270e-02,   7.38220215e-02],
                        [  7.95898438e-02,   7.95288086e-02],
                        [  7.02819824e-02,   7.04345703e-02],
                        [  5.67932129e-02,   5.68847656e-02],
                        [  4.87976074e-02,   4.87365723e-02],
                        [  4.97131348e-02,   4.95910645e-02],
                        [  5.93261719e-02,   5.92956543e-02],
                        [  7.37304688e-02,   7.38220215e-02],
                        [  8.55407715e-02,   8.56018066e-02],
                        [  8.79211426e-02,   8.78906250e-02],
                        [  7.80639648e-02,   7.79724121e-02],
                        [  5.95703125e-02,   5.95397949e-02],
                        [  4.19616699e-02,   4.20227051e-02],
                        [  3.30505371e-02,   3.31420898e-02],
                        [  3.12805176e-02,   3.12500000e-02],
                        [  2.92358398e-02,   2.91137695e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.30712891e-02,   2.31628418e-02],
                        [  3.01818848e-02,   3.02429199e-02],
                        [  4.28161621e-02,   4.27856445e-02],
                        [  5.35278320e-02,   5.34973145e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  5.15441895e-02,   5.15747070e-02],
                        [  3.86047363e-02,   3.86352539e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  4.82177734e-03,   4.79125977e-03],
                        [ -1.12609863e-02,  -1.12915039e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -3.37524414e-02,  -3.36914062e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -4.75769043e-02,  -4.76074219e-02],
                        [ -3.86657715e-02,  -3.87268066e-02],
                        [ -7.20214844e-03,  -7.17163086e-03],
                        [  4.31213379e-02,   4.32128906e-02],
                        [  9.22851562e-02,   9.23156738e-02],
                        [  1.18041992e-01,   1.17919922e-01],
                        [  1.14288330e-01,   1.14257812e-01],
                        [  9.42382812e-02,   9.43603516e-02],
                        [  7.52868652e-02,   7.53479004e-02],
                        [  6.16149902e-02,   6.15234375e-02],
                        [  4.60510254e-02,   4.59899902e-02],
                        [  2.70385742e-02,   2.70690918e-02],
                        [  1.17492676e-02,   1.18408203e-02],
                        [  4.97436523e-03,   5.00488281e-03],
                        [  5.40161133e-03,   5.34057617e-03],
                        [  8.94165039e-03,   8.91113281e-03],
                        [  1.05590820e-02,   1.05895996e-02],
                        [  6.74438477e-03,   6.80541992e-03],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [ -1.78222656e-02,  -1.79138184e-02],
                        [ -3.19519043e-02,  -3.20434570e-02],
                        [ -3.76281738e-02,  -3.75366211e-02],
                        [ -3.07006836e-02,  -3.05480957e-02],
                        [ -1.64184570e-02,  -1.64794922e-02],
                        [ -6.74438477e-03,  -6.92749023e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -1.43127441e-02,  -1.41296387e-02],
                        [ -1.55639648e-02,  -1.54724121e-02],
                        [ -1.10168457e-02,  -1.11389160e-02],
                        [ -5.58471680e-03,  -5.70678711e-03],
                        [ -1.25122070e-03,  -1.19018555e-03],
                        [  3.35693359e-03,   3.47900391e-03],
                        [  8.45336914e-03,   8.48388672e-03],
                        [  1.21765137e-02,   1.21154785e-02],
                        [  1.35803223e-02,   1.34887695e-02],
                        [  1.42822266e-02,   1.42517090e-02],
                        [  1.65710449e-02,   1.66931152e-02],
                        [  2.04772949e-02,   2.05688477e-02],
                        [  2.14233398e-02,   2.13012695e-02],
                        [  1.10778809e-02,   1.09252930e-02],
                        [ -1.55639648e-02,  -1.55029297e-02],
                        [ -5.57861328e-02,  -5.56030273e-02],
                        [ -1.04339600e-01,  -1.04309082e-01],
                        [ -1.55792236e-01,  -1.55944824e-01],
                        [ -1.98699951e-01,  -1.98791504e-01],
                        [ -2.19116211e-01,  -2.18994141e-01],
                        [ -2.13714600e-01,  -2.13592529e-01],
                        [ -1.92138672e-01,  -1.92169189e-01],
                        [ -1.66259766e-01,  -1.66351318e-01],
                        [ -1.41845703e-01,  -1.41876221e-01],
                        [ -1.18835449e-01,  -1.18774414e-01],
                        [ -9.74426270e-02,  -9.73815918e-02],
                        [ -8.20312500e-02,  -8.20617676e-02],
                        [ -7.56530762e-02,  -7.57141113e-02],
                        [ -7.39135742e-02,  -7.39440918e-02],
                        [ -6.86645508e-02,  -6.86340332e-02],
                        [ -5.54809570e-02,  -5.54504395e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.35803223e-02,  -1.36413574e-02],
                        [  5.61523438e-03,   5.58471680e-03],
                        [  1.65405273e-02,   1.65710449e-02],
                        [  1.79138184e-02,   1.79443359e-02],
                        [  1.43737793e-02,   1.43432617e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  1.54418945e-02,   1.54113770e-02],
                        [  2.33764648e-02,   2.33154297e-02],
                        [  3.07006836e-02,   3.07312012e-02],
                        [  3.89099121e-02,   3.90014648e-02],
                        [  5.16662598e-02,   5.16357422e-02],
                        [  6.74438477e-02,   6.72912598e-02],
                        [  8.27636719e-02,   8.27331543e-02],
                        [  9.84497070e-02,   9.86328125e-02],
                        [  1.15600586e-01,   1.15661621e-01],
                        [  1.26739502e-01,   1.26586914e-01],
                        [  1.17553711e-01,   1.17431641e-01],
                        [  7.84301758e-02,   7.85522461e-02],
                        [  1.25122070e-02,   1.26342773e-02],
                        [ -6.48193359e-02,  -6.48498535e-02],
                        [ -1.28753662e-01,  -1.28845215e-01],
                        [ -1.53717041e-01,  -1.53717041e-01],
                        [ -1.28479004e-01,  -1.28417969e-01],
                        [ -6.69250488e-02,  -6.68640137e-02],
                        [ -1.77001953e-03,  -1.80053711e-03],
                        [  3.81469727e-02,   3.80859375e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  4.83093262e-02,   4.83398438e-02],
                        [  5.19104004e-02,   5.19714355e-02],
                        [  5.88684082e-02,   5.88378906e-02],
                        [  5.91125488e-02,   5.90515137e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  3.93066406e-02,   3.93676758e-02],
                        [  3.68957520e-02,   3.68652344e-02],
                        [  4.41284180e-02,   4.40673828e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  7.04345703e-02,   7.04650879e-02],
                        [  7.76672363e-02,   7.76672363e-02],
                        [  7.26623535e-02,   7.26013184e-02],
                        [  5.59082031e-02,   5.59387207e-02],
                        [  3.71704102e-02,   3.72314453e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  2.85644531e-02,   2.85034180e-02],
                        [  3.33251953e-02,   3.32946777e-02],
                        [  3.52783203e-02,   3.53088379e-02],
                        [  3.51562500e-02,   3.52172852e-02],
                        [  3.77197266e-02,   3.76892090e-02],
                        [  4.43115234e-02,   4.42199707e-02],
                        [  4.99877930e-02,   4.99572754e-02],
                        [  4.83093262e-02,   4.84008789e-02],
                        [  3.82690430e-02,   3.83605957e-02],
                        [  2.36511230e-02,   2.35900879e-02],
                        [  7.32421875e-03,   7.23266602e-03],
                        [ -8.97216797e-03,  -8.94165039e-03],
                        [ -2.24609375e-02,  -2.23693848e-02],
                        [ -3.13110352e-02,  -3.12805176e-02],
                        [ -3.61022949e-02,  -3.61633301e-02],
                        [ -3.69873047e-02,  -3.70178223e-02],
                        [ -3.10668945e-02,  -3.10363770e-02],
                        [ -1.38549805e-02,  -1.38244629e-02],
                        [  1.65100098e-02,   1.65710449e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  8.79211426e-02,   8.78295898e-02],
                        [  1.00799561e-01,   1.00769043e-01],
                        [  9.12475586e-02,   9.13085938e-02],
                        [  7.23266602e-02,   7.23876953e-02],
                        [  5.72814941e-02,   5.72509766e-02],
                        [  4.73327637e-02,   4.72717285e-02],
                        [  3.77807617e-02,   3.77502441e-02],
                        [  2.68554688e-02,   2.69165039e-02],
                        [  1.69677734e-02,   1.70593262e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  9.12475586e-03,   9.03320312e-03],
                        [  5.09643555e-03,   5.03540039e-03],
                        [ -2.28881836e-03,  -2.19726562e-03],
                        [ -9.97924805e-03,  -9.85717773e-03],
                        [ -1.65405273e-02,  -1.66015625e-02],
                        [ -2.21252441e-02,  -2.22778320e-02],
                        [ -2.28576660e-02,  -2.27966309e-02],
                        [ -1.44042969e-02,  -1.42517090e-02],
                        [ -1.77001953e-03,  -1.80053711e-03],
                        [  3.84521484e-03,   3.69262695e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -9.15527344e-03,  -9.03320312e-03],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.46179199e-02,  -1.47094727e-02],
                        [ -1.15661621e-02,  -1.15356445e-02],
                        [ -4.82177734e-03,  -4.73022461e-03],
                        [  4.11987305e-03,   4.08935547e-03],
                        [  1.18408203e-02,   1.17492676e-02],
                        [  1.61132812e-02,   1.61437988e-02],
                        [  1.95312500e-02,   1.95922852e-02],
                        [  2.73132324e-02,   2.72827148e-02],
                        [  4.10461426e-02,   4.09851074e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  6.47277832e-02,   6.47888184e-02],
                        [  5.49621582e-02,   5.49926758e-02],
                        [  1.90124512e-02,   1.89514160e-02],
                        [ -4.22668457e-02,  -4.22973633e-02],
                        [ -1.17706299e-01,  -1.17614746e-01],
                        [ -1.90734863e-01,  -1.90704346e-01],
                        [ -2.44598389e-01,  -2.44659424e-01],
                        [ -2.65533447e-01,  -2.65563965e-01],
                        [ -2.49084473e-01,  -2.49023438e-01],
                        [ -2.06268311e-01,  -2.06237793e-01],
                        [ -1.59393311e-01,  -1.59454346e-01],
                        [ -1.26159668e-01,  -1.26190186e-01],
                        [ -1.07391357e-01,  -1.07299805e-01],
                        [ -9.40551758e-02,  -9.40246582e-02],
                        [ -8.35876465e-02,  -8.36791992e-02],
                        [ -7.96508789e-02,  -7.97119141e-02],
                        [ -7.93762207e-02,  -7.92846680e-02],
                        [ -7.30895996e-02,  -7.30590820e-02],
                        [ -5.78308105e-02,  -5.79223633e-02],
                        [ -4.00695801e-02,  -4.01306152e-02],
                        [ -2.43225098e-02,  -2.42309570e-02],
                        [ -7.96508789e-03,  -7.87353516e-03],
                        [  1.04064941e-02,   1.03454590e-02],
                        [  2.50549316e-02,   2.49633789e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.21252441e-02,   2.22473145e-02],
                        [  1.11389160e-02,   1.11694336e-02],
                        [  3.47900391e-03,   3.38745117e-03],
                        [  4.88281250e-04,   3.96728516e-04],
                        [  5.79833984e-04,   6.71386719e-04],
                        [  5.49316406e-03,   5.58471680e-03],
                        [  1.69067383e-02,   1.68457031e-02],
                        [  3.20739746e-02,   3.19519043e-02],
                        [  4.97741699e-02,   4.98046875e-02],
                        [  7.31811523e-02,   7.33337402e-02],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  1.21429443e-01,   1.21337891e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.17126465e-01,   1.17187500e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  4.88586426e-02,   4.88281250e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -7.80029297e-02,  -7.80029297e-02],
                        [ -1.16363525e-01,  -1.16394043e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -4.81567383e-02,  -4.80651855e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  6.53381348e-02,   6.52465820e-02],
                        [  6.43615723e-02,   6.43310547e-02],
                        [  3.78112793e-02,   3.79333496e-02],
                        [  1.53198242e-02,   1.53503418e-02],
                        [  9.46044922e-03,   9.33837891e-03],
                        [  1.18103027e-02,   1.17187500e-02],
                        [  1.15966797e-02,   1.16882324e-02],
                        [  1.09558105e-02,   1.10778809e-02],
                        [  1.89514160e-02,   1.89208984e-02],
                        [  3.56750488e-02,   3.55834961e-02],
                        [  5.09948730e-02,   5.09643555e-02],
                        [  5.70373535e-02,   5.71289062e-02],
                        [  5.39855957e-02,   5.40466309e-02],
                        [  4.59594727e-02,   4.58679199e-02],
                        [  3.77807617e-02,   3.77197266e-02],
                        [  3.39050293e-02,   3.39660645e-02],
                        [  3.66821289e-02,   3.67431641e-02],
                        [  4.46777344e-02,   4.46472168e-02],
                        [  5.06286621e-02,   5.05981445e-02],
                        [  4.66918945e-02,   4.67224121e-02],
                        [  3.43017578e-02,   3.43322754e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.53808594e-02,   1.53503418e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  4.88281250e-03,   4.94384766e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  3.57055664e-03,   3.54003906e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -7.59887695e-03,  -7.56835938e-03],
                        [ -2.20031738e-02,  -2.19726562e-02],
                        [ -3.60412598e-02,  -3.60717773e-02],
                        [ -4.46472168e-02,  -4.47082520e-02],
                        [ -4.17480469e-02,  -4.17175293e-02],
                        [ -2.11791992e-02,  -2.11181641e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  6.21337891e-02,   6.20727539e-02],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.21002197e-01,   1.21032715e-01],
                        [  1.14807129e-01,   1.14837646e-01],
                        [  8.96911621e-02,   8.96606445e-02],
                        [  6.17675781e-02,   6.17370605e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  2.71911621e-02,   2.72216797e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  4.11987305e-03,   4.08935547e-03],
                        [  2.04467773e-03,   2.01416016e-03],
                        [  9.55200195e-03,   9.58251953e-03],
                        [  2.13928223e-02,   2.14233398e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [ -6.40869141e-04,  -6.71386719e-04],
                        [ -2.03857422e-02,  -2.03552246e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -1.01013184e-02,  -1.01318359e-02],
                        [  7.59887695e-03,   7.56835938e-03],
                        [  2.37731934e-02,   2.38037109e-02],
                        [  3.16162109e-02,   3.16467285e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  2.13317871e-02,   2.12707520e-02],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  1.24511719e-02,   1.25427246e-02],
                        [  2.49023438e-02,   2.48718262e-02],
                        [  4.40673828e-02,   4.39758301e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  6.93664551e-02,   6.94580078e-02],
                        [  5.80749512e-02,   5.81054688e-02],
                        [  2.14843750e-02,   2.14233398e-02],
                        [ -3.77502441e-02,  -3.77807617e-02],
                        [ -1.07971191e-01,  -1.07940674e-01],
                        [ -1.73858643e-01,  -1.73858643e-01],
                        [ -2.20794678e-01,  -2.20794678e-01],
                        [ -2.38067627e-01,  -2.38037109e-01],
                        [ -2.24609375e-01,  -2.24639893e-01],
                        [ -1.92199707e-01,  -1.92230225e-01],
                        [ -1.58203125e-01,  -1.58172607e-01],
                        [ -1.34155273e-01,  -1.34124756e-01],
                        [ -1.20513916e-01,  -1.20544434e-01],
                        [ -1.10626221e-01,  -1.10687256e-01],
                        [ -9.94262695e-02,  -9.94567871e-02],
                        [ -8.80737305e-02,  -8.80432129e-02],
                        [ -7.94982910e-02,  -7.94677734e-02],
                        [ -7.25708008e-02,  -7.25402832e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -4.61425781e-02,  -4.61730957e-02],
                        [ -2.53601074e-02,  -2.53906250e-02],
                        [ -3.96728516e-03,  -3.90625000e-03],
                        [  1.58081055e-02,   1.58691406e-02],
                        [  3.09753418e-02,   3.09143066e-02],
                        [  3.58886719e-02,   3.57971191e-02],
                        [  2.81372070e-02,   2.81677246e-02],
                        [  1.42517090e-02,   1.43432617e-02],
                        [  3.99780273e-03,   3.96728516e-03],
                        [  4.27246094e-04,   3.35693359e-04],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  2.92968750e-03,   2.99072266e-03],
                        [  1.01623535e-02,   1.01928711e-02],
                        [  2.37426758e-02,   2.37121582e-02],
                        [  4.24804688e-02,   4.24499512e-02],
                        [  6.34765625e-02,   6.34765625e-02],
                        [  8.31909180e-02,   8.32214355e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.15600586e-01,   1.15570068e-01],
                        [  1.30310059e-01,   1.30279541e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  8.50219727e-02,   8.49914551e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -8.71276855e-02,  -8.71276855e-02],
                        [ -9.49096680e-02,  -9.49096680e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -1.70593262e-02,  -1.70898438e-02],
                        [  1.49841309e-02,   1.49536133e-02],
                        [  2.41088867e-02,   2.41699219e-02],
                        [  2.16674805e-02,   2.16979980e-02],
                        [  2.18505859e-02,   2.17895508e-02],
                        [  2.63671875e-02,   2.63061523e-02],
                        [  2.74353027e-02,   2.74658203e-02],
                        [  2.19116211e-02,   2.19726562e-02],
                        [  1.55334473e-02,   1.55639648e-02],
                        [  1.34582520e-02,   1.33666992e-02],
                        [  1.52587891e-02,   1.51977539e-02],
                        [  1.95617676e-02,   1.96533203e-02],
                        [  2.61535645e-02,   2.62756348e-02],
                        [  3.54309082e-02,   3.53698730e-02],
                        [  4.78820801e-02,   4.76989746e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  6.40258789e-02,   6.41784668e-02],
                        [  5.79528809e-02,   5.80139160e-02],
                        [  4.63867188e-02,   4.62951660e-02],
                        [  3.43017578e-02,   3.41796875e-02],
                        [  2.57263184e-02,   2.57568359e-02],
                        [  2.45056152e-02,   2.46276855e-02],
                        [  2.92968750e-02,   2.93273926e-02],
                        [  3.21044922e-02,   3.20129395e-02],
                        [  2.69165039e-02,   2.67944336e-02],
                        [  1.64489746e-02,   1.65100098e-02],
                        [  8.23974609e-03,   8.39233398e-03],
                        [  4.94384766e-03,   4.97436523e-03],
                        [  1.15966797e-03,   1.03759766e-03],
                        [ -9.24682617e-03,  -9.33837891e-03],
                        [ -2.52685547e-02,  -2.52380371e-02],
                        [ -4.01306152e-02,  -4.00390625e-02],
                        [ -4.69665527e-02,  -4.69360352e-02],
                        [ -4.06188965e-02,  -4.06799316e-02],
                        [ -1.76391602e-02,  -1.77307129e-02],
                        [  2.09960938e-02,   2.10266113e-02],
                        [  6.65588379e-02,   6.66503906e-02],
                        [  1.03973389e-01,   1.04003906e-01],
                        [  1.19689941e-01,   1.19628906e-01],
                        [  1.10290527e-01,   1.10198975e-01],
                        [  8.42285156e-02,   8.42590332e-02],
                        [  5.53588867e-02,   5.54809570e-02],
                        [  3.36608887e-02,   3.37219238e-02],
                        [  2.13928223e-02,   2.13012695e-02],
                        [  1.62353516e-02,   1.61132812e-02],
                        [  1.53503418e-02,   1.53808594e-02],
                        [  1.68762207e-02,   1.70288086e-02],
                        [  1.97753906e-02,   1.98059082e-02],
                        [  2.13317871e-02,   2.12097168e-02],
                        [  1.56555176e-02,   1.55639648e-02],
                        [  7.32421875e-04,   7.93457031e-04],
                        [ -1.53503418e-02,  -1.52282715e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.42614746e-02,  -2.43835449e-02],
                        [ -2.41699219e-02,  -2.42309570e-02],
                        [ -2.44140625e-02,  -2.43225098e-02],
                        [ -2.16674805e-02,  -2.15759277e-02],
                        [ -1.57775879e-02,  -1.58386230e-02],
                        [ -9.64355469e-03,  -9.73510742e-03],
                        [ -3.90625000e-03,  -3.87573242e-03],
                        [  2.74658203e-03,   2.83813477e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.57470703e-02,   1.56860352e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  2.86560059e-02,   2.86865234e-02],
                        [  3.63464355e-02,   3.63769531e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  4.54406738e-02,   4.54101562e-02],
                        [  4.85534668e-02,   4.85839844e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -2.90832520e-02,  -2.91137695e-02],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -1.70104980e-01,  -1.70104980e-01],
                        [ -2.31506348e-01,  -2.31536865e-01],
                        [ -2.58422852e-01,  -2.58392334e-01],
                        [ -2.46368408e-01,  -2.46368408e-01],
                        [ -2.10662842e-01,  -2.10662842e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.44592285e-01,  -1.44561768e-01],
                        [ -1.27471924e-01,  -1.27471924e-01],
                        [ -1.14990234e-01,  -1.15051270e-01],
                        [ -1.01623535e-01,  -1.01593018e-01],
                        [ -8.55712891e-02,  -8.54797363e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -5.44128418e-02,  -5.45043945e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -4.36401367e-02,  -4.35791016e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -2.88696289e-02,  -2.89306641e-02],
                        [ -1.35803223e-02,  -1.36108398e-02],
                        [  3.38745117e-03,   3.41796875e-03],
                        [  1.71813965e-02,   1.72119141e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  1.75476074e-02,   1.75170898e-02],
                        [  9.67407227e-03,   9.64355469e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  9.64355469e-03,   9.67407227e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  5.67321777e-02,   5.67626953e-02],
                        [  7.99255371e-02,   7.98950195e-02],
                        [  9.93957520e-02,   9.93957520e-02],
                        [  1.15234375e-01,   1.15203857e-01],
                        [  1.27746582e-01,   1.27746582e-01],
                        [  1.35101318e-01,   1.35131836e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.13891602e-01,   1.13861084e-01],
                        [  6.99768066e-02,   6.99462891e-02],
                        [  7.01904297e-03,   7.04956055e-03],
                        [ -5.20629883e-02,  -5.20324707e-02],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -7.57446289e-02,  -7.57751465e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -1.57165527e-02,  -1.56555176e-02],
                        [  3.23486328e-03,   3.26538086e-03],
                        [  1.15966797e-02,   1.15661621e-02],
                        [  1.56555176e-02,   1.56250000e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.50146484e-02,   1.50451660e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  5.54809570e-02,   5.55114746e-02],
                        [  5.62133789e-02,   5.61828613e-02],
                        [  5.57556152e-02,   5.57250977e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -8.69750977e-03,  -8.72802734e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  7.62939453e-04,   7.93457031e-04],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  3.10058594e-02,   3.09753418e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  2.28881836e-03,   2.31933594e-03],
                        [ -2.34985352e-02,  -2.34985352e-02],
                        [ -4.79431152e-02,  -4.79736328e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -6.40563965e-02,  -6.40258789e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -1.52587891e-03,  -1.55639648e-03],
                        [  5.26123047e-02,   5.25817871e-02],
                        [  1.02996826e-01,   1.03027344e-01],
                        [  1.29913330e-01,   1.29943848e-01],
                        [  1.22344971e-01,   1.22314453e-01],
                        [  8.83178711e-02,   8.82873535e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.15356445e-02,   1.15661621e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.09252930e-02,   1.08642578e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [ -7.32421875e-04,  -7.01904297e-04],
                        [ -1.60217285e-02,  -1.59912109e-02],
                        [ -2.20642090e-02,  -2.20947266e-02],
                        [ -1.66015625e-02,  -1.66320801e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -5.24902344e-03,  -5.21850586e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -2.22778320e-03,  -2.28881836e-03],
                        [  1.34277344e-03,   1.31225586e-03],
                        [  7.44628906e-03,   7.50732422e-03],
                        [  1.55334473e-02,   1.55639648e-02],
                        [  2.13317871e-02,   2.13012695e-02],
                        [  2.12402344e-02,   2.12097168e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  3.02124023e-02,   3.02429199e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  7.91015625e-02,   7.90710449e-02],
                        [  9.17968750e-02,   9.17663574e-02],
                        [  8.35571289e-02,   8.35876465e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [ -7.78503418e-02,  -7.78503418e-02],
                        [ -1.53747559e-01,  -1.53747559e-01],
                        [ -2.15576172e-01,  -2.15576172e-01],
                        [ -2.52746582e-01,  -2.52746582e-01],
                        [ -2.59857178e-01,  -2.59826660e-01],
                        [ -2.36572266e-01,  -2.36572266e-01],
                        [ -1.93725586e-01,  -1.93786621e-01],
                        [ -1.52069092e-01,  -1.52069092e-01],
                        [ -1.26983643e-01,  -1.26922607e-01],
                        [ -1.16363525e-01,  -1.16333008e-01],
                        [ -1.06079102e-01,  -1.06170654e-01],
                        [ -8.73718262e-02,  -8.74023438e-02],
                        [ -6.50329590e-02,  -6.49719238e-02],
                        [ -4.89501953e-02,  -4.89196777e-02],
                        [ -4.17785645e-02,  -4.18090820e-02],
                        [ -3.83911133e-02,  -3.84216309e-02],
                        [ -3.32336426e-02,  -3.32031250e-02],
                        [ -2.44445801e-02,  -2.44140625e-02],
                        [ -1.42822266e-02,  -1.42517090e-02],
                        [ -6.13403320e-03,  -6.16455078e-03],
                        [ -4.57763672e-04,  -4.88281250e-04],
                        [  5.34057617e-03,   5.37109375e-03],
                        [  1.25732422e-02,   1.26342773e-02],
                        [  1.92871094e-02,   1.92565918e-02],
                        [  2.13928223e-02,   2.13623047e-02],
                        [  1.58691406e-02,   1.59301758e-02],
                        [  5.61523438e-03,   5.64575195e-03],
                        [ -1.06811523e-03,  -1.09863281e-03],
                        [  5.79833984e-04,   5.49316406e-04],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.40380859e-02,   1.40686035e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  3.39660645e-02,   3.39355469e-02],
                        [  4.95300293e-02,   4.95605469e-02],
                        [  6.81457520e-02,   6.81762695e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.28967285e-01,   1.28936768e-01],
                        [  1.73614502e-01,   1.73614502e-01],
                        [  2.13378906e-01,   2.13439941e-01],
                        [  2.25982666e-01,   2.25952148e-01],
                        [  1.91802979e-01,   1.91772461e-01],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  6.40869141e-03,   6.43920898e-03],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -1.16149902e-01,  -1.16180420e-01],
                        [ -1.01654053e-01,  -1.01654053e-01],
                        [ -6.12487793e-02,  -6.12182617e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -1.17492676e-02,  -1.17797852e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  8.36181641e-03,   8.33129883e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  7.81250000e-03,   7.78198242e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.71203613e-02,   1.71508789e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  4.29077148e-02,   4.28771973e-02],
                        [  5.02319336e-02,   5.02014160e-02],
                        [  4.69970703e-02,   4.70275879e-02],
                        [  3.64379883e-02,   3.64685059e-02],
                        [  2.49633789e-02,   2.49328613e-02],
                        [  1.86462402e-02,   1.85852051e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  1.84326172e-02,   1.84631348e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.24206543e-02,   1.23901367e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.42919922e-02,  -2.43225098e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  8.04748535e-02,   8.04748535e-02],
                        [  1.22650146e-01,   1.22650146e-01],
                        [  1.31256104e-01,   1.31286621e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  7.45849609e-02,   7.45544434e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.21044922e-02,   3.21350098e-02],
                        [  2.26745605e-02,   2.27050781e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  1.80358887e-02,   1.80053711e-02],
                        [  1.98974609e-02,   1.98669434e-02],
                        [  2.02331543e-02,   2.02636719e-02],
                        [  1.74865723e-02,   1.75170898e-02],
                        [  9.94873047e-03,   9.91821289e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -1.59912109e-02,  -1.59606934e-02],
                        [ -2.15759277e-02,  -2.15454102e-02],
                        [ -1.85852051e-02,  -1.86157227e-02],
                        [ -1.33972168e-02,  -1.34277344e-02],
                        [ -9.88769531e-03,  -9.85717773e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  4.13818359e-02,   4.14123535e-02],
                        [  5.69458008e-02,   5.69152832e-02],
                        [  6.55212402e-02,   6.54907227e-02],
                        [  6.85729980e-02,   6.86035156e-02],
                        [  7.14721680e-02,   7.15026855e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  8.23364258e-02,   8.23364258e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [ -1.85241699e-02,  -1.84936523e-02],
                        [ -9.90905762e-02,  -9.91210938e-02],
                        [ -1.85180664e-01,  -1.85211182e-01],
                        [ -2.55584717e-01,  -2.55554199e-01],
                        [ -2.88055420e-01,  -2.88024902e-01],
                        [ -2.72064209e-01,  -2.72064209e-01],
                        [ -2.22991943e-01,  -2.22991943e-01],
                        [ -1.74285889e-01,  -1.74285889e-01],
                        [ -1.45904541e-01,  -1.45904541e-01],
                        [ -1.30096436e-01,  -1.30065918e-01],
                        [ -1.12609863e-01,  -1.12579346e-01],
                        [ -9.28649902e-02,  -9.29260254e-02],
                        [ -7.78198242e-02,  -7.78503418e-02],
                        [ -6.90307617e-02,  -6.89697266e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -5.66101074e-02,  -5.66406250e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -3.06701660e-02,  -3.06396484e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  3.78417969e-03,   3.75366211e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.44653320e-02,  -1.44348145e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  1.25732422e-02,   1.25427246e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  1.50024414e-01,   1.50024414e-01],
                        [  2.10693359e-01,   2.10693359e-01],
                        [  2.65228271e-01,   2.65228271e-01],
                        [  2.88787842e-01,   2.88818359e-01],
                        [  2.60162354e-01,   2.60162354e-01],
                        [  1.72882080e-01,   1.72851562e-01],
                        [  4.85229492e-02,   4.85229492e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -1.37390137e-01,  -1.37359619e-01],
                        [ -1.48010254e-01,  -1.48010254e-01],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -7.00683594e-02,  -7.00683594e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -2.44140625e-03,  -2.47192383e-03],
                        [ -6.80541992e-03,  -6.83593750e-03],
                        [ -2.32849121e-02,  -2.32543945e-02],
                        [ -3.92150879e-02,  -3.91845703e-02],
                        [ -3.81774902e-02,  -3.82080078e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  5.00183105e-02,   4.99877930e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  6.31408691e-02,   6.31713867e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [ -7.35473633e-03,  -7.32421875e-03],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.24914551e-02,  -2.24609375e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.66210938e-02,  -3.66516113e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.53393555e-02,  -3.53088379e-02],
                        [ -1.39770508e-02,  -1.40075684e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  9.39941406e-02,   9.40246582e-02],
                        [  7.16552734e-02,   7.16247559e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [ -8.27026367e-03,  -8.30078125e-03],
                        [ -2.61230469e-02,  -2.60925293e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -9.76562500e-04,  -9.46044922e-04],
                        [  5.95092773e-03,   5.98144531e-03],
                        [  8.94165039e-03,   8.91113281e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  2.33154297e-02,   2.33459473e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  8.75244141e-02,   8.75549316e-02],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  1.11175537e-01,   1.11145020e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  7.98339844e-02,   7.98645020e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [ -1.15966797e-02,  -1.16271973e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -1.61285400e-01,  -1.61254883e-01],
                        [ -2.35107422e-01,  -2.35137939e-01],
                        [ -2.73071289e-01,  -2.73040771e-01],
                        [ -2.66265869e-01,  -2.66265869e-01],
                        [ -2.29980469e-01,  -2.30010986e-01],
                        [ -1.88171387e-01,  -1.88201904e-01],
                        [ -1.57836914e-01,  -1.57836914e-01],
                        [ -1.41632080e-01,  -1.41601562e-01],
                        [ -1.30310059e-01,  -1.30340576e-01],
                        [ -1.14990234e-01,  -1.14990234e-01],
                        [ -9.58862305e-02,  -9.58557129e-02],
                        [ -7.83996582e-02,  -7.83996582e-02],
                        [ -6.48498535e-02,  -6.48803711e-02],
                        [ -5.34667969e-02,  -5.34362793e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -2.77709961e-02,  -2.78015137e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -7.78198242e-03,  -7.75146484e-03],
                        [ -4.42504883e-03,  -4.45556641e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  8.30078125e-03,   8.33129883e-03],
                        [  1.50146484e-02,   1.50451660e-02],
                        [  1.91650391e-02,   1.91345215e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -3.05175781e-03,  -3.08227539e-03],
                        [ -9.46044922e-03,  -9.42993164e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.65405273e-02,  -1.65710449e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.75476074e-02,  -1.75170898e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  6.97937012e-02,   6.98242188e-02],
                        [  1.48925781e-01,   1.48925781e-01],
                        [  2.33245850e-01,   2.33215332e-01],
                        [  2.99224854e-01,   2.99224854e-01],
                        [  3.30047607e-01,   3.30047607e-01],
                        [  3.17596436e-01,   3.17596436e-01],
                        [  2.58880615e-01,   2.58880615e-01],
                        [  1.57287598e-01,   1.57287598e-01],
                        [  3.08837891e-02,   3.08837891e-02],
                        [ -8.55712891e-02,  -8.55712891e-02],
                        [ -1.54754639e-01,  -1.54754639e-01],
                        [ -1.59332275e-01,  -1.59332275e-01],
                        [ -1.15997314e-01,  -1.16027832e-01],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.20947266e-02,  -2.21252441e-02],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  3.84826660e-02,   3.84826660e-02],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  5.75561523e-02,   5.75256348e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  2.04772949e-02,   2.05078125e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -6.95800781e-03,  -6.98852539e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.09863281e-02,  -1.09558105e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -3.28674316e-02,  -3.28979492e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -3.55224609e-02,  -3.54919434e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [  1.17187500e-02,   1.16882324e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  9.54895020e-02,   9.55200195e-02],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.09130859e-01,   1.09100342e-01],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  7.09228516e-02,   7.09228516e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  2.38037109e-02,   2.37731934e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.93884277e-02,  -2.94189453e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.22375488e-02,  -1.22070312e-02],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -4.27246094e-04,  -4.57763672e-04],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  4.11987305e-03,   4.15039062e-03],
                        [  2.00195312e-02,   1.99890137e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  5.84106445e-02,   5.84411621e-02],
                        [  6.36901855e-02,   6.36596680e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  8.20617676e-02,   8.20922852e-02],
                        [  1.02691650e-01,   1.02691650e-01],
                        [  1.16027832e-01,   1.15997314e-01],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  1.32751465e-02,   1.32446289e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -1.54571533e-01,  -1.54541016e-01],
                        [ -2.33184814e-01,  -2.33184814e-01],
                        [ -2.79052734e-01,  -2.79083252e-01],
                        [ -2.77496338e-01,  -2.77496338e-01],
                        [ -2.36663818e-01,  -2.36663818e-01],
                        [ -1.82464600e-01,  -1.82495117e-01],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.18713379e-01,  -1.18713379e-01],
                        [ -1.15966797e-01,  -1.15966797e-01],
                        [ -1.18225098e-01,  -1.18225098e-01],
                        [ -1.11511230e-01,  -1.11511230e-01],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -7.24487305e-02,  -7.24487305e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [  1.83105469e-03,   1.80053711e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  7.93457031e-03,   7.90405273e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.75476074e-02,  -1.75781250e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -1.27868652e-02,  -1.28173828e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  9.22241211e-02,   9.21936035e-02],
                        [  1.65008545e-01,   1.65008545e-01],
                        [  2.41638184e-01,   2.41638184e-01],
                        [  2.97515869e-01,   2.97485352e-01],
                        [  3.17535400e-01,   3.17535400e-01],
                        [  3.02093506e-01,   3.02093506e-01],
                        [  2.59643555e-01,   2.59643555e-01],
                        [  1.96472168e-01,   1.96472168e-01],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.20239258e-02,   1.20544434e-02],
                        [ -8.78295898e-02,  -8.78295898e-02],
                        [ -1.54235840e-01,  -1.54235840e-01],
                        [ -1.62261963e-01,  -1.62261963e-01],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.65893555e-02,  -6.65588379e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.15234375e-02,  -6.15234375e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -3.54614258e-02,  -3.54309082e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  4.88281250e-02,   4.88586426e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  6.43615723e-02,   6.43310547e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -2.42919922e-02,  -2.43225098e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.78833008e-02,  -1.79138184e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.35290527e-02,  -2.34985352e-02],
                        [ -3.60412598e-02,  -3.60717773e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  8.47473145e-02,   8.47473145e-02],
                        [  1.14929199e-01,   1.14929199e-01],
                        [  1.22711182e-01,   1.22680664e-01],
                        [  1.09252930e-01,   1.09252930e-01],
                        [  8.15124512e-02,   8.15124512e-02],
                        [  5.09643555e-02,   5.09643555e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  1.66931152e-02,   1.67236328e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.12609863e-02,   1.12304688e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  3.78417969e-03,   3.81469727e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -7.23266602e-03,  -7.26318359e-03],
                        [ -1.69067383e-02,  -1.68762207e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.62145996e-02,  -2.62451172e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.00097656e-02,  -9.97924805e-03],
                        [  7.44628906e-03,   7.41577148e-03],
                        [  2.91748047e-02,   2.91442871e-02],
                        [  5.11779785e-02,   5.12084961e-02],
                        [  7.14416504e-02,   7.14721680e-02],
                        [  9.14611816e-02,   9.14306641e-02],
                        [  1.10443115e-01,   1.10443115e-01],
                        [  1.23626709e-01,   1.23657227e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [ -1.73187256e-01,  -1.73187256e-01],
                        [ -2.57965088e-01,  -2.57965088e-01],
                        [ -3.10333252e-01,  -3.10333252e-01],
                        [ -3.15277100e-01,  -3.15277100e-01],
                        [ -2.72369385e-01,  -2.72369385e-01],
                        [ -2.06207275e-01,  -2.06207275e-01],
                        [ -1.51763916e-01,  -1.51763916e-01],
                        [ -1.23779297e-01,  -1.23779297e-01],
                        [ -1.09191895e-01,  -1.09191895e-01],
                        [ -9.17968750e-02,  -9.17663574e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.35070801e-02,  -6.34765625e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -6.67419434e-02,  -6.67724609e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -5.21850586e-03,  -5.24902344e-03],
                        [  5.55419922e-03,   5.52368164e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -3.44848633e-03,  -3.47900391e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.70898438e-02,  -1.71203613e-02],
                        [ -2.67639160e-02,  -2.67333984e-02],
                        [ -3.63464355e-02,  -3.63769531e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.31115723e-02,  -3.30810547e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  2.38037109e-02,   2.38342285e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.88964844e-01,   1.88964844e-01],
                        [  2.39593506e-01,   2.39593506e-01],
                        [  2.72766113e-01,   2.72766113e-01],
                        [  2.82409668e-01,   2.82409668e-01],
                        [  2.70507812e-01,   2.70538330e-01],
                        [  2.45941162e-01,   2.45941162e-01],
                        [  2.14874268e-01,   2.14874268e-01],
                        [  1.71905518e-01,   1.71905518e-01],
                        [  1.05621338e-01,   1.05590820e-01],
                        [  1.52282715e-02,   1.52282715e-02],
                        [ -8.00170898e-02,  -8.00170898e-02],
                        [ -1.49169922e-01,  -1.49169922e-01],
                        [ -1.71600342e-01,  -1.71630859e-01],
                        [ -1.54632568e-01,  -1.54602051e-01],
                        [ -1.24786377e-01,  -1.24786377e-01],
                        [ -1.02539062e-01,  -1.02539062e-01],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -8.26721191e-02,  -8.26416016e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -1.64794922e-03,  -1.67846680e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.93786621e-02,   1.94091797e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  4.36096191e-02,   4.36401367e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  3.91540527e-02,   3.91235352e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  8.02612305e-03,   8.02612305e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -9.33837891e-03,  -9.30786133e-03],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -3.26538086e-02,  -3.26843262e-02],
                        [ -5.03845215e-02,  -5.03540039e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -5.96923828e-02,  -5.96923828e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -2.72216797e-02,  -2.71911621e-02],
                        [  1.14440918e-02,   1.14135742e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.11816406e-01,   1.11816406e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  1.60827637e-02,   1.61132812e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.53503418e-02,  -1.53808594e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  1.13525391e-02,   1.13220215e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  7.29675293e-02,   7.29370117e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.20513916e-01,   1.20513916e-01],
                        [  7.88879395e-02,   7.88879395e-02],
                        [  7.81250000e-03,   7.78198242e-03],
                        [ -8.65478516e-02,  -8.65478516e-02],
                        [ -1.86553955e-01,  -1.86553955e-01],
                        [ -2.63488770e-01,  -2.63519287e-01],
                        [ -2.92541504e-01,  -2.92541504e-01],
                        [ -2.71911621e-01,  -2.71911621e-01],
                        [ -2.23480225e-01,  -2.23510742e-01],
                        [ -1.75323486e-01,  -1.75323486e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -1.29364014e-01,  -1.29364014e-01],
                        [ -1.17584229e-01,  -1.17584229e-01],
                        [ -1.00006104e-01,  -1.00006104e-01],
                        [ -8.12683105e-02,  -8.12683105e-02],
                        [ -7.07702637e-02,  -7.07702637e-02],
                        [ -6.75048828e-02,  -6.75048828e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -5.15747070e-03,  -5.18798828e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -5.08422852e-02,  -5.08117676e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.95983887e-01,   1.95983887e-01],
                        [  2.39349365e-01,   2.39349365e-01],
                        [  2.50335693e-01,   2.50335693e-01],
                        [  2.39562988e-01,   2.39562988e-01],
                        [  2.26226807e-01,   2.26196289e-01],
                        [  2.21588135e-01,   2.21588135e-01],
                        [  2.22564697e-01,   2.22595215e-01],
                        [  2.16705322e-01,   2.16705322e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  6.42089844e-02,   6.42089844e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -1.57745361e-01,  -1.57745361e-01],
                        [ -1.64337158e-01,  -1.64337158e-01],
                        [ -1.36352539e-01,  -1.36383057e-01],
                        [ -1.01318359e-01,  -1.01318359e-01],
                        [ -8.40148926e-02,  -8.40148926e-02],
                        [ -8.50219727e-02,  -8.50524902e-02],
                        [ -8.41979980e-02,  -8.41979980e-02],
                        [ -6.73522949e-02,  -6.73217773e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  1.44348145e-02,   1.44653320e-02],
                        [  2.47192383e-02,   2.46887207e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.10668945e-02,   3.10974121e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.67333984e-02,   2.67639160e-02],
                        [  1.29089355e-02,   1.29394531e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -5.34667969e-02,  -5.34362793e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  8.06884766e-02,   8.06579590e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  2.36816406e-02,   2.36511230e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  6.65283203e-03,   6.68334961e-03],
                        [ -9.06372070e-03,  -9.09423828e-03],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  3.75366211e-03,   3.78417969e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  1.32141113e-02,   1.32446289e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  7.33642578e-02,   7.33642578e-02],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  1.33911133e-01,   1.33880615e-01],
                        [  1.57379150e-01,   1.57379150e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  6.05773926e-02,   6.05773926e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -2.07031250e-01,  -2.07031250e-01],
                        [ -2.79205322e-01,  -2.79205322e-01],
                        [ -3.05053711e-01,  -3.05053711e-01],
                        [ -2.79876709e-01,  -2.79876709e-01],
                        [ -2.25006104e-01,  -2.25006104e-01],
                        [ -1.73980713e-01,  -1.73980713e-01],
                        [ -1.46667480e-01,  -1.46697998e-01],
                        [ -1.36535645e-01,  -1.36566162e-01],
                        [ -1.24694824e-01,  -1.24694824e-01],
                        [ -1.01562500e-01,  -1.01562500e-01],
                        [ -7.24792480e-02,  -7.24792480e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -3.59497070e-02,  -3.59191895e-02],
                        [ -3.06396484e-02,  -3.06701660e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.65100098e-02,  -1.65405273e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -4.79125977e-03,  -4.82177734e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.93981934e-02,  -3.94287109e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  1.43035889e-01,   1.43035889e-01],
                        [  1.90185547e-01,   1.90185547e-01],
                        [  2.20092773e-01,   2.20092773e-01],
                        [  2.27020264e-01,   2.27020264e-01],
                        [  2.17712402e-01,   2.17712402e-01],
                        [  2.07885742e-01,   2.07885742e-01],
                        [  2.08465576e-01,   2.08465576e-01],
                        [  2.15881348e-01,   2.15881348e-01],
                        [  2.17285156e-01,   2.17285156e-01],
                        [  2.00927734e-01,   2.00927734e-01],
                        [  1.59362793e-01,   1.59362793e-01],
                        [  8.85009766e-02,   8.85009766e-02],
                        [ -7.44628906e-03,  -7.41577148e-03],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -1.81365967e-01,  -1.81396484e-01],
                        [ -2.06268311e-01,  -2.06237793e-01],
                        [ -1.85791016e-01,  -1.85760498e-01],
                        [ -1.43707275e-01,  -1.43737793e-01],
                        [ -1.06597900e-01,  -1.06597900e-01],
                        [ -8.56018066e-02,  -8.56018066e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.32751465e-02,  -1.33056641e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  1.23626709e-01,   1.23626709e-01],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  1.47735596e-01,   1.47735596e-01],
                        [  1.47216797e-01,   1.47186279e-01],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [ -6.82678223e-02,  -6.82678223e-02],
                        [ -1.54785156e-01,  -1.54785156e-01],
                        [ -2.36877441e-01,  -2.36877441e-01],
                        [ -2.90832520e-01,  -2.90863037e-01],
                        [ -2.94982910e-01,  -2.94982910e-01],
                        [ -2.54608154e-01,  -2.54577637e-01],
                        [ -2.01995850e-01,  -2.02026367e-01],
                        [ -1.64978027e-01,  -1.64978027e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.26678467e-01,  -1.26678467e-01],
                        [ -1.06353760e-01,  -1.06353760e-01],
                        [ -8.65478516e-02,  -8.65478516e-02],
                        [ -6.92443848e-02,  -6.92138672e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.51660156e-02,  -4.51354980e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -2.17590332e-02,  -2.17285156e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -4.82177734e-02,  -4.81872559e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  7.27233887e-02,   7.27233887e-02],
                        [  1.19873047e-01,   1.19903564e-01],
                        [  1.66229248e-01,   1.66229248e-01],
                        [  2.07489014e-01,   2.07489014e-01],
                        [  2.30560303e-01,   2.30560303e-01],
                        [  2.26562500e-01,   2.26562500e-01],
                        [  2.04223633e-01,   2.04223633e-01],
                        [  1.82922363e-01,   1.82922363e-01],
                        [  1.73309326e-01,   1.73309326e-01],
                        [  1.72149658e-01,   1.72149658e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  1.69982910e-01,   1.69982910e-01],
                        [  1.62322998e-01,   1.62322998e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.91955566e-02,   1.92260742e-02],
                        [ -8.07495117e-02,  -8.07495117e-02],
                        [ -1.67358398e-01,  -1.67358398e-01],
                        [ -2.09777832e-01,  -2.09777832e-01],
                        [ -2.02697754e-01,  -2.02697754e-01],
                        [ -1.63665771e-01,  -1.63665771e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -8.75854492e-02,  -8.75854492e-02],
                        [ -7.11059570e-02,  -7.11059570e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [  6.40869141e-04,   6.71386719e-04],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -3.26843262e-02,  -3.27148438e-02],
                        [  2.02026367e-02,   2.02331543e-02],
                        [  8.25195312e-02,   8.25195312e-02],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.40594482e-01,   1.40594482e-01],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  5.19104004e-02,   5.19104004e-02],
                        [  3.22265625e-02,   3.22570801e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.61437988e-02,   1.61743164e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  4.46166992e-02,   4.45861816e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.46972656e-01,   1.47003174e-01],
                        [  1.43035889e-01,   1.43035889e-01],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  3.86962891e-02,   3.86962891e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -1.62048340e-01,  -1.62048340e-01],
                        [ -2.54699707e-01,  -2.54699707e-01],
                        [ -3.06823730e-01,  -3.06823730e-01],
                        [ -3.00170898e-01,  -3.00170898e-01],
                        [ -2.48138428e-01,  -2.48138428e-01],
                        [ -1.90429688e-01,  -1.90460205e-01],
                        [ -1.55273438e-01,  -1.55273438e-01],
                        [ -1.36047363e-01,  -1.36047363e-01],
                        [ -1.12945557e-01,  -1.12945557e-01],
                        [ -8.49609375e-02,  -8.49609375e-02],
                        [ -6.68029785e-02,  -6.67724609e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -1.87988281e-02,  -1.87988281e-02],
                        [  2.62451172e-03,   2.65502930e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -5.66101074e-02,  -5.65795898e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -7.32116699e-02,  -7.32116699e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.87164307e-01,   1.87164307e-01],
                        [  2.12829590e-01,   2.12829590e-01],
                        [  2.11669922e-01,   2.11669922e-01],
                        [  1.90765381e-01,   1.90765381e-01],
                        [  1.66687012e-01,   1.66687012e-01],
                        [  1.48529053e-01,   1.48529053e-01],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  1.27716064e-01,   1.27716064e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.47308350e-01,   1.47308350e-01],
                        [  1.54205322e-01,   1.54205322e-01],
                        [  1.41845703e-01,   1.41845703e-01],
                        [  9.79003906e-02,   9.79309082e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [ -7.67211914e-02,  -7.67211914e-02],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -2.11608887e-01,  -2.11608887e-01],
                        [ -1.93145752e-01,  -1.93145752e-01],
                        [ -1.30798340e-01,  -1.30798340e-01],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  2.89001465e-02,   2.89306641e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  2.15454102e-02,   2.15454102e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -5.20935059e-02,  -5.21240234e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  1.32751465e-01,   1.32751465e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  6.07604980e-02,   6.07299805e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  6.52770996e-02,   6.52770996e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.29425049e-01,   1.29394531e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.27960205e-01,   1.27960205e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  5.81359863e-02,   5.81359863e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -1.25732422e-01,  -1.25732422e-01],
                        [ -2.23449707e-01,  -2.23480225e-01],
                        [ -2.89825439e-01,  -2.89825439e-01],
                        [ -3.04443359e-01,  -3.04443359e-01],
                        [ -2.68157959e-01,  -2.68188477e-01],
                        [ -2.07458496e-01,  -2.07458496e-01],
                        [ -1.54022217e-01,  -1.53991699e-01],
                        [ -1.20819092e-01,  -1.20819092e-01],
                        [ -1.02050781e-01,  -1.02050781e-01],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -7.77282715e-02,  -7.77282715e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.54907227e-02,  -6.54602051e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -7.76062012e-02,  -7.75756836e-02],
                        [ -7.15942383e-02,  -7.16247559e-02],
                        [ -5.15747070e-02,  -5.15747070e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  9.10339355e-02,   9.10034180e-02],
                        [  1.54998779e-01,   1.54998779e-01],
                        [  2.08923340e-01,   2.08923340e-01],
                        [  2.37243652e-01,   2.37243652e-01],
                        [  2.34008789e-01,   2.34008789e-01],
                        [  2.06939697e-01,   2.06939697e-01],
                        [  1.71569824e-01,   1.71539307e-01],
                        [  1.40228271e-01,   1.40228271e-01],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  1.03240967e-01,   1.03240967e-01],
                        [  9.88159180e-02,   9.88159180e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.13525391e-01,   1.13525391e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  1.36169434e-01,   1.36169434e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.15051270e-01,   1.15051270e-01],
                        [  5.17883301e-02,   5.17883301e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -1.37542725e-01,  -1.37542725e-01],
                        [ -1.97265625e-01,  -1.97265625e-01],
                        [ -2.04467773e-01,  -2.04467773e-01],
                        [ -1.68914795e-01,  -1.68914795e-01],
                        [ -1.17675781e-01,  -1.17675781e-01],
                        [ -7.65380859e-02,  -7.65380859e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  5.31005859e-03,   5.34057617e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -2.09655762e-02,  -2.09960938e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -1.91650391e-02,  -1.91345215e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  1.04614258e-01,   1.04644775e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  1.12823486e-01,   1.12823486e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.41082764e-01,   1.41082764e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  3.03955078e-02,   3.03955078e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -1.78649902e-01,  -1.78649902e-01],
                        [ -2.73376465e-01,  -2.73376465e-01],
                        [ -3.21685791e-01,  -3.21685791e-01],
                        [ -3.04840088e-01,  -3.04840088e-01],
                        [ -2.38677979e-01,  -2.38677979e-01],
                        [ -1.67877197e-01,  -1.67877197e-01],
                        [ -1.27807617e-01,  -1.27807617e-01],
                        [ -1.15173340e-01,  -1.15173340e-01],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -8.05969238e-02,  -8.05969238e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.41687012e-02,  -5.41992188e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -7.80029297e-02,  -7.80029297e-02],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -7.56530762e-02,  -7.56530762e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  1.45751953e-01,   1.45751953e-01],
                        [  2.02575684e-01,   2.02575684e-01],
                        [  2.34222412e-01,   2.34222412e-01],
                        [  2.31719971e-01,   2.31719971e-01],
                        [  2.04040527e-01,   2.04040527e-01],
                        [  1.67785645e-01,   1.67785645e-01],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  1.06048584e-01,   1.06048584e-01],
                        [  1.08032227e-01,   1.08032227e-01],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.43676758e-01,   1.43676758e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.00097656e-01,   1.00097656e-01],
                        [  4.07714844e-02,   4.07714844e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -1.29669189e-01,  -1.29669189e-01],
                        [ -1.87652588e-01,  -1.87652588e-01],
                        [ -1.99249268e-01,  -1.99249268e-01],
                        [ -1.69647217e-01,  -1.69647217e-01],
                        [ -1.20330811e-01,  -1.20330811e-01],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  1.18896484e-01,   1.18896484e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.58477783e-01,   1.58477783e-01],
                        [  1.56036377e-01,   1.56036377e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -1.67388916e-01,  -1.67388916e-01],
                        [ -2.61352539e-01,  -2.61352539e-01],
                        [ -3.13079834e-01,  -3.13079834e-01],
                        [ -2.98400879e-01,  -2.98400879e-01],
                        [ -2.30834961e-01,  -2.30834961e-01],
                        [ -1.56738281e-01,  -1.56738281e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -1.01928711e-01,  -1.01928711e-01],
                        [ -9.75646973e-02,  -9.75646973e-02],
                        [ -8.89587402e-02,  -8.89587402e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -7.82165527e-02,  -7.82165527e-02],
                        [ -7.72094727e-02,  -7.72094727e-02],
                        [ -7.27844238e-02,  -7.27844238e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -2.81677246e-02,  -2.81982422e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -7.27844238e-02,  -7.27844238e-02],
                        [ -7.44018555e-02,  -7.44018555e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.69769287e-01,   1.69769287e-01],
                        [  2.00897217e-01,   2.00897217e-01],
                        [  2.04193115e-01,   2.04193115e-01],
                        [  1.86645508e-01,   1.86645508e-01],
                        [  1.60308838e-01,   1.60308838e-01],
                        [  1.35223389e-01,   1.35223389e-01],
                        [  1.15814209e-01,   1.15814209e-01],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  6.34765625e-02,   6.34765625e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -8.27331543e-02,  -8.27331543e-02],
                        [ -1.55792236e-01,  -1.55792236e-01],
                        [ -1.97875977e-01,  -1.97875977e-01],
                        [ -1.94610596e-01,  -1.94610596e-01],
                        [ -1.54541016e-01,  -1.54541016e-01],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  8.54492188e-02,   8.54492188e-02],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.50573730e-01,   1.50573730e-01],
                        [  1.59576416e-01,   1.59576416e-01],
                        [  1.43371582e-01,   1.43371582e-01],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  3.71704102e-02,   3.71704102e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -1.53900146e-01,  -1.53900146e-01],
                        [ -2.52380371e-01,  -2.52380371e-01],
                        [ -3.07800293e-01,  -3.07800293e-01],
                        [ -2.94525146e-01,  -2.94525146e-01],
                        [ -2.25982666e-01,  -2.25982666e-01],
                        [ -1.50054932e-01,  -1.50054932e-01],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -9.81445312e-02,  -9.81445312e-02],
                        [ -9.21630859e-02,  -9.21630859e-02],
                        [ -8.40148926e-02,  -8.40148926e-02],
                        [ -7.53479004e-02,  -7.53479004e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -7.11669922e-02,  -7.11669922e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  1.41021729e-01,   1.41021729e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  2.05169678e-01,   2.05169678e-01],
                        [  1.92077637e-01,   1.92077637e-01],
                        [  1.60369873e-01,   1.60369873e-01],
                        [  1.27868652e-01,   1.27868652e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  6.77795410e-02,   6.77795410e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  6.28356934e-02,   6.28356934e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -9.69848633e-02,  -9.69848633e-02],
                        [ -1.72760010e-01,  -1.72760010e-01],
                        [ -2.07611084e-01,  -2.07611084e-01],
                        [ -1.93084717e-01,  -1.93084717e-01],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -8.86840820e-02,  -8.86840820e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.40228271e-01,   1.40228271e-01],
                        [  1.60980225e-01,   1.60980225e-01],
                        [  1.65924072e-01,   1.65924072e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  9.59167480e-02,   9.59167480e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -1.85516357e-01,  -1.85516357e-01],
                        [ -2.56713867e-01,  -2.56713867e-01],
                        [ -2.84912109e-01,  -2.84912109e-01],
                        [ -2.65380859e-01,  -2.65380859e-01],
                        [ -2.12005615e-01,  -2.12005615e-01],
                        [ -1.55609131e-01,  -1.55609131e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -1.12030029e-01,  -1.12030029e-01],
                        [ -1.06475830e-01,  -1.06475830e-01],
                        [ -9.45129395e-02,  -9.45129395e-02],
                        [ -8.20617676e-02,  -8.20617676e-02],
                        [ -7.67517090e-02,  -7.67517090e-02],
                        [ -7.28149414e-02,  -7.28149414e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  1.74621582e-01,   1.74621582e-01],
                        [  2.09747314e-01,   2.09747314e-01],
                        [  2.09960938e-01,   2.09960938e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  1.47277832e-01,   1.47277832e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  5.94177246e-02,   5.94177246e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -1.29516602e-01,  -1.29516602e-01],
                        [ -1.55517578e-01,  -1.55517578e-01],
                        [ -1.51214600e-01,  -1.51214600e-01],
                        [ -1.28936768e-01,  -1.28936768e-01],
                        [ -1.03057861e-01,  -1.03057861e-01],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -8.09020996e-02,  -8.09020996e-02],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -7.61718750e-02,  -7.61718750e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  5.34362793e-02,   5.34362793e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.06231689e-01,   1.06231689e-01],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  7.16247559e-02,   7.16247559e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -1.14257812e-01,  -1.14257812e-01],
                        [ -2.05474854e-01,  -2.05474854e-01],
                        [ -2.65411377e-01,  -2.65411377e-01],
                        [ -2.77099609e-01,  -2.77099609e-01],
                        [ -2.43316650e-01,  -2.43316650e-01],
                        [ -1.90124512e-01,  -1.90124512e-01],
                        [ -1.46148682e-01,  -1.46148682e-01],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -1.01623535e-01,  -1.01623535e-01],
                        [ -8.56018066e-02,  -8.56018066e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -7.86132812e-02,  -7.86132812e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.77886963e-01,   1.77886963e-01],
                        [  1.99096680e-01,   1.99096680e-01],
                        [  1.91589355e-01,   1.91589355e-01],
                        [  1.65069580e-01,   1.65069580e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.07177734e-01,   1.07177734e-01],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  7.08312988e-02,   7.08312988e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  7.07092285e-02,   7.07092285e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -1.36352539e-01,  -1.36352539e-01],
                        [ -1.94000244e-01,  -1.94000244e-01],
                        [ -2.02056885e-01,  -2.02056885e-01],
                        [ -1.70440674e-01,  -1.70440674e-01],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -1.02478027e-01,  -1.02478027e-01],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -8.59069824e-02,  -8.59069824e-02],
                        [ -8.65783691e-02,  -8.65783691e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  8.45336914e-02,   8.45336914e-02],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.22619629e-01,   1.22619629e-01],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -1.68273926e-01,  -1.68273926e-01],
                        [ -2.44232178e-01,  -2.44232178e-01],
                        [ -2.71789551e-01,  -2.71789551e-01],
                        [ -2.43988037e-01,  -2.43988037e-01],
                        [ -1.86157227e-01,  -1.86157227e-01],
                        [ -1.33819580e-01,  -1.33819580e-01],
                        [ -1.05987549e-01,  -1.05987549e-01],
                        [ -9.90600586e-02,  -9.90600586e-02],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -8.35266113e-02,  -8.35266113e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -7.37304688e-02,  -7.37304688e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  1.34033203e-01,   1.34033203e-01],
                        [  1.99737549e-01,   1.99737549e-01],
                        [  2.34222412e-01,   2.34222412e-01],
                        [  2.27539062e-01,   2.27539062e-01],
                        [  1.87927246e-01,   1.87927246e-01],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.58996582e-02,   1.58996582e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.23413086e-01,   1.23413086e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -8.78906250e-02,  -8.78906250e-02],
                        [ -1.69586182e-01,  -1.69586182e-01],
                        [ -2.14782715e-01,  -2.14782715e-01],
                        [ -2.09045410e-01,  -2.09045410e-01],
                        [ -1.67846680e-01,  -1.67846680e-01],
                        [ -1.20605469e-01,  -1.20605469e-01],
                        [ -8.54797363e-02,  -8.54797363e-02],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -8.05358887e-02,  -8.05358887e-02],
                        [ -9.75036621e-02,  -9.75036621e-02],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  7.78198242e-02,   7.78198242e-02],
                        [  5.98754883e-02,   5.98754883e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  7.37304688e-02,   7.37304688e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  5.78002930e-02,   5.78002930e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  9.39331055e-02,   9.39331055e-02],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.42547607e-01,   1.42547607e-01],
                        [  1.39404297e-01,   1.39404297e-01],
                        [  1.01104736e-01,   1.01104736e-01],
                        [  2.45361328e-02,   2.45361328e-02],
                        [ -8.04748535e-02,  -8.04748535e-02],
                        [ -1.88720703e-01,  -1.88720703e-01],
                        [ -2.67608643e-01,  -2.67608643e-01],
                        [ -2.92663574e-01,  -2.92663574e-01],
                        [ -2.61291504e-01,  -2.61291504e-01],
                        [ -1.95770264e-01,  -1.95770264e-01],
                        [ -1.29486084e-01,  -1.29486084e-01],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -7.36694336e-02,  -7.36694336e-02],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -8.58459473e-02,  -8.58459473e-02],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.88903809e-01,   1.88903809e-01],
                        [  2.05291748e-01,   2.05291748e-01],
                        [  1.91040039e-01,   1.91040039e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.22406006e-01,   1.22406006e-01],
                        [  1.00280762e-01,   1.00280762e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  6.19812012e-02,   6.19812012e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.26953125e-01,   1.26953125e-01],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -8.53576660e-02,  -8.53576660e-02],
                        [ -1.69647217e-01,  -1.69647217e-01],
                        [ -2.17864990e-01,  -2.17864990e-01],
                        [ -2.18261719e-01,  -2.18261719e-01],
                        [ -1.79382324e-01,  -1.79382324e-01],
                        [ -1.27380371e-01,  -1.27380371e-01],
                        [ -8.73718262e-02,  -8.73718262e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.84411621e-02,  -5.84411621e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -7.81860352e-02,  -7.81860352e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  9.37194824e-02,   9.37194824e-02],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.48498535e-02,   6.48498535e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  6.80847168e-02,   6.80847168e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  7.28759766e-02,   7.28759766e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  8.15429688e-02,   8.15429688e-02],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [ -7.49816895e-02,  -7.49816895e-02],
                        [ -1.82952881e-01,  -1.82952881e-01],
                        [ -2.67730713e-01,  -2.67730713e-01],
                        [ -2.99041748e-01,  -2.99041748e-01],
                        [ -2.72918701e-01,  -2.72918701e-01],
                        [ -2.13226318e-01,  -2.13226318e-01],
                        [ -1.52526855e-01,  -1.52526855e-01],
                        [ -1.11541748e-01,  -1.11541748e-01],
                        [ -9.18273926e-02,  -9.18273926e-02],
                        [ -8.23364258e-02,  -8.23364258e-02],
                        [ -7.23571777e-02,  -7.23571777e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  1.37725830e-01,   1.37725830e-01],
                        [  1.91741943e-01,   1.91741943e-01],
                        [  2.14385986e-01,   2.14385986e-01],
                        [  2.03155518e-01,   2.03155518e-01],
                        [  1.75109863e-01,   1.75109863e-01],
                        [  1.45080566e-01,   1.45080566e-01],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  8.33435059e-02,   8.33435059e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  1.98364258e-03,   1.98364258e-03],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -1.46301270e-01,  -1.46301270e-01],
                        [ -1.90643311e-01,  -1.90643311e-01],
                        [ -1.95343018e-01,  -1.95343018e-01],
                        [ -1.65191650e-01,  -1.65191650e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -8.38317871e-02,  -8.38317871e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -7.69653320e-02,  -7.69653320e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -7.55615234e-02,  -7.55615234e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -9.25598145e-02,  -9.25598145e-02],
                        [ -1.04095459e-01,  -1.04095459e-01],
                        [ -9.82971191e-02,  -9.82971191e-02],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  9.23156738e-02,   9.23156738e-02],
                        [  1.21124268e-01,   1.21124268e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  7.84912109e-02,   7.84912109e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  6.13403320e-02,   6.13403320e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  1.13677979e-01,   1.13677979e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.37756348e-01,   1.37756348e-01],
                        [  1.25854492e-01,   1.25854492e-01],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [ -8.64562988e-02,  -8.64562988e-02],
                        [ -2.00012207e-01,  -2.00012207e-01],
                        [ -2.81738281e-01,  -2.81738281e-01],
                        [ -3.06121826e-01,  -3.06121826e-01],
                        [ -2.75970459e-01,  -2.75970459e-01],
                        [ -2.15393066e-01,  -2.15393066e-01],
                        [ -1.55914307e-01,  -1.55914307e-01],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.02569580e-01,  -1.02569580e-01],
                        [ -9.19189453e-02,  -9.19189453e-02],
                        [ -8.04748535e-02,  -8.04748535e-02],
                        [ -7.09228516e-02,  -7.09228516e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -6.87255859e-02,  -6.87255859e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -8.95996094e-02,  -8.95996094e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  1.63635254e-01,   1.63635254e-01],
                        [  2.07519531e-01,   2.07519531e-01],
                        [  2.20794678e-01,   2.20794678e-01],
                        [  2.04437256e-01,   2.04437256e-01],
                        [  1.72119141e-01,   1.72119141e-01],
                        [  1.39099121e-01,   1.39099121e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -8.99658203e-02,  -8.99658203e-02],
                        [ -1.68975830e-01,  -1.68975830e-01],
                        [ -2.10296631e-01,  -2.10296631e-01],
                        [ -2.02270508e-01,  -2.02270508e-01],
                        [ -1.61590576e-01,  -1.61590576e-01],
                        [ -1.19964600e-01,  -1.19964600e-01],
                        [ -9.79003906e-02,  -9.79003906e-02],
                        [ -9.15222168e-02,  -9.15222168e-02],
                        [ -8.62731934e-02,  -8.62731934e-02],
                        [ -7.60803223e-02,  -7.60803223e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -8.27026367e-02,  -8.27026367e-02],
                        [ -9.93041992e-02,  -9.93041992e-02],
                        [ -1.00463867e-01,  -1.00463867e-01],
                        [ -8.92028809e-02,  -8.92028809e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  1.33880615e-01,   1.33880615e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  1.01104736e-01,   1.01104736e-01],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.32141113e-01,   1.32141113e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.13342285e-01,   1.13342285e-01],
                        [  6.56127930e-02,   6.56127930e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.24725342e-01,  -1.24725342e-01],
                        [ -2.26470947e-01,  -2.26470947e-01],
                        [ -2.84484863e-01,  -2.84484863e-01],
                        [ -2.80914307e-01,  -2.80914307e-01],
                        [ -2.33825684e-01,  -2.33825684e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.47155762e-01,  -1.47155762e-01],
                        [ -1.30096436e-01,  -1.30096436e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  1.50543213e-01,   1.50543213e-01],
                        [  1.99066162e-01,   1.99066162e-01],
                        [  2.05017090e-01,   2.05017090e-01],
                        [  1.76452637e-01,   1.76452637e-01],
                        [  1.45599365e-01,   1.45599365e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.28143311e-01,   1.28143311e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  7.97119141e-02,   7.97119141e-02],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -1.24694824e-01,  -1.24694824e-01],
                        [ -2.08618164e-01,  -2.08618164e-01],
                        [ -2.37335205e-01,  -2.37335205e-01],
                        [ -2.06848145e-01,  -2.06848145e-01],
                        [ -1.50512695e-01,  -1.50512695e-01],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -8.10546875e-02,  -8.10546875e-02],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -7.94372559e-02,  -7.94372559e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  1.09252930e-01,   1.09252930e-01],
                        [  1.27441406e-01,   1.27441406e-01],
                        [  1.17248535e-01,   1.17248535e-01],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  1.02752686e-01,   1.02752686e-01],
                        [  1.08062744e-01,   1.08062744e-01],
                        [  1.06475830e-01,   1.06475830e-01],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  1.21520996e-01,   1.21520996e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  6.60095215e-02,   6.60095215e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.04003906e-01,  -1.04003906e-01],
                        [ -1.94244385e-01,  -1.94244385e-01],
                        [ -2.59338379e-01,  -2.59338379e-01],
                        [ -2.76702881e-01,  -2.76702881e-01],
                        [ -2.44445801e-01,  -2.44445801e-01],
                        [ -1.86614990e-01,  -1.86614990e-01],
                        [ -1.35253906e-01,  -1.35253906e-01],
                        [ -1.09100342e-01,  -1.09100342e-01],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -8.02307129e-02,  -8.02307129e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  1.58233643e-01,   1.58233643e-01],
                        [  1.96838379e-01,   1.96838379e-01],
                        [  2.03857422e-01,   2.03857422e-01],
                        [  1.77764893e-01,   1.77764893e-01],
                        [  1.39892578e-01,   1.39892578e-01],
                        [  1.15051270e-01,   1.15051270e-01],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.09680176e-01,   1.09680176e-01],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  4.00695801e-02,   4.00695801e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  6.51855469e-02,   6.51855469e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.06658936e-01,  -1.06658936e-01],
                        [ -1.93786621e-01,  -1.93786621e-01],
                        [ -2.33917236e-01,  -2.33917236e-01],
                        [ -2.16491699e-01,  -2.16491699e-01],
                        [ -1.63208008e-01,  -1.63208008e-01],
                        [ -1.08825684e-01,  -1.08825684e-01],
                        [ -7.58056641e-02,  -7.58056641e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -9.88159180e-02,  -9.88159180e-02],
                        [ -9.07287598e-02,  -9.07287598e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  6.50024414e-02,   6.50024414e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.20758057e-01,   1.20758057e-01],
                        [  1.09527588e-01,   1.09527588e-01],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  1.07879639e-01,   1.07879639e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.23199463e-01,   1.23199463e-01],
                        [  1.30249023e-01,   1.30249023e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  7.40966797e-02,   7.40966797e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -1.76696777e-01,  -1.76696777e-01],
                        [ -2.46582031e-01,  -2.46582031e-01],
                        [ -2.77130127e-01,  -2.77130127e-01],
                        [ -2.54852295e-01,  -2.54852295e-01],
                        [ -1.98760986e-01,  -1.98760986e-01],
                        [ -1.48590088e-01,  -1.48590088e-01],
                        [ -1.25946045e-01,  -1.25946045e-01],
                        [ -1.19903564e-01,  -1.19903564e-01],
                        [ -1.11083984e-01,  -1.11083984e-01],
                        [ -9.53063965e-02,  -9.53063965e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  1.39038086e-01,   1.39038086e-01],
                        [  1.80053711e-01,   1.80053711e-01],
                        [  1.99096680e-01,   1.99096680e-01],
                        [  1.93389893e-01,   1.93389893e-01],
                        [  1.70715332e-01,   1.70715332e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.17523193e-01,   1.17523193e-01],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  8.88061523e-02,   8.88061523e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -1.85516357e-01,  -1.85516357e-01],
                        [ -2.24456787e-01,  -2.24456787e-01],
                        [ -2.05139160e-01,  -2.05139160e-01],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -1.03271484e-01,  -1.03271484e-01],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -7.33032227e-02,  -7.33032227e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -9.13391113e-02,  -9.13391113e-02],
                        [ -1.03515625e-01,  -1.03515625e-01],
                        [ -9.75952148e-02,  -9.75952148e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.31439209e-01,   1.31439209e-01],
                        [  1.16607666e-01,   1.16607666e-01],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.73413086e-02,   8.73413086e-02],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.42944336e-01,   1.42944336e-01],
                        [  1.56494141e-01,   1.56494141e-01],
                        [  1.64581299e-01,   1.64581299e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  7.36999512e-02,   7.36999512e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.19232178e-01,  -1.19232178e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -2.88055420e-01,  -2.88055420e-01],
                        [ -3.05847168e-01,  -3.05847168e-01],
                        [ -2.68615723e-01,  -2.68615723e-01],
                        [ -2.01507568e-01,  -2.01507568e-01],
                        [ -1.43707275e-01,  -1.43707275e-01],
                        [ -1.15142822e-01,  -1.15142822e-01],
                        [ -1.05224609e-01,  -1.05224609e-01],
                        [ -9.73510742e-02,  -9.73510742e-02],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -8.81652832e-02,  -8.81652832e-02],
                        [ -8.55712891e-02,  -8.55712891e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.74530029e-01,   1.74530029e-01],
                        [  1.97967529e-01,   1.97967529e-01],
                        [  1.96716309e-01,   1.96716309e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.35375977e-01,   1.35375977e-01],
                        [  1.24969482e-01,   1.24969482e-01],
                        [  1.08612061e-01,   1.08612061e-01],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.02941895e-02,  -2.02941895e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  8.39843750e-02,   8.39843750e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -1.10809326e-01,  -1.10809326e-01],
                        [ -1.83929443e-01,  -1.83929443e-01],
                        [ -2.11120605e-01,  -2.11120605e-01],
                        [ -1.83258057e-01,  -1.83258057e-01],
                        [ -1.27502441e-01,  -1.27502441e-01],
                        [ -8.33435059e-02,  -8.33435059e-02],
                        [ -6.94580078e-02,  -6.94580078e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -6.68945312e-02,  -6.68945312e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -9.01184082e-02,  -9.01184082e-02],
                        [ -9.53674316e-02,  -9.53674316e-02],
                        [ -8.98742676e-02,  -8.98742676e-02],
                        [ -7.66296387e-02,  -7.66296387e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -6.47888184e-02,  -6.48193359e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  1.10382080e-01,   1.10382080e-01],
                        [  1.23138428e-01,   1.23138428e-01],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  9.29565430e-02,   9.29565430e-02],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.51763916e-01,   1.51763916e-01],
                        [  1.71966553e-01,   1.71966553e-01],
                        [  1.78619385e-01,   1.78619385e-01],
                        [  1.64215088e-01,   1.64215088e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  5.57861328e-02,   5.57861328e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -1.40350342e-01,  -1.40350342e-01],
                        [ -2.33795166e-01,  -2.33795166e-01],
                        [ -2.87689209e-01,  -2.87689209e-01],
                        [ -2.88452148e-01,  -2.88452148e-01],
                        [ -2.47924805e-01,  -2.47924805e-01],
                        [ -1.94305420e-01,  -1.94305420e-01],
                        [ -1.53656006e-01,  -1.53656006e-01],
                        [ -1.33758545e-01,  -1.33758545e-01],
                        [ -1.22772217e-01,  -1.22772217e-01],
                        [ -1.07238770e-01,  -1.07238770e-01],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  6.98547363e-02,   6.98547363e-02],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.66595459e-01,   1.66595459e-01],
                        [  1.93389893e-01,   1.93389893e-01],
                        [  2.02758789e-01,   2.02758789e-01],
                        [  1.95068359e-01,   1.95068359e-01],
                        [  1.76818848e-01,   1.76818848e-01],
                        [  1.57073975e-01,   1.57073975e-01],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  5.03540039e-02,   5.03540039e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.55639648e-03,   1.55639648e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  8.35266113e-02,   8.35266113e-02],
                        [  8.65783691e-02,   8.65783691e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -1.15051270e-01,  -1.15051270e-01],
                        [ -1.79992676e-01,  -1.79992676e-01],
                        [ -2.02178955e-01,  -2.02178955e-01],
                        [ -1.78100586e-01,  -1.78100586e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -8.51135254e-02,  -8.51135254e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -8.63037109e-02,  -8.63037109e-02],
                        [ -9.24987793e-02,  -9.24987793e-02],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -8.45947266e-02,  -8.45947266e-02],
                        [ -7.84912109e-02,  -7.84912109e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.29791260e-01,   1.29791260e-01],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  8.93249512e-02,   8.93249512e-02],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  1.03759766e-01,   1.03729248e-01],
                        [  1.14654541e-01,   1.14654541e-01],
                        [  1.25000000e-01,   1.25000000e-01],
                        [  1.37176514e-01,   1.37176514e-01],
                        [  1.53747559e-01,   1.53747559e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.85607910e-01,   1.85607910e-01],
                        [  1.79046631e-01,   1.79046631e-01],
                        [  1.46972656e-01,   1.46972656e-01],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.07940674e-01,  -1.07940674e-01],
                        [ -2.14385986e-01,  -2.14385986e-01],
                        [ -2.90740967e-01,  -2.90740967e-01],
                        [ -3.12866211e-01,  -3.12866211e-01],
                        [ -2.72460938e-01,  -2.72460938e-01],
                        [ -1.93695068e-01,  -1.93695068e-01],
                        [ -1.27075195e-01,  -1.27075195e-01],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -1.11511230e-01,  -1.11511230e-01],
                        [ -1.12335205e-01,  -1.12335205e-01],
                        [ -9.80834961e-02,  -9.80834961e-02],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -7.85827637e-02,  -7.85827637e-02],
                        [ -7.25708008e-02,  -7.25708008e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.37219238e-02,  -3.36914062e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  1.50939941e-01,   1.50939941e-01],
                        [  1.86706543e-01,   1.86706543e-01],
                        [  1.98394775e-01,   1.98394775e-01],
                        [  1.84692383e-01,   1.84692383e-01],
                        [  1.55487061e-01,   1.55487061e-01],
                        [  1.30371094e-01,   1.30371094e-01],
                        [  1.21734619e-01,   1.21734619e-01],
                        [  1.23596191e-01,   1.23596191e-01],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.18255615e-01,   1.18255615e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  8.85009766e-04,   8.85009766e-04],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  9.52758789e-02,   9.52758789e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -1.39617920e-01,  -1.39617920e-01],
                        [ -1.88110352e-01,  -1.88110352e-01],
                        [ -1.92687988e-01,  -1.92687988e-01],
                        [ -1.63970947e-01,  -1.63940430e-01],
                        [ -1.30554199e-01,  -1.30554199e-01],
                        [ -1.12152100e-01,  -1.12152100e-01],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -1.10198975e-01,  -1.10198975e-01],
                        [ -1.10473633e-01,  -1.10473633e-01],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -9.46960449e-02,  -9.46960449e-02],
                        [ -8.49609375e-02,  -8.49609375e-02],
                        [ -7.73315430e-02,  -7.73315430e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  1.19476318e-01,   1.19476318e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  1.27441406e-01,   1.27441406e-01],
                        [  1.21673584e-01,   1.21704102e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.71264648e-01,   1.71264648e-01],
                        [  1.85729980e-01,   1.85729980e-01],
                        [  1.75598145e-01,   1.75598145e-01],
                        [  1.33605957e-01,   1.33605957e-01],
                        [  5.94482422e-02,   5.94482422e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -1.51062012e-01,  -1.51062012e-01],
                        [ -2.46582031e-01,  -2.46582031e-01],
                        [ -2.98370361e-01,  -2.98370361e-01],
                        [ -2.90710449e-01,  -2.90710449e-01],
                        [ -2.36022949e-01,  -2.36022949e-01],
                        [ -1.72332764e-01,  -1.72332764e-01],
                        [ -1.35986328e-01,  -1.35986328e-01],
                        [ -1.32385254e-01,  -1.32385254e-01],
                        [ -1.37847900e-01,  -1.37847900e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -1.08764648e-01,  -1.08764648e-01],
                        [ -8.42895508e-02,  -8.42895508e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  1.58050537e-01,   1.58050537e-01],
                        [  1.99188232e-01,   1.99188232e-01],
                        [  2.10449219e-01,   2.10449219e-01],
                        [  1.96350098e-01,   1.96350098e-01],
                        [  1.73126221e-01,   1.73126221e-01],
                        [  1.50909424e-01,   1.50909424e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  8.25805664e-02,   8.25805664e-02],
                        [  7.97119141e-02,   7.97119141e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [ -6.16455078e-02,  -6.16455078e-02],
                        [ -1.43493652e-01,  -1.43493652e-01],
                        [ -1.96136475e-01,  -1.96136475e-01],
                        [ -2.07550049e-01,  -2.07550049e-01],
                        [ -1.85577393e-01,  -1.85577393e-01],
                        [ -1.51397705e-01,  -1.51397705e-01],
                        [ -1.23596191e-01,  -1.23596191e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -9.74121094e-02,  -9.74121094e-02],
                        [ -8.61206055e-02,  -8.61206055e-02],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -7.15637207e-02,  -7.15942383e-02],
                        [ -8.23974609e-02,  -8.23974609e-02],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  1.17309570e-01,   1.17309570e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.15234375e-01,   1.15234375e-01],
                        [  1.05010986e-01,   1.05010986e-01],
                        [  9.98229980e-02,   9.98229980e-02],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.52587891e-01,   1.52587891e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.95617676e-01,   1.95617676e-01],
                        [  1.99279785e-01,   1.99249268e-01],
                        [  1.81213379e-01,   1.81213379e-01],
                        [  1.35894775e-01,   1.35894775e-01],
                        [  6.11572266e-02,   6.11572266e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -1.47430420e-01,  -1.47430420e-01],
                        [ -2.46917725e-01,  -2.46917725e-01],
                        [ -3.12408447e-01,  -3.12408447e-01],
                        [ -3.23669434e-01,  -3.23669434e-01],
                        [ -2.77038574e-01,  -2.77038574e-01],
                        [ -1.97418213e-01,  -1.97418213e-01],
                        [ -1.27807617e-01,  -1.27807617e-01],
                        [ -9.63745117e-02,  -9.63745117e-02],
                        [ -9.62219238e-02,  -9.62219238e-02],
                        [ -1.01043701e-01,  -1.01043701e-01],
                        [ -9.50012207e-02,  -9.50012207e-02],
                        [ -8.16040039e-02,  -8.16040039e-02],
                        [ -7.03735352e-02,  -7.03735352e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -7.11059570e-02,  -7.11059570e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  7.31201172e-02,   7.31201172e-02],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  1.70776367e-01,   1.70776367e-01],
                        [  1.97143555e-01,   1.97143555e-01],
                        [  1.94458008e-01,   1.94458008e-01],
                        [  1.69189453e-01,   1.69189453e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.28906250e-01,   1.28936768e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  1.06475830e-01,   1.06475830e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  1.00097656e-01,   1.00097656e-01],
                        [  9.69238281e-02,   9.69238281e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  4.48608398e-03,   4.51660156e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -7.78198242e-03,  -7.81250000e-03],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  7.33032227e-02,   7.33032227e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  8.59680176e-02,   8.59680176e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -1.06536865e-01,  -1.06536865e-01],
                        [ -1.70715332e-01,  -1.70715332e-01],
                        [ -1.93542480e-01,  -1.93542480e-01],
                        [ -1.76055908e-01,  -1.76055908e-01],
                        [ -1.39160156e-01,  -1.39160156e-01],
                        [ -1.10687256e-01,  -1.10687256e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.13494873e-01,  -1.13494873e-01],
                        [ -1.16058350e-01,  -1.16058350e-01],
                        [ -1.04492188e-01,  -1.04492188e-01],
                        [ -8.79516602e-02,  -8.79516602e-02],
                        [ -8.04138184e-02,  -8.03833008e-02],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -8.49914551e-02,  -8.49914551e-02],
                        [ -7.51953125e-02,  -7.51647949e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.22955322e-01,   1.22955322e-01],
                        [  1.18103027e-01,   1.18103027e-01],
                        [  1.14807129e-01,   1.14807129e-01],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.43524170e-01,   1.43524170e-01],
                        [  1.71020508e-01,   1.71020508e-01],
                        [  1.94915771e-01,   1.94915771e-01],
                        [  2.02026367e-01,   2.02026367e-01],
                        [  1.90093994e-01,   1.90093994e-01],
                        [  1.59149170e-01,   1.59149170e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.55944824e-02,   1.55944824e-02],
                        [ -9.81445312e-02,  -9.81445312e-02],
                        [ -2.15423584e-01,  -2.15423584e-01],
                        [ -2.99865723e-01,  -2.99865723e-01],
                        [ -3.21685791e-01,  -3.21685791e-01],
                        [ -2.81768799e-01,  -2.81768799e-01],
                        [ -2.11120605e-01,  -2.11120605e-01],
                        [ -1.46423340e-01,  -1.46423340e-01],
                        [ -1.08551025e-01,  -1.08551025e-01],
                        [ -9.68017578e-02,  -9.68017578e-02],
                        [ -9.48791504e-02,  -9.48791504e-02],
                        [ -8.71582031e-02,  -8.71582031e-02],
                        [ -7.43408203e-02,  -7.43408203e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  1.60308838e-01,   1.60308838e-01],
                        [  1.87500000e-01,   1.87500000e-01],
                        [  1.88293457e-01,   1.88293457e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  1.55944824e-01,   1.55944824e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.37115479e-01,   1.37115479e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  4.85229492e-03,   4.85229492e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  6.37512207e-02,   6.37512207e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  4.78515625e-02,   4.78515625e-02],
                        [ -1.01318359e-02,  -1.01623535e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -1.38885498e-01,  -1.38885498e-01],
                        [ -1.73797607e-01,  -1.73797607e-01],
                        [ -1.73553467e-01,  -1.73553467e-01],
                        [ -1.51397705e-01,  -1.51397705e-01],
                        [ -1.30096436e-01,  -1.30096436e-01],
                        [ -1.22711182e-01,  -1.22711182e-01],
                        [ -1.26312256e-01,  -1.26312256e-01],
                        [ -1.28204346e-01,  -1.28204346e-01],
                        [ -1.18927002e-01,  -1.18927002e-01],
                        [ -1.03027344e-01,  -1.03027344e-01],
                        [ -9.34143066e-02,  -9.33837891e-02],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  1.00982666e-01,   1.00982666e-01],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.40563965e-01,   1.40563965e-01],
                        [  1.56951904e-01,   1.56921387e-01],
                        [  1.74743652e-01,   1.74743652e-01],
                        [  1.95037842e-01,   1.95037842e-01],
                        [  2.12646484e-01,   2.12646484e-01],
                        [  2.14202881e-01,   2.14202881e-01],
                        [  1.86187744e-01,   1.86187744e-01],
                        [  1.22344971e-01,   1.22344971e-01],
                        [  2.66723633e-02,   2.66723633e-02],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -1.96990967e-01,  -1.96990967e-01],
                        [ -2.83203125e-01,  -2.83203125e-01],
                        [ -3.20373535e-01,  -3.20373535e-01],
                        [ -2.95532227e-01,  -2.95532227e-01],
                        [ -2.28576660e-01,  -2.28576660e-01],
                        [ -1.62841797e-01,  -1.62841797e-01],
                        [ -1.27349854e-01,  -1.27349854e-01],
                        [ -1.17126465e-01,  -1.17126465e-01],
                        [ -1.11358643e-01,  -1.11358643e-01],
                        [ -9.77172852e-02,  -9.77172852e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -8.93249512e-02,  -8.93249512e-02],
                        [ -8.21838379e-02,  -8.21838379e-02],
                        [ -6.82067871e-02,  -6.82067871e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  6.66198730e-02,   6.66198730e-02],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.88171387e-01,   1.88171387e-01],
                        [  2.16674805e-01,   2.16674805e-01],
                        [  2.09197998e-01,   2.09197998e-01],
                        [  1.80755615e-01,   1.80755615e-01],
                        [  1.54937744e-01,   1.54937744e-01],
                        [  1.41143799e-01,   1.41143799e-01],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.24969482e-01,   1.24969482e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  9.42382812e-02,   9.42382812e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  7.44628906e-03,   7.44628906e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  2.12402344e-02,   2.12097168e-02],
                        [  3.55529785e-02,   3.55834961e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  4.62646484e-02,   4.62646484e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -9.54895020e-02,  -9.54895020e-02],
                        [ -1.69250488e-01,  -1.69250488e-01],
                        [ -2.13348389e-01,  -2.13348389e-01],
                        [ -2.12524414e-01,  -2.12524414e-01],
                        [ -1.78771973e-01,  -1.78771973e-01],
                        [ -1.41174316e-01,  -1.41174316e-01],
                        [ -1.17767334e-01,  -1.17767334e-01],
                        [ -1.05163574e-01,  -1.05163574e-01],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -9.03625488e-02,  -9.03625488e-02],
                        [ -9.49401855e-02,  -9.49401855e-02],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -1.16149902e-01,  -1.16149902e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -9.89685059e-02,  -9.89685059e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  1.24542236e-01,   1.24511719e-01],
                        [  1.23260498e-01,   1.23260498e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.46850586e-01,   1.46850586e-01],
                        [  1.66137695e-01,   1.66137695e-01],
                        [  1.87377930e-01,   1.87377930e-01],
                        [  2.07580566e-01,   2.07580566e-01],
                        [  2.20703125e-01,   2.20703125e-01],
                        [  2.14721680e-01,   2.14721680e-01],
                        [  1.76422119e-01,   1.76422119e-01],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  2.07519531e-03,   2.07519531e-03],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -2.20916748e-01,  -2.20916748e-01],
                        [ -3.02673340e-01,  -3.02673340e-01],
                        [ -3.30322266e-01,  -3.30322266e-01],
                        [ -2.96295166e-01,  -2.96295166e-01],
                        [ -2.23999023e-01,  -2.23999023e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.15722656e-01,  -1.15722656e-01],
                        [ -1.06475830e-01,  -1.06475830e-01],
                        [ -1.08428955e-01,  -1.08428955e-01],
                        [ -1.08062744e-01,  -1.08062744e-01],
                        [ -1.02996826e-01,  -1.02996826e-01],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  1.33087158e-01,   1.33087158e-01],
                        [  1.93176270e-01,   1.93176270e-01],
                        [  2.26135254e-01,   2.26135254e-01],
                        [  2.26318359e-01,   2.26318359e-01],
                        [  2.00683594e-01,   2.00683594e-01],
                        [  1.64855957e-01,   1.64855957e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.20513916e-01,   1.20513916e-01],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  8.50524902e-02,   8.50524902e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  7.62329102e-02,   7.62329102e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  1.52587891e-02,   1.52282715e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.25885010e-01,   1.25885010e-01],
                        [  1.10382080e-01,   1.10382080e-01],
                        [  6.46362305e-02,   6.46362305e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -2.10571289e-01,  -2.10571289e-01],
                        [ -2.06848145e-01,  -2.06848145e-01],
                        [ -1.73583984e-01,  -1.73583984e-01],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.20117188e-01,  -1.20086670e-01],
                        [ -1.17095947e-01,  -1.17095947e-01],
                        [ -1.09283447e-01,  -1.09283447e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -1.07910156e-01,  -1.07910156e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -1.10534668e-01,  -1.10534668e-01],
                        [ -9.46960449e-02,  -9.46960449e-02],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.66308594e-02,  -4.66003418e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  1.20208740e-01,   1.20178223e-01],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  9.87548828e-02,   9.87548828e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.32476807e-01,   1.32476807e-01],
                        [  1.50756836e-01,   1.50756836e-01],
                        [  1.63269043e-01,   1.63269043e-01],
                        [  1.78466797e-01,   1.78466797e-01],
                        [  2.03369141e-01,   2.03369141e-01],
                        [  2.24914551e-01,   2.24914551e-01],
                        [  2.17407227e-01,   2.17407227e-01],
                        [  1.71539307e-01,   1.71539307e-01],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.47094727e-02,   1.47094727e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -2.02148438e-01,  -2.02148438e-01],
                        [ -2.94525146e-01,  -2.94525146e-01],
                        [ -3.29315186e-01,  -3.29315186e-01],
                        [ -2.95898438e-01,  -2.95898438e-01],
                        [ -2.20764160e-01,  -2.20764160e-01],
                        [ -1.51550293e-01,  -1.51550293e-01],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -1.14654541e-01,  -1.14654541e-01],
                        [ -1.13769531e-01,  -1.13769531e-01],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -1.12121582e-01,  -1.12121582e-01],
                        [ -1.15997314e-01,  -1.15997314e-01],
                        [ -1.11755371e-01,  -1.11755371e-01],
                        [ -9.54589844e-02,  -9.54589844e-02],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  1.97326660e-01,   1.97326660e-01],
                        [  2.35107422e-01,   2.35107422e-01],
                        [  2.27630615e-01,   2.27630615e-01],
                        [  1.82495117e-01,   1.82495117e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.16271973e-01,   1.16271973e-01],
                        [  1.18377686e-01,   1.18377686e-01],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.17401123e-01,   1.17401123e-01],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -1.50146484e-02,  -1.49841309e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  8.18481445e-02,   8.18481445e-02],
                        [  9.86633301e-02,   9.86633301e-02],
                        [  1.05651855e-01,   1.05651855e-01],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -1.11267090e-01,  -1.11267090e-01],
                        [ -1.75689697e-01,  -1.75689697e-01],
                        [ -2.04254150e-01,  -2.04254150e-01],
                        [ -1.91436768e-01,  -1.91436768e-01],
                        [ -1.60217285e-01,  -1.60217285e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -1.30889893e-01,  -1.30889893e-01],
                        [ -1.24053955e-01,  -1.24053955e-01],
                        [ -1.13250732e-01,  -1.13250732e-01],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -1.02600098e-01,  -1.02569580e-01],
                        [ -8.46557617e-02,  -8.46557617e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.25000000e-01,   1.25000000e-01],
                        [  1.26098633e-01,   1.26098633e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.38397217e-01,   1.38397217e-01],
                        [  1.61285400e-01,   1.61285400e-01],
                        [  1.80877686e-01,   1.80877686e-01],
                        [  2.04040527e-01,   2.04040527e-01],
                        [  2.21740723e-01,   2.21740723e-01],
                        [  2.14050293e-01,   2.14080811e-01],
                        [  1.73065186e-01,   1.73065186e-01],
                        [  1.03607178e-01,   1.03607178e-01],
                        [  8.11767578e-03,   8.11767578e-03],
                        [ -1.09466553e-01,  -1.09466553e-01],
                        [ -2.27172852e-01,  -2.27172852e-01],
                        [ -3.08319092e-01,  -3.08319092e-01],
                        [ -3.26110840e-01,  -3.26110840e-01],
                        [ -2.84606934e-01,  -2.84606934e-01],
                        [ -2.17681885e-01,  -2.17681885e-01],
                        [ -1.64428711e-01,  -1.64428711e-01],
                        [ -1.39953613e-01,  -1.39953613e-01],
                        [ -1.29577637e-01,  -1.29577637e-01],
                        [ -1.14288330e-01,  -1.14288330e-01],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -8.14819336e-02,  -8.14819336e-02],
                        [ -8.04138184e-02,  -8.04138184e-02],
                        [ -8.76464844e-02,  -8.76464844e-02],
                        [ -9.67712402e-02,  -9.67712402e-02],
                        [ -9.71069336e-02,  -9.71069336e-02],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  1.77246094e-01,   1.77246094e-01],
                        [  2.18170166e-01,   2.18170166e-01],
                        [  2.32208252e-01,   2.32208252e-01],
                        [  2.20550537e-01,   2.20550537e-01],
                        [  1.92199707e-01,   1.92199707e-01],
                        [  1.59484863e-01,   1.59484863e-01],
                        [  1.33636475e-01,   1.33666992e-01],
                        [  1.18011475e-01,   1.18011475e-01],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  7.44934082e-02,   7.44934082e-02],
                        [  6.14013672e-02,   6.13708496e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  9.62524414e-02,   9.62524414e-02],
                        [  8.28247070e-02,   8.28247070e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -1.16271973e-01,  -1.16271973e-01],
                        [ -1.87042236e-01,  -1.87042236e-01],
                        [ -2.11914062e-01,  -2.11914062e-01],
                        [ -1.92657471e-01,  -1.92657471e-01],
                        [ -1.54113770e-01,  -1.54113770e-01],
                        [ -1.21612549e-01,  -1.21612549e-01],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -1.23962402e-01,  -1.23962402e-01],
                        [ -1.25854492e-01,  -1.25854492e-01],
                        [ -1.15112305e-01,  -1.15112305e-01],
                        [ -9.76257324e-02,  -9.76562500e-02],
                        [ -7.91625977e-02,  -7.91625977e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  9.93347168e-02,   9.93347168e-02],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  9.39636230e-02,   9.39941406e-02],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.40014648e-01,   1.40014648e-01],
                        [  1.64184570e-01,   1.64215088e-01],
                        [  1.81793213e-01,   1.81793213e-01],
                        [  1.95861816e-01,   1.95861816e-01],
                        [  2.04925537e-01,   2.04925537e-01],
                        [  2.01019287e-01,   2.01019287e-01],
                        [  1.75140381e-01,   1.75140381e-01],
                        [  1.19812012e-01,   1.19812012e-01],
                        [  3.37219238e-02,   3.37219238e-02],
                        [ -7.20520020e-02,  -7.20520020e-02],
                        [ -1.77459717e-01,  -1.77459717e-01],
                        [ -2.61566162e-01,  -2.61566162e-01],
                        [ -3.04534912e-01,  -3.04534912e-01],
                        [ -2.92083740e-01,  -2.92083740e-01],
                        [ -2.31719971e-01,  -2.31719971e-01],
                        [ -1.59881592e-01,  -1.59881592e-01],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.06201172e-01,  -1.06201172e-01],
                        [ -1.10778809e-01,  -1.10778809e-01],
                        [ -1.12579346e-01,  -1.12579346e-01],
                        [ -1.11145020e-01,  -1.11145020e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -1.08459473e-01,  -1.08459473e-01],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -8.82263184e-02,  -8.82263184e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  2.02117920e-01,   2.02117920e-01],
                        [  2.30743408e-01,   2.30743408e-01],
                        [  2.18383789e-01,   2.18383789e-01],
                        [  1.77734375e-01,   1.77734375e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.09985352e-01,   1.09985352e-01],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -2.21557617e-02,  -2.21862793e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  8.04748535e-02,   8.04748535e-02],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [ -5.57861328e-02,  -5.57861328e-02],
                        [ -1.43127441e-01,  -1.43127441e-01],
                        [ -2.01049805e-01,  -2.01049805e-01],
                        [ -2.11944580e-01,  -2.11944580e-01],
                        [ -1.83898926e-01,  -1.83898926e-01],
                        [ -1.44866943e-01,  -1.44866943e-01],
                        [ -1.19079590e-01,  -1.19079590e-01],
                        [ -1.12243652e-01,  -1.12243652e-01],
                        [ -1.16271973e-01,  -1.16271973e-01],
                        [ -1.18499756e-01,  -1.18499756e-01],
                        [ -1.10504150e-01,  -1.10504150e-01],
                        [ -9.65576172e-02,  -9.65576172e-02],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -8.74938965e-02,  -8.74938965e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -6.95495605e-02,  -6.95495605e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  9.31396484e-02,   9.31396484e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.35833740e-01,   1.35833740e-01],
                        [  1.52404785e-01,   1.52404785e-01],
                        [  1.66137695e-01,   1.66137695e-01],
                        [  1.84051514e-01,   1.84082031e-01],
                        [  2.02362061e-01,   2.02362061e-01],
                        [  2.09228516e-01,   2.09228516e-01],
                        [  1.96105957e-01,   1.96105957e-01],
                        [  1.57592773e-01,   1.57592773e-01],
                        [  8.67614746e-02,   8.67614746e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -2.55065918e-01,  -2.55096436e-01],
                        [ -3.14880371e-01,  -3.14880371e-01],
                        [ -3.05389404e-01,  -3.05389404e-01],
                        [ -2.43194580e-01,  -2.43194580e-01],
                        [ -1.73767090e-01,  -1.73767090e-01],
                        [ -1.36627197e-01,  -1.36627197e-01],
                        [ -1.33850098e-01,  -1.33850098e-01],
                        [ -1.39343262e-01,  -1.39343262e-01],
                        [ -1.35070801e-01,  -1.35101318e-01],
                        [ -1.27349854e-01,  -1.27349854e-01],
                        [ -1.26708984e-01,  -1.26708984e-01],
                        [ -1.28326416e-01,  -1.28326416e-01],
                        [ -1.20574951e-01,  -1.20574951e-01],
                        [ -1.00006104e-01,  -1.00006104e-01],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  9.71984863e-02,   9.71984863e-02],
                        [  1.46026611e-01,   1.46026611e-01],
                        [  1.81915283e-01,   1.81915283e-01],
                        [  1.99035645e-01,   1.99035645e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.65435791e-01,   1.65435791e-01],
                        [  1.38732910e-01,   1.38732910e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.18560791e-01,   1.18560791e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.21734619e-01,   1.21734619e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  7.49511719e-02,   7.49511719e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.99072266e-02,  -2.99377441e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -1.76361084e-01,  -1.76361084e-01],
                        [ -2.27264404e-01,  -2.27264404e-01],
                        [ -2.27020264e-01,  -2.27020264e-01],
                        [ -1.87622070e-01,  -1.87622070e-01],
                        [ -1.43585205e-01,  -1.43554688e-01],
                        [ -1.18743896e-01,  -1.18743896e-01],
                        [ -1.09252930e-01,  -1.09252930e-01],
                        [ -1.01959229e-01,  -1.01928711e-01],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -8.78906250e-02,  -8.78906250e-02],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -1.05133057e-01,  -1.05133057e-01],
                        [ -1.11236572e-01,  -1.11236572e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.29455566e-01,   1.29455566e-01],
                        [  1.49078369e-01,   1.49078369e-01],
                        [  1.71264648e-01,   1.71264648e-01],
                        [  2.02026367e-01,   2.01995850e-01],
                        [  2.31353760e-01,   2.31353760e-01],
                        [  2.34924316e-01,   2.34924316e-01],
                        [  1.96563721e-01,   1.96563721e-01],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  8.91113281e-03,   8.91113281e-03],
                        [ -1.16333008e-01,  -1.16333008e-01],
                        [ -2.36114502e-01,  -2.36114502e-01],
                        [ -3.18817139e-01,  -3.18817139e-01],
                        [ -3.36883545e-01,  -3.36883545e-01],
                        [ -2.90161133e-01,  -2.90161133e-01],
                        [ -2.12921143e-01,  -2.12921143e-01],
                        [ -1.50207520e-01,  -1.50207520e-01],
                        [ -1.23992920e-01,  -1.23992920e-01],
                        [ -1.23870850e-01,  -1.23870850e-01],
                        [ -1.27899170e-01,  -1.27899170e-01],
                        [ -1.24450684e-01,  -1.24450684e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -1.07208252e-01,  -1.07208252e-01],
                        [ -1.05010986e-01,  -1.05010986e-01],
                        [ -1.04705811e-01,  -1.04705811e-01],
                        [ -9.34753418e-02,  -9.34753418e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  7.91015625e-02,   7.91015625e-02],
                        [  1.50604248e-01,   1.50604248e-01],
                        [  2.04528809e-01,   2.04528809e-01],
                        [  2.31384277e-01,   2.31384277e-01],
                        [  2.28149414e-01,   2.28149414e-01],
                        [  2.02270508e-01,   2.02270508e-01],
                        [  1.67510986e-01,   1.67510986e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  8.70971680e-02,   8.70971680e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  9.93957520e-02,   9.93957520e-02],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -1.24023438e-01,  -1.24023438e-01],
                        [ -1.75689697e-01,  -1.75720215e-01],
                        [ -2.02209473e-01,  -2.02209473e-01],
                        [ -1.98303223e-01,  -1.98303223e-01],
                        [ -1.72546387e-01,  -1.72546387e-01],
                        [ -1.44287109e-01,  -1.44287109e-01],
                        [ -1.25274658e-01,  -1.25274658e-01],
                        [ -1.12304688e-01,  -1.12304688e-01],
                        [ -1.00982666e-01,  -1.00982666e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -9.20410156e-02,  -9.20410156e-02],
                        [ -9.23156738e-02,  -9.23156738e-02],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -8.99047852e-02,  -8.99047852e-02],
                        [ -8.73413086e-02,  -8.73413086e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.31896973e-01,   1.31896973e-01],
                        [  1.26190186e-01,   1.26220703e-01],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  1.29425049e-01,   1.29425049e-01],
                        [  1.50695801e-01,   1.50695801e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  2.08709717e-01,   2.08709717e-01],
                        [  2.26257324e-01,   2.26257324e-01],
                        [  2.09930420e-01,   2.09930420e-01],
                        [  1.52404785e-01,   1.52404785e-01],
                        [  6.36596680e-02,   6.36596680e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -1.50451660e-01,  -1.50451660e-01],
                        [ -2.46673584e-01,  -2.46673584e-01],
                        [ -3.02215576e-01,  -3.02215576e-01],
                        [ -2.95135498e-01,  -2.95135498e-01],
                        [ -2.36694336e-01,  -2.36694336e-01],
                        [ -1.71966553e-01,  -1.71966553e-01],
                        [ -1.39648438e-01,  -1.39648438e-01],
                        [ -1.37329102e-01,  -1.37329102e-01],
                        [ -1.38427734e-01,  -1.38427734e-01],
                        [ -1.30737305e-01,  -1.30737305e-01],
                        [ -1.22558594e-01,  -1.22558594e-01],
                        [ -1.22894287e-01,  -1.22894287e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -1.33636475e-01,  -1.33636475e-01],
                        [ -1.19628906e-01,  -1.19628906e-01],
                        [ -7.85827637e-02,  -7.85827637e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  1.51885986e-01,   1.51885986e-01],
                        [  2.12493896e-01,   2.12493896e-01],
                        [  2.38189697e-01,   2.38189697e-01],
                        [  2.29217529e-01,   2.29217529e-01],
                        [  2.00012207e-01,   2.00012207e-01],
                        [  1.67724609e-01,   1.67724609e-01],
                        [  1.41784668e-01,   1.41784668e-01],
                        [  1.20239258e-01,   1.20239258e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  8.36181641e-02,   8.36181641e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  9.01489258e-02,   9.01489258e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  6.40869141e-03,   6.43920898e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.01898193e-01,  -1.01898193e-01],
                        [ -1.76757812e-01,  -1.76757812e-01],
                        [ -2.19421387e-01,  -2.19421387e-01],
                        [ -2.19848633e-01,  -2.19848633e-01],
                        [ -1.92077637e-01,  -1.92077637e-01],
                        [ -1.60491943e-01,  -1.60491943e-01],
                        [ -1.39801025e-01,  -1.39801025e-01],
                        [ -1.28845215e-01,  -1.28845215e-01],
                        [ -1.18591309e-01,  -1.18560791e-01],
                        [ -1.02325439e-01,  -1.02325439e-01],
                        [ -8.30993652e-02,  -8.30993652e-02],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.36993408e-01,   1.36993408e-01],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.05529785e-01,   1.05529785e-01],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.68395996e-01,   1.68395996e-01],
                        [  2.02667236e-01,   2.02667236e-01],
                        [  2.20123291e-01,   2.20123291e-01],
                        [  2.13378906e-01,   2.13378906e-01],
                        [  1.75811768e-01,   1.75811768e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -1.17950439e-01,  -1.17950439e-01],
                        [ -2.27996826e-01,  -2.27996826e-01],
                        [ -3.01391602e-01,  -3.01391602e-01],
                        [ -3.15887451e-01,  -3.15887451e-01],
                        [ -2.75024414e-01,  -2.75024414e-01],
                        [ -2.12524414e-01,  -2.12524414e-01],
                        [ -1.66351318e-01,  -1.66351318e-01],
                        [ -1.47888184e-01,  -1.47888184e-01],
                        [ -1.43188477e-01,  -1.43188477e-01],
                        [ -1.37786865e-01,  -1.37756348e-01],
                        [ -1.30249023e-01,  -1.30249023e-01],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.22497559e-01,  -1.22497559e-01],
                        [ -1.13311768e-01,  -1.13311768e-01],
                        [ -9.06066895e-02,  -9.06066895e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  1.54296875e-01,   1.54296875e-01],
                        [  2.11975098e-01,   2.11975098e-01],
                        [  2.36450195e-01,   2.36450195e-01],
                        [  2.23876953e-01,   2.23876953e-01],
                        [  1.85760498e-01,   1.85760498e-01],
                        [  1.43493652e-01,   1.43493652e-01],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.13616943e-01,   1.13616943e-01],
                        [  1.10351562e-01,   1.10351562e-01],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  8.47778320e-02,   8.47778320e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -1.20727539e-01,  -1.20727539e-01],
                        [ -1.85089111e-01,  -1.85089111e-01],
                        [ -2.10876465e-01,  -2.10876465e-01],
                        [ -1.99493408e-01,  -1.99493408e-01],
                        [ -1.72698975e-01,  -1.72698975e-01],
                        [ -1.48956299e-01,  -1.48956299e-01],
                        [ -1.33850098e-01,  -1.33850098e-01],
                        [ -1.26251221e-01,  -1.26251221e-01],
                        [ -1.23107910e-01,  -1.23107910e-01],
                        [ -1.20086670e-01,  -1.20086670e-01],
                        [ -1.14196777e-01,  -1.14196777e-01],
                        [ -1.08093262e-01,  -1.08093262e-01],
                        [ -1.05804443e-01,  -1.05804443e-01],
                        [ -1.02264404e-01,  -1.02264404e-01],
                        [ -8.67614746e-02,  -8.67614746e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.64703369e-01,   1.64703369e-01],
                        [  1.95281982e-01,   1.95281982e-01],
                        [  2.10968018e-01,   2.10968018e-01],
                        [  2.06359863e-01,   2.06359863e-01],
                        [  1.77734375e-01,   1.77734375e-01],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -1.20300293e-01,  -1.20300293e-01],
                        [ -2.43164062e-01,  -2.43164062e-01],
                        [ -3.21441650e-01,  -3.21441650e-01],
                        [ -3.30627441e-01,  -3.30627441e-01],
                        [ -2.77191162e-01,  -2.77191162e-01],
                        [ -2.02423096e-01,  -2.02423096e-01],
                        [ -1.52130127e-01,  -1.52130127e-01],
                        [ -1.37756348e-01,  -1.37756348e-01],
                        [ -1.38336182e-01,  -1.38336182e-01],
                        [ -1.36993408e-01,  -1.36993408e-01],
                        [ -1.36199951e-01,  -1.36199951e-01],
                        [ -1.38397217e-01,  -1.38397217e-01],
                        [ -1.33239746e-01,  -1.33239746e-01],
                        [ -1.11358643e-01,  -1.11358643e-01],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.64855957e-01,   1.64855957e-01],
                        [  2.16979980e-01,   2.16979980e-01],
                        [  2.32849121e-01,   2.32849121e-01],
                        [  2.11029053e-01,   2.11029053e-01],
                        [  1.70074463e-01,   1.70074463e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -7.00683594e-02,  -7.00683594e-02],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.98242188e-01,  -1.98242188e-01],
                        [ -2.16430664e-01,  -2.16430664e-01],
                        [ -2.00134277e-01,  -2.00134277e-01],
                        [ -1.69036865e-01,  -1.69036865e-01],
                        [ -1.42944336e-01,  -1.42944336e-01],
                        [ -1.28997803e-01,  -1.28997803e-01],
                        [ -1.20605469e-01,  -1.20605469e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -9.76562500e-02,  -9.76562500e-02],
                        [ -9.06677246e-02,  -9.06677246e-02],
                        [ -8.77685547e-02,  -8.77685547e-02],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  8.64868164e-02,   8.64868164e-02],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.41479492e-01,   1.41479492e-01],
                        [  1.65069580e-01,   1.65069580e-01],
                        [  1.89849854e-01,   1.89849854e-01],
                        [  2.09289551e-01,   2.09289551e-01],
                        [  2.11700439e-01,   2.11700439e-01],
                        [  1.79443359e-01,   1.79443359e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.43585205e-01,  -1.43585205e-01],
                        [ -2.50030518e-01,  -2.50030518e-01],
                        [ -3.10424805e-01,  -3.10424805e-01],
                        [ -3.08929443e-01,  -3.08929443e-01],
                        [ -2.50793457e-01,  -2.50793457e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -1.22406006e-01,  -1.22406006e-01],
                        [ -1.17614746e-01,  -1.17614746e-01],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -1.56219482e-01,  -1.56219482e-01],
                        [ -1.67022705e-01,  -1.67022705e-01],
                        [ -1.66992188e-01,  -1.66992188e-01],
                        [ -1.49810791e-01,  -1.49810791e-01],
                        [ -1.13067627e-01,  -1.13067627e-01],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.92108154e-01,   1.92108154e-01],
                        [  2.28424072e-01,   2.28424072e-01],
                        [  2.29583740e-01,   2.29583740e-01],
                        [  1.98577881e-01,   1.98577881e-01],
                        [  1.56311035e-01,   1.56311035e-01],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  8.94775391e-02,   8.94775391e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -1.03424072e-01,  -1.03424072e-01],
                        [ -1.66412354e-01,  -1.66412354e-01],
                        [ -2.08099365e-01,  -2.08099365e-01],
                        [ -2.18048096e-01,  -2.18048096e-01],
                        [ -1.96441650e-01,  -1.96441650e-01],
                        [ -1.56799316e-01,  -1.56799316e-01],
                        [ -1.21948242e-01,  -1.21948242e-01],
                        [ -1.06658936e-01,  -1.06658936e-01],
                        [ -1.04766846e-01,  -1.04766846e-01],
                        [ -9.88464355e-02,  -9.88464355e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -9.06982422e-02,  -9.06982422e-02],
                        [ -9.77478027e-02,  -9.77478027e-02],
                        [ -8.87145996e-02,  -8.87145996e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  1.16394043e-01,   1.16394043e-01],
                        [  1.39038086e-01,   1.39038086e-01],
                        [  1.44287109e-01,   1.44287109e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.37817383e-01,   1.37817383e-01],
                        [  1.41540527e-01,   1.41540527e-01],
                        [  1.57348633e-01,   1.57348633e-01],
                        [  1.86248779e-01,   1.86248779e-01],
                        [  2.16674805e-01,   2.16674805e-01],
                        [  2.28790283e-01,   2.28790283e-01],
                        [  2.10754395e-01,   2.10754395e-01],
                        [  1.61163330e-01,   1.61163330e-01],
                        [  8.02307129e-02,   8.02307129e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -1.52648926e-01,  -1.52648926e-01],
                        [ -2.62084961e-01,  -2.62084961e-01],
                        [ -3.23760986e-01,  -3.23760986e-01],
                        [ -3.17443848e-01,  -3.17443848e-01],
                        [ -2.55737305e-01,  -2.55737305e-01],
                        [ -1.81945801e-01,  -1.81945801e-01],
                        [ -1.38305664e-01,  -1.38305664e-01],
                        [ -1.32263184e-01,  -1.32263184e-01],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -1.24206543e-01,  -1.24206543e-01],
                        [ -1.14776611e-01,  -1.14776611e-01],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.63818359e-01,   1.63818359e-01],
                        [  2.06573486e-01,   2.06573486e-01],
                        [  2.20001221e-01,   2.20001221e-01],
                        [  1.99249268e-01,   1.99249268e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  8.43505859e-02,   8.43505859e-02],
                        [  8.70056152e-02,   8.70056152e-02],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.22973633e-02,   4.22973633e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  5.33447266e-02,   5.33447266e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -1.70135498e-01,  -1.70135498e-01],
                        [ -2.08923340e-01,  -2.08923340e-01],
                        [ -2.14996338e-01,  -2.14996338e-01],
                        [ -1.90460205e-01,  -1.90460205e-01],
                        [ -1.51275635e-01,  -1.51275635e-01],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.05285645e-01,  -1.05285645e-01],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.05865479e-01,  -1.05865479e-01],
                        [ -1.00158691e-01,  -1.00158691e-01],
                        [ -9.16748047e-02,  -9.16748047e-02],
                        [ -8.58459473e-02,  -8.58459473e-02],
                        [ -8.26416016e-02,  -8.26416016e-02],
                        [ -7.47070312e-02,  -7.47070312e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  1.19232178e-01,   1.19232178e-01],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.40930176e-01,   1.40930176e-01],
                        [  1.64581299e-01,   1.64581299e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  2.20031738e-01,   2.20031738e-01],
                        [  2.15545654e-01,   2.15545654e-01],
                        [  1.80206299e-01,   1.80206299e-01],
                        [  1.14898682e-01,   1.14898682e-01],
                        [  1.76696777e-02,   1.76696777e-02],
                        [ -1.04095459e-01,  -1.04095459e-01],
                        [ -2.22473145e-01,  -2.22473145e-01],
                        [ -2.99041748e-01,  -2.99041748e-01],
                        [ -3.08197021e-01,  -3.08197021e-01],
                        [ -2.58392334e-01,  -2.58392334e-01],
                        [ -1.90612793e-01,  -1.90612793e-01],
                        [ -1.47033691e-01,  -1.47033691e-01],
                        [ -1.39526367e-01,  -1.39526367e-01],
                        [ -1.50573730e-01,  -1.50573730e-01],
                        [ -1.58264160e-01,  -1.58264160e-01],
                        [ -1.53076172e-01,  -1.53076172e-01],
                        [ -1.35925293e-01,  -1.35925293e-01],
                        [ -1.10748291e-01,  -1.10748291e-01],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  1.69097900e-01,   1.69097900e-01],
                        [  2.23449707e-01,   2.23449707e-01],
                        [  2.39318848e-01,   2.39318848e-01],
                        [  2.16430664e-01,   2.16430664e-01],
                        [  1.73583984e-01,   1.73583984e-01],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  8.29467773e-02,   8.29467773e-02],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -1.54846191e-01,  -1.54846191e-01],
                        [ -2.06146240e-01,  -2.06146240e-01],
                        [ -2.15484619e-01,  -2.15484619e-01],
                        [ -1.87225342e-01,  -1.87225342e-01],
                        [ -1.48284912e-01,  -1.48284912e-01],
                        [ -1.21337891e-01,  -1.21337891e-01],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -9.97924805e-02,  -9.97924805e-02],
                        [ -9.52453613e-02,  -9.52453613e-02],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -9.57641602e-02,  -9.57641602e-02],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -7.41882324e-02,  -7.41882324e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.62231445e-01,   1.62231445e-01],
                        [  1.62170410e-01,   1.62170410e-01],
                        [  1.51092529e-01,   1.51092529e-01],
                        [  1.52069092e-01,   1.52069092e-01],
                        [  1.73309326e-01,   1.73309326e-01],
                        [  1.99218750e-01,   1.99218750e-01],
                        [  2.12097168e-01,   2.12097168e-01],
                        [  2.07641602e-01,   2.07641602e-01],
                        [  1.82312012e-01,   1.82312012e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  2.69165039e-02,   2.69165039e-02],
                        [ -9.49401855e-02,  -9.49401855e-02],
                        [ -2.15698242e-01,  -2.15698242e-01],
                        [ -3.05114746e-01,  -3.05114746e-01],
                        [ -3.33557129e-01,  -3.33557129e-01],
                        [ -2.90954590e-01,  -2.90954590e-01],
                        [ -2.08374023e-01,  -2.08374023e-01],
                        [ -1.39739990e-01,  -1.39739990e-01],
                        [ -1.13281250e-01,  -1.13281250e-01],
                        [ -1.17034912e-01,  -1.17034912e-01],
                        [ -1.29455566e-01,  -1.29455566e-01],
                        [ -1.40625000e-01,  -1.40625000e-01],
                        [ -1.43646240e-01,  -1.43646240e-01],
                        [ -1.27899170e-01,  -1.27899170e-01],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.94274902e-01,   1.94274902e-01],
                        [  2.26593018e-01,   2.26593018e-01],
                        [  2.17834473e-01,   2.17834473e-01],
                        [  1.85211182e-01,   1.85211182e-01],
                        [  1.48010254e-01,   1.48010254e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  8.95080566e-02,   8.95080566e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.77795410e-02,   6.77795410e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  1.83105469e-02,   1.83105469e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -9.19189453e-02,  -9.19189453e-02],
                        [ -1.58935547e-01,  -1.58935547e-01],
                        [ -2.02362061e-01,  -2.02362061e-01],
                        [ -2.07763672e-01,  -2.07763672e-01],
                        [ -1.83410645e-01,  -1.83410645e-01],
                        [ -1.52496338e-01,  -1.52496338e-01],
                        [ -1.32019043e-01,  -1.32019043e-01],
                        [ -1.20086670e-01,  -1.20086670e-01],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -9.03930664e-02,  -9.03930664e-02],
                        [ -7.98339844e-02,  -7.98339844e-02],
                        [ -7.88879395e-02,  -7.88879395e-02],
                        [ -7.71789551e-02,  -7.71789551e-02],
                        [ -6.19201660e-02,  -6.19201660e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  1.24633789e-01,   1.24633789e-01],
                        [  1.42944336e-01,   1.42944336e-01],
                        [  1.54693604e-01,   1.54693604e-01],
                        [  1.70043945e-01,   1.70043945e-01],
                        [  1.88201904e-01,   1.88201904e-01],
                        [  2.01110840e-01,   2.01110840e-01],
                        [  2.04254150e-01,   2.04254150e-01],
                        [  1.95343018e-01,   1.95343018e-01],
                        [  1.66564941e-01,   1.66564941e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.20849609e-02,   1.20849609e-02],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -2.19879150e-01,  -2.19879150e-01],
                        [ -2.99468994e-01,  -2.99468994e-01],
                        [ -3.20190430e-01,  -3.20190430e-01],
                        [ -2.84332275e-01,  -2.84332275e-01],
                        [ -2.21557617e-01,  -2.21557617e-01],
                        [ -1.68640137e-01,  -1.68640137e-01],
                        [ -1.44989014e-01,  -1.44989014e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.46850586e-01,  -1.46850586e-01],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -1.25244141e-01,  -1.25244141e-01],
                        [ -1.08551025e-01,  -1.08551025e-01],
                        [ -8.22143555e-02,  -8.22143555e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.99523926e-01,   1.99523926e-01],
                        [  2.26531982e-01,   2.26531982e-01],
                        [  2.12371826e-01,   2.12371826e-01],
                        [  1.73370361e-01,   1.73370361e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  6.58874512e-02,   6.58874512e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  5.09643555e-03,   5.09643555e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -1.61834717e-01,  -1.61834717e-01],
                        [ -1.96990967e-01,  -1.96990967e-01],
                        [ -1.94427490e-01,  -1.94427490e-01],
                        [ -1.65985107e-01,  -1.65985107e-01],
                        [ -1.35589600e-01,  -1.35589600e-01],
                        [ -1.17248535e-01,  -1.17248535e-01],
                        [ -1.05957031e-01,  -1.05957031e-01],
                        [ -9.34143066e-02,  -9.34143066e-02],
                        [ -8.18786621e-02,  -8.18786621e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -7.74536133e-02,  -7.74536133e-02],
                        [ -7.44018555e-02,  -7.44018555e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  8.40148926e-02,   8.40148926e-02],
                        [  1.26556396e-01,   1.26556396e-01],
                        [  1.53930664e-01,   1.53930664e-01],
                        [  1.63116455e-01,   1.63116455e-01],
                        [  1.66809082e-01,   1.66809082e-01],
                        [  1.79931641e-01,   1.79931641e-01],
                        [  2.02880859e-01,   2.02880859e-01],
                        [  2.20764160e-01,   2.20764160e-01],
                        [  2.13439941e-01,   2.13439941e-01],
                        [  1.67388916e-01,   1.67388916e-01],
                        [  8.29772949e-02,   8.29772949e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -1.47888184e-01,  -1.47888184e-01],
                        [ -2.50762939e-01,  -2.50762939e-01],
                        [ -3.06915283e-01,  -3.06915283e-01],
                        [ -3.00506592e-01,  -3.00506592e-01],
                        [ -2.47009277e-01,  -2.47009277e-01],
                        [ -1.87103271e-01,  -1.87103271e-01],
                        [ -1.54998779e-01,  -1.54998779e-01],
                        [ -1.52740479e-01,  -1.52740479e-01],
                        [ -1.59423828e-01,  -1.59423828e-01],
                        [ -1.58691406e-01,  -1.58691406e-01],
                        [ -1.47644043e-01,  -1.47644043e-01],
                        [ -1.27044678e-01,  -1.27044678e-01],
                        [ -9.41467285e-02,  -9.41467285e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.68487549e-01,   1.68487549e-01],
                        [  2.10937500e-01,   2.10937500e-01],
                        [  2.17742920e-01,   2.17742920e-01],
                        [  1.99615479e-01,   1.99615479e-01],
                        [  1.71325684e-01,   1.71325684e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  7.68737793e-02,   7.68737793e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -9.34448242e-02,  -9.34448242e-02],
                        [ -1.48101807e-01,  -1.48101807e-01],
                        [ -1.82098389e-01,  -1.82098389e-01],
                        [ -1.82128906e-01,  -1.82128906e-01],
                        [ -1.57531738e-01,  -1.57531738e-01],
                        [ -1.30218506e-01,  -1.30218506e-01],
                        [ -1.12548828e-01,  -1.12548828e-01],
                        [ -1.02233887e-01,  -1.02233887e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -7.62329102e-02,  -7.62329102e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  5.83496094e-02,   5.83496094e-02],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.63421631e-01,   1.63421631e-01],
                        [  1.95220947e-01,   1.95220947e-01],
                        [  2.17132568e-01,   2.17132568e-01],
                        [  2.30438232e-01,   2.30438232e-01],
                        [  2.33001709e-01,   2.33001709e-01],
                        [  2.20367432e-01,   2.20367432e-01],
                        [  1.85638428e-01,   1.85638428e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  2.93884277e-02,   2.93884277e-02],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -1.99615479e-01,  -1.99615479e-01],
                        [ -2.93090820e-01,  -2.93090820e-01],
                        [ -3.31939697e-01,  -3.31939697e-01],
                        [ -3.03680420e-01,  -3.03680420e-01],
                        [ -2.37091064e-01,  -2.37091064e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.60003662e-01,  -1.60003662e-01],
                        [ -1.60339355e-01,  -1.60339355e-01],
                        [ -1.58172607e-01,  -1.58172607e-01],
                        [ -1.45629883e-01,  -1.45629883e-01],
                        [ -1.26586914e-01,  -1.26586914e-01],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  2.24121094e-01,   2.24121094e-01],
                        [  2.16644287e-01,   2.16644287e-01],
                        [  1.80480957e-01,   1.80480957e-01],
                        [  1.45538330e-01,   1.45538330e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  6.91528320e-02,   6.91528320e-02],
                        [  8.15429688e-02,   8.15429688e-02],
                        [  8.56323242e-02,   8.56323242e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  9.46044922e-04,   9.46044922e-04],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.69616699e-01,  -1.69616699e-01],
                        [ -1.84570312e-01,  -1.84570312e-01],
                        [ -1.74194336e-01,  -1.74194336e-01],
                        [ -1.45233154e-01,  -1.45233154e-01],
                        [ -1.12945557e-01,  -1.12945557e-01],
                        [ -9.09423828e-02,  -9.09423828e-02],
                        [ -8.11157227e-02,  -8.11157227e-02],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -4.26940918e-02,  -4.26940918e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.77947998e-01,   1.77947998e-01],
                        [  2.09259033e-01,   2.09259033e-01],
                        [  2.30499268e-01,   2.30499268e-01],
                        [  2.35992432e-01,   2.35992432e-01],
                        [  2.18444824e-01,   2.18444824e-01],
                        [  1.66412354e-01,   1.66412354e-01],
                        [  7.55310059e-02,   7.55310059e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -1.61895752e-01,  -1.61895752e-01],
                        [ -2.60864258e-01,  -2.60864258e-01],
                        [ -3.15765381e-01,  -3.15765381e-01],
                        [ -3.12927246e-01,  -3.12927246e-01],
                        [ -2.62145996e-01,  -2.62145996e-01],
                        [ -1.99035645e-01,  -1.99035645e-01],
                        [ -1.60522461e-01,  -1.60522461e-01],
                        [ -1.53656006e-01,  -1.53656006e-01],
                        [ -1.56005859e-01,  -1.56005859e-01],
                        [ -1.47644043e-01,  -1.47644043e-01],
                        [ -1.28662109e-01,  -1.28662109e-01],
                        [ -1.04248047e-01,  -1.04248047e-01],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  2.14019775e-01,   2.14019775e-01],
                        [  2.28240967e-01,   2.28240967e-01],
                        [  2.04162598e-01,   2.04162598e-01],
                        [  1.65069580e-01,   1.65069580e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  9.67102051e-02,   9.67102051e-02],
                        [  8.05053711e-02,   8.05053711e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  7.32116699e-02,   7.32116699e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.67431641e-02,   3.67431641e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -1.06994629e-01,  -1.06994629e-01],
                        [ -1.62139893e-01,  -1.62139893e-01],
                        [ -1.88537598e-01,  -1.88537598e-01],
                        [ -1.76330566e-01,  -1.76330566e-01],
                        [ -1.40014648e-01,  -1.40014648e-01],
                        [ -1.06872559e-01,  -1.06872559e-01],
                        [ -9.12780762e-02,  -9.12780762e-02],
                        [ -8.73718262e-02,  -8.73718262e-02],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -8.12072754e-02,  -8.12072754e-02],
                        [ -7.82470703e-02,  -7.82470703e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  1.27624512e-01,   1.27624512e-01],
                        [  1.72729492e-01,   1.72729492e-01],
                        [  2.04681396e-01,   2.04681396e-01],
                        [  2.23785400e-01,   2.23785400e-01],
                        [  2.32360840e-01,   2.32360840e-01],
                        [  2.28729248e-01,   2.28729248e-01],
                        [  2.02117920e-01,   2.02117920e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  3.70483398e-02,   3.70483398e-02],
                        [ -8.80432129e-02,  -8.80432129e-02],
                        [ -2.09350586e-01,  -2.09350586e-01],
                        [ -2.97607422e-01,  -2.97607422e-01],
                        [ -3.29559326e-01,  -3.29559326e-01],
                        [ -3.02185059e-01,  -3.02185059e-01],
                        [ -2.42309570e-01,  -2.42309570e-01],
                        [ -1.90307617e-01,  -1.90307617e-01],
                        [ -1.67694092e-01,  -1.67694092e-01],
                        [ -1.64398193e-01,  -1.64398193e-01],
                        [ -1.57775879e-01,  -1.57775879e-01],
                        [ -1.37268066e-01,  -1.37268066e-01],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.91864014e-01,   1.91864014e-01],
                        [  2.17590332e-01,   2.17590332e-01],
                        [  2.14385986e-01,   2.14385986e-01],
                        [  1.89361572e-01,   1.89361572e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  6.30493164e-02,   6.30493164e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  6.51245117e-02,   6.51245117e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.40661621e-02,   7.40661621e-02],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -1.02783203e-01,  -1.02783203e-01],
                        [ -1.58020020e-01,  -1.58020020e-01],
                        [ -1.84387207e-01,  -1.84387207e-01],
                        [ -1.77154541e-01,  -1.77154541e-01],
                        [ -1.50299072e-01,  -1.50299072e-01],
                        [ -1.25061035e-01,  -1.25061035e-01],
                        [ -1.12182617e-01,  -1.12182617e-01],
                        [ -1.05163574e-01,  -1.05163574e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -7.56530762e-02,  -7.56530762e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.47186279e-01,   1.47186279e-01],
                        [  1.92901611e-01,   1.92901611e-01],
                        [  2.26470947e-01,   2.26470947e-01],
                        [  2.49450684e-01,   2.49450684e-01],
                        [  2.58575439e-01,   2.58575439e-01],
                        [  2.39166260e-01,   2.39166260e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  7.03735352e-02,   7.03735352e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -1.91772461e-01,  -1.91772461e-01],
                        [ -2.98706055e-01,  -2.98706055e-01],
                        [ -3.51745605e-01,  -3.51745605e-01],
                        [ -3.36181641e-01,  -3.36181641e-01],
                        [ -2.72583008e-01,  -2.72583008e-01],
                        [ -2.05841064e-01,  -2.05841064e-01],
                        [ -1.68426514e-01,  -1.68426514e-01],
                        [ -1.58905029e-01,  -1.58905029e-01],
                        [ -1.55303955e-01,  -1.55303955e-01],
                        [ -1.40197754e-01,  -1.40197754e-01],
                        [ -1.10015869e-01,  -1.10015869e-01],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  2.01995850e-01,   2.01995850e-01],
                        [  2.22656250e-01,   2.22656250e-01],
                        [  2.10693359e-01,   2.10693359e-01],
                        [  1.80511475e-01,   1.80511475e-01],
                        [  1.46759033e-01,   1.46759033e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  9.46044922e-02,   9.46044922e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  1.11389160e-02,   1.11389160e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  5.42297363e-02,   5.42297363e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -1.21032715e-01,  -1.21032715e-01],
                        [ -1.71478271e-01,  -1.71478271e-01],
                        [ -1.90521240e-01,  -1.90521240e-01],
                        [ -1.78375244e-01,  -1.78375244e-01],
                        [ -1.49261475e-01,  -1.49261475e-01],
                        [ -1.21185303e-01,  -1.21185303e-01],
                        [ -1.02447510e-01,  -1.02447510e-01],
                        [ -8.90197754e-02,  -8.90197754e-02],
                        [ -7.58056641e-02,  -7.58056641e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.85089111e-01,   1.85089111e-01],
                        [  2.26440430e-01,   2.26440430e-01],
                        [  2.45788574e-01,   2.45788574e-01],
                        [  2.40875244e-01,   2.40875244e-01],
                        [  2.08343506e-01,   2.08343506e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  4.03747559e-02,   4.03747559e-02],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -2.09442139e-01,  -2.09442139e-01],
                        [ -3.03588867e-01,  -3.03588867e-01],
                        [ -3.42376709e-01,  -3.42376709e-01],
                        [ -3.19732666e-01,  -3.19732666e-01],
                        [ -2.58422852e-01,  -2.58422852e-01],
                        [ -1.99127197e-01,  -1.99127197e-01],
                        [ -1.69006348e-01,  -1.69006348e-01],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -1.50329590e-01,  -1.50329590e-01],
                        [ -1.22192383e-01,  -1.22192383e-01],
                        [ -8.06274414e-02,  -8.06274414e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  1.59515381e-01,   1.59515381e-01],
                        [  1.99188232e-01,   1.99188232e-01],
                        [  2.08282471e-01,   2.08282471e-01],
                        [  1.91650391e-01,   1.91650391e-01],
                        [  1.62933350e-01,   1.62933350e-01],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -1.51184082e-01,  -1.51184082e-01],
                        [ -1.58691406e-01,  -1.58691406e-01],
                        [ -1.36627197e-01,  -1.36627197e-01],
                        [ -1.08489990e-01,  -1.08489990e-01],
                        [ -9.23156738e-02,  -9.23156738e-02],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -7.63244629e-02,  -7.63244629e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  2.16125488e-01,   2.16125488e-01],
                        [  2.39471436e-01,   2.39471436e-01],
                        [  2.33612061e-01,   2.33612061e-01],
                        [  1.90795898e-01,   1.90795898e-01],
                        [  1.10534668e-01,   1.10534668e-01],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -1.31347656e-01,  -1.31347656e-01],
                        [ -2.52716064e-01,  -2.52716064e-01],
                        [ -3.29132080e-01,  -3.29132080e-01],
                        [ -3.38134766e-01,  -3.38134766e-01],
                        [ -2.90832520e-01,  -2.90832520e-01],
                        [ -2.25402832e-01,  -2.25402832e-01],
                        [ -1.79504395e-01,  -1.79504395e-01],
                        [ -1.65069580e-01,  -1.65069580e-01],
                        [ -1.64550781e-01,  -1.64550781e-01],
                        [ -1.51031494e-01,  -1.51031494e-01],
                        [ -1.12731934e-01,  -1.12731934e-01],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  2.03338623e-01,   2.03338623e-01],
                        [  2.01751709e-01,   2.01751709e-01],
                        [  1.83410645e-01,   1.83410645e-01],
                        [  1.59820557e-01,   1.59820557e-01],
                        [  1.32843018e-01,   1.32843018e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  5.27038574e-02,   5.27038574e-02],
                        [  6.24694824e-02,   6.24694824e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  6.23168945e-02,   6.23168945e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -7.96203613e-02,  -7.96203613e-02],
                        [ -1.28326416e-01,  -1.28326416e-01],
                        [ -1.52069092e-01,  -1.52069092e-01],
                        [ -1.45599365e-01,  -1.45599365e-01],
                        [ -1.23321533e-01,  -1.23321533e-01],
                        [ -1.02233887e-01,  -1.02233887e-01],
                        [ -8.84399414e-02,  -8.84399414e-02],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  1.84204102e-01,   1.84204102e-01],
                        [  2.30682373e-01,   2.30682373e-01],
                        [  2.42553711e-01,   2.42553711e-01],
                        [  2.17437744e-01,   2.17437744e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  6.44531250e-02,   6.44531250e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -1.89361572e-01,  -1.89361572e-01],
                        [ -2.96447754e-01,  -2.96447754e-01],
                        [ -3.46618652e-01,  -3.46618652e-01],
                        [ -3.28857422e-01,  -3.28857422e-01],
                        [ -2.66387939e-01,  -2.66387939e-01],
                        [ -2.03338623e-01,  -2.03338623e-01],
                        [ -1.69799805e-01,  -1.69799805e-01],
                        [ -1.60308838e-01,  -1.60308838e-01],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -1.18133545e-01,  -1.18133545e-01],
                        [ -7.19909668e-02,  -7.19909668e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.42761230e-01,   1.42761230e-01],
                        [  1.75506592e-01,   1.75506592e-01],
                        [  1.86035156e-01,   1.86035156e-01],
                        [  1.78924561e-01,   1.78924561e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.40716553e-01,   1.40716553e-01],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [  5.37109375e-02,   5.37109375e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  6.36901855e-02,   6.36901855e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -7.75146484e-03,  -7.75146484e-03],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -1.09466553e-01,  -1.09466553e-01],
                        [ -1.40289307e-01,  -1.40289307e-01],
                        [ -1.46514893e-01,  -1.46514893e-01],
                        [ -1.31103516e-01,  -1.31103516e-01],
                        [ -1.05621338e-01,  -1.05621338e-01],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  1.06140137e-01,   1.06140137e-01],
                        [  1.63208008e-01,   1.63208008e-01],
                        [  2.11914062e-01,   2.11914062e-01],
                        [  2.29034424e-01,   2.29034424e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  1.31195068e-01,   1.31195068e-01],
                        [  2.91442871e-02,   2.91442871e-02],
                        [ -9.35058594e-02,  -9.35058594e-02],
                        [ -2.18505859e-01,  -2.18505859e-01],
                        [ -3.15124512e-01,  -3.15124512e-01],
                        [ -3.52600098e-01,  -3.52600098e-01],
                        [ -3.25561523e-01,  -3.25561523e-01],
                        [ -2.63793945e-01,  -2.63793945e-01],
                        [ -2.07489014e-01,  -2.07489014e-01],
                        [ -1.72729492e-01,  -1.72729492e-01],
                        [ -1.46850586e-01,  -1.46850586e-01],
                        [ -1.14349365e-01,  -1.14349365e-01],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  1.64794922e-01,   1.64794922e-01],
                        [  1.86279297e-01,   1.86279297e-01],
                        [  1.81579590e-01,   1.81579590e-01],
                        [  1.65863037e-01,   1.65863037e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  3.23486328e-03,   3.23486328e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -9.06372070e-02,  -9.06372070e-02],
                        [ -1.41754150e-01,  -1.41754150e-01],
                        [ -1.68853760e-01,  -1.68853760e-01],
                        [ -1.61285400e-01,  -1.61285400e-01],
                        [ -1.25762939e-01,  -1.25762939e-01],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  2.02178955e-01,   2.02178955e-01],
                        [  2.37579346e-01,   2.37579346e-01],
                        [  2.30895996e-01,   2.30895996e-01],
                        [  1.79138184e-01,   1.79138184e-01],
                        [  8.98742676e-02,   8.98742676e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -1.58081055e-01,  -1.58081055e-01],
                        [ -2.78625488e-01,  -2.78625488e-01],
                        [ -3.53515625e-01,  -3.53515625e-01],
                        [ -3.58978271e-01,  -3.58978271e-01],
                        [ -3.08654785e-01,  -3.08654785e-01],
                        [ -2.48199463e-01,  -2.48199463e-01],
                        [ -2.12768555e-01,  -2.12768555e-01],
                        [ -1.96563721e-01,  -1.96563721e-01],
                        [ -1.70837402e-01,  -1.70837402e-01],
                        [ -1.22436523e-01,  -1.22436523e-01],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [  5.04455566e-02,   5.04455566e-02],
                        [  1.05316162e-01,   1.05316162e-01],
                        [  1.53015137e-01,   1.53015137e-01],
                        [  1.82189941e-01,   1.82189941e-01],
                        [  1.89331055e-01,   1.89331055e-01],
                        [  1.81243896e-01,   1.81243896e-01],
                        [  1.66809082e-01,   1.66809082e-01],
                        [  1.49414062e-01,   1.49414062e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  7.39135742e-02,   7.39135742e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -1.18408203e-01,  -1.18408203e-01],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -1.35833740e-01,  -1.35833740e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -8.71887207e-02,  -8.71887207e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  1.72027588e-01,   1.72027588e-01],
                        [  2.15850830e-01,   2.15850830e-01],
                        [  2.29278564e-01,   2.29278564e-01],
                        [  1.97692871e-01,   1.97692871e-01],
                        [  1.23229980e-01,   1.23229980e-01],
                        [  1.69372559e-02,   1.69372559e-02],
                        [ -1.10748291e-01,  -1.10748291e-01],
                        [ -2.40936279e-01,  -2.40936279e-01],
                        [ -3.37341309e-01,  -3.37341309e-01],
                        [ -3.66760254e-01,  -3.66760254e-01],
                        [ -3.31604004e-01,  -3.31604004e-01],
                        [ -2.69775391e-01,  -2.69775391e-01],
                        [ -2.18933105e-01,  -2.18933105e-01],
                        [ -1.88446045e-01,  -1.88446045e-01],
                        [ -1.65832520e-01,  -1.65832520e-01],
                        [ -1.36779785e-01,  -1.36779785e-01],
                        [ -9.19799805e-02,  -9.19799805e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  1.65374756e-01,   1.65374756e-01],
                        [  1.82617188e-01,   1.82617188e-01],
                        [  1.83502197e-01,   1.83502197e-01],
                        [  1.76330566e-01,   1.76330566e-01],
                        [  1.65130615e-01,   1.65130615e-01],
                        [  1.51031494e-01,   1.51031494e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  6.27136230e-02,   6.27136230e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  7.87963867e-02,   7.87963867e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  4.85229492e-03,   4.85229492e-03],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -7.10144043e-02,  -7.10144043e-02],
                        [ -1.16729736e-01,  -1.16729736e-01],
                        [ -1.41082764e-01,  -1.41082764e-01],
                        [ -1.32141113e-01,  -1.32141113e-01],
                        [ -1.01013184e-01,  -1.01013184e-01],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  8.95996094e-02,   8.95996094e-02],
                        [  1.48529053e-01,   1.48529053e-01],
                        [  2.01446533e-01,   2.01446533e-01],
                        [  2.27996826e-01,   2.27996826e-01],
                        [  2.12799072e-01,   2.12799072e-01],
                        [  1.52709961e-01,   1.52709961e-01],
                        [  5.31921387e-02,   5.31921387e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -2.01171875e-01,  -2.01171875e-01],
                        [ -3.00872803e-01,  -3.00872803e-01],
                        [ -3.45886230e-01,  -3.45886230e-01],
                        [ -3.31512451e-01,  -3.31512451e-01],
                        [ -2.80059814e-01,  -2.80059814e-01],
                        [ -2.26928711e-01,  -2.26928711e-01],
                        [ -1.94183350e-01,  -1.94183350e-01],
                        [ -1.75354004e-01,  -1.75354004e-01],
                        [ -1.46942139e-01,  -1.46942139e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  1.68914795e-01,   1.68914795e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  1.69525146e-01,   1.69525146e-01],
                        [  1.48895264e-01,   1.48895264e-01],
                        [  1.17401123e-01,   1.17401123e-01],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.33666992e-01,  -1.33666992e-01],
                        [ -1.28448486e-01,  -1.28448486e-01],
                        [ -9.52453613e-02,  -9.52453613e-02],
                        [ -6.34155273e-02,  -6.34155273e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  7.04956055e-02,   7.04956055e-02],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.88262939e-01,   1.88262939e-01],
                        [  2.24273682e-01,   2.24273682e-01],
                        [  2.23144531e-01,   2.23144531e-01],
                        [  1.77124023e-01,   1.77124023e-01],
                        [  8.74023438e-02,   8.74023438e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -1.70745850e-01,  -1.70745850e-01],
                        [ -2.81982422e-01,  -2.81982422e-01],
                        [ -3.39233398e-01,  -3.39233398e-01],
                        [ -3.34411621e-01,  -3.34411621e-01],
                        [ -2.87200928e-01,  -2.87200928e-01],
                        [ -2.32299805e-01,  -2.32299805e-01],
                        [ -1.95495605e-01,  -1.95495605e-01],
                        [ -1.76757812e-01,  -1.76757812e-01],
                        [ -1.55944824e-01,  -1.55944824e-01],
                        [ -1.14990234e-01,  -1.14990234e-01],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  8.70971680e-02,   8.70971680e-02],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.58691406e-01,   1.58691406e-01],
                        [  1.60064697e-01,   1.60064697e-01],
                        [  1.54052734e-01,   1.54052734e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.58843994e-01,   1.58843994e-01],
                        [  1.52069092e-01,   1.52069092e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  9.90600586e-02,   9.90600586e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  5.50231934e-02,   5.50231934e-02],
                        [  6.65283203e-02,   6.65283203e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  6.80541992e-02,   6.80541992e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -1.40228271e-01,  -1.40228271e-01],
                        [ -1.47186279e-01,  -1.47186279e-01],
                        [ -1.21185303e-01,  -1.21185303e-01],
                        [ -8.13293457e-02,  -8.13293457e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.86767578e-01,   1.86767578e-01],
                        [  2.16003418e-01,   2.16003418e-01],
                        [  2.11486816e-01,   2.11486816e-01],
                        [  1.60736084e-01,   1.60736084e-01],
                        [  6.59484863e-02,   6.59484863e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -1.94000244e-01,  -1.94000244e-01],
                        [ -3.07220459e-01,  -3.07220459e-01],
                        [ -3.64868164e-01,  -3.64868164e-01],
                        [ -3.51318359e-01,  -3.51318359e-01],
                        [ -2.87322998e-01,  -2.87322998e-01],
                        [ -2.19207764e-01,  -2.19207764e-01],
                        [ -1.80297852e-01,  -1.80297852e-01],
                        [ -1.64733887e-01,  -1.64733887e-01],
                        [ -1.42639160e-01,  -1.42639160e-01],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.57897949e-01,   1.57897949e-01],
                        [  1.56127930e-01,   1.56127930e-01],
                        [  1.56280518e-01,   1.56280518e-01],
                        [  1.60858154e-01,   1.60858154e-01],
                        [  1.58752441e-01,   1.58752441e-01],
                        [  1.40228271e-01,   1.40228271e-01],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  7.35473633e-02,   7.35473633e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -1.03881836e-01,  -1.03881836e-01],
                        [ -1.42578125e-01,  -1.42578125e-01],
                        [ -1.51306152e-01,  -1.51306152e-01],
                        [ -1.28051758e-01,  -1.28051758e-01],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  1.77581787e-01,   1.77581787e-01],
                        [  1.98944092e-01,   1.98944092e-01],
                        [  1.85455322e-01,   1.85455322e-01],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.23291016e-02,   1.23291016e-02],
                        [ -1.24114990e-01,  -1.24114990e-01],
                        [ -2.52532959e-01,  -2.52532959e-01],
                        [ -3.40118408e-01,  -3.40118408e-01],
                        [ -3.64074707e-01,  -3.64074707e-01],
                        [ -3.25042725e-01,  -3.25042725e-01],
                        [ -2.54791260e-01,  -2.54791260e-01],
                        [ -1.96380615e-01,  -1.96380615e-01],
                        [ -1.68457031e-01,  -1.68457031e-01],
                        [ -1.52587891e-01,  -1.52587891e-01],
                        [ -1.17431641e-01,  -1.17431641e-01],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  1.45996094e-01,   1.45996094e-01],
                        [  1.53808594e-01,   1.53808594e-01],
                        [  1.44744873e-01,   1.44744873e-01],
                        [  1.39556885e-01,   1.39556885e-01],
                        [  1.42974854e-01,   1.42974854e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  8.06274414e-02,   8.06274414e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  8.31909180e-02,   8.31909180e-02],
                        [  8.56323242e-02,   8.56323242e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  7.80334473e-02,   7.80334473e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -1.01531982e-01,  -1.01531982e-01],
                        [ -1.27075195e-01,  -1.27075195e-01],
                        [ -1.29119873e-01,  -1.29119873e-01],
                        [ -1.07147217e-01,  -1.07147217e-01],
                        [ -7.11059570e-02,  -7.11059570e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  1.55029297e-01,   1.55029297e-01],
                        [  1.87683105e-01,   1.87683105e-01],
                        [  1.94702148e-01,   1.94702148e-01],
                        [  1.56555176e-01,   1.56555176e-01],
                        [  6.82067871e-02,   6.82067871e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -1.89300537e-01,  -1.89300537e-01],
                        [ -3.03009033e-01,  -3.03009033e-01],
                        [ -3.66577148e-01,  -3.66577148e-01],
                        [ -3.65661621e-01,  -3.65661621e-01],
                        [ -3.14788818e-01,  -3.14788818e-01],
                        [ -2.47833252e-01,  -2.47833252e-01],
                        [ -1.93145752e-01,  -1.93145752e-01],
                        [ -1.56280518e-01,  -1.56280518e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -7.35473633e-02,  -7.35473633e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.41693115e-01,   1.41693115e-01],
                        [  1.40075684e-01,   1.40075684e-01],
                        [  1.41113281e-01,   1.41113281e-01],
                        [  1.45721436e-01,   1.45721436e-01],
                        [  1.43218994e-01,   1.43218994e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -7.56835938e-03,  -7.56835938e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.05590820e-02,   1.05590820e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  1.29089355e-02,   1.29089355e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -9.71069336e-02,  -9.71069336e-02],
                        [ -1.19903564e-01,  -1.19903564e-01],
                        [ -1.17828369e-01,  -1.17828369e-01],
                        [ -9.53063965e-02,  -9.53063965e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  1.20910645e-01,   1.20910645e-01],
                        [  1.72454834e-01,   1.72454834e-01],
                        [  2.02911377e-01,   2.02911377e-01],
                        [  1.94580078e-01,   1.94580078e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  4.40673828e-02,   4.40673828e-02],
                        [ -8.61816406e-02,  -8.61816406e-02],
                        [ -2.25067139e-01,  -2.25067139e-01],
                        [ -3.35357666e-01,  -3.35357666e-01],
                        [ -3.84368896e-01,  -3.84368896e-01],
                        [ -3.63891602e-01,  -3.63891602e-01],
                        [ -2.98675537e-01,  -2.98675537e-01],
                        [ -2.31536865e-01,  -2.31536865e-01],
                        [ -1.89544678e-01,  -1.89544678e-01],
                        [ -1.63452148e-01,  -1.63452148e-01],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.41571045e-01,   1.41571045e-01],
                        [  1.31042480e-01,   1.31042480e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.25854492e-01,   1.25854492e-01],
                        [  1.29974365e-01,   1.29974365e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.19659424e-01,   1.19659424e-01],
                        [  1.05529785e-01,   1.05529785e-01],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  7.61108398e-02,   7.61108398e-02],
                        [  9.39025879e-02,   9.39025879e-02],
                        [  1.04614258e-01,   1.04614258e-01],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  7.26928711e-02,   7.26928711e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -1.05590820e-01,  -1.05590820e-01],
                        [ -1.28814697e-01,  -1.28814697e-01],
                        [ -1.23016357e-01,  -1.23016357e-01],
                        [ -9.47265625e-02,  -9.47265625e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.58721924e-01,   1.58721924e-01],
                        [  1.92596436e-01,   1.92596436e-01],
                        [  1.95831299e-01,   1.95831299e-01],
                        [  1.55212402e-01,   1.55212402e-01],
                        [  6.46362305e-02,   6.46362305e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -2.04772949e-01,  -2.04772949e-01],
                        [ -3.17199707e-01,  -3.17199707e-01],
                        [ -3.71948242e-01,  -3.71948242e-01],
                        [ -3.60809326e-01,  -3.60809326e-01],
                        [ -3.05908203e-01,  -3.05908203e-01],
                        [ -2.45513916e-01,  -2.45513916e-01],
                        [ -2.04528809e-01,  -2.04528809e-01],
                        [ -1.76727295e-01,  -1.76727295e-01],
                        [ -1.37268066e-01,  -1.37268066e-01],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  1.17828369e-01,   1.17828369e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.34460449e-01,   1.34460449e-01],
                        [  1.40747070e-01,   1.40747070e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  8.86230469e-02,   8.86535645e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  8.88671875e-02,   8.88671875e-02],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  4.61730957e-02,   4.62036133e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -5.46264648e-03,  -5.43212891e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.32031250e-02,  -3.31726074e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -9.62829590e-02,  -9.62829590e-02],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  5.19104004e-02,   5.18798828e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.67297363e-01,   1.67297363e-01],
                        [  1.72454834e-01,   1.72485352e-01],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  5.05371094e-02,   5.05371094e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -2.07275391e-01,  -2.07275391e-01],
                        [ -3.13537598e-01,  -3.13537598e-01],
                        [ -3.62792969e-01,  -3.62792969e-01],
                        [ -3.48419189e-01,  -3.48419189e-01],
                        [ -2.91290283e-01,  -2.91290283e-01],
                        [ -2.27569580e-01,  -2.27569580e-01],
                        [ -1.82861328e-01,  -1.82861328e-01],
                        [ -1.53259277e-01,  -1.53259277e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  1.16638184e-01,   1.16638184e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.30798340e-01,   1.30798340e-01],
                        [  1.20971680e-01,   1.20971680e-01],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  4.49523926e-02,   4.49523926e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.46679688e-02,   3.46374512e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.26831055e-02,   6.26831055e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.64172363e-02,   4.63867188e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.05895996e-02,  -1.05590820e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.95312500e-02,   1.95617676e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -2.80151367e-02,  -2.79846191e-02],
                        [ -3.32641602e-02,  -3.32946777e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -2.45971680e-02,  -2.45666504e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -1.84936523e-02,  -1.84631348e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -4.52880859e-02,  -4.53186035e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [ -2.80761719e-03,  -2.83813477e-03],
                        [ -2.99377441e-02,  -2.99072266e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -1.94091797e-02,  -1.93786621e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  3.27758789e-02,   3.28063965e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  1.25457764e-01,   1.25457764e-01],
                        [  1.50665283e-01,   1.50665283e-01],
                        [  1.41601562e-01,   1.41601562e-01],
                        [  8.31604004e-02,   8.31604004e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.46179199e-01,  -1.46179199e-01],
                        [ -2.63824463e-01,  -2.63824463e-01],
                        [ -3.44207764e-01,  -3.44207764e-01],
                        [ -3.68011475e-01,  -3.68011475e-01],
                        [ -3.38134766e-01,  -3.38134766e-01],
                        [ -2.79205322e-01,  -2.79205322e-01],
                        [ -2.18231201e-01,  -2.18231201e-01],
                        [ -1.67663574e-01,  -1.67663574e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.31774902e-01,   1.31774902e-01],
                        [  1.14776611e-01,   1.14776611e-01],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.15295410e-01,   1.15295410e-01],
                        [  1.21917725e-01,   1.21887207e-01],
                        [  1.19354248e-01,   1.19354248e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  1.00189209e-01,   1.00189209e-01],
                        [  8.41369629e-02,   8.41369629e-02],
                        [  6.13403320e-02,   6.13708496e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  2.05078125e-02,   2.04772949e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.09558105e-02,   1.09252930e-02],
                        [  2.07824707e-02,   2.08129883e-02],
                        [  3.61022949e-02,   3.61328125e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  7.25708008e-02,   7.25402832e-02],
                        [  8.59680176e-02,   8.59985352e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  3.34777832e-02,   3.35083008e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.81274414e-02,  -1.81579590e-02],
                        [ -3.04260254e-02,  -3.03955078e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -2.62451172e-02,  -2.62756348e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  7.23266602e-03,   7.20214844e-03],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -4.08935547e-03,  -4.05883789e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -3.66210938e-04,  -3.96728516e-04],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  2.11181641e-02,   2.10876465e-02],
                        [  2.19726562e-02,   2.19421387e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.93884277e-02,  -2.94189453e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.75671387e-02,  -3.75976562e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -6.68945312e-02,  -6.69250488e-02],
                        [ -6.68640137e-02,  -6.68334961e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [  1.69372559e-02,   1.69677734e-02],
                        [  4.89807129e-02,   4.89501953e-02],
                        [  9.08813477e-02,   9.08813477e-02],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.54388428e-01,   1.54357910e-01],
                        [  1.39556885e-01,   1.39556885e-01],
                        [  8.06274414e-02,   8.06274414e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -2.73162842e-01,  -2.73162842e-01],
                        [ -3.55041504e-01,  -3.55010986e-01],
                        [ -3.72528076e-01,  -3.72528076e-01],
                        [ -3.33831787e-01,  -3.33831787e-01],
                        [ -2.68188477e-01,  -2.68188477e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.59973145e-01,  -1.59973145e-01],
                        [ -1.20788574e-01,  -1.20788574e-01],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [  6.14318848e-02,   6.14318848e-02],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  1.18988037e-01,   1.18988037e-01],
                        [  1.15112305e-01,   1.15142822e-01],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  1.23016357e-01,   1.22985840e-01],
                        [  1.26037598e-01,   1.26007080e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.14318848e-01,   1.14318848e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  5.48706055e-02,   5.49011230e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  1.30310059e-02,   1.30004883e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  2.80761719e-03,   2.77709961e-03],
                        [  1.42211914e-02,   1.42517090e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  5.27343750e-02,   5.27038574e-02],
                        [  7.32116699e-02,   7.32116699e-02],
                        [  8.42895508e-02,   8.43200684e-02],
                        [  8.50830078e-02,   8.50524902e-02],
                        [  7.97424316e-02,   7.97119141e-02],
                        [  7.36694336e-02,   7.36999512e-02],
                        [  6.86645508e-02,   6.86340332e-02],
                        [  6.17065430e-02,   6.16760254e-02],
                        [  5.10253906e-02,   5.10559082e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.82592773e-02,   2.82287598e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  6.77490234e-03,   6.80541992e-03],
                        [ -5.79833984e-03,  -5.82885742e-03],
                        [ -2.14538574e-02,  -2.14843750e-02],
                        [ -3.60717773e-02,  -3.60412598e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -2.89001465e-02,  -2.89306641e-02],
                        [ -1.13525391e-02,  -1.13220215e-02],
                        [  1.43432617e-03,   1.46484375e-03],
                        [  7.84301758e-03,   7.81250000e-03],
                        [  1.42211914e-02,   1.41906738e-02],
                        [  2.40478516e-02,   2.41088867e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.50952148e-02,   3.50646973e-02],
                        [  3.08532715e-02,   3.08837891e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.16979980e-02,   2.16369629e-02],
                        [  1.91955566e-02,   1.92260742e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.71508789e-02,   1.71203613e-02],
                        [  1.01013184e-02,   1.00708008e-02],
                        [ -7.62939453e-04,  -7.32421875e-04],
                        [ -8.75854492e-03,  -8.78906250e-03],
                        [ -1.22680664e-02,  -1.22985840e-02],
                        [ -1.41906738e-02,  -1.41601562e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.77917480e-02,  -1.78222656e-02],
                        [ -2.37731934e-02,  -2.37426758e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.12292480e-02,  -4.12597656e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -2.81677246e-02,  -2.81372070e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -1.53808594e-02,  -1.54113770e-02],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  1.28784180e-02,   1.29089355e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.54113770e-02,   1.54418945e-02],
                        [  1.11389160e-02,   1.11083984e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -6.62841797e-02,  -6.63146973e-02],
                        [ -8.33435059e-02,  -8.33740234e-02],
                        [ -7.61108398e-02,  -7.61108398e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.71447754e-01,   1.71447754e-01],
                        [  1.36535645e-01,   1.36505127e-01],
                        [  4.60510254e-02,   4.60510254e-02],
                        [ -8.82263184e-02,  -8.81958008e-02],
                        [ -2.32452393e-01,  -2.32482910e-01],
                        [ -3.43170166e-01,  -3.43170166e-01],
                        [ -3.87908936e-01,  -3.87878418e-01],
                        [ -3.64105225e-01,  -3.64135742e-01],
                        [ -3.00262451e-01,  -3.00262451e-01],
                        [ -2.33612061e-01,  -2.33612061e-01],
                        [ -1.81610107e-01,  -1.81610107e-01],
                        [ -1.33819580e-01,  -1.33819580e-01],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  1.01684570e-01,   1.01715088e-01],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  9.45129395e-02,   9.44824219e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  1.00891113e-01,   1.00921631e-01],
                        [  1.17492676e-01,   1.17431641e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  1.17218018e-01,   1.17279053e-01],
                        [  1.00738525e-01,   1.00708008e-01],
                        [  8.48999023e-02,   8.48693848e-02],
                        [  7.19909668e-02,   7.20520020e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  4.08630371e-02,   4.08020020e-02],
                        [  2.02941895e-02,   2.03247070e-02],
                        [  3.81469727e-03,   3.87573242e-03],
                        [ -2.34985352e-03,  -2.38037109e-03],
                        [  3.47900391e-03,   3.44848633e-03],
                        [  2.11486816e-02,   2.12097168e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  7.55920410e-02,   7.55615234e-02],
                        [  9.61914062e-02,   9.62219238e-02],
                        [  1.06903076e-01,   1.06933594e-01],
                        [  1.07116699e-01,   1.07055664e-01],
                        [  9.71069336e-02,   9.71374512e-02],
                        [  8.16040039e-02,   8.16345215e-02],
                        [  6.62536621e-02,   6.62231445e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  3.28369141e-02,   3.28674316e-02],
                        [  1.08337402e-02,   1.08032227e-02],
                        [ -9.79614258e-03,  -9.82666016e-03],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -1.32446289e-02,  -1.32751465e-02],
                        [ -5.46264648e-03,  -5.43212891e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [ -1.22070312e-04,  -1.52587891e-04],
                        [  1.58691406e-03,   1.58691406e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  7.96508789e-03,   7.93457031e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  2.06604004e-02,   2.06298828e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  1.90124512e-02,   1.90429688e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.70898438e-02,   1.70593262e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.94396973e-02,   1.94702148e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  6.98852539e-03,   6.98852539e-03],
                        [ -2.59399414e-03,  -2.56347656e-03],
                        [ -1.04370117e-02,  -1.04064941e-02],
                        [ -1.58386230e-02,  -1.58691406e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -3.20434570e-02,  -3.20129395e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -4.96215820e-02,  -4.95910645e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.13220215e-02,  -1.13525391e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.56555176e-02,  -1.56250000e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.16064453e-02,  -2.16369629e-02],
                        [ -1.06201172e-02,  -1.06506348e-02],
                        [  1.00708008e-03,   1.03759766e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  7.08007812e-03,   7.04956055e-03],
                        [ -1.67846680e-03,  -1.64794922e-03],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -3.58581543e-02,  -3.58886719e-02],
                        [ -5.00488281e-02,  -5.00183105e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -3.41796875e-02,  -3.42102051e-02],
                        [ -4.69970703e-03,  -4.66918945e-03],
                        [  3.10974121e-02,   3.11279297e-02],
                        [  6.71081543e-02,   6.70776367e-02],
                        [  1.00372314e-01,   1.00341797e-01],
                        [  1.30310059e-01,   1.30371094e-01],
                        [  1.52557373e-01,   1.52557373e-01],
                        [  1.54693604e-01,   1.54663086e-01],
                        [  1.21704102e-01,   1.21734619e-01],
                        [  4.43420410e-02,   4.43725586e-02],
                        [ -7.51647949e-02,  -7.52258301e-02],
                        [ -2.15301514e-01,  -2.15301514e-01],
                        [ -3.33465576e-01,  -3.33404541e-01],
                        [ -3.88916016e-01,  -3.88946533e-01],
                        [ -3.72283936e-01,  -3.72314453e-01],
                        [ -3.08471680e-01,  -3.08410645e-01],
                        [ -2.33978271e-01,  -2.33978271e-01],
                        [ -1.72637939e-01,  -1.72698975e-01],
                        [ -1.24542236e-01,  -1.24481201e-01],
                        [ -7.51647949e-02,  -7.51037598e-02],
                        [ -1.68762207e-02,  -1.69372559e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  7.68127441e-02,   7.68737793e-02],
                        [  8.51135254e-02,   8.50830078e-02],
                        [  7.46765137e-02,   7.46154785e-02],
                        [  6.63452148e-02,   6.64062500e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  9.23767090e-02,   9.23156738e-02],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  1.14532471e-01,   1.14562988e-01],
                        [  1.14532471e-01,   1.14501953e-01],
                        [  1.12274170e-01,   1.12243652e-01],
                        [  1.05804443e-01,   1.05865479e-01],
                        [  8.99963379e-02,   8.99658203e-02],
                        [  6.44836426e-02,   6.44531250e-02],
                        [  3.72619629e-02,   3.73229980e-02],
                        [  1.85241699e-02,   1.85546875e-02],
                        [  1.31225586e-02,   1.30920410e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  3.29895020e-02,   3.30200195e-02],
                        [  4.68444824e-02,   4.68139648e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  7.00073242e-02,   7.00378418e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  9.50927734e-02,   9.50622559e-02],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  8.55102539e-02,   8.55407715e-02],
                        [  7.05871582e-02,   7.05566406e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  2.97546387e-02,   2.97851562e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -3.10974121e-02,  -3.10668945e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.37426758e-02,   2.37121582e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -9.70458984e-03,  -9.73510742e-03],
                        [  2.74658203e-04,   2.44140625e-04],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  3.33557129e-02,   3.33251953e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  5.39855957e-02,   5.40161133e-02],
                        [  5.91430664e-02,   5.91125488e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  5.09033203e-02,   5.09338379e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  1.38244629e-02,   1.37939453e-02],
                        [ -8.42285156e-03,  -8.39233398e-03],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -4.78210449e-02,  -4.78515625e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -6.89086914e-02,  -6.89392090e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [  4.57763672e-04,   4.88281250e-04],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  8.81958008e-03,   8.78906250e-03],
                        [  4.51660156e-03,   4.54711914e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -3.62243652e-02,  -3.62548828e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.65808105e-02,  -2.66113281e-02],
                        [ -3.56445312e-02,  -3.56140137e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -5.43212891e-02,  -5.43518066e-02],
                        [ -4.11987305e-02,  -4.11682129e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [  3.41186523e-02,   3.40881348e-02],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  1.24908447e-01,   1.24938965e-01],
                        [  1.60064697e-01,   1.60064697e-01],
                        [  1.77825928e-01,   1.77825928e-01],
                        [  1.68243408e-01,   1.68273926e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  2.92358398e-02,   2.92053223e-02],
                        [ -1.06445312e-01,  -1.06414795e-01],
                        [ -2.63000488e-01,  -2.62969971e-01],
                        [ -3.97827148e-01,  -3.97857666e-01],
                        [ -4.66156006e-01,  -4.66156006e-01],
                        [ -4.48944092e-01,  -4.48944092e-01],
                        [ -3.68377686e-01,  -3.68408203e-01],
                        [ -2.70416260e-01,  -2.70416260e-01],
                        [ -1.87469482e-01,  -1.87438965e-01],
                        [ -1.18316650e-01,  -1.18316650e-01],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [  4.22668457e-02,   4.22973633e-02],
                        [  1.20330811e-01,   1.20330811e-01],
                        [  1.64001465e-01,   1.63970947e-01],
                        [  1.65954590e-01,   1.65985107e-01],
                        [  1.42608643e-01,   1.42578125e-01],
                        [  1.16882324e-01,   1.16851807e-01],
                        [  1.01043701e-01,   1.01043701e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  7.78198242e-02,   7.77893066e-02],
                        [  5.84106445e-02,   5.84411621e-02],
                        [  4.16870117e-02,   4.17175293e-02],
                        [  3.41186523e-02,   3.40881348e-02],
                        [  3.11584473e-02,   3.11889648e-02],
                        [  2.39868164e-02,   2.40173340e-02],
                        [  1.23291016e-02,   1.22985840e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.15356445e-02,   1.15661621e-02],
                        [  2.87170410e-02,   2.86865234e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  6.91223145e-02,   6.91528320e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  8.77075195e-02,   8.76770020e-02],
                        [  9.53369141e-02,   9.53674316e-02],
                        [  1.04644775e-01,   1.04675293e-01],
                        [  1.08306885e-01,   1.08276367e-01],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  8.34655762e-02,   8.34960938e-02],
                        [  6.18896484e-02,   6.18591309e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  1.76391602e-02,   1.76696777e-02],
                        [  1.09863281e-03,   1.09863281e-03],
                        [ -1.19018555e-02,  -1.19323730e-02],
                        [ -2.30712891e-02,  -2.30407715e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -2.91137695e-02,  -2.91442871e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.04064941e-02,  -1.04370117e-02],
                        [ -7.72094727e-03,  -7.75146484e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.80358887e-02,   1.80053711e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.92968750e-02,   2.93273926e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  3.92761230e-02,   3.92456055e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  4.00085449e-02,   4.00390625e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [ -6.89697266e-03,  -6.92749023e-03],
                        [ -1.67846680e-02,  -1.67541504e-02],
                        [ -2.19116211e-02,  -2.18811035e-02],
                        [ -2.47192383e-02,  -2.47802734e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.72009277e-02,  -3.71704102e-02],
                        [ -4.30603027e-02,  -4.30908203e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -3.95812988e-02,  -3.95507812e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -2.88085938e-02,  -2.88391113e-02],
                        [ -2.42614746e-02,  -2.42309570e-02],
                        [ -2.07214355e-02,  -2.06909180e-02],
                        [ -2.10266113e-02,  -2.10571289e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -3.08837891e-02,  -3.08532715e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -2.79846191e-02,  -2.80151367e-02],
                        [ -2.62451172e-02,  -2.62145996e-02],
                        [ -2.51159668e-02,  -2.50854492e-02],
                        [ -2.18200684e-02,  -2.18505859e-02],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -8.05664062e-03,  -8.02612305e-03],
                        [  2.68554688e-03,   2.65502930e-03],
                        [  1.42822266e-02,   1.42517090e-02],
                        [  2.31933594e-02,   2.32238770e-02],
                        [  2.64587402e-02,   2.64892578e-02],
                        [  2.04772949e-02,   2.04467773e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -2.28881836e-02,  -2.28576660e-02],
                        [ -4.28771973e-02,  -4.29382324e-02],
                        [ -4.56848145e-02,  -4.57153320e-02],
                        [ -2.93884277e-02,  -2.93273926e-02],
                        [ -1.06811523e-03,  -1.09863281e-03],
                        [  3.16162109e-02,   3.15856934e-02],
                        [  6.56433105e-02,   6.56738281e-02],
                        [  9.89074707e-02,   9.89379883e-02],
                        [  1.25640869e-01,   1.25610352e-01],
                        [  1.35772705e-01,   1.35772705e-01],
                        [  1.14349365e-01,   1.14379883e-01],
                        [  4.45861816e-02,   4.45556641e-02],
                        [ -7.44934082e-02,  -7.45239258e-02],
                        [ -2.12585449e-01,  -2.12524414e-01],
                        [ -3.21380615e-01,  -3.21380615e-01],
                        [ -3.66271973e-01,  -3.66333008e-01],
                        [ -3.44421387e-01,  -3.44390869e-01],
                        [ -2.81585693e-01,  -2.81555176e-01],
                        [ -2.14996338e-01,  -2.15026855e-01],
                        [ -1.67755127e-01,  -1.67755127e-01],
                        [ -1.33026123e-01,  -1.32995605e-01],
                        [ -8.87756348e-02,  -8.88061523e-02],
                        [ -2.97241211e-02,  -2.97546387e-02],
                        [  2.36511230e-02,   2.36816406e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [  4.93164062e-02,   4.92858887e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  6.67114258e-02,   6.67724609e-02],
                        [  1.01379395e-01,   1.01348877e-01],
                        [  1.32110596e-01,   1.32110596e-01],
                        [  1.44042969e-01,   1.44073486e-01],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.31256104e-01,   1.31225586e-01],
                        [  1.24633789e-01,   1.24664307e-01],
                        [  1.12518311e-01,   1.12548828e-01],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  5.61218262e-02,   5.61218262e-02],
                        [  3.23486328e-02,   3.23791504e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  1.68457031e-02,   1.68151855e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  3.19519043e-02,   3.19213867e-02],
                        [  4.44641113e-02,   4.44641113e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  8.01391602e-02,   8.01696777e-02],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  7.38525391e-02,   7.38220215e-02],
                        [  5.84106445e-02,   5.84411621e-02],
                        [  4.05883789e-02,   4.06188965e-02],
                        [  2.65502930e-02,   2.65197754e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.27563477e-02,   1.27868652e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.77001953e-03,  -1.73950195e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.73950195e-03,  -1.77001953e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.26342773e-02,  -1.26647949e-02],
                        [ -3.44848633e-03,  -3.47900391e-03],
                        [  9.27734375e-03,   9.30786133e-03],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.23083496e-02,   2.22473145e-02],
                        [  2.86560059e-02,   2.86865234e-02],
                        [  3.84521484e-02,   3.84826660e-02],
                        [  4.76074219e-02,   4.75463867e-02],
                        [  5.30700684e-02,   5.31005859e-02],
                        [  5.51147461e-02,   5.51757812e-02],
                        [  5.15441895e-02,   5.14831543e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  1.15051270e-02,   1.15661621e-02],
                        [ -2.09655762e-02,  -2.09960938e-02],
                        [ -5.05981445e-02,  -5.06591797e-02],
                        [ -6.71386719e-02,  -6.70776367e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -6.37207031e-02,  -6.37817383e-02],
                        [ -6.31408691e-02,  -6.31103516e-02],
                        [ -6.78710938e-02,  -6.78100586e-02],
                        [ -7.46154785e-02,  -7.46765137e-02],
                        [ -8.00170898e-02,  -8.00476074e-02],
                        [ -7.83691406e-02,  -7.83386230e-02],
                        [ -6.47277832e-02,  -6.47583008e-02],
                        [ -4.23889160e-02,  -4.24194336e-02],
                        [ -2.09350586e-02,  -2.09045410e-02],
                        [ -7.81250000e-03,  -7.78198242e-03],
                        [ -3.63159180e-03,  -3.69262695e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  5.36804199e-02,   5.36499023e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [ -3.47900391e-03,  -3.50952148e-03],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  1.02294922e-01,   1.02294922e-01],
                        [  1.13983154e-01,   1.14013672e-01],
                        [  8.92944336e-02,   8.92639160e-02],
                        [  1.57470703e-02,   1.57165527e-02],
                        [ -1.01043701e-01,  -1.01013184e-01],
                        [ -2.29248047e-01,  -2.29248047e-01],
                        [ -3.24432373e-01,  -3.24462891e-01],
                        [ -3.56231689e-01,  -3.56231689e-01],
                        [ -3.26690674e-01,  -3.26660156e-01],
                        [ -2.65930176e-01,  -2.65960693e-01],
                        [ -2.06695557e-01,  -2.06695557e-01],
                        [ -1.59454346e-01,  -1.59423828e-01],
                        [ -1.12213135e-01,  -1.12213135e-01],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [  1.94091797e-02,   1.94396973e-02],
                        [  7.80639648e-02,   7.80334473e-02],
                        [  1.04248047e-01,   1.04217529e-01],
                        [  9.77172852e-02,   9.77478027e-02],
                        [  7.63854980e-02,   7.64160156e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  7.08312988e-02,   7.08007812e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  1.03698730e-01,   1.03729248e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.06140137e-01,   1.06170654e-01],
                        [  9.35974121e-02,   9.35668945e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  5.02319336e-02,   5.02624512e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [ -5.92041016e-03,  -5.95092773e-03],
                        [ -1.95007324e-02,  -1.94702148e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.10778809e-02,  -1.11083984e-02],
                        [ -5.52368164e-03,  -5.49316406e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [  8.85009766e-04,   8.54492188e-04],
                        [  6.59179688e-03,   6.62231445e-03],
                        [  1.19628906e-02,   1.19934082e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -9.94873047e-03,  -9.97924805e-03],
                        [ -8.51440430e-03,  -8.48388672e-03],
                        [  2.38037109e-03,   2.34985352e-03],
                        [  2.33459473e-02,   2.33154297e-02],
                        [  4.53186035e-02,   4.53491211e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  2.99377441e-02,   2.99682617e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.78417969e-03,   3.75366211e-03],
                        [ -4.18090820e-03,  -4.15039062e-03],
                        [ -9.70458984e-03,  -9.67407227e-03],
                        [ -1.20849609e-02,  -1.21154785e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [  7.14111328e-03,   7.11059570e-03],
                        [  1.51672363e-02,   1.51367188e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  8.39233398e-03,   8.36181641e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.90429688e-02,  -1.90124512e-02],
                        [ -3.73535156e-02,  -3.73840332e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -6.63757324e-02,  -6.63452148e-02],
                        [ -6.90917969e-02,  -6.90917969e-02],
                        [ -6.40563965e-02,  -6.40869141e-02],
                        [ -5.56335449e-02,  -5.56030273e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.13513184e-02,  -4.13818359e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -2.26440430e-02,  -2.26135254e-02],
                        [ -4.85229492e-03,  -4.88281250e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.72729492e-02,   1.73034668e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.07421875e-02,   1.07116699e-02],
                        [  1.35803223e-02,   1.36108398e-02],
                        [  2.16064453e-02,   2.16369629e-02],
                        [  2.57568359e-02,   2.57263184e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -4.32434082e-02,  -4.32739258e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [  1.71508789e-02,   1.71203613e-02],
                        [  6.45446777e-02,   6.45446777e-02],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  1.20117188e-01,   1.20086670e-01],
                        [  7.48291016e-02,   7.48291016e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.23809814e-01,  -1.23809814e-01],
                        [ -2.48962402e-01,  -2.48992920e-01],
                        [ -3.40698242e-01,  -3.40698242e-01],
                        [ -3.64715576e-01,  -3.64685059e-01],
                        [ -3.21868896e-01,  -3.21899414e-01],
                        [ -2.46093750e-01,  -2.46124268e-01],
                        [ -1.76574707e-01,  -1.76544189e-01],
                        [ -1.31011963e-01,  -1.31011963e-01],
                        [ -9.95788574e-02,  -9.96093750e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -1.29089355e-02,  -1.28784180e-02],
                        [  2.93273926e-02,   2.92968750e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  3.72314453e-02,   3.72619629e-02],
                        [  2.99682617e-02,   2.99377441e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  7.11059570e-02,   7.11364746e-02],
                        [  1.03424072e-01,   1.03393555e-01],
                        [  1.24389648e-01,   1.24359131e-01],
                        [  1.30187988e-01,   1.30218506e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.13433838e-01,   1.13403320e-01],
                        [  9.65270996e-02,   9.65576172e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  5.21240234e-02,   5.20935059e-02],
                        [  3.46679688e-02,   3.46984863e-02],
                        [  2.74658203e-02,   2.74963379e-02],
                        [  3.04260254e-02,   3.03955078e-02],
                        [  4.00390625e-02,   4.00695801e-02],
                        [  5.19104004e-02,   5.19409180e-02],
                        [  6.16149902e-02,   6.15844727e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  7.29980469e-02,   7.30590820e-02],
                        [  7.97424316e-02,   7.97119141e-02],
                        [  8.52050781e-02,   8.51440430e-02],
                        [  8.56323242e-02,   8.56933594e-02],
                        [  7.87353516e-02,   7.87658691e-02],
                        [  6.35070801e-02,   6.34460449e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  2.41088867e-02,   2.41394043e-02],
                        [  1.13525391e-02,   1.13220215e-02],
                        [  3.14331055e-03,   3.11279297e-03],
                        [ -2.74658203e-03,  -2.71606445e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.10473633e-02,  -1.11083984e-02],
                        [ -1.43127441e-02,  -1.42822266e-02],
                        [ -1.37023926e-02,  -1.36718750e-02],
                        [ -8.08715820e-03,  -8.11767578e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  1.06811523e-02,   1.07421875e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.79028320e-02,   3.78417969e-02],
                        [  5.16357422e-02,   5.16662598e-02],
                        [  6.14929199e-02,   6.15234375e-02],
                        [  6.33544922e-02,   6.33239746e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  4.17480469e-02,   4.18090820e-02],
                        [  2.88696289e-02,   2.88391113e-02],
                        [  1.87988281e-02,   1.87377930e-02],
                        [  1.13525391e-02,   1.14135742e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -5.79833984e-04,  -6.40869141e-04],
                        [ -9.61303711e-03,  -9.58251953e-03],
                        [ -1.81274414e-02,  -1.80969238e-02],
                        [ -2.32238770e-02,  -2.32849121e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.78320312e-02,  -2.78015137e-02],
                        [ -2.73437500e-02,  -2.73742676e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -2.08740234e-02,  -2.08129883e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -1.10473633e-02,  -1.10778809e-02],
                        [  7.62939453e-04,   7.93457031e-04],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.33666992e-02,   1.33361816e-02],
                        [  2.99072266e-03,   3.05175781e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -2.53906250e-02,  -2.54211426e-02],
                        [ -3.25012207e-02,  -3.24707031e-02],
                        [ -3.49731445e-02,  -3.49426270e-02],
                        [ -3.95812988e-02,  -3.96118164e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -6.31408691e-02,  -6.31103516e-02],
                        [ -6.75659180e-02,  -6.76269531e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.43518066e-02,  -5.42907715e-02],
                        [ -4.32128906e-02,  -4.32434082e-02],
                        [ -2.75573730e-02,  -2.75878906e-02],
                        [ -6.89697266e-03,  -6.83593750e-03],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  2.69165039e-02,   2.68859863e-02],
                        [  2.42004395e-02,   2.42309570e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -1.91650391e-02,  -1.91955566e-02],
                        [ -3.74450684e-02,  -3.74145508e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.03039551e-02,  -3.03344727e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [  8.94165039e-03,   8.97216797e-03],
                        [  3.17993164e-02,   3.17687988e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  7.63854980e-02,   7.64160156e-02],
                        [  9.76257324e-02,   9.75952148e-02],
                        [  1.14013672e-01,   1.13983154e-01],
                        [  1.22497559e-01,   1.22528076e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  1.14776611e-01,   1.14746094e-01],
                        [  9.13085938e-02,   9.13391113e-02],
                        [  4.23278809e-02,   4.23583984e-02],
                        [ -4.03747559e-02,  -4.04052734e-02],
                        [ -1.49658203e-01,  -1.49658203e-01],
                        [ -2.55859375e-01,  -2.55798340e-01],
                        [ -3.21655273e-01,  -3.21685791e-01],
                        [ -3.28460693e-01,  -3.28491211e-01],
                        [ -2.88665771e-01,  -2.88635254e-01],
                        [ -2.34466553e-01,  -2.34466553e-01],
                        [ -1.91345215e-01,  -1.91375732e-01],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -5.67932129e-02,  -5.68542480e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  5.62133789e-02,   5.62438965e-02],
                        [  7.48901367e-02,   7.48596191e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  7.97119141e-02,   7.97424316e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  1.06506348e-01,   1.06475830e-01],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  1.12976074e-01,   1.13006592e-01],
                        [  1.02691650e-01,   1.02661133e-01],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  7.25097656e-02,   7.25402832e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  4.50744629e-02,   4.50439453e-02],
                        [  2.99377441e-02,   2.99682617e-02],
                        [  1.89819336e-02,   1.90124512e-02],
                        [  1.74255371e-02,   1.73645020e-02],
                        [  2.37731934e-02,   2.38037109e-02],
                        [  3.20434570e-02,   3.20739746e-02],
                        [  3.76892090e-02,   3.76586914e-02],
                        [  4.19921875e-02,   4.19616699e-02],
                        [  5.05981445e-02,   5.06286621e-02],
                        [  6.60705566e-02,   6.60400391e-02],
                        [  8.36791992e-02,   8.36486816e-02],
                        [  9.55200195e-02,   9.55505371e-02],
                        [  9.59167480e-02,   9.59167480e-02],
                        [  8.45947266e-02,   8.45642090e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.05371094e-02,   5.05676270e-02],
                        [  3.57666016e-02,   3.57360840e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [ -3.44848633e-03,  -3.41796875e-03],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -3.61938477e-02,  -3.62243652e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -3.17993164e-02,  -3.18298340e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.01110840e-02,  -2.00805664e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  3.25012207e-02,   3.25317383e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  2.27966309e-02,   2.27661133e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -1.41296387e-02,  -1.40991211e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -5.39550781e-02,  -5.39245605e-02],
                        [ -4.82177734e-02,  -4.82482910e-02],
                        [ -3.30810547e-02,  -3.31115723e-02],
                        [ -1.84631348e-02,  -1.84326172e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -8.51440430e-03,  -8.57543945e-03],
                        [ -9.33837891e-03,  -9.30786133e-03],
                        [ -1.01013184e-02,  -1.00708008e-02],
                        [ -1.06506348e-02,  -1.07116699e-02],
                        [ -1.25732422e-02,  -1.26037598e-02],
                        [ -1.75476074e-02,  -1.74865723e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -4.53491211e-02,  -4.54101562e-02],
                        [ -6.43310547e-02,  -6.42700195e-02],
                        [ -7.52258301e-02,  -7.51953125e-02],
                        [ -7.36389160e-02,  -7.36999512e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.49523926e-02,  -4.48913574e-02],
                        [ -2.75878906e-02,  -2.76489258e-02],
                        [ -1.39160156e-02,  -1.39465332e-02],
                        [ -2.86865234e-03,  -2.77709961e-03],
                        [  7.29370117e-03,   7.26318359e-03],
                        [  1.36108398e-02,   1.35192871e-02],
                        [  1.48620605e-02,   1.49230957e-02],
                        [  1.60522461e-02,   1.61132812e-02],
                        [  2.00805664e-02,   1.99890137e-02],
                        [  2.38952637e-02,   2.39257812e-02],
                        [  2.53601074e-02,   2.54516602e-02],
                        [  2.38952637e-02,   2.38647461e-02],
                        [  1.69067383e-02,   1.68457031e-02],
                        [  3.60107422e-03,   3.69262695e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.96838379e-02,  -1.97753906e-02],
                        [ -1.52893066e-02,  -1.52587891e-02],
                        [  5.12695312e-03,   5.15747070e-03],
                        [  3.78112793e-02,   3.77502441e-02],
                        [  7.52868652e-02,   7.52868652e-02],
                        [  1.12762451e-01,   1.12823486e-01],
                        [  1.47949219e-01,   1.47888184e-01],
                        [  1.75262451e-01,   1.75262451e-01],
                        [  1.83105469e-01,   1.83166504e-01],
                        [  1.54846191e-01,   1.54785156e-01],
                        [  7.86132812e-02,   7.85827637e-02],
                        [ -3.75976562e-02,  -3.75061035e-02],
                        [ -1.65008545e-01,  -1.65008545e-01],
                        [ -2.69165039e-01,  -2.69226074e-01],
                        [ -3.24615479e-01,  -3.24584961e-01],
                        [ -3.25347900e-01,  -3.25317383e-01],
                        [ -2.88391113e-01,  -2.88452148e-01],
                        [ -2.40875244e-01,  -2.40844727e-01],
                        [ -1.98699951e-01,  -1.98669434e-01],
                        [ -1.59881592e-01,  -1.59942627e-01],
                        [ -1.15692139e-01,  -1.15692139e-01],
                        [ -6.39953613e-02,  -6.39343262e-02],
                        [ -1.30004883e-02,  -1.30310059e-02],
                        [  2.60314941e-02,   2.59704590e-02],
                        [  4.92248535e-02,   4.92858887e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  7.20214844e-02,   7.19604492e-02],
                        [  8.58154297e-02,   8.58459473e-02],
                        [  1.03729248e-01,   1.03759766e-01],
                        [  1.18621826e-01,   1.18560791e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.15142822e-01,   1.15203857e-01],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  8.37097168e-02,   8.36486816e-02],
                        [  6.16760254e-02,   6.17065430e-02],
                        [  3.78417969e-02,   3.78723145e-02],
                        [  1.68762207e-02,   1.68457031e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [ -5.09643555e-03,  -5.06591797e-03],
                        [ -4.51660156e-03,  -4.54711914e-03],
                        [  4.21142578e-03,   4.18090820e-03],
                        [  2.10266113e-02,   2.10571289e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  6.00585938e-02,   5.99975586e-02],
                        [  6.99157715e-02,   6.99462891e-02],
                        [  7.35168457e-02,   7.35778809e-02],
                        [  7.30895996e-02,   7.30590820e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  5.82580566e-02,   5.82885742e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.38232422e-02,   4.37927246e-02],
                        [  4.21447754e-02,   4.21752930e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  3.24707031e-02,   3.24401855e-02],
                        [  1.81884766e-02,   1.82189941e-02],
                        [  1.58691406e-03,   1.61743164e-03],
                        [ -1.26953125e-02,  -1.27258301e-02],
                        [ -2.47497559e-02,  -2.47802734e-02],
                        [ -3.62548828e-02,  -3.62243652e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -4.92248535e-02,  -4.92553711e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.01416016e-03,  -1.98364258e-03],
                        [  1.95617676e-02,   1.95312500e-02],
                        [  3.88793945e-02,   3.88488770e-02],
                        [  5.03540039e-02,   5.04150391e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  4.95910645e-02,   4.95605469e-02],
                        [  4.76074219e-02,   4.76379395e-02],
                        [  4.98962402e-02,   4.99267578e-02],
                        [  5.40161133e-02,   5.39855957e-02],
                        [  5.67932129e-02,   5.68237305e-02],
                        [  5.82580566e-02,   5.82885742e-02],
                        [  5.88073730e-02,   5.87768555e-02],
                        [  5.74645996e-02,   5.74340820e-02],
                        [  5.34362793e-02,   5.34667969e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  2.95715332e-02,   2.95410156e-02],
                        [  7.04956055e-03,   7.08007812e-03],
                        [ -1.91955566e-02,  -1.92260742e-02],
                        [ -4.69665527e-02,  -4.69970703e-02],
                        [ -7.43713379e-02,  -7.43103027e-02],
                        [ -9.64965820e-02,  -9.64660645e-02],
                        [ -1.06842041e-01,  -1.06903076e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -8.55407715e-02,  -8.54797363e-02],
                        [ -6.50634766e-02,  -6.51245117e-02],
                        [ -4.80957031e-02,  -4.81262207e-02],
                        [ -3.50952148e-02,  -3.50341797e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.15661621e-02,  -1.16271973e-02],
                        [ -6.71386719e-04,  -6.40869141e-04],
                        [  9.97924805e-03,   1.00097656e-02],
                        [  1.85241699e-02,   1.84936523e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -4.50134277e-02,  -4.50439453e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.62341309e-02,  -4.62036133e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -2.64282227e-02,  -2.64587402e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -3.29589844e-03,  -3.26538086e-03],
                        [  1.23596191e-02,   1.23291016e-02],
                        [  2.88085938e-02,   2.87475586e-02],
                        [  4.33654785e-02,   4.33959961e-02],
                        [  5.36499023e-02,   5.36804199e-02],
                        [  5.78002930e-02,   5.77697754e-02],
                        [  5.65185547e-02,   5.65185547e-02],
                        [  5.34362793e-02,   5.34667969e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  4.78515625e-02,   4.78210449e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  4.48303223e-02,   4.48608398e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  6.90917969e-02,   6.90917969e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  1.14654541e-01,   1.14624023e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.01226807e-01,   1.01257324e-01],
                        [  4.76074219e-02,   4.76074219e-02],
                        [ -4.10156250e-02,  -4.10461426e-02],
                        [ -1.50207520e-01,  -1.50207520e-01],
                        [ -2.50549316e-01,  -2.50518799e-01],
                        [ -3.12957764e-01,  -3.12957764e-01],
                        [ -3.24645996e-01,  -3.24645996e-01],
                        [ -2.93701172e-01,  -2.93701172e-01],
                        [ -2.43835449e-01,  -2.43865967e-01],
                        [ -1.97937012e-01,  -1.97937012e-01],
                        [ -1.60888672e-01,  -1.60827637e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -6.85424805e-02,  -6.85729980e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [  2.99682617e-02,   2.99987793e-02],
                        [  4.79736328e-02,   4.80041504e-02],
                        [  5.05065918e-02,   5.04760742e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  1.03240967e-01,   1.03210449e-01],
                        [  1.07208252e-01,   1.07177734e-01],
                        [  9.82055664e-02,   9.82360840e-02],
                        [  8.40148926e-02,   8.40454102e-02],
                        [  7.42797852e-02,   7.42187500e-02],
                        [  7.07092285e-02,   7.06787109e-02],
                        [  6.67724609e-02,   6.68029785e-02],
                        [  5.61218262e-02,   5.61523438e-02],
                        [  4.03442383e-02,   4.03137207e-02],
                        [  2.66113281e-02,   2.65808105e-02],
                        [  1.92565918e-02,   1.92871094e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  1.94091797e-02,   1.94396973e-02],
                        [  1.69982910e-02,   1.69677734e-02],
                        [  1.41906738e-02,   1.41601562e-02],
                        [  9.30786133e-03,   9.33837891e-03],
                        [  4.33349609e-03,   4.36401367e-03],
                        [  4.18090820e-03,   4.11987305e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  1.83715820e-02,   1.84326172e-02],
                        [  2.45666504e-02,   2.45361328e-02],
                        [  2.91442871e-02,   2.90832520e-02],
                        [  3.32641602e-02,   3.32946777e-02],
                        [  3.55529785e-02,   3.56140137e-02],
                        [  3.40270996e-02,   3.39965820e-02],
                        [  2.98767090e-02,   2.98461914e-02],
                        [  2.61840820e-02,   2.62145996e-02],
                        [  2.23693848e-02,   2.23999023e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.08642578e-02,   1.08337402e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  4.94384766e-03,   4.97436523e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -7.38525391e-03,  -7.41577148e-03],
                        [ -1.14135742e-02,  -1.13830566e-02],
                        [ -1.27258301e-02,  -1.26953125e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -8.20922852e-03,  -8.27026367e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  1.62963867e-02,   1.63269043e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  3.22265625e-02,   3.21960449e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -6.07299805e-03,  -6.04248047e-03],
                        [ -1.63269043e-02,  -1.63574219e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.09960938e-02,  -2.10266113e-02],
                        [ -1.97448730e-02,  -1.97753906e-02],
                        [ -1.87683105e-02,  -1.87377930e-02],
                        [ -2.14538574e-02,  -2.14233398e-02],
                        [ -3.03649902e-02,  -3.03955078e-02],
                        [ -4.35791016e-02,  -4.36401367e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -6.60400391e-02,  -6.59790039e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -6.29577637e-02,  -6.30187988e-02],
                        [ -4.59594727e-02,  -4.59289551e-02],
                        [ -2.13317871e-02,  -2.13012695e-02],
                        [  2.96020508e-03,   2.89916992e-03],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  2.32849121e-02,   2.33459473e-02],
                        [  1.73339844e-02,   1.73034668e-02],
                        [  6.13403320e-03,   6.10351562e-03],
                        [ -2.89916992e-03,  -2.83813477e-03],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [ -2.34985352e-03,  -2.38037109e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.28271484e-02,  -2.27966309e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.19116211e-02,  -2.19726562e-02],
                        [ -1.70288086e-02,  -1.70593262e-02],
                        [ -1.12609863e-02,  -1.11999512e-02],
                        [ -4.60815430e-03,  -4.57763672e-03],
                        [  5.40161133e-03,   5.34057617e-03],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  3.49426270e-02,   3.49731445e-02],
                        [  4.61730957e-02,   4.62036133e-02],
                        [  5.37109375e-02,   5.36804199e-02],
                        [  6.30798340e-02,   6.30493164e-02],
                        [  7.88269043e-02,   7.88574219e-02],
                        [  1.01104736e-01,   1.01135254e-01],
                        [  1.25244141e-01,   1.25213623e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.40869141e-01,   1.40899658e-01],
                        [  1.12426758e-01,   1.12365723e-01],
                        [  5.02929688e-02,   5.02624512e-02],
                        [ -4.50439453e-02,  -4.49829102e-02],
                        [ -1.60552979e-01,  -1.60522461e-01],
                        [ -2.68951416e-01,  -2.69012451e-01],
                        [ -3.38165283e-01,  -3.38165283e-01],
                        [ -3.51318359e-01,  -3.51287842e-01],
                        [ -3.17932129e-01,  -3.17962646e-01],
                        [ -2.63397217e-01,  -2.63427734e-01],
                        [ -2.10754395e-01,  -2.10723877e-01],
                        [ -1.68670654e-01,  -1.68670654e-01],
                        [ -1.29089355e-01,  -1.29119873e-01],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [  4.91027832e-02,   4.91333008e-02],
                        [  9.23156738e-02,   9.23461914e-02],
                        [  1.12121582e-01,   1.12091064e-01],
                        [  1.18438721e-01,   1.18408203e-01],
                        [  1.20971680e-01,   1.21002197e-01],
                        [  1.21795654e-01,   1.21826172e-01],
                        [  1.18316650e-01,   1.18255615e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  9.31701660e-02,   9.32312012e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  5.44433594e-02,   5.44128418e-02],
                        [  3.60412598e-02,   3.60717773e-02],
                        [  2.09045410e-02,   2.09350586e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -8.11767578e-03,  -8.08715820e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  4.73022461e-03,   4.69970703e-03],
                        [  1.74560547e-02,   1.74255371e-02],
                        [  3.21655273e-02,   3.21960449e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  5.67321777e-02,   5.67016602e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  6.80236816e-02,   6.79931641e-02],
                        [  6.91528320e-02,   6.91528320e-02],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  5.25512695e-02,   5.25512695e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  1.99890137e-02,   1.99584961e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  6.16455078e-03,   6.19506836e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -2.08740234e-02,  -2.09045410e-02],
                        [ -2.64587402e-02,  -2.64892578e-02],
                        [ -2.01721191e-02,  -2.01416016e-02],
                        [ -5.82885742e-03,  -5.79833984e-03],
                        [  1.06811523e-02,   1.07116699e-02],
                        [  2.43530273e-02,   2.43225098e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.57263184e-02,   2.57873535e-02],
                        [  1.70593262e-02,   1.70898438e-02],
                        [  1.08947754e-02,   1.08642578e-02],
                        [  9.12475586e-03,   9.09423828e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  3.08227539e-03,   3.11279297e-03],
                        [  2.07519531e-03,   2.10571289e-03],
                        [  9.46044922e-03,   9.39941406e-03],
                        [  2.64892578e-02,   2.63977051e-02],
                        [  4.77294922e-02,   4.77905273e-02],
                        [  6.24694824e-02,   6.25915527e-02],
                        [  6.31103516e-02,   6.30798340e-02],
                        [  5.16357422e-02,   5.15441895e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  1.77917480e-02,   1.78833008e-02],
                        [ -9.46044922e-04,  -9.15527344e-04],
                        [ -2.02026367e-02,  -2.02941895e-02],
                        [ -3.63769531e-02,  -3.64379883e-02],
                        [ -4.76684570e-02,  -4.75769043e-02],
                        [ -5.49011230e-02,  -5.48400879e-02],
                        [ -5.88989258e-02,  -5.89599609e-02],
                        [ -5.96313477e-02,  -5.97229004e-02],
                        [ -5.68542480e-02,  -5.67932129e-02],
                        [ -5.02319336e-02,  -5.01098633e-02],
                        [ -3.88488770e-02,  -3.88793945e-02],
                        [ -2.16369629e-02,  -2.17285156e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  1.58081055e-02,   1.59301758e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.80053711e-02,   1.79443359e-02],
                        [  9.67407227e-03,   9.64355469e-03],
                        [  3.05175781e-04,   3.35693359e-04],
                        [ -1.16271973e-02,  -1.15661621e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -4.08935547e-02,  -4.09240723e-02],
                        [ -5.23681641e-02,  -5.23986816e-02],
                        [ -5.82580566e-02,  -5.82275391e-02],
                        [ -5.71594238e-02,  -5.71289062e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -1.80969238e-02,  -1.81274414e-02],
                        [ -2.65502930e-03,  -2.68554688e-03],
                        [  1.03149414e-02,   1.03759766e-02],
                        [  2.02636719e-02,   2.02941895e-02],
                        [  2.60925293e-02,   2.60314941e-02],
                        [  2.65502930e-02,   2.65197754e-02],
                        [  2.23693848e-02,   2.24609375e-02],
                        [  1.68151855e-02,   1.68457031e-02],
                        [  1.25732422e-02,   1.25122070e-02],
                        [  1.01013184e-02,   1.00708008e-02],
                        [  9.00268555e-03,   9.03320312e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  3.54003906e-03,   3.50952148e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  1.21154785e-02,   1.21459961e-02],
                        [  2.84118652e-02,   2.84423828e-02],
                        [  5.52062988e-02,   5.51757812e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  1.24176025e-01,   1.24206543e-01],
                        [  1.48895264e-01,   1.48864746e-01],
                        [  1.58905029e-01,   1.58874512e-01],
                        [  1.47857666e-01,   1.47888184e-01],
                        [  1.04431152e-01,   1.04461670e-01],
                        [  2.17285156e-02,   2.16979980e-02],
                        [ -9.07897949e-02,  -9.08203125e-02],
                        [ -2.08587646e-01,  -2.08557129e-01],
                        [ -3.02032471e-01,  -3.02001953e-01],
                        [ -3.46771240e-01,  -3.46771240e-01],
                        [ -3.36944580e-01,  -3.36944580e-01],
                        [ -2.92144775e-01,  -2.92144775e-01],
                        [ -2.42614746e-01,  -2.42614746e-01],
                        [ -2.04467773e-01,  -2.04467773e-01],
                        [ -1.70776367e-01,  -1.70776367e-01],
                        [ -1.26220703e-01,  -1.26190186e-01],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [  1.70898438e-03,   1.64794922e-03],
                        [  6.01196289e-02,   6.00891113e-02],
                        [  9.53674316e-02,   9.54284668e-02],
                        [  1.05743408e-01,   1.05773926e-01],
                        [  1.02935791e-01,   1.02844238e-01],
                        [  9.98535156e-02,   9.98229980e-02],
                        [  1.01379395e-01,   1.01470947e-01],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  9.79919434e-02,   9.79003906e-02],
                        [  8.51745605e-02,   8.52050781e-02],
                        [  7.01293945e-02,   7.01904297e-02],
                        [  5.74035645e-02,   5.73425293e-02],
                        [  4.78515625e-02,   4.78210449e-02],
                        [  3.81774902e-02,   3.82385254e-02],
                        [  2.38342285e-02,   2.38952637e-02],
                        [  6.46972656e-03,   6.40869141e-03],
                        [ -5.95092773e-03,  -6.01196289e-03],
                        [ -7.41577148e-03,  -7.38525391e-03],
                        [  9.15527344e-04,   9.46044922e-04],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  2.73132324e-02,   2.72827148e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.95910645e-02,   4.95605469e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.13305664e-02,   5.13916016e-02],
                        [  4.44641113e-02,   4.44030762e-02],
                        [  3.34472656e-02,   3.33862305e-02],
                        [  2.07214355e-02,   2.07519531e-02],
                        [  8.91113281e-03,   9.00268555e-03],
                        [  2.19726562e-03,   2.16674805e-03],
                        [  3.41796875e-03,   3.32641602e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  1.67541504e-02,   1.68457031e-02],
                        [  1.76696777e-02,   1.77001953e-02],
                        [  1.27868652e-02,   1.26953125e-02],
                        [  3.47900391e-03,   3.44848633e-03],
                        [ -9.00268555e-03,  -8.94165039e-03],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -2.77404785e-02,  -2.78320312e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.18811035e-02,  -2.18200684e-02],
                        [ -1.49230957e-02,  -1.49536133e-02],
                        [ -6.04248047e-03,  -6.10351562e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  2.60314941e-02,   2.60620117e-02],
                        [  4.43725586e-02,   4.43420410e-02],
                        [  5.82580566e-02,   5.82275391e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  5.81359863e-02,   5.81665039e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  1.76696777e-02,   1.77001953e-02],
                        [  8.42285156e-03,   8.45336914e-03],
                        [  6.10351562e-04,   5.79833984e-04],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [ -3.87573242e-03,  -3.84521484e-03],
                        [ -2.04467773e-03,  -1.98364258e-03],
                        [ -1.67846680e-03,  -1.73950195e-03],
                        [ -4.97436523e-03,  -5.03540039e-03],
                        [ -1.25122070e-02,  -1.24511719e-02],
                        [ -2.42919922e-02,  -2.42309570e-02],
                        [ -3.70483398e-02,  -3.70788574e-02],
                        [ -4.62341309e-02,  -4.62951660e-02],
                        [ -5.09033203e-02,  -5.08728027e-02],
                        [ -5.16967773e-02,  -5.16662598e-02],
                        [ -4.84008789e-02,  -4.84313965e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -2.82592773e-02,  -2.82287598e-02],
                        [ -1.62658691e-02,  -1.62963867e-02],
                        [ -9.39941406e-03,  -9.46044922e-03],
                        [ -8.02612305e-03,  -7.99560547e-03],
                        [ -8.97216797e-03,  -8.88061523e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -3.87573242e-03,  -3.99780273e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -2.86865234e-03,  -2.77709961e-03],
                        [ -1.23291016e-02,  -1.23596191e-02],
                        [ -2.42614746e-02,  -2.43530273e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.49426270e-02,  -3.48815918e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.44848633e-02,  -3.45764160e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.00598145e-02,  -2.99682617e-02],
                        [ -2.32238770e-02,  -2.32543945e-02],
                        [ -1.23596191e-02,  -1.24206543e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  1.20239258e-02,   1.21154785e-02],
                        [  1.99890137e-02,   1.99584961e-02],
                        [  2.57263184e-02,   2.56347656e-02],
                        [  2.99987793e-02,   2.99682617e-02],
                        [  3.13110352e-02,   3.13720703e-02],
                        [  2.67944336e-02,   2.68249512e-02],
                        [  1.64794922e-02,   1.64489746e-02],
                        [  5.85937500e-03,   5.82885742e-03],
                        [  2.13623047e-04,   2.74658203e-04],
                        [  2.04467773e-03,   2.10571289e-03],
                        [  1.22680664e-02,   1.22070312e-02],
                        [  2.86865234e-02,   2.86560059e-02],
                        [  4.81262207e-02,   4.81567383e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  8.99353027e-02,   8.98742676e-02],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.29516602e-01,   1.29608154e-01],
                        [  1.39373779e-01,   1.39404297e-01],
                        [  1.32812500e-01,   1.32720947e-01],
                        [  9.96398926e-02,   9.96093750e-02],
                        [  3.22265625e-02,   3.22875977e-02],
                        [ -6.65893555e-02,  -6.65588379e-02],
                        [ -1.78253174e-01,  -1.78283691e-01],
                        [ -2.72308350e-01,  -2.72369385e-01],
                        [ -3.23394775e-01,  -3.23364258e-01],
                        [ -3.26049805e-01,  -3.25958252e-01],
                        [ -2.94189453e-01,  -2.94219971e-01],
                        [ -2.49755859e-01,  -2.49847412e-01],
                        [ -2.09564209e-01,  -2.09503174e-01],
                        [ -1.76452637e-01,  -1.76391602e-01],
                        [ -1.39526367e-01,  -1.39587402e-01],
                        [ -8.67004395e-02,  -8.67614746e-02],
                        [ -2.21557617e-02,  -2.20947266e-02],
                        [  3.47900391e-02,   3.48510742e-02],
                        [  6.88171387e-02,   6.87561035e-02],
                        [  8.05664062e-02,   8.05053711e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  9.05456543e-02,   9.06066895e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.24420166e-01,   1.24389648e-01],
                        [  1.33697510e-01,   1.33636475e-01],
                        [  1.28112793e-01,   1.28143311e-01],
                        [  1.11145020e-01,   1.11206055e-01],
                        [  8.96911621e-02,   8.96606445e-02],
                        [  6.80236816e-02,   6.79626465e-02],
                        [  4.67529297e-02,   4.67224121e-02],
                        [  2.50244141e-02,   2.50854492e-02],
                        [  5.40161133e-03,   5.43212891e-03],
                        [ -7.01904297e-03,  -7.04956055e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -3.02124023e-03,  -3.05175781e-03],
                        [  6.10351562e-03,   6.07299805e-03],
                        [  1.44042969e-02,   1.44653320e-02],
                        [  2.29492188e-02,   2.30102539e-02],
                        [  3.42102051e-02,   3.41491699e-02],
                        [  4.90112305e-02,   4.89501953e-02],
                        [  6.37817383e-02,   6.38427734e-02],
                        [  7.24792480e-02,   7.25402832e-02],
                        [  7.43103027e-02,   7.42492676e-02],
                        [  7.17163086e-02,   7.16552734e-02],
                        [  6.32019043e-02,   6.32934570e-02],
                        [  4.62951660e-02,   4.63562012e-02],
                        [  2.42614746e-02,   2.42004395e-02],
                        [  4.57763672e-03,   4.54711914e-03],
                        [ -8.66699219e-03,  -8.57543945e-03],
                        [ -1.67236328e-02,  -1.66931152e-02],
                        [ -2.14538574e-02,  -2.15148926e-02],
                        [ -2.28881836e-02,  -2.29187012e-02],
                        [ -2.15454102e-02,  -2.14843750e-02],
                        [ -1.81274414e-02,  -1.80664062e-02],
                        [ -1.21765137e-02,  -1.22375488e-02],
                        [ -3.99780273e-03,  -4.02832031e-03],
                        [  3.93676758e-03,   3.96728516e-03],
                        [  9.79614258e-03,   9.82666016e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.43530273e-02,   2.43225098e-02],
                        [  3.65295410e-02,   3.65600586e-02],
                        [  4.84924316e-02,   4.84619141e-02],
                        [  5.64575195e-02,   5.64270020e-02],
                        [  5.90820312e-02,   5.91430664e-02],
                        [  5.61828613e-02,   5.62133789e-02],
                        [  4.91027832e-02,   4.90722656e-02],
                        [  4.08935547e-02,   4.08020020e-02],
                        [  3.18603516e-02,   3.19213867e-02],
                        [  2.07824707e-02,   2.08740234e-02],
                        [  9.55200195e-03,   9.52148438e-03],
                        [  1.37329102e-03,   1.34277344e-03],
                        [ -4.39453125e-03,  -4.36401367e-03],
                        [ -1.21459961e-02,  -1.21154785e-02],
                        [ -2.38342285e-02,  -2.38647461e-02],
                        [ -3.70178223e-02,  -3.70483398e-02],
                        [ -4.93164062e-02,  -4.92553711e-02],
                        [ -5.85327148e-02,  -5.84716797e-02],
                        [ -6.02416992e-02,  -6.03027344e-02],
                        [ -5.14526367e-02,  -5.14831543e-02],
                        [ -3.40576172e-02,  -3.39660645e-02],
                        [ -1.33666992e-02,  -1.33056641e-02],
                        [  5.21850586e-03,   5.12695312e-03],
                        [  1.69372559e-02,   1.68457031e-02],
                        [  1.84020996e-02,   1.84631348e-02],
                        [  1.12304688e-02,   1.12609863e-02],
                        [  2.25830078e-03,   2.22778320e-03],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [ -7.01904297e-03,  -6.98852539e-03],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -2.54821777e-02,  -2.55126953e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -4.22363281e-02,  -4.22058105e-02],
                        [ -4.26330566e-02,  -4.26635742e-02],
                        [ -3.73229980e-02,  -3.73840332e-02],
                        [ -2.92968750e-02,  -2.92663574e-02],
                        [ -2.40478516e-02,  -2.39562988e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.43530273e-02,  -2.44445801e-02],
                        [ -2.02941895e-02,  -2.03552246e-02],
                        [ -1.26342773e-02,  -1.25427246e-02],
                        [ -6.22558594e-03,  -6.16455078e-03],
                        [ -3.29589844e-03,  -3.38745117e-03],
                        [ -3.32641602e-03,  -3.38745117e-03],
                        [ -5.43212891e-03,  -5.37109375e-03],
                        [ -8.42285156e-03,  -8.36181641e-03],
                        [ -8.66699219e-03,  -8.69750977e-03],
                        [ -1.95312500e-03,  -1.98364258e-03],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  1.97753906e-02,   1.98364258e-02],
                        [  2.52075195e-02,   2.51770020e-02],
                        [  2.62756348e-02,   2.62451172e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  2.21252441e-02,   2.21557617e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  3.02429199e-02,   3.02124023e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  6.41174316e-02,   6.41479492e-02],
                        [  8.37707520e-02,   8.38012695e-02],
                        [  1.03485107e-01,   1.03454590e-01],
                        [  1.22467041e-01,   1.22436523e-01],
                        [  1.34185791e-01,   1.34216309e-01],
                        [  1.26800537e-01,   1.26861572e-01],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  7.59887695e-03,   7.56835938e-03],
                        [ -1.03790283e-01,  -1.03820801e-01],
                        [ -2.19299316e-01,  -2.19299316e-01],
                        [ -3.04229736e-01,  -3.04168701e-01],
                        [ -3.37219238e-01,  -3.37188721e-01],
                        [ -3.21472168e-01,  -3.21533203e-01],
                        [ -2.78717041e-01,  -2.78778076e-01],
                        [ -2.34558105e-01,  -2.34497070e-01],
                        [ -2.01721191e-01,  -2.01629639e-01],
                        [ -1.72393799e-01,  -1.72424316e-01],
                        [ -1.30889893e-01,  -1.30981445e-01],
                        [ -7.19299316e-02,  -7.19299316e-02],
                        [ -4.85229492e-03,  -4.82177734e-03],
                        [  5.35583496e-02,   5.35888672e-02],
                        [  9.16442871e-02,   9.16748047e-02],
                        [  1.10839844e-01,   1.10809326e-01],
                        [  1.20330811e-01,   1.20300293e-01],
                        [  1.26098633e-01,   1.26129150e-01],
                        [  1.27746582e-01,   1.27777100e-01],
                        [  1.23168945e-01,   1.23138428e-01],
                        [  1.12091064e-01,   1.12030029e-01],
                        [  9.47570801e-02,   9.47875977e-02],
                        [  7.17468262e-02,   7.17773438e-02],
                        [  4.53491211e-02,   4.53186035e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [  6.80541992e-03,   6.77490234e-03],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  4.87365723e-02,   4.87976074e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  8.23364258e-02,   8.22448730e-02],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  8.13293457e-02,   8.14208984e-02],
                        [  6.89697266e-02,   6.90002441e-02],
                        [  5.52368164e-02,   5.51757812e-02],
                        [  4.33959961e-02,   4.33654785e-02],
                        [  3.25317383e-02,   3.25927734e-02],
                        [  2.03552246e-02,   2.03857422e-02],
                        [  7.65991211e-03,   7.62939453e-03],
                        [ -3.32641602e-03,  -3.35693359e-03],
                        [ -1.34277344e-02,  -1.33972168e-02],
                        [ -2.31933594e-02,  -2.31628418e-02],
                        [ -2.89611816e-02,  -2.89916992e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.97143555e-02,  -1.96533203e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -3.05175781e-05,  -1.22070312e-04],
                        [  9.12475586e-03,   9.09423828e-03],
                        [  1.62963867e-02,   1.64184570e-02],
                        [  2.09045410e-02,   2.09350586e-02],
                        [  2.64892578e-02,   2.63671875e-02],
                        [  3.44848633e-02,   3.44238281e-02],
                        [  3.84521484e-02,   3.85437012e-02],
                        [  3.37829590e-02,   3.38745117e-02],
                        [  2.54211426e-02,   2.53601074e-02],
                        [  2.15759277e-02,   2.15148926e-02],
                        [  2.51464844e-02,   2.51770020e-02],
                        [  3.02734375e-02,   3.03649902e-02],
                        [  2.89001465e-02,   2.89306641e-02],
                        [  2.03247070e-02,   2.02636719e-02],
                        [  9.73510742e-03,   9.67407227e-03],
                        [  1.37329102e-03,   1.40380859e-03],
                        [ -3.50952148e-03,  -3.47900391e-03],
                        [ -5.09643555e-03,  -5.12695312e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  9.27734375e-03,   9.24682617e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.36718750e-02,  -1.36413574e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.31018066e-02,  -2.31323242e-02],
                        [ -2.49023438e-02,  -2.48718262e-02],
                        [ -2.87780762e-02,  -2.87170410e-02],
                        [ -3.38745117e-02,  -3.39050293e-02],
                        [ -3.65905762e-02,  -3.66821289e-02],
                        [ -3.61022949e-02,  -3.60717773e-02],
                        [ -3.60717773e-02,  -3.59802246e-02],
                        [ -3.83605957e-02,  -3.83911133e-02],
                        [ -3.85131836e-02,  -3.85742188e-02],
                        [ -3.28674316e-02,  -3.28369141e-02],
                        [ -2.38342285e-02,  -2.38037109e-02],
                        [ -1.56555176e-02,  -1.56860352e-02],
                        [ -1.04675293e-02,  -1.05285645e-02],
                        [ -9.03320312e-03,  -8.97216797e-03],
                        [ -1.09252930e-02,  -1.08642578e-02],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -1.29394531e-02,  -1.30004883e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -6.68334961e-03,  -6.62231445e-03],
                        [ -9.61303711e-03,  -9.58251953e-03],
                        [ -1.59301758e-02,  -1.60217285e-02],
                        [ -2.24914551e-02,  -2.25524902e-02],
                        [ -2.76794434e-02,  -2.76184082e-02],
                        [ -2.86254883e-02,  -2.85644531e-02],
                        [ -1.99890137e-02,  -2.00195312e-02],
                        [  1.83105469e-04,   6.10351562e-05],
                        [  2.49938965e-02,   2.50244141e-02],
                        [  4.27856445e-02,   4.28771973e-02],
                        [  4.66308594e-02,   4.66613770e-02],
                        [  3.93676758e-02,   3.92761230e-02],
                        [  2.85339355e-02,   2.85034180e-02],
                        [  1.88598633e-02,   1.88903809e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.07421875e-02,   1.07116699e-02],
                        [  1.65100098e-02,   1.65405273e-02],
                        [  2.80761719e-02,   2.81066895e-02],
                        [  4.55932617e-02,   4.55322266e-02],
                        [  7.01293945e-02,   7.00988770e-02],
                        [  9.73205566e-02,   9.73815918e-02],
                        [  1.19415283e-01,   1.19445801e-01],
                        [  1.32720947e-01,   1.32659912e-01],
                        [  1.34948730e-01,   1.34918213e-01],
                        [  1.18011475e-01,   1.18041992e-01],
                        [  6.97937012e-02,   6.98242188e-02],
                        [ -1.62658691e-02,  -1.62353516e-02],
                        [ -1.30523682e-01,  -1.30584717e-01],
                        [ -2.43865967e-01,  -2.43896484e-01],
                        [ -3.21014404e-01,  -3.20983887e-01],
                        [ -3.43933105e-01,  -3.43872070e-01],
                        [ -3.21594238e-01,  -3.21624756e-01],
                        [ -2.79724121e-01,  -2.79785156e-01],
                        [ -2.41882324e-01,  -2.41851807e-01],
                        [ -2.13745117e-01,  -2.13653564e-01],
                        [ -1.81488037e-01,  -1.81518555e-01],
                        [ -1.27899170e-01,  -1.27990723e-01],
                        [ -5.24291992e-02,  -5.23986816e-02],
                        [  2.49328613e-02,   2.50549316e-02],
                        [  8.24279785e-02,   8.23974609e-02],
                        [  1.14868164e-01,   1.14746094e-01],
                        [  1.30371094e-01,   1.30371094e-01],
                        [  1.37054443e-01,   1.37207031e-01],
                        [  1.38092041e-01,   1.38122559e-01],
                        [  1.33483887e-01,   1.33361816e-01],
                        [  1.22467041e-01,   1.22406006e-01],
                        [  1.04980469e-01,   1.05072021e-01],
                        [  8.35876465e-02,   8.36486816e-02],
                        [  6.32934570e-02,   6.32324219e-02],
                        [  4.70886230e-02,   4.70275879e-02],
                        [  3.22875977e-02,   3.23181152e-02],
                        [  1.60217285e-02,   1.60522461e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.73339844e-02,   1.73034668e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.90527344e-02,   2.90832520e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  3.70788574e-02,   3.70178223e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  5.27343750e-02,   5.27648926e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.30090332e-02,   5.29785156e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  4.03442383e-02,   4.03442383e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.01928711e-02,   1.02233887e-02],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -3.23486328e-03,  -3.29589844e-03],
                        [  1.01623535e-02,   1.01928711e-02],
                        [  2.51770020e-02,   2.52685547e-02],
                        [  3.52172852e-02,   3.51867676e-02],
                        [  3.89709473e-02,   3.88488770e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  4.01306152e-02,   4.02526855e-02],
                        [  3.75366211e-02,   3.75671387e-02],
                        [  3.37219238e-02,   3.35998535e-02],
                        [  2.91748047e-02,   2.91442871e-02],
                        [  2.29187012e-02,   2.30102539e-02],
                        [  1.50756836e-02,   1.51062012e-02],
                        [  8.51440430e-03,   8.48388672e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  4.24194336e-03,   4.21142578e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  2.56347656e-03,   2.59399414e-03],
                        [  3.75366211e-03,   3.72314453e-03],
                        [  7.93457031e-03,   7.87353516e-03],
                        [  1.00708008e-02,   1.01013184e-02],
                        [  5.67626953e-03,   5.76782227e-03],
                        [ -5.21850586e-03,  -5.24902344e-03],
                        [ -1.95922852e-02,  -1.96533203e-02],
                        [ -3.30505371e-02,  -3.30200195e-02],
                        [ -4.65087891e-02,  -4.64172363e-02],
                        [ -6.12487793e-02,  -6.12182617e-02],
                        [ -7.05261230e-02,  -7.06176758e-02],
                        [ -6.76879883e-02,  -6.77185059e-02],
                        [ -5.43212891e-02,  -5.41992188e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.10876465e-02,  -2.11791992e-02],
                        [ -7.62939453e-03,  -7.65991211e-03],
                        [  1.49536133e-03,   1.58691406e-03],
                        [  5.82885742e-03,   5.88989258e-03],
                        [  1.02539062e-02,   1.01623535e-02],
                        [  1.64184570e-02,   1.63574219e-02],
                        [  1.85852051e-02,   1.86462402e-02],
                        [  1.19934082e-02,   1.20239258e-02],
                        [ -4.88281250e-04,  -5.49316406e-04],
                        [ -1.04064941e-02,  -1.04370117e-02],
                        [ -1.27563477e-02,  -1.27258301e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -1.80053711e-03,  -1.83105469e-03],
                        [  2.92968750e-03,   2.99072266e-03],
                        [  1.15966797e-03,   1.22070312e-03],
                        [ -4.02832031e-03,  -4.11987305e-03],
                        [ -5.70678711e-03,  -5.76782227e-03],
                        [ -1.12915039e-03,  -1.03759766e-03],
                        [  5.64575195e-03,   5.70678711e-03],
                        [  1.06506348e-02,   1.05590820e-02],
                        [  1.57775879e-02,   1.57165527e-02],
                        [  2.31323242e-02,   2.31933594e-02],
                        [  3.16162109e-02,   3.16467285e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [  5.13305664e-02,   5.13610840e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  7.65991211e-02,   7.65380859e-02],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.23809814e-01,   1.23931885e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.48620605e-01,   1.48498535e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  5.33142090e-02,   5.34362793e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -1.81823730e-01,  -1.81915283e-01],
                        [ -2.81494141e-01,  -2.81463623e-01],
                        [ -3.30291748e-01,  -3.30200195e-01],
                        [ -3.25439453e-01,  -3.25439453e-01],
                        [ -2.87109375e-01,  -2.87139893e-01],
                        [ -2.44323730e-01,  -2.44293213e-01],
                        [ -2.13043213e-01,  -2.13012695e-01],
                        [ -1.86737061e-01,  -1.86767578e-01],
                        [ -1.49414062e-01,  -1.49414062e-01],
                        [ -9.35363770e-02,  -9.35058594e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [  3.34167480e-02,   3.33862305e-02],
                        [  7.10754395e-02,   7.11364746e-02],
                        [  8.52050781e-02,   8.52355957e-02],
                        [  8.77075195e-02,   8.76159668e-02],
                        [  9.15527344e-02,   9.14916992e-02],
                        [  9.97314453e-02,   9.98229980e-02],
                        [  1.05773926e-01,   1.05895996e-01],
                        [  1.05010986e-01,   1.04949951e-01],
                        [  9.99450684e-02,   9.98229980e-02],
                        [  9.43298340e-02,   9.43603516e-02],
                        [  8.70666504e-02,   8.72192383e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  5.98754883e-02,   5.97534180e-02],
                        [  4.49523926e-02,   4.48913574e-02],
                        [  3.19519043e-02,   3.20434570e-02],
                        [  2.10266113e-02,   2.10571289e-02],
                        [  1.46484375e-02,   1.45874023e-02],
                        [  1.56860352e-02,   1.56555176e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  3.81469727e-02,   3.81164551e-02],
                        [  3.93371582e-02,   3.92761230e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.01306152e-02,   4.01916504e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  9.06372070e-03,   9.03320312e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -3.90625000e-03,  -3.87573242e-03],
                        [  4.94384766e-03,   4.97436523e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.15966797e-02,  -1.16577148e-02],
                        [ -2.37426758e-02,  -2.37731934e-02],
                        [ -2.25830078e-02,  -2.24914551e-02],
                        [ -1.04064941e-02,  -1.03454590e-02],
                        [  1.61743164e-03,   1.52587891e-03],
                        [  5.64575195e-03,   5.61523438e-03],
                        [  1.80053711e-03,   1.89208984e-03],
                        [ -2.96020508e-03,  -2.89916992e-03],
                        [  1.03759766e-03,   9.46044922e-04],
                        [  1.54113770e-02,   1.53503418e-02],
                        [  2.94494629e-02,   2.95715332e-02],
                        [  3.31115723e-02,   3.31420898e-02],
                        [  2.85949707e-02,   2.85034180e-02],
                        [  2.52990723e-02,   2.52380371e-02],
                        [  2.77709961e-02,   2.78625488e-02],
                        [  3.26843262e-02,   3.27453613e-02],
                        [  3.52478027e-02,   3.51867676e-02],
                        [  3.44848633e-02,   3.44238281e-02],
                        [  3.23486328e-02,   3.23791504e-02],
                        [  3.10974121e-02,   3.11279297e-02],
                        [  3.06701660e-02,   3.07006836e-02],
                        [  2.83813477e-02,   2.83508301e-02],
                        [  2.09655762e-02,   2.09350586e-02],
                        [  7.87353516e-03,   7.90405273e-03],
                        [ -6.28662109e-03,  -6.25610352e-03],
                        [ -1.52587891e-02,  -1.52893066e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.51672363e-02,  -1.51977539e-02],
                        [ -2.01416016e-02,  -2.01721191e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.87475586e-02,  -2.86865234e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -3.14025879e-02,  -3.14941406e-02],
                        [ -2.54211426e-02,  -2.54516602e-02],
                        [ -1.61743164e-02,  -1.60827637e-02],
                        [ -1.00402832e-02,  -1.00097656e-02],
                        [ -1.17797852e-02,  -1.18408203e-02],
                        [ -1.90734863e-02,  -1.91650391e-02],
                        [ -2.75573730e-02,  -2.75268555e-02],
                        [ -3.46984863e-02,  -3.46069336e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -3.76586914e-02,  -3.77197266e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.51770020e-02,  -2.51464844e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -1.60217285e-02,  -1.60827637e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -5.67626953e-03,  -5.61523438e-03],
                        [ -1.40380859e-03,  -1.43432617e-03],
                        [  2.25830078e-03,   2.19726562e-03],
                        [  4.05883789e-03,   4.08935547e-03],
                        [  2.34985352e-03,   2.41088867e-03],
                        [ -3.20434570e-03,  -3.26538086e-03],
                        [ -9.36889648e-03,  -9.39941406e-03],
                        [ -1.24816895e-02,  -1.24511719e-02],
                        [ -1.22985840e-02,  -1.22375488e-02],
                        [ -7.87353516e-03,  -7.90405273e-03],
                        [  1.55639648e-03,   1.49536133e-03],
                        [  1.23596191e-02,   1.23901367e-02],
                        [  1.95922852e-02,   1.96228027e-02],
                        [  2.19116211e-02,   2.18811035e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.31323242e-02,   2.31933594e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.91442871e-02,   2.90832520e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  5.33447266e-02,   5.34057617e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  1.05255127e-01,   1.05194092e-01],
                        [  1.34246826e-01,   1.34246826e-01],
                        [  1.51245117e-01,   1.51245117e-01],
                        [  1.43218994e-01,   1.43188477e-01],
                        [  1.00036621e-01,   1.00006104e-01],
                        [  1.72424316e-02,   1.72729492e-02],
                        [ -9.79003906e-02,  -9.79003906e-02],
                        [ -2.20550537e-01,  -2.20611572e-01],
                        [ -3.16345215e-01,  -3.16375732e-01],
                        [ -3.59863281e-01,  -3.59771729e-01],
                        [ -3.47290039e-01,  -3.47259521e-01],
                        [ -2.95745850e-01,  -2.95837402e-01],
                        [ -2.31658936e-01,  -2.31750488e-01],
                        [ -1.77276611e-01,  -1.77185059e-01],
                        [ -1.38854980e-01,  -1.38732910e-01],
                        [ -1.03424072e-01,  -1.03515625e-01],
                        [ -5.47790527e-02,  -5.48706055e-02],
                        [  4.69970703e-03,   4.79125977e-03],
                        [  5.55114746e-02,   5.56030273e-02],
                        [  8.31909180e-02,   8.30993652e-02],
                        [  9.06982422e-02,   9.06372070e-02],
                        [  8.93554688e-02,   8.94470215e-02],
                        [  8.76770020e-02,   8.77075195e-02],
                        [  8.98132324e-02,   8.97216797e-02],
                        [  9.35974121e-02,   9.35668945e-02],
                        [  9.11254883e-02,   9.12475586e-02],
                        [  7.96813965e-02,   7.97119141e-02],
                        [  6.59179688e-02,   6.58264160e-02],
                        [  5.63049316e-02,   5.62744141e-02],
                        [  5.00793457e-02,   5.01403809e-02],
                        [  4.24804688e-02,   4.25109863e-02],
                        [  3.10974121e-02,   3.10668945e-02],
                        [  1.95312500e-02,   1.95007324e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  5.70068359e-02,   5.70373535e-02],
                        [  7.46154785e-02,   7.45849609e-02],
                        [  8.83483887e-02,   8.82873535e-02],
                        [  9.66796875e-02,   9.67102051e-02],
                        [  9.61608887e-02,   9.61914062e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  6.33850098e-02,   6.33544922e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.17382812e-03,   3.20434570e-03],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -5.17272949e-02,  -5.17578125e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -6.50024414e-02,  -6.49719238e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.48095703e-02,  -5.48400879e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.79736328e-02,  -4.79431152e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -2.12097168e-02,  -2.12707520e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  3.22265625e-02,   3.22875977e-02],
                        [  4.89196777e-02,   4.89501953e-02],
                        [  5.65795898e-02,   5.65490723e-02],
                        [  6.04858398e-02,   6.04553223e-02],
                        [  6.31713867e-02,   6.32019043e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.50329590e-02,   6.50024414e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  6.39648438e-02,   6.39953613e-02],
                        [  5.72509766e-02,   5.72204590e-02],
                        [  4.86755371e-02,   4.86145020e-02],
                        [  3.91235352e-02,   3.91540527e-02],
                        [  2.53601074e-02,   2.54516602e-02],
                        [  6.89697266e-03,   6.86645508e-03],
                        [ -1.03454590e-02,  -1.04675293e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -2.51770020e-02,  -2.50549316e-02],
                        [ -2.88696289e-02,  -2.88085938e-02],
                        [ -3.20434570e-02,  -3.21350098e-02],
                        [ -3.03649902e-02,  -3.03955078e-02],
                        [ -2.18200684e-02,  -2.17895508e-02],
                        [ -9.24682617e-03,  -9.21630859e-03],
                        [  3.57055664e-03,   3.54003906e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.72424316e-02,   1.72729492e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [ -1.15661621e-02,  -1.15051270e-02],
                        [ -2.74353027e-02,  -2.74658203e-02],
                        [ -4.11987305e-02,  -4.12902832e-02],
                        [ -4.79736328e-02,  -4.80041504e-02],
                        [ -4.91027832e-02,  -4.90112305e-02],
                        [ -4.87670898e-02,  -4.87365723e-02],
                        [ -4.79431152e-02,  -4.80041504e-02],
                        [ -4.43725586e-02,  -4.44030762e-02],
                        [ -3.81469727e-02,  -3.81164551e-02],
                        [ -3.22265625e-02,  -3.21655273e-02],
                        [ -2.59704590e-02,  -2.60009766e-02],
                        [ -1.70288086e-02,  -1.70593262e-02],
                        [ -7.41577148e-03,  -7.38525391e-03],
                        [ -1.19018555e-03,  -1.15966797e-03],
                        [  1.22070312e-04,   9.15527344e-05],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -6.62231445e-03,  -6.59179688e-03],
                        [ -1.01318359e-02,  -1.01013184e-02],
                        [ -1.29699707e-02,  -1.30004883e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -5.06591797e-03,  -5.03540039e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.71508789e-02,   1.71203613e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.82189941e-02,   1.82495117e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.07519531e-02,   2.06909180e-02],
                        [  2.76794434e-02,   2.76489258e-02],
                        [  3.63464355e-02,   3.64074707e-02],
                        [  4.32128906e-02,   4.32434082e-02],
                        [  4.90722656e-02,   4.89807129e-02],
                        [  5.74951172e-02,   5.74035645e-02],
                        [  6.82678223e-02,   6.83288574e-02],
                        [  7.80334473e-02,   7.81250000e-02],
                        [  8.68225098e-02,   8.67919922e-02],
                        [  9.63439941e-02,   9.62524414e-02],
                        [  1.00128174e-01,   1.00158691e-01],
                        [  8.10852051e-02,   8.11462402e-02],
                        [  2.29492188e-02,   2.29187012e-02],
                        [ -7.42797852e-02,  -7.43408203e-02],
                        [ -1.89880371e-01,  -1.89849854e-01],
                        [ -2.88665771e-01,  -2.88604736e-01],
                        [ -3.36700439e-01,  -3.36761475e-01],
                        [ -3.24310303e-01,  -3.24371338e-01],
                        [ -2.74597168e-01,  -2.74536133e-01],
                        [ -2.23510742e-01,  -2.23419189e-01],
                        [ -1.90551758e-01,  -1.90612793e-01],
                        [ -1.68090820e-01,  -1.68182373e-01],
                        [ -1.37054443e-01,  -1.37023926e-01],
                        [ -8.77380371e-02,  -8.76159668e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [  3.14025879e-02,   3.13110352e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  8.85009766e-02,   8.85925293e-02],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  1.05926514e-01,   1.05865479e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.32232666e-01,   1.32263184e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.20056152e-01,   1.20025635e-01],
                        [  9.93652344e-02,   9.94262695e-02],
                        [  7.41577148e-02,   7.41882324e-02],
                        [  4.92553711e-02,   4.92248535e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  1.80053711e-02,   1.80358887e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.38244629e-02,   1.37939453e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  3.96423340e-02,   3.96118164e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  5.62133789e-02,   5.62744141e-02],
                        [  6.10656738e-02,   6.10351562e-02],
                        [  6.37817383e-02,   6.37512207e-02],
                        [  6.21032715e-02,   6.21337891e-02],
                        [  5.14221191e-02,   5.14221191e-02],
                        [  3.20434570e-02,   3.20129395e-02],
                        [  1.08947754e-02,   1.09252930e-02],
                        [ -5.98144531e-03,  -5.95092773e-03],
                        [ -1.60522461e-02,  -1.60827637e-02],
                        [ -1.87377930e-02,  -1.87683105e-02],
                        [ -1.67846680e-02,  -1.67541504e-02],
                        [ -1.49230957e-02,  -1.48620605e-02],
                        [ -1.73034668e-02,  -1.73339844e-02],
                        [ -2.50854492e-02,  -2.51464844e-02],
                        [ -3.31726074e-02,  -3.31420898e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -2.84118652e-02,  -2.83813477e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  4.69970703e-03,   4.63867188e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.47399902e-02,   1.48315430e-02],
                        [  2.15759277e-02,   2.16064453e-02],
                        [  3.38745117e-02,   3.37524414e-02],
                        [  4.75158691e-02,   4.74853516e-02],
                        [  5.40771484e-02,   5.41687012e-02],
                        [  4.98046875e-02,   4.98657227e-02],
                        [  4.01306152e-02,   4.01000977e-02],
                        [  3.29895020e-02,   3.28979492e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  3.35388184e-02,   3.35998535e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  4.05273438e-02,   4.04968262e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  3.20739746e-02,   3.21044922e-02],
                        [  2.40783691e-02,   2.41088867e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -5.00488281e-03,  -4.94384766e-03],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -2.26745605e-02,  -2.27661133e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -3.08532715e-02,  -3.07922363e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.61022949e-02,  -3.61328125e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.69470215e-02,  -2.69775391e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.37939453e-02,  -1.37329102e-02],
                        [ -1.38244629e-02,  -1.38549805e-02],
                        [ -1.55639648e-02,  -1.56555176e-02],
                        [ -1.75476074e-02,  -1.75170898e-02],
                        [ -2.07519531e-02,  -2.06298828e-02],
                        [ -2.33459473e-02,  -2.34069824e-02],
                        [ -2.20642090e-02,  -2.22167969e-02],
                        [ -1.93481445e-02,  -1.93176270e-02],
                        [ -1.96533203e-02,  -1.95312500e-02],
                        [ -2.11181641e-02,  -2.11486816e-02],
                        [ -1.92565918e-02,  -1.93176270e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.49536133e-02,  -1.49230957e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.81274414e-02,  -1.81579590e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -5.67626953e-03,  -5.70678711e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.01928711e-02,   1.02539062e-02],
                        [  9.88769531e-03,   9.85717773e-03],
                        [  5.92041016e-03,   5.85937500e-03],
                        [  4.15039062e-03,   4.18090820e-03],
                        [  7.78198242e-03,   7.84301758e-03],
                        [  1.47705078e-02,   1.47094727e-02],
                        [  2.10266113e-02,   2.09350586e-02],
                        [  2.29187012e-02,   2.29797363e-02],
                        [  1.85546875e-02,   1.86462402e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  7.62939453e-03,   7.56835938e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  2.82897949e-02,   2.83508301e-02],
                        [  4.81872559e-02,   4.82482910e-02],
                        [  6.93664551e-02,   6.93969727e-02],
                        [  9.28039551e-02,   9.27124023e-02],
                        [  1.18774414e-01,   1.18713379e-01],
                        [  1.37329102e-01,   1.37390137e-01],
                        [  1.32751465e-01,   1.32873535e-01],
                        [  9.65270996e-02,   9.64965820e-02],
                        [  2.86865234e-02,   2.85644531e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -1.73828125e-01,  -1.73706055e-01],
                        [ -2.69805908e-01,  -2.69744873e-01],
                        [ -3.25866699e-01,  -3.25988770e-01],
                        [ -3.30261230e-01,  -3.30322266e-01],
                        [ -2.97424316e-01,  -2.97332764e-01],
                        [ -2.54913330e-01,  -2.54852295e-01],
                        [ -2.20001221e-01,  -2.20031738e-01],
                        [ -1.88201904e-01,  -1.88232422e-01],
                        [ -1.42486572e-01,  -1.42486572e-01],
                        [ -7.46154785e-02,  -7.45849609e-02],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  1.08734131e-01,   1.08703613e-01],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  9.82971191e-02,   9.83581543e-02],
                        [  9.56726074e-02,   9.57031250e-02],
                        [  9.46044922e-02,   9.45129395e-02],
                        [  9.06677246e-02,   9.06372070e-02],
                        [  8.00476074e-02,   8.01391602e-02],
                        [  6.37207031e-02,   6.37817383e-02],
                        [  4.81262207e-02,   4.80346680e-02],
                        [  3.93981934e-02,   3.92761230e-02],
                        [  3.58276367e-02,   3.59191895e-02],
                        [  3.18603516e-02,   3.20129395e-02],
                        [  2.71606445e-02,   2.71301270e-02],
                        [  2.73437500e-02,   2.71301270e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  4.75463867e-02,   4.77600098e-02],
                        [  5.72509766e-02,   5.73120117e-02],
                        [  6.63757324e-02,   6.61926270e-02],
                        [  7.66906738e-02,   7.65686035e-02],
                        [  8.20312500e-02,   8.22143555e-02],
                        [  7.45544434e-02,   7.46765137e-02],
                        [  5.40161133e-02,   5.39245605e-02],
                        [  2.75573730e-02,   2.74353027e-02],
                        [  2.53295898e-03,   2.56347656e-03],
                        [ -1.64184570e-02,  -1.63574219e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.03344727e-02,  -3.03649902e-02],
                        [ -3.14331055e-02,  -3.14636230e-02],
                        [ -3.22570801e-02,  -3.22265625e-02],
                        [ -3.01818848e-02,  -3.01208496e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -1.62963867e-02,  -1.63879395e-02],
                        [ -6.56127930e-03,  -6.59179688e-03],
                        [  2.10571289e-03,   2.16674805e-03],
                        [  8.88061523e-03,   8.91113281e-03],
                        [  1.55029297e-02,   1.54418945e-02],
                        [  2.38037109e-02,   2.37121582e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  4.04357910e-02,   4.05273438e-02],
                        [  4.33654785e-02,   4.33959961e-02],
                        [  4.47692871e-02,   4.46777344e-02],
                        [  4.78210449e-02,   4.77600098e-02],
                        [  5.03845215e-02,   5.04760742e-02],
                        [  4.75769043e-02,   4.76989746e-02],
                        [  4.07714844e-02,   4.07104492e-02],
                        [  3.70788574e-02,   3.69567871e-02],
                        [  3.64685059e-02,   3.65295410e-02],
                        [  3.14331055e-02,   3.15551758e-02],
                        [  2.06604004e-02,   2.06298828e-02],
                        [  1.03454590e-02,   1.02233887e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.19018555e-03,   1.28173828e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [  2.71606445e-03,   2.68554688e-03],
                        [  4.94384766e-03,   4.85229492e-03],
                        [  7.78198242e-03,   7.75146484e-03],
                        [  1.07421875e-02,   1.08337402e-02],
                        [  9.61303711e-03,   9.67407227e-03],
                        [  1.61743164e-03,   1.55639648e-03],
                        [ -1.01013184e-02,  -1.02233887e-02],
                        [ -2.14233398e-02,  -2.13928223e-02],
                        [ -2.98156738e-02,  -2.96630859e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.27758789e-02,  -3.28979492e-02],
                        [ -2.88391113e-02,  -2.88696289e-02],
                        [ -2.44750977e-02,  -2.44140625e-02],
                        [ -2.20336914e-02,  -2.19726562e-02],
                        [ -2.14538574e-02,  -2.14843750e-02],
                        [ -2.15759277e-02,  -2.16369629e-02],
                        [ -2.07824707e-02,  -2.07519531e-02],
                        [ -1.75170898e-02,  -1.74560547e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -3.57055664e-03,  -3.63159180e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  2.65502930e-03,   2.71606445e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -1.49841309e-02,  -1.50451660e-02],
                        [ -2.12097168e-02,  -2.11791992e-02],
                        [ -2.22778320e-02,  -2.22167969e-02],
                        [ -2.06298828e-02,  -2.06604004e-02],
                        [ -1.70898438e-02,  -1.71508789e-02],
                        [ -1.11694336e-02,  -1.11389160e-02],
                        [ -3.50952148e-03,  -3.44848633e-03],
                        [  4.88281250e-03,   4.85229492e-03],
                        [  1.20849609e-02,   1.20544434e-02],
                        [  1.49536133e-02,   1.50146484e-02],
                        [  1.33666992e-02,   1.33972168e-02],
                        [  1.12915039e-02,   1.12304688e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.26037598e-02,   1.26647949e-02],
                        [  1.09558105e-02,   1.10168457e-02],
                        [  9.06372070e-03,   8.97216797e-03],
                        [  9.64355469e-03,   9.58251953e-03],
                        [  1.12915039e-02,   1.13525391e-02],
                        [  1.31835938e-02,   1.32751465e-02],
                        [  1.84631348e-02,   1.84020996e-02],
                        [  3.03039551e-02,   3.02124023e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [  7.28454590e-02,   7.29675293e-02],
                        [  9.85412598e-02,   9.85717773e-02],
                        [  1.21673584e-01,   1.21551514e-01],
                        [  1.35620117e-01,   1.35559082e-01],
                        [  1.31805420e-01,   1.31896973e-01],
                        [  9.96704102e-02,   9.97619629e-02],
                        [  3.25622559e-02,   3.25012207e-02],
                        [ -6.48193359e-02,  -6.49108887e-02],
                        [ -1.76574707e-01,  -1.76513672e-01],
                        [ -2.77862549e-01,  -2.77770996e-01],
                        [ -3.39172363e-01,  -3.39202881e-01],
                        [ -3.41888428e-01,  -3.41949463e-01],
                        [ -2.96783447e-01,  -2.96752930e-01],
                        [ -2.40386963e-01,  -2.40325928e-01],
                        [ -2.02697754e-01,  -2.02758789e-01],
                        [ -1.81060791e-01,  -1.81121826e-01],
                        [ -1.52343750e-01,  -1.52313232e-01],
                        [ -1.02447510e-01,  -1.02416992e-01],
                        [ -3.58276367e-02,  -3.58581543e-02],
                        [  3.08837891e-02,   3.08532715e-02],
                        [  7.91015625e-02,   7.91320801e-02],
                        [  1.02478027e-01,   1.02447510e-01],
                        [  1.10839844e-01,   1.10809326e-01],
                        [  1.16546631e-01,   1.16607666e-01],
                        [  1.22497559e-01,   1.22528076e-01],
                        [  1.25366211e-01,   1.25305176e-01],
                        [  1.22558594e-01,   1.22497559e-01],
                        [  1.11968994e-01,   1.12060547e-01],
                        [  9.28344727e-02,   9.29260254e-02],
                        [  6.92749023e-02,   6.91833496e-02],
                        [  4.67224121e-02,   4.66308594e-02],
                        [  2.59704590e-02,   2.60620117e-02],
                        [  7.20214844e-03,   7.29370117e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [ -9.15527344e-04,  -9.76562500e-04],
                        [  1.51977539e-02,   1.52282715e-02],
                        [  3.68957520e-02,   3.69567871e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.07189941e-02,   8.06884766e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  3.96423340e-02,   3.96728516e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [ -1.87988281e-02,  -1.88598633e-02],
                        [ -3.18603516e-02,  -3.18908691e-02],
                        [ -3.40270996e-02,  -3.39660645e-02],
                        [ -3.20434570e-02,  -3.20129395e-02],
                        [ -3.19519043e-02,  -3.20434570e-02],
                        [ -3.51867676e-02,  -3.52172852e-02],
                        [ -3.85437012e-02,  -3.84521484e-02],
                        [ -3.92456055e-02,  -3.91845703e-02],
                        [ -3.63159180e-02,  -3.64074707e-02],
                        [ -2.75268555e-02,  -2.75878906e-02],
                        [ -1.17797852e-02,  -1.17187500e-02],
                        [  5.82885742e-03,   5.92041016e-03],
                        [  1.90124512e-02,   1.89819336e-02],
                        [  2.75573730e-02,   2.74658203e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.71093750e-02,   3.72009277e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.72619629e-02,   3.71704102e-02],
                        [  4.36706543e-02,   4.36096191e-02],
                        [  4.96520996e-02,   4.97131348e-02],
                        [  4.94689941e-02,   4.95300293e-02],
                        [  4.52270508e-02,   4.51660156e-02],
                        [  4.19616699e-02,   4.19006348e-02],
                        [  4.06188965e-02,   4.06494141e-02],
                        [  3.87573242e-02,   3.88183594e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  2.96936035e-02,   2.96325684e-02],
                        [  2.19421387e-02,   2.19726562e-02],
                        [  1.28784180e-02,   1.29089355e-02],
                        [  5.88989258e-03,   5.85937500e-03],
                        [  4.82177734e-03,   4.79125977e-03],
                        [  9.30786133e-03,   9.33837891e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.04980469e-02,   1.04675293e-02],
                        [  1.49536133e-03,   1.46484375e-03],
                        [ -1.17492676e-02,  -1.17187500e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.54919434e-02,  -3.55529785e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.49426270e-02,  -3.49121094e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.27453613e-02,  -3.28063965e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.60717773e-02,  -3.60107422e-02],
                        [ -3.59497070e-02,  -3.59191895e-02],
                        [ -3.43627930e-02,  -3.44238281e-02],
                        [ -2.95104980e-02,  -2.95715332e-02],
                        [ -2.28881836e-02,  -2.28271484e-02],
                        [ -2.02636719e-02,  -2.02026367e-02],
                        [ -2.29187012e-02,  -2.29492188e-02],
                        [ -2.38342285e-02,  -2.39257812e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -1.32141113e-02,  -1.31225586e-02],
                        [ -1.00402832e-02,  -1.00097656e-02],
                        [ -7.44628906e-03,  -7.53784180e-03],
                        [ -1.25122070e-03,  -1.31225586e-03],
                        [  7.50732422e-03,   7.53784180e-03],
                        [  1.17187500e-02,   1.17797852e-02],
                        [  8.72802734e-03,   8.69750977e-03],
                        [  5.12695312e-03,   5.06591797e-03],
                        [  6.46972656e-03,   6.43920898e-03],
                        [  9.03320312e-03,   9.06372070e-03],
                        [  6.62231445e-03,   6.68334961e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -3.81469727e-03,  -3.87573242e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [ -1.06811523e-03,  -1.00708008e-03],
                        [  3.69262695e-03,   3.72314453e-03],
                        [  9.94873047e-03,   9.88769531e-03],
                        [  1.59912109e-02,   1.59301758e-02],
                        [  1.93176270e-02,   1.93786621e-02],
                        [  2.02941895e-02,   2.03552246e-02],
                        [  2.25524902e-02,   2.24914551e-02],
                        [  2.82897949e-02,   2.82287598e-02],
                        [  3.68652344e-02,   3.68957520e-02],
                        [  4.81872559e-02,   4.82482910e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  8.50830078e-02,   8.50219727e-02],
                        [  1.07513428e-01,   1.07482910e-01],
                        [  1.22619629e-01,   1.22650146e-01],
                        [  1.19232178e-01,   1.19262695e-01],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  3.18603516e-02,   3.18298340e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -1.44622803e-01,  -1.44561768e-01],
                        [ -2.38708496e-01,  -2.38708496e-01],
                        [ -3.04138184e-01,  -3.04138184e-01],
                        [ -3.21807861e-01,  -3.21807861e-01],
                        [ -2.97027588e-01,  -2.97058105e-01],
                        [ -2.54516602e-01,  -2.54516602e-01],
                        [ -2.17498779e-01,  -2.17468262e-01],
                        [ -1.91650391e-01,  -1.91650391e-01],
                        [ -1.64276123e-01,  -1.64337158e-01],
                        [ -1.19354248e-01,  -1.19415283e-01],
                        [ -5.59387207e-02,  -5.58471680e-02],
                        [  1.15051270e-02,   1.15966797e-02],
                        [  6.83288574e-02,   6.82678223e-02],
                        [  1.09588623e-01,   1.09466553e-01],
                        [  1.35040283e-01,   1.35070801e-01],
                        [  1.43249512e-01,   1.43371582e-01],
                        [  1.36688232e-01,   1.36688232e-01],
                        [  1.24633789e-01,   1.24511719e-01],
                        [  1.12457275e-01,   1.12426758e-01],
                        [  9.62524414e-02,   9.63439941e-02],
                        [  7.28454590e-02,   7.28759766e-02],
                        [  4.80957031e-02,   4.80346680e-02],
                        [  3.14331055e-02,   3.13720703e-02],
                        [  2.47802734e-02,   2.48107910e-02],
                        [  2.24304199e-02,   2.24609375e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.90429688e-02,   1.89819336e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  3.71093750e-02,   3.71398926e-02],
                        [  5.82580566e-02,   5.82580566e-02],
                        [  7.96508789e-02,   7.96203613e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  8.40148926e-02,   8.40148926e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [ -4.15039062e-03,  -4.18090820e-03],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -8.08715820e-03,  -8.05664062e-03],
                        [ -7.90405273e-03,  -7.87353516e-03],
                        [ -1.82495117e-02,  -1.82800293e-02],
                        [ -3.44848633e-02,  -3.45458984e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -5.03540039e-02,  -5.02929688e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.30200195e-02,  -3.30810547e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.80053711e-03,  -1.73950195e-03],
                        [  1.27868652e-02,   1.28173828e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  3.89099121e-02,   3.88793945e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.27246094e-02,   4.26940918e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  2.92053223e-02,   2.92663574e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.07519531e-02,   2.07214355e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  2.68249512e-02,   2.68554688e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.92968750e-02,   2.92663574e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  4.01916504e-02,   4.02221680e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.21044922e-02,  -3.21350098e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.76892090e-02,  -3.76586914e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.56445312e-02,  -3.56750488e-02],
                        [ -2.90222168e-02,  -2.90527344e-02],
                        [ -2.54211426e-02,  -2.53601074e-02],
                        [ -2.44445801e-02,  -2.44140625e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -1.39160156e-02,  -1.39465332e-02],
                        [ -1.21765137e-02,  -1.21459961e-02],
                        [ -1.40991211e-02,  -1.40686035e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -7.29370117e-03,  -7.32421875e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -1.30920410e-02,  -1.31225586e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -7.26318359e-03,  -7.23266602e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  1.77001953e-02,   1.77307129e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.19018555e-02,   1.18713379e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -2.41088867e-03,  -2.38037109e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.33056641e-02,  -1.33361816e-02],
                        [ -4.57763672e-03,  -4.60815430e-03],
                        [  8.02612305e-03,   8.05664062e-03],
                        [  1.58386230e-02,   1.58691406e-02],
                        [  2.05993652e-02,   2.05688477e-02],
                        [  2.89611816e-02,   2.89306641e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  5.00488281e-02,   5.00793457e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  7.76367188e-02,   7.76367188e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.31072998e-01,   1.31103516e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  6.40258789e-02,   6.40258789e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -1.43127441e-01,  -1.43127441e-01],
                        [ -2.52929688e-01,  -2.52899170e-01],
                        [ -3.22448730e-01,  -3.22418213e-01],
                        [ -3.32733154e-01,  -3.32733154e-01],
                        [ -2.91137695e-01,  -2.91137695e-01],
                        [ -2.30682373e-01,  -2.30682373e-01],
                        [ -1.88049316e-01,  -1.88049316e-01],
                        [ -1.71905518e-01,  -1.71905518e-01],
                        [ -1.59393311e-01,  -1.59393311e-01],
                        [ -1.26251221e-01,  -1.26251221e-01],
                        [ -7.12280273e-02,  -7.12280273e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [  4.49218750e-02,   4.49523926e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.21063232e-01,   1.21063232e-01],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  9.43908691e-02,   9.43908691e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  7.47375488e-02,   7.47070312e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  1.81884766e-02,   1.82189941e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  3.85437012e-02,   3.85131836e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  7.81250000e-02,   7.81250000e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  5.91735840e-02,   5.91430664e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [ -5.49316406e-04,  -5.18798828e-04],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.33972168e-02,  -1.33666992e-02],
                        [ -1.09558105e-02,  -1.09252930e-02],
                        [ -1.77307129e-02,  -1.77612305e-02],
                        [ -2.96936035e-02,  -2.97241211e-02],
                        [ -4.01611328e-02,  -4.01306152e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.44543457e-02,  -3.44848633e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [  9.70458984e-03,   9.70458984e-03],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  3.55224609e-02,   3.54919434e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.93273926e-02,   2.93579102e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  3.23181152e-02,   3.22875977e-02],
                        [  3.23791504e-02,   3.24096680e-02],
                        [  3.40881348e-02,   3.41186523e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.53088379e-02,   3.52783203e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  3.33251953e-02,   3.33557129e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  1.78527832e-02,   1.78833008e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  7.93457031e-04,   7.93457031e-04],
                        [ -3.05175781e-03,  -3.02124023e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -4.15344238e-02,  -4.15039062e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.26342773e-02,  -1.26647949e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.27355957e-02,  -2.27661133e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  6.98852539e-03,   7.01904297e-03],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.27410889e-01,   1.27380371e-01],
                        [  1.26190186e-01,   1.26190186e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -1.40167236e-01,  -1.40167236e-01],
                        [ -2.49816895e-01,  -2.49816895e-01],
                        [ -3.26843262e-01,  -3.26843262e-01],
                        [ -3.42895508e-01,  -3.42895508e-01],
                        [ -3.04779053e-01,  -3.04809570e-01],
                        [ -2.46948242e-01,  -2.46948242e-01],
                        [ -1.99645996e-01,  -1.99645996e-01],
                        [ -1.70043945e-01,  -1.70043945e-01],
                        [ -1.47308350e-01,  -1.47308350e-01],
                        [ -1.16912842e-01,  -1.16912842e-01],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  1.24847412e-01,   1.24847412e-01],
                        [  1.34216309e-01,   1.34216309e-01],
                        [  1.32568359e-01,   1.32568359e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  5.73120117e-02,   5.73120117e-02],
                        [  4.31823730e-02,   4.31518555e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  4.93164062e-02,   4.93469238e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  5.97534180e-02,   5.97229004e-02],
                        [  5.98449707e-02,   5.98449707e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.68457031e-02,  -1.68762207e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.42517090e-02,  -1.42211914e-02],
                        [ -2.08435059e-02,  -2.08129883e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.15966797e-03,   1.15966797e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  8.34045410e-02,   8.34045410e-02],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  7.15637207e-02,   7.15637207e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -2.36389160e-01,  -2.36389160e-01],
                        [ -3.19396973e-01,  -3.19396973e-01],
                        [ -3.41003418e-01,  -3.41003418e-01],
                        [ -3.03405762e-01,  -3.03405762e-01],
                        [ -2.40875244e-01,  -2.40875244e-01],
                        [ -1.91802979e-01,  -1.91802979e-01],
                        [ -1.68670654e-01,  -1.68670654e-01],
                        [ -1.56341553e-01,  -1.56341553e-01],
                        [ -1.34124756e-01,  -1.34124756e-01],
                        [ -9.37194824e-02,  -9.37194824e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  1.33544922e-01,   1.33544922e-01],
                        [  1.43920898e-01,   1.43920898e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.23321533e-01,   1.23321533e-01],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  6.26831055e-02,   6.26831055e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -6.25610352e-03,  -6.25610352e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  4.11682129e-02,   4.11682129e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.50909424e-01,   1.50909424e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  7.19299316e-02,   7.19299316e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -2.56866455e-01,  -2.56866455e-01],
                        [ -3.27270508e-01,  -3.27270508e-01],
                        [ -3.37799072e-01,  -3.37799072e-01],
                        [ -2.98919678e-01,  -2.98919678e-01],
                        [ -2.41455078e-01,  -2.41455078e-01],
                        [ -1.95587158e-01,  -1.95587158e-01],
                        [ -1.71081543e-01,  -1.71081543e-01],
                        [ -1.54998779e-01,  -1.54998779e-01],
                        [ -1.29608154e-01,  -1.29608154e-01],
                        [ -9.10949707e-02,  -9.10949707e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.37817383e-01,   1.37817383e-01],
                        [  1.34002686e-01,   1.34002686e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.17340088e-01,   1.17340088e-01],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  7.45544434e-02,   7.45544434e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  8.58154297e-02,   8.58154297e-02],
                        [  7.92236328e-02,   7.92236328e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  4.41284180e-02,   4.41284180e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  6.24084473e-02,   6.24084473e-02],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  4.45556641e-02,   4.45556641e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -2.65045166e-01,  -2.65045166e-01],
                        [ -3.26080322e-01,  -3.26080322e-01],
                        [ -3.28186035e-01,  -3.28186035e-01],
                        [ -2.83935547e-01,  -2.83935547e-01],
                        [ -2.26867676e-01,  -2.26867676e-01],
                        [ -1.87438965e-01,  -1.87438965e-01],
                        [ -1.71813965e-01,  -1.71813965e-01],
                        [ -1.63818359e-01,  -1.63818359e-01],
                        [ -1.45446777e-01,  -1.45446777e-01],
                        [ -1.11114502e-01,  -1.11114502e-01],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  1.08154297e-01,   1.08154297e-01],
                        [  1.53564453e-01,   1.53564453e-01],
                        [  1.71478271e-01,   1.71478271e-01],
                        [  1.65161133e-01,   1.65161133e-01],
                        [  1.49871826e-01,   1.49871826e-01],
                        [  1.34582520e-01,   1.34582520e-01],
                        [  1.18408203e-01,   1.18408203e-01],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  3.31115723e-02,   3.31115723e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  1.10076904e-01,   1.10076904e-01],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -1.60491943e-01,  -1.60491943e-01],
                        [ -2.52227783e-01,  -2.52227783e-01],
                        [ -3.10272217e-01,  -3.10272217e-01],
                        [ -3.14544678e-01,  -3.14544678e-01],
                        [ -2.72888184e-01,  -2.72888184e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -1.82250977e-01,  -1.82250977e-01],
                        [ -1.65435791e-01,  -1.65435791e-01],
                        [ -1.51550293e-01,  -1.51550293e-01],
                        [ -1.28112793e-01,  -1.28112793e-01],
                        [ -9.47875977e-02,  -9.47875977e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  1.45263672e-01,   1.45263672e-01],
                        [  1.64184570e-01,   1.64184570e-01],
                        [  1.60675049e-01,   1.60675049e-01],
                        [  1.47796631e-01,   1.47796631e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  6.52770996e-02,   6.52770996e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  1.89208984e-03,   1.89208984e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -1.53533936e-01,  -1.53533936e-01],
                        [ -2.50030518e-01,  -2.50030518e-01],
                        [ -3.08135986e-01,  -3.08135986e-01],
                        [ -3.09478760e-01,  -3.09478760e-01],
                        [ -2.63244629e-01,  -2.63244629e-01],
                        [ -2.03613281e-01,  -2.03613281e-01],
                        [ -1.64337158e-01,  -1.64337158e-01],
                        [ -1.51550293e-01,  -1.51550293e-01],
                        [ -1.46392822e-01,  -1.46392822e-01],
                        [ -1.32171631e-01,  -1.32171631e-01],
                        [ -1.08154297e-01,  -1.08154297e-01],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  7.71789551e-02,   7.71789551e-02],
                        [  1.32232666e-01,   1.32232666e-01],
                        [  1.66381836e-01,   1.66381836e-01],
                        [  1.75598145e-01,   1.75598145e-01],
                        [  1.65374756e-01,   1.65374756e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.88293457e-02,   1.88293457e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.07312012e-02,  -3.07312012e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  2.13623047e-04,   2.13623047e-04],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.37603760e-01,   1.37603760e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  5.38024902e-02,   5.38024902e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -1.57897949e-01,  -1.57897949e-01],
                        [ -2.60406494e-01,  -2.60406494e-01],
                        [ -3.19030762e-01,  -3.19030762e-01],
                        [ -3.16467285e-01,  -3.16467285e-01],
                        [ -2.65838623e-01,  -2.65838623e-01],
                        [ -2.03918457e-01,  -2.03918457e-01],
                        [ -1.62658691e-01,  -1.62658691e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.43798828e-01,  -1.43798828e-01],
                        [ -1.33544922e-01,  -1.33544922e-01],
                        [ -1.12487793e-01,  -1.12487793e-01],
                        [ -8.41674805e-02,  -8.41674805e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.69006348e-01,   1.69006348e-01],
                        [  1.84326172e-01,   1.84326172e-01],
                        [  1.80084229e-01,   1.80084229e-01],
                        [  1.67266846e-01,   1.67266846e-01],
                        [  1.51855469e-01,   1.51855469e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.18408203e-02,  -1.18408203e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  7.93457031e-04,   7.93457031e-04],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  1.07177734e-01,   1.07177734e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.36322021e-01,   1.36322021e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  4.98962402e-02,   4.98962402e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -1.48071289e-01,  -1.48071289e-01],
                        [ -2.48382568e-01,  -2.48382568e-01],
                        [ -3.10821533e-01,  -3.10821533e-01],
                        [ -3.17382812e-01,  -3.17382812e-01],
                        [ -2.77526855e-01,  -2.77526855e-01],
                        [ -2.21313477e-01,  -2.21313477e-01],
                        [ -1.77185059e-01,  -1.77185059e-01],
                        [ -1.54724121e-01,  -1.54724121e-01],
                        [ -1.43646240e-01,  -1.43646240e-01],
                        [ -1.29272461e-01,  -1.29272461e-01],
                        [ -1.07513428e-01,  -1.07513428e-01],
                        [ -8.22753906e-02,  -8.22753906e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  1.07116699e-01,   1.07116699e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.92718506e-01,   1.92718506e-01],
                        [  2.00561523e-01,   2.00561523e-01],
                        [  1.93420410e-01,   1.93420410e-01],
                        [  1.79931641e-01,   1.79931641e-01],
                        [  1.58843994e-01,   1.58843994e-01],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  1.21215820e-01,   1.21215820e-01],
                        [  1.38702393e-01,   1.38702393e-01],
                        [  1.36688232e-01,   1.36688232e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  4.86450195e-02,   4.86450195e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -1.46759033e-01,  -1.46759033e-01],
                        [ -2.44445801e-01,  -2.44445801e-01],
                        [ -3.02093506e-01,  -3.02093506e-01],
                        [ -3.03131104e-01,  -3.03131104e-01],
                        [ -2.59429932e-01,  -2.59429932e-01],
                        [ -2.04071045e-01,  -2.04071045e-01],
                        [ -1.67297363e-01,  -1.67297363e-01],
                        [ -1.56005859e-01,  -1.56005859e-01],
                        [ -1.54663086e-01,  -1.54663086e-01],
                        [ -1.45690918e-01,  -1.45690918e-01],
                        [ -1.24572754e-01,  -1.24572754e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  1.71447754e-01,   1.71447754e-01],
                        [  2.00347900e-01,   2.00347900e-01],
                        [  2.03491211e-01,   2.03491211e-01],
                        [  1.91009521e-01,   1.91009521e-01],
                        [  1.73095703e-01,   1.73095703e-01],
                        [  1.49291992e-01,   1.49291992e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  5.69763184e-02,   5.69763184e-02],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  1.14440918e-02,   1.14440918e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  7.21435547e-02,   7.21435547e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  2.14843750e-02,   2.14843750e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  2.92358398e-02,   2.92358398e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  8.37402344e-02,   8.37402344e-02],
                        [  1.02874756e-01,   1.02874756e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  1.23321533e-01,   1.23321533e-01],
                        [  1.03393555e-01,   1.03393555e-01],
                        [  4.89196777e-02,   4.89196777e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -1.37298584e-01,  -1.37298584e-01],
                        [ -2.28240967e-01,  -2.28240967e-01],
                        [ -2.85675049e-01,  -2.85675049e-01],
                        [ -2.93884277e-01,  -2.93884277e-01],
                        [ -2.57781982e-01,  -2.57781982e-01],
                        [ -2.05718994e-01,  -2.05718994e-01],
                        [ -1.68548584e-01,  -1.68548584e-01],
                        [ -1.53045654e-01,  -1.53045654e-01],
                        [ -1.43615723e-01,  -1.43615723e-01],
                        [ -1.28204346e-01,  -1.28204346e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -7.69042969e-02,  -7.69042969e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.02905273e-01,   1.02905273e-01],
                        [  1.77459717e-01,   1.77459717e-01],
                        [  2.23602295e-01,   2.23602295e-01],
                        [  2.30529785e-01,   2.30529785e-01],
                        [  2.07885742e-01,   2.07885742e-01],
                        [  1.72271729e-01,   1.72271729e-01],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  7.43713379e-02,   7.43713379e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.10473633e-02,  -1.10473633e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.10565186e-01,   1.10565186e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -1.32354736e-01,  -1.32354736e-01],
                        [ -2.21588135e-01,  -2.21588135e-01],
                        [ -2.81005859e-01,  -2.81005859e-01],
                        [ -2.86254883e-01,  -2.86254883e-01],
                        [ -2.42980957e-01,  -2.42980957e-01],
                        [ -1.87347412e-01,  -1.87347412e-01],
                        [ -1.52709961e-01,  -1.52709961e-01],
                        [ -1.44012451e-01,  -1.44012451e-01],
                        [ -1.45996094e-01,  -1.45996094e-01],
                        [ -1.43554688e-01,  -1.43554688e-01],
                        [ -1.30432129e-01,  -1.30432129e-01],
                        [ -1.07269287e-01,  -1.07269287e-01],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.67480469e-01,   1.67480469e-01],
                        [  2.13562012e-01,   2.13562012e-01],
                        [  2.30163574e-01,   2.30163574e-01],
                        [  2.15301514e-01,   2.15301514e-01],
                        [  1.70501709e-01,   1.70501709e-01],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  3.32641602e-02,   3.32641602e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.23596191e-02,   1.23596191e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  9.38415527e-02,   9.38415527e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  7.33642578e-02,   7.33642578e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  8.59985352e-02,   8.59985352e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  5.12695312e-02,   5.12695312e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -1.29272461e-01,  -1.29272461e-01],
                        [ -2.24304199e-01,  -2.24304199e-01],
                        [ -2.86743164e-01,  -2.86743164e-01],
                        [ -2.94342041e-01,  -2.94342041e-01],
                        [ -2.52502441e-01,  -2.52502441e-01],
                        [ -1.95220947e-01,  -1.95220947e-01],
                        [ -1.54510498e-01,  -1.54510498e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.27136230e-01,  -1.27136230e-01],
                        [ -1.18713379e-01,  -1.18713379e-01],
                        [ -1.07940674e-01,  -1.07940674e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -7.41271973e-02,  -7.41271973e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  9.21936035e-02,   9.21936035e-02],
                        [  1.63513184e-01,   1.63513184e-01],
                        [  2.14416504e-01,   2.14416504e-01],
                        [  2.30834961e-01,   2.30834961e-01],
                        [  2.07092285e-01,   2.07092285e-01],
                        [  1.48498535e-01,   1.48498535e-01],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -5.77697754e-02,  -5.77697754e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -2.41638184e-01,  -2.41638184e-01],
                        [ -2.91534424e-01,  -2.91534424e-01],
                        [ -2.87384033e-01,  -2.87384033e-01],
                        [ -2.40112305e-01,  -2.40112305e-01],
                        [ -1.81488037e-01,  -1.81488037e-01],
                        [ -1.38824463e-01,  -1.38824463e-01],
                        [ -1.18652344e-01,  -1.18652344e-01],
                        [ -1.11785889e-01,  -1.11785889e-01],
                        [ -1.07604980e-01,  -1.07604980e-01],
                        [ -1.02386475e-01,  -1.02386475e-01],
                        [ -9.67102051e-02,  -9.67102051e-02],
                        [ -8.72497559e-02,  -8.72497559e-02],
                        [ -6.32324219e-02,  -6.32324219e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  1.45446777e-01,   1.45446777e-01],
                        [  2.07122803e-01,   2.07122803e-01],
                        [  2.23083496e-01,   2.23083496e-01],
                        [  1.85699463e-01,   1.85699463e-01],
                        [  1.10961914e-01,   1.10961914e-01],
                        [  3.16467285e-02,   3.16467285e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.00292969e-02,  -3.00292969e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  9.89379883e-02,   9.89379883e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  3.66821289e-02,   3.66821289e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  6.83593750e-03,   6.83593750e-03],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  8.34655762e-02,   8.34655762e-02],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  1.12457275e-01,   1.12457275e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  9.79003906e-02,   9.79003906e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -1.44317627e-01,  -1.44317627e-01],
                        [ -2.44567871e-01,  -2.44567871e-01],
                        [ -3.04199219e-01,  -3.04199219e-01],
                        [ -3.00659180e-01,  -3.00659180e-01],
                        [ -2.43682861e-01,  -2.43682861e-01],
                        [ -1.72393799e-01,  -1.72393799e-01],
                        [ -1.22924805e-01,  -1.22924805e-01],
                        [ -1.02874756e-01,  -1.02874756e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -9.57336426e-02,  -9.57336426e-02],
                        [ -8.83789062e-02,  -8.83789062e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  1.53594971e-01,   1.53594971e-01],
                        [  1.65039062e-01,   1.65039062e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  9.78088379e-02,   9.78088379e-02],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -1.27258301e-02,  -1.27258301e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.30187988e-01,   1.30187988e-01],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  4.88281250e-02,   4.88281250e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -1.35864258e-01,  -1.35864258e-01],
                        [ -2.30560303e-01,  -2.30560303e-01],
                        [ -2.89672852e-01,  -2.89672852e-01],
                        [ -2.91656494e-01,  -2.91656494e-01],
                        [ -2.43103027e-01,  -2.43103027e-01],
                        [ -1.78344727e-01,  -1.78344727e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -9.91821289e-02,  -9.91821289e-02],
                        [ -9.33227539e-02,  -9.33227539e-02],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  9.31396484e-02,   9.31396484e-02],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  3.90319824e-02,   3.90319824e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  6.39953613e-02,   6.39953613e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -3.30810547e-02,  -3.30810547e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.21307373e-01,   1.21307373e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  5.49011230e-02,   5.49011230e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -1.27166748e-01,  -1.27166748e-01],
                        [ -2.24945068e-01,  -2.24945068e-01],
                        [ -2.84454346e-01,  -2.84454346e-01],
                        [ -2.87689209e-01,  -2.87689209e-01],
                        [ -2.43896484e-01,  -2.43896484e-01],
                        [ -1.83227539e-01,  -1.83227539e-01],
                        [ -1.36779785e-01,  -1.36779785e-01],
                        [ -1.14257812e-01,  -1.14257812e-01],
                        [ -1.02783203e-01,  -1.02783203e-01],
                        [ -8.89587402e-02,  -8.89587402e-02],
                        [ -7.33947754e-02,  -7.33947754e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  5.98449707e-02,   5.98449707e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  7.61718750e-02,   7.61718750e-02],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.19903564e-01,   1.19903564e-01],
                        [  1.14593506e-01,   1.14593506e-01],
                        [  9.14306641e-02,   9.14306641e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -1.36444092e-01,  -1.36444092e-01],
                        [ -2.23571777e-01,  -2.23571777e-01],
                        [ -2.74475098e-01,  -2.74475098e-01],
                        [ -2.74505615e-01,  -2.74505615e-01],
                        [ -2.30957031e-01,  -2.30957031e-01],
                        [ -1.73583984e-01,  -1.73583984e-01],
                        [ -1.33911133e-01,  -1.33911133e-01],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -1.05377197e-01,  -1.05377197e-01],
                        [ -8.32824707e-02,  -8.32824707e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  5.78308105e-02,   5.78308105e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  9.33837891e-02,   9.33837891e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  9.80529785e-02,   9.80529785e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  9.10644531e-02,   9.10644531e-02],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -2.22259521e-01,  -2.22259521e-01],
                        [ -2.81402588e-01,  -2.81402588e-01],
                        [ -2.82043457e-01,  -2.82043457e-01],
                        [ -2.29705811e-01,  -2.29705811e-01],
                        [ -1.60247803e-01,  -1.60247803e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -8.32824707e-02,  -8.32824707e-02],
                        [ -7.05261230e-02,  -7.05261230e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -9.41467285e-02,  -9.41467285e-02],
                        [ -1.16882324e-01,  -1.16882324e-01],
                        [ -1.18286133e-01,  -1.18286133e-01],
                        [ -9.12170410e-02,  -9.12170410e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  1.18499756e-01,   1.18499756e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  8.61511230e-02,   8.61511230e-02],
                        [  6.44226074e-02,   6.44226074e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  7.30285645e-02,   7.30285645e-02],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.00189209e-01,   1.00189209e-01],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.37524414e-02,   3.37524414e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -1.30615234e-01,  -1.30615234e-01],
                        [ -2.12921143e-01,  -2.12921143e-01],
                        [ -2.61871338e-01,  -2.61871338e-01],
                        [ -2.61749268e-01,  -2.61749268e-01],
                        [ -2.17956543e-01,  -2.17956543e-01],
                        [ -1.58630371e-01,  -1.58630371e-01],
                        [ -1.13037109e-01,  -1.13037109e-01],
                        [ -8.85009766e-02,  -8.85009766e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -1.08032227e-01,  -1.08032227e-01],
                        [ -1.35864258e-01,  -1.35864258e-01],
                        [ -1.39831543e-01,  -1.39831543e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  6.84814453e-02,   6.84814453e-02],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.17401123e-01,   1.17401123e-01],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  9.40246582e-02,   9.40246582e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  6.84204102e-02,   6.84204102e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  3.66210938e-02,   3.66210938e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.30310059e-02,   1.30310059e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.69055176e-02,  -4.69055176e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  8.41369629e-02,   8.41369629e-02],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.41357422e-01,   1.41357422e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  6.46667480e-02,   6.46667480e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -2.07489014e-01,  -2.07489014e-01],
                        [ -2.71392822e-01,  -2.71392822e-01],
                        [ -2.85003662e-01,  -2.85003662e-01],
                        [ -2.48962402e-01,  -2.48962402e-01],
                        [ -1.86920166e-01,  -1.86920166e-01],
                        [ -1.26556396e-01,  -1.26556396e-01],
                        [ -8.05358887e-02,  -8.05358887e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -1.02111816e-01,  -1.02111816e-01],
                        [ -1.47491455e-01,  -1.47491455e-01],
                        [ -1.74835205e-01,  -1.74835205e-01],
                        [ -1.73919678e-01,  -1.73919678e-01],
                        [ -1.37725830e-01,  -1.37725830e-01],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.27655029e-01,   1.27655029e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  6.14624023e-02,   6.14624023e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  1.09252930e-01,   1.09252930e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.01806641e-01,   1.01806641e-01],
                        [  8.03527832e-02,   8.03527832e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  6.92443848e-02,   6.92443848e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  7.08923340e-02,   7.08923340e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.64172363e-02,  -4.64172363e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  7.54394531e-02,   7.54394531e-02],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  1.38854980e-01,   1.38854980e-01],
                        [  1.15203857e-01,   1.15203857e-01],
                        [  6.38122559e-02,   6.38122559e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.09527588e-01,  -1.09527588e-01],
                        [ -2.05200195e-01,  -2.05200195e-01],
                        [ -2.73040771e-01,  -2.73040771e-01],
                        [ -2.87597656e-01,  -2.87597656e-01],
                        [ -2.47283936e-01,  -2.47283936e-01],
                        [ -1.80236816e-01,  -1.80236816e-01],
                        [ -1.21276855e-01,  -1.21276855e-01],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.58355713e-01,  -1.58355713e-01],
                        [ -1.93908691e-01,  -1.93908691e-01],
                        [ -1.97601318e-01,  -1.97601318e-01],
                        [ -1.69219971e-01,  -1.69219971e-01],
                        [ -1.19415283e-01,  -1.19415283e-01],
                        [ -6.12487793e-02,  -6.12487793e-02],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  1.21887207e-01,   1.21887207e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  7.59582520e-02,   7.59582520e-02],
                        [  7.92236328e-02,   7.92236328e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  8.96301270e-02,   8.96301270e-02],
                        [  1.07910156e-01,   1.07910156e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  1.30706787e-01,   1.30706787e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.16058350e-01,   1.16058350e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.97229004e-02,   5.97229004e-02],
                        [  6.14013672e-02,   6.14013672e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  5.74340820e-02,   5.74340820e-02],
                        [  5.63964844e-02,   5.63964844e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  7.93457031e-04,   7.93457031e-04],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -5.53283691e-02,  -5.53283691e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.89904785e-02,  -5.89904785e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  9.44519043e-02,   9.44519043e-02],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.38488770e-01,   1.38488770e-01],
                        [  1.45355225e-01,   1.45355225e-01],
                        [  1.26831055e-01,   1.26831055e-01],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -9.33227539e-02,  -9.33227539e-02],
                        [ -1.92504883e-01,  -1.92504883e-01],
                        [ -2.66082764e-01,  -2.66082764e-01],
                        [ -2.87170410e-01,  -2.87170410e-01],
                        [ -2.51281738e-01,  -2.51281738e-01],
                        [ -1.81549072e-01,  -1.81549072e-01],
                        [ -1.11450195e-01,  -1.11450195e-01],
                        [ -6.32019043e-02,  -6.32019043e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -7.77587891e-02,  -7.77587891e-02],
                        [ -1.22314453e-01,  -1.22314453e-01],
                        [ -1.69067383e-01,  -1.69067383e-01],
                        [ -1.99676514e-01,  -1.99676514e-01],
                        [ -1.98730469e-01,  -1.98730469e-01],
                        [ -1.66961670e-01,  -1.66961670e-01],
                        [ -1.20605469e-01,  -1.20605469e-01],
                        [ -7.51342773e-02,  -7.51342773e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.32415771e-01,   1.32415771e-01],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  9.22546387e-02,   9.22546387e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.26586914e-01,   1.26586914e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.46118164e-01,   1.46118164e-01],
                        [  1.37451172e-01,   1.37451172e-01],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.01135254e-01,   1.01135254e-01],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  7.93457031e-02,   7.93457031e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  5.93872070e-02,   5.93872070e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.72521973e-02,   2.72521973e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.05883789e-02,  -4.05883789e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.45629883e-01,   1.45629883e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.40686035e-01,   1.40686035e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [ -8.34655762e-02,  -8.34655762e-02],
                        [ -1.90765381e-01,  -1.90765381e-01],
                        [ -2.68310547e-01,  -2.68310547e-01],
                        [ -2.87353516e-01,  -2.87353516e-01],
                        [ -2.46215820e-01,  -2.46215820e-01],
                        [ -1.71447754e-01,  -1.71447754e-01],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -1.47460938e-01,  -1.47460938e-01],
                        [ -1.93359375e-01,  -1.93359375e-01],
                        [ -2.14050293e-01,  -2.14050293e-01],
                        [ -2.02270508e-01,  -2.02270508e-01],
                        [ -1.66534424e-01,  -1.66534424e-01],
                        [ -1.23626709e-01,  -1.23626709e-01],
                        [ -8.59985352e-02,  -8.59985352e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  1.40136719e-01,   1.40136719e-01],
                        [  1.57501221e-01,   1.57501221e-01],
                        [  1.47430420e-01,   1.47430420e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  8.95996094e-02,   8.95996094e-02],
                        [  9.36279297e-02,   9.36279297e-02],
                        [  9.61914062e-02,   9.61914062e-02],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  1.19171143e-01,   1.19171143e-01],
                        [  1.34979248e-01,   1.34979248e-01],
                        [  1.40808105e-01,   1.40808105e-01],
                        [  1.32751465e-01,   1.32751465e-01],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  8.24890137e-02,   8.24890137e-02],
                        [  8.14208984e-02,   8.14208984e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.83178711e-02,   8.83178711e-02],
                        [  8.47778320e-02,   8.47778320e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.03955078e-02,  -3.03955078e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  4.29382324e-02,   4.29382324e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  8.68530273e-02,   8.68530273e-02],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  1.34948730e-01,   1.34948730e-01],
                        [  1.48468018e-01,   1.48468018e-01],
                        [  1.41387939e-01,   1.41387939e-01],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  5.77392578e-02,   5.77392578e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -1.83471680e-01,  -1.83471680e-01],
                        [ -2.47192383e-01,  -2.47192383e-01],
                        [ -2.59460449e-01,  -2.59460449e-01],
                        [ -2.15850830e-01,  -2.15850830e-01],
                        [ -1.43463135e-01,  -1.43463135e-01],
                        [ -8.32519531e-02,  -8.32519531e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -6.75048828e-02,  -6.75048828e-02],
                        [ -8.77685547e-02,  -8.77685547e-02],
                        [ -1.12060547e-01,  -1.12060547e-01],
                        [ -1.42211914e-01,  -1.42211914e-01],
                        [ -1.73919678e-01,  -1.73919678e-01],
                        [ -1.92687988e-01,  -1.92687988e-01],
                        [ -1.88751221e-01,  -1.88751221e-01],
                        [ -1.67327881e-01,  -1.67327881e-01],
                        [ -1.40380859e-01,  -1.40380859e-01],
                        [ -1.13739014e-01,  -1.13739014e-01],
                        [ -8.57849121e-02,  -8.57849121e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.43157959e-01,   1.43157959e-01],
                        [  1.41998291e-01,   1.41998291e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  9.53979492e-02,   9.53979492e-02],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  1.07421875e-01,   1.07421875e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.35894775e-01,   1.35894775e-01],
                        [  1.37390137e-01,   1.37390137e-01],
                        [  1.28234863e-01,   1.28234863e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  8.30688477e-02,   8.30688477e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  6.51245117e-02,   6.51245117e-02],
                        [  6.36596680e-02,   6.36596680e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.13708496e-02,   6.13708496e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  4.91333008e-03,   4.91333008e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.66931152e-02,   1.66931152e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -4.90112305e-02,  -4.90112305e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  9.76257324e-02,   9.76257324e-02],
                        [  1.29333496e-01,   1.29333496e-01],
                        [  1.56280518e-01,   1.56280518e-01],
                        [  1.60583496e-01,   1.60583496e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  7.62023926e-02,   7.62023926e-02],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -1.88140869e-01,  -1.88140869e-01],
                        [ -2.44079590e-01,  -2.44079590e-01],
                        [ -2.46520996e-01,  -2.46520996e-01],
                        [ -1.99218750e-01,  -1.99218750e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -7.62939453e-02,  -7.62939453e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -1.20666504e-01,  -1.20666504e-01],
                        [ -1.60736084e-01,  -1.60736084e-01],
                        [ -1.88140869e-01,  -1.88140869e-01],
                        [ -1.95648193e-01,  -1.95648193e-01],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -1.59912109e-01,  -1.59912109e-01],
                        [ -1.36627197e-01,  -1.36627197e-01],
                        [ -1.18896484e-01,  -1.18896484e-01],
                        [ -1.03912354e-01,  -1.03912354e-01],
                        [ -8.50524902e-02,  -8.50524902e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  1.42944336e-01,   1.42944336e-01],
                        [  1.53106689e-01,   1.53106689e-01],
                        [  1.43341064e-01,   1.43341064e-01],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.34979248e-01,   1.34979248e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.50207520e-01,   1.50207520e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  8.17260742e-02,   8.17260742e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  8.68225098e-02,   8.68225098e-02],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.31317139e-01,   1.31317139e-01],
                        [  1.44714355e-01,   1.44714355e-01],
                        [  1.43280029e-01,   1.43280029e-01],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  6.88171387e-02,   6.88171387e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -8.97827148e-02,  -8.97827148e-02],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -2.27264404e-01,  -2.27264404e-01],
                        [ -2.33001709e-01,  -2.33001709e-01],
                        [ -1.92321777e-01,  -1.92321777e-01],
                        [ -1.34490967e-01,  -1.34490967e-01],
                        [ -9.65576172e-02,  -9.65576172e-02],
                        [ -9.66491699e-02,  -9.66491699e-02],
                        [ -1.24420166e-01,  -1.24420166e-01],
                        [ -1.57165527e-01,  -1.57165527e-01],
                        [ -1.79901123e-01,  -1.79901123e-01],
                        [ -1.87713623e-01,  -1.87713623e-01],
                        [ -1.79199219e-01,  -1.79199219e-01],
                        [ -1.57440186e-01,  -1.57440186e-01],
                        [ -1.32232666e-01,  -1.32232666e-01],
                        [ -1.13586426e-01,  -1.13586426e-01],
                        [ -1.03759766e-01,  -1.03759766e-01],
                        [ -9.82666016e-02,  -9.82666016e-02],
                        [ -9.16748047e-02,  -9.16748047e-02],
                        [ -7.94677734e-02,  -7.94677734e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  1.50421143e-01,   1.50421143e-01],
                        [  1.70623779e-01,   1.70623779e-01],
                        [  1.61376953e-01,   1.61376953e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  1.07910156e-01,   1.07910156e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.40838623e-01,   1.40838623e-01],
                        [  1.55426025e-01,   1.55426025e-01],
                        [  1.63604736e-01,   1.63604736e-01],
                        [  1.62597656e-01,   1.62597656e-01],
                        [  1.52740479e-01,   1.52740479e-01],
                        [  1.35009766e-01,   1.35009766e-01],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  6.34155273e-02,   6.34155273e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.26037598e-02,   1.26037598e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -4.12292480e-02,  -4.12292480e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  1.40350342e-01,   1.40350342e-01],
                        [  1.57318115e-01,   1.57318115e-01],
                        [  1.57440186e-01,   1.57440186e-01],
                        [  1.32751465e-01,   1.32751465e-01],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -9.23461914e-02,  -9.23461914e-02],
                        [ -1.78161621e-01,  -1.78161621e-01],
                        [ -2.29217529e-01,  -2.29217529e-01],
                        [ -2.28485107e-01,  -2.28485107e-01],
                        [ -1.86126709e-01,  -1.86126709e-01],
                        [ -1.36749268e-01,  -1.36749268e-01],
                        [ -1.13830566e-01,  -1.13830566e-01],
                        [ -1.26922607e-01,  -1.26922607e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.94458008e-01,  -1.94458008e-01],
                        [ -2.06329346e-01,  -2.06329346e-01],
                        [ -1.92230225e-01,  -1.92230225e-01],
                        [ -1.61804199e-01,  -1.61804199e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -1.07147217e-01,  -1.07147217e-01],
                        [ -9.55200195e-02,  -9.55200195e-02],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -8.88366699e-02,  -8.88366699e-02],
                        [ -7.53479004e-02,  -7.53479004e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  1.53015137e-01,   1.53015137e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.72912598e-01,   1.72912598e-01],
                        [  1.54510498e-01,   1.54510498e-01],
                        [  1.34185791e-01,   1.34185791e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.14257812e-01,   1.14257812e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.45019531e-01,   1.45019531e-01],
                        [  1.61437988e-01,   1.61437988e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.60156250e-01,   1.60156250e-01],
                        [  1.39739990e-01,   1.39739990e-01],
                        [  1.20269775e-01,   1.20269775e-01],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.78833008e-02,   1.78833008e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -6.06079102e-02,  -6.06079102e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.77404785e-02,  -2.77404785e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  1.30737305e-01,   1.30737305e-01],
                        [  1.47766113e-01,   1.47766113e-01],
                        [  1.49871826e-01,   1.49871826e-01],
                        [  1.27777100e-01,   1.27777100e-01],
                        [  7.38220215e-02,   7.38220215e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.03851318e-01,  -1.03851318e-01],
                        [ -1.83258057e-01,  -1.83258057e-01],
                        [ -2.25891113e-01,  -2.25891113e-01],
                        [ -2.22045898e-01,  -2.22045898e-01],
                        [ -1.83715820e-01,  -1.83715820e-01],
                        [ -1.46026611e-01,  -1.46026611e-01],
                        [ -1.43249512e-01,  -1.43249512e-01],
                        [ -1.77124023e-01,  -1.77124023e-01],
                        [ -2.18200684e-01,  -2.18200684e-01],
                        [ -2.36572266e-01,  -2.36572266e-01],
                        [ -2.24456787e-01,  -2.24456787e-01],
                        [ -1.92657471e-01,  -1.92657471e-01],
                        [ -1.56677246e-01,  -1.56677246e-01],
                        [ -1.26403809e-01,  -1.26403809e-01],
                        [ -1.02966309e-01,  -1.02966309e-01],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.53625488e-01,   1.53625488e-01],
                        [  1.63909912e-01,   1.63909912e-01],
                        [  1.52252197e-01,   1.52252197e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  1.17584229e-01,   1.17584229e-01],
                        [  1.38305664e-01,   1.38305664e-01],
                        [  1.60858154e-01,   1.60858154e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.84173584e-01,   1.84173584e-01],
                        [  1.80297852e-01,   1.80297852e-01],
                        [  1.63146973e-01,   1.63146973e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.60400391e-02,  -6.60400391e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.55609131e-01,   1.55609131e-01],
                        [  1.62078857e-01,   1.62078857e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.00891113e-01,   1.00891113e-01],
                        [  3.74450684e-02,   3.74450684e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -1.25885010e-01,  -1.25885010e-01],
                        [ -1.96960449e-01,  -1.96960449e-01],
                        [ -2.32940674e-01,  -2.32940674e-01],
                        [ -2.32879639e-01,  -2.32879639e-01],
                        [ -2.21069336e-01,  -2.21069336e-01],
                        [ -2.20581055e-01,  -2.20581055e-01],
                        [ -2.29766846e-01,  -2.29766846e-01],
                        [ -2.30651855e-01,  -2.30651855e-01],
                        [ -2.11975098e-01,  -2.11975098e-01],
                        [ -1.78741455e-01,  -1.78741455e-01],
                        [ -1.45172119e-01,  -1.45172119e-01],
                        [ -1.23291016e-01,  -1.23291016e-01],
                        [ -1.14288330e-01,  -1.14288330e-01],
                        [ -1.07177734e-01,  -1.07177734e-01],
                        [ -8.93859863e-02,  -8.93859863e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  1.47827148e-01,   1.47827148e-01],
                        [  1.49719238e-01,   1.49719238e-01],
                        [  1.40594482e-01,   1.40594482e-01],
                        [  1.34368896e-01,   1.34368896e-01],
                        [  1.42211914e-01,   1.42211914e-01],
                        [  1.65435791e-01,   1.65435791e-01],
                        [  1.93115234e-01,   1.93115234e-01],
                        [  2.09808350e-01,   2.09808350e-01],
                        [  2.08312988e-01,   2.08312988e-01],
                        [  1.92932129e-01,   1.92932129e-01],
                        [  1.70959473e-01,   1.70959473e-01],
                        [  1.47094727e-01,   1.47094727e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  4.63562012e-02,   4.63562012e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.52575684e-02,  -4.52575684e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -7.03125000e-02,  -7.03125000e-02],
                        [ -6.71997070e-02,  -6.71997070e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  8.27026367e-02,   8.27026367e-02],
                        [  1.19598389e-01,   1.19598389e-01],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.86889648e-01,   1.86889648e-01],
                        [  1.91925049e-01,   1.91925049e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.18225098e-01,   1.18225098e-01],
                        [  4.25415039e-02,   4.25415039e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -2.17529297e-01,  -2.17529297e-01],
                        [ -2.58850098e-01,  -2.58850098e-01],
                        [ -2.69683838e-01,  -2.69683838e-01],
                        [ -2.61993408e-01,  -2.61993408e-01],
                        [ -2.50549316e-01,  -2.50549316e-01],
                        [ -2.42614746e-01,  -2.42614746e-01],
                        [ -2.31933594e-01,  -2.31933594e-01],
                        [ -2.07519531e-01,  -2.07519531e-01],
                        [ -1.70654297e-01,  -1.70654297e-01],
                        [ -1.36840820e-01,  -1.36840820e-01],
                        [ -1.16485596e-01,  -1.16485596e-01],
                        [ -1.02050781e-01,  -1.02050781e-01],
                        [ -8.17260742e-02,  -8.17260742e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  1.09161377e-01,   1.09161377e-01],
                        [  1.39038086e-01,   1.39038086e-01],
                        [  1.59118652e-01,   1.59118652e-01],
                        [  1.68121338e-01,   1.68121338e-01],
                        [  1.69342041e-01,   1.69342041e-01],
                        [  1.70379639e-01,   1.70379639e-01],
                        [  1.76940918e-01,   1.76940918e-01],
                        [  1.86523438e-01,   1.86523438e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  1.83746338e-01,   1.83746338e-01],
                        [  1.69158936e-01,   1.69158936e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  1.32781982e-01,   1.32781982e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  9.19799805e-02,   9.19799805e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.67236328e-02,   1.67236328e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.02929688e-02,  -5.02929688e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -6.62231445e-02,  -6.62231445e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  5.85632324e-02,   5.85632324e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  1.17553711e-01,   1.17553711e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.75292969e-01,   1.75292969e-01],
                        [  1.83959961e-01,   1.83959961e-01],
                        [  1.59698486e-01,   1.59698486e-01],
                        [  9.49707031e-02,   9.49707031e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.18164062e-01,  -1.18164062e-01],
                        [ -2.26409912e-01,  -2.26409912e-01],
                        [ -3.03222656e-01,  -3.03222656e-01],
                        [ -3.33709717e-01,  -3.33709717e-01],
                        [ -3.22357178e-01,  -3.22357178e-01],
                        [ -2.87658691e-01,  -2.87658691e-01],
                        [ -2.47192383e-01,  -2.47192383e-01],
                        [ -2.09075928e-01,  -2.09075928e-01],
                        [ -1.74377441e-01,  -1.74377441e-01],
                        [ -1.44378662e-01,  -1.44378662e-01],
                        [ -1.22589111e-01,  -1.22589111e-01],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -9.53674316e-02,  -9.53674316e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -5.76782227e-02,  -5.76782227e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  1.52679443e-01,   1.52679443e-01],
                        [  1.82220459e-01,   1.82220459e-01],
                        [  1.94732666e-01,   1.94732666e-01],
                        [  1.98822021e-01,   1.98822021e-01],
                        [  2.03155518e-01,   2.03155518e-01],
                        [  2.07519531e-01,   2.07519531e-01],
                        [  2.05200195e-01,   2.05200195e-01],
                        [  1.92810059e-01,   1.92810059e-01],
                        [  1.75872803e-01,   1.75872803e-01],
                        [  1.61895752e-01,   1.61895752e-01],
                        [  1.50878906e-01,   1.50878906e-01],
                        [  1.37786865e-01,   1.37786865e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -6.53991699e-02,  -6.53991699e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -7.81860352e-02,  -7.81860352e-02],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.51049805e-02,  -4.51049805e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.65161133e-01,   1.65161133e-01],
                        [  1.95770264e-01,   1.95770264e-01],
                        [  2.02117920e-01,   2.02117920e-01],
                        [  1.75933838e-01,   1.75933838e-01],
                        [  1.11480713e-01,   1.11480713e-01],
                        [  8.17871094e-03,   8.17871094e-03],
                        [ -1.23718262e-01,  -1.23718262e-01],
                        [ -2.58605957e-01,  -2.58605957e-01],
                        [ -3.58551025e-01,  -3.58551025e-01],
                        [ -3.92303467e-01,  -3.92303467e-01],
                        [ -3.60626221e-01,  -3.60626221e-01],
                        [ -2.96478271e-01,  -2.96478271e-01],
                        [ -2.35229492e-01,  -2.35229492e-01],
                        [ -1.91406250e-01,  -1.91406250e-01],
                        [ -1.62414551e-01,  -1.62414551e-01],
                        [ -1.40991211e-01,  -1.40991211e-01],
                        [ -1.20971680e-01,  -1.20971680e-01],
                        [ -1.00433350e-01,  -1.00433350e-01],
                        [ -8.38012695e-02,  -8.38012695e-02],
                        [ -7.46765137e-02,  -7.46765137e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.72546387e-01,   1.72546387e-01],
                        [  2.15728760e-01,   2.15728760e-01],
                        [  2.44018555e-01,   2.44018555e-01],
                        [  2.54943848e-01,   2.54943848e-01],
                        [  2.50305176e-01,   2.50305176e-01],
                        [  2.36846924e-01,   2.36846924e-01],
                        [  2.19390869e-01,   2.19390869e-01],
                        [  1.98760986e-01,   1.98760986e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  1.57684326e-01,   1.57684326e-01],
                        [  1.40655518e-01,   1.40655518e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  9.68627930e-02,   9.68627930e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  4.42504883e-03,   4.42504883e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.38635254e-02,  -5.38635254e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.88903809e-02,  -1.88903809e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  1.13220215e-01,   1.13220215e-01],
                        [  1.37969971e-01,   1.37969971e-01],
                        [  1.63360596e-01,   1.63360596e-01],
                        [  1.82708740e-01,   1.82708740e-01],
                        [  1.85424805e-01,   1.85424805e-01],
                        [  1.57287598e-01,   1.57287598e-01],
                        [  8.64868164e-02,   8.64868164e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -3.09112549e-01,  -3.09112549e-01],
                        [ -3.94592285e-01,  -3.94592285e-01],
                        [ -4.04174805e-01,  -4.04174805e-01],
                        [ -3.49609375e-01,  -3.49609375e-01],
                        [ -2.68402100e-01,  -2.68402100e-01],
                        [ -1.98059082e-01,  -1.98059082e-01],
                        [ -1.56707764e-01,  -1.56707764e-01],
                        [ -1.38183594e-01,  -1.38183594e-01],
                        [ -1.23260498e-01,  -1.23260498e-01],
                        [ -1.00646973e-01,  -1.00646973e-01],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  1.78009033e-01,   1.78009033e-01],
                        [  2.39868164e-01,   2.39868164e-01],
                        [  2.71942139e-01,   2.71942139e-01],
                        [  2.72888184e-01,   2.72888184e-01],
                        [  2.58636475e-01,   2.58636475e-01],
                        [  2.44110107e-01,   2.44110107e-01],
                        [  2.29125977e-01,   2.29125977e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  1.82830811e-01,   1.82830811e-01],
                        [  1.57531738e-01,   1.57531738e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [  2.13928223e-02,   2.13928223e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -5.52673340e-02,  -5.52673340e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -6.11877441e-02,  -6.11877441e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -7.67517090e-02,  -7.67517090e-02],
                        [ -7.70263672e-02,  -7.70263672e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -6.40563965e-02,  -6.40563965e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  5.91430664e-02,   5.91430664e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  9.01489258e-02,   9.01489258e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.59240723e-01,   1.59240723e-01],
                        [  1.86706543e-01,   1.86706543e-01],
                        [  1.93115234e-01,   1.93115234e-01],
                        [  1.69128418e-01,   1.69128418e-01],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  9.91821289e-03,   9.91821289e-03],
                        [ -1.17187500e-01,  -1.17187500e-01],
                        [ -2.55493164e-01,  -2.55493164e-01],
                        [ -3.70605469e-01,  -3.70605469e-01],
                        [ -4.21325684e-01,  -4.21325684e-01],
                        [ -3.92395020e-01,  -3.92395020e-01],
                        [ -3.13049316e-01,  -3.13049316e-01],
                        [ -2.32666016e-01,  -2.32666016e-01],
                        [ -1.80755615e-01,  -1.80755615e-01],
                        [ -1.54174805e-01,  -1.54174805e-01],
                        [ -1.34368896e-01,  -1.34368896e-01],
                        [ -1.09283447e-01,  -1.09283447e-01],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  1.75933838e-01,   1.75933838e-01],
                        [  2.40051270e-01,   2.40051270e-01],
                        [  2.78778076e-01,   2.78778076e-01],
                        [  2.85675049e-01,   2.85675049e-01],
                        [  2.67883301e-01,   2.67883301e-01],
                        [  2.39471436e-01,   2.39471436e-01],
                        [  2.11395264e-01,   2.11395264e-01],
                        [  1.86798096e-01,   1.86798096e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.42700195e-01,   1.42700195e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.00128174e-01,   1.00128174e-01],
                        [  8.08715820e-02,   8.08715820e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.78308105e-02,  -5.78308105e-02],
                        [ -6.31103516e-02,  -6.31103516e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.42907715e-02,  -5.42907715e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  6.96105957e-02,   6.96105957e-02],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  1.06323242e-01,   1.06323242e-01],
                        [  1.31713867e-01,   1.31713867e-01],
                        [  1.62750244e-01,   1.62750244e-01],
                        [  1.88140869e-01,   1.88140869e-01],
                        [  1.89727783e-01,   1.89727783e-01],
                        [  1.54693604e-01,   1.54693604e-01],
                        [  7.97424316e-02,   7.97424316e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -1.69891357e-01,  -1.69891357e-01],
                        [ -3.00781250e-01,  -3.00781250e-01],
                        [ -3.84613037e-01,  -3.84613037e-01],
                        [ -3.96881104e-01,  -3.96881104e-01],
                        [ -3.47076416e-01,  -3.47076416e-01],
                        [ -2.72491455e-01,  -2.72491455e-01],
                        [ -2.11029053e-01,  -2.11029053e-01],
                        [ -1.76025391e-01,  -1.76025391e-01],
                        [ -1.56555176e-01,  -1.56555176e-01],
                        [ -1.37847900e-01,  -1.37847900e-01],
                        [ -1.15783691e-01,  -1.15783691e-01],
                        [ -9.43908691e-02,  -9.43908691e-02],
                        [ -7.58361816e-02,  -7.58361816e-02],
                        [ -5.52978516e-02,  -5.52978516e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  1.87408447e-01,   1.87408447e-01],
                        [  2.55004883e-01,   2.55004883e-01],
                        [  2.95623779e-01,   2.95623779e-01],
                        [  2.99652100e-01,   2.99652100e-01],
                        [  2.72369385e-01,   2.72369385e-01],
                        [  2.34985352e-01,   2.34985352e-01],
                        [  2.07275391e-01,   2.07275391e-01],
                        [  1.90582275e-01,   1.90582275e-01],
                        [  1.75506592e-01,   1.75506592e-01],
                        [  1.58660889e-01,   1.58660889e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  9.72290039e-02,   9.72290039e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  2.43530273e-02,   2.43530273e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -8.33435059e-02,  -8.33435059e-02],
                        [ -8.02307129e-02,  -8.02307129e-02],
                        [ -6.90917969e-02,  -6.90917969e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -7.23266602e-02,  -7.23266602e-02],
                        [ -7.47375488e-02,  -7.47375488e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  5.26428223e-02,   5.26428223e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.59637451e-01,   1.59637451e-01],
                        [  1.78894043e-01,   1.78894043e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  6.78405762e-02,   6.78405762e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -1.76818848e-01,  -1.76818848e-01],
                        [ -3.02368164e-01,  -3.02368164e-01],
                        [ -3.81652832e-01,  -3.81652832e-01],
                        [ -3.93218994e-01,  -3.93218994e-01],
                        [ -3.45672607e-01,  -3.45672607e-01],
                        [ -2.72155762e-01,  -2.72155762e-01],
                        [ -2.08099365e-01,  -2.08099365e-01],
                        [ -1.68304443e-01,  -1.68304443e-01],
                        [ -1.43585205e-01,  -1.43585205e-01],
                        [ -1.18621826e-01,  -1.18621826e-01],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  9.32312012e-02,   9.32312012e-02],
                        [  1.76269531e-01,   1.76269531e-01],
                        [  2.55767822e-01,   2.55767822e-01],
                        [  3.09539795e-01,   3.09539795e-01],
                        [  3.22937012e-01,   3.22937012e-01],
                        [  2.99774170e-01,   2.99774170e-01],
                        [  2.58148193e-01,   2.58148193e-01],
                        [  2.16033936e-01,   2.16033936e-01],
                        [  1.80847168e-01,   1.80847168e-01],
                        [  1.51397705e-01,   1.51397705e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  9.10949707e-02,   9.10949707e-02],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -6.80236816e-02,  -6.80236816e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -7.66601562e-02,  -7.66601562e-02],
                        [ -7.45544434e-02,  -7.45544434e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  9.69848633e-02,   9.69848633e-02],
                        [  1.23870850e-01,   1.23870850e-01],
                        [  1.55761719e-01,   1.55761719e-01],
                        [  1.77703857e-01,   1.77703857e-01],
                        [  1.74499512e-01,   1.74499512e-01],
                        [  1.40045166e-01,   1.40045166e-01],
                        [  7.57141113e-02,   7.57141113e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -2.12402344e-01,  -2.12402344e-01],
                        [ -2.98980713e-01,  -2.98980713e-01],
                        [ -3.54095459e-01,  -3.54095459e-01],
                        [ -3.63891602e-01,  -3.63891602e-01],
                        [ -3.29650879e-01,  -3.29650879e-01],
                        [ -2.68798828e-01,  -2.68798828e-01],
                        [ -2.05444336e-01,  -2.05444336e-01],
                        [ -1.57196045e-01,  -1.57196045e-01],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  1.84478760e-01,   1.84478760e-01],
                        [  2.54272461e-01,   2.54272461e-01],
                        [  2.96264648e-01,   2.96264648e-01],
                        [  3.02795410e-01,   3.02795410e-01],
                        [  2.81768799e-01,   2.81768799e-01],
                        [  2.48046875e-01,   2.48046875e-01],
                        [  2.11151123e-01,   2.11151123e-01],
                        [  1.74774170e-01,   1.74774170e-01],
                        [  1.43005371e-01,   1.43005371e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  8.27331543e-02,   8.27331543e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -3.68652344e-02,  -3.68652344e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.50115967e-01,   1.50115967e-01],
                        [  1.59698486e-01,   1.59698486e-01],
                        [  1.53167725e-01,   1.53167725e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  5.15747070e-03,   5.15747070e-03],
                        [ -7.20214844e-02,  -7.20214844e-02],
                        [ -1.54846191e-01,  -1.54846191e-01],
                        [ -2.36175537e-01,  -2.36175537e-01],
                        [ -3.03649902e-01,  -3.03649902e-01],
                        [ -3.42285156e-01,  -3.42285156e-01],
                        [ -3.40576172e-01,  -3.40576172e-01],
                        [ -2.98889160e-01,  -2.98889160e-01],
                        [ -2.34985352e-01,  -2.34985352e-01],
                        [ -1.76208496e-01,  -1.76208496e-01],
                        [ -1.39068604e-01,  -1.39068604e-01],
                        [ -1.16577148e-01,  -1.16577148e-01],
                        [ -9.32312012e-02,  -9.32312012e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.68249512e-02,   2.68249512e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  1.84967041e-01,   1.84967041e-01],
                        [  2.51098633e-01,   2.51098633e-01],
                        [  2.91229248e-01,   2.91198730e-01],
                        [  3.01177979e-01,   3.01177979e-01],
                        [  2.85430908e-01,   2.85430908e-01],
                        [  2.52227783e-01,   2.52227783e-01],
                        [  2.12280273e-01,   2.12280273e-01],
                        [  1.75170898e-01,   1.75170898e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  9.00878906e-02,   9.00878906e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  4.32128906e-02,   4.32128906e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  2.23999023e-02,   2.23999023e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.12182617e-02,  -6.12182617e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -6.28051758e-02,  -6.28051758e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.25183105e-01,   1.25183105e-01],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -8.54187012e-02,  -8.54187012e-02],
                        [ -1.54846191e-01,  -1.54846191e-01],
                        [ -2.26562500e-01,  -2.26562500e-01],
                        [ -2.94250488e-01,  -2.94250488e-01],
                        [ -3.40026855e-01,  -3.40026855e-01],
                        [ -3.41339111e-01,  -3.41339111e-01],
                        [ -2.93090820e-01,  -2.93090820e-01],
                        [ -2.19726562e-01,  -2.19726562e-01],
                        [ -1.56555176e-01,  -1.56555176e-01],
                        [ -1.19018555e-01,  -1.19018555e-01],
                        [ -9.68627930e-02,  -9.68627930e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  1.56585693e-01,   1.56585693e-01],
                        [  2.21984863e-01,   2.21984863e-01],
                        [  2.70690918e-01,   2.70690918e-01],
                        [  2.92297363e-01,   2.92297363e-01],
                        [  2.85247803e-01,   2.85247803e-01],
                        [  2.55889893e-01,   2.55889893e-01],
                        [  2.17376709e-01,   2.17376709e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.36993408e-01,   1.36993408e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  3.19519043e-02,   3.19824219e-02],
                        [  2.34069824e-02,   2.34069824e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -4.60815430e-02,  -4.60510254e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.86645508e-02,  -6.86645508e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -1.00097656e-02,  -1.00097656e-02],
                        [ -8.11767578e-03,  -8.11767578e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -9.08203125e-02,  -9.08203125e-02],
                        [ -1.24023438e-01,  -1.24023438e-01],
                        [ -1.82678223e-01,  -1.82678223e-01],
                        [ -2.61474609e-01,  -2.61474609e-01],
                        [ -3.21838379e-01,  -3.21838379e-01],
                        [ -3.25134277e-01,  -3.25134277e-01],
                        [ -2.70721436e-01,  -2.70721436e-01],
                        [ -1.94061279e-01,  -1.94061279e-01],
                        [ -1.33972168e-01,  -1.33972168e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -9.36584473e-02,  -9.36584473e-02],
                        [ -7.93762207e-02,  -7.93762207e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  6.47583008e-02,   6.47583008e-02],
                        [  1.10168457e-01,   1.10168457e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  2.03582764e-01,   2.03582764e-01],
                        [  2.43957520e-01,   2.43957520e-01],
                        [  2.72399902e-01,   2.72399902e-01],
                        [  2.79357910e-01,   2.79357910e-01],
                        [  2.62207031e-01,   2.62207031e-01],
                        [  2.30590820e-01,   2.30590820e-01],
                        [  1.96868896e-01,   1.96868896e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  1.38702393e-01,   1.38702393e-01],
                        [  1.13464355e-01,   1.13464355e-01],
                        [  9.00268555e-02,   9.00268555e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  3.22875977e-02,   3.22570801e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.33361816e-02,  -1.33361816e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -2.27661133e-02,  -2.27661133e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.29174805e-02,  -5.29174805e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.91735840e-02,  -5.91735840e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  7.88879395e-02,   7.88879395e-02],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.19476318e-01,   1.19476318e-01],
                        [  1.06842041e-01,   1.06842041e-01],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -1.06719971e-01,  -1.06719971e-01],
                        [ -1.86706543e-01,  -1.86676025e-01],
                        [ -2.71270752e-01,  -2.71270752e-01],
                        [ -3.20983887e-01,  -3.20983887e-01],
                        [ -3.11431885e-01,  -3.11431885e-01],
                        [ -2.54150391e-01,  -2.54150391e-01],
                        [ -1.86218262e-01,  -1.86218262e-01],
                        [ -1.37695312e-01,  -1.37695312e-01],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -9.40551758e-02,  -9.40551758e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  1.01257324e-01,   1.01257324e-01],
                        [  1.39617920e-01,   1.39617920e-01],
                        [  1.79809570e-01,   1.79809570e-01],
                        [  2.19451904e-01,   2.19451904e-01],
                        [  2.55157471e-01,   2.55157471e-01],
                        [  2.75482178e-01,   2.75482178e-01],
                        [  2.66571045e-01,   2.66571045e-01],
                        [  2.30682373e-01,   2.30682373e-01],
                        [  1.88293457e-01,   1.88293457e-01],
                        [  1.56402588e-01,   1.56402588e-01],
                        [  1.34704590e-01,   1.34704590e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  5.99975586e-02,   5.99975586e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.80053711e-03,   1.80053711e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.08740234e-02,  -2.08740234e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -7.01293945e-02,  -7.01293945e-02],
                        [ -7.21435547e-02,  -7.21435547e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -6.15234375e-02,  -6.15234375e-02],
                        [ -6.71691895e-02,  -6.71386719e-02],
                        [ -6.58569336e-02,  -6.58569336e-02],
                        [ -5.91430664e-02,  -5.91430664e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  8.79516602e-02,   8.79516602e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -1.06842041e-01,  -1.06842041e-01],
                        [ -1.83074951e-01,  -1.83074951e-01],
                        [ -2.55737305e-01,  -2.55737305e-01],
                        [ -2.91473389e-01,  -2.91473389e-01],
                        [ -2.76794434e-01,  -2.76794434e-01],
                        [ -2.26531982e-01,  -2.26531982e-01],
                        [ -1.71081543e-01,  -1.71081543e-01],
                        [ -1.33270264e-01,  -1.33239746e-01],
                        [ -1.13189697e-01,  -1.13189697e-01],
                        [ -9.49096680e-02,  -9.49096680e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  9.03015137e-02,   9.03015137e-02],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.29669189e-01,   1.29669189e-01],
                        [  1.54296875e-01,   1.54296875e-01],
                        [  1.89697266e-01,   1.89697266e-01],
                        [  2.28973389e-01,   2.28973389e-01],
                        [  2.55950928e-01,   2.55950928e-01],
                        [  2.57843018e-01,   2.57843018e-01],
                        [  2.36450195e-01,   2.36450195e-01],
                        [  2.04742432e-01,   2.04742432e-01],
                        [  1.72973633e-01,   1.72973633e-01],
                        [  1.43829346e-01,   1.43829346e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  3.99475098e-02,   3.99475098e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  3.03039551e-02,   3.03039551e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -4.73632812e-02,  -4.73632812e-02],
                        [ -4.69665527e-02,  -4.69665527e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -6.93664551e-02,  -6.93664551e-02],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -7.68127441e-02,  -7.68127441e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -2.10571289e-03,  -2.10571289e-03],
                        [  6.74438477e-03,   6.77490234e-03],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  5.51147461e-02,   5.51147461e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  9.12780762e-02,   9.12780762e-02],
                        [  1.01287842e-01,   1.01287842e-01],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -5.67016602e-02,  -5.67016602e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [ -8.05664062e-03,  -8.02612305e-03],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -1.59454346e-01,  -1.59454346e-01],
                        [ -2.46795654e-01,  -2.46795654e-01],
                        [ -2.98522949e-01,  -2.98522949e-01],
                        [ -2.94830322e-01,  -2.94830322e-01],
                        [ -2.44659424e-01,  -2.44659424e-01],
                        [ -1.78405762e-01,  -1.78405762e-01],
                        [ -1.23352051e-01,  -1.23352051e-01],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.46984863e-02,  -3.46984863e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  2.09106445e-01,   2.09106445e-01],
                        [  2.29644775e-01,   2.29644775e-01],
                        [  2.21954346e-01,   2.21954346e-01],
                        [  1.92962646e-01,   1.92962646e-01],
                        [  1.60186768e-01,   1.60186768e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.00219727e-01,   1.00219727e-01],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.15661621e-02,   1.15966797e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -6.55822754e-02,  -6.55822754e-02],
                        [ -6.20117188e-02,  -6.20117188e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.76379395e-02,  -4.76684570e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -5.53894043e-02,  -5.53894043e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  7.57141113e-02,   7.57141113e-02],
                        [  9.92431641e-02,   9.92431641e-02],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -8.88366699e-02,  -8.88366699e-02],
                        [ -1.02172852e-01,  -1.02172852e-01],
                        [ -7.62023926e-02,  -7.62023926e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  1.58996582e-02,   1.58996582e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -6.96105957e-02,  -6.96105957e-02],
                        [ -1.43157959e-01,  -1.43157959e-01],
                        [ -2.15759277e-01,  -2.15759277e-01],
                        [ -2.63732910e-01,  -2.63732910e-01],
                        [ -2.67822266e-01,  -2.67822266e-01],
                        [ -2.29705811e-01,  -2.29705811e-01],
                        [ -1.73370361e-01,  -1.73370361e-01],
                        [ -1.24420166e-01,  -1.24420166e-01],
                        [ -9.16442871e-02,  -9.16442871e-02],
                        [ -7.02514648e-02,  -7.02514648e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.19519043e-02,  -3.19519043e-02],
                        [ -2.95410156e-02,  -2.95410156e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -1.75781250e-02,  -1.75476074e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  1.96838379e-02,   1.96533203e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  1.01562500e-01,   1.01562500e-01],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.62506104e-01,   1.62506104e-01],
                        [  2.00897217e-01,   2.00897217e-01],
                        [  2.30926514e-01,   2.30926514e-01],
                        [  2.40051270e-01,   2.40051270e-01],
                        [  2.25830078e-01,   2.25830078e-01],
                        [  1.95037842e-01,   1.95037842e-01],
                        [  1.60675049e-01,   1.60644531e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  5.37414551e-02,   5.37414551e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.06896973e-02,  -5.06896973e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -5.13305664e-02,  -5.13305664e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.79016113e-02,  -6.79016113e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  8.92028809e-02,   8.91723633e-02],
                        [  5.65185547e-02,   5.65185547e-02],
                        [  6.86645508e-03,   6.86645508e-03],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -8.74328613e-02,  -8.74328613e-02],
                        [ -9.35668945e-02,  -9.35668945e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -1.02264404e-01,  -1.02264404e-01],
                        [ -1.90185547e-01,  -1.90185547e-01],
                        [ -2.66357422e-01,  -2.66357422e-01],
                        [ -2.99072266e-01,  -2.99072266e-01],
                        [ -2.74261475e-01,  -2.74261475e-01],
                        [ -2.10113525e-01,  -2.10113525e-01],
                        [ -1.41296387e-01,  -1.41296387e-01],
                        [ -9.39025879e-02,  -9.39025879e-02],
                        [ -7.26623535e-02,  -7.26623535e-02],
                        [ -6.41174316e-02,  -6.41479492e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.98156738e-02,  -2.98156738e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  8.35571289e-02,   8.35571289e-02],
                        [  7.26928711e-02,   7.26928711e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  1.18408203e-01,   1.18408203e-01],
                        [  1.64459229e-01,   1.64459229e-01],
                        [  2.12463379e-01,   2.12463379e-01],
                        [  2.45727539e-01,   2.45727539e-01],
                        [  2.50671387e-01,   2.50671387e-01],
                        [  2.29187012e-01,   2.29187012e-01],
                        [  1.96044922e-01,   1.96044922e-01],
                        [  1.64947510e-01,   1.64947510e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  2.01721191e-02,   2.01721191e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.73828125e-02,  -6.73828125e-02],
                        [ -6.93359375e-02,  -6.93359375e-02],
                        [ -7.03430176e-02,  -7.03430176e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -7.06787109e-02,  -7.06481934e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -4.36401367e-02,  -4.36401367e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -1.15631104e-01,  -1.15631104e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  2.20336914e-02,   2.20336914e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -1.03393555e-01,  -1.03393555e-01],
                        [ -1.82189941e-01,  -1.82189941e-01],
                        [ -2.44934082e-01,  -2.44934082e-01],
                        [ -2.65472412e-01,  -2.65472412e-01],
                        [ -2.37365723e-01,  -2.37396240e-01],
                        [ -1.81274414e-01,  -1.81274414e-01],
                        [ -1.26892090e-01,  -1.26892090e-01],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -6.55212402e-02,  -6.55212402e-02],
                        [ -4.91638184e-02,  -4.91333008e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  3.30810547e-02,   3.31115723e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  7.28454590e-02,   7.28454590e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.06536865e-01,   1.06536865e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.50012207e-02,   9.50012207e-02],
                        [  8.20312500e-02,   8.20312500e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  9.68017578e-02,   9.68322754e-02],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.82586670e-01,   1.82586670e-01],
                        [  2.18658447e-01,   2.18658447e-01],
                        [  2.30438232e-01,   2.30438232e-01],
                        [  2.17987061e-01,   2.17987061e-01],
                        [  1.90399170e-01,   1.90399170e-01],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.12579346e-01,   1.12579346e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  7.59277344e-02,   7.58972168e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  5.16662598e-02,   5.16662598e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  6.17980957e-02,   6.17980957e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -3.72619629e-02,  -3.72619629e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.09338379e-02,  -5.09338379e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.72607422e-02,  -6.72607422e-02],
                        [ -6.88171387e-02,  -6.88171387e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -6.82067871e-02,  -6.81762695e-02],
                        [ -6.53686523e-02,  -6.53686523e-02],
                        [ -6.21032715e-02,  -6.21032715e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -5.91735840e-02,  -5.91735840e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  7.99865723e-02,   7.99865723e-02],
                        [  8.73718262e-02,   8.73718262e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -1.24023438e-01,  -1.24023438e-01],
                        [ -1.05804443e-01,  -1.05804443e-01],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -1.33575439e-01,  -1.33575439e-01],
                        [ -2.19970703e-01,  -2.19970703e-01],
                        [ -2.74993896e-01,  -2.74993896e-01],
                        [ -2.74810791e-01,  -2.74810791e-01],
                        [ -2.25708008e-01,  -2.25708008e-01],
                        [ -1.56341553e-01,  -1.56341553e-01],
                        [ -9.72900391e-02,  -9.72900391e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.62145996e-02,   2.61840820e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  5.92346191e-02,   5.92346191e-02],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  1.27502441e-01,   1.27502441e-01],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.25061035e-01,   1.25061035e-01],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  6.58264160e-02,   6.58264160e-02],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  1.45935059e-01,   1.45935059e-01],
                        [  1.88537598e-01,   1.88537598e-01],
                        [  2.19665527e-01,   2.19665527e-01],
                        [  2.30743408e-01,   2.30743408e-01],
                        [  2.16827393e-01,   2.16827393e-01],
                        [  1.85333252e-01,   1.85333252e-01],
                        [  1.51458740e-01,   1.51458740e-01],
                        [  1.22772217e-01,   1.22772217e-01],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  7.66296387e-02,   7.66296387e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.39355469e-02,  -3.39355469e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -7.71179199e-02,  -7.71179199e-02],
                        [ -7.83081055e-02,  -7.83081055e-02],
                        [ -7.35778809e-02,  -7.35778809e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.84521484e-02,  -3.84521484e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -5.19714355e-02,  -5.19714355e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -5.12390137e-02,  -5.12084961e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  7.74536133e-02,   7.74536133e-02],
                        [  9.03625488e-02,   9.03320312e-02],
                        [  9.82666016e-02,   9.82666016e-02],
                        [  9.93347168e-02,   9.93347168e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -1.01196289e-01,  -1.01196289e-01],
                        [ -1.45996094e-01,  -1.45996094e-01],
                        [ -1.46057129e-01,  -1.46057129e-01],
                        [ -1.02691650e-01,  -1.02691650e-01],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -1.76239014e-01,  -1.76239014e-01],
                        [ -2.48687744e-01,  -2.48687744e-01],
                        [ -2.74261475e-01,  -2.74261475e-01],
                        [ -2.44293213e-01,  -2.44293213e-01],
                        [ -1.80572510e-01,  -1.80572510e-01],
                        [ -1.21063232e-01,  -1.21063232e-01],
                        [ -8.94165039e-02,  -8.94165039e-02],
                        [ -8.01086426e-02,  -8.01086426e-02],
                        [ -7.33032227e-02,  -7.33032227e-02],
                        [ -5.91735840e-02,  -5.91735840e-02],
                        [ -4.33959961e-02,  -4.34265137e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [  5.49316406e-03,   5.52368164e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  1.02294922e-01,   1.02294922e-01],
                        [  1.29425049e-01,   1.29425049e-01],
                        [  1.38732910e-01,   1.38732910e-01],
                        [  1.25671387e-01,   1.25671387e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  9.87548828e-02,   9.87548828e-02],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.86340332e-01,   1.86340332e-01],
                        [  2.18048096e-01,   2.18048096e-01],
                        [  2.28179932e-01,   2.28179932e-01],
                        [  2.13867188e-01,   2.13867188e-01],
                        [  1.80145264e-01,   1.80145264e-01],
                        [  1.41754150e-01,   1.41754150e-01],
                        [  1.13861084e-01,   1.13861084e-01],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  7.86437988e-02,   7.86437988e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  6.65283203e-02,   6.65283203e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  3.57055664e-03,   3.57055664e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -6.52160645e-02,  -6.52160645e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.90515137e-02,  -5.90820312e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -5.95703125e-02,  -5.95703125e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  6.95495605e-02,   6.95495605e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -9.51843262e-02,  -9.51843262e-02],
                        [ -1.39923096e-01,  -1.39923096e-01],
                        [ -1.45385742e-01,  -1.45385742e-01],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  5.90209961e-02,   5.90515137e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  6.42395020e-02,   6.42395020e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -1.35772705e-01,  -1.35772705e-01],
                        [ -2.24548340e-01,  -2.24548340e-01],
                        [ -2.73101807e-01,  -2.73101807e-01],
                        [ -2.64587402e-01,  -2.64587402e-01],
                        [ -2.12066650e-01,  -2.12066650e-01],
                        [ -1.48529053e-01,  -1.48529053e-01],
                        [ -1.02539062e-01,  -1.02539062e-01],
                        [ -8.04443359e-02,  -8.04443359e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.31011963e-01,   1.31011963e-01],
                        [  1.30187988e-01,   1.30187988e-01],
                        [  1.09680176e-01,   1.09680176e-01],
                        [  7.97119141e-02,   7.97119141e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  1.00311279e-01,   1.00311279e-01],
                        [  1.43188477e-01,   1.43188477e-01],
                        [  1.86737061e-01,   1.86737061e-01],
                        [  2.20123291e-01,   2.20123291e-01],
                        [  2.32147217e-01,   2.32147217e-01],
                        [  2.18078613e-01,   2.18078613e-01],
                        [  1.85302734e-01,   1.85302734e-01],
                        [  1.49261475e-01,   1.49261475e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  5.74645996e-02,   5.74645996e-02],
                        [  6.10656738e-02,   6.10656738e-02],
                        [  5.73730469e-02,   5.73730469e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -3.95202637e-02,  -3.95202637e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -7.02514648e-02,  -7.02514648e-02],
                        [ -7.21130371e-02,  -7.21130371e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.72607422e-02,  -6.72607422e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -5.35888672e-02,  -5.35888672e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -1.25213623e-01,  -1.25213623e-01],
                        [ -1.65557861e-01,  -1.65557861e-01],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -1.14105225e-01,  -1.14105225e-01],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -1.26678467e-01,  -1.26678467e-01],
                        [ -2.10876465e-01,  -2.10876465e-01],
                        [ -2.58026123e-01,  -2.58026123e-01],
                        [ -2.51831055e-01,  -2.51831055e-01],
                        [ -2.02392578e-01,  -2.02392578e-01],
                        [ -1.41784668e-01,  -1.41784668e-01],
                        [ -9.91210938e-02,  -9.91210938e-02],
                        [ -7.99865723e-02,  -7.99865723e-02],
                        [ -7.31201172e-02,  -7.31201172e-02],
                        [ -6.88781738e-02,  -6.88781738e-02],
                        [ -6.48193359e-02,  -6.48193359e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.31213379e-02,   4.31213379e-02],
                        [  3.18908691e-02,   3.18603516e-02],
                        [  2.44445801e-02,   2.44445801e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  1.23046875e-01,   1.23046875e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  1.38061523e-01,   1.38061523e-01],
                        [  1.14471436e-01,   1.14471436e-01],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  1.19110107e-01,   1.19110107e-01],
                        [  1.68975830e-01,   1.68975830e-01],
                        [  2.11578369e-01,   2.11578369e-01],
                        [  2.31811523e-01,   2.31811523e-01],
                        [  2.23815918e-01,   2.23815918e-01],
                        [  1.93634033e-01,   1.93634033e-01],
                        [  1.54815674e-01,   1.54815674e-01],
                        [  1.20941162e-01,   1.20941162e-01],
                        [  9.74426270e-02,   9.74426270e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  6.57348633e-02,   6.57348633e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -6.66809082e-02,  -6.66809082e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -7.51342773e-02,  -7.51342773e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -1.19659424e-01,  -1.19659424e-01],
                        [ -1.54998779e-01,  -1.54998779e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.08062744e-01,  -1.08062744e-01],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  5.11169434e-02,   5.11169434e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -1.40869141e-01,  -1.40869141e-01],
                        [ -2.19207764e-01,  -2.19207764e-01],
                        [ -2.55889893e-01,  -2.55889893e-01],
                        [ -2.42279053e-01,  -2.42279053e-01],
                        [ -1.93695068e-01,  -1.93695068e-01],
                        [ -1.35375977e-01,  -1.35375977e-01],
                        [ -8.99963379e-02,  -8.99963379e-02],
                        [ -6.77795410e-02,  -6.77795410e-02],
                        [ -6.17065430e-02,  -6.17065430e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.26525879e-01,   1.26525879e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.26495361e-01,   1.26495361e-01],
                        [  9.67102051e-02,   9.67102051e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  6.98242188e-02,   6.98242188e-02],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  1.36505127e-01,   1.36505127e-01],
                        [  1.76452637e-01,   1.76452637e-01],
                        [  2.03216553e-01,   2.03216553e-01],
                        [  2.09442139e-01,   2.09442139e-01],
                        [  1.94610596e-01,   1.94610596e-01],
                        [  1.66687012e-01,   1.66687012e-01],
                        [  1.39709473e-01,   1.39709473e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  8.49914551e-02,   8.49914551e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.91442871e-02,  -2.91137695e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -7.01599121e-02,  -7.01599121e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -6.76269531e-02,  -6.76269531e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -6.68945312e-02,  -6.68945312e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  8.41979980e-02,   8.41979980e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  7.89794922e-02,   7.89794922e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -1.08673096e-01,  -1.08673096e-01],
                        [ -1.65771484e-01,  -1.65771484e-01],
                        [ -1.77825928e-01,  -1.77825928e-01],
                        [ -1.44531250e-01,  -1.44531250e-01],
                        [ -8.58154297e-02,  -8.58154297e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [  2.37426758e-02,   2.37426758e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  7.46154785e-02,   7.46154785e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -1.96411133e-01,  -1.96411133e-01],
                        [ -2.58728027e-01,  -2.58728027e-01],
                        [ -2.71972656e-01,  -2.71972656e-01],
                        [ -2.36175537e-01,  -2.36175537e-01],
                        [ -1.74407959e-01,  -1.74407959e-01],
                        [ -1.17431641e-01,  -1.17431641e-01],
                        [ -8.31298828e-02,  -8.31298828e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  4.16564941e-02,   4.16564941e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  1.28875732e-01,   1.28875732e-01],
                        [  1.47552490e-01,   1.47552490e-01],
                        [  1.42364502e-01,   1.42364502e-01],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.59454346e-01,   1.59454346e-01],
                        [  2.01202393e-01,   2.01202393e-01],
                        [  2.22290039e-01,   2.22290039e-01],
                        [  2.17559814e-01,   2.17559814e-01],
                        [  1.93084717e-01,   1.93084717e-01],
                        [  1.61712646e-01,   1.61712646e-01],
                        [  1.34155273e-01,   1.34155273e-01],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  8.07495117e-02,   8.07495117e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -5.84716797e-02,  -5.84716797e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -7.02819824e-02,  -7.02819824e-02],
                        [ -6.47583008e-02,  -6.47583008e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -7.39746094e-02,  -7.39746094e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  5.60607910e-02,   5.60607910e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  4.11682129e-02,   4.11682129e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -1.56677246e-01,  -1.56677246e-01],
                        [ -1.86950684e-01,  -1.86950684e-01],
                        [ -1.68060303e-01,  -1.68060303e-01],
                        [ -1.11083984e-01,  -1.11083984e-01],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  7.69958496e-02,   7.69958496e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -1.40777588e-01,  -1.40777588e-01],
                        [ -2.25891113e-01,  -2.25891113e-01],
                        [ -2.67608643e-01,  -2.67608643e-01],
                        [ -2.56561279e-01,  -2.56561279e-01],
                        [ -2.06726074e-01,  -2.06726074e-01],
                        [ -1.45721436e-01,  -1.45721436e-01],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -7.68432617e-02,  -7.68432617e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  5.32531738e-02,   5.32531738e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  1.04949951e-01,   1.04949951e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.31469727e-01,   1.31469727e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.02752686e-01,   1.02752686e-01],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.90490723e-01,   1.90490723e-01],
                        [  2.27569580e-01,   2.27569580e-01],
                        [  2.34313965e-01,   2.34313965e-01],
                        [  2.11059570e-01,   2.11059570e-01],
                        [  1.74713135e-01,   1.74713135e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.02966309e-01,   1.02966309e-01],
                        [  8.54187012e-02,   8.54187012e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -5.68847656e-02,  -5.68847656e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.87158203e-02,  -5.87158203e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -6.99157715e-02,  -6.99157715e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -4.98657227e-02,  -4.98657227e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  6.90307617e-02,   6.90307617e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -1.20391846e-01,  -1.20391846e-01],
                        [ -1.57073975e-01,  -1.57073975e-01],
                        [ -1.60339355e-01,  -1.60339355e-01],
                        [ -1.30798340e-01,  -1.30798340e-01],
                        [ -8.08105469e-02,  -8.08105469e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -1.44195557e-01,  -1.44195557e-01],
                        [ -2.13073730e-01,  -2.13073730e-01],
                        [ -2.44140625e-01,  -2.44140625e-01],
                        [ -2.28149414e-01,  -2.28149414e-01],
                        [ -1.78497314e-01,  -1.78497314e-01],
                        [ -1.24206543e-01,  -1.24206543e-01],
                        [ -8.85925293e-02,  -8.85925293e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  5.36499023e-02,   5.36499023e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  1.17584229e-01,   1.17584229e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.22314453e-01,   1.22314453e-01],
                        [  1.13037109e-01,   1.13037109e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  6.84814453e-02,   6.84814453e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.56127930e-01,   1.56127930e-01],
                        [  1.95007324e-01,   1.95007324e-01],
                        [  2.15576172e-01,   2.15576172e-01],
                        [  2.12432861e-01,   2.12432861e-01],
                        [  1.88842773e-01,   1.88842773e-01],
                        [  1.54449463e-01,   1.54449463e-01],
                        [  1.19873047e-01,   1.19873047e-01],
                        [  9.35363770e-02,   9.35363770e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  6.68334961e-02,   6.68334961e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.74133301e-02,  -6.74133301e-02],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -5.92041016e-02,  -5.92041016e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.94995117e-02,  -4.94995117e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -5.27343750e-02,  -5.27343750e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -4.89501953e-02,  -4.89501953e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -5.63964844e-02,  -5.63964844e-02],
                        [ -1.23687744e-01,  -1.23687744e-01],
                        [ -1.67419434e-01,  -1.67419434e-01],
                        [ -1.71234131e-01,  -1.71234131e-01],
                        [ -1.39282227e-01,  -1.39282227e-01],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  5.29785156e-02,   5.29785156e-02],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -1.53015137e-01,  -1.53015137e-01],
                        [ -2.23480225e-01,  -2.23480225e-01],
                        [ -2.45666504e-01,  -2.45666504e-01],
                        [ -2.16613770e-01,  -2.16613770e-01],
                        [ -1.58782959e-01,  -1.58782959e-01],
                        [ -1.04888916e-01,  -1.04888916e-01],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -6.93664551e-02,  -6.93664551e-02],
                        [ -6.92749023e-02,  -6.92749023e-02],
                        [ -6.28967285e-02,  -6.28967285e-02],
                        [ -4.80041504e-02,  -4.80041504e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  9.41772461e-02,   9.41772461e-02],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.39465332e-01,   1.39465332e-01],
                        [  1.20971680e-01,   1.20971680e-01],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.51367188e-01,   1.51367188e-01],
                        [  1.94732666e-01,   1.94732666e-01],
                        [  2.13226318e-01,   2.13226318e-01],
                        [  2.03948975e-01,   2.03948975e-01],
                        [  1.76635742e-01,   1.76635742e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -6.23474121e-02,  -6.23474121e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.17980957e-02,  -6.17980957e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -1.83288574e-01,  -1.83288574e-01],
                        [ -1.97845459e-01,  -1.97845459e-01],
                        [ -1.68151855e-01,  -1.68151855e-01],
                        [ -1.12030029e-01,  -1.12030029e-01],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -1.41052246e-01,  -1.41052246e-01],
                        [ -2.01416016e-01,  -2.01416016e-01],
                        [ -2.23907471e-01,  -2.23907471e-01],
                        [ -2.03369141e-01,  -2.03369141e-01],
                        [ -1.57623291e-01,  -1.57623291e-01],
                        [ -1.14837646e-01,  -1.14837646e-01],
                        [ -9.03930664e-02,  -9.03930664e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -6.53076172e-02,  -6.53076172e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.46026611e-01,   1.46026611e-01],
                        [  1.49963379e-01,   1.49963379e-01],
                        [  1.37969971e-01,   1.37969971e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.80175781e-01,   1.80175781e-01],
                        [  2.07519531e-01,   2.07519531e-01],
                        [  2.10235596e-01,   2.10235596e-01],
                        [  1.87530518e-01,   1.87530518e-01],
                        [  1.49047852e-01,   1.49047852e-01],
                        [  1.13433838e-01,   1.13433838e-01],
                        [  9.43603516e-02,   9.43603516e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  8.77380371e-02,   8.77380371e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  7.50732422e-03,   7.50732422e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.03759766e-03,  -1.03759766e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -7.13500977e-02,  -7.13500977e-02],
                        [ -7.19909668e-02,  -7.19909668e-02],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -6.03942871e-02,  -6.03942871e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  7.10754395e-02,   7.10754395e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -1.24389648e-01,  -1.24389648e-01],
                        [ -1.84722900e-01,  -1.84722900e-01],
                        [ -2.10723877e-01,  -2.10723877e-01],
                        [ -1.89056396e-01,  -1.89056396e-01],
                        [ -1.32324219e-01,  -1.32324219e-01],
                        [ -7.15942383e-02,  -7.15942383e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [ -6.79931641e-02,  -6.79931641e-02],
                        [ -1.45172119e-01,  -1.45172119e-01],
                        [ -2.03399658e-01,  -2.03399658e-01],
                        [ -2.22259521e-01,  -2.22259521e-01],
                        [ -1.97784424e-01,  -1.97784424e-01],
                        [ -1.50146484e-01,  -1.50146484e-01],
                        [ -1.07757568e-01,  -1.07757568e-01],
                        [ -8.30078125e-02,  -8.30078125e-02],
                        [ -6.88781738e-02,  -6.88781738e-02],
                        [ -5.46264648e-02,  -5.46264648e-02],
                        [ -3.69567871e-02,  -3.69567871e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.50244141e-03,  -2.50244141e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  1.06079102e-01,   1.06079102e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.44531250e-01,   1.44531250e-01],
                        [  1.40197754e-01,   1.40197754e-01],
                        [  1.26220703e-01,   1.26220703e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  4.37316895e-02,   4.37316895e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  8.86535645e-02,   8.86535645e-02],
                        [  1.25915527e-01,   1.25915527e-01],
                        [  1.64611816e-01,   1.64611816e-01],
                        [  1.89666748e-01,   1.89666748e-01],
                        [  1.89758301e-01,   1.89758301e-01],
                        [  1.67602539e-01,   1.67602539e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  8.61206055e-02,   8.61206055e-02],
                        [  6.75048828e-02,   6.75048828e-02],
                        [  5.08422852e-02,   5.08422852e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -5.25512695e-02,  -5.25512695e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  4.49829102e-02,   4.49829102e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -1.30249023e-01,  -1.30249023e-01],
                        [ -1.90216064e-01,  -1.90216064e-01],
                        [ -2.14294434e-01,  -2.14294434e-01],
                        [ -1.98333740e-01,  -1.98333740e-01],
                        [ -1.55456543e-01,  -1.55456543e-01],
                        [ -1.02691650e-01,  -1.02691650e-01],
                        [ -5.41992188e-02,  -5.41992188e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  9.78393555e-02,   9.78393555e-02],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -1.17279053e-01,  -1.17279053e-01],
                        [ -1.94641113e-01,  -1.94641113e-01],
                        [ -2.32147217e-01,  -2.32147217e-01],
                        [ -2.22137451e-01,  -2.22137451e-01],
                        [ -1.81060791e-01,  -1.81060791e-01],
                        [ -1.32934570e-01,  -1.32934570e-01],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  9.17663574e-02,   9.17663574e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.21582031e-01,   1.21582031e-01],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  1.45629883e-01,   1.45629883e-01],
                        [  1.85241699e-01,   1.85241699e-01],
                        [  2.02270508e-01,   2.02270508e-01],
                        [  1.89514160e-01,   1.89514160e-01],
                        [  1.57257080e-01,   1.57257080e-01],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  8.15429688e-02,   8.15429688e-02],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  6.12792969e-02,   6.12792969e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.29699707e-02,  -1.29699707e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.96826172e-02,  -4.96826172e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.54406738e-02,  -4.54406738e-02],
                        [ -5.27954102e-02,  -5.27954102e-02],
                        [ -5.95092773e-02,  -5.95092773e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  2.31323242e-02,   2.31323242e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -1.17492676e-01,  -1.17492676e-01],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -2.11151123e-01,  -2.11151123e-01],
                        [ -1.95739746e-01,  -1.95739746e-01],
                        [ -1.55487061e-01,  -1.55487061e-01],
                        [ -1.14593506e-01,  -1.14593506e-01],
                        [ -8.32824707e-02,  -8.32824707e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  7.76977539e-02,   7.76977539e-02],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -1.37023926e-01,  -1.37023926e-01],
                        [ -2.05108643e-01,  -2.05108643e-01],
                        [ -2.30865479e-01,  -2.30865479e-01],
                        [ -2.11944580e-01,  -2.11944580e-01],
                        [ -1.64459229e-01,  -1.64459229e-01],
                        [ -1.15295410e-01,  -1.15295410e-01],
                        [ -8.48693848e-02,  -8.48693848e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  1.18347168e-01,   1.18347168e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.16119385e-01,   1.16119385e-01],
                        [  1.02050781e-01,   1.02050781e-01],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  5.46569824e-02,   5.46569824e-02],
                        [  4.48303223e-02,   4.48303223e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.48986816e-01,   1.48986816e-01],
                        [  1.80999756e-01,   1.80999756e-01],
                        [  1.92962646e-01,   1.92962646e-01],
                        [  1.76788330e-01,   1.76788330e-01],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.98059082e-02,  -1.98059082e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.49011230e-02,  -5.49011230e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -6.40869141e-02,  -6.40869141e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -5.59387207e-02,  -5.59387207e-02],
                        [ -4.77294922e-02,  -4.77294922e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  4.57763672e-04,   4.57763672e-04],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -1.37878418e-01,  -1.37878418e-01],
                        [ -1.70959473e-01,  -1.70959473e-01],
                        [ -1.75811768e-01,  -1.75811768e-01],
                        [ -1.58172607e-01,  -1.58172607e-01],
                        [ -1.28540039e-01,  -1.28540039e-01],
                        [ -9.85107422e-02,  -9.85107422e-02],
                        [ -7.44934082e-02,  -7.44934082e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  8.19702148e-02,   8.19702148e-02],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -1.26403809e-01,  -1.26403809e-01],
                        [ -2.04742432e-01,  -2.04742432e-01],
                        [ -2.34771729e-01,  -2.34771729e-01],
                        [ -2.13104248e-01,  -2.13104248e-01],
                        [ -1.62475586e-01,  -1.62475586e-01],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -8.17871094e-02,  -8.17871094e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  5.41076660e-02,   5.41076660e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  1.51062012e-01,   1.51062012e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.80541992e-02,   6.80541992e-02],
                        [  5.21240234e-02,   5.21240234e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  1.25335693e-01,   1.25335693e-01],
                        [  1.64184570e-01,   1.64184570e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  1.45629883e-01,   1.45629883e-01],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -7.01599121e-02,  -7.01599121e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -7.05871582e-02,  -7.05871582e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -4.14123535e-02,  -4.14123535e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [  1.61743164e-03,   1.61743164e-03],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  4.69970703e-03,   4.69970703e-03],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -1.19140625e-01,  -1.19140625e-01],
                        [ -1.71844482e-01,  -1.71844482e-01],
                        [ -1.98883057e-01,  -1.98883057e-01],
                        [ -1.91528320e-01,  -1.91528320e-01],
                        [ -1.54174805e-01,  -1.54174805e-01],
                        [ -1.07727051e-01,  -1.07727051e-01],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  8.66699219e-02,   8.66699219e-02],
                        [  1.15570068e-01,   1.15570068e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -1.84753418e-01,  -1.84753418e-01],
                        [ -2.44598389e-01,  -2.44598389e-01],
                        [ -2.45391846e-01,  -2.45391846e-01],
                        [ -1.95922852e-01,  -1.95922852e-01],
                        [ -1.28509521e-01,  -1.28509521e-01],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -4.70886230e-02,  -4.70886230e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.33270264e-01,   1.33270264e-01],
                        [  1.45263672e-01,   1.45263672e-01],
                        [  1.43035889e-01,   1.43035889e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.18133545e-01,   1.18133545e-01],
                        [  1.07299805e-01,   1.07299805e-01],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  1.15631104e-01,   1.15631104e-01],
                        [  1.53106689e-01,   1.53106689e-01],
                        [  1.72454834e-01,   1.72454834e-01],
                        [  1.68518066e-01,   1.68518066e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  8.41064453e-02,   8.41064453e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  3.55529785e-02,   3.55529785e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.99365234e-02,  -5.99365234e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  6.73522949e-02,   6.73522949e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -1.03027344e-01,  -1.03027344e-01],
                        [ -1.77856445e-01,  -1.77856445e-01],
                        [ -2.25585938e-01,  -2.25585938e-01],
                        [ -2.29431152e-01,  -2.29431152e-01],
                        [ -1.92840576e-01,  -1.92840576e-01],
                        [ -1.39343262e-01,  -1.39343262e-01],
                        [ -9.53979492e-02,  -9.53979492e-02],
                        [ -7.00378418e-02,  -7.00378418e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -3.70178223e-02,  -3.70178223e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.42120361e-01,   1.42120361e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  3.88488770e-02,   3.88488770e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -1.55273438e-01,  -1.55273438e-01],
                        [ -2.21618652e-01,  -2.21618652e-01],
                        [ -2.37854004e-01,  -2.37854004e-01],
                        [ -2.09289551e-01,  -2.09289551e-01],
                        [ -1.60400391e-01,  -1.60400391e-01],
                        [ -1.16546631e-01,  -1.16546631e-01],
                        [ -8.94470215e-02,  -8.94470215e-02],
                        [ -7.31201172e-02,  -7.31201172e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  1.22711182e-01,   1.22711182e-01],
                        [  1.47399902e-01,   1.47399902e-01],
                        [  1.50787354e-01,   1.50787354e-01],
                        [  1.35528564e-01,   1.35528564e-01],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  9.37194824e-02,   9.37194824e-02],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  8.40148926e-02,   8.40148926e-02],
                        [  6.84814453e-02,   6.84814453e-02],
                        [  5.13305664e-02,   5.13305664e-02],
                        [  3.22875977e-02,   3.22875977e-02],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  1.36352539e-01,   1.36352539e-01],
                        [  1.79901123e-01,   1.79901123e-01],
                        [  1.95800781e-01,   1.95800781e-01],
                        [  1.78741455e-01,   1.78741455e-01],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  7.07397461e-02,   7.07397461e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.44335938e-02,  -4.44641113e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -7.71484375e-02,  -7.71484375e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -3.43017578e-02,  -3.42712402e-02],
                        [ -2.39868164e-02,  -2.39868164e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  3.18908691e-02,   3.18908691e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -6.84204102e-02,  -6.84204102e-02],
                        [ -1.38610840e-01,  -1.38610840e-01],
                        [ -1.96838379e-01,  -1.96838379e-01],
                        [ -2.23327637e-01,  -2.23327637e-01],
                        [ -2.09289551e-01,  -2.09289551e-01],
                        [ -1.68395996e-01,  -1.68395996e-01],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -1.03363037e-01,  -1.03363037e-01],
                        [ -9.26513672e-02,  -9.26513672e-02],
                        [ -8.34350586e-02,  -8.34350586e-02],
                        [ -6.61621094e-02,  -6.61621094e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  3.00598145e-02,   3.00598145e-02],
                        [  6.42089844e-02,   6.42089844e-02],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  1.54663086e-01,   1.54663086e-01],
                        [  1.49108887e-01,   1.49108887e-01],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  4.49218750e-02,   4.49218750e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -1.59362793e-01,  -1.59362793e-01],
                        [ -2.35961914e-01,  -2.35961914e-01],
                        [ -2.58728027e-01,  -2.58728027e-01],
                        [ -2.26654053e-01,  -2.26654053e-01],
                        [ -1.65100098e-01,  -1.65100098e-01],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -7.57141113e-02,  -7.57141113e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.61743164e-02,   1.61743164e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  1.12243652e-01,   1.12243652e-01],
                        [  1.35192871e-01,   1.35192871e-01],
                        [  1.42333984e-01,   1.42333984e-01],
                        [  1.31744385e-01,   1.31744385e-01],
                        [  1.13647461e-01,   1.13647461e-01],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  8.35876465e-02,   8.35876465e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  5.31005859e-03,   5.31005859e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.48071289e-01,   1.48071289e-01],
                        [  1.66717529e-01,   1.66717529e-01],
                        [  1.61895752e-01,   1.61895752e-01],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -8.15429688e-02,  -8.15429688e-02],
                        [ -8.29467773e-02,  -8.29467773e-02],
                        [ -7.63854980e-02,  -7.63854980e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -5.56335449e-02,  -5.56335449e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  6.94580078e-02,   6.94580078e-02],
                        [  5.12695312e-02,   5.13000488e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [ -7.12280273e-02,  -7.12280273e-02],
                        [ -1.55975342e-01,  -1.55975342e-01],
                        [ -2.20001221e-01,  -2.19970703e-01],
                        [ -2.43713379e-01,  -2.43713379e-01],
                        [ -2.26074219e-01,  -2.26074219e-01],
                        [ -1.81427002e-01,  -1.81427002e-01],
                        [ -1.30920410e-01,  -1.30920410e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  4.94384766e-02,   4.94384766e-02],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.56036377e-01,   1.56036377e-01],
                        [  1.65435791e-01,   1.65435791e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  6.53991699e-02,   6.53991699e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -1.49291992e-01,  -1.49261475e-01],
                        [ -2.25616455e-01,  -2.25616455e-01],
                        [ -2.49969482e-01,  -2.49969482e-01],
                        [ -2.22839355e-01,  -2.22839355e-01],
                        [ -1.66351318e-01,  -1.66351318e-01],
                        [ -1.10839844e-01,  -1.10839844e-01],
                        [ -7.48596191e-02,  -7.48596191e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.45843506e-01,   1.45843506e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  8.36486816e-02,   8.36486816e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  3.50952148e-03,   3.50952148e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.33239746e-01,   1.33239746e-01],
                        [  1.57562256e-01,   1.57562256e-01],
                        [  1.58294678e-01,   1.58294678e-01],
                        [  1.39953613e-01,   1.39953613e-01],
                        [  1.16546631e-01,   1.16546631e-01],
                        [  1.00585938e-01,   1.00585938e-01],
                        [  9.20715332e-02,   9.20715332e-02],
                        [  8.27331543e-02,   8.27026367e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  3.25622559e-02,   3.25317383e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  6.71386719e-04,   6.71386719e-04],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.15747070e-02,  -5.15441895e-02],
                        [ -5.35278320e-02,  -5.35278320e-02],
                        [ -5.74645996e-02,  -5.74645996e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -5.88989258e-02,  -5.88989258e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  3.37524414e-02,   3.37219238e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  6.30798340e-02,   6.31103516e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [ -8.78906250e-03,  -8.75854492e-03],
                        [ -8.23364258e-02,  -8.23364258e-02],
                        [ -1.61987305e-01,  -1.61987305e-01],
                        [ -2.26470947e-01,  -2.26440430e-01],
                        [ -2.53265381e-01,  -2.53265381e-01],
                        [ -2.32360840e-01,  -2.32360840e-01],
                        [ -1.80145264e-01,  -1.80145264e-01],
                        [ -1.28662109e-01,  -1.28662109e-01],
                        [ -9.65270996e-02,  -9.65576172e-02],
                        [ -7.77893066e-02,  -7.77893066e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  7.79113770e-02,   7.79113770e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [ -9.42382812e-02,  -9.42382812e-02],
                        [ -1.80389404e-01,  -1.80389404e-01],
                        [ -2.30468750e-01,  -2.30468750e-01],
                        [ -2.30102539e-01,  -2.30102539e-01],
                        [ -1.90093994e-01,  -1.90093994e-01],
                        [ -1.38000488e-01,  -1.38000488e-01],
                        [ -9.68322754e-02,  -9.68322754e-02],
                        [ -6.98242188e-02,  -6.98242188e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.51367188e-02,   1.51672363e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  8.51135254e-02,   8.51135254e-02],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.53076172e-01,   1.53076172e-01],
                        [  1.47094727e-01,   1.47094727e-01],
                        [  1.34338379e-01,   1.34338379e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  1.06750488e-01,   1.06781006e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  7.42492676e-02,   7.42492676e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  1.72119141e-02,   1.72119141e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.45019531e-01,   1.45019531e-01],
                        [  1.62384033e-01,   1.62414551e-01],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  1.34887695e-01,   1.34887695e-01],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  9.08203125e-02,   9.08203125e-02],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  6.67114258e-02,   6.67114258e-02],
                        [  5.31005859e-02,   5.31005859e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -4.69970703e-02,  -4.69970703e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -6.01806641e-02,  -6.01806641e-02],
                        [ -5.60607910e-02,  -5.60302734e-02],
                        [ -5.27954102e-02,  -5.27648926e-02],
                        [ -4.91638184e-02,  -4.91638184e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [ -3.94592285e-02,  -3.94287109e-02],
                        [ -1.14105225e-01,  -1.14105225e-01],
                        [ -1.86553955e-01,  -1.86553955e-01],
                        [ -2.29858398e-01,  -2.29858398e-01],
                        [ -2.28942871e-01,  -2.28912354e-01],
                        [ -1.93084717e-01,  -1.93084717e-01],
                        [ -1.47216797e-01,  -1.47216797e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -8.64868164e-02,  -8.64868164e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  1.07635498e-01,   1.07635498e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.59545898e-01,   1.59515381e-01],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  9.87243652e-02,   9.87548828e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [ -9.54589844e-02,  -9.54589844e-02],
                        [ -1.91345215e-01,  -1.91345215e-01],
                        [ -2.42126465e-01,  -2.42126465e-01],
                        [ -2.36572266e-01,  -2.36572266e-01],
                        [ -1.87957764e-01,  -1.87988281e-01],
                        [ -1.25122070e-01,  -1.25122070e-01],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  4.27246094e-03,   4.24194336e-03],
                        [  1.08032227e-02,   1.08337402e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  2.01721191e-02,   2.02026367e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  7.91015625e-02,   7.91015625e-02],
                        [  1.15814209e-01,   1.15783691e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.45965576e-01,   1.45965576e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.19415283e-01,   1.19415283e-01],
                        [  1.21612549e-01,   1.21643066e-01],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  1.05926514e-01,   1.05895996e-01],
                        [  9.04846191e-02,   9.05151367e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  6.57653809e-02,   6.57653809e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.60827637e-01,   1.60827637e-01],
                        [  1.62719727e-01,   1.62689209e-01],
                        [  1.40411377e-01,   1.40411377e-01],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  6.92138672e-02,   6.91833496e-02],
                        [  5.65795898e-02,   5.66101074e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  2.30712891e-02,   2.31018066e-02],
                        [  2.16064453e-02,   2.15759277e-02],
                        [  1.84936523e-02,   1.84936523e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.74658203e-03,   2.74658203e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -1.42822266e-02,  -1.42517090e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.52075195e-02,  -2.52075195e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.78015137e-02,  -2.78320312e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.06506348e-02,  -1.06811523e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -5.63354492e-02,  -5.63659668e-02],
                        [ -6.44836426e-02,  -6.44836426e-02],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -7.18688965e-02,  -7.18688965e-02],
                        [ -6.86645508e-02,  -6.86950684e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.54211426e-02,  -2.54516602e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  3.66821289e-02,   3.66516113e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -4.87060547e-02,  -4.86755371e-02],
                        [ -1.15173340e-01,  -1.15173340e-01],
                        [ -1.77581787e-01,  -1.77612305e-01],
                        [ -2.14843750e-01,  -2.14843750e-01],
                        [ -2.10449219e-01,  -2.10449219e-01],
                        [ -1.69158936e-01,  -1.69158936e-01],
                        [ -1.17340088e-01,  -1.17340088e-01],
                        [ -8.09631348e-02,  -8.09326172e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -8.33129883e-03,  -8.30078125e-03],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  7.47985840e-02,   7.47680664e-02],
                        [  1.07360840e-01,   1.07360840e-01],
                        [  1.28051758e-01,   1.28051758e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.23779297e-01,   1.23779297e-01],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -1.35894775e-01,  -1.35894775e-01],
                        [ -1.99981689e-01,  -1.99981689e-01],
                        [ -2.19207764e-01,  -2.19207764e-01],
                        [ -1.90979004e-01,  -1.90979004e-01],
                        [ -1.36627197e-01,  -1.36596680e-01],
                        [ -8.66394043e-02,  -8.66394043e-02],
                        [ -5.95092773e-02,  -5.95397949e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.19311523e-02,  -4.19006348e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -6.13403320e-03,  -6.10351562e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.67431641e-02,   3.67736816e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  2.13317871e-02,   2.13012695e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.39923096e-01,   1.39923096e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.32354736e-01,   1.32324219e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.26190186e-01,   1.26190186e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.11053467e-01,   1.11053467e-01],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  3.57055664e-03,   3.60107422e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  4.96826172e-02,   4.96826172e-02],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  1.35620117e-01,   1.35620117e-01],
                        [  1.60430908e-01,   1.60430908e-01],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  1.29882812e-01,   1.29852295e-01],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  3.31115723e-02,   3.31420898e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.57153320e-02,  -4.57458496e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -6.03637695e-02,  -6.03332520e-02],
                        [ -6.84509277e-02,  -6.84509277e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -6.48803711e-02,  -6.48498535e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.39343262e-02,  -6.39343262e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.78210449e-02,  -4.78210449e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -1.24206543e-02,  -1.23901367e-02],
                        [  3.84521484e-03,   3.81469727e-03],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  4.14733887e-02,   4.14733887e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -1.74377441e-01,  -1.74377441e-01],
                        [ -2.17193604e-01,  -2.17193604e-01],
                        [ -2.22534180e-01,  -2.22534180e-01],
                        [ -1.89849854e-01,  -1.89849854e-01],
                        [ -1.37420654e-01,  -1.37420654e-01],
                        [ -9.25903320e-02,  -9.25903320e-02],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -6.25915527e-02,  -6.26220703e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  7.82165527e-02,   7.81860352e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -1.23962402e-01,  -1.23962402e-01],
                        [ -1.89727783e-01,  -1.89727783e-01],
                        [ -2.10784912e-01,  -2.10784912e-01],
                        [ -1.84051514e-01,  -1.84051514e-01],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -6.43005371e-02,  -6.43005371e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -5.70373535e-02,  -5.70068359e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [  1.70898438e-03,   1.73950195e-03],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  3.12500000e-02,   3.12194824e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [  7.55004883e-02,   7.55004883e-02],
                        [  1.09832764e-01,   1.09832764e-01],
                        [  1.40319824e-01,   1.40319824e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.49780273e-01,   1.49780273e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.24420166e-01,   1.24420166e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.46942139e-01,   1.46911621e-01],
                        [  1.45782471e-01,   1.45782471e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  6.94274902e-02,   6.94580078e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  5.40771484e-02,   5.40466309e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  3.08532715e-02,   3.08837891e-02],
                        [  1.50451660e-02,   1.50146484e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.09863281e-02,  -1.09558105e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.71203613e-02,  -1.71203613e-02],
                        [ -1.92871094e-02,  -1.93176270e-02],
                        [ -2.15148926e-02,  -2.14843750e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -3.19213867e-02,  -3.18908691e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.65393066e-02,  -4.65087891e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.65588379e-02,  -6.65893555e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -4.84924316e-02,  -4.84924316e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -7.29370117e-03,  -7.26318359e-03],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  5.99365234e-02,   5.99365234e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [ -5.73730469e-02,  -5.73730469e-02],
                        [ -1.25549316e-01,  -1.25549316e-01],
                        [ -1.87652588e-01,  -1.87652588e-01],
                        [ -2.22900391e-01,  -2.22869873e-01],
                        [ -2.19879150e-01,  -2.19879150e-01],
                        [ -1.84844971e-01,  -1.84844971e-01],
                        [ -1.37664795e-01,  -1.37634277e-01],
                        [ -9.99450684e-02,  -9.99450684e-02],
                        [ -8.06274414e-02,  -8.06274414e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -6.37512207e-02,  -6.37512207e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -2.38342285e-02,  -2.38342285e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  2.27661133e-02,   2.27661133e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  1.04125977e-01,   1.04125977e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  5.61218262e-02,   5.61218262e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -1.81121826e-01,  -1.81121826e-01],
                        [ -2.22991943e-01,  -2.22991943e-01],
                        [ -2.18994141e-01,  -2.19024658e-01],
                        [ -1.78100586e-01,  -1.78100586e-01],
                        [ -1.24938965e-01,  -1.24938965e-01],
                        [ -8.16955566e-02,  -8.16955566e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  1.46484375e-03,   1.43432617e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  8.92028809e-02,   8.92028809e-02],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.42333984e-01,   1.42333984e-01],
                        [  1.51245117e-01,   1.51245117e-01],
                        [  1.47186279e-01,   1.47186279e-01],
                        [  1.34857178e-01,   1.34857178e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.10687256e-01,   1.10687256e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  7.39135742e-02,   7.39135742e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  5.31921387e-02,   5.31921387e-02],
                        [  3.82995605e-02,   3.82690430e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  4.79125977e-03,   4.82177734e-03],
                        [ -4.36401367e-03,  -4.36401367e-03],
                        [ -2.99072266e-03,  -3.02124023e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.42059326e-01,   1.42059326e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  8.89587402e-02,   8.89587402e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  6.42700195e-02,   6.42700195e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  2.97851562e-02,   2.97851562e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.21557617e-02,  -2.21557617e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -5.52673340e-02,  -5.52368164e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -5.05981445e-02,  -5.06286621e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -4.55932617e-02,  -4.56237793e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  5.80749512e-02,   5.81054688e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  4.84924316e-02,   4.85229492e-02],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -6.50939941e-02,  -6.50939941e-02],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -2.06298828e-01,  -2.06298828e-01],
                        [ -2.41821289e-01,  -2.41821289e-01],
                        [ -2.35260010e-01,  -2.35260010e-01],
                        [ -1.93664551e-01,  -1.93664551e-01],
                        [ -1.41021729e-01,  -1.41021729e-01],
                        [ -1.02416992e-01,  -1.02416992e-01],
                        [ -8.48693848e-02,  -8.48693848e-02],
                        [ -7.51953125e-02,  -7.51953125e-02],
                        [ -5.95397949e-02,  -5.95397949e-02],
                        [ -4.02221680e-02,  -4.02526855e-02],
                        [ -2.68859863e-02,  -2.68554688e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [  2.23388672e-02,   2.23083496e-02],
                        [  5.80749512e-02,   5.81054688e-02],
                        [  9.48791504e-02,   9.48791504e-02],
                        [  1.24298096e-01,   1.24298096e-01],
                        [  1.41723633e-01,   1.41723633e-01],
                        [  1.43066406e-01,   1.43066406e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  6.56433105e-02,   6.56433105e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -1.12091064e-01,  -1.12091064e-01],
                        [ -1.90948486e-01,  -1.90948486e-01],
                        [ -2.27294922e-01,  -2.27294922e-01],
                        [ -2.11639404e-01,  -2.11639404e-01],
                        [ -1.61590576e-01,  -1.61590576e-01],
                        [ -1.09161377e-01,  -1.09191895e-01],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [  9.15527344e-05,   9.15527344e-05],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  4.14428711e-02,   4.14428711e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  1.34277344e-02,   1.34277344e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.57165527e-01,   1.57165527e-01],
                        [  1.67633057e-01,   1.67633057e-01],
                        [  1.65161133e-01,   1.65161133e-01],
                        [  1.55456543e-01,   1.55456543e-01],
                        [  1.41845703e-01,   1.41845703e-01],
                        [  1.27960205e-01,   1.27960205e-01],
                        [  1.18194580e-01,   1.18194580e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  9.46655273e-02,   9.46655273e-02],
                        [  7.55615234e-02,   7.55615234e-02],
                        [  5.52978516e-02,   5.52673340e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  1.67846680e-03,   1.67846680e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  1.54418945e-01,   1.54418945e-01],
                        [  1.57501221e-01,   1.57501221e-01],
                        [  1.35955811e-01,   1.35986328e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  7.90710449e-02,   7.90405273e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  6.20727539e-02,   6.21032715e-02],
                        [  5.76171875e-02,   5.76171875e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  8.72802734e-03,   8.72802734e-03],
                        [ -5.85937500e-03,  -5.88989258e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -2.22473145e-02,  -2.22778320e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -1.67846680e-02,  -1.68151855e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.45971680e-02,  -2.46276855e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.23693848e-02,  -2.23999023e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -7.90710449e-02,  -7.90710449e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -5.49926758e-02,  -5.49926758e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.21752930e-02,  -4.22058105e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  6.25610352e-02,   6.25305176e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -1.32293701e-01,  -1.32293701e-01],
                        [ -2.01629639e-01,  -2.01629639e-01],
                        [ -2.43896484e-01,  -2.43865967e-01],
                        [ -2.43194580e-01,  -2.43164062e-01],
                        [ -2.03643799e-01,  -2.03643799e-01],
                        [ -1.49200439e-01,  -1.49200439e-01],
                        [ -1.05010986e-01,  -1.05010986e-01],
                        [ -8.00476074e-02,  -8.00781250e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -3.30200195e-02,  -3.30505371e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [  4.57763672e-03,   4.54711914e-03],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.41082764e-01,   1.41082764e-01],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  7.89184570e-02,   7.89184570e-02],
                        [ -5.61523438e-03,  -5.64575195e-03],
                        [ -1.09680176e-01,  -1.09649658e-01],
                        [ -1.96014404e-01,  -1.96014404e-01],
                        [ -2.32910156e-01,  -2.32940674e-01],
                        [ -2.14965820e-01,  -2.14965820e-01],
                        [ -1.61132812e-01,  -1.61102295e-01],
                        [ -1.01654053e-01,  -1.01654053e-01],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -1.36108398e-02,  -1.36413574e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  4.36706543e-02,   4.36401367e-02],
                        [  3.75976562e-02,   3.75976562e-02],
                        [  2.92968750e-02,   2.92968750e-02],
                        [  2.20947266e-02,   2.20642090e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  3.48510742e-02,   3.48205566e-02],
                        [  7.08618164e-02,   7.08618164e-02],
                        [  1.09405518e-01,   1.09436035e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.59881592e-01,   1.59881592e-01],
                        [  1.59576416e-01,   1.59576416e-01],
                        [  1.47247314e-01,   1.47247314e-01],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  1.10534668e-01,   1.10534668e-01],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  1.04248047e-01,   1.04248047e-01],
                        [  9.19189453e-02,   9.19189453e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  4.75769043e-02,   4.76074219e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  1.38336182e-01,   1.38366699e-01],
                        [  1.69708252e-01,   1.69708252e-01],
                        [  1.69677734e-01,   1.69677734e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -1.95312500e-03,  -1.92260742e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  1.37023926e-02,   1.36718750e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  1.55944824e-02,   1.55639648e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -1.41601562e-02,  -1.41296387e-02],
                        [ -2.78930664e-02,  -2.79235840e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -4.16259766e-02,  -4.16564941e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -4.11071777e-02,  -4.11376953e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -6.90307617e-02,  -6.90307617e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -6.37207031e-02,  -6.37512207e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -4.68139648e-02,  -4.68444824e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.48510742e-02,  -3.48205566e-02],
                        [ -2.85034180e-02,  -2.85339355e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -1.66625977e-02,  -1.66320801e-02],
                        [  1.55639648e-03,   1.58691406e-03],
                        [  2.38342285e-02,   2.38037109e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  4.73022461e-03,   4.73022461e-03],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -1.18011475e-01,  -1.18011475e-01],
                        [ -1.82678223e-01,  -1.82678223e-01],
                        [ -2.19238281e-01,  -2.19238281e-01],
                        [ -2.14752197e-01,  -2.14752197e-01],
                        [ -1.80694580e-01,  -1.80694580e-01],
                        [ -1.42181396e-01,  -1.42181396e-01],
                        [ -1.15875244e-01,  -1.15875244e-01],
                        [ -1.01348877e-01,  -1.01348877e-01],
                        [ -9.05761719e-02,  -9.05761719e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -6.46362305e-02,  -6.46362305e-02],
                        [ -4.81567383e-02,  -4.81567383e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  3.70483398e-02,   3.70788574e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  1.12274170e-01,   1.12243652e-01],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.52679443e-01,   1.52679443e-01],
                        [  1.42944336e-01,   1.42944336e-01],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -1.78985596e-01,  -1.78985596e-01],
                        [ -2.22412109e-01,  -2.22412109e-01],
                        [ -2.16430664e-01,  -2.16430664e-01],
                        [ -1.72332764e-01,  -1.72332764e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -7.36999512e-02,  -7.36999512e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  6.10351562e-05,   3.05175781e-05],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  2.85034180e-02,   2.85034180e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.43554688e-01,   1.43585205e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.42791748e-01,   1.42791748e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.23504639e-01,   1.23474121e-01],
                        [  1.28814697e-01,   1.28814697e-01],
                        [  1.32385254e-01,   1.32385254e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.17523193e-01,   1.17523193e-01],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [ -1.26647949e-02,  -1.26342773e-02],
                        [ -2.99987793e-02,  -3.00292969e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.41571045e-01,   1.41601562e-01],
                        [  1.55181885e-01,   1.55181885e-01],
                        [  1.38580322e-01,   1.38580322e-01],
                        [  1.08764648e-01,   1.08764648e-01],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.27258301e-02,   1.27258301e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -4.79125977e-02,  -4.78820801e-02],
                        [ -5.86547852e-02,  -5.86242676e-02],
                        [ -6.24084473e-02,  -6.24084473e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.36804199e-02,  -5.36804199e-02],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [ -6.35681152e-02,  -6.35375977e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.55322266e-02,  -4.55017090e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  4.11682129e-02,   4.11682129e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  6.85729980e-02,   6.85424805e-02],
                        [  5.29174805e-02,   5.29174805e-02],
                        [  1.61132812e-02,   1.61437988e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -1.28997803e-01,  -1.28997803e-01],
                        [ -2.10052490e-01,  -2.10052490e-01],
                        [ -2.56195068e-01,  -2.56195068e-01],
                        [ -2.52807617e-01,  -2.52838135e-01],
                        [ -2.12921143e-01,  -2.12921143e-01],
                        [ -1.62139893e-01,  -1.62139893e-01],
                        [ -1.20727539e-01,  -1.20758057e-01],
                        [ -9.56726074e-02,  -9.56726074e-02],
                        [ -8.14514160e-02,  -8.14208984e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  3.82995605e-02,   3.83300781e-02],
                        [  7.16247559e-02,   7.16247559e-02],
                        [  1.05133057e-01,   1.05102539e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  1.43005371e-01,   1.43005371e-01],
                        [  1.34674072e-01,   1.34674072e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  2.18811035e-02,   2.19116211e-02],
                        [ -7.33032227e-02,  -7.33032227e-02],
                        [ -1.61010742e-01,  -1.61010742e-01],
                        [ -2.12768555e-01,  -2.12768555e-01],
                        [ -2.16339111e-01,  -2.16339111e-01],
                        [ -1.80816650e-01,  -1.80816650e-01],
                        [ -1.28723145e-01,  -1.28723145e-01],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -5.16357422e-02,  -5.16662598e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  5.61828613e-02,   5.61828613e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  2.99377441e-02,   2.99072266e-02],
                        [  7.32727051e-02,   7.32727051e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.62445068e-01,   1.62445068e-01],
                        [  1.82403564e-01,   1.82403564e-01],
                        [  1.79901123e-01,   1.79931641e-01],
                        [  1.64886475e-01,   1.64886475e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.41021729e-01,   1.41052246e-01],
                        [  1.31561279e-01,   1.31561279e-01],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  8.63037109e-02,   8.63037109e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  7.31201172e-02,   7.30895996e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  3.84521484e-03,   3.81469727e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.40478516e-02,  -2.40173340e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.69152832e-02,   5.69458008e-02],
                        [  1.03485107e-01,   1.03454590e-01],
                        [  1.36230469e-01,   1.36230469e-01],
                        [  1.45050049e-01,   1.45050049e-01],
                        [  1.33819580e-01,   1.33819580e-01],
                        [  1.13616943e-01,   1.13586426e-01],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  4.29687500e-02,   4.29382324e-02],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  1.17492676e-02,   1.17797852e-02],
                        [  1.15966797e-02,   1.15661621e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.54516602e-02,  -2.54211426e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.86560059e-02,  -2.86865234e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.05676270e-02,  -5.05371094e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [  5.31005859e-03,   5.34057617e-03],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -1.65618896e-01,  -1.65618896e-01],
                        [ -2.24426270e-01,  -2.24426270e-01],
                        [ -2.40692139e-01,  -2.40692139e-01],
                        [ -2.12402344e-01,  -2.12402344e-01],
                        [ -1.61071777e-01,  -1.61071777e-01],
                        [ -1.16668701e-01,  -1.16668701e-01],
                        [ -9.43603516e-02,  -9.43298340e-02],
                        [ -8.86840820e-02,  -8.86840820e-02],
                        [ -8.58459473e-02,  -8.58764648e-02],
                        [ -7.64465332e-02,  -7.64160156e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -6.83593750e-03,  -6.80541992e-03],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  7.19604492e-02,   7.19909668e-02],
                        [  1.05682373e-01,   1.05712891e-01],
                        [  1.34857178e-01,   1.34826660e-01],
                        [  1.50848389e-01,   1.50848389e-01],
                        [  1.41235352e-01,   1.41235352e-01],
                        [  9.19494629e-02,   9.19189453e-02],
                        [ -5.49316406e-04,  -5.79833984e-04],
                        [ -1.14624023e-01,  -1.14624023e-01],
                        [ -2.08679199e-01,  -2.08648682e-01],
                        [ -2.47528076e-01,  -2.47528076e-01],
                        [ -2.24273682e-01,  -2.24273682e-01],
                        [ -1.60644531e-01,  -1.60644531e-01],
                        [ -9.14306641e-02,  -9.14611816e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  4.17785645e-02,   4.17480469e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  7.98645020e-02,   7.98645020e-02],
                        [  1.20117188e-01,   1.20147705e-01],
                        [  1.49475098e-01,   1.49475098e-01],
                        [  1.59484863e-01,   1.59515381e-01],
                        [  1.56097412e-01,   1.56097412e-01],
                        [  1.50451660e-01,   1.50451660e-01],
                        [  1.46118164e-01,   1.46118164e-01],
                        [  1.39587402e-01,   1.39617920e-01],
                        [  1.29394531e-01,   1.29394531e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  8.76159668e-02,   8.76159668e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  4.65087891e-02,   4.65087891e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.45764160e-02,  -3.45764160e-02],
                        [ -1.62658691e-02,  -1.62963867e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.28906250e-01,   1.28906250e-01],
                        [  1.30157471e-01,   1.30157471e-01],
                        [  1.12426758e-01,   1.12457275e-01],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  6.96716309e-02,   6.96716309e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  2.80151367e-02,   2.80456543e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.10668945e-02,  -3.10974121e-02],
                        [ -3.82690430e-02,  -3.82995605e-02],
                        [ -4.12597656e-02,  -4.12292480e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -4.17480469e-02,  -4.17785645e-02],
                        [ -4.52575684e-02,  -4.52270508e-02],
                        [ -4.91638184e-02,  -4.91333008e-02],
                        [ -5.26123047e-02,  -5.26428223e-02],
                        [ -5.58471680e-02,  -5.58776855e-02],
                        [ -5.73730469e-02,  -5.73425293e-02],
                        [ -5.59997559e-02,  -5.59997559e-02],
                        [ -5.27648926e-02,  -5.27954102e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -3.88183594e-02,  -3.88488770e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -4.76074219e-02,  -4.75769043e-02],
                        [ -4.19311523e-02,  -4.19006348e-02],
                        [ -2.67944336e-02,  -2.68249512e-02],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [  2.33764648e-02,   2.34069824e-02],
                        [  4.49523926e-02,   4.49218750e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.23986816e-02,   5.23986816e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [ -1.63574219e-02,  -1.63879395e-02],
                        [ -8.16040039e-02,  -8.15734863e-02],
                        [ -1.48468018e-01,  -1.48437500e-01],
                        [ -1.97479248e-01,  -1.97509766e-01],
                        [ -2.14080811e-01,  -2.14080811e-01],
                        [ -1.96044922e-01,  -1.96014404e-01],
                        [ -1.60583496e-01,  -1.60583496e-01],
                        [ -1.32995605e-01,  -1.32995605e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.20147705e-01,  -1.20147705e-01],
                        [ -1.08764648e-01,  -1.08764648e-01],
                        [ -8.46862793e-02,  -8.46862793e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  1.11358643e-01,   1.11358643e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  1.29669189e-01,   1.29699707e-01],
                        [  9.39331055e-02,   9.39331055e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [ -7.61413574e-02,  -7.61413574e-02],
                        [ -1.67449951e-01,  -1.67449951e-01],
                        [ -2.17407227e-01,  -2.17407227e-01],
                        [ -2.09533691e-01,  -2.09533691e-01],
                        [ -1.60308838e-01,  -1.60308838e-01],
                        [ -1.03912354e-01,  -1.03912354e-01],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  5.18798828e-04,   5.49316406e-04],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  4.44030762e-02,   4.44030762e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.37329102e-03,   1.34277344e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  1.51550293e-01,   1.51550293e-01],
                        [  1.67755127e-01,   1.67724609e-01],
                        [  1.69372559e-01,   1.69372559e-01],
                        [  1.62231445e-01,   1.62261963e-01],
                        [  1.52221680e-01,   1.52221680e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.33148193e-01,   1.33148193e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  8.96911621e-02,   8.97216797e-02],
                        [  7.40356445e-02,   7.40356445e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  2.65197754e-02,   2.65502930e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -2.60925293e-02,  -2.61230469e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.01513672e-02,  -3.01818848e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  5.85632324e-02,   5.85937500e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.34979248e-01,   1.34979248e-01],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.12792969e-01,   1.12792969e-01],
                        [  8.52966309e-02,   8.52966309e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  3.93066406e-02,   3.93066406e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  3.74145508e-02,   3.74145508e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -5.65795898e-02,  -5.65490723e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -3.93371582e-02,  -3.93066406e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -5.14221191e-02,  -5.13916016e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -5.39245605e-02,  -5.39550781e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.93872070e-02,  -5.93872070e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -5.29785156e-02,  -5.29479980e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -1.28173828e-03,  -1.31225586e-03],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  8.22143555e-02,   8.22143555e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -9.63134766e-02,  -9.63134766e-02],
                        [ -1.72790527e-01,  -1.72790527e-01],
                        [ -2.21221924e-01,  -2.21221924e-01],
                        [ -2.29919434e-01,  -2.29919434e-01],
                        [ -2.07366943e-01,  -2.07366943e-01],
                        [ -1.73736572e-01,  -1.73736572e-01],
                        [ -1.45965576e-01,  -1.45965576e-01],
                        [ -1.27441406e-01,  -1.27441406e-01],
                        [ -1.10839844e-01,  -1.10839844e-01],
                        [ -9.00878906e-02,  -9.00573730e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -4.79736328e-02,  -4.79736328e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.13928223e-02,  -2.13928223e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  1.22375488e-01,   1.22375488e-01],
                        [  1.43066406e-01,   1.43066406e-01],
                        [  1.47369385e-01,   1.47369385e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -9.87548828e-02,  -9.87548828e-02],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -2.31689453e-01,  -2.31689453e-01],
                        [ -2.19177246e-01,  -2.19177246e-01],
                        [ -1.66076660e-01,  -1.66076660e-01],
                        [ -1.05133057e-01,  -1.05163574e-01],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -3.45458984e-02,  -3.45458984e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.45874023e-02,   1.45568848e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.38134766e-02,   3.38134766e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.42517090e-02,  -1.42517090e-02],
                        [  9.76562500e-04,   9.76562500e-04],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  8.30993652e-02,   8.30688477e-02],
                        [  1.33361816e-01,   1.33361816e-01],
                        [  1.72790527e-01,   1.72821045e-01],
                        [  1.91528320e-01,   1.91497803e-01],
                        [  1.87622070e-01,   1.87622070e-01],
                        [  1.69799805e-01,   1.69799805e-01],
                        [  1.51489258e-01,   1.51489258e-01],
                        [  1.39221191e-01,   1.39190674e-01],
                        [  1.28540039e-01,   1.28540039e-01],
                        [  1.13555908e-01,   1.13555908e-01],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  7.27844238e-02,   7.27844238e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [ -1.78833008e-02,  -1.78527832e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  9.46044922e-02,   9.46044922e-02],
                        [  1.26098633e-01,   1.26098633e-01],
                        [  1.35955811e-01,   1.35955811e-01],
                        [  1.23168945e-01,   1.23168945e-01],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  5.35888672e-02,   5.35888672e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [ -1.25122070e-03,  -1.28173828e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -6.56738281e-02,  -6.57043457e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.46472168e-02,  -4.46166992e-02],
                        [ -4.18090820e-02,  -4.17785645e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  7.22656250e-02,   7.22961426e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  4.46777344e-02,   4.46777344e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -8.89892578e-02,  -8.89892578e-02],
                        [ -1.72912598e-01,  -1.72912598e-01],
                        [ -2.36053467e-01,  -2.36053467e-01],
                        [ -2.56011963e-01,  -2.56011963e-01],
                        [ -2.30529785e-01,  -2.30529785e-01],
                        [ -1.80877686e-01,  -1.80877686e-01],
                        [ -1.36047363e-01,  -1.36047363e-01],
                        [ -1.10778809e-01,  -1.10778809e-01],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -8.38928223e-02,  -8.38928223e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -4.92248535e-02,  -4.92248535e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -3.41796875e-02,  -3.41491699e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  3.78723145e-02,   3.79028320e-02],
                        [  7.23876953e-02,   7.23876953e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.36230469e-01,   1.36260986e-01],
                        [  1.35314941e-01,   1.35314941e-01],
                        [  1.15753174e-01,   1.15753174e-01],
                        [  6.94580078e-02,   6.94580078e-02],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.06475830e-01,  -1.06506348e-01],
                        [ -1.90063477e-01,  -1.90063477e-01],
                        [ -2.22595215e-01,  -2.22595215e-01],
                        [ -1.96319580e-01,  -1.96319580e-01],
                        [ -1.37176514e-01,  -1.37176514e-01],
                        [ -8.00170898e-02,  -8.00170898e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -3.72314453e-03,  -3.72314453e-03],
                        [ -5.95092773e-03,  -5.95092773e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  1.02233887e-01,   1.02233887e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.86279297e-01,   1.86279297e-01],
                        [  1.74316406e-01,   1.74316406e-01],
                        [  1.53076172e-01,   1.53076172e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.17736816e-01,   1.17736816e-01],
                        [  1.09619141e-01,   1.09619141e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -1.52893066e-02,  -1.52893066e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  1.31805420e-01,   1.31805420e-01],
                        [  1.41998291e-01,   1.41998291e-01],
                        [  1.28051758e-01,   1.28051758e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  2.84729004e-02,   2.84729004e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -2.72521973e-02,  -2.72216797e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.91027832e-02,  -4.90722656e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  1.21154785e-02,   1.21459961e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -1.32110596e-01,  -1.32141113e-01],
                        [ -2.10723877e-01,  -2.10723877e-01],
                        [ -2.55157471e-01,  -2.55157471e-01],
                        [ -2.45880127e-01,  -2.45880127e-01],
                        [ -1.94274902e-01,  -1.94274902e-01],
                        [ -1.37664795e-01,  -1.37664795e-01],
                        [ -1.06964111e-01,  -1.06964111e-01],
                        [ -1.01470947e-01,  -1.01470947e-01],
                        [ -9.93957520e-02,  -9.93957520e-02],
                        [ -8.81958008e-02,  -8.81958008e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  1.19842529e-01,   1.19842529e-01],
                        [  1.34490967e-01,   1.34490967e-01],
                        [  1.42120361e-01,   1.42120361e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  4.42504883e-02,   4.42504883e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -1.51763916e-01,  -1.51763916e-01],
                        [ -2.18963623e-01,  -2.18963623e-01],
                        [ -2.30438232e-01,  -2.30438232e-01],
                        [ -1.90612793e-01,  -1.90612793e-01],
                        [ -1.28875732e-01,  -1.28875732e-01],
                        [ -7.83081055e-02,  -7.83081055e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  1.63574219e-02,   1.63574219e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  2.99072266e-02,   2.99377441e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  1.32904053e-01,   1.32904053e-01],
                        [  1.74102783e-01,   1.74102783e-01],
                        [  1.91772461e-01,   1.91772461e-01],
                        [  1.83013916e-01,   1.83013916e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.41235352e-01,   1.41235352e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  6.09436035e-02,   6.09436035e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -2.47802734e-02,  -2.47497559e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  1.16577148e-01,   1.16577148e-01],
                        [  1.43218994e-01,   1.43218994e-01],
                        [  1.40350342e-01,   1.40350342e-01],
                        [  1.18652344e-01,   1.18652344e-01],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -3.94592285e-02,  -3.94592285e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -5.91430664e-02,  -5.91430664e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -1.49810791e-01,  -1.49810791e-01],
                        [ -2.18963623e-01,  -2.18963623e-01],
                        [ -2.50000000e-01,  -2.50000000e-01],
                        [ -2.35168457e-01,  -2.35168457e-01],
                        [ -1.90979004e-01,  -1.90979004e-01],
                        [ -1.45660400e-01,  -1.45660400e-01],
                        [ -1.17584229e-01,  -1.17584229e-01],
                        [ -1.04400635e-01,  -1.04400635e-01],
                        [ -9.35363770e-02,  -9.35363770e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -5.91125488e-02,  -5.91125488e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [  3.01208496e-02,   3.01208496e-02],
                        [  6.58874512e-02,   6.58874512e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.33300781e-01,   1.33300781e-01],
                        [  1.39221191e-01,   1.39221191e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.03027344e-01,   1.03027344e-01],
                        [  4.47692871e-02,   4.47692871e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -1.45141602e-01,  -1.45141602e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -2.30224609e-01,  -2.30224609e-01],
                        [ -1.88842773e-01,  -1.88842773e-01],
                        [ -1.25793457e-01,  -1.25793457e-01],
                        [ -7.59277344e-02,  -7.59277344e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  6.04858398e-02,   6.04858398e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  3.67736816e-02,   3.67736816e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  7.39440918e-02,   7.39440918e-02],
                        [  1.23870850e-01,   1.23870850e-01],
                        [  1.70379639e-01,   1.70379639e-01],
                        [  1.96472168e-01,   1.96472168e-01],
                        [  1.93115234e-01,   1.93115234e-01],
                        [  1.69494629e-01,   1.69494629e-01],
                        [  1.45660400e-01,   1.45660400e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.07147217e-01,   1.07147217e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -6.13403320e-02,  -6.13403320e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.37634277e-01,   1.37634277e-01],
                        [  1.44805908e-01,   1.44805908e-01],
                        [  1.27075195e-01,   1.27075195e-01],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  7.98034668e-02,   7.98034668e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -1.65710449e-02,  -1.65710449e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  5.15747070e-02,   5.15747070e-02],
                        [  7.04345703e-02,   7.04345703e-02],
                        [  7.40966797e-02,   7.40966797e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -1.44226074e-01,  -1.44226074e-01],
                        [ -2.16461182e-01,  -2.16461182e-01],
                        [ -2.57263184e-01,  -2.57263184e-01],
                        [ -2.55371094e-01,  -2.55371094e-01],
                        [ -2.16766357e-01,  -2.16766357e-01],
                        [ -1.65740967e-01,  -1.65740967e-01],
                        [ -1.28326416e-01,  -1.28326416e-01],
                        [ -1.12335205e-01,  -1.12335205e-01],
                        [ -1.05834961e-01,  -1.05834961e-01],
                        [ -9.45739746e-02,  -9.45739746e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  4.23278809e-02,   4.23278809e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  9.27124023e-02,   9.27124023e-02],
                        [  1.05682373e-01,   1.05682373e-01],
                        [  1.14929199e-01,   1.14929199e-01],
                        [  1.19720459e-01,   1.19720459e-01],
                        [  1.12762451e-01,   1.12762451e-01],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -1.30859375e-01,  -1.30859375e-01],
                        [ -1.92718506e-01,  -1.92718506e-01],
                        [ -2.04071045e-01,  -2.04071045e-01],
                        [ -1.68640137e-01,  -1.68640137e-01],
                        [ -1.16302490e-01,  -1.16302490e-01],
                        [ -7.74230957e-02,  -7.74230957e-02],
                        [ -6.05468750e-02,  -6.05468750e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.73492432e-01,   1.73492432e-01],
                        [  1.90948486e-01,   1.90948486e-01],
                        [  1.81243896e-01,   1.81243896e-01],
                        [  1.57287598e-01,   1.57287598e-01],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.21673584e-01,   1.21673584e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.27246094e-02,  -4.27246094e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  6.06994629e-02,   6.06994629e-02],
                        [  1.00616455e-01,   1.00616455e-01],
                        [  1.22100830e-01,   1.22100830e-01],
                        [  1.21673584e-01,   1.21673584e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  4.45251465e-02,   4.45251465e-02],
                        [  4.22058105e-02,   4.22058105e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  9.15527344e-05,   9.15527344e-05],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -4.05273438e-02,  -4.05273438e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -1.17462158e-01,  -1.17462158e-01],
                        [ -1.95800781e-01,  -1.95800781e-01],
                        [ -2.51098633e-01,  -2.51098633e-01],
                        [ -2.63427734e-01,  -2.63427734e-01],
                        [ -2.32055664e-01,  -2.32055664e-01],
                        [ -1.77520752e-01,  -1.77520752e-01],
                        [ -1.27105713e-01,  -1.27105713e-01],
                        [ -9.71069336e-02,  -9.71069336e-02],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  1.16912842e-01,   1.16912842e-01],
                        [  1.42486572e-01,   1.42486572e-01],
                        [  1.57104492e-01,   1.57104492e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.17370605e-01,   1.17370605e-01],
                        [  5.16967773e-02,   5.16967773e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -1.30615234e-01,  -1.30615234e-01],
                        [ -1.95251465e-01,  -1.95251465e-01],
                        [ -2.10357666e-01,  -2.10357666e-01],
                        [ -1.79504395e-01,  -1.79504395e-01],
                        [ -1.28265381e-01,  -1.28265381e-01],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  1.23199463e-01,   1.23199463e-01],
                        [  1.52282715e-01,   1.52282715e-01],
                        [  1.68212891e-01,   1.68212891e-01],
                        [  1.69647217e-01,   1.69647217e-01],
                        [  1.62048340e-01,   1.62048340e-01],
                        [  1.53137207e-01,   1.53137207e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.40075684e-01,   1.40075684e-01],
                        [  1.30065918e-01,   1.30065918e-01],
                        [  1.14196777e-01,   1.14196777e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  4.85839844e-02,   4.85839844e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  8.01086426e-02,   8.01086426e-02],
                        [  1.24359131e-01,   1.24359131e-01],
                        [  1.40106201e-01,   1.40106201e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  6.01196289e-02,   6.01196289e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [  4.08935547e-03,   4.08935547e-03],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.53796387e-02,  -4.53796387e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -1.59759521e-01,  -1.59759521e-01],
                        [ -2.28942871e-01,  -2.28942871e-01],
                        [ -2.59185791e-01,  -2.59185791e-01],
                        [ -2.45513916e-01,  -2.45513916e-01],
                        [ -2.01324463e-01,  -2.01324463e-01],
                        [ -1.50787354e-01,  -1.50787354e-01],
                        [ -1.16882324e-01,  -1.16882324e-01],
                        [ -1.05712891e-01,  -1.05712891e-01],
                        [ -1.03302002e-01,  -1.03302002e-01],
                        [ -9.28955078e-02,  -9.28955078e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -5.22766113e-02,  -5.22766113e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  5.75866699e-02,   5.75866699e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  1.03668213e-01,   1.03668213e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.36566162e-01,   1.36566162e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -1.36840820e-01,  -1.36840820e-01],
                        [ -1.92810059e-01,  -1.92810059e-01],
                        [ -1.96044922e-01,  -1.96044922e-01],
                        [ -1.52679443e-01,  -1.52679443e-01],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  3.54003906e-02,   3.54003906e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  2.16064453e-02,   2.16064453e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.66290283e-01,   1.66290283e-01],
                        [  1.77398682e-01,   1.77398682e-01],
                        [  1.68670654e-01,   1.68670654e-01],
                        [  1.51824951e-01,   1.51824951e-01],
                        [  1.38519287e-01,   1.38519287e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.22558594e-01,   1.22558594e-01],
                        [  1.08032227e-01,   1.08032227e-01],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  5.67626953e-02,   5.67626953e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.27716064e-01,   1.27716064e-01],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  8.20922852e-03,   8.20922852e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -4.39453125e-02,  -4.39453125e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [  1.07421875e-02,   1.07421875e-02],
                        [  2.70080566e-02,   2.70080566e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  1.47094727e-02,   1.47094727e-02],
                        [ -4.87976074e-02,  -4.87976074e-02],
                        [ -1.36016846e-01,  -1.36016846e-01],
                        [ -2.15057373e-01,  -2.15057373e-01],
                        [ -2.53814697e-01,  -2.53814697e-01],
                        [ -2.42431641e-01,  -2.42431641e-01],
                        [ -1.96868896e-01,  -1.96868896e-01],
                        [ -1.45263672e-01,  -1.45263672e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -9.43908691e-02,  -9.43908691e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -8.05358887e-02,  -8.05358887e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [  1.92260742e-03,   1.92260742e-03],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.05041504e-01,   1.05041504e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  6.72302246e-02,   6.72302246e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -1.58843994e-01,  -1.58843994e-01],
                        [ -1.96777344e-01,  -1.96777344e-01],
                        [ -1.87377930e-01,  -1.87377930e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -9.20715332e-02,  -9.20715332e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -1.09863281e-02,  -1.09863281e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  3.39050293e-02,   3.39050293e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  1.24389648e-01,   1.24389648e-01],
                        [  1.59637451e-01,   1.59637451e-01],
                        [  1.76879883e-01,   1.76879883e-01],
                        [  1.77429199e-01,   1.77429199e-01],
                        [  1.68792725e-01,   1.68792725e-01],
                        [  1.57958984e-01,   1.57958984e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.40533447e-01,   1.40533447e-01],
                        [  1.32171631e-01,   1.32171631e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  2.19726562e-03,   2.19726562e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [  4.28771973e-02,   4.28771973e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.24938965e-01,   1.24938965e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  2.35900879e-02,   2.35900879e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -9.85717773e-03,  -9.85717773e-03],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  4.06799316e-02,   4.06799316e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -1.01043701e-01,  -1.01043701e-01],
                        [ -1.82281494e-01,  -1.82281494e-01],
                        [ -2.42279053e-01,  -2.42279053e-01],
                        [ -2.61016846e-01,  -2.61016846e-01],
                        [ -2.35198975e-01,  -2.35198975e-01],
                        [ -1.85424805e-01,  -1.85424805e-01],
                        [ -1.41296387e-01,  -1.41296387e-01],
                        [ -1.15844727e-01,  -1.15844727e-01],
                        [ -1.01440430e-01,  -1.01440430e-01],
                        [ -8.85620117e-02,  -8.85620117e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  6.73522949e-02,   6.73522949e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.13281250e-01,   1.13281250e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  6.29577637e-02,   6.29577637e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -1.61132812e-01,  -1.61132812e-01],
                        [ -1.96319580e-01,  -1.96319580e-01],
                        [ -1.80908203e-01,  -1.80908203e-01],
                        [ -1.29852295e-01,  -1.29852295e-01],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  4.27246094e-04,   4.27246094e-04],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  1.40350342e-01,   1.40350342e-01],
                        [  1.70867920e-01,   1.70867920e-01],
                        [  1.80755615e-01,   1.80755615e-01],
                        [  1.72821045e-01,   1.72821045e-01],
                        [  1.56311035e-01,   1.56311035e-01],
                        [  1.42608643e-01,   1.42608643e-01],
                        [  1.37542725e-01,   1.37542725e-01],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.06353760e-01,   1.06353760e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  7.99560547e-02,   7.99560547e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  9.62829590e-02,   9.62829590e-02],
                        [  1.09466553e-01,   1.09466553e-01],
                        [  1.05133057e-01,   1.05133057e-01],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  6.69555664e-02,   6.69555664e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -3.01818848e-02,  -3.01818848e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -4.54406738e-02,  -4.54406738e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -6.52465820e-02,  -6.52465820e-02],
                        [ -1.54876709e-01,  -1.54876709e-01],
                        [ -2.35015869e-01,  -2.35015869e-01],
                        [ -2.76000977e-01,  -2.76000977e-01],
                        [ -2.68005371e-01,  -2.68005371e-01],
                        [ -2.24334717e-01,  -2.24334717e-01],
                        [ -1.70867920e-01,  -1.70867920e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -1.08825684e-01,  -1.08825684e-01],
                        [ -9.41162109e-02,  -9.41162109e-02],
                        [ -7.51037598e-02,  -7.51037598e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  6.67114258e-02,   6.67114258e-02],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.12213135e-01,   1.12213135e-01],
                        [  1.13647461e-01,   1.13647461e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  7.02514648e-02,   7.02514648e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -1.49475098e-01,  -1.49475098e-01],
                        [ -1.98547363e-01,  -1.98547363e-01],
                        [ -1.99188232e-01,  -1.99188232e-01],
                        [ -1.61712646e-01,  -1.61712646e-01],
                        [ -1.13861084e-01,  -1.13861084e-01],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  5.44433594e-02,   5.44433594e-02],
                        [  9.94262695e-02,   9.94262695e-02],
                        [  1.41601562e-01,   1.41601562e-01],
                        [  1.73339844e-01,   1.73339844e-01],
                        [  1.87591553e-01,   1.87591553e-01],
                        [  1.80847168e-01,   1.80847168e-01],
                        [  1.59393311e-01,   1.59393311e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.13342285e-01,   1.13342285e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.04522705e-01,   1.04522705e-01],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  7.61108398e-02,   7.61108398e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  1.04309082e-01,   1.04309082e-01],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.81469727e-02,  -3.81469727e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.25622559e-02,  -3.25622559e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  3.00903320e-02,   3.00903320e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -8.03833008e-02,  -8.03833008e-02],
                        [ -1.61529541e-01,  -1.61529541e-01],
                        [ -2.32452393e-01,  -2.32452393e-01],
                        [ -2.65563965e-01,  -2.65563965e-01],
                        [ -2.48687744e-01,  -2.48687744e-01],
                        [ -1.97875977e-01,  -1.97875977e-01],
                        [ -1.45416260e-01,  -1.45416260e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -1.01470947e-01,  -1.01470947e-01],
                        [ -9.46350098e-02,  -9.46350098e-02],
                        [ -8.21228027e-02,  -8.21228027e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -5.11474609e-02,  -5.11474609e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.11785889e-01,   1.11785889e-01],
                        [  6.42700195e-02,   6.42700195e-02],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.01257324e-01,  -1.01257324e-01],
                        [ -1.69281006e-01,  -1.69281006e-01],
                        [ -1.93511963e-01,  -1.93511963e-01],
                        [ -1.71020508e-01,  -1.71020508e-01],
                        [ -1.23992920e-01,  -1.23992920e-01],
                        [ -8.24890137e-02,  -8.24890137e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -5.17883301e-02,  -5.17883301e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [  2.10571289e-03,   2.10571289e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.34985352e-02,   2.34985352e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  1.45812988e-01,   1.45812988e-01],
                        [  1.67236328e-01,   1.67236328e-01],
                        [  1.66503906e-01,   1.66503906e-01],
                        [  1.52313232e-01,   1.52313232e-01],
                        [  1.39404297e-01,   1.39404297e-01],
                        [  1.36322021e-01,   1.36322021e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.35986328e-01,   1.35986328e-01],
                        [  1.27319336e-01,   1.27319336e-01],
                        [  1.16455078e-01,   1.16455078e-01],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  8.53881836e-02,   8.53881836e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  1.80358887e-02,   1.80358887e-02],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -5.64270020e-02,  -5.64270020e-02],
                        [ -5.62133789e-02,  -5.62133789e-02],
                        [ -5.14221191e-02,  -5.14221191e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  1.18133545e-01,   1.18133545e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  9.62829590e-02,   9.62829590e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.44348145e-02,  -1.44348145e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -9.62829590e-02,  -9.62829590e-02],
                        [ -1.76361084e-01,  -1.76361084e-01],
                        [ -2.43194580e-01,  -2.43194580e-01],
                        [ -2.76062012e-01,  -2.76062012e-01],
                        [ -2.62237549e-01,  -2.62237549e-01],
                        [ -2.11334229e-01,  -2.11334229e-01],
                        [ -1.54479980e-01,  -1.54479980e-01],
                        [ -1.18804932e-01,  -1.18804932e-01],
                        [ -1.04064941e-01,  -1.04064941e-01],
                        [ -9.31091309e-02,  -9.31091309e-02],
                        [ -7.83691406e-02,  -7.83691406e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  1.16241455e-01,   1.16241455e-01],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  6.97937012e-02,   6.97937012e-02],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -1.75170898e-01,  -1.75170898e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.79382324e-01,  -1.79382324e-01],
                        [ -1.21795654e-01,  -1.21795654e-01],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  7.56835938e-02,   7.56835938e-02],
                        [  1.19201660e-01,   1.19201660e-01],
                        [  1.55426025e-01,   1.55426025e-01],
                        [  1.72637939e-01,   1.72637939e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.19232178e-01,   1.19232178e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  1.24603271e-01,   1.24603271e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.27410889e-01,   1.27410889e-01],
                        [  1.21978760e-01,   1.21978760e-01],
                        [  1.10260010e-01,   1.10260010e-01],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  8.47778320e-02,   8.47778320e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  4.99572754e-02,   4.99572754e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -3.18908691e-02,  -3.18908691e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  8.33435059e-02,   8.33435059e-02],
                        [  1.14288330e-01,   1.14288330e-01],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  1.00402832e-02,   1.00402832e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  9.61303711e-03,   9.61303711e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [ -1.17797852e-02,  -1.17797852e-02],
                        [ -8.60900879e-02,  -8.60900879e-02],
                        [ -1.69097900e-01,  -1.69097900e-01],
                        [ -2.35443115e-01,  -2.35443115e-01],
                        [ -2.60559082e-01,  -2.60559082e-01],
                        [ -2.36968994e-01,  -2.36968994e-01],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -1.33239746e-01,  -1.33239746e-01],
                        [ -1.09741211e-01,  -1.09741211e-01],
                        [ -1.09130859e-01,  -1.09130859e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -1.02386475e-01,  -1.02386475e-01],
                        [ -8.60290527e-02,  -8.60290527e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -2.00805664e-02,  -2.00805664e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  7.69348145e-02,   7.69348145e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  1.08245850e-01,   1.08245850e-01],
                        [  1.13861084e-01,   1.13861084e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  4.91027832e-02,   4.91027832e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -1.68518066e-01,  -1.68518066e-01],
                        [ -1.79534912e-01,  -1.79534912e-01],
                        [ -1.46972656e-01,  -1.46972656e-01],
                        [ -9.86938477e-02,  -9.86938477e-02],
                        [ -6.51245117e-02,  -6.51245117e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -3.99169922e-02,  -3.99169922e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  1.53381348e-01,   1.53381348e-01],
                        [  1.72607422e-01,   1.72607422e-01],
                        [  1.67663574e-01,   1.67663574e-01],
                        [  1.48345947e-01,   1.48345947e-01],
                        [  1.30218506e-01,   1.30218506e-01],
                        [  1.22314453e-01,   1.22314453e-01],
                        [  1.20758057e-01,   1.20758057e-01],
                        [  1.17218018e-01,   1.17218018e-01],
                        [  1.10931396e-01,   1.10931396e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  1.03363037e-01,   1.03363037e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  9.11254883e-02,   9.11254883e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -5.32226562e-02,  -5.32226562e-02],
                        [ -6.61010742e-02,  -6.61010742e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  1.22253418e-01,   1.22253418e-01],
                        [  1.34918213e-01,   1.34918213e-01],
                        [  1.16424561e-01,   1.16424561e-01],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  6.07604980e-02,   6.07604980e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.54211426e-02,  -2.54211426e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -4.15039062e-02,  -4.15039062e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  5.46264648e-02,   5.46264648e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  5.17272949e-02,   5.17578125e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -2.15759277e-01,  -2.15759277e-01],
                        [ -2.72277832e-01,  -2.72277832e-01],
                        [ -2.79846191e-01,  -2.79846191e-01],
                        [ -2.43591309e-01,  -2.43591309e-01],
                        [ -1.90917969e-01,  -1.90917969e-01],
                        [ -1.47277832e-01,  -1.47277832e-01],
                        [ -1.17065430e-01,  -1.17065430e-01],
                        [ -9.13696289e-02,  -9.13696289e-02],
                        [ -6.64978027e-02,  -6.64978027e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  4.75769043e-02,   4.75769043e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  9.12780762e-02,   9.12780762e-02],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.08367920e-01,   1.08367920e-01],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -1.73126221e-01,  -1.73126221e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.36932373e-01,  -1.36932373e-01],
                        [ -9.51232910e-02,  -9.51232910e-02],
                        [ -6.40869141e-02,  -6.40869141e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -6.10046387e-02,  -6.10046387e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -4.73022461e-03,  -4.73022461e-03],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  8.01391602e-02,   8.01391602e-02],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.61437988e-01,   1.61437988e-01],
                        [  1.79748535e-01,   1.79748535e-01],
                        [  1.76055908e-01,   1.76055908e-01],
                        [  1.54785156e-01,   1.54785156e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.10656738e-01,   1.10656738e-01],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  1.07391357e-01,   1.07391357e-01],
                        [  1.10351562e-01,   1.10382080e-01],
                        [  1.13952637e-01,   1.13952637e-01],
                        [  1.17034912e-01,   1.17034912e-01],
                        [  1.13250732e-01,   1.13250732e-01],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [  1.95007324e-02,   1.95007324e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  1.05499268e-01,   1.05499268e-01],
                        [  1.11175537e-01,   1.11175537e-01],
                        [  9.04541016e-02,   9.04541016e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  5.02624512e-02,   5.02624512e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.05175781e-03,   3.05175781e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.90124512e-02,  -1.90124512e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -4.15649414e-02,  -4.15649414e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.13220215e-02,  -1.12915039e-02],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  2.25524902e-02,   2.25830078e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  5.21850586e-02,   5.21850586e-02],
                        [  2.31018066e-02,   2.31323242e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -1.91558838e-01,  -1.91558838e-01],
                        [ -2.55218506e-01,  -2.55218506e-01],
                        [ -2.76550293e-01,  -2.76550293e-01],
                        [ -2.51586914e-01,  -2.51586914e-01],
                        [ -1.99554443e-01,  -1.99554443e-01],
                        [ -1.49993896e-01,  -1.49993896e-01],
                        [ -1.21032715e-01,  -1.21032715e-01],
                        [ -1.08795166e-01,  -1.08795166e-01],
                        [ -9.93957520e-02,  -9.93957520e-02],
                        [ -8.65478516e-02,  -8.65478516e-02],
                        [ -7.39440918e-02,  -7.39440918e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.04150391e-02,   5.04150391e-02],
                        [  5.84411621e-02,   5.84411621e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  1.13494873e-01,   1.13494873e-01],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -1.49383545e-01,  -1.49383545e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.53472900e-01,  -1.53472900e-01],
                        [ -1.10107422e-01,  -1.10107422e-01],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -4.69360352e-02,  -4.69665527e-02],
                        [ -4.31213379e-02,  -4.30908203e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  9.83886719e-02,   9.83886719e-02],
                        [  1.39648438e-01,   1.39648438e-01],
                        [  1.68670654e-01,   1.68670654e-01],
                        [  1.75750732e-01,   1.75750732e-01],
                        [  1.59210205e-01,   1.59210205e-01],
                        [  1.28173828e-01,   1.28173828e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  8.88671875e-02,   8.88977051e-02],
                        [  1.02844238e-01,   1.02844238e-01],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  1.34216309e-01,   1.34216309e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.17156982e-01,   1.17156982e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  4.88586426e-02,   4.88586426e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -2.73742676e-02,  -2.73437500e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  2.10571289e-03,   2.10571289e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  4.15039062e-03,   4.15039062e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -3.76892090e-02,  -3.76892090e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.51660156e-02,  -4.51965332e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -1.32965088e-01,  -1.32965088e-01],
                        [ -2.07611084e-01,  -2.07611084e-01],
                        [ -2.54730225e-01,  -2.54730225e-01],
                        [ -2.59765625e-01,  -2.59765625e-01],
                        [ -2.27111816e-01,  -2.27111816e-01],
                        [ -1.77215576e-01,  -1.77215576e-01],
                        [ -1.32659912e-01,  -1.32659912e-01],
                        [ -1.06811523e-01,  -1.06811523e-01],
                        [ -9.96398926e-02,  -9.96398926e-02],
                        [ -1.00341797e-01,  -1.00341797e-01],
                        [ -9.71069336e-02,  -9.71069336e-02],
                        [ -8.57238770e-02,  -8.57238770e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -5.12084961e-02,  -5.12084961e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.49169922e-01,   1.49169922e-01],
                        [  1.51641846e-01,   1.51641846e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  5.35278320e-02,   5.35278320e-02],
                        [ -4.20532227e-02,  -4.20837402e-02],
                        [ -1.32202148e-01,  -1.32202148e-01],
                        [ -1.81762695e-01,  -1.81762695e-01],
                        [ -1.78009033e-01,  -1.78009033e-01],
                        [ -1.37145996e-01,  -1.37145996e-01],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -6.23168945e-02,  -6.23168945e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.69342041e-01,   1.69342041e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  2.02087402e-01,   2.02087402e-01],
                        [  1.75231934e-01,   1.75231934e-01],
                        [  1.39587402e-01,   1.39587402e-01],
                        [  1.12304688e-01,   1.12274170e-01],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  8.70971680e-02,   8.70971680e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.02111816e-01,   1.02111816e-01],
                        [  9.49707031e-02,   9.49707031e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  6.60095215e-02,   6.60095215e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  3.34472656e-02,   3.34167480e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -4.90722656e-02,  -4.90417480e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [  3.21044922e-02,   3.20739746e-02],
                        [  8.82568359e-02,   8.82568359e-02],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.26159668e-01,   1.26159668e-01],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  3.58886719e-02,   3.58581543e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.05590820e-02,   1.05895996e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  1.10778809e-02,   1.10473633e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -4.05883789e-03,  -4.02832031e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -3.08227539e-02,  -3.08532715e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -1.27532959e-01,  -1.27532959e-01],
                        [ -2.05474854e-01,  -2.05474854e-01],
                        [ -2.54852295e-01,  -2.54852295e-01],
                        [ -2.61108398e-01,  -2.61108398e-01],
                        [ -2.31781006e-01,  -2.31781006e-01],
                        [ -1.89056396e-01,  -1.89056396e-01],
                        [ -1.50909424e-01,  -1.50909424e-01],
                        [ -1.22009277e-01,  -1.22009277e-01],
                        [ -9.98535156e-02,  -9.98535156e-02],
                        [ -8.25500488e-02,  -8.25500488e-02],
                        [ -6.97326660e-02,  -6.97326660e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  1.25305176e-01,   1.25305176e-01],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  6.46972656e-03,   6.43920898e-03],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -1.52038574e-01,  -1.52038574e-01],
                        [ -1.81213379e-01,  -1.81213379e-01],
                        [ -1.67419434e-01,  -1.67419434e-01],
                        [ -1.30889893e-01,  -1.30859375e-01],
                        [ -9.67407227e-02,  -9.67407227e-02],
                        [ -7.66601562e-02,  -7.66601562e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -5.23071289e-02,  -5.23071289e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -2.06604004e-02,  -2.06604004e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  7.07397461e-02,   7.07702637e-02],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  1.59912109e-01,   1.59912109e-01],
                        [  1.83471680e-01,   1.83471680e-01],
                        [  1.86523438e-01,   1.86523438e-01],
                        [  1.71600342e-01,   1.71600342e-01],
                        [  1.46728516e-01,   1.46697998e-01],
                        [  1.19506836e-01,   1.19506836e-01],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  7.50427246e-02,   7.50122070e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  6.86340332e-02,   6.86035156e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  9.75341797e-02,   9.75341797e-02],
                        [  9.18579102e-02,   9.18273926e-02],
                        [  8.19091797e-02,   8.19091797e-02],
                        [  7.22656250e-02,   7.22656250e-02],
                        [  6.01196289e-02,   6.00891113e-02],
                        [  4.30603027e-02,   4.30908203e-02],
                        [  2.60925293e-02,   2.61230469e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -3.01818848e-02,  -3.02124023e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -1.10168457e-02,  -1.09863281e-02],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -3.34777832e-02,  -3.35083008e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.93371582e-02,  -3.93676758e-02],
                        [ -3.63769531e-02,  -3.64074707e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -9.89685059e-02,  -9.89685059e-02],
                        [ -1.68579102e-01,  -1.68579102e-01],
                        [ -2.20642090e-01,  -2.20642090e-01],
                        [ -2.37274170e-01,  -2.37274170e-01],
                        [ -2.20581055e-01,  -2.20581055e-01],
                        [ -1.87377930e-01,  -1.87377930e-01],
                        [ -1.54998779e-01,  -1.54998779e-01],
                        [ -1.31408691e-01,  -1.31378174e-01],
                        [ -1.14807129e-01,  -1.14807129e-01],
                        [ -9.93957520e-02,  -9.94262695e-02],
                        [ -8.25500488e-02,  -8.25500488e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  3.90930176e-02,   3.90930176e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  7.48291016e-02,   7.48291016e-02],
                        [  8.23364258e-02,   8.23364258e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.17065430e-01,   1.17065430e-01],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  1.95922852e-02,   1.95922852e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -1.49719238e-01,  -1.49749756e-01],
                        [ -1.91253662e-01,  -1.91253662e-01],
                        [ -1.82464600e-01,  -1.82464600e-01],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -9.24377441e-02,  -9.24377441e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -3.82690430e-02,  -3.82385254e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -4.03747559e-02,  -4.03442383e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -3.45153809e-02,  -3.44848633e-02],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  1.02935791e-01,   1.02935791e-01],
                        [  1.46850586e-01,   1.46881104e-01],
                        [  1.70440674e-01,   1.70410156e-01],
                        [  1.71051025e-01,   1.71051025e-01],
                        [  1.53808594e-01,   1.53808594e-01],
                        [  1.26800537e-01,   1.26800537e-01],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  8.30993652e-02,   8.31298828e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  9.16137695e-02,   9.15832520e-02],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  8.83178711e-02,   8.83178711e-02],
                        [  7.38525391e-02,   7.38525391e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  5.32531738e-02,   5.32531738e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  1.62353516e-02,   1.62353516e-02],
                        [  8.91113281e-03,   8.94165039e-03],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -5.81665039e-02,  -5.81665039e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  7.58361816e-02,   7.58361816e-02],
                        [  1.09832764e-01,   1.09832764e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  8.30078125e-02,   8.30078125e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -2.44140625e-03,  -2.41088867e-03],
                        [ -9.49096680e-03,  -9.52148438e-03],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -3.43933105e-02,  -3.43933105e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.02526855e-02,  -4.02832031e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -4.25109863e-02,  -4.25415039e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -1.20574951e-01,  -1.20605469e-01],
                        [ -1.97418213e-01,  -1.97418213e-01],
                        [ -2.49694824e-01,  -2.49694824e-01],
                        [ -2.63397217e-01,  -2.63397217e-01],
                        [ -2.43621826e-01,  -2.43621826e-01],
                        [ -2.07794189e-01,  -2.07794189e-01],
                        [ -1.70471191e-01,  -1.70501709e-01],
                        [ -1.36444092e-01,  -1.36444092e-01],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -8.50219727e-02,  -8.49914551e-02],
                        [ -7.51647949e-02,  -7.51647949e-02],
                        [ -7.32116699e-02,  -7.32116699e-02],
                        [ -6.95800781e-02,  -6.95495605e-02],
                        [ -5.85937500e-02,  -5.85937500e-02],
                        [ -4.16870117e-02,  -4.17175293e-02],
                        [ -2.13012695e-02,  -2.12707520e-02],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  2.22473145e-02,   2.22167969e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  4.53796387e-02,   4.54101562e-02],
                        [  4.84313965e-02,   4.84008789e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  5.04760742e-02,   5.05065918e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  8.44421387e-02,   8.44116211e-02],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.27624512e-01,   1.27655029e-01],
                        [  1.20758057e-01,   1.20727539e-01],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  9.58251953e-03,   9.61303711e-03],
                        [ -7.87353516e-02,  -7.87353516e-02],
                        [ -1.55853271e-01,  -1.55853271e-01],
                        [ -1.92626953e-01,  -1.92626953e-01],
                        [ -1.78192139e-01,  -1.78192139e-01],
                        [ -1.29119873e-01,  -1.29119873e-01],
                        [ -7.66296387e-02,  -7.66296387e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -6.31103516e-02,  -6.30798340e-02],
                        [ -5.59082031e-02,  -5.59082031e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [  2.08435059e-02,   2.08740234e-02],
                        [  8.38317871e-02,   8.38317871e-02],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.70959473e-01,   1.70989990e-01],
                        [  1.76727295e-01,   1.76727295e-01],
                        [  1.62658691e-01,   1.62658691e-01],
                        [  1.41845703e-01,   1.41845703e-01],
                        [  1.24786377e-01,   1.24816895e-01],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.88171387e-02,   6.88476562e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  4.36401367e-02,   4.36706543e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -3.48815918e-02,  -3.48510742e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  1.08001709e-01,   1.08001709e-01],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  4.35485840e-02,   4.35791016e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  2.52990723e-02,   2.52685547e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.96020508e-03,   2.96020508e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.71704102e-02,  -3.71704102e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.35595703e-02,  -2.35290527e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -4.06494141e-02,  -4.06799316e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.94396973e-02,   1.94396973e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  4.56237793e-02,   4.55932617e-02],
                        [  5.08117676e-02,   5.08117676e-02],
                        [  4.80651855e-02,   4.80957031e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -7.38525391e-02,  -7.38525391e-02],
                        [ -1.52374268e-01,  -1.52374268e-01],
                        [ -2.21038818e-01,  -2.21038818e-01],
                        [ -2.58148193e-01,  -2.58148193e-01],
                        [ -2.55401611e-01,  -2.55401611e-01],
                        [ -2.22259521e-01,  -2.22259521e-01],
                        [ -1.79534912e-01,  -1.79565430e-01],
                        [ -1.45141602e-01,  -1.45141602e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -1.08520508e-01,  -1.08520508e-01],
                        [ -9.24682617e-02,  -9.24682617e-02],
                        [ -7.21130371e-02,  -7.21130371e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  6.02416992e-02,   6.02416992e-02],
                        [  6.85424805e-02,   6.85729980e-02],
                        [  7.48901367e-02,   7.48901367e-02],
                        [  8.03833008e-02,   8.03833008e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  9.97924805e-02,   9.97924805e-02],
                        [  1.08154297e-01,   1.08154297e-01],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -1.29516602e-01,  -1.29516602e-01],
                        [ -1.62506104e-01,  -1.62506104e-01],
                        [ -1.52984619e-01,  -1.52984619e-01],
                        [ -1.18072510e-01,  -1.18041992e-01],
                        [ -8.44116211e-02,  -8.44421387e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.68945312e-02,  -6.68945312e-02],
                        [ -7.04650879e-02,  -7.04650879e-02],
                        [ -7.23876953e-02,  -7.24182129e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [  1.36108398e-02,   1.35803223e-02],
                        [  7.15332031e-02,   7.15332031e-02],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.67602539e-01,   1.67602539e-01],
                        [  1.84600830e-01,   1.84600830e-01],
                        [  1.79077148e-01,   1.79077148e-01],
                        [  1.60980225e-01,   1.60949707e-01],
                        [  1.41998291e-01,   1.42028809e-01],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  8.49304199e-02,   8.49609375e-02],
                        [  8.12377930e-02,   8.12072754e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  7.89184570e-02,   7.89489746e-02],
                        [  7.17773438e-02,   7.17468262e-02],
                        [  5.97839355e-02,   5.97534180e-02],
                        [  4.95910645e-02,   4.96215820e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  4.73327637e-02,   4.73632812e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [ -3.32946777e-02,  -3.32946777e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -5.37109375e-02,  -5.37109375e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  7.13195801e-02,   7.13195801e-02],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  1.08215332e-01,   1.08215332e-01],
                        [  8.97827148e-02,   8.97827148e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  1.59301758e-02,   1.58996582e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  1.19628906e-02,   1.19934082e-02],
                        [  7.35473633e-03,   7.32421875e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.06811523e-02,   1.06506348e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  4.08935547e-03,   4.08935547e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -2.59399414e-02,  -2.59704590e-02],
                        [ -1.73034668e-02,  -1.73034668e-02],
                        [ -1.48315430e-02,  -1.48010254e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.27966309e-02,  -2.27661133e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.97851562e-02,  -2.97546387e-02],
                        [ -3.91235352e-02,  -3.90930176e-02],
                        [ -4.26330566e-02,  -4.26635742e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.96020508e-02,  -2.96020508e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  5.80139160e-02,   5.80139160e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [ -2.75573730e-02,  -2.75573730e-02],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -1.87805176e-01,  -1.87805176e-01],
                        [ -2.49725342e-01,  -2.49694824e-01],
                        [ -2.70355225e-01,  -2.70355225e-01],
                        [ -2.49572754e-01,  -2.49572754e-01],
                        [ -2.05718994e-01,  -2.05718994e-01],
                        [ -1.60217285e-01,  -1.60217285e-01],
                        [ -1.25213623e-01,  -1.25244141e-01],
                        [ -1.02447510e-01,  -1.02447510e-01],
                        [ -8.83178711e-02,  -8.82873535e-02],
                        [ -7.80639648e-02,  -7.80639648e-02],
                        [ -6.85424805e-02,  -6.85119629e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  7.58666992e-02,   7.58361816e-02],
                        [  9.42687988e-02,   9.42687988e-02],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  1.35894775e-01,   1.35864258e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -1.64276123e-01,  -1.64245605e-01],
                        [ -2.00347900e-01,  -2.00347900e-01],
                        [ -1.85943604e-01,  -1.85943604e-01],
                        [ -1.42852783e-01,  -1.42852783e-01],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -8.05664062e-02,  -8.05664062e-02],
                        [ -7.13195801e-02,  -7.13195801e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  8.55712891e-02,   8.55407715e-02],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.67755127e-01,   1.67785645e-01],
                        [  1.77307129e-01,   1.77276611e-01],
                        [  1.60827637e-01,   1.60827637e-01],
                        [  1.30554199e-01,   1.30584717e-01],
                        [  1.04827881e-01,   1.04797363e-01],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  9.11865234e-02,   9.11865234e-02],
                        [  8.84704590e-02,   8.84399414e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  6.75354004e-02,   6.75048828e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  3.79028320e-02,   3.78723145e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  7.47680664e-03,   7.47680664e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  4.09851074e-02,   4.09851074e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  5.49621582e-02,   5.49621582e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.86462402e-02,  -1.86157227e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -1.75170898e-02,  -1.75476074e-02],
                        [ -1.45874023e-02,  -1.45568848e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.95715332e-02,  -2.96020508e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.23291016e-02,  -1.22985840e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  6.77795410e-02,   6.78100586e-02],
                        [  8.72497559e-02,   8.72497559e-02],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -1.07055664e-01,  -1.07055664e-01],
                        [ -1.99310303e-01,  -1.99340820e-01],
                        [ -2.64984131e-01,  -2.64984131e-01],
                        [ -2.86621094e-01,  -2.86621094e-01],
                        [ -2.60375977e-01,  -2.60375977e-01],
                        [ -2.03552246e-01,  -2.03552246e-01],
                        [ -1.49322510e-01,  -1.49322510e-01],
                        [ -1.20880127e-01,  -1.20880127e-01],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -1.04858398e-01,  -1.04827881e-01],
                        [ -8.76464844e-02,  -8.76159668e-02],
                        [ -6.90917969e-02,  -6.91223145e-02],
                        [ -5.63354492e-02,  -5.63049316e-02],
                        [ -4.62646484e-02,  -4.62646484e-02],
                        [ -3.47900391e-02,  -3.47900391e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  4.11071777e-02,   4.10766602e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  9.81140137e-02,   9.81140137e-02],
                        [  1.17889404e-01,   1.17889404e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  5.53894043e-02,   5.53894043e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -1.62414551e-01,  -1.62414551e-01],
                        [ -1.76330566e-01,  -1.76330566e-01],
                        [ -1.54327393e-01,  -1.54327393e-01],
                        [ -1.19506836e-01,  -1.19506836e-01],
                        [ -9.43298340e-02,  -9.43603516e-02],
                        [ -8.47778320e-02,  -8.47778320e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  1.00494385e-01,   1.00494385e-01],
                        [  1.43463135e-01,   1.43493652e-01],
                        [  1.60827637e-01,   1.60827637e-01],
                        [  1.52252197e-01,   1.52252197e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  8.17871094e-02,   8.17871094e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  6.96411133e-02,   6.96716309e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  3.65295410e-02,   3.65295410e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  3.99780273e-02,   3.99475098e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.63256836e-02,   4.63256836e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -3.14331055e-02,  -3.14331055e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  3.85437012e-02,   3.85131836e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  9.16137695e-02,   9.16442871e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  4.46472168e-02,   4.46777344e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  4.15344238e-02,   4.15344238e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [ -9.46044922e-04,  -9.76562500e-04],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.44543457e-02,  -3.44543457e-02],
                        [ -3.66821289e-02,  -3.66516113e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -2.00805664e-02,  -2.01110840e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -3.26232910e-02,  -3.25927734e-02],
                        [ -4.04052734e-02,  -4.04357910e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -2.38037109e-03,  -2.34985352e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  5.70678711e-03,   5.70678711e-03],
                        [  1.27868652e-02,   1.28173828e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  4.31213379e-02,   4.30908203e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  3.28369141e-02,   3.28063965e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.08306885e-01,  -1.08306885e-01],
                        [ -2.02056885e-01,  -2.02056885e-01],
                        [ -2.73712158e-01,  -2.73712158e-01],
                        [ -2.94891357e-01,  -2.94891357e-01],
                        [ -2.61993408e-01,  -2.62023926e-01],
                        [ -2.00592041e-01,  -2.00622559e-01],
                        [ -1.45812988e-01,  -1.45812988e-01],
                        [ -1.17065430e-01,  -1.17065430e-01],
                        [ -1.08337402e-01,  -1.08367920e-01],
                        [ -1.00189209e-01,  -1.00189209e-01],
                        [ -8.10546875e-02,  -8.10546875e-02],
                        [ -5.75256348e-02,  -5.75256348e-02],
                        [ -4.28466797e-02,  -4.28771973e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  1.19934082e-02,   1.19628906e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  6.31103516e-02,   6.31103516e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  1.07177734e-01,   1.07177734e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.39556885e-01,   1.39556885e-01],
                        [  1.24023438e-01,   1.24023438e-01],
                        [  6.99462891e-02,   6.99462891e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.11572266e-01,  -1.11572266e-01],
                        [ -1.79595947e-01,  -1.79565430e-01],
                        [ -2.00378418e-01,  -2.00378418e-01],
                        [ -1.77886963e-01,  -1.77886963e-01],
                        [ -1.36047363e-01,  -1.36047363e-01],
                        [ -1.01409912e-01,  -1.01409912e-01],
                        [ -8.47167969e-02,  -8.47167969e-02],
                        [ -7.55920410e-02,  -7.55920410e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -1.97143555e-02,  -1.97448730e-02],
                        [  2.95715332e-02,   2.96020508e-02],
                        [  7.88269043e-02,   7.88269043e-02],
                        [  1.16546631e-01,   1.16546631e-01],
                        [  1.37756348e-01,   1.37756348e-01],
                        [  1.43463135e-01,   1.43463135e-01],
                        [  1.38000488e-01,   1.38000488e-01],
                        [  1.27502441e-01,   1.27502441e-01],
                        [  1.18072510e-01,   1.18072510e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.10900879e-01,   1.10900879e-01],
                        [  1.06231689e-01,   1.06231689e-01],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  2.52990723e-02,   2.52685547e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  4.18090820e-02,   4.18090820e-02],
                        [  4.50744629e-02,   4.50744629e-02],
                        [  4.40979004e-02,   4.40673828e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.69970703e-02,   4.70275879e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  3.87573242e-02,   3.87573242e-02],
                        [  1.26953125e-02,   1.26953125e-02],
                        [ -1.85546875e-02,  -1.85852051e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -5.12084961e-02,  -5.11779785e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  1.05560303e-01,   1.05560303e-01],
                        [  9.39331055e-02,   9.39331055e-02],
                        [  6.63146973e-02,   6.62841797e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -1.02844238e-02,  -1.03149414e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -1.60522461e-02,  -1.60827637e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.17687988e-02,  -3.17687988e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  3.72009277e-02,   3.72009277e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  6.37817383e-02,   6.37817383e-02],
                        [  6.69860840e-02,   6.69860840e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -1.07452393e-01,  -1.07452393e-01],
                        [ -1.97570801e-01,  -1.97570801e-01],
                        [ -2.64770508e-01,  -2.64770508e-01],
                        [ -2.89886475e-01,  -2.89916992e-01],
                        [ -2.70324707e-01,  -2.70324707e-01],
                        [ -2.20764160e-01,  -2.20764160e-01],
                        [ -1.66015625e-01,  -1.66015625e-01],
                        [ -1.25335693e-01,  -1.25335693e-01],
                        [ -1.02020264e-01,  -1.01989746e-01],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -8.32214355e-02,  -8.32214355e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -4.21142578e-02,  -4.21447754e-02],
                        [ -2.38952637e-02,  -2.38952637e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  3.43322754e-02,   3.43017578e-02],
                        [  4.65393066e-02,   4.65698242e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  1.42761230e-01,   1.42761230e-01],
                        [  1.61315918e-01,   1.61315918e-01],
                        [  1.54510498e-01,   1.54479980e-01],
                        [  1.12182617e-01,   1.12182617e-01],
                        [  3.30505371e-02,   3.30505371e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -1.61529541e-01,  -1.61529541e-01],
                        [ -2.14599609e-01,  -2.14569092e-01],
                        [ -2.12463379e-01,  -2.12463379e-01],
                        [ -1.69403076e-01,  -1.69403076e-01],
                        [ -1.15509033e-01,  -1.15478516e-01],
                        [ -7.11364746e-02,  -7.11364746e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  5.82580566e-02,   5.82580566e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.26861572e-01,   1.26892090e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  8.83178711e-02,   8.83178711e-02],
                        [  8.30383301e-02,   8.30383301e-02],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  9.00268555e-02,   9.00573730e-02],
                        [  8.18176270e-02,   8.18176270e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  5.22155762e-02,   5.22460938e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  3.41186523e-02,   3.41186523e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  4.17785645e-02,   4.17785645e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  4.76989746e-02,   4.76989746e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.82678223e-02,  -6.82678223e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -3.70788574e-02,  -3.70788574e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  1.14013672e-01,   1.14013672e-01],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  6.07910156e-02,   6.08215332e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  2.70080566e-02,   2.70385742e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  2.16674805e-03,   2.16674805e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.34582520e-02,  -1.34887695e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -3.55224609e-02,  -3.54919434e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -1.60522461e-02,  -1.60827637e-02],
                        [ -9.73510742e-03,  -9.70458984e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -8.36181641e-03,  -8.39233398e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -8.51440430e-03,  -8.48388672e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  2.46582031e-02,   2.46276855e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  5.14526367e-02,   5.14831543e-02],
                        [  4.59899902e-02,   4.59899902e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -1.40472412e-01,  -1.40472412e-01],
                        [ -1.97906494e-01,  -1.97906494e-01],
                        [ -2.34649658e-01,  -2.34649658e-01],
                        [ -2.41058350e-01,  -2.41058350e-01],
                        [ -2.17163086e-01,  -2.17132568e-01],
                        [ -1.78924561e-01,  -1.78924561e-01],
                        [ -1.49993896e-01,  -1.49993896e-01],
                        [ -1.39068604e-01,  -1.39068604e-01],
                        [ -1.33605957e-01,  -1.33605957e-01],
                        [ -1.19110107e-01,  -1.19110107e-01],
                        [ -9.43908691e-02,  -9.43908691e-02],
                        [ -6.68945312e-02,  -6.68640137e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -2.95715332e-02,  -2.96020508e-02],
                        [ -2.37731934e-02,  -2.37426758e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.83105469e-02,  -1.83410645e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  1.55639648e-03,   1.58691406e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  2.78625488e-02,   2.78320312e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  5.21240234e-02,   5.21545410e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  1.21704102e-01,   1.21704102e-01],
                        [  1.38854980e-01,   1.38824463e-01],
                        [  1.38305664e-01,   1.38305664e-01],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  2.92053223e-02,   2.91748047e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -1.61590576e-01,  -1.61560059e-01],
                        [ -2.06573486e-01,  -2.06573486e-01],
                        [ -1.92169189e-01,  -1.92169189e-01],
                        [ -1.34490967e-01,  -1.34490967e-01],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  3.62243652e-02,   3.61938477e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  7.25097656e-02,   7.25097656e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  7.27539062e-02,   7.27233887e-02],
                        [  6.64978027e-02,   6.65283203e-02],
                        [  6.79321289e-02,   6.79321289e-02],
                        [  7.67822266e-02,   7.67822266e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  1.02081299e-01,   1.02081299e-01],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  7.60498047e-02,   7.60498047e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.94799805e-02,   2.94494629e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  4.07714844e-02,   4.07409668e-02],
                        [  4.24499512e-02,   4.24804688e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [ -6.10351562e-05,  -3.05175781e-05],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -5.69458008e-02,  -5.69763184e-02],
                        [ -6.53686523e-02,  -6.53686523e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  9.69238281e-02,   9.68933105e-02],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  7.97424316e-02,   7.97424316e-02],
                        [  5.43518066e-02,   5.43518066e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.19519043e-02,   3.19519043e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.85241699e-02,  -1.84936523e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -1.25427246e-02,  -1.25732422e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.03552246e-02,  -2.03247070e-02],
                        [ -1.93176270e-02,  -1.93481445e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.17492676e-02,  -1.17187500e-02],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.82495117e-02,   1.82189941e-02],
                        [  1.69067383e-02,   1.69067383e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -4.59594727e-02,  -4.59594727e-02],
                        [ -8.28247070e-02,  -8.28247070e-02],
                        [ -1.18957520e-01,  -1.18957520e-01],
                        [ -1.48559570e-01,  -1.48559570e-01],
                        [ -1.67327881e-01,  -1.67327881e-01],
                        [ -1.73950195e-01,  -1.73950195e-01],
                        [ -1.72180176e-01,  -1.72180176e-01],
                        [ -1.68273926e-01,  -1.68273926e-01],
                        [ -1.65313721e-01,  -1.65313721e-01],
                        [ -1.61193848e-01,  -1.61193848e-01],
                        [ -1.51000977e-01,  -1.51000977e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -7.58972168e-02,  -7.58972168e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -3.10363770e-02,  -3.10058594e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -8.78906250e-03,  -8.81958008e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  4.42504883e-03,   4.39453125e-03],
                        [  7.47680664e-03,   7.50732422e-03],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  6.98852539e-03,   6.95800781e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  3.37829590e-02,   3.37829590e-02],
                        [  5.32836914e-02,   5.32836914e-02],
                        [  6.96105957e-02,   6.96411133e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.20178223e-01,   1.20178223e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  4.53796387e-02,   4.53796387e-02],
                        [ -3.72314453e-02,  -3.72314453e-02],
                        [ -1.24114990e-01,  -1.24145508e-01],
                        [ -1.84570312e-01,  -1.84570312e-01],
                        [ -1.93878174e-01,  -1.93878174e-01],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -8.68225098e-02,  -8.68225098e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  7.44934082e-02,   7.44934082e-02],
                        [  6.89086914e-02,   6.89086914e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  6.20422363e-02,   6.20422363e-02],
                        [  6.90002441e-02,   6.90002441e-02],
                        [  8.02001953e-02,   8.02001953e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  8.21228027e-02,   8.21228027e-02],
                        [  6.61621094e-02,   6.61621094e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  3.48815918e-02,   3.48510742e-02],
                        [  3.21044922e-02,   3.21350098e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.45556641e-02,  -4.45556641e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  9.50622559e-02,   9.50622559e-02],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  6.79626465e-02,   6.79931641e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  1.00708008e-02,   1.00402832e-02],
                        [  3.63159180e-03,   3.63159180e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.41601562e-02,  -1.41296387e-02],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -2.10571289e-03,  -2.07519531e-03],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.13830566e-02,   1.14135742e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -4.97131348e-02,  -4.97131348e-02],
                        [ -9.61914062e-02,  -9.61914062e-02],
                        [ -1.47583008e-01,  -1.47583008e-01],
                        [ -1.94305420e-01,  -1.94305420e-01],
                        [ -2.22320557e-01,  -2.22320557e-01],
                        [ -2.24060059e-01,  -2.24060059e-01],
                        [ -2.05139160e-01,  -2.05139160e-01],
                        [ -1.78466797e-01,  -1.78466797e-01],
                        [ -1.52801514e-01,  -1.52801514e-01],
                        [ -1.27746582e-01,  -1.27777100e-01],
                        [ -9.95788574e-02,  -9.95788574e-02],
                        [ -7.11364746e-02,  -7.11059570e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  1.71203613e-02,   1.71508789e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  3.51562500e-02,   3.51562500e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.80761719e-02,   2.81066895e-02],
                        [  3.88183594e-02,   3.88183594e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  7.97424316e-02,   7.97424316e-02],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.43463135e-01,   1.43463135e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  9.01794434e-02,   9.01794434e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [ -7.37304688e-02,  -7.36999512e-02],
                        [ -1.47003174e-01,  -1.47003174e-01],
                        [ -1.73461914e-01,  -1.73461914e-01],
                        [ -1.43280029e-01,  -1.43280029e-01],
                        [ -7.66601562e-02,  -7.66601562e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  6.73522949e-02,   6.73522949e-02],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  3.14636230e-02,   3.14941406e-02],
                        [  4.56542969e-02,   4.56542969e-02],
                        [  6.45751953e-02,   6.45751953e-02],
                        [  7.37609863e-02,   7.37609863e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  3.36914062e-02,   3.36914062e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  3.20129395e-02,   3.20129395e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.04553223e-01,   1.04553223e-01],
                        [  8.37707520e-02,   8.37707520e-02],
                        [  6.50329590e-02,   6.50329590e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -6.95800781e-03,  -6.95800781e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  5.44738770e-02,   5.44738770e-02],
                        [  6.66503906e-02,   6.66503906e-02],
                        [  7.29980469e-02,   7.29980469e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -1.38977051e-01,  -1.38977051e-01],
                        [ -2.11730957e-01,  -2.11730957e-01],
                        [ -2.56469727e-01,  -2.56469727e-01],
                        [ -2.67272949e-01,  -2.67272949e-01],
                        [ -2.46826172e-01,  -2.46826172e-01],
                        [ -2.06878662e-01,  -2.06878662e-01],
                        [ -1.64306641e-01,  -1.64306641e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -1.08703613e-01,  -1.08703613e-01],
                        [ -9.29565430e-02,  -9.29565430e-02],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -7.79113770e-02,  -7.79113770e-02],
                        [ -7.63854980e-02,  -7.63854980e-02],
                        [ -6.97937012e-02,  -6.97631836e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  5.34057617e-03,   5.34057617e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  7.90405273e-03,   7.90405273e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  3.21960449e-02,   3.21960449e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  1.23840332e-01,   1.23840332e-01],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.13677979e-01,   1.13677979e-01],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -1.08917236e-01,  -1.08917236e-01],
                        [ -1.04675293e-01,  -1.04675293e-01],
                        [ -5.76477051e-02,  -5.76477051e-02],
                        [  2.68554688e-03,   2.68554688e-03],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  5.45349121e-02,   5.45349121e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  4.29992676e-02,   4.29992676e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [  4.18090820e-03,   4.18090820e-03],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.21673584e-01,   1.21673584e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  3.11279297e-03,   3.14331055e-03],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.46789551e-02,  -1.46789551e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.18200684e-02,  -2.18200684e-02],
                        [ -1.08642578e-02,  -1.08642578e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  5.55725098e-02,   5.55725098e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -1.12060547e-01,  -1.12060547e-01],
                        [ -1.88568115e-01,  -1.88568115e-01],
                        [ -2.38494873e-01,  -2.38525391e-01],
                        [ -2.51495361e-01,  -2.51495361e-01],
                        [ -2.32940674e-01,  -2.32940674e-01],
                        [ -1.98730469e-01,  -1.98730469e-01],
                        [ -1.64825439e-01,  -1.64825439e-01],
                        [ -1.40686035e-01,  -1.40686035e-01],
                        [ -1.26800537e-01,  -1.26800537e-01],
                        [ -1.15539551e-01,  -1.15539551e-01],
                        [ -1.00585938e-01,  -1.00585938e-01],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -6.06384277e-02,  -6.06384277e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -1.92260742e-02,  -1.92260742e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.97131348e-02,   4.97131348e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  7.97729492e-02,   7.97729492e-02],
                        [  9.91516113e-02,   9.91516113e-02],
                        [  1.18652344e-01,   1.18652344e-01],
                        [  1.31439209e-01,   1.31439209e-01],
                        [  1.24877930e-01,   1.24877930e-01],
                        [  8.94165039e-02,   8.94165039e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  3.57055664e-03,   3.57055664e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -1.83715820e-02,  -1.83715820e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  5.90820312e-02,   5.90820312e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  1.58996582e-02,   1.58996582e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -1.03668213e-01,  -1.03668213e-01],
                        [ -1.75415039e-01,  -1.75415039e-01],
                        [ -2.31933594e-01,  -2.31933594e-01],
                        [ -2.53540039e-01,  -2.53540039e-01],
                        [ -2.37304688e-01,  -2.37304688e-01],
                        [ -2.00683594e-01,  -2.00683594e-01],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -1.26342773e-01,  -1.26342773e-01],
                        [ -1.09558105e-01,  -1.09558105e-01],
                        [ -9.32617188e-02,  -9.32617188e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -7.32116699e-02,  -7.32116699e-02],
                        [ -6.52770996e-02,  -6.52770996e-02],
                        [ -5.67321777e-02,  -5.67321777e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [ -4.51660156e-03,  -4.51660156e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.18988037e-01,   1.18988037e-01],
                        [  1.42303467e-01,   1.42303467e-01],
                        [  1.56250000e-01,   1.56250000e-01],
                        [  1.50482178e-01,   1.50482178e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  5.38330078e-02,   5.38330078e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -8.73107910e-02,  -8.73107910e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  5.54199219e-02,   5.54199219e-02],
                        [  5.64575195e-02,   5.64575195e-02],
                        [  5.25512695e-02,   5.25512695e-02],
                        [  4.00085449e-02,   4.00085449e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  1.37939453e-02,   1.37939453e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  1.32293701e-01,   1.32293701e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.55126953e-02,   2.55126953e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -1.19689941e-01,  -1.19689941e-01],
                        [ -1.91864014e-01,  -1.91864014e-01],
                        [ -2.45117188e-01,  -2.45117188e-01],
                        [ -2.65502930e-01,  -2.65502930e-01],
                        [ -2.50030518e-01,  -2.50030518e-01],
                        [ -2.10449219e-01,  -2.10449219e-01],
                        [ -1.66870117e-01,  -1.66870117e-01],
                        [ -1.34429932e-01,  -1.34429932e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -1.02600098e-01,  -1.02600098e-01],
                        [ -8.77990723e-02,  -8.77990723e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -2.68249512e-02,  -2.68249512e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  6.13403320e-03,   6.13403320e-03],
                        [  2.04467773e-03,   2.04467773e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  4.65698242e-02,   4.65698242e-02],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.73004150e-01,   1.73004150e-01],
                        [  2.10418701e-01,   2.10418701e-01],
                        [  2.21557617e-01,   2.21557617e-01],
                        [  1.89147949e-01,   1.89147949e-01],
                        [  1.11541748e-01,   1.11541748e-01],
                        [  1.18408203e-02,   1.18408203e-02],
                        [ -7.05871582e-02,  -7.05871582e-02],
                        [ -1.05407715e-01,  -1.05407715e-01],
                        [ -9.15527344e-02,  -9.15527344e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.23083496e-02,  -2.23083496e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  2.92968750e-03,   2.92968750e-03],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.49523926e-02,  -4.49523926e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  7.96203613e-02,   7.96203613e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.06933594e-01,   1.06933594e-01],
                        [  8.13598633e-02,   8.13598633e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  4.57763672e-03,   4.57763672e-03],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  8.26721191e-02,   8.26721191e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  3.75366211e-02,   3.75366211e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -9.87548828e-02,  -9.87548828e-02],
                        [ -1.81976318e-01,  -1.81976318e-01],
                        [ -2.50701904e-01,  -2.50701904e-01],
                        [ -2.82623291e-01,  -2.82623291e-01],
                        [ -2.67486572e-01,  -2.67486572e-01],
                        [ -2.21466064e-01,  -2.21466064e-01],
                        [ -1.77001953e-01,  -1.77001953e-01],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -1.09436035e-01,  -1.09436035e-01],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -7.66906738e-02,  -7.66906738e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -6.75354004e-02,  -6.75354004e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  6.04248047e-03,   6.04248047e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  1.14227295e-01,   1.14227295e-01],
                        [  1.64123535e-01,   1.64123535e-01],
                        [  2.15301514e-01,   2.15301514e-01],
                        [  2.57110596e-01,   2.57110596e-01],
                        [  2.75268555e-01,   2.75268555e-01],
                        [  2.52197266e-01,   2.52197266e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  6.36291504e-02,   6.36291504e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -1.22070312e-01,  -1.22070312e-01],
                        [ -1.40869141e-01,  -1.40869141e-01],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -7.78503418e-02,  -7.78503418e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -1.15966797e-03,  -1.15966797e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  2.41088867e-03,   2.41088867e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -3.30810547e-02,  -3.30810547e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  1.04644775e-01,   1.04644775e-01],
                        [  1.11267090e-01,   1.11267090e-01],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.52685547e-02,  -2.52685547e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.12579346e-01,   1.12579346e-01],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -1.72454834e-01,  -1.72454834e-01],
                        [ -2.49420166e-01,  -2.49420166e-01],
                        [ -2.85919189e-01,  -2.85919189e-01],
                        [ -2.70782471e-01,  -2.70782471e-01],
                        [ -2.23663330e-01,  -2.23663330e-01],
                        [ -1.76666260e-01,  -1.76666260e-01],
                        [ -1.48986816e-01,  -1.48986816e-01],
                        [ -1.37115479e-01,  -1.37115479e-01],
                        [ -1.26220703e-01,  -1.26220703e-01],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -8.41369629e-02,  -8.41369629e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.51672363e-02,  -1.51672363e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  6.80541992e-02,   6.80541992e-02],
                        [  1.39251709e-01,   1.39251709e-01],
                        [  2.16644287e-01,   2.16644287e-01],
                        [  2.79846191e-01,   2.79846191e-01],
                        [  3.15002441e-01,   3.15002441e-01],
                        [  3.14636230e-01,   3.14636230e-01],
                        [  2.71148682e-01,   2.71148682e-01],
                        [  1.81640625e-01,   1.81640625e-01],
                        [  6.01196289e-02,   6.01196289e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -1.44317627e-01,  -1.44317627e-01],
                        [ -1.66534424e-01,  -1.66534424e-01],
                        [ -1.34796143e-01,  -1.34796143e-01],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  3.80249023e-02,   3.80249023e-02],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.74548340e-02,   4.74548340e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  1.20208740e-01,   1.20208740e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  8.23974609e-04,   8.23974609e-04],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -2.31018066e-02,  -2.31018066e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [  9.49096680e-03,   9.49096680e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  8.65478516e-02,   8.65478516e-02],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -1.42242432e-01,  -1.42242432e-01],
                        [ -2.21099854e-01,  -2.21099854e-01],
                        [ -2.78991699e-01,  -2.78991699e-01],
                        [ -2.89062500e-01,  -2.89062500e-01],
                        [ -2.50274658e-01,  -2.50274658e-01],
                        [ -1.90460205e-01,  -1.90460205e-01],
                        [ -1.41479492e-01,  -1.41479492e-01],
                        [ -1.16851807e-01,  -1.16851807e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -1.04248047e-01,  -1.04248047e-01],
                        [ -9.09729004e-02,  -9.09729004e-02],
                        [ -7.85522461e-02,  -7.85522461e-02],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  3.94897461e-02,   3.94897461e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  2.11914062e-01,   2.11914062e-01],
                        [  2.70538330e-01,   2.70538330e-01],
                        [  3.00872803e-01,   3.00872803e-01],
                        [  2.98370361e-01,   2.98370361e-01],
                        [  2.66693115e-01,   2.66693115e-01],
                        [  2.09808350e-01,   2.09808350e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  2.61840820e-02,   2.61840820e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -1.67541504e-01,  -1.67541504e-01],
                        [ -1.27319336e-01,  -1.27319336e-01],
                        [ -7.30285645e-02,  -7.30285645e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -5.32531738e-02,  -5.32531738e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  4.08630371e-02,   4.08630371e-02],
                        [  6.29882812e-02,   6.29882812e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -7.62939453e-03,  -7.62939453e-03],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -6.62536621e-02,  -6.62536621e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.41052246e-01,   1.41052246e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  7.05566406e-02,   7.05566406e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  5.63659668e-02,   5.63659668e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.22253418e-01,   1.22253418e-01],
                        [  9.50317383e-02,   9.50317383e-02],
                        [  3.54919434e-02,   3.54919434e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -1.53167725e-01,  -1.53167725e-01],
                        [ -2.45239258e-01,  -2.45239258e-01],
                        [ -3.05938721e-01,  -3.05938721e-01],
                        [ -3.15185547e-01,  -3.15185547e-01],
                        [ -2.72949219e-01,  -2.72949219e-01],
                        [ -2.09899902e-01,  -2.09899902e-01],
                        [ -1.63787842e-01,  -1.63787842e-01],
                        [ -1.43005371e-01,  -1.43005371e-01],
                        [ -1.27868652e-01,  -1.27868652e-01],
                        [ -1.02905273e-01,  -1.02905273e-01],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  8.50830078e-02,   8.50830078e-02],
                        [  1.44714355e-01,   1.44714355e-01],
                        [  2.02056885e-01,   2.02056885e-01],
                        [  2.45727539e-01,   2.45727539e-01],
                        [  2.66479492e-01,   2.66479492e-01],
                        [  2.62054443e-01,   2.62054443e-01],
                        [  2.42218018e-01,   2.42218018e-01],
                        [  2.22167969e-01,   2.22167969e-01],
                        [  2.04895020e-01,   2.04895020e-01],
                        [  1.74835205e-01,   1.74835205e-01],
                        [  1.13739014e-01,   1.13739014e-01],
                        [  2.30407715e-02,   2.30407715e-02],
                        [ -7.09228516e-02,  -7.09228516e-02],
                        [ -1.35009766e-01,  -1.35009766e-01],
                        [ -1.54693604e-01,  -1.54693604e-01],
                        [ -1.42913818e-01,  -1.42913818e-01],
                        [ -1.23748779e-01,  -1.23748779e-01],
                        [ -1.10168457e-01,  -1.10168457e-01],
                        [ -9.99145508e-02,  -9.99145508e-02],
                        [ -8.84094238e-02,  -8.84094238e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -5.85021973e-02,  -5.85021973e-02],
                        [ -3.61938477e-02,  -3.61938477e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  4.30297852e-02,   4.30297852e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  1.12884521e-01,   1.12884521e-01],
                        [  1.22894287e-01,   1.22894287e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  8.30078125e-03,   8.30078125e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  6.74133301e-02,   6.74133301e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  1.11846924e-01,   1.11846924e-01],
                        [  1.30065918e-01,   1.30065918e-01],
                        [  1.36993408e-01,   1.36993408e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  8.45947266e-02,   8.45947266e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -8.53881836e-02,  -8.53881836e-02],
                        [ -1.92443848e-01,  -1.92443848e-01],
                        [ -2.74444580e-01,  -2.74444580e-01],
                        [ -3.06579590e-01,  -3.06579590e-01],
                        [ -2.88055420e-01,  -2.88055420e-01],
                        [ -2.37915039e-01,  -2.37915039e-01],
                        [ -1.81701660e-01,  -1.81701660e-01],
                        [ -1.39831543e-01,  -1.39831543e-01],
                        [ -1.16821289e-01,  -1.16821289e-01],
                        [ -1.01287842e-01,  -1.01287842e-01],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -6.45751953e-02,  -6.45751953e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.36291504e-02,  -6.36291504e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -3.43322754e-02,  -3.43322754e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.87866211e-01,   1.87866211e-01],
                        [  2.31445312e-01,   2.31445312e-01],
                        [  2.45574951e-01,   2.45574951e-01],
                        [  2.35260010e-01,   2.35260010e-01],
                        [  2.19848633e-01,   2.19848633e-01],
                        [  2.14660645e-01,   2.14660645e-01],
                        [  2.16644287e-01,   2.16644287e-01],
                        [  2.10449219e-01,   2.10449219e-01],
                        [  1.83319092e-01,   1.83319092e-01],
                        [  1.30798340e-01,   1.30798340e-01],
                        [  5.59082031e-02,   5.59082031e-02],
                        [ -3.11889648e-02,  -3.11889648e-02],
                        [ -1.12579346e-01,  -1.12579346e-01],
                        [ -1.65924072e-01,  -1.65924072e-01],
                        [ -1.75445557e-01,  -1.75445557e-01],
                        [ -1.45111084e-01,  -1.45111084e-01],
                        [ -1.00158691e-01,  -1.00158691e-01],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  3.92456055e-02,   3.92456055e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -5.83801270e-02,  -5.83801270e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  3.97338867e-02,   3.97338867e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.49841309e-02,   1.49841309e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.23999023e-02,  -2.23999023e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  5.34057617e-02,   5.34057617e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.36901855e-01,   1.36901855e-01],
                        [  1.59240723e-01,   1.59240723e-01],
                        [  1.54357910e-01,   1.54357910e-01],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  5.61523438e-02,   5.61523438e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -2.20550537e-01,  -2.20550537e-01],
                        [ -2.85247803e-01,  -2.85247803e-01],
                        [ -3.00354004e-01,  -3.00354004e-01],
                        [ -2.67272949e-01,  -2.67272949e-01],
                        [ -2.09716797e-01,  -2.09716797e-01],
                        [ -1.60888672e-01,  -1.60888672e-01],
                        [ -1.39831543e-01,  -1.39831543e-01],
                        [ -1.37756348e-01,  -1.37756348e-01],
                        [ -1.32141113e-01,  -1.32141113e-01],
                        [ -1.11755371e-01,  -1.11755371e-01],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -6.33239746e-02,  -6.33239746e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.64587402e-02,  -2.64587402e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -5.82885742e-02,  -5.82885742e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.42639160e-01,   1.42639160e-01],
                        [  1.82708740e-01,   1.82708740e-01],
                        [  2.15454102e-01,   2.15454102e-01],
                        [  2.29766846e-01,   2.29766846e-01],
                        [  2.22198486e-01,   2.22198486e-01],
                        [  2.05078125e-01,   2.05078125e-01],
                        [  1.95312500e-01,   1.95312500e-01],
                        [  1.96411133e-01,   1.96411133e-01],
                        [  1.97662354e-01,   1.97662354e-01],
                        [  1.85485840e-01,   1.85485840e-01],
                        [  1.50634766e-01,   1.50634766e-01],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -8.75244141e-02,  -8.75244141e-02],
                        [ -1.61041260e-01,  -1.61041260e-01],
                        [ -1.94702148e-01,  -1.94702148e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.53961182e-01,  -1.53961182e-01],
                        [ -1.19354248e-01,  -1.19354248e-01],
                        [ -9.51843262e-02,  -9.51843262e-02],
                        [ -7.73010254e-02,  -7.73010254e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.83105469e-02,  -1.83105469e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -5.37719727e-02,  -5.37719727e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  6.51245117e-02,   6.51245117e-02],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.22131348e-01,   1.22131348e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  5.67932129e-02,   5.67932129e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  1.01104736e-01,   1.01104736e-01],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.31652832e-01,   1.31652832e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -1.59057617e-01,  -1.59057617e-01],
                        [ -2.42004395e-01,  -2.42004395e-01],
                        [ -2.96752930e-01,  -2.96752930e-01],
                        [ -3.01177979e-01,  -3.01177979e-01],
                        [ -2.56530762e-01,  -2.56530762e-01],
                        [ -1.94641113e-01,  -1.94641113e-01],
                        [ -1.48895264e-01,  -1.48895264e-01],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -1.11755371e-01,  -1.11755371e-01],
                        [ -9.85412598e-02,  -9.85412598e-02],
                        [ -8.60900879e-02,  -8.60900879e-02],
                        [ -7.50732422e-02,  -7.50732422e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  5.79833984e-02,   5.79833984e-02],
                        [  1.06842041e-01,   1.06842041e-01],
                        [  1.53503418e-01,   1.53503418e-01],
                        [  1.94244385e-01,   1.94244385e-01],
                        [  2.18841553e-01,   2.18841553e-01],
                        [  2.18780518e-01,   2.18780518e-01],
                        [  2.00469971e-01,   2.00469971e-01],
                        [  1.82373047e-01,   1.82373047e-01],
                        [  1.77520752e-01,   1.77520752e-01],
                        [  1.83685303e-01,   1.83685303e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  1.86828613e-01,   1.86828613e-01],
                        [  1.68121338e-01,   1.68121338e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  7.15026855e-02,   7.15026855e-02],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -9.79614258e-02,  -9.79614258e-02],
                        [ -1.71691895e-01,  -1.71691895e-01],
                        [ -2.06451416e-01,  -2.06451416e-01],
                        [ -1.96868896e-01,  -1.96868896e-01],
                        [ -1.57073975e-01,  -1.57073975e-01],
                        [ -1.09985352e-01,  -1.09985352e-01],
                        [ -7.33642578e-02,  -7.33642578e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -3.79943848e-02,  -3.79943848e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  7.37915039e-02,   7.37915039e-02],
                        [  1.24481201e-01,   1.24481201e-01],
                        [  1.42852783e-01,   1.42852783e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  6.67724609e-02,   6.67724609e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  5.06591797e-03,   5.06591797e-03],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  7.64770508e-02,   7.64770508e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.36077881e-01,   1.36077881e-01],
                        [  1.49261475e-01,   1.49261475e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [ -7.56835938e-02,  -7.56835938e-02],
                        [ -1.76666260e-01,  -1.76666260e-01],
                        [ -2.65655518e-01,  -2.65655518e-01],
                        [ -3.15948486e-01,  -3.15948486e-01],
                        [ -3.06610107e-01,  -3.06610107e-01],
                        [ -2.49786377e-01,  -2.49786377e-01],
                        [ -1.87103271e-01,  -1.87103271e-01],
                        [ -1.48559570e-01,  -1.48559570e-01],
                        [ -1.27136230e-01,  -1.27136230e-01],
                        [ -1.01989746e-01,  -1.01989746e-01],
                        [ -7.32421875e-02,  -7.32421875e-02],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  4.15039062e-03,   4.15039062e-03],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.80456543e-02,  -2.80456543e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -5.74951172e-02,  -5.74951172e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  1.30737305e-01,   1.30737305e-01],
                        [  1.81671143e-01,   1.81671143e-01],
                        [  2.11700439e-01,   2.11700439e-01],
                        [  2.11364746e-01,   2.11364746e-01],
                        [  1.91284180e-01,   1.91284180e-01],
                        [  1.71905518e-01,   1.71905518e-01],
                        [  1.63055420e-01,   1.63055420e-01],
                        [  1.60400391e-01,   1.60400391e-01],
                        [  1.56860352e-01,   1.56860352e-01],
                        [  1.51397705e-01,   1.51397705e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.52832031e-01,   1.52832031e-01],
                        [  1.53625488e-01,   1.53625488e-01],
                        [  1.34307861e-01,   1.34307861e-01],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -9.04235840e-02,  -9.04235840e-02],
                        [ -1.71722412e-01,  -1.71722412e-01],
                        [ -2.12310791e-01,  -2.12310791e-01],
                        [ -1.95953369e-01,  -1.95953369e-01],
                        [ -1.37329102e-01,  -1.37329102e-01],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  3.57055664e-03,   3.57055664e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.87255859e-02,  -6.87255859e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [  4.86145020e-02,   4.86145020e-02],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  1.30950928e-01,   1.30950928e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  9.53063965e-02,   9.53063965e-02],
                        [  6.71081543e-02,   6.71081543e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  1.17614746e-01,   1.17614746e-01],
                        [  1.33239746e-01,   1.33239746e-01],
                        [  1.39923096e-01,   1.39923096e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [ -3.56140137e-02,  -3.56140137e-02],
                        [ -1.38916016e-01,  -1.38916016e-01],
                        [ -2.34558105e-01,  -2.34558105e-01],
                        [ -2.94403076e-01,  -2.94403076e-01],
                        [ -3.01605225e-01,  -3.01605225e-01],
                        [ -2.59185791e-01,  -2.59185791e-01],
                        [ -1.93542480e-01,  -1.93542480e-01],
                        [ -1.38885498e-01,  -1.38885498e-01],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -9.33837891e-02,  -9.33837891e-02],
                        [ -8.85620117e-02,  -8.85620117e-02],
                        [ -8.73718262e-02,  -8.73718262e-02],
                        [ -8.73413086e-02,  -8.73413086e-02],
                        [ -8.02612305e-02,  -8.02612305e-02],
                        [ -5.94482422e-02,  -5.94482422e-02],
                        [ -2.85949707e-02,  -2.85949707e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.39562988e-02,   2.39562988e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -5.65185547e-02,  -5.65185547e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -7.49511719e-02,  -7.49511719e-02],
                        [ -7.59887695e-02,  -7.59887695e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -5.25207520e-02,  -5.25207520e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  9.32922363e-02,   9.32922363e-02],
                        [  1.59393311e-01,   1.59393311e-01],
                        [  2.14508057e-01,   2.14508057e-01],
                        [  2.40875244e-01,   2.40875244e-01],
                        [  2.31475830e-01,   2.31475830e-01],
                        [  1.97937012e-01,   1.97937012e-01],
                        [  1.60095215e-01,   1.60095215e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  1.09283447e-01,   1.09313965e-01],
                        [  9.98535156e-02,   9.98535156e-02],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  1.31530762e-01,   1.31530762e-01],
                        [  1.39770508e-01,   1.39770508e-01],
                        [  1.45080566e-01,   1.45080566e-01],
                        [  1.43493652e-01,   1.43493652e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  5.58471680e-02,   5.58471680e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -1.39373779e-01,  -1.39373779e-01],
                        [ -2.03216553e-01,  -2.03216553e-01],
                        [ -2.08557129e-01,  -2.08557129e-01],
                        [ -1.66503906e-01,  -1.66503906e-01],
                        [ -1.11511230e-01,  -1.11511230e-01],
                        [ -7.35473633e-02,  -7.35473633e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  3.04565430e-02,   3.04565430e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [ -1.59912109e-02,  -1.59912109e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [  5.25512695e-02,   5.25512695e-02],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.07482910e-01,   1.07482910e-01],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  4.61730957e-02,   4.61730957e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  2.04772949e-02,   2.04772949e-02],
                        [  7.50732422e-03,   7.50732422e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -8.57543945e-03,  -8.60595703e-03],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  7.58972168e-02,   7.58972168e-02],
                        [  8.75854492e-02,   8.75854492e-02],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  1.03179932e-01,   1.03179932e-01],
                        [  1.17736816e-01,   1.17736816e-01],
                        [  1.30187988e-01,   1.30187988e-01],
                        [  1.35894775e-01,   1.35894775e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [ -6.37207031e-02,  -6.37207031e-02],
                        [ -1.67480469e-01,  -1.67480469e-01],
                        [ -2.58819580e-01,  -2.58819580e-01],
                        [ -3.04870605e-01,  -3.04870605e-01],
                        [ -2.89306641e-01,  -2.89306641e-01],
                        [ -2.29461670e-01,  -2.29461670e-01],
                        [ -1.65924072e-01,  -1.65924072e-01],
                        [ -1.30920410e-01,  -1.30920410e-01],
                        [ -1.23596191e-01,  -1.23596191e-01],
                        [ -1.19171143e-01,  -1.19171143e-01],
                        [ -1.00677490e-01,  -1.00677490e-01],
                        [ -7.34252930e-02,  -7.34252930e-02],
                        [ -5.07507324e-02,  -5.07507324e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -4.29077148e-02,  -4.29077148e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -7.49816895e-02,  -7.49816895e-02],
                        [ -8.30078125e-02,  -8.30078125e-02],
                        [ -7.88879395e-02,  -7.88879395e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  4.87365723e-02,   4.87365723e-02],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.61865234e-01,   1.61865234e-01],
                        [  2.06481934e-01,   2.06481934e-01],
                        [  2.29614258e-01,   2.29614258e-01],
                        [  2.22930908e-01,   2.22930908e-01],
                        [  1.93115234e-01,   1.93115234e-01],
                        [  1.56738281e-01,   1.56738281e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  1.01043701e-01,   1.01043701e-01],
                        [  1.09405518e-01,   1.09405518e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.47491455e-01,   1.47491455e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  4.27246094e-02,   4.27246094e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -1.96624756e-01,  -1.96624756e-01],
                        [ -2.16888428e-01,  -2.16888428e-01],
                        [ -1.92535400e-01,  -1.92535400e-01],
                        [ -1.40869141e-01,  -1.40869141e-01],
                        [ -8.78295898e-02,  -8.78601074e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -7.27539062e-02,  -7.27539062e-02],
                        [ -7.19604492e-02,  -7.19604492e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  7.98339844e-02,   7.98339844e-02],
                        [  1.15142822e-01,   1.15173340e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  3.69262695e-02,   3.69262695e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.03759766e-02,   1.03759766e-02],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [  1.90429688e-02,   1.90429688e-02],
                        [  5.69458008e-02,   5.69458008e-02],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.50482178e-01,   1.50482178e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.50756836e-01,   1.50756836e-01],
                        [  1.30096436e-01,   1.30096436e-01],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [ -7.17773438e-02,  -7.17773438e-02],
                        [ -1.71478271e-01,  -1.71478271e-01],
                        [ -2.57690430e-01,  -2.57690430e-01],
                        [ -3.02398682e-01,  -3.02398682e-01],
                        [ -2.88269043e-01,  -2.88269043e-01],
                        [ -2.28302002e-01,  -2.28302002e-01],
                        [ -1.62261963e-01,  -1.62261963e-01],
                        [ -1.23199463e-01,  -1.23199463e-01],
                        [ -1.10443115e-01,  -1.10443115e-01],
                        [ -1.02935791e-01,  -1.02935791e-01],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -7.70263672e-02,  -7.70263672e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -7.00988770e-02,  -7.00988770e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -2.31933594e-03,  -2.34985352e-03],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -7.72399902e-02,  -7.72399902e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  1.14135742e-01,   1.14135742e-01],
                        [  1.62536621e-01,   1.62536621e-01],
                        [  1.93328857e-01,   1.93328857e-01],
                        [  2.01019287e-01,   2.01019287e-01],
                        [  1.88720703e-01,   1.88720703e-01],
                        [  1.68518066e-01,   1.68518066e-01],
                        [  1.49078369e-01,   1.49078369e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  9.60388184e-02,   9.60388184e-02],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  1.16790771e-01,   1.16760254e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.11877441e-01,   1.11877441e-01],
                        [  1.00555420e-01,   1.00555420e-01],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  5.36804199e-02,   5.36804199e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -1.55609131e-01,  -1.55609131e-01],
                        [ -2.01660156e-01,  -2.01660156e-01],
                        [ -2.01141357e-01,  -2.01141357e-01],
                        [ -1.60675049e-01,  -1.60675049e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -7.62329102e-02,  -7.62329102e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -5.12695312e-02,  -5.12695312e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.31225586e-03,   1.31225586e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -4.25720215e-02,  -4.25720215e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -7.25097656e-02,  -7.25097656e-02],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -6.46057129e-02,  -6.46057129e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  1.28173828e-01,   1.28173828e-01],
                        [  1.37817383e-01,   1.37817383e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  8.85314941e-02,   8.85314941e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  4.44335938e-02,   4.44641113e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  2.18811035e-02,   2.18811035e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  3.76281738e-02,   3.75976562e-02],
                        [  5.05981445e-02,   5.05676270e-02],
                        [  6.94580078e-02,   6.94580078e-02],
                        [  9.41772461e-02,   9.41772461e-02],
                        [  1.23291016e-01,   1.23291016e-01],
                        [  1.50115967e-01,   1.50115967e-01],
                        [  1.62475586e-01,   1.62475586e-01],
                        [  1.49902344e-01,   1.49902344e-01],
                        [  1.09436035e-01,   1.09436035e-01],
                        [  4.26330566e-02,   4.26330566e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -1.56585693e-01,  -1.56585693e-01],
                        [ -2.58697510e-01,  -2.58697510e-01],
                        [ -3.18359375e-01,  -3.18328857e-01],
                        [ -3.06915283e-01,  -3.06915283e-01],
                        [ -2.34558105e-01,  -2.34558105e-01],
                        [ -1.52160645e-01,  -1.52160645e-01],
                        [ -1.07391357e-01,  -1.07391357e-01],
                        [ -1.03179932e-01,  -1.03179932e-01],
                        [ -1.08947754e-01,  -1.08978271e-01],
                        [ -1.02478027e-01,  -1.02478027e-01],
                        [ -8.70056152e-02,  -8.69750977e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [ -2.49938965e-02,  -2.49633789e-02],
                        [ -4.61730957e-02,  -4.62036133e-02],
                        [ -6.07910156e-02,  -6.08215332e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -5.80749512e-02,  -5.81054688e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [  1.25122070e-02,   1.24816895e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  1.22985840e-01,   1.22985840e-01],
                        [  1.77246094e-01,   1.77246094e-01],
                        [  2.09014893e-01,   2.09014893e-01],
                        [  2.08648682e-01,   2.08648682e-01],
                        [  1.81182861e-01,   1.81182861e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.03546143e-01,   1.03576660e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  7.65380859e-02,   7.65686035e-02],
                        [  7.54699707e-02,   7.54699707e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  6.53076172e-02,   6.53076172e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [ -1.78527832e-02,  -1.78222656e-02],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -1.76147461e-01,  -1.76177979e-01],
                        [ -2.02331543e-01,  -2.02331543e-01],
                        [ -1.80877686e-01,  -1.80877686e-01],
                        [ -1.38580322e-01,  -1.38580322e-01],
                        [ -1.05529785e-01,  -1.05529785e-01],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -7.56530762e-02,  -7.56530762e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -4.67834473e-02,  -4.67834473e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -6.93664551e-02,  -6.93969727e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -6.05163574e-02,  -6.05163574e-02],
                        [ -6.00280762e-02,  -6.00585938e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  1.02172852e-01,   1.02172852e-01],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  8.53881836e-02,   8.53881836e-02],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  6.38732910e-02,   6.38732910e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.68859863e-02,   2.68859863e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.48651123e-01,   1.48651123e-01],
                        [  1.36810303e-01,   1.36810303e-01],
                        [  9.85717773e-02,   9.85717773e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [ -6.58874512e-02,  -6.59179688e-02],
                        [ -1.67724609e-01,  -1.67724609e-01],
                        [ -2.51403809e-01,  -2.51403809e-01],
                        [ -2.92358398e-01,  -2.92358398e-01],
                        [ -2.77435303e-01,  -2.77435303e-01],
                        [ -2.20397949e-01,  -2.20397949e-01],
                        [ -1.59698486e-01,  -1.59698486e-01],
                        [ -1.26434326e-01,  -1.26434326e-01],
                        [ -1.17706299e-01,  -1.17706299e-01],
                        [ -1.10626221e-01,  -1.10626221e-01],
                        [ -9.52758789e-02,  -9.53063965e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -7.63244629e-02,  -7.63244629e-02],
                        [ -7.18994141e-02,  -7.18994141e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -3.27758789e-02,  -3.27453613e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  1.11389160e-02,   1.11694336e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -7.38525391e-02,  -7.38525391e-02],
                        [ -6.55517578e-02,  -6.55212402e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [  4.27246094e-02,   4.27551270e-02],
                        [  1.12487793e-01,   1.12487793e-01],
                        [  1.79168701e-01,   1.79138184e-01],
                        [  2.18383789e-01,   2.18383789e-01],
                        [  2.18200684e-01,   2.18231201e-01],
                        [  1.88781738e-01,   1.88781738e-01],
                        [  1.52404785e-01,   1.52374268e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  9.93652344e-02,   9.93347168e-02],
                        [  8.59069824e-02,   8.59069824e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  6.82983398e-02,   6.82678223e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  6.22253418e-02,   6.22253418e-02],
                        [  6.36596680e-02,   6.36596680e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [ -8.03222656e-02,  -8.03222656e-02],
                        [ -1.38244629e-01,  -1.38275146e-01],
                        [ -1.67419434e-01,  -1.67419434e-01],
                        [ -1.64337158e-01,  -1.64337158e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -1.12823486e-01,  -1.12823486e-01],
                        [ -9.10949707e-02,  -9.10644531e-02],
                        [ -7.47070312e-02,  -7.47070312e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -4.27551270e-02,  -4.27246094e-02],
                        [ -3.14941406e-02,  -3.14636230e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -1.67236328e-02,  -1.67236328e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  7.75146484e-03,   7.75146484e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -5.28869629e-02,  -5.29174805e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -8.59985352e-02,  -8.59985352e-02],
                        [ -8.27941895e-02,  -8.27941895e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  8.62121582e-02,   8.61816406e-02],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  8.50524902e-02,   8.50524902e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  5.94177246e-02,   5.94177246e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.45556641e-02,   4.45861816e-02],
                        [  4.49829102e-02,   4.49523926e-02],
                        [  4.22668457e-02,   4.22363281e-02],
                        [  4.05273438e-02,   4.05578613e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  1.42150879e-01,   1.42150879e-01],
                        [  1.21002197e-01,   1.21002197e-01],
                        [  6.54907227e-02,   6.55212402e-02],
                        [ -2.02636719e-02,  -2.02941895e-02],
                        [ -1.19995117e-01,  -1.19995117e-01],
                        [ -2.10266113e-01,  -2.10235596e-01],
                        [ -2.66784668e-01,  -2.66784668e-01],
                        [ -2.74810791e-01,  -2.74810791e-01],
                        [ -2.40661621e-01,  -2.40661621e-01],
                        [ -1.89208984e-01,  -1.89178467e-01],
                        [ -1.44989014e-01,  -1.44989014e-01],
                        [ -1.17523193e-01,  -1.17553711e-01],
                        [ -1.02569580e-01,  -1.02569580e-01],
                        [ -9.28039551e-02,  -9.27734375e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -7.77282715e-02,  -7.77587891e-02],
                        [ -6.96716309e-02,  -6.96716309e-02],
                        [ -5.72204590e-02,  -5.72204590e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  7.11059570e-03,   7.11059570e-03],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -3.54309082e-02,  -3.54309082e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -8.67309570e-02,  -8.67309570e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [  1.47399902e-02,   1.47705078e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  1.25213623e-01,   1.25183105e-01],
                        [  1.76727295e-01,   1.76727295e-01],
                        [  2.04681396e-01,   2.04711914e-01],
                        [  2.00836182e-01,   2.00836182e-01],
                        [  1.71142578e-01,   1.71112061e-01],
                        [  1.30828857e-01,   1.30828857e-01],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  8.06884766e-02,   8.06579590e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  7.51953125e-02,   7.51953125e-02],
                        [  7.22961426e-02,   7.22961426e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  7.18994141e-02,   7.18994141e-02],
                        [  6.76269531e-02,   6.76269531e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  3.82690430e-02,   3.82995605e-02],
                        [  2.51770020e-02,   2.51770020e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  8.47473145e-02,   8.47473145e-02],
                        [  1.08642578e-01,   1.08612061e-01],
                        [  1.22161865e-01,   1.22192383e-01],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  9.35668945e-02,   9.35668945e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [ -4.34570312e-02,  -4.34265137e-02],
                        [ -1.31866455e-01,  -1.31896973e-01],
                        [ -1.89239502e-01,  -1.89239502e-01],
                        [ -1.94305420e-01,  -1.94274902e-01],
                        [ -1.61468506e-01,  -1.61499023e-01],
                        [ -1.25640869e-01,  -1.25640869e-01],
                        [ -1.08062744e-01,  -1.08032227e-01],
                        [ -1.02020264e-01,  -1.02020264e-01],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -1.44958496e-02,  -1.44958496e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -1.96533203e-02,  -1.96533203e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -7.62634277e-02,  -7.62634277e-02],
                        [ -9.18579102e-02,  -9.18579102e-02],
                        [ -9.20104980e-02,  -9.20104980e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  6.87255859e-02,   6.86950684e-02],
                        [  1.10748291e-01,   1.10748291e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  9.17968750e-02,   9.17968750e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  5.30395508e-02,   5.30395508e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  3.93371582e-02,   3.93676758e-02],
                        [  3.16162109e-02,   3.16467285e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  4.20837402e-02,   4.21142578e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  6.02722168e-02,   6.02722168e-02],
                        [  5.34362793e-02,   5.34667969e-02],
                        [  5.35583496e-02,   5.35278320e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  7.98339844e-02,   7.98339844e-02],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  1.30859375e-01,   1.30859375e-01],
                        [  1.44836426e-01,   1.44836426e-01],
                        [  1.40625000e-01,   1.40625000e-01],
                        [  1.15264893e-01,   1.15234375e-01],
                        [  6.61315918e-02,   6.61315918e-02],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -9.46350098e-02,  -9.46655273e-02],
                        [ -1.84753418e-01,  -1.84753418e-01],
                        [ -2.53936768e-01,  -2.53936768e-01],
                        [ -2.76824951e-01,  -2.76855469e-01],
                        [ -2.45574951e-01,  -2.45574951e-01],
                        [ -1.84356689e-01,  -1.84326172e-01],
                        [ -1.31561279e-01,  -1.31591797e-01],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -1.00982666e-01,  -1.00952148e-01],
                        [ -9.81445312e-02,  -9.81445312e-02],
                        [ -9.26513672e-02,  -9.26818848e-02],
                        [ -8.88366699e-02,  -8.88366699e-02],
                        [ -8.62731934e-02,  -8.62731934e-02],
                        [ -7.57446289e-02,  -7.57446289e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -2.53906250e-02,  -2.53601074e-02],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -1.52587891e-04,  -1.52587891e-04],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.32751465e-02,  -1.33056641e-02],
                        [ -1.89514160e-02,  -1.89514160e-02],
                        [ -3.45458984e-02,  -3.45153809e-02],
                        [ -5.48095703e-02,  -5.48400879e-02],
                        [ -6.56127930e-02,  -6.56433105e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [  1.89208984e-03,   1.86157227e-03],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  1.25610352e-01,   1.25610352e-01],
                        [  1.85546875e-01,   1.85546875e-01],
                        [  2.19482422e-01,   2.19482422e-01],
                        [  2.14477539e-01,   2.14477539e-01],
                        [  1.74957275e-01,   1.74957275e-01],
                        [  1.25305176e-01,   1.25274658e-01],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  7.86743164e-02,   7.86743164e-02],
                        [  8.22753906e-02,   8.22753906e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  7.34558105e-02,   7.34558105e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  5.59692383e-02,   5.59692383e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  9.32006836e-02,   9.32006836e-02],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.27532959e-01,   1.27502441e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  9.78393555e-02,   9.78393555e-02],
                        [  2.17895508e-02,   2.17895508e-02],
                        [ -8.28552246e-02,  -8.28552246e-02],
                        [ -1.76910400e-01,  -1.76879883e-01],
                        [ -2.22534180e-01,  -2.22534180e-01],
                        [ -2.11242676e-01,  -2.11273193e-01],
                        [ -1.65832520e-01,  -1.65802002e-01],
                        [ -1.16241455e-01,  -1.16210938e-01],
                        [ -7.89794922e-02,  -7.90100098e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.58984375e-02,  -4.58679199e-02],
                        [ -4.11987305e-02,  -4.12292480e-02],
                        [ -4.22363281e-02,  -4.22668457e-02],
                        [ -5.14526367e-02,  -5.14221191e-02],
                        [ -6.23779297e-02,  -6.23779297e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -4.28771973e-02,  -4.28466797e-02],
                        [ -2.16064453e-02,  -2.15759277e-02],
                        [ -9.06372070e-03,  -9.09423828e-03],
                        [ -6.01196289e-03,  -6.01196289e-03],
                        [ -7.38525391e-03,  -7.35473633e-03],
                        [ -9.70458984e-03,  -9.73510742e-03],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -2.19726562e-02,  -2.19421387e-02],
                        [ -3.65905762e-02,  -3.65600586e-02],
                        [ -5.50537109e-02,  -5.50842285e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -8.62731934e-02,  -8.62426758e-02],
                        [ -8.37707520e-02,  -8.37707520e-02],
                        [ -5.91430664e-02,  -5.91430664e-02],
                        [ -1.81884766e-02,  -1.81884766e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  8.52355957e-02,   8.52355957e-02],
                        [  9.88769531e-02,   9.88769531e-02],
                        [  9.85412598e-02,   9.85412598e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.48303223e-02,   4.47998047e-02],
                        [  4.93469238e-02,   4.93774414e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  6.19506836e-02,   6.19201660e-02],
                        [  5.69763184e-02,   5.69763184e-02],
                        [  5.16357422e-02,   5.16662598e-02],
                        [  5.43823242e-02,   5.43518066e-02],
                        [  6.53686523e-02,   6.53381348e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  1.15936279e-01,   1.15905762e-01],
                        [  1.32873535e-01,   1.32873535e-01],
                        [  1.41448975e-01,   1.41448975e-01],
                        [  1.31744385e-01,   1.31744385e-01],
                        [  9.30786133e-02,   9.30786133e-02],
                        [  1.94702148e-02,   1.95007324e-02],
                        [ -8.21228027e-02,  -8.21228027e-02],
                        [ -1.89544678e-01,  -1.89575195e-01],
                        [ -2.71972656e-01,  -2.71942139e-01],
                        [ -3.02093506e-01,  -3.02093506e-01],
                        [ -2.72430420e-01,  -2.72430420e-01],
                        [ -2.04620361e-01,  -2.04620361e-01],
                        [ -1.36444092e-01,  -1.36413574e-01],
                        [ -9.34143066e-02,  -9.34143066e-02],
                        [ -7.61413574e-02,  -7.61718750e-02],
                        [ -7.10449219e-02,  -7.10144043e-02],
                        [ -6.69250488e-02,  -6.69250488e-02],
                        [ -6.36901855e-02,  -6.37207031e-02],
                        [ -6.77185059e-02,  -6.77185059e-02],
                        [ -7.74841309e-02,  -7.74536133e-02],
                        [ -7.91015625e-02,  -7.91320801e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -4.16564941e-02,  -4.16259766e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -1.40380859e-02,  -1.40686035e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -1.78222656e-02,  -1.78527832e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -6.42089844e-02,  -6.42089844e-02],
                        [ -5.18188477e-02,  -5.18188477e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  1.45812988e-01,   1.45812988e-01],
                        [  1.87316895e-01,   1.87316895e-01],
                        [  2.01690674e-01,   2.01690674e-01],
                        [  1.86309814e-01,   1.86309814e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.17736816e-01,   1.17736816e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  8.50830078e-02,   8.50524902e-02],
                        [  7.70568848e-02,   7.70568848e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  4.66918945e-02,   4.67224121e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.00195312e-02,   1.99890137e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.89709473e-02,   3.89709473e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  6.53991699e-02,   6.54296875e-02],
                        [  9.34448242e-02,   9.34143066e-02],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.28295898e-01,   1.28326416e-01],
                        [  9.60083008e-02,   9.60388184e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -1.64093018e-01,  -1.64062500e-01],
                        [ -2.11303711e-01,  -2.11303711e-01],
                        [ -2.11975098e-01,  -2.12005615e-01],
                        [ -1.76147461e-01,  -1.76147461e-01],
                        [ -1.27624512e-01,  -1.27624512e-01],
                        [ -8.88366699e-02,  -8.88671875e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -5.44738770e-02,  -5.44738770e-02],
                        [ -6.09741211e-02,  -6.10046387e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -7.80334473e-02,  -7.80334473e-02],
                        [ -7.65991211e-02,  -7.65991211e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -5.17578125e-02,  -5.17272949e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [  7.53784180e-03,   7.56835938e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -4.92248535e-02,  -4.91943359e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -6.59790039e-02,  -6.59790039e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  9.06372070e-02,   9.06372070e-02],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  9.80834961e-02,   9.81140137e-02],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  6.43920898e-02,   6.43615723e-02],
                        [  6.08825684e-02,   6.09130859e-02],
                        [  6.10046387e-02,   6.10351562e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  6.14624023e-02,   6.14929199e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  5.26123047e-02,   5.26428223e-02],
                        [  4.99267578e-02,   4.99267578e-02],
                        [  6.01501465e-02,   6.01501465e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.41296387e-01,   1.41296387e-01],
                        [  1.53320312e-01,   1.53320312e-01],
                        [  1.35253906e-01,   1.35253906e-01],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [ -7.62023926e-02,  -7.62023926e-02],
                        [ -1.77246094e-01,  -1.77276611e-01],
                        [ -2.59796143e-01,  -2.59796143e-01],
                        [ -2.94128418e-01,  -2.94128418e-01],
                        [ -2.71148682e-01,  -2.71179199e-01],
                        [ -2.10266113e-01,  -2.10266113e-01],
                        [ -1.46026611e-01,  -1.46026611e-01],
                        [ -1.04370117e-01,  -1.04400635e-01],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -8.40759277e-02,  -8.40454102e-02],
                        [ -7.85522461e-02,  -7.85522461e-02],
                        [ -6.70471191e-02,  -6.70471191e-02],
                        [ -5.47485352e-02,  -5.47180176e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.65393066e-02,  -4.65698242e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -7.03125000e-02,  -7.03125000e-02],
                        [ -6.84814453e-02,  -6.84814453e-02],
                        [ -4.48303223e-02,  -4.48303223e-02],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [  5.63049316e-02,   5.63049316e-02],
                        [  1.31683350e-01,   1.31683350e-01],
                        [  2.02117920e-01,   2.02117920e-01],
                        [  2.35260010e-01,   2.35260010e-01],
                        [  2.20001221e-01,   2.19970703e-01],
                        [  1.76971436e-01,   1.76971436e-01],
                        [  1.32659912e-01,   1.32690430e-01],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  7.73925781e-02,   7.73925781e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  6.62536621e-02,   6.62536621e-02],
                        [  6.55517578e-02,   6.55517578e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  6.44531250e-02,   6.44531250e-02],
                        [  5.82885742e-02,   5.82885742e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  1.75476074e-02,   1.75781250e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.89611816e-02,   2.89611816e-02],
                        [  3.93066406e-02,   3.92761230e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  6.29882812e-02,   6.29882812e-02],
                        [  7.00988770e-02,   7.00988770e-02],
                        [  8.22448730e-02,   8.22448730e-02],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  7.01599121e-02,   7.01599121e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -1.34521484e-01,  -1.34552002e-01],
                        [ -1.84600830e-01,  -1.84600830e-01],
                        [ -1.96594238e-01,  -1.96594238e-01],
                        [ -1.71569824e-01,  -1.71569824e-01],
                        [ -1.27166748e-01,  -1.27166748e-01],
                        [ -8.57543945e-02,  -8.57543945e-02],
                        [ -5.93261719e-02,  -5.93261719e-02],
                        [ -4.77294922e-02,  -4.77600098e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.44836426e-02,  -6.44836426e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -4.73022461e-03,  -4.76074219e-03],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [ -3.74145508e-02,  -3.74145508e-02],
                        [ -5.81359863e-02,  -5.81359863e-02],
                        [ -7.96508789e-02,  -7.96508789e-02],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  8.29772949e-02,   8.29467773e-02],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [  7.88574219e-02,   7.88574219e-02],
                        [  5.81665039e-02,   5.81970215e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  4.48913574e-02,   4.48608398e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  5.49011230e-02,   5.49316406e-02],
                        [  6.00891113e-02,   6.00585938e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  9.26208496e-02,   9.26208496e-02],
                        [  9.38110352e-02,   9.38110352e-02],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  1.10778809e-01,   1.10748291e-01],
                        [  1.27410889e-01,   1.27380371e-01],
                        [  1.36779785e-01,   1.36779785e-01],
                        [  1.26678467e-01,   1.26678467e-01],
                        [  8.88366699e-02,   8.88061523e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [ -8.45642090e-02,  -8.45336914e-02],
                        [ -1.95159912e-01,  -1.95159912e-01],
                        [ -2.77465820e-01,  -2.77496338e-01],
                        [ -3.05603027e-01,  -3.05572510e-01],
                        [ -2.80151367e-01,  -2.80151367e-01],
                        [ -2.23327637e-01,  -2.23327637e-01],
                        [ -1.65313721e-01,  -1.65313721e-01],
                        [ -1.27502441e-01,  -1.27502441e-01],
                        [ -1.09619141e-01,  -1.09649658e-01],
                        [ -9.79309082e-02,  -9.79309082e-02],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -7.06176758e-02,  -7.06176758e-02],
                        [ -5.69763184e-02,  -5.69763184e-02],
                        [ -3.95507812e-02,  -3.95202637e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.13525391e-02,   1.13220215e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -4.46472168e-02,  -4.46166992e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -9.84802246e-02,  -9.85107422e-02],
                        [ -9.89379883e-02,  -9.89379883e-02],
                        [ -7.58972168e-02,  -7.58666992e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  1.04187012e-01,   1.04187012e-01],
                        [  1.75262451e-01,   1.75262451e-01],
                        [  2.21008301e-01,   2.21008301e-01],
                        [  2.29431152e-01,   2.29400635e-01],
                        [  2.05566406e-01,   2.05566406e-01],
                        [  1.66931152e-01,   1.66931152e-01],
                        [  1.32507324e-01,   1.32476807e-01],
                        [  1.11602783e-01,   1.11602783e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  6.99157715e-02,   6.99157715e-02],
                        [  5.51757812e-02,   5.52062988e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.50952148e-02,   3.50646973e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [ -2.28881836e-03,  -2.25830078e-03],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  3.78723145e-02,   3.78723145e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  9.90905762e-02,   9.90905762e-02],
                        [  1.05560303e-01,   1.05529785e-01],
                        [  1.06689453e-01,   1.06689453e-01],
                        [  9.61303711e-02,   9.61303711e-02],
                        [  6.00891113e-02,   6.00891113e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -9.88769531e-02,  -9.88464355e-02],
                        [ -1.78985596e-01,  -1.78985596e-01],
                        [ -2.16796875e-01,  -2.16796875e-01],
                        [ -2.02941895e-01,  -2.02941895e-01],
                        [ -1.58233643e-01,  -1.58233643e-01],
                        [ -1.15203857e-01,  -1.15203857e-01],
                        [ -9.22851562e-02,  -9.22851562e-02],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -8.24584961e-02,  -8.24584961e-02],
                        [ -7.64770508e-02,  -7.64770508e-02],
                        [ -6.98852539e-02,  -6.98852539e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.27441406e-02,  -6.27746582e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.15356445e-02,  -1.15661621e-02],
                        [  3.35693359e-04,   3.35693359e-04],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -4.94384766e-03,  -4.97436523e-03],
                        [ -2.21557617e-02,  -2.21862793e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -7.40356445e-02,  -7.40356445e-02],
                        [ -9.57641602e-02,  -9.57946777e-02],
                        [ -1.04400635e-01,  -1.04400635e-01],
                        [ -1.00006104e-01,  -9.99755859e-02],
                        [ -8.36181641e-02,  -8.36181641e-02],
                        [ -4.99877930e-02,  -5.00183105e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  1.15356445e-01,   1.15325928e-01],
                        [  1.39892578e-01,   1.39892578e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  7.61718750e-02,   7.61413574e-02],
                        [  5.94482422e-02,   5.94787598e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  7.21740723e-02,   7.21740723e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.30767822e-01,   1.30737305e-01],
                        [  1.19995117e-01,   1.19995117e-01],
                        [  7.27539062e-02,   7.27539062e-02],
                        [ -1.46789551e-02,  -1.47094727e-02],
                        [ -1.24755859e-01,  -1.24755859e-01],
                        [ -2.24639893e-01,  -2.24639893e-01],
                        [ -2.80792236e-01,  -2.80792236e-01],
                        [ -2.77587891e-01,  -2.77618408e-01],
                        [ -2.31689453e-01,  -2.31689453e-01],
                        [ -1.81182861e-01,  -1.81182861e-01],
                        [ -1.52374268e-01,  -1.52374268e-01],
                        [ -1.41174316e-01,  -1.41174316e-01],
                        [ -1.28906250e-01,  -1.28906250e-01],
                        [ -1.06384277e-01,  -1.06384277e-01],
                        [ -7.81555176e-02,  -7.81555176e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.76391602e-02,  -1.76696777e-02],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -5.21850586e-02,  -5.21850586e-02],
                        [ -6.35375977e-02,  -6.35681152e-02],
                        [ -6.35375977e-02,  -6.35070801e-02],
                        [ -4.90722656e-02,  -4.90417480e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [  2.76184082e-02,   2.75878906e-02],
                        [  9.06372070e-02,   9.06677246e-02],
                        [  1.59790039e-01,   1.59820557e-01],
                        [  2.10571289e-01,   2.10571289e-01],
                        [  2.19787598e-01,   2.19787598e-01],
                        [  1.89941406e-01,   1.89971924e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  1.30767822e-01,   1.30767822e-01],
                        [  1.22314453e-01,   1.22314453e-01],
                        [  9.71374512e-02,   9.71374512e-02],
                        [  6.84509277e-02,   6.84509277e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  4.07714844e-02,   4.08020020e-02],
                        [  3.15246582e-02,   3.15246582e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [  3.66210938e-04,   3.35693359e-04],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  6.03942871e-02,   6.03942871e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.10015869e-01,   1.09985352e-01],
                        [  1.12792969e-01,   1.12792969e-01],
                        [  9.68322754e-02,   9.68627930e-02],
                        [  5.03845215e-02,   5.03845215e-02],
                        [ -2.82287598e-02,  -2.82592773e-02],
                        [ -1.21856689e-01,  -1.21856689e-01],
                        [ -1.97326660e-01,  -1.97326660e-01],
                        [ -2.25036621e-01,  -2.25036621e-01],
                        [ -2.01416016e-01,  -2.01416016e-01],
                        [ -1.51336670e-01,  -1.51306152e-01],
                        [ -1.05651855e-01,  -1.05651855e-01],
                        [ -7.94982910e-02,  -7.94982910e-02],
                        [ -7.04345703e-02,  -7.04345703e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -5.96923828e-02,  -5.97229004e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -5.55725098e-02,  -5.55725098e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -2.07519531e-02,  -2.07824707e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -6.67114258e-02,  -6.67114258e-02],
                        [ -8.33129883e-02,  -8.33129883e-02],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -9.86633301e-02,  -9.86328125e-02],
                        [ -8.58459473e-02,  -8.58764648e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [  7.81250000e-03,   7.81250000e-03],
                        [  6.77490234e-02,   6.77185059e-02],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.26922607e-01,   1.26953125e-01],
                        [  1.16729736e-01,   1.16699219e-01],
                        [  9.19799805e-02,   9.19494629e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  7.50427246e-02,   7.50122070e-02],
                        [  8.79211426e-02,   8.79211426e-02],
                        [  8.68530273e-02,   8.68835449e-02],
                        [  7.73925781e-02,   7.73620605e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  8.55102539e-02,   8.55102539e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  1.03698730e-01,   1.03698730e-01],
                        [  1.14532471e-01,   1.14532471e-01],
                        [  1.33789062e-01,   1.33789062e-01],
                        [  1.53442383e-01,   1.53411865e-01],
                        [  1.57470703e-01,   1.57470703e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  8.18786621e-02,   8.19091797e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -9.35363770e-02,  -9.35363770e-02],
                        [ -1.94793701e-01,  -1.94793701e-01],
                        [ -2.70996094e-01,  -2.70996094e-01],
                        [ -2.94830322e-01,  -2.94830322e-01],
                        [ -2.64038086e-01,  -2.64038086e-01],
                        [ -2.04284668e-01,  -2.04284668e-01],
                        [ -1.48803711e-01,  -1.48834229e-01],
                        [ -1.18560791e-01,  -1.18530273e-01],
                        [ -1.13494873e-01,  -1.13464355e-01],
                        [ -1.15447998e-01,  -1.15478516e-01],
                        [ -1.05895996e-01,  -1.05895996e-01],
                        [ -8.35571289e-02,  -8.35571289e-02],
                        [ -5.96008301e-02,  -5.96008301e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  1.10107422e-01,   1.10137939e-01],
                        [  1.59149170e-01,   1.59149170e-01],
                        [  1.92810059e-01,   1.92810059e-01],
                        [  1.94610596e-01,   1.94641113e-01],
                        [  1.68212891e-01,   1.68212891e-01],
                        [  1.38244629e-01,   1.38214111e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.25305176e-01,   1.25335693e-01],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  1.04217529e-01,   1.04187012e-01],
                        [  7.72705078e-02,   7.72705078e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  3.78417969e-02,   3.78417969e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  2.84423828e-02,   2.84729004e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  5.00488281e-03,   5.03540039e-03],
                        [ -7.35473633e-03,  -7.38525391e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  1.06811523e-03,   1.09863281e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  4.62646484e-02,   4.62341309e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.26770020e-01,   1.26770020e-01],
                        [  1.26098633e-01,   1.26068115e-01],
                        [  8.75244141e-02,   8.75244141e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -9.96704102e-02,  -9.96704102e-02],
                        [ -1.89880371e-01,  -1.89880371e-01],
                        [ -2.28912354e-01,  -2.28881836e-01],
                        [ -2.10937500e-01,  -2.10937500e-01],
                        [ -1.60766602e-01,  -1.60766602e-01],
                        [ -1.12152100e-01,  -1.12121582e-01],
                        [ -8.53271484e-02,  -8.53271484e-02],
                        [ -7.88574219e-02,  -7.88879395e-02],
                        [ -7.84912109e-02,  -7.84606934e-02],
                        [ -7.34558105e-02,  -7.34558105e-02],
                        [ -6.54907227e-02,  -6.54907227e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -6.11267090e-02,  -6.11267090e-02],
                        [ -5.22155762e-02,  -5.21850586e-02],
                        [ -4.39758301e-02,  -4.39453125e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.88183594e-02,  -3.88183594e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -6.35375977e-02,  -6.35375977e-02],
                        [ -8.15124512e-02,  -8.15124512e-02],
                        [ -9.01489258e-02,  -9.01794434e-02],
                        [ -8.52355957e-02,  -8.52355957e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  9.87548828e-02,   9.87548828e-02],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  8.67919922e-02,   8.67919922e-02],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  1.01745605e-01,   1.01745605e-01],
                        [  9.57031250e-02,   9.56726074e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.37207031e-01,   1.37207031e-01],
                        [  1.52954102e-01,   1.52954102e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.41174316e-01,   1.41174316e-01],
                        [  8.24890137e-02,   8.24890137e-02],
                        [ -5.34057617e-03,  -5.37109375e-03],
                        [ -1.00219727e-01,  -1.00219727e-01],
                        [ -1.86218262e-01,  -1.86218262e-01],
                        [ -2.52777100e-01,  -2.52807617e-01],
                        [ -2.82775879e-01,  -2.82775879e-01],
                        [ -2.62268066e-01,  -2.62268066e-01],
                        [ -2.05078125e-01,  -2.05078125e-01],
                        [ -1.49414062e-01,  -1.49444580e-01],
                        [ -1.21826172e-01,  -1.21826172e-01],
                        [ -1.15539551e-01,  -1.15539551e-01],
                        [ -1.09924316e-01,  -1.09924316e-01],
                        [ -9.77478027e-02,  -9.77478027e-02],
                        [ -8.50830078e-02,  -8.50830078e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -6.66503906e-02,  -6.66503906e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  8.30993652e-02,   8.30993652e-02],
                        [  1.38824463e-01,   1.38824463e-01],
                        [  1.82556152e-01,   1.82556152e-01],
                        [  2.00317383e-01,   2.00317383e-01],
                        [  1.91741943e-01,   1.91741943e-01],
                        [  1.69158936e-01,   1.69158936e-01],
                        [  1.45507812e-01,   1.45507812e-01],
                        [  1.27349854e-01,   1.27349854e-01],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  4.15039062e-02,   4.15039062e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.20739746e-02,  -3.20739746e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  1.41906738e-02,   1.42211914e-02],
                        [  2.78625488e-02,   2.78320312e-02],
                        [  2.92358398e-02,   2.92053223e-02],
                        [  2.35290527e-02,   2.35595703e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.12707520e-02,   2.12402344e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  4.02221680e-02,   4.02526855e-02],
                        [  5.13000488e-02,   5.13000488e-02],
                        [  6.56127930e-02,   6.56127930e-02],
                        [  8.66088867e-02,   8.66088867e-02],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.15173340e-01,   1.15173340e-01],
                        [  8.32519531e-02,   8.32824707e-02],
                        [  6.89697266e-03,   6.89697266e-03],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -1.77215576e-01,  -1.77215576e-01],
                        [ -2.09899902e-01,  -2.09899902e-01],
                        [ -1.86370850e-01,  -1.86370850e-01],
                        [ -1.35681152e-01,  -1.35681152e-01],
                        [ -9.67407227e-02,  -9.67407227e-02],
                        [ -8.66394043e-02,  -8.66394043e-02],
                        [ -9.26818848e-02,  -9.27124023e-02],
                        [ -9.32006836e-02,  -9.32006836e-02],
                        [ -8.13598633e-02,  -8.13598633e-02],
                        [ -6.64367676e-02,  -6.64367676e-02],
                        [ -5.66406250e-02,  -5.66711426e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.23278809e-02,  -4.23583984e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.61120605e-02,  -4.61425781e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -8.62731934e-02,  -8.63037109e-02],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -9.75952148e-02,  -9.75646973e-02],
                        [ -7.73315430e-02,  -7.73315430e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  1.06445312e-01,   1.06414795e-01],
                        [  1.38793945e-01,   1.38763428e-01],
                        [  1.43310547e-01,   1.43341064e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.18591309e-01,   1.18591309e-01],
                        [  1.07635498e-01,   1.07635498e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  8.66394043e-02,   8.66394043e-02],
                        [  9.57031250e-02,   9.57031250e-02],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.38885498e-01,   1.38854980e-01],
                        [  1.49932861e-01,   1.49932861e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.35864258e-01,   1.35864258e-01],
                        [  8.79516602e-02,   8.79516602e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -1.00036621e-01,  -1.00036621e-01],
                        [ -2.05200195e-01,  -2.05200195e-01],
                        [ -2.81677246e-01,  -2.81677246e-01],
                        [ -3.04565430e-01,  -3.04565430e-01],
                        [ -2.68432617e-01,  -2.68432617e-01],
                        [ -1.98425293e-01,  -1.98455811e-01],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -1.01959229e-01,  -1.01959229e-01],
                        [ -9.24072266e-02,  -9.24072266e-02],
                        [ -9.09118652e-02,  -9.09423828e-02],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -1.00128174e-01,  -1.00128174e-01],
                        [ -1.03942871e-01,  -1.03942871e-01],
                        [ -9.36584473e-02,  -9.36889648e-02],
                        [ -7.04956055e-02,  -7.04956055e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -3.15246582e-02,  -3.15551758e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [  2.83813477e-02,   2.83813477e-02],
                        [  7.87353516e-02,   7.87048340e-02],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.71997070e-01,   1.71997070e-01],
                        [  1.91406250e-01,   1.91375732e-01],
                        [  1.85913086e-01,   1.85913086e-01],
                        [  1.63726807e-01,   1.63726807e-01],
                        [  1.42425537e-01,   1.42395020e-01],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.24114990e-01,   1.24114990e-01],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  8.78295898e-02,   8.78295898e-02],
                        [  7.44628906e-02,   7.44628906e-02],
                        [  6.83898926e-02,   6.83898926e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  5.84716797e-02,   5.84716797e-02],
                        [  5.02319336e-02,   5.02319336e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  1.61437988e-02,   1.61132812e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.20849609e-02,   1.20849609e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  1.73645020e-02,   1.73339844e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  5.82275391e-02,   5.82275391e-02],
                        [  7.46459961e-02,   7.46154785e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  4.92553711e-02,   4.92553711e-02],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -9.62219238e-02,  -9.61914062e-02],
                        [ -1.68975830e-01,  -1.68975830e-01],
                        [ -1.98394775e-01,  -1.98394775e-01],
                        [ -1.75201416e-01,  -1.75170898e-01],
                        [ -1.23748779e-01,  -1.23748779e-01],
                        [ -8.26721191e-02,  -8.26721191e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -8.45947266e-02,  -8.45947266e-02],
                        [ -7.73620605e-02,  -7.73620605e-02],
                        [ -7.11059570e-02,  -7.11059570e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -8.59069824e-02,  -8.59069824e-02],
                        [ -9.46655273e-02,  -9.46655273e-02],
                        [ -9.54895020e-02,  -9.54895020e-02],
                        [ -8.38623047e-02,  -8.38623047e-02],
                        [ -6.14624023e-02,  -6.14624023e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  6.26831055e-02,   6.26831055e-02],
                        [  9.52148438e-02,   9.52148438e-02],
                        [  1.16210938e-01,   1.16210938e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.11480713e-01,   1.11450195e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  9.03320312e-02,   9.03320312e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.75018311e-01,   1.75018311e-01],
                        [  1.84844971e-01,   1.84844971e-01],
                        [  1.71295166e-01,   1.71295166e-01],
                        [  1.30310059e-01,   1.30310059e-01],
                        [  6.24694824e-02,   6.24694824e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -1.38397217e-01,  -1.38397217e-01],
                        [ -2.39135742e-01,  -2.39166260e-01],
                        [ -2.99346924e-01,  -2.99346924e-01],
                        [ -3.00750732e-01,  -3.00750732e-01],
                        [ -2.55859375e-01,  -2.55859375e-01],
                        [ -1.97723389e-01,  -1.97723389e-01],
                        [ -1.54754639e-01,  -1.54754639e-01],
                        [ -1.32965088e-01,  -1.32965088e-01],
                        [ -1.18194580e-01,  -1.18225098e-01],
                        [ -9.66796875e-02,  -9.66796875e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -5.77697754e-02,  -5.77697754e-02],
                        [ -5.50537109e-02,  -5.50537109e-02],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -2.88696289e-02,  -2.88696289e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  7.34863281e-02,   7.34863281e-02],
                        [  1.38763428e-01,   1.38763428e-01],
                        [  1.87896729e-01,   1.87896729e-01],
                        [  2.15240479e-01,   2.15240479e-01],
                        [  2.22534180e-01,   2.22534180e-01],
                        [  2.11334229e-01,   2.11334229e-01],
                        [  1.85394287e-01,   1.85394287e-01],
                        [  1.52893066e-01,   1.52893066e-01],
                        [  1.23016357e-01,   1.23016357e-01],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  8.30688477e-02,   8.30688477e-02],
                        [  6.72607422e-02,   6.72607422e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  5.06286621e-02,   5.05981445e-02],
                        [  5.09643555e-02,   5.09643555e-02],
                        [  4.80651855e-02,   4.80651855e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.14538574e-02,  -2.14843750e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  1.40380859e-03,   1.43432617e-03],
                        [  6.25610352e-03,   6.22558594e-03],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  6.32629395e-02,   6.32629395e-02],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  9.90600586e-02,   9.90295410e-02],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  9.21325684e-02,   9.21325684e-02],
                        [  7.28454590e-02,   7.28454590e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -1.10382080e-01,  -1.10351562e-01],
                        [ -1.68060303e-01,  -1.68060303e-01],
                        [ -1.86370850e-01,  -1.86370850e-01],
                        [ -1.63055420e-01,  -1.63055420e-01],
                        [ -1.19506836e-01,  -1.19506836e-01],
                        [ -8.54797363e-02,  -8.54797363e-02],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -8.09631348e-02,  -8.09326172e-02],
                        [ -8.52050781e-02,  -8.52050781e-02],
                        [ -8.28552246e-02,  -8.28857422e-02],
                        [ -8.05664062e-02,  -8.05664062e-02],
                        [ -8.46862793e-02,  -8.46862793e-02],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -9.80529785e-02,  -9.80529785e-02],
                        [ -9.15222168e-02,  -9.15222168e-02],
                        [ -7.45849609e-02,  -7.46154785e-02],
                        [ -5.70983887e-02,  -5.70983887e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -5.08117676e-02,  -5.08117676e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [  1.09558105e-02,   1.09252930e-02],
                        [  5.59997559e-02,   5.59997559e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.13708496e-01,   1.13739014e-01],
                        [  1.03729248e-01,   1.03729248e-01],
                        [  9.84191895e-02,   9.83886719e-02],
                        [  9.93652344e-02,   9.93652344e-02],
                        [  1.04705811e-01,   1.04705811e-01],
                        [  1.12304688e-01,   1.12304688e-01],
                        [  1.20147705e-01,   1.20147705e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.42791748e-01,   1.42791748e-01],
                        [  1.66778564e-01,   1.66778564e-01],
                        [  1.91986084e-01,   1.91986084e-01],
                        [  1.99615479e-01,   1.99615479e-01],
                        [  1.74072266e-01,   1.74102783e-01],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  1.05285645e-02,   1.05285645e-02],
                        [ -1.10382080e-01,  -1.10382080e-01],
                        [ -2.26470947e-01,  -2.26470947e-01],
                        [ -3.06030273e-01,  -3.06030273e-01],
                        [ -3.24523926e-01,  -3.24523926e-01],
                        [ -2.78137207e-01,  -2.78137207e-01],
                        [ -1.95770264e-01,  -1.95770264e-01],
                        [ -1.27716064e-01,  -1.27716064e-01],
                        [ -1.04003906e-01,  -1.04003906e-01],
                        [ -1.09313965e-01,  -1.09313965e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -9.97619629e-02,  -9.97619629e-02],
                        [ -8.83789062e-02,  -8.83789062e-02],
                        [ -8.40454102e-02,  -8.40454102e-02],
                        [ -7.99560547e-02,  -7.99560547e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -4.33044434e-02,  -4.33044434e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  1.44287109e-01,   1.44287109e-01],
                        [  1.88720703e-01,   1.88720703e-01],
                        [  2.06298828e-01,   2.06298828e-01],
                        [  1.93328857e-01,   1.93298340e-01],
                        [  1.63360596e-01,   1.63360596e-01],
                        [  1.37023926e-01,   1.37023926e-01],
                        [  1.24481201e-01,   1.24481201e-01],
                        [  1.20819092e-01,   1.20819092e-01],
                        [  1.16699219e-01,   1.16699219e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.58691406e-03,   1.58691406e-03],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -4.33349609e-03,  -4.33349609e-03],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.56958008e-02,  -2.57263184e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -2.50854492e-02,  -2.50854492e-02],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [  1.11999512e-02,   1.11694336e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.54418945e-02,   1.54418945e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  7.47375488e-02,   7.47375488e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  9.61608887e-02,   9.61608887e-02],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  5.65185547e-02,   5.65185547e-02],
                        [ -2.47192383e-03,  -2.47192383e-03],
                        [ -7.00988770e-02,  -7.01293945e-02],
                        [ -1.28753662e-01,  -1.28753662e-01],
                        [ -1.65039062e-01,  -1.65039062e-01],
                        [ -1.71234131e-01,  -1.71234131e-01],
                        [ -1.53656006e-01,  -1.53656006e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.18286133e-01,  -1.18286133e-01],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -1.11541748e-01,  -1.11511230e-01],
                        [ -1.06414795e-01,  -1.06414795e-01],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -8.70971680e-02,  -8.70971680e-02],
                        [ -8.20617676e-02,  -8.20617676e-02],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -5.33447266e-02,  -5.33142090e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.54296875e-02,  -6.54296875e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -1.89208984e-03,  -1.92260742e-03],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  1.27532959e-01,   1.27532959e-01],
                        [  1.30126953e-01,   1.30126953e-01],
                        [  1.28662109e-01,   1.28662109e-01],
                        [  1.19995117e-01,   1.19995117e-01],
                        [  1.08612061e-01,   1.08612061e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  1.01409912e-01,   1.01409912e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.26373291e-01,   1.26373291e-01],
                        [  1.49261475e-01,   1.49261475e-01],
                        [  1.70104980e-01,   1.70104980e-01],
                        [  1.79718018e-01,   1.79718018e-01],
                        [  1.69830322e-01,   1.69830322e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  6.30187988e-02,   6.30187988e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -1.50756836e-01,  -1.50756836e-01],
                        [ -2.51220703e-01,  -2.51220703e-01],
                        [ -3.06243896e-01,  -3.06243896e-01],
                        [ -2.96783447e-01,  -2.96783447e-01],
                        [ -2.35443115e-01,  -2.35443115e-01],
                        [ -1.65985107e-01,  -1.65985107e-01],
                        [ -1.29791260e-01,  -1.29791260e-01],
                        [ -1.29302979e-01,  -1.29302979e-01],
                        [ -1.33636475e-01,  -1.33636475e-01],
                        [ -1.19262695e-01,  -1.19262695e-01],
                        [ -9.25903320e-02,  -9.25903320e-02],
                        [ -7.11975098e-02,  -7.11975098e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  1.59973145e-01,   1.59973145e-01],
                        [  1.95892334e-01,   1.95892334e-01],
                        [  2.04772949e-01,   2.04772949e-01],
                        [  1.91619873e-01,   1.91619873e-01],
                        [  1.69921875e-01,   1.69921875e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.19476318e-01,   1.19476318e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  1.00280762e-01,   1.00280762e-01],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  7.26318359e-02,   7.26318359e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  1.22070312e-04,   1.22070312e-04],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.80664062e-02,   1.80664062e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -1.25122070e-02,  -1.25122070e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -1.07727051e-02,  -1.07727051e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  8.87145996e-02,   8.87145996e-02],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  1.02569580e-01,   1.02569580e-01],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [ -5.16662598e-02,  -5.16662598e-02],
                        [ -1.30065918e-01,  -1.30065918e-01],
                        [ -1.81884766e-01,  -1.81884766e-01],
                        [ -1.93206787e-01,  -1.93206787e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -1.43615723e-01,  -1.43615723e-01],
                        [ -1.25366211e-01,  -1.25366211e-01],
                        [ -1.20422363e-01,  -1.20422363e-01],
                        [ -1.18103027e-01,  -1.18103027e-01],
                        [ -1.07696533e-01,  -1.07696533e-01],
                        [ -9.03930664e-02,  -9.03930664e-02],
                        [ -7.75451660e-02,  -7.75451660e-02],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -7.42797852e-02,  -7.42797852e-02],
                        [ -6.86950684e-02,  -6.86950684e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -6.00891113e-02,  -6.00891113e-02],
                        [ -6.02416992e-02,  -6.02416992e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -7.18994141e-02,  -7.18994141e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -6.78405762e-02,  -6.78405762e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  9.48181152e-02,   9.48181152e-02],
                        [  1.14074707e-01,   1.14074707e-01],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.07391357e-01,   1.07391357e-01],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  9.54284668e-02,   9.54284668e-02],
                        [  1.07879639e-01,   1.07879639e-01],
                        [  1.32934570e-01,   1.32934570e-01],
                        [  1.61132812e-01,   1.61132812e-01],
                        [  1.84692383e-01,   1.84692383e-01],
                        [  2.01080322e-01,   2.01080322e-01],
                        [  2.06207275e-01,   2.06207275e-01],
                        [  1.89849854e-01,   1.89849854e-01],
                        [  1.40991211e-01,   1.40991211e-01],
                        [  5.71899414e-02,   5.71899414e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -1.67358398e-01,  -1.67327881e-01],
                        [ -2.66357422e-01,  -2.66357422e-01],
                        [ -3.25653076e-01,  -3.25653076e-01],
                        [ -3.28125000e-01,  -3.28125000e-01],
                        [ -2.75451660e-01,  -2.75451660e-01],
                        [ -1.95678711e-01,  -1.95678711e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -9.64660645e-02,  -9.64660645e-02],
                        [ -9.13696289e-02,  -9.13696289e-02],
                        [ -9.09423828e-02,  -9.09423828e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -7.10449219e-02,  -7.10449219e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -7.07702637e-02,  -7.07702637e-02],
                        [ -7.59887695e-02,  -7.59887695e-02],
                        [ -7.43103027e-02,  -7.43103027e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  7.45239258e-02,   7.45239258e-02],
                        [  1.30279541e-01,   1.30279541e-01],
                        [  1.73767090e-01,   1.73767090e-01],
                        [  1.94915771e-01,   1.94915771e-01],
                        [  1.90185547e-01,   1.90185547e-01],
                        [  1.67541504e-01,   1.67541504e-01],
                        [  1.43798828e-01,   1.43798828e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.12823486e-01,   1.12823486e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  8.48999023e-02,   8.48999023e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  1.33361816e-02,   1.33361816e-02],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.32446289e-02,  -1.32446289e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.67028809e-02,   2.67028809e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  5.38330078e-02,   5.38330078e-02],
                        [  6.42089844e-02,   6.42089844e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  8.03222656e-02,   8.03222656e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -1.16241455e-01,  -1.16241455e-01],
                        [ -1.71691895e-01,  -1.71691895e-01],
                        [ -1.85119629e-01,  -1.85119629e-01],
                        [ -1.61895752e-01,  -1.61895752e-01],
                        [ -1.26098633e-01,  -1.26098633e-01],
                        [ -1.04248047e-01,  -1.04248047e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -1.15081787e-01,  -1.15081787e-01],
                        [ -1.17736816e-01,  -1.17736816e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -9.20104980e-02,  -9.20104980e-02],
                        [ -8.28857422e-02,  -8.28857422e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -8.18786621e-02,  -8.18786621e-02],
                        [ -7.35168457e-02,  -7.35168457e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -5.45349121e-02,  -5.45349121e-02],
                        [ -5.28259277e-02,  -5.28259277e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  9.07592773e-02,   9.07592773e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  1.05712891e-01,   1.05712891e-01],
                        [  1.20849609e-01,   1.20849609e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.57562256e-01,   1.57562256e-01],
                        [  1.79534912e-01,   1.79534912e-01],
                        [  1.97845459e-01,   1.97845459e-01],
                        [  2.04559326e-01,   2.04559326e-01],
                        [  1.96075439e-01,   1.96075439e-01],
                        [  1.64001465e-01,   1.64001465e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -1.12426758e-01,  -1.12426758e-01],
                        [ -2.20153809e-01,  -2.20153809e-01],
                        [ -2.98126221e-01,  -2.98126221e-01],
                        [ -3.22113037e-01,  -3.22113037e-01],
                        [ -2.87658691e-01,  -2.87658691e-01],
                        [ -2.20581055e-01,  -2.20581055e-01],
                        [ -1.56829834e-01,  -1.56829834e-01],
                        [ -1.16729736e-01,  -1.16729736e-01],
                        [ -9.92126465e-02,  -9.92126465e-02],
                        [ -9.08203125e-02,  -9.08203125e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -6.45446777e-02,  -6.45446777e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -5.23681641e-02,  -5.23681641e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.56494141e-01,   1.56494141e-01],
                        [  1.91345215e-01,   1.91345215e-01],
                        [  1.95404053e-01,   1.95404053e-01],
                        [  1.75872803e-01,   1.75872803e-01],
                        [  1.51000977e-01,   1.51000977e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.28906250e-01,   1.28906250e-01],
                        [  1.25640869e-01,   1.25640869e-01],
                        [  1.15203857e-01,   1.15203857e-01],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  8.92944336e-02,   8.92944336e-02],
                        [  8.10241699e-02,   8.10241699e-02],
                        [  6.77185059e-02,   6.77185059e-02],
                        [  4.68444824e-02,   4.68444824e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -5.64575195e-03,  -5.64575195e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -8.98437500e-02,  -8.98437500e-02],
                        [ -1.61804199e-01,  -1.61804199e-01],
                        [ -1.97204590e-01,  -1.97204590e-01],
                        [ -1.85577393e-01,  -1.85577393e-01],
                        [ -1.48773193e-01,  -1.48773193e-01],
                        [ -1.18865967e-01,  -1.18865967e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -1.12609863e-01,  -1.12609863e-01],
                        [ -1.10229492e-01,  -1.10229492e-01],
                        [ -1.01684570e-01,  -1.01684570e-01],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -9.59472656e-02,  -9.59472656e-02],
                        [ -9.79309082e-02,  -9.79309082e-02],
                        [ -8.97216797e-02,  -8.97216797e-02],
                        [ -7.25402832e-02,  -7.25402832e-02],
                        [ -5.69458008e-02,  -5.69458008e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.38537598e-02,  -4.38537598e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.14776611e-01,   1.14776611e-01],
                        [  1.13647461e-01,   1.13647461e-01],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  1.30096436e-01,   1.30096436e-01],
                        [  1.47033691e-01,   1.47033691e-01],
                        [  1.69555664e-01,   1.69555664e-01],
                        [  1.97235107e-01,   1.97235107e-01],
                        [  2.19177246e-01,   2.19177246e-01],
                        [  2.18109131e-01,   2.18109131e-01],
                        [  1.83044434e-01,   1.83044434e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.78833008e-02,   1.78833008e-02],
                        [ -9.20410156e-02,  -9.20410156e-02],
                        [ -1.98577881e-01,  -1.98577881e-01],
                        [ -2.80761719e-01,  -2.80761719e-01],
                        [ -3.16650391e-01,  -3.16650391e-01],
                        [ -2.95257568e-01,  -2.95257568e-01],
                        [ -2.33337402e-01,  -2.33337402e-01],
                        [ -1.70227051e-01,  -1.70227051e-01],
                        [ -1.35345459e-01,  -1.35345459e-01],
                        [ -1.24938965e-01,  -1.24938965e-01],
                        [ -1.16455078e-01,  -1.16455078e-01],
                        [ -9.74426270e-02,  -9.74426270e-02],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -6.74743652e-02,  -6.74743652e-02],
                        [ -7.55004883e-02,  -7.55004883e-02],
                        [ -8.66394043e-02,  -8.66394043e-02],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -6.50329590e-02,  -6.50329590e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  6.79016113e-02,   6.79016113e-02],
                        [  1.23718262e-01,   1.23718262e-01],
                        [  1.73553467e-01,   1.73553467e-01],
                        [  2.01263428e-01,   2.01263428e-01],
                        [  1.99066162e-01,   1.99066162e-01],
                        [  1.75903320e-01,   1.75903320e-01],
                        [  1.51397705e-01,   1.51397705e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.32812500e-01,   1.32812500e-01],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  5.98144531e-02,   5.98144531e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  1.09558105e-01,   1.09558105e-01],
                        [  1.06933594e-01,   1.06933594e-01],
                        [  9.03320312e-02,   9.03320312e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.06140137e-01,  -1.06140137e-01],
                        [ -1.78375244e-01,  -1.78375244e-01],
                        [ -2.17254639e-01,  -2.17254639e-01],
                        [ -2.12219238e-01,  -2.12219238e-01],
                        [ -1.77795410e-01,  -1.77795410e-01],
                        [ -1.42547607e-01,  -1.42547607e-01],
                        [ -1.21856689e-01,  -1.21856689e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -1.04095459e-01,  -1.04095459e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -1.07543945e-01,  -1.07543945e-01],
                        [ -1.13861084e-01,  -1.13861084e-01],
                        [ -1.12091064e-01,  -1.12091064e-01],
                        [ -9.81750488e-02,  -9.81750488e-02],
                        [ -7.32727051e-02,  -7.32727051e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -4.77905273e-02,  -4.77905273e-02],
                        [ -4.54711914e-02,  -4.54711914e-02],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  1.11389160e-01,   1.11389160e-01],
                        [  1.27227783e-01,   1.27227783e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.31134033e-01,   1.31134033e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.48254395e-01,   1.48254395e-01],
                        [  1.71539307e-01,   1.71539307e-01],
                        [  1.96929932e-01,   1.96929932e-01],
                        [  2.14721680e-01,   2.14721680e-01],
                        [  2.12158203e-01,   2.12158203e-01],
                        [  1.77246094e-01,   1.77246094e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  9.70458984e-03,   9.70458984e-03],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -2.11303711e-01,  -2.11303711e-01],
                        [ -2.90039062e-01,  -2.90039062e-01],
                        [ -3.14636230e-01,  -3.14636230e-01],
                        [ -2.81219482e-01,  -2.81219482e-01],
                        [ -2.14172363e-01,  -2.14172363e-01],
                        [ -1.50604248e-01,  -1.50604248e-01],
                        [ -1.14044189e-01,  -1.14044189e-01],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -1.12152100e-01,  -1.12152100e-01],
                        [ -1.22833252e-01,  -1.22833252e-01],
                        [ -1.25030518e-01,  -1.25030518e-01],
                        [ -1.14379883e-01,  -1.14379883e-01],
                        [ -9.73815918e-02,  -9.73815918e-02],
                        [ -8.22143555e-02,  -8.22143555e-02],
                        [ -7.00073242e-02,  -7.00073242e-02],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [  1.24389648e-01,   1.24389648e-01],
                        [  1.85760498e-01,   1.85760498e-01],
                        [  2.27905273e-01,   2.27905273e-01],
                        [  2.33734131e-01,   2.33734131e-01],
                        [  2.04864502e-01,   2.04864502e-01],
                        [  1.63482666e-01,   1.63482666e-01],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.18621826e-01,   1.18621826e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  6.88781738e-02,   6.88781738e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  5.51757812e-02,   5.51757812e-02],
                        [  3.20739746e-02,   3.20739746e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  7.33032227e-02,   7.33032227e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  9.79309082e-02,   9.79309082e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  5.18798828e-04,   5.18798828e-04],
                        [ -7.75756836e-02,  -7.75756836e-02],
                        [ -1.50054932e-01,  -1.50054932e-01],
                        [ -1.97479248e-01,  -1.97479248e-01],
                        [ -2.07061768e-01,  -2.07061768e-01],
                        [ -1.83349609e-01,  -1.83349609e-01],
                        [ -1.49841309e-01,  -1.49841309e-01],
                        [ -1.30218506e-01,  -1.30218506e-01],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -1.21520996e-01,  -1.21520996e-01],
                        [ -1.13769531e-01,  -1.13769531e-01],
                        [ -1.09985352e-01,  -1.09985352e-01],
                        [ -1.04553223e-01,  -1.04553223e-01],
                        [ -8.91113281e-02,  -8.91113281e-02],
                        [ -6.70166016e-02,  -6.70166016e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -4.66003418e-02,  -4.66003418e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.19311523e-02,  -4.19311523e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  1.18835449e-01,   1.18835449e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.14562988e-01,   1.14562988e-01],
                        [  1.05163574e-01,   1.05163574e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.82495117e-01,   1.82495117e-01],
                        [  2.14782715e-01,   2.14782715e-01],
                        [  2.36633301e-01,   2.36633301e-01],
                        [  2.27325439e-01,   2.27325439e-01],
                        [  1.81762695e-01,   1.81762695e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  1.75781250e-02,   1.75781250e-02],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -2.04345703e-01,  -2.04345703e-01],
                        [ -2.90679932e-01,  -2.90679932e-01],
                        [ -3.21838379e-01,  -3.21838379e-01],
                        [ -2.89031982e-01,  -2.89031982e-01],
                        [ -2.17559814e-01,  -2.17559814e-01],
                        [ -1.54296875e-01,  -1.54296875e-01],
                        [ -1.27288818e-01,  -1.27288818e-01],
                        [ -1.24725342e-01,  -1.24725342e-01],
                        [ -1.23199463e-01,  -1.23199463e-01],
                        [ -1.17950439e-01,  -1.17950439e-01],
                        [ -1.14013672e-01,  -1.14013672e-01],
                        [ -1.09283447e-01,  -1.09283447e-01],
                        [ -1.00311279e-01,  -1.00311279e-01],
                        [ -8.98742676e-02,  -8.98742676e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [  2.79846191e-02,   2.79846191e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  1.51824951e-01,   1.51824951e-01],
                        [  2.09320068e-01,   2.09320068e-01],
                        [  2.42126465e-01,   2.42126465e-01],
                        [  2.32482910e-01,   2.32482910e-01],
                        [  1.89056396e-01,   1.89056396e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.14379883e-01,   1.14379883e-01],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  8.92333984e-02,   8.92333984e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  7.07092285e-02,   7.07092285e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  6.56127930e-03,   6.56127930e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -5.27648926e-02,  -5.27648926e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.19616699e-02,  -4.19616699e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  3.37524414e-02,   3.37524414e-02],
                        [  4.84619141e-02,   4.84619141e-02],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  6.88476562e-02,   6.88476562e-02],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  8.85620117e-02,   8.85620117e-02],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  3.41796875e-02,   3.41796875e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -1.11999512e-01,  -1.11999512e-01],
                        [ -1.75964355e-01,  -1.75964355e-01],
                        [ -2.05841064e-01,  -2.05841064e-01],
                        [ -1.96258545e-01,  -1.96258545e-01],
                        [ -1.65252686e-01,  -1.65252686e-01],
                        [ -1.36962891e-01,  -1.36962891e-01],
                        [ -1.20635986e-01,  -1.20635986e-01],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -1.06506348e-01,  -1.06506348e-01],
                        [ -1.06323242e-01,  -1.06323242e-01],
                        [ -1.10260010e-01,  -1.10260010e-01],
                        [ -1.10778809e-01,  -1.10778809e-01],
                        [ -1.01074219e-01,  -1.01074219e-01],
                        [ -8.41674805e-02,  -8.41674805e-02],
                        [ -7.01904297e-02,  -7.01904297e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -6.85424805e-02,  -6.85424805e-02],
                        [ -7.22045898e-02,  -7.22045898e-02],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -5.79528809e-02,  -5.79528809e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  1.29852295e-01,   1.29852295e-01],
                        [  1.25823975e-01,   1.25823975e-01],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  1.08520508e-01,   1.08520508e-01],
                        [  1.35681152e-01,   1.35681152e-01],
                        [  1.56524658e-01,   1.56524658e-01],
                        [  1.75476074e-01,   1.75476074e-01],
                        [  2.03308105e-01,   2.03308105e-01],
                        [  2.27966309e-01,   2.27966309e-01],
                        [  2.23388672e-01,   2.23388672e-01],
                        [  1.79626465e-01,   1.79626465e-01],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  3.90625000e-03,   3.90625000e-03],
                        [ -1.14227295e-01,  -1.14227295e-01],
                        [ -2.28851318e-01,  -2.28851318e-01],
                        [ -3.06884766e-01,  -3.06884766e-01],
                        [ -3.23059082e-01,  -3.23059082e-01],
                        [ -2.78961182e-01,  -2.78961182e-01],
                        [ -2.07458496e-01,  -2.07458496e-01],
                        [ -1.50939941e-01,  -1.50939941e-01],
                        [ -1.27655029e-01,  -1.27655029e-01],
                        [ -1.23535156e-01,  -1.23535156e-01],
                        [ -1.17828369e-01,  -1.17828369e-01],
                        [ -1.06567383e-01,  -1.06567383e-01],
                        [ -9.69238281e-02,  -9.69238281e-02],
                        [ -9.13391113e-02,  -9.13391113e-02],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -8.61511230e-02,  -8.61511230e-02],
                        [ -8.29467773e-02,  -8.29467773e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  6.14929199e-02,   6.14929199e-02],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  1.69647217e-01,   1.69647217e-01],
                        [  2.01080322e-01,   2.01080322e-01],
                        [  2.08648682e-01,   2.08648682e-01],
                        [  1.95678711e-01,   1.95678711e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.44378662e-01,   1.44378662e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.23291016e-01,   1.23291016e-01],
                        [  1.18408203e-01,   1.18408203e-01],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -2.49633789e-02,  -2.49633789e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [  2.13623047e-03,   2.13623047e-03],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.47192383e-02,   2.47192383e-02],
                        [  3.77807617e-02,   3.77807617e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  8.55712891e-02,   8.55712891e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  7.44628906e-02,   7.44628906e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -1.27288818e-01,  -1.27288818e-01],
                        [ -1.95434570e-01,  -1.95434570e-01],
                        [ -2.14813232e-01,  -2.14813232e-01],
                        [ -1.86340332e-01,  -1.86340332e-01],
                        [ -1.39404297e-01,  -1.39404297e-01],
                        [ -1.06597900e-01,  -1.06597900e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -1.15936279e-01,  -1.15936279e-01],
                        [ -1.25885010e-01,  -1.25885010e-01],
                        [ -1.18560791e-01,  -1.18560791e-01],
                        [ -1.00341797e-01,  -1.00341797e-01],
                        [ -8.43505859e-02,  -8.43505859e-02],
                        [ -7.43713379e-02,  -7.43713379e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -7.19909668e-02,  -7.19909668e-02],
                        [ -7.94067383e-02,  -7.94067383e-02],
                        [ -7.97729492e-02,  -7.97729492e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -5.16967773e-02,  -5.16967773e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  8.38928223e-02,   8.38928223e-02],
                        [  1.12731934e-01,   1.12731934e-01],
                        [  1.18957520e-01,   1.18957520e-01],
                        [  1.09466553e-01,   1.09466553e-01],
                        [  9.89074707e-02,   9.89074707e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.21459961e-01,   1.21459961e-01],
                        [  1.46606445e-01,   1.46606445e-01],
                        [  1.64947510e-01,   1.64947510e-01],
                        [  1.74926758e-01,   1.74926758e-01],
                        [  1.84143066e-01,   1.84143066e-01],
                        [  1.96441650e-01,   1.96441650e-01],
                        [  2.03033447e-01,   2.03033447e-01],
                        [  1.86309814e-01,   1.86309814e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  4.02221680e-02,   4.02221680e-02],
                        [ -7.31506348e-02,  -7.31506348e-02],
                        [ -1.84204102e-01,  -1.84204102e-01],
                        [ -2.69927979e-01,  -2.69927979e-01],
                        [ -3.09875488e-01,  -3.09875488e-01],
                        [ -2.91564941e-01,  -2.91564941e-01],
                        [ -2.27111816e-01,  -2.27111816e-01],
                        [ -1.56127930e-01,  -1.56127930e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -1.07788086e-01,  -1.07788086e-01],
                        [ -1.08245850e-01,  -1.08245850e-01],
                        [ -1.04339600e-01,  -1.04339600e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -1.07727051e-01,  -1.07727051e-01],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -8.90502930e-02,  -8.90502930e-02],
                        [ -6.66198730e-02,  -6.66198730e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  1.31958008e-01,   1.31958008e-01],
                        [  1.92321777e-01,   1.92321777e-01],
                        [  2.21557617e-01,   2.21557617e-01],
                        [  2.08099365e-01,   2.08099365e-01],
                        [  1.67572021e-01,   1.67572021e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.04919434e-01,   1.04919434e-01],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  1.17492676e-01,   1.17492676e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  1.14837646e-01,   1.14837646e-01],
                        [  8.72802734e-02,   8.72802734e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -3.99780273e-02,  -3.99780273e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  9.79614258e-03,   9.79614258e-03],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  7.55310059e-02,   7.55310059e-02],
                        [  9.12170410e-02,   9.12170410e-02],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [ -6.40869141e-02,  -6.40869141e-02],
                        [ -1.47064209e-01,  -1.47064209e-01],
                        [ -2.01751709e-01,  -2.01751709e-01],
                        [ -2.09686279e-01,  -2.09686279e-01],
                        [ -1.79473877e-01,  -1.79473877e-01],
                        [ -1.39190674e-01,  -1.39190674e-01],
                        [ -1.11633301e-01,  -1.11633301e-01],
                        [ -1.02447510e-01,  -1.02447510e-01],
                        [ -1.04003906e-01,  -1.04003906e-01],
                        [ -1.03485107e-01,  -1.03485107e-01],
                        [ -9.53369141e-02,  -9.53369141e-02],
                        [ -8.81042480e-02,  -8.81042480e-02],
                        [ -9.13085938e-02,  -9.13085938e-02],
                        [ -9.88159180e-02,  -9.88159180e-02],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -6.65893555e-02,  -6.65893555e-02],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  6.62231445e-02,   6.62231445e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  9.36279297e-02,   9.36279297e-02],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  9.73205566e-02,   9.73205566e-02],
                        [  1.04949951e-01,   1.04949951e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.40502930e-01,   1.40502930e-01],
                        [  1.51245117e-01,   1.51245117e-01],
                        [  1.59271240e-01,   1.59271240e-01],
                        [  1.74377441e-01,   1.74377441e-01],
                        [  1.94213867e-01,   1.94213867e-01],
                        [  2.05688477e-01,   2.05688477e-01],
                        [  1.96105957e-01,   1.96105957e-01],
                        [  1.55609131e-01,   1.55609131e-01],
                        [  7.82165527e-02,   7.82165527e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -1.51794434e-01,  -1.51794434e-01],
                        [ -2.54974365e-01,  -2.54974365e-01],
                        [ -3.13232422e-01,  -3.13232422e-01],
                        [ -3.10028076e-01,  -3.10028076e-01],
                        [ -2.53143311e-01,  -2.53143311e-01],
                        [ -1.79840088e-01,  -1.79840088e-01],
                        [ -1.31744385e-01,  -1.31744385e-01],
                        [ -1.18347168e-01,  -1.18347168e-01],
                        [ -1.18469238e-01,  -1.18469238e-01],
                        [ -1.15478516e-01,  -1.15478516e-01],
                        [ -1.13555908e-01,  -1.13555908e-01],
                        [ -1.17370605e-01,  -1.17370605e-01],
                        [ -1.18011475e-01,  -1.18011475e-01],
                        [ -1.07971191e-01,  -1.07971191e-01],
                        [ -9.08508301e-02,  -9.08508301e-02],
                        [ -6.71081543e-02,  -6.71081543e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [  2.30102539e-02,   2.30102539e-02],
                        [  7.92846680e-02,   7.92846680e-02],
                        [  1.32324219e-01,   1.32324219e-01],
                        [  1.79962158e-01,   1.79962158e-01],
                        [  2.12097168e-01,   2.12097168e-01],
                        [  2.12890625e-01,   2.12890625e-01],
                        [  1.81640625e-01,   1.81640625e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  1.16790771e-01,   1.16790771e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.34277344e-01,   1.34277344e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.18865967e-01,   1.18865967e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  7.24792480e-02,   7.24792480e-02],
                        [  5.65795898e-02,   5.65795898e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.22070312e-03,   1.22070312e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.29492188e-02,  -2.29492188e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -5.40161133e-03,  -5.40161133e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  9.51232910e-02,   9.51232910e-02],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -9.82055664e-02,  -9.82055664e-02],
                        [ -1.76177979e-01,  -1.76177979e-01],
                        [ -2.17712402e-01,  -2.17712402e-01],
                        [ -2.13867188e-01,  -2.13867188e-01],
                        [ -1.78039551e-01,  -1.78039551e-01],
                        [ -1.38397217e-01,  -1.38397217e-01],
                        [ -1.14013672e-01,  -1.14013672e-01],
                        [ -1.02966309e-01,  -1.02966309e-01],
                        [ -9.58557129e-02,  -9.58557129e-02],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -8.68530273e-02,  -8.68530273e-02],
                        [ -9.52148438e-02,  -9.52148438e-02],
                        [ -1.02355957e-01,  -1.02355957e-01],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -9.78393555e-02,  -9.78393555e-02],
                        [ -8.94775391e-02,  -8.94775391e-02],
                        [ -7.14111328e-02,  -7.14111328e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  1.26281738e-01,   1.26281738e-01],
                        [  1.48620605e-01,   1.48620605e-01],
                        [  1.71752930e-01,   1.71752930e-01],
                        [  2.02423096e-01,   2.02423096e-01],
                        [  2.30590820e-01,   2.30590820e-01],
                        [  2.32849121e-01,   2.32849121e-01],
                        [  1.95373535e-01,   1.95373535e-01],
                        [  1.20941162e-01,   1.20941162e-01],
                        [  1.75476074e-02,   1.75476074e-02],
                        [ -1.05072021e-01,  -1.05072021e-01],
                        [ -2.28179932e-01,  -2.28179932e-01],
                        [ -3.20465088e-01,  -3.20465088e-01],
                        [ -3.49731445e-01,  -3.49731445e-01],
                        [ -3.08837891e-01,  -3.08837891e-01],
                        [ -2.28851318e-01,  -2.28851318e-01],
                        [ -1.57165527e-01,  -1.57165527e-01],
                        [ -1.19903564e-01,  -1.19903564e-01],
                        [ -1.09588623e-01,  -1.09588623e-01],
                        [ -1.07574463e-01,  -1.07574463e-01],
                        [ -1.06323242e-01,  -1.06323242e-01],
                        [ -1.07482910e-01,  -1.07482910e-01],
                        [ -1.11022949e-01,  -1.11022949e-01],
                        [ -1.13677979e-01,  -1.13677979e-01],
                        [ -1.10534668e-01,  -1.10534668e-01],
                        [ -9.30786133e-02,  -9.30786133e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  7.91625977e-02,   7.91625977e-02],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.92810059e-01,   1.92810059e-01],
                        [  2.25402832e-01,   2.25402832e-01],
                        [  2.30285645e-01,   2.30285645e-01],
                        [  2.05993652e-01,   2.05993652e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  8.13293457e-02,   8.13293457e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  7.98339844e-02,   7.98339844e-02],
                        [  6.61926270e-02,   6.61926270e-02],
                        [  5.09643555e-02,   5.09643555e-02],
                        [  3.86047363e-02,   3.86047363e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.14349365e-01,   1.14349365e-01],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -1.46759033e-01,  -1.46759033e-01],
                        [ -1.99859619e-01,  -1.99859619e-01],
                        [ -2.18780518e-01,  -2.18780518e-01],
                        [ -2.00805664e-01,  -2.00805664e-01],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -1.24084473e-01,  -1.24084473e-01],
                        [ -1.02478027e-01,  -1.02478027e-01],
                        [ -9.21630859e-02,  -9.21630859e-02],
                        [ -8.63342285e-02,  -8.63342285e-02],
                        [ -8.62426758e-02,  -8.62426758e-02],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -1.02630615e-01,  -1.02630615e-01],
                        [ -1.08215332e-01,  -1.08215332e-01],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.04461670e-01,  -1.04461670e-01],
                        [ -9.85412598e-02,  -9.85412598e-02],
                        [ -8.61206055e-02,  -8.61206055e-02],
                        [ -5.82580566e-02,  -5.82580566e-02],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [  4.91943359e-02,   4.91943359e-02],
                        [  1.00738525e-01,   1.00738525e-01],
                        [  1.26068115e-01,   1.26068115e-01],
                        [  1.24786377e-01,   1.24786377e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  1.05041504e-01,   1.05041504e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.25885010e-01,   1.25885010e-01],
                        [  1.46759033e-01,   1.46759033e-01],
                        [  1.78771973e-01,   1.78771973e-01],
                        [  2.14019775e-01,   2.14019775e-01],
                        [  2.32696533e-01,   2.32696533e-01],
                        [  2.17437744e-01,   2.17437744e-01],
                        [  1.63879395e-01,   1.63879395e-01],
                        [  7.64465332e-02,   7.64465332e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -1.56646729e-01,  -1.56646729e-01],
                        [ -2.61352539e-01,  -2.61352539e-01],
                        [ -3.18054199e-01,  -3.18054199e-01],
                        [ -3.05664062e-01,  -3.05664062e-01],
                        [ -2.39013672e-01,  -2.39013672e-01],
                        [ -1.67175293e-01,  -1.67175293e-01],
                        [ -1.31469727e-01,  -1.31469727e-01],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -1.35803223e-01,  -1.35803223e-01],
                        [ -1.33575439e-01,  -1.33575439e-01],
                        [ -1.28417969e-01,  -1.28417969e-01],
                        [ -1.28479004e-01,  -1.28479004e-01],
                        [ -1.33941650e-01,  -1.33941650e-01],
                        [ -1.33361816e-01,  -1.33361816e-01],
                        [ -1.10321045e-01,  -1.10321045e-01],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  1.53930664e-01,   1.53930664e-01],
                        [  2.03277588e-01,   2.03277588e-01],
                        [  2.24395752e-01,   2.24395752e-01],
                        [  2.15393066e-01,   2.15393066e-01],
                        [  1.86584473e-01,   1.86584473e-01],
                        [  1.56036377e-01,   1.56036377e-01],
                        [  1.37878418e-01,   1.37878418e-01],
                        [  1.29150391e-01,   1.29150391e-01],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  9.43298340e-02,   9.43298340e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  7.64770508e-02,   7.64770508e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -3.87878418e-02,  -3.87878418e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -6.37817383e-02,  -6.37817383e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  8.02612305e-03,   8.02612305e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  5.95397949e-02,   5.95397949e-02],
                        [  7.46765137e-02,   7.46765137e-02],
                        [  9.51538086e-02,   9.51538086e-02],
                        [  1.06201172e-01,   1.06201172e-01],
                        [  9.82971191e-02,   9.82971191e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.06536865e-01,  -1.06536865e-01],
                        [ -1.82769775e-01,  -1.82769775e-01],
                        [ -2.23693848e-01,  -2.23693848e-01],
                        [ -2.20489502e-01,  -2.20489502e-01],
                        [ -1.89727783e-01,  -1.89727783e-01],
                        [ -1.56005859e-01,  -1.56005859e-01],
                        [ -1.33422852e-01,  -1.33422852e-01],
                        [ -1.21398926e-01,  -1.21398926e-01],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -9.74426270e-02,  -9.74426270e-02],
                        [ -8.18176270e-02,  -8.18176270e-02],
                        [ -7.63549805e-02,  -7.63549805e-02],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -9.70764160e-02,  -9.70764160e-02],
                        [ -9.79919434e-02,  -9.79919434e-02],
                        [ -8.64868164e-02,  -8.64868164e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  1.08184814e-01,   1.08184814e-01],
                        [  1.21032715e-01,   1.21032715e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.04675293e-01,   1.04675293e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.18560791e-01,   1.18560791e-01],
                        [  1.37390137e-01,   1.37390137e-01],
                        [  1.59820557e-01,   1.59820557e-01],
                        [  1.84265137e-01,   1.84265137e-01],
                        [  2.07183838e-01,   2.07183838e-01],
                        [  2.16888428e-01,   2.16888428e-01],
                        [  1.93359375e-01,   1.93359375e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -1.27593994e-01,  -1.27593994e-01],
                        [ -2.46398926e-01,  -2.46398926e-01],
                        [ -3.18603516e-01,  -3.18603516e-01],
                        [ -3.25714111e-01,  -3.25714111e-01],
                        [ -2.76519775e-01,  -2.76519775e-01],
                        [ -2.06787109e-01,  -2.06787109e-01],
                        [ -1.54724121e-01,  -1.54724121e-01],
                        [ -1.33728027e-01,  -1.33728027e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -1.29974365e-01,  -1.29974365e-01],
                        [ -1.24450684e-01,  -1.24450684e-01],
                        [ -1.20147705e-01,  -1.20147705e-01],
                        [ -1.20666504e-01,  -1.20666504e-01],
                        [ -1.19049072e-01,  -1.19049072e-01],
                        [ -1.02783203e-01,  -1.02783203e-01],
                        [ -6.20727539e-02,  -6.20727539e-02],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  8.76464844e-02,   8.76464844e-02],
                        [  1.65191650e-01,   1.65191650e-01],
                        [  2.17742920e-01,   2.17742920e-01],
                        [  2.35137939e-01,   2.35137939e-01],
                        [  2.17620850e-01,   2.17620850e-01],
                        [  1.77124023e-01,   1.77124023e-01],
                        [  1.35925293e-01,   1.35925293e-01],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.12335205e-01,   1.12335205e-01],
                        [  1.17614746e-01,   1.17614746e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  9.72900391e-02,   9.72900391e-02],
                        [  8.18176270e-02,   8.18176270e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  5.81054688e-02,   5.81054688e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.92456055e-02,  -3.92456055e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  4.99572754e-02,   4.99572754e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  7.70263672e-02,   7.70263672e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.16040039e-02,   8.16040039e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -1.04431152e-01,  -1.04431152e-01],
                        [ -1.72637939e-01,  -1.72637939e-01],
                        [ -2.10388184e-01,  -2.10388184e-01],
                        [ -2.11547852e-01,  -2.11547852e-01],
                        [ -1.88629150e-01,  -1.88629150e-01],
                        [ -1.58416748e-01,  -1.58416748e-01],
                        [ -1.31622314e-01,  -1.31622314e-01],
                        [ -1.12976074e-01,  -1.12976074e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -1.01531982e-01,  -1.01531982e-01],
                        [ -1.01562500e-01,  -1.01562500e-01],
                        [ -1.03332520e-01,  -1.03332520e-01],
                        [ -1.08978271e-01,  -1.08978271e-01],
                        [ -1.12579346e-01,  -1.12579346e-01],
                        [ -1.03057861e-01,  -1.03057861e-01],
                        [ -8.04443359e-02,  -8.04443359e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  8.00476074e-02,   8.00476074e-02],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.40869141e-01,   1.40869141e-01],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  1.09954834e-01,   1.09954834e-01],
                        [  1.36352539e-01,   1.36352539e-01],
                        [  1.69372559e-01,   1.69372559e-01],
                        [  2.03063965e-01,   2.03063965e-01],
                        [  2.22351074e-01,   2.22351074e-01],
                        [  2.15393066e-01,   2.15393066e-01],
                        [  1.76361084e-01,   1.76361084e-01],
                        [  1.01104736e-01,   1.01104736e-01],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -1.31103516e-01,  -1.31103516e-01],
                        [ -2.46368408e-01,  -2.46368408e-01],
                        [ -3.23211670e-01,  -3.23211670e-01],
                        [ -3.36029053e-01,  -3.36029053e-01],
                        [ -2.84881592e-01,  -2.84881592e-01],
                        [ -2.06939697e-01,  -2.06939697e-01],
                        [ -1.49505615e-01,  -1.49505615e-01],
                        [ -1.28692627e-01,  -1.28692627e-01],
                        [ -1.26464844e-01,  -1.26464844e-01],
                        [ -1.24633789e-01,  -1.24633789e-01],
                        [ -1.23504639e-01,  -1.23504639e-01],
                        [ -1.26556396e-01,  -1.26556396e-01],
                        [ -1.25946045e-01,  -1.25946045e-01],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  9.41467285e-02,   9.41467285e-02],
                        [  1.67480469e-01,   1.67480469e-01],
                        [  2.15454102e-01,   2.15454102e-01],
                        [  2.26379395e-01,   2.26379395e-01],
                        [  2.04589844e-01,   2.04589844e-01],
                        [  1.66656494e-01,   1.66656494e-01],
                        [  1.30981445e-01,   1.30981445e-01],
                        [  1.08459473e-01,   1.08459473e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.06750488e-01,   1.06750488e-01],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  3.40576172e-02,   3.40576172e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.97241211e-02,   2.97241211e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.33654785e-02,  -4.33654785e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  2.20947266e-02,   2.21252441e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.44653320e-02,   1.44348145e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  6.01806641e-02,   6.01806641e-02],
                        [  7.58056641e-02,   7.58056641e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  8.85925293e-02,   8.85925293e-02],
                        [  8.14514160e-02,   8.14514160e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -5.96313477e-02,  -5.96313477e-02],
                        [ -1.41265869e-01,  -1.41265869e-01],
                        [ -2.10845947e-01,  -2.10845947e-01],
                        [ -2.37243652e-01,  -2.37243652e-01],
                        [ -2.16125488e-01,  -2.16125488e-01],
                        [ -1.76086426e-01,  -1.76086426e-01],
                        [ -1.47583008e-01,  -1.47583008e-01],
                        [ -1.36352539e-01,  -1.36352539e-01],
                        [ -1.28143311e-01,  -1.28143311e-01],
                        [ -1.11968994e-01,  -1.11968994e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -8.14514160e-02,  -8.14514160e-02],
                        [ -8.10852051e-02,  -8.10852051e-02],
                        [ -8.54797363e-02,  -8.54797363e-02],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -8.30383301e-02,  -8.30383301e-02],
                        [ -6.83898926e-02,  -6.83898926e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  8.78906250e-02,   8.78906250e-02],
                        [  1.24786377e-01,   1.24786377e-01],
                        [  1.39343262e-01,   1.39343262e-01],
                        [  1.33209229e-01,   1.33209229e-01],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.21948242e-01,   1.21948242e-01],
                        [  1.37573242e-01,   1.37573242e-01],
                        [  1.60461426e-01,   1.60461426e-01],
                        [  1.81274414e-01,   1.81274414e-01],
                        [  1.97692871e-01,   1.97692871e-01],
                        [  2.08435059e-01,   2.08435059e-01],
                        [  2.03918457e-01,   2.03918457e-01],
                        [  1.67846680e-01,   1.67846680e-01],
                        [  8.99658203e-02,   8.99658203e-02],
                        [ -2.31628418e-02,  -2.31628418e-02],
                        [ -1.48162842e-01,  -1.48162842e-01],
                        [ -2.53875732e-01,  -2.53875732e-01],
                        [ -3.12927246e-01,  -3.12927246e-01],
                        [ -3.11706543e-01,  -3.11706543e-01],
                        [ -2.58636475e-01,  -2.58636475e-01],
                        [ -1.86462402e-01,  -1.86462402e-01],
                        [ -1.35772705e-01,  -1.35772705e-01],
                        [ -1.24389648e-01,  -1.24389648e-01],
                        [ -1.37664795e-01,  -1.37664795e-01],
                        [ -1.52832031e-01,  -1.52832031e-01],
                        [ -1.59851074e-01,  -1.59851074e-01],
                        [ -1.56372070e-01,  -1.56372070e-01],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -1.01440430e-01,  -1.01440430e-01],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  7.34252930e-02,   7.34252930e-02],
                        [  1.38641357e-01,   1.38641357e-01],
                        [  1.94244385e-01,   1.94244385e-01],
                        [  2.21893311e-01,   2.21893311e-01],
                        [  2.10388184e-01,   2.10388184e-01],
                        [  1.71447754e-01,   1.71447754e-01],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.06994629e-01,   1.06994629e-01],
                        [  9.82055664e-02,   9.82055664e-02],
                        [  9.80529785e-02,   9.80529785e-02],
                        [  1.00250244e-01,   1.00250244e-01],
                        [  1.01318359e-01,   1.01318359e-01],
                        [  1.01531982e-01,   1.01531982e-01],
                        [  1.01593018e-01,   1.01593018e-01],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  8.79821777e-02,   8.79821777e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  4.41284180e-02,   4.41284180e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -2.91748047e-02,  -2.91748047e-02],
                        [ -2.61840820e-02,  -2.61840820e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [  4.63867188e-03,   4.63867188e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  3.79028320e-02,   3.79028320e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -9.05456543e-02,  -9.05456543e-02],
                        [ -1.60339355e-01,  -1.60339355e-01],
                        [ -2.07733154e-01,  -2.07733154e-01],
                        [ -2.18688965e-01,  -2.18688965e-01],
                        [ -1.98303223e-01,  -1.98303223e-01],
                        [ -1.64947510e-01,  -1.64947510e-01],
                        [ -1.36322021e-01,  -1.36322021e-01],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -1.11236572e-01,  -1.11236572e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -9.42687988e-02,  -9.42687988e-02],
                        [ -8.77685547e-02,  -8.77685547e-02],
                        [ -8.87451172e-02,  -8.87451172e-02],
                        [ -9.19799805e-02,  -9.19799805e-02],
                        [ -8.85314941e-02,  -8.85314941e-02],
                        [ -7.46154785e-02,  -7.46154785e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [  3.43017578e-02,   3.42712402e-02],
                        [  8.33129883e-02,   8.33129883e-02],
                        [  1.24176025e-01,   1.24176025e-01],
                        [  1.44927979e-01,   1.44927979e-01],
                        [  1.43524170e-01,   1.43524170e-01],
                        [  1.32568359e-01,   1.32568359e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.33575439e-01,   1.33575439e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.81671143e-01,   1.81671143e-01],
                        [  2.09381104e-01,   2.09381104e-01],
                        [  2.18139648e-01,   2.18139648e-01],
                        [  1.99127197e-01,   1.99127197e-01],
                        [  1.51458740e-01,   1.51458740e-01],
                        [  7.33642578e-02,   7.33642578e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -1.55456543e-01,  -1.55456543e-01],
                        [ -2.63275146e-01,  -2.63275146e-01],
                        [ -3.23394775e-01,  -3.23394775e-01],
                        [ -3.15155029e-01,  -3.15155029e-01],
                        [ -2.51556396e-01,  -2.51556396e-01],
                        [ -1.77551270e-01,  -1.77551270e-01],
                        [ -1.36138916e-01,  -1.36138916e-01],
                        [ -1.32537842e-01,  -1.32537842e-01],
                        [ -1.39495850e-01,  -1.39495850e-01],
                        [ -1.35833740e-01,  -1.35833740e-01],
                        [ -1.26281738e-01,  -1.26312256e-01],
                        [ -1.21368408e-01,  -1.21368408e-01],
                        [ -1.13342285e-01,  -1.13342285e-01],
                        [ -8.32519531e-02,  -8.32824707e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  1.07513428e-01,   1.07513428e-01],
                        [  1.57043457e-01,   1.57043457e-01],
                        [  1.92352295e-01,   1.92382812e-01],
                        [  2.08221436e-01,   2.08221436e-01],
                        [  1.96044922e-01,   1.96014404e-01],
                        [  1.60827637e-01,   1.60827637e-01],
                        [  1.24145508e-01,   1.24145508e-01],
                        [  1.01470947e-01,   1.01470947e-01],
                        [  8.93859863e-02,   8.93554688e-02],
                        [  8.07189941e-02,   8.07495117e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  8.09936523e-02,   8.09936523e-02],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  8.84704590e-02,   8.85009766e-02],
                        [  9.05151367e-02,   9.05151367e-02],
                        [  9.03015137e-02,   9.03015137e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  5.67321777e-02,   5.67321777e-02],
                        [  4.77294922e-02,   4.77294922e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  2.04467773e-02,   2.04772949e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.12097168e-02,  -2.12097168e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -9.76562500e-03,  -9.73510742e-03],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [  3.26538086e-03,   3.26538086e-03],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  4.72106934e-02,   4.71801758e-02],
                        [  5.58776855e-02,   5.58776855e-02],
                        [  5.80749512e-02,   5.80749512e-02],
                        [  5.44128418e-02,   5.43823242e-02],
                        [  4.64477539e-02,   4.64477539e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -1.04888916e-01,  -1.04888916e-01],
                        [ -1.70898438e-01,  -1.70898438e-01],
                        [ -2.13897705e-01,  -2.13897705e-01],
                        [ -2.18353271e-01,  -2.18353271e-01],
                        [ -1.88232422e-01,  -1.88232422e-01],
                        [ -1.44958496e-01,  -1.44958496e-01],
                        [ -1.13250732e-01,  -1.13250732e-01],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -1.06079102e-01,  -1.06079102e-01],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -1.01135254e-01,  -1.01135254e-01],
                        [ -9.69543457e-02,  -9.69543457e-02],
                        [ -9.33532715e-02,  -9.33532715e-02],
                        [ -8.47778320e-02,  -8.48083496e-02],
                        [ -6.84509277e-02,  -6.84509277e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [  1.37329102e-03,   1.37329102e-03],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  1.01074219e-01,   1.01074219e-01],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.35803223e-01,   1.35803223e-01],
                        [  1.33392334e-01,   1.33392334e-01],
                        [  1.31408691e-01,   1.31439209e-01],
                        [  1.32354736e-01,   1.32354736e-01],
                        [  1.38244629e-01,   1.38244629e-01],
                        [  1.55242920e-01,   1.55242920e-01],
                        [  1.83380127e-01,   1.83380127e-01],
                        [  2.07733154e-01,   2.07733154e-01],
                        [  2.08984375e-01,   2.08984375e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -1.10290527e-01,  -1.10290527e-01],
                        [ -2.24639893e-01,  -2.24639893e-01],
                        [ -2.98736572e-01,  -2.98736572e-01],
                        [ -3.08563232e-01,  -3.08563232e-01],
                        [ -2.60437012e-01,  -2.60467529e-01],
                        [ -1.92138672e-01,  -1.92138672e-01],
                        [ -1.44531250e-01,  -1.44531250e-01],
                        [ -1.30737305e-01,  -1.30737305e-01],
                        [ -1.35894775e-01,  -1.35894775e-01],
                        [ -1.41052246e-01,  -1.41052246e-01],
                        [ -1.38488770e-01,  -1.38488770e-01],
                        [ -1.28204346e-01,  -1.28204346e-01],
                        [ -1.12030029e-01,  -1.12030029e-01],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  8.11157227e-02,   8.11157227e-02],
                        [  1.60491943e-01,   1.60491943e-01],
                        [  2.17102051e-01,   2.17102051e-01],
                        [  2.35260010e-01,   2.35260010e-01],
                        [  2.16888428e-01,   2.16888428e-01],
                        [  1.79687500e-01,   1.79687500e-01],
                        [  1.44104004e-01,   1.44104004e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  8.46252441e-02,   8.46252441e-02],
                        [  7.61108398e-02,   7.61108398e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  8.26416016e-02,   8.26416016e-02],
                        [  7.88879395e-02,   7.88879395e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  4.88891602e-02,   4.89196777e-02],
                        [  4.50439453e-02,   4.50134277e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  3.79333496e-02,   3.79638672e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.47094727e-02,  -1.46789551e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.37426758e-02,  -2.37121582e-02],
                        [ -1.88598633e-02,  -1.88598633e-02],
                        [ -1.56250000e-02,  -1.56555176e-02],
                        [ -1.63574219e-02,  -1.63269043e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -4.04968262e-02,  -4.05273438e-02],
                        [ -5.88684082e-02,  -5.88684082e-02],
                        [ -6.36596680e-02,  -6.36291504e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.86865234e-02,   2.87170410e-02],
                        [  3.11889648e-02,   3.11889648e-02],
                        [  3.45153809e-02,   3.44848633e-02],
                        [  3.64990234e-02,   3.64990234e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  1.84020996e-02,   1.83715820e-02],
                        [  9.15527344e-03,   9.18579102e-03],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  2.92053223e-02,   2.91748047e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -8.21838379e-02,  -8.21838379e-02],
                        [ -1.56158447e-01,  -1.56158447e-01],
                        [ -2.09686279e-01,  -2.09686279e-01],
                        [ -2.18566895e-01,  -2.18536377e-01],
                        [ -1.86523438e-01,  -1.86492920e-01],
                        [ -1.42150879e-01,  -1.42150879e-01],
                        [ -1.10321045e-01,  -1.10321045e-01],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -8.70361328e-02,  -8.70361328e-02],
                        [ -8.52661133e-02,  -8.52661133e-02],
                        [ -8.88366699e-02,  -8.88366699e-02],
                        [ -9.58557129e-02,  -9.58557129e-02],
                        [ -1.02539062e-01,  -1.02539062e-01],
                        [ -1.03179932e-01,  -1.03179932e-01],
                        [ -8.99353027e-02,  -8.99353027e-02],
                        [ -5.71594238e-02,  -5.71899414e-02],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  1.07635498e-01,   1.07635498e-01],
                        [  1.46636963e-01,   1.46636963e-01],
                        [  1.60430908e-01,   1.60430908e-01],
                        [  1.52130127e-01,   1.52130127e-01],
                        [  1.40045166e-01,   1.40045166e-01],
                        [  1.45507812e-01,   1.45507812e-01],
                        [  1.72149658e-01,   1.72149658e-01],
                        [  2.02331543e-01,   2.02331543e-01],
                        [  2.18139648e-01,   2.18139648e-01],
                        [  2.14447021e-01,   2.14447021e-01],
                        [  1.86614990e-01,   1.86614990e-01],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.60217285e-02,   1.60217285e-02],
                        [ -1.11846924e-01,  -1.11846924e-01],
                        [ -2.29156494e-01,  -2.29156494e-01],
                        [ -3.07830811e-01,  -3.07830811e-01],
                        [ -3.28521729e-01,  -3.28521729e-01],
                        [ -2.87506104e-01,  -2.87536621e-01],
                        [ -2.12249756e-01,  -2.12249756e-01],
                        [ -1.49963379e-01,  -1.49963379e-01],
                        [ -1.26068115e-01,  -1.26068115e-01],
                        [ -1.27441406e-01,  -1.27471924e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -1.31225586e-01,  -1.31195068e-01],
                        [ -1.26281738e-01,  -1.26312256e-01],
                        [ -1.10565186e-01,  -1.10565186e-01],
                        [ -7.74841309e-02,  -7.74841309e-02],
                        [ -2.56347656e-02,  -2.56347656e-02],
                        [  4.41589355e-02,   4.41284180e-02],
                        [  1.23474121e-01,   1.23474121e-01],
                        [  1.89117432e-01,   1.89117432e-01],
                        [  2.17010498e-01,   2.16979980e-01],
                        [  2.06298828e-01,   2.06268311e-01],
                        [  1.77429199e-01,   1.77459717e-01],
                        [  1.47644043e-01,   1.47644043e-01],
                        [  1.21795654e-01,   1.21795654e-01],
                        [  1.04156494e-01,   1.04187012e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  9.73510742e-02,   9.73205566e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  8.45947266e-02,   8.46252441e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  7.05871582e-02,   7.05871582e-02],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  4.63867188e-02,   4.64172363e-02],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  4.64782715e-02,   4.64782715e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.88903809e-02,  -1.89208984e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -1.06506348e-02,  -1.06201172e-02],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.88903809e-02,   1.89208984e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.50146484e-02,   1.49841309e-02],
                        [  4.42504883e-03,   4.42504883e-03],
                        [ -3.08227539e-03,  -3.08227539e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [  6.40869141e-03,   6.37817383e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.43823242e-02,   5.43823242e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -8.96911621e-02,  -8.96911621e-02],
                        [ -1.62017822e-01,  -1.62017822e-01],
                        [ -2.13378906e-01,  -2.13378906e-01],
                        [ -2.24182129e-01,  -2.24182129e-01],
                        [ -1.99493408e-01,  -1.99493408e-01],
                        [ -1.64428711e-01,  -1.64428711e-01],
                        [ -1.38946533e-01,  -1.38946533e-01],
                        [ -1.22467041e-01,  -1.22467041e-01],
                        [ -1.04766846e-01,  -1.04766846e-01],
                        [ -8.48999023e-02,  -8.48999023e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -7.22351074e-02,  -7.22351074e-02],
                        [ -7.52868652e-02,  -7.52868652e-02],
                        [ -6.82373047e-02,  -6.82373047e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [  1.75476074e-02,   1.75476074e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  1.08001709e-01,   1.07971191e-01],
                        [  1.42700195e-01,   1.42730713e-01],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.61712646e-01,   1.61682129e-01],
                        [  1.63818359e-01,   1.63818359e-01],
                        [  1.70593262e-01,   1.70593262e-01],
                        [  1.79962158e-01,   1.79931641e-01],
                        [  1.87896729e-01,   1.87866211e-01],
                        [  1.89666748e-01,   1.89666748e-01],
                        [  1.73583984e-01,   1.73583984e-01],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  2.95410156e-02,   2.95410156e-02],
                        [ -9.06372070e-02,  -9.06372070e-02],
                        [ -2.08709717e-01,  -2.08709717e-01],
                        [ -2.92541504e-01,  -2.92541504e-01],
                        [ -3.18786621e-01,  -3.18786621e-01],
                        [ -2.86315918e-01,  -2.86315918e-01],
                        [ -2.22381592e-01,  -2.22381592e-01],
                        [ -1.67877197e-01,  -1.67877197e-01],
                        [ -1.47308350e-01,  -1.47308350e-01],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -1.57104492e-01,  -1.57073975e-01],
                        [ -1.47247314e-01,  -1.47247314e-01],
                        [ -1.28570557e-01,  -1.28570557e-01],
                        [ -1.09161377e-01,  -1.09161377e-01],
                        [ -8.20312500e-02,  -8.20312500e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [  4.33959961e-02,   4.34265137e-02],
                        [  1.28356934e-01,   1.28356934e-01],
                        [  1.96289062e-01,   1.96289062e-01],
                        [  2.26470947e-01,   2.26470947e-01],
                        [  2.15484619e-01,   2.15484619e-01],
                        [  1.78955078e-01,   1.78955078e-01],
                        [  1.39739990e-01,   1.39739990e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  9.17358398e-02,   9.17358398e-02],
                        [  7.72399902e-02,   7.72399902e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  7.33642578e-02,   7.33947754e-02],
                        [  7.90405273e-02,   7.90405273e-02],
                        [  7.67211914e-02,   7.67211914e-02],
                        [  6.71386719e-02,   6.71691895e-02],
                        [  5.91125488e-02,   5.91430664e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.10253906e-02,   5.10253906e-02],
                        [  5.05065918e-02,   5.05371094e-02],
                        [  5.85937500e-02,   5.85632324e-02],
                        [  6.93359375e-02,   6.93054199e-02],
                        [  7.18383789e-02,   7.18383789e-02],
                        [  6.54602051e-02,   6.54907227e-02],
                        [  5.67321777e-02,   5.67016602e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  3.03344727e-02,   3.03649902e-02],
                        [  1.11389160e-02,   1.11389160e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -2.90222168e-02,  -2.90222168e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -2.89001465e-02,  -2.88696289e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -2.74047852e-02,  -2.74353027e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.17187500e-02,   1.17492676e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [ -3.35693359e-04,  -3.35693359e-04],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -1.08673096e-01,  -1.08673096e-01],
                        [ -1.73492432e-01,  -1.73461914e-01],
                        [ -2.08648682e-01,  -2.08648682e-01],
                        [ -1.99951172e-01,  -1.99951172e-01],
                        [ -1.60827637e-01,  -1.60827637e-01],
                        [ -1.23321533e-01,  -1.23321533e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -9.75036621e-02,  -9.75036621e-02],
                        [ -8.77380371e-02,  -8.77380371e-02],
                        [ -7.78198242e-02,  -7.78198242e-02],
                        [ -7.43408203e-02,  -7.43713379e-02],
                        [ -7.55310059e-02,  -7.55310059e-02],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -6.43615723e-02,  -6.43920898e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  7.28759766e-02,   7.28454590e-02],
                        [  1.14715576e-01,   1.14715576e-01],
                        [  1.43402100e-01,   1.43402100e-01],
                        [  1.58325195e-01,   1.58325195e-01],
                        [  1.68609619e-01,   1.68609619e-01],
                        [  1.84539795e-01,   1.84539795e-01],
                        [  2.08038330e-01,   2.08038330e-01],
                        [  2.28393555e-01,   2.28393555e-01],
                        [  2.25891113e-01,   2.25891113e-01],
                        [  1.84326172e-01,   1.84326172e-01],
                        [  1.01837158e-01,   1.01837158e-01],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.36566162e-01,  -1.36566162e-01],
                        [ -2.49847412e-01,  -2.49847412e-01],
                        [ -3.19244385e-01,  -3.19213867e-01],
                        [ -3.24340820e-01,  -3.24371338e-01],
                        [ -2.75726318e-01,  -2.75726318e-01],
                        [ -2.11608887e-01,  -2.11608887e-01],
                        [ -1.69433594e-01,  -1.69433594e-01],
                        [ -1.57348633e-01,  -1.57348633e-01],
                        [ -1.55883789e-01,  -1.55883789e-01],
                        [ -1.46820068e-01,  -1.46820068e-01],
                        [ -1.30920410e-01,  -1.30920410e-01],
                        [ -1.14044189e-01,  -1.14074707e-01],
                        [ -8.96301270e-02,  -8.96301270e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  1.05743408e-01,   1.05743408e-01],
                        [  1.76513672e-01,   1.76513672e-01],
                        [  2.15789795e-01,   2.15759277e-01],
                        [  2.17742920e-01,   2.17742920e-01],
                        [  1.94000244e-01,   1.94000244e-01],
                        [  1.59942627e-01,   1.59942627e-01],
                        [  1.24084473e-01,   1.24084473e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  7.08923340e-02,   7.09228516e-02],
                        [  6.52160645e-02,   6.51855469e-02],
                        [  7.09838867e-02,   7.09838867e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  7.15942383e-02,   7.15637207e-02],
                        [  5.69763184e-02,   5.70068359e-02],
                        [  4.81872559e-02,   4.81872559e-02],
                        [  5.00183105e-02,   5.00183105e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  6.33239746e-02,   6.33544922e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  5.88684082e-02,   5.88989258e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  6.35070801e-02,   6.34765625e-02],
                        [  5.78613281e-02,   5.78613281e-02],
                        [  4.11987305e-02,   4.11987305e-02],
                        [  1.93481445e-02,   1.93176270e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [ -1.22680664e-02,  -1.22375488e-02],
                        [ -2.15759277e-02,  -2.15759277e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.27563477e-02,  -1.27258301e-02],
                        [ -4.39453125e-03,  -4.36401367e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  2.03552246e-02,   2.03247070e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -1.54418945e-01,  -1.54418945e-01],
                        [ -1.91955566e-01,  -1.91986084e-01],
                        [ -1.90155029e-01,  -1.90155029e-01],
                        [ -1.58325195e-01,  -1.58294678e-01],
                        [ -1.22009277e-01,  -1.22009277e-01],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -8.49304199e-02,  -8.48999023e-02],
                        [ -7.92541504e-02,  -7.92541504e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -7.40356445e-02,  -7.40356445e-02],
                        [ -6.49108887e-02,  -6.49108887e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [  3.66210938e-04,   3.66210938e-04],
                        [  5.99670410e-02,   5.99670410e-02],
                        [  1.17797852e-01,   1.17828369e-01],
                        [  1.60980225e-01,   1.60949707e-01],
                        [  1.90917969e-01,   1.90917969e-01],
                        [  2.15576172e-01,   2.15576172e-01],
                        [  2.36114502e-01,   2.36114502e-01],
                        [  2.44720459e-01,   2.44720459e-01],
                        [  2.32269287e-01,   2.32269287e-01],
                        [  1.92749023e-01,   1.92749023e-01],
                        [  1.22985840e-01,   1.22955322e-01],
                        [  2.48107910e-02,   2.48107910e-02],
                        [ -9.24682617e-02,  -9.24377441e-02],
                        [ -2.11975098e-01,  -2.11975098e-01],
                        [ -3.06518555e-01,  -3.06549072e-01],
                        [ -3.43048096e-01,  -3.43017578e-01],
                        [ -3.08349609e-01,  -3.08349609e-01],
                        [ -2.33123779e-01,  -2.33123779e-01],
                        [ -1.71173096e-01,  -1.71173096e-01],
                        [ -1.49841309e-01,  -1.49810791e-01],
                        [ -1.52801514e-01,  -1.52801514e-01],
                        [ -1.52160645e-01,  -1.52160645e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -1.17675781e-01,  -1.17675781e-01],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -5.16052246e-02,  -5.16052246e-02],
                        [  9.24682617e-03,   9.24682617e-03],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  1.65985107e-01,   1.65985107e-01],
                        [  2.13470459e-01,   2.13500977e-01],
                        [  2.16674805e-01,   2.16644287e-01],
                        [  1.89056396e-01,   1.89056396e-01],
                        [  1.58416748e-01,   1.58416748e-01],
                        [  1.38305664e-01,   1.38305664e-01],
                        [  1.19964600e-01,   1.19934082e-01],
                        [  9.28344727e-02,   9.28344727e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  4.61425781e-02,   4.61120605e-02],
                        [  4.94079590e-02,   4.94079590e-02],
                        [  6.30798340e-02,   6.30798340e-02],
                        [  7.14721680e-02,   7.14721680e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  6.08215332e-02,   6.08215332e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [ -1.92260742e-02,  -1.91955566e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.16259766e-02,  -4.15954590e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.98559570e-02,  -3.98864746e-02],
                        [ -3.85437012e-02,  -3.85131836e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [  9.73510742e-03,   9.70458984e-03],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.34985352e-02,   2.35290527e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  1.67541504e-02,   1.67236328e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  4.05883789e-03,   4.05883789e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -8.39538574e-02,  -8.39538574e-02],
                        [ -1.41082764e-01,  -1.41082764e-01],
                        [ -1.78314209e-01,  -1.78314209e-01],
                        [ -1.85913086e-01,  -1.85913086e-01],
                        [ -1.66198730e-01,  -1.66198730e-01],
                        [ -1.32904053e-01,  -1.32904053e-01],
                        [ -1.02722168e-01,  -1.02722168e-01],
                        [ -8.49914551e-02,  -8.49914551e-02],
                        [ -7.97119141e-02,  -7.97424316e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -7.94372559e-02,  -7.94067383e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [  3.05786133e-02,   3.05786133e-02],
                        [  8.29772949e-02,   8.29772949e-02],
                        [  1.29791260e-01,   1.29791260e-01],
                        [  1.66870117e-01,   1.66870117e-01],
                        [  1.97601318e-01,   1.97631836e-01],
                        [  2.21405029e-01,   2.21405029e-01],
                        [  2.33734131e-01,   2.33734131e-01],
                        [  2.31781006e-01,   2.31781006e-01],
                        [  2.09838867e-01,   2.09838867e-01],
                        [  1.56066895e-01,   1.56066895e-01],
                        [  6.42089844e-02,   6.42089844e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -1.73797607e-01,  -1.73828125e-01],
                        [ -2.69134521e-01,  -2.69134521e-01],
                        [ -3.19183350e-01,  -3.19183350e-01],
                        [ -3.13385010e-01,  -3.13385010e-01],
                        [ -2.61596680e-01,  -2.61596680e-01],
                        [ -1.97235107e-01,  -1.97204590e-01],
                        [ -1.56982422e-01,  -1.56982422e-01],
                        [ -1.49627686e-01,  -1.49627686e-01],
                        [ -1.51977539e-01,  -1.51977539e-01],
                        [ -1.40655518e-01,  -1.40655518e-01],
                        [ -1.16119385e-01,  -1.16119385e-01],
                        [ -8.83483887e-02,  -8.83483887e-02],
                        [ -5.44128418e-02,  -5.44128418e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  6.58569336e-02,   6.58569336e-02],
                        [  1.38763428e-01,   1.38732910e-01],
                        [  1.94549561e-01,   1.94549561e-01],
                        [  2.16766357e-01,   2.16735840e-01],
                        [  2.03979492e-01,   2.03948975e-01],
                        [  1.73248291e-01,   1.73248291e-01],
                        [  1.45294189e-01,   1.45294189e-01],
                        [  1.25396729e-01,   1.25396729e-01],
                        [  1.05529785e-01,   1.05529785e-01],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  5.86547852e-02,   5.86242676e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  8.02001953e-02,   8.01696777e-02],
                        [  7.54089355e-02,   7.54394531e-02],
                        [  7.14111328e-02,   7.14111328e-02],
                        [  7.07702637e-02,   7.07397461e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  6.24694824e-02,   6.25000000e-02],
                        [  5.40771484e-02,   5.40771484e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.44848633e-02,   3.44543457e-02],
                        [  3.29589844e-02,   3.29284668e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  1.10473633e-02,   1.10168457e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -3.36608887e-02,  -3.36608887e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -2.30712891e-02,  -2.30407715e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.99377441e-02,  -2.99072266e-02],
                        [ -2.64587402e-02,  -2.64892578e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [  1.06811523e-03,   1.03759766e-03],
                        [  5.12695312e-03,   5.15747070e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [  3.81469727e-03,   3.81469727e-03],
                        [ -2.74658203e-03,  -2.71606445e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.97546387e-02,   2.97546387e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -1.16149902e-01,  -1.16149902e-01],
                        [ -1.67114258e-01,  -1.67114258e-01],
                        [ -1.87591553e-01,  -1.87591553e-01],
                        [ -1.72271729e-01,  -1.72271729e-01],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -1.08062744e-01,  -1.08062744e-01],
                        [ -9.69848633e-02,  -9.69848633e-02],
                        [ -9.77478027e-02,  -9.77478027e-02],
                        [ -1.00311279e-01,  -1.00311279e-01],
                        [ -1.00067139e-01,  -1.00067139e-01],
                        [ -9.46044922e-02,  -9.46044922e-02],
                        [ -8.00476074e-02,  -8.00476074e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  1.46697998e-01,   1.46697998e-01],
                        [  1.84692383e-01,   1.84692383e-01],
                        [  2.11120605e-01,   2.11120605e-01],
                        [  2.28637695e-01,   2.28637695e-01],
                        [  2.37548828e-01,   2.37548828e-01],
                        [  2.30926514e-01,   2.30926514e-01],
                        [  1.96136475e-01,   1.96136475e-01],
                        [  1.24725342e-01,   1.24725342e-01],
                        [  2.10571289e-02,   2.10571289e-02],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -2.16094971e-01,  -2.16094971e-01],
                        [ -3.01452637e-01,  -3.01452637e-01],
                        [ -3.30841064e-01,  -3.30841064e-01],
                        [ -3.02337646e-01,  -3.02337646e-01],
                        [ -2.45086670e-01,  -2.45086670e-01],
                        [ -1.96105957e-01,  -1.96105957e-01],
                        [ -1.70898438e-01,  -1.70898438e-01],
                        [ -1.59881592e-01,  -1.59881592e-01],
                        [ -1.47308350e-01,  -1.47308350e-01],
                        [ -1.26251221e-01,  -1.26251221e-01],
                        [ -9.71679688e-02,  -9.71679688e-02],
                        [ -5.90515137e-02,  -5.90515137e-02],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [  6.03027344e-02,   6.03027344e-02],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.87133789e-01,   1.87164307e-01],
                        [  2.14111328e-01,   2.14111328e-01],
                        [  2.11822510e-01,   2.11822510e-01],
                        [  1.87133789e-01,   1.87133789e-01],
                        [  1.49169922e-01,   1.49200439e-01],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  8.15429688e-02,   8.15429688e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  6.39038086e-02,   6.39038086e-02],
                        [  6.35986328e-02,   6.35986328e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  5.74951172e-02,   5.75256348e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  4.13208008e-02,   4.12902832e-02],
                        [  4.43115234e-02,   4.43115234e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  8.02001953e-02,   8.02001953e-02],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  7.73620605e-02,   7.73620605e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  5.61523438e-03,   5.61523438e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.07922363e-02,  -3.07922363e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [  1.55639648e-03,   1.55639648e-03],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  1.19018555e-03,   1.22070312e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  6.56127930e-03,   6.56127930e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -4.27246094e-03,  -4.30297852e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -4.63867188e-03,  -4.63867188e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.36413574e-02,   1.36108398e-02],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -1.06994629e-01,  -1.06994629e-01],
                        [ -1.61407471e-01,  -1.61407471e-01],
                        [ -1.89666748e-01,  -1.89697266e-01],
                        [ -1.85363770e-01,  -1.85363770e-01],
                        [ -1.58660889e-01,  -1.58630371e-01],
                        [ -1.30157471e-01,  -1.30157471e-01],
                        [ -1.14257812e-01,  -1.14257812e-01],
                        [ -1.06903076e-01,  -1.06903076e-01],
                        [ -9.47265625e-02,  -9.47265625e-02],
                        [ -7.47070312e-02,  -7.47070312e-02],
                        [ -5.55419922e-02,  -5.55114746e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -2.19421387e-02,  -2.19421387e-02],
                        [  9.85717773e-03,   9.82666016e-03],
                        [  5.59387207e-02,   5.59387207e-02],
                        [  1.10229492e-01,   1.10260010e-01],
                        [  1.62139893e-01,   1.62139893e-01],
                        [  2.01904297e-01,   2.01873779e-01],
                        [  2.27386475e-01,   2.27416992e-01],
                        [  2.41729736e-01,   2.41729736e-01],
                        [  2.41516113e-01,   2.41516113e-01],
                        [  2.13745117e-01,   2.13714600e-01],
                        [  1.47247314e-01,   1.47216797e-01],
                        [  4.43725586e-02,   4.44030762e-02],
                        [ -7.97424316e-02,  -7.97119141e-02],
                        [ -2.03521729e-01,  -2.03552246e-01],
                        [ -2.99987793e-01,  -2.99987793e-01],
                        [ -3.41033936e-01,  -3.41033936e-01],
                        [ -3.17260742e-01,  -3.17230225e-01],
                        [ -2.53845215e-01,  -2.53845215e-01],
                        [ -1.94244385e-01,  -1.94213867e-01],
                        [ -1.64184570e-01,  -1.64184570e-01],
                        [ -1.56951904e-01,  -1.56982422e-01],
                        [ -1.50878906e-01,  -1.50848389e-01],
                        [ -1.32629395e-01,  -1.32629395e-01],
                        [ -1.01776123e-01,  -1.01776123e-01],
                        [ -5.92651367e-02,  -5.92651367e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  1.36718750e-01,   1.36688232e-01],
                        [  1.87225342e-01,   1.87255859e-01],
                        [  2.05413818e-01,   2.05413818e-01],
                        [  1.92138672e-01,   1.92138672e-01],
                        [  1.62567139e-01,   1.62567139e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  9.67407227e-02,   9.67407227e-02],
                        [  8.52050781e-02,   8.51745605e-02],
                        [  7.55615234e-02,   7.55310059e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  5.89294434e-02,   5.89599609e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  5.17883301e-02,   5.17578125e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  3.29895020e-02,   3.30200195e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  5.57861328e-02,   5.57556152e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  9.10339355e-02,   9.10644531e-02],
                        [  9.91821289e-02,   9.91821289e-02],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  8.83483887e-02,   8.83789062e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  5.62438965e-02,   5.62133789e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [ -5.03540039e-03,  -5.06591797e-03],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -1.38549805e-02,  -1.38244629e-02],
                        [ -2.17285156e-02,  -2.17590332e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -3.70483398e-02,  -3.69873047e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -3.97033691e-02,  -3.97644043e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -1.84020996e-02,  -1.83410645e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [  3.60107422e-03,   3.57055664e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  8.94165039e-03,   8.97216797e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  7.99560547e-03,   7.96508789e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -1.97143555e-02,  -1.97448730e-02],
                        [ -9.21630859e-03,  -9.21630859e-03],
                        [ -1.25122070e-03,  -1.22070312e-03],
                        [ -1.70898438e-03,  -1.67846680e-03],
                        [ -5.12695312e-03,  -5.15747070e-03],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -6.95800781e-03,  -6.92749023e-03],
                        [ -6.46972656e-03,  -6.43920898e-03],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.30920410e-02,   1.30615234e-02],
                        [  2.06298828e-02,   2.05993652e-02],
                        [  3.00292969e-02,   3.00598145e-02],
                        [  3.99475098e-02,   3.99780273e-02],
                        [  4.11071777e-02,   4.10766602e-02],
                        [  2.41394043e-02,   2.40783691e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -6.72607422e-02,  -6.71997070e-02],
                        [ -1.27319336e-01,  -1.27288818e-01],
                        [ -1.77307129e-01,  -1.77398682e-01],
                        [ -1.98791504e-01,  -1.98852539e-01],
                        [ -1.83563232e-01,  -1.83502197e-01],
                        [ -1.43127441e-01,  -1.43035889e-01],
                        [ -1.01165771e-01,  -1.01226807e-01],
                        [ -7.45544434e-02,  -7.46459961e-02],
                        [ -6.42089844e-02,  -6.41784668e-02],
                        [ -6.29272461e-02,  -6.28356934e-02],
                        [ -6.50939941e-02,  -6.50634766e-02],
                        [ -6.54907227e-02,  -6.55517578e-02],
                        [ -5.56335449e-02,  -5.56640625e-02],
                        [ -2.72827148e-02,  -2.71911621e-02],
                        [  2.05688477e-02,   2.06298828e-02],
                        [  8.00781250e-02,   8.00170898e-02],
                        [  1.39801025e-01,   1.39770508e-01],
                        [  1.90124512e-01,   1.90155029e-01],
                        [  2.23907471e-01,   2.23937988e-01],
                        [  2.36022949e-01,   2.36022949e-01],
                        [  2.24761963e-01,   2.24731445e-01],
                        [  1.90643311e-01,   1.90643311e-01],
                        [  1.30645752e-01,   1.30645752e-01],
                        [  3.95507812e-02,   3.95202637e-02],
                        [ -7.78808594e-02,  -7.78808594e-02],
                        [ -1.99279785e-01,  -1.99249268e-01],
                        [ -2.92205811e-01,  -2.92236328e-01],
                        [ -3.30169678e-01,  -3.30200195e-01],
                        [ -3.07861328e-01,  -3.07861328e-01],
                        [ -2.49481201e-01,  -2.49450684e-01],
                        [ -1.96777344e-01,  -1.96746826e-01],
                        [ -1.76330566e-01,  -1.76361084e-01],
                        [ -1.76544189e-01,  -1.76574707e-01],
                        [ -1.65222168e-01,  -1.65222168e-01],
                        [ -1.28631592e-01,  -1.28631592e-01],
                        [ -7.98339844e-02,  -7.98339844e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  9.43603516e-02,   9.43298340e-02],
                        [  1.63635254e-01,   1.63665771e-01],
                        [  2.11486816e-01,   2.11517334e-01],
                        [  2.24121094e-01,   2.24121094e-01],
                        [  2.04315186e-01,   2.04284668e-01],
                        [  1.67236328e-01,   1.67236328e-01],
                        [  1.29913330e-01,   1.29974365e-01],
                        [  1.00830078e-01,   1.00891113e-01],
                        [  7.93151855e-02,   7.92846680e-02],
                        [  6.41174316e-02,   6.40563965e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.67932129e-02,   5.68542480e-02],
                        [  5.55725098e-02,   5.55725098e-02],
                        [  4.87976074e-02,   4.87365723e-02],
                        [  4.03442383e-02,   4.02832031e-02],
                        [  3.65295410e-02,   3.65905762e-02],
                        [  3.91845703e-02,   3.92456055e-02],
                        [  4.66918945e-02,   4.66308594e-02],
                        [  5.82885742e-02,   5.82275391e-02],
                        [  7.43408203e-02,   7.43713379e-02],
                        [  9.10034180e-02,   9.10644531e-02],
                        [  9.89074707e-02,   9.88464355e-02],
                        [  9.13085938e-02,   9.12475586e-02],
                        [  7.14721680e-02,   7.15332031e-02],
                        [  4.82177734e-02,   4.82482910e-02],
                        [  2.80761719e-02,   2.80151367e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  3.90625000e-03,   3.96728516e-03],
                        [ -3.63159180e-03,  -3.60107422e-03],
                        [ -9.76562500e-03,  -9.79614258e-03],
                        [ -1.30920410e-02,  -1.31225586e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.19421387e-02,  -2.18811035e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -4.50439453e-02,  -4.50744629e-02],
                        [ -5.02929688e-02,  -5.02624512e-02],
                        [ -4.37927246e-02,  -4.37316895e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -1.12915039e-03,  -1.19018555e-03],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.80151367e-02,   2.80456543e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  2.25830078e-02,   2.25524902e-02],
                        [  1.16577148e-02,   1.16882324e-02],
                        [ -8.85009766e-04,  -8.54492188e-04],
                        [ -1.20239258e-02,  -1.20544434e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.72424316e-02,  -1.72119141e-02],
                        [ -1.02233887e-02,  -1.01928711e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [ -1.06811523e-03,  -1.09863281e-03],
                        [ -4.21142578e-03,  -4.24194336e-03],
                        [ -1.11999512e-02,  -1.11694336e-02],
                        [ -2.01721191e-02,  -2.01110840e-02],
                        [ -2.73437500e-02,  -2.73742676e-02],
                        [ -2.80761719e-02,  -2.81372070e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.38244629e-02,  -1.37329102e-02],
                        [ -9.00268555e-03,  -8.97216797e-03],
                        [ -5.40161133e-03,  -5.49316406e-03],
                        [  1.06811523e-03,   1.00708008e-03],
                        [  8.51440430e-03,   8.54492188e-03],
                        [  1.28784180e-02,   1.29699707e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.30407715e-02,   2.29187012e-02],
                        [  2.63061523e-02,   2.62756348e-02],
                        [  1.73339844e-02,   1.74255371e-02],
                        [ -4.54711914e-03,  -4.48608398e-03],
                        [ -3.67126465e-02,  -3.67431641e-02],
                        [ -7.99560547e-02,  -8.00476074e-02],
                        [ -1.28845215e-01,  -1.28845215e-01],
                        [ -1.63330078e-01,  -1.63269043e-01],
                        [ -1.64642334e-01,  -1.64611816e-01],
                        [ -1.36688232e-01,  -1.36718750e-01],
                        [ -1.03271484e-01,  -1.03363037e-01],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -7.62329102e-02,  -7.61413574e-02],
                        [ -6.92138672e-02,  -6.91528320e-02],
                        [ -5.86853027e-02,  -5.87463379e-02],
                        [ -4.97131348e-02,  -4.97741699e-02],
                        [ -4.18395996e-02,  -4.18090820e-02],
                        [ -2.46887207e-02,  -2.46276855e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.36291504e-02,   6.35986328e-02],
                        [  1.22039795e-01,   1.22009277e-01],
                        [  1.74072266e-01,   1.74072266e-01],
                        [  2.11944580e-01,   2.11975098e-01],
                        [  2.30407715e-01,   2.30407715e-01],
                        [  2.22564697e-01,   2.22534180e-01],
                        [  1.82647705e-01,   1.82647705e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  5.67626953e-03,   5.64575195e-03],
                        [ -1.20666504e-01,  -1.20635986e-01],
                        [ -2.42980957e-01,  -2.42950439e-01],
                        [ -3.22082520e-01,  -3.22082520e-01],
                        [ -3.33709717e-01,  -3.33770752e-01],
                        [ -2.89123535e-01,  -2.89123535e-01],
                        [ -2.25921631e-01,  -2.25891113e-01],
                        [ -1.82037354e-01,  -1.81976318e-01],
                        [ -1.70623779e-01,  -1.70623779e-01],
                        [ -1.72180176e-01,  -1.72241211e-01],
                        [ -1.56066895e-01,  -1.56097412e-01],
                        [ -1.12579346e-01,  -1.12518311e-01],
                        [ -5.64575195e-02,  -5.63964844e-02],
                        [ -3.05175781e-04,  -3.35693359e-04],
                        [  5.93872070e-02,   5.92956543e-02],
                        [  1.25488281e-01,   1.25488281e-01],
                        [  1.84570312e-01,   1.84661865e-01],
                        [  2.17285156e-01,   2.17315674e-01],
                        [  2.17895508e-01,   2.17864990e-01],
                        [  1.95953369e-01,   1.95922852e-01],
                        [  1.62414551e-01,   1.62414551e-01],
                        [  1.22772217e-01,   1.22802734e-01],
                        [  8.30993652e-02,   8.31298828e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  4.44335938e-02,   4.44030762e-02],
                        [  5.23071289e-02,   5.23071289e-02],
                        [  6.49414062e-02,   6.50024414e-02],
                        [  6.93054199e-02,   6.93359375e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  5.09948730e-02,   5.09338379e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  4.39758301e-02,   4.40368652e-02],
                        [  5.05981445e-02,   5.06591797e-02],
                        [  6.09436035e-02,   6.09130859e-02],
                        [  6.90307617e-02,   6.89697266e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  6.34765625e-02,   6.35070801e-02],
                        [  5.81665039e-02,   5.81970215e-02],
                        [  5.64575195e-02,   5.64270020e-02],
                        [  5.44128418e-02,   5.43823242e-02],
                        [  4.66613770e-02,   4.66613770e-02],
                        [  3.19519043e-02,   3.19824219e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.74560547e-02,  -1.73950195e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.58691406e-02,  -1.58996582e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.60925293e-02,  -2.60620117e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -6.37817383e-03,  -6.40869141e-03],
                        [ -3.57055664e-03,  -3.60107422e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  2.74658203e-04,   3.05175781e-04],
                        [  5.03540039e-03,   5.00488281e-03],
                        [  1.22070312e-02,   1.21765137e-02],
                        [  1.46789551e-02,   1.47399902e-02],
                        [  8.81958008e-03,   8.85009766e-03],
                        [  1.98364258e-03,   1.89208984e-03],
                        [  3.05175781e-03,   3.05175781e-03],
                        [  1.01928711e-02,   1.02844238e-02],
                        [  1.33972168e-02,   1.34277344e-02],
                        [  7.26318359e-03,   7.14111328e-03],
                        [ -5.46264648e-03,  -5.46264648e-03],
                        [ -1.95007324e-02,  -1.93786621e-02],
                        [ -3.01208496e-02,  -3.00598145e-02],
                        [ -3.37829590e-02,  -3.39050293e-02],
                        [ -3.21655273e-02,  -3.22265625e-02],
                        [ -2.94494629e-02,  -2.93273926e-02],
                        [ -2.61230469e-02,  -2.60314941e-02],
                        [ -2.21862793e-02,  -2.22473145e-02],
                        [ -2.12707520e-02,  -2.13928223e-02],
                        [ -2.36816406e-02,  -2.36511230e-02],
                        [ -2.22473145e-02,  -2.21862793e-02],
                        [ -1.16271973e-02,  -1.15966797e-02],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  2.02026367e-02,   2.01110840e-02],
                        [  3.14025879e-02,   3.13415527e-02],
                        [  3.78417969e-02,   3.79333496e-02],
                        [  3.56140137e-02,   3.57360840e-02],
                        [  1.59912109e-02,   1.59301758e-02],
                        [ -2.71911621e-02,  -2.73437500e-02],
                        [ -8.66088867e-02,  -8.66088867e-02],
                        [ -1.40533447e-01,  -1.40411377e-01],
                        [ -1.67755127e-01,  -1.67694092e-01],
                        [ -1.64489746e-01,  -1.64550781e-01],
                        [ -1.43585205e-01,  -1.43676758e-01],
                        [ -1.18804932e-01,  -1.18774414e-01],
                        [ -9.59777832e-02,  -9.58557129e-02],
                        [ -7.69958496e-02,  -7.69653320e-02],
                        [ -6.26525879e-02,  -6.27441406e-02],
                        [ -4.91943359e-02,  -4.93164062e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -4.11987305e-03,  -3.99780273e-03],
                        [  2.68554688e-02,   2.69165039e-02],
                        [  6.68029785e-02,   6.67114258e-02],
                        [  1.21582031e-01,   1.21459961e-01],
                        [  1.82830811e-01,   1.82891846e-01],
                        [  2.28485107e-01,   2.28576660e-01],
                        [  2.41088867e-01,   2.41088867e-01],
                        [  2.17163086e-01,   2.17102051e-01],
                        [  1.57714844e-01,   1.57653809e-01],
                        [  6.16760254e-02,   6.16760254e-02],
                        [ -6.43615723e-02,  -6.43005371e-02],
                        [ -1.96716309e-01,  -1.96685791e-01],
                        [ -3.00262451e-01,  -3.00262451e-01],
                        [ -3.44482422e-01,  -3.44573975e-01],
                        [ -3.21136475e-01,  -3.21166992e-01],
                        [ -2.55279541e-01,  -2.55218506e-01],
                        [ -1.92962646e-01,  -1.92871094e-01],
                        [ -1.64550781e-01,  -1.64581299e-01],
                        [ -1.61560059e-01,  -1.61682129e-01],
                        [ -1.54083252e-01,  -1.54083252e-01],
                        [ -1.25183105e-01,  -1.25091553e-01],
                        [ -8.03222656e-02,  -8.02917480e-02],
                        [ -2.90832520e-02,  -2.91137695e-02],
                        [  2.77404785e-02,   2.77099609e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  1.45935059e-01,   1.45965576e-01],
                        [  1.84082031e-01,   1.84143066e-01],
                        [  1.97937012e-01,   1.97937012e-01],
                        [  1.91009521e-01,   1.90948486e-01],
                        [  1.72637939e-01,   1.72607422e-01],
                        [  1.50909424e-01,   1.50939941e-01],
                        [  1.27441406e-01,   1.27502441e-01],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  7.52563477e-02,   7.51647949e-02],
                        [  5.56945801e-02,   5.56335449e-02],
                        [  4.59289551e-02,   4.59899902e-02],
                        [  4.34265137e-02,   4.35180664e-02],
                        [  4.33959961e-02,   4.33654785e-02],
                        [  4.39453125e-02,   4.38232422e-02],
                        [  4.53796387e-02,   4.53796387e-02],
                        [  4.82177734e-02,   4.83093262e-02],
                        [  5.39550781e-02,   5.39855957e-02],
                        [  6.30187988e-02,   6.29272461e-02],
                        [  7.12890625e-02,   7.12280273e-02],
                        [  7.42797852e-02,   7.43408203e-02],
                        [  7.32727051e-02,   7.33337402e-02],
                        [  7.25097656e-02,   7.24792480e-02],
                        [  7.32421875e-02,   7.31811523e-02],
                        [  7.18688965e-02,   7.18994141e-02],
                        [  6.27441406e-02,   6.27746582e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  2.13317871e-02,   2.12707520e-02],
                        [  1.80053711e-03,   1.77001953e-03],
                        [ -1.16577148e-02,  -1.16271973e-02],
                        [ -1.92565918e-02,  -1.91955566e-02],
                        [ -2.00500488e-02,  -2.01110840e-02],
                        [ -1.37634277e-02,  -1.38244629e-02],
                        [ -5.00488281e-03,  -4.97436523e-03],
                        [ -1.64794922e-03,  -1.55639648e-03],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -1.13830566e-02,  -1.14746094e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.50146484e-02,  -1.49536133e-02],
                        [ -1.59606934e-02,  -1.59301758e-02],
                        [ -1.33972168e-02,  -1.34582520e-02],
                        [ -5.73730469e-03,  -5.79833984e-03],
                        [  2.71606445e-03,   2.77709961e-03],
                        [  7.14111328e-03,   7.23266602e-03],
                        [  7.47680664e-03,   7.41577148e-03],
                        [  6.86645508e-03,   6.77490234e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  1.06201172e-02,   1.07421875e-02],
                        [  1.48925781e-02,   1.49536133e-02],
                        [  1.69067383e-02,   1.68151855e-02],
                        [  1.19323730e-02,   1.18408203e-02],
                        [  2.44140625e-04,   3.05175781e-04],
                        [ -1.30615234e-02,  -1.29699707e-02],
                        [ -2.39257812e-02,  -2.39562988e-02],
                        [ -2.98767090e-02,  -2.99682617e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -1.96533203e-02,  -1.95922852e-02],
                        [ -8.78906250e-03,  -8.72802734e-03],
                        [ -8.85009766e-04,  -9.15527344e-04],
                        [  7.62939453e-04,   7.32421875e-04],
                        [ -4.45556641e-03,  -4.51660156e-03],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -2.03247070e-02,  -2.02636719e-02],
                        [ -2.06298828e-02,  -2.05993652e-02],
                        [ -1.31225586e-02,  -1.31835938e-02],
                        [  1.52587891e-04,   6.10351562e-05],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  3.08837891e-02,   3.10058594e-02],
                        [  3.81774902e-02,   3.82080078e-02],
                        [  2.86865234e-02,   2.85949707e-02],
                        [ -3.17382812e-03,  -3.26538086e-03],
                        [ -5.27954102e-02,  -5.27343750e-02],
                        [ -1.05346680e-01,  -1.05255127e-01],
                        [ -1.43676758e-01,  -1.43676758e-01],
                        [ -1.57012939e-01,  -1.57073975e-01],
                        [ -1.45080566e-01,  -1.45141602e-01],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -8.91113281e-02,  -8.90502930e-02],
                        [ -6.68640137e-02,  -6.67724609e-02],
                        [ -5.14526367e-02,  -5.14831543e-02],
                        [ -4.08020020e-02,  -4.09240723e-02],
                        [ -3.17077637e-02,  -3.17382812e-02],
                        [ -1.77917480e-02,  -1.76696777e-02],
                        [  8.45336914e-03,   8.57543945e-03],
                        [  5.15441895e-02,   5.14831543e-02],
                        [  1.09832764e-01,   1.09680176e-01],
                        [  1.73156738e-01,   1.73126221e-01],
                        [  2.22503662e-01,   2.22625732e-01],
                        [  2.36663818e-01,   2.36755371e-01],
                        [  2.04925537e-01,   2.04864502e-01],
                        [  1.32904053e-01,   1.32751465e-01],
                        [  3.28063965e-02,   3.27453613e-02],
                        [ -8.55102539e-02,  -8.53576660e-02],
                        [ -2.06878662e-01,  -2.06726074e-01],
                        [ -3.02124023e-01,  -3.02215576e-01],
                        [ -3.40393066e-01,  -3.40576172e-01],
                        [ -3.16284180e-01,  -3.16253662e-01],
                        [ -2.59460449e-01,  -2.59307861e-01],
                        [ -2.08740234e-01,  -2.08648682e-01],
                        [ -1.77185059e-01,  -1.77307129e-01],
                        [ -1.52679443e-01,  -1.52801514e-01],
                        [ -1.23260498e-01,  -1.23229980e-01],
                        [ -8.77990723e-02,  -8.76464844e-02],
                        [ -4.73327637e-02,  -4.72717285e-02],
                        [  7.32421875e-04,   6.71386719e-04],
                        [  5.90515137e-02,   5.89294434e-02],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  1.67144775e-01,   1.67266846e-01],
                        [  1.84173584e-01,   1.84295654e-01],
                        [  1.77703857e-01,   1.77581787e-01],
                        [  1.65405273e-01,   1.65252686e-01],
                        [  1.56005859e-01,   1.56097412e-01],
                        [  1.43402100e-01,   1.43615723e-01],
                        [  1.20758057e-01,   1.20697021e-01],
                        [  9.21020508e-02,   9.19189453e-02],
                        [  6.70166016e-02,   6.70776367e-02],
                        [  5.04150391e-02,   5.05981445e-02],
                        [  4.18701172e-02,   4.18395996e-02],
                        [  3.74145508e-02,   3.72924805e-02],
                        [  3.13720703e-02,   3.14025879e-02],
                        [  2.38037109e-02,   2.38952637e-02],
                        [  2.19726562e-02,   2.19421387e-02],
                        [  2.94799805e-02,   2.93884277e-02],
                        [  4.11682129e-02,   4.12292480e-02],
                        [  5.17883301e-02,   5.18493652e-02],
                        [  6.06689453e-02,   6.06079102e-02],
                        [  6.68029785e-02,   6.67419434e-02],
                        [  6.67419434e-02,   6.68029785e-02],
                        [  6.07910156e-02,   6.08215332e-02],
                        [  5.45654297e-02,   5.45043945e-02],
                        [  5.05676270e-02,   5.05676270e-02],
                        [  4.47998047e-02,   4.48303223e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  2.70690918e-02,   2.70385742e-02],
                        [  1.95007324e-02,   1.95312500e-02],
                        [  8.97216797e-03,   8.97216797e-03],
                        [ -3.60107422e-03,  -3.66210938e-03],
                        [ -1.29699707e-02,  -1.30004883e-02],
                        [ -1.81884766e-02,  -1.81274414e-02],
                        [ -2.11486816e-02,  -2.11181641e-02],
                        [ -2.02331543e-02,  -2.03247070e-02],
                        [ -1.37939453e-02,  -1.38549805e-02],
                        [ -5.27954102e-03,  -5.21850586e-03],
                        [  1.12915039e-03,   1.19018555e-03],
                        [  4.57763672e-03,   4.51660156e-03],
                        [  4.82177734e-03,   4.76074219e-03],
                        [  1.40380859e-03,   1.40380859e-03],
                        [ -3.50952148e-03,  -3.47900391e-03],
                        [ -6.19506836e-03,  -6.13403320e-03],
                        [ -4.76074219e-03,  -4.79125977e-03],
                        [ -6.10351562e-04,  -7.01904297e-04],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  1.19018555e-03,   1.34277344e-03],
                        [ -2.34985352e-03,  -2.28881836e-03],
                        [ -2.99072266e-03,  -3.08227539e-03],
                        [  0.00000000e+00,  -9.15527344e-05],
                        [  1.92260742e-03,   1.95312500e-03],
                        [  9.15527344e-04,   1.00708008e-03],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  1.22070312e-03,   1.19018555e-03],
                        [ -8.54492188e-04,  -9.46044922e-04],
                        [ -8.17871094e-03,  -8.20922852e-03],
                        [ -1.79748535e-02,  -1.78833008e-02],
                        [ -2.77404785e-02,  -2.76489258e-02],
                        [ -3.76892090e-02,  -3.77502441e-02],
                        [ -4.74853516e-02,  -4.76379395e-02],
                        [ -5.44128418e-02,  -5.44433594e-02],
                        [ -5.46569824e-02,  -5.45043945e-02],
                        [ -4.60815430e-02,  -4.59899902e-02],
                        [ -3.06701660e-02,  -3.08227539e-02],
                        [ -1.29089355e-02,  -1.30615234e-02],
                        [  4.30297852e-03,   4.36401367e-03],
                        [  2.05993652e-02,   2.07214355e-02],
                        [  3.57360840e-02,   3.57666016e-02],
                        [  4.66918945e-02,   4.65698242e-02],
                        [  4.58374023e-02,   4.57763672e-02],
                        [  2.38647461e-02,   2.39257812e-02],
                        [ -2.24914551e-02,  -2.24304199e-02],
                        [ -8.34655762e-02,  -8.34350586e-02],
                        [ -1.38000488e-01,  -1.38061523e-01],
                        [ -1.66412354e-01,  -1.66442871e-01],
                        [ -1.62170410e-01,  -1.62139893e-01],
                        [ -1.32598877e-01,  -1.32537842e-01],
                        [ -9.22546387e-02,  -9.22546387e-02],
                        [ -5.71289062e-02,  -5.71289062e-02],
                        [ -3.80249023e-02,  -3.79943848e-02],
                        [ -3.37219238e-02,  -3.37524414e-02],
                        [ -3.19213867e-02,  -3.19824219e-02],
                        [ -1.88903809e-02,  -1.88293457e-02],
                        [  1.24206543e-02,   1.25427246e-02],
                        [  6.21948242e-02,   6.21643066e-02],
                        [  1.25793457e-01,   1.25671387e-01],
                        [  1.90917969e-01,   1.90887451e-01],
                        [  2.35687256e-01,   2.35839844e-01],
                        [  2.39013672e-01,   2.39105225e-01],
                        [  1.94671631e-01,   1.94580078e-01],
                        [  1.10717773e-01,   1.10565186e-01],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.37908936e-01,  -1.37756348e-01],
                        [ -2.68371582e-01,  -2.68280029e-01],
                        [ -3.52966309e-01,  -3.53088379e-01],
                        [ -3.62487793e-01,  -3.62670898e-01],
                        [ -3.11126709e-01,  -3.11126709e-01],
                        [ -2.46490479e-01,  -2.46307373e-01],
                        [ -2.06298828e-01,  -2.06207275e-01],
                        [ -1.89758301e-01,  -1.89910889e-01],
                        [ -1.70959473e-01,  -1.71142578e-01],
                        [ -1.31469727e-01,  -1.31408691e-01],
                        [ -7.39135742e-02,  -7.36694336e-02],
                        [ -9.33837891e-03,  -9.27734375e-03],
                        [  5.58776855e-02,   5.56335449e-02],
                        [  1.17034912e-01,   1.16912842e-01],
                        [  1.65069580e-01,   1.65252686e-01],
                        [  1.90887451e-01,   1.91070557e-01],
                        [  1.94061279e-01,   1.93969727e-01],
                        [  1.83105469e-01,   1.82922363e-01],
                        [  1.66534424e-01,   1.66534424e-01],
                        [  1.45843506e-01,   1.45996094e-01],
                        [  1.19506836e-01,   1.19567871e-01],
                        [  9.16442871e-02,   9.15222168e-02],
                        [  7.20214844e-02,   7.18994141e-02],
                        [  6.58874512e-02,   6.59484863e-02],
                        [  6.68029785e-02,   6.68945312e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  4.65087891e-02,   4.64477539e-02],
                        [  2.67333984e-02,   2.67028809e-02],
                        [  1.32446289e-02,   1.33056641e-02],
                        [  1.14746094e-02,   1.15051270e-02],
                        [  2.12707520e-02,   2.12402344e-02],
                        [  3.93371582e-02,   3.93066406e-02],
                        [  5.99975586e-02,   6.00280762e-02],
                        [  7.65380859e-02,   7.65686035e-02],
                        [  8.46252441e-02,   8.45642090e-02],
                        [  8.39538574e-02,   8.39233398e-02],
                        [  7.60498047e-02,   7.61413574e-02],
                        [  6.20117188e-02,   6.20422363e-02],
                        [  4.48608398e-02,   4.47692871e-02],
                        [  2.96936035e-02,   2.96630859e-02],
                        [  1.80969238e-02,   1.82189941e-02],
                        [  9.12475586e-03,   9.18579102e-03],
                        [  4.97436523e-03,   4.85229492e-03],
                        [  7.17163086e-03,   7.04956055e-03],
                        [  9.30786133e-03,   9.42993164e-03],
                        [  3.23486328e-03,   3.35693359e-03],
                        [ -1.01013184e-02,  -1.02233887e-02],
                        [ -2.25219727e-02,  -2.26745605e-02],
                        [ -2.88391113e-02,  -2.86865234e-02],
                        [ -2.86560059e-02,  -2.85339355e-02],
                        [ -2.11791992e-02,  -2.13012695e-02],
                        [ -6.53076172e-03,  -6.65283203e-03],
                        [  7.04956055e-03,   7.20214844e-03],
                        [  1.02233887e-02,   1.03149414e-02],
                        [  6.59179688e-03,   6.43920898e-03],
                        [  7.53784180e-03,   7.38525391e-03],
                        [  1.35498047e-02,   1.37329102e-02],
                        [  1.48315430e-02,   1.49841309e-02],
                        [  9.21630859e-03,   9.03320312e-03],
                        [  6.16455078e-03,   5.95092773e-03],
                        [  1.03454590e-02,   1.04980469e-02],
                        [  1.38549805e-02,   1.40686035e-02],
                        [  9.09423828e-03,   9.03320312e-03],
                        [ -7.93457031e-04,  -1.03759766e-03],
                        [ -9.55200195e-03,  -9.58251953e-03],
                        [ -1.56250000e-02,  -1.54113770e-02],
                        [ -1.98059082e-02,  -1.97143555e-02],
                        [ -2.16979980e-02,  -2.18811035e-02],
                        [ -2.02331543e-02,  -2.04162598e-02],
                        [ -1.67846680e-02,  -1.67236328e-02],
                        [ -1.55639648e-02,  -1.53808594e-02],
                        [ -1.80969238e-02,  -1.80664062e-02],
                        [ -2.13623047e-02,  -2.14843750e-02],
                        [ -2.42614746e-02,  -2.43225098e-02],
                        [ -2.88696289e-02,  -2.88085938e-02],
                        [ -3.30505371e-02,  -3.29895020e-02],
                        [ -3.12194824e-02,  -3.11889648e-02],
                        [ -2.26135254e-02,  -2.26440430e-02],
                        [ -1.12915039e-02,  -1.13525391e-02],
                        [  3.35693359e-04,   3.05175781e-04],
                        [  1.15356445e-02,   1.15966797e-02],
                        [  1.95922852e-02,   1.96838379e-02],
                        [  2.18505859e-02,   2.17895508e-02],
                        [  1.75781250e-02,   1.74560547e-02],
                        [  3.38745117e-03,   3.41796875e-03],
                        [ -2.64892578e-02,  -2.63671875e-02],
                        [ -6.97631836e-02,  -6.97326660e-02],
                        [ -1.11938477e-01,  -1.12030029e-01],
                        [ -1.37573242e-01,  -1.37603760e-01],
                        [ -1.40197754e-01,  -1.40136719e-01],
                        [ -1.22802734e-01,  -1.22802734e-01],
                        [ -9.60388184e-02,  -9.60693359e-02],
                        [ -7.43713379e-02,  -7.42492676e-02],
                        [ -6.54296875e-02,  -6.53991699e-02],
                        [ -6.03332520e-02,  -6.04858398e-02],
                        [ -3.90930176e-02,  -3.92150879e-02],
                        [  7.81250000e-03,   8.05664062e-03],
                        [  6.99462891e-02,   7.01599121e-02],
                        [  1.32843018e-01,   1.32629395e-01],
                        [  1.90673828e-01,   1.90338135e-01],
                        [  2.34313965e-01,   2.34436035e-01],
                        [  2.44598389e-01,   2.45025635e-01],
                        [  2.08618164e-01,   2.08618164e-01],
                        [  1.30645752e-01,   1.30187988e-01],
                        [  2.15454102e-02,   2.13928223e-02],
                        [ -1.09161377e-01,  -1.08764648e-01],
                        [ -2.41760254e-01,  -2.41516113e-01],
                        [ -3.38653564e-01,  -3.38958740e-01],
                        [ -3.66607666e-01,  -3.66943359e-01],
                        [ -3.29833984e-01,  -3.29650879e-01],
                        [ -2.68157959e-01,  -2.67761230e-01],
                        [ -2.18719482e-01,  -2.18780518e-01],
                        [ -1.88110352e-01,  -1.88476562e-01],
                        [ -1.62414551e-01,  -1.62475586e-01],
                        [ -1.30004883e-01,  -1.29699707e-01],
                        [ -8.59069824e-02,  -8.57849121e-02],
                        [ -2.70690918e-02,  -2.73132324e-02],
                        [  4.27246094e-02,   4.25720215e-02],
                        [  1.08123779e-01,   1.08245850e-01],
                        [  1.52740479e-01,   1.52862549e-01],
                        [  1.71844482e-01,   1.71783447e-01],
                        [  1.71875000e-01,   1.71813965e-01],
                        [  1.63085938e-01,   1.63116455e-01],
                        [  1.53625488e-01,   1.53594971e-01],
                        [  1.45111084e-01,   1.45080566e-01],
                        [  1.32843018e-01,   1.32904053e-01],
                        [  1.14257812e-01,   1.14318848e-01],
                        [  9.52758789e-02,   9.51538086e-02],
                        [  8.30078125e-02,   8.29467773e-02],
                        [  7.48291016e-02,   7.49511719e-02],
                        [  6.20422363e-02,   6.21337891e-02],
                        [  4.31823730e-02,   4.30603027e-02],
                        [  2.48718262e-02,   2.47497559e-02],
                        [  1.19323730e-02,   1.20239258e-02],
                        [  6.46972656e-03,   6.53076172e-03],
                        [  1.28173828e-02,   1.27258301e-02],
                        [  3.23181152e-02,   3.22875977e-02],
                        [  5.66711426e-02,   5.67321777e-02],
                        [  7.58666992e-02,   7.58361816e-02],
                        [  8.84094238e-02,   8.82873535e-02],
                        [  9.45739746e-02,   9.46350098e-02],
                        [  8.96606445e-02,   8.98437500e-02],
                        [  7.40966797e-02,   7.40356445e-02],
                        [  5.86547852e-02,   5.84411621e-02],
                        [  4.96215820e-02,   4.96826172e-02],
                        [  3.99780273e-02,   4.01916504e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  6.04248047e-03,   5.85937500e-03],
                        [ -3.72314453e-03,  -3.75366211e-03],
                        [ -8.20922852e-03,  -8.08715820e-03],
                        [ -1.41296387e-02,  -1.40686035e-02],
                        [ -2.12402344e-02,  -2.12707520e-02],
                        [ -2.44445801e-02,  -2.44750977e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -9.30786133e-03,  -9.24682617e-03],
                        [ -5.09643555e-03,  -5.03540039e-03],
                        [ -3.66210938e-04,  -4.27246094e-04],
                        [  7.38525391e-03,   7.32421875e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.56250000e-02,   1.56555176e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  5.49316406e-03,   5.49316406e-03],
                        [  1.25122070e-03,   1.28173828e-03],
                        [ -1.86157227e-03,  -1.95312500e-03],
                        [ -3.63159180e-03,  -3.69262695e-03],
                        [ -4.73022461e-03,  -4.60815430e-03],
                        [ -7.29370117e-03,  -7.14111328e-03],
                        [ -1.03454590e-02,  -1.04980469e-02],
                        [ -1.02539062e-02,  -1.04675293e-02],
                        [ -7.78198242e-03,  -7.65991211e-03],
                        [ -7.99560547e-03,  -7.75146484e-03],
                        [ -1.12609863e-02,  -1.12915039e-02],
                        [ -1.31530762e-02,  -1.34277344e-02],
                        [ -1.41601562e-02,  -1.41906738e-02],
                        [ -1.94702148e-02,  -1.92871094e-02],
                        [ -2.93579102e-02,  -2.92968750e-02],
                        [ -3.67431641e-02,  -3.68347168e-02],
                        [ -3.58581543e-02,  -3.59191895e-02],
                        [ -2.86254883e-02,  -2.85949707e-02],
                        [ -2.11791992e-02,  -2.11486816e-02],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.70288086e-02,  -1.69982910e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -1.73950195e-02,  -1.74255371e-02],
                        [ -1.29089355e-02,  -1.29699707e-02],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [  1.15661621e-02,   1.16271973e-02],
                        [  2.56347656e-02,   2.56652832e-02],
                        [  2.85949707e-02,   2.85339355e-02],
                        [  1.10778809e-02,   1.09558105e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -8.03527832e-02,  -8.02001953e-02],
                        [ -1.27502441e-01,  -1.27410889e-01],
                        [ -1.51519775e-01,  -1.51702881e-01],
                        [ -1.43585205e-01,  -1.43798828e-01],
                        [ -1.13525391e-01,  -1.13403320e-01],
                        [ -8.47473145e-02,  -8.44726562e-02],
                        [ -7.08618164e-02,  -7.08923340e-02],
                        [ -6.11267090e-02,  -6.14624023e-02],
                        [ -3.75671387e-02,  -3.76586914e-02],
                        [  1.89208984e-03,   2.16674805e-03],
                        [  4.73327637e-02,   4.75158691e-02],
                        [  9.50012207e-02,   9.48181152e-02],
                        [  1.46881104e-01,   1.46667480e-01],
                        [  1.95404053e-01,   1.95465088e-01],
                        [  2.22259521e-01,   2.22442627e-01],
                        [  2.12127686e-01,   2.12188721e-01],
                        [  1.58355713e-01,   1.58264160e-01],
                        [  6.09741211e-02,   6.08825684e-02],
                        [ -6.94885254e-02,  -6.94885254e-02],
                        [ -2.07977295e-01,  -2.07885742e-01],
                        [ -3.19000244e-01,  -3.18908691e-01],
                        [ -3.69506836e-01,  -3.69537354e-01],
                        [ -3.50097656e-01,  -3.50219727e-01],
                        [ -2.86651611e-01,  -2.86682129e-01],
                        [ -2.21771240e-01,  -2.21618652e-01],
                        [ -1.81091309e-01,  -1.81030273e-01],
                        [ -1.60003662e-01,  -1.60125732e-01],
                        [ -1.36718750e-01,  -1.36840820e-01],
                        [ -9.48486328e-02,  -9.47570801e-02],
                        [ -3.48205566e-02,  -3.46984863e-02],
                        [  3.23181152e-02,   3.22875977e-02],
                        [  9.54589844e-02,   9.53063965e-02],
                        [  1.44714355e-01,   1.44683838e-01],
                        [  1.72668457e-01,   1.72790527e-01],
                        [  1.80419922e-01,   1.80480957e-01],
                        [  1.78009033e-01,   1.77886963e-01],
                        [  1.72454834e-01,   1.72363281e-01],
                        [  1.59851074e-01,   1.59912109e-01],
                        [  1.34887695e-01,   1.35009766e-01],
                        [  1.04431152e-01,   1.04400635e-01],
                        [  8.18786621e-02,   8.17565918e-02],
                        [  7.10449219e-02,   7.10449219e-02],
                        [  6.40563965e-02,   6.41479492e-02],
                        [  5.30700684e-02,   5.31005859e-02],
                        [  3.90930176e-02,   3.90014648e-02],
                        [  2.80456543e-02,   2.80151367e-02],
                        [  2.32849121e-02,   2.33154297e-02],
                        [  2.45361328e-02,   2.45666504e-02],
                        [  3.15856934e-02,   3.15551758e-02],
                        [  4.35485840e-02,   4.35485840e-02],
                        [  5.68542480e-02,   5.68847656e-02],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  7.58056641e-02,   7.57751465e-02],
                        [  7.77893066e-02,   7.78198242e-02],
                        [  7.16552734e-02,   7.17163086e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  4.64782715e-02,   4.64172363e-02],
                        [  3.95507812e-02,   3.95202637e-02],
                        [  3.75366211e-02,   3.75976562e-02],
                        [  3.47290039e-02,   3.48205566e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  1.15356445e-02,   1.14440918e-02],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [ -1.21765137e-02,  -1.20849609e-02],
                        [ -1.49841309e-02,  -1.49230957e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -1.66320801e-02,  -1.66931152e-02],
                        [ -1.73950195e-02,  -1.74560547e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -1.46179199e-02,  -1.45263672e-02],
                        [ -1.06506348e-02,  -1.05895996e-02],
                        [ -6.56127930e-03,  -6.62231445e-03],
                        [ -5.49316406e-04,  -7.01904297e-04],
                        [  8.81958008e-03,   8.85009766e-03],
                        [  1.73645020e-02,   1.75781250e-02],
                        [  1.99584961e-02,   2.00500488e-02],
                        [  1.85852051e-02,   1.83715820e-02],
                        [  1.86157227e-02,   1.84326172e-02],
                        [  1.97448730e-02,   1.98974609e-02],
                        [  1.71508789e-02,   1.73950195e-02],
                        [  1.09252930e-02,   1.08642578e-02],
                        [  6.34765625e-03,   6.13403320e-03],
                        [  4.66918945e-03,   4.60815430e-03],
                        [  1.25122070e-03,   1.40380859e-03],
                        [ -6.80541992e-03,  -6.71386719e-03],
                        [ -1.65710449e-02,  -1.66320801e-02],
                        [ -2.31323242e-02,  -2.32238770e-02],
                        [ -2.52685547e-02,  -2.53295898e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.21350098e-02,  -3.20434570e-02],
                        [ -3.68347168e-02,  -3.67736816e-02],
                        [ -3.60412598e-02,  -3.61328125e-02],
                        [ -2.95410156e-02,  -2.96936035e-02],
                        [ -2.25219727e-02,  -2.24609375e-02],
                        [ -2.10266113e-02,  -2.08740234e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.85949707e-02,  -2.87475586e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -1.58691406e-02,  -1.57470703e-02],
                        [ -5.76782227e-03,  -5.79833984e-03],
                        [  8.85009766e-03,   8.75854492e-03],
                        [  2.59094238e-02,   2.60009766e-02],
                        [  3.21960449e-02,   3.23181152e-02],
                        [  1.71508789e-02,   1.70288086e-02],
                        [ -1.65100098e-02,  -1.67236328e-02],
                        [ -5.98754883e-02,  -5.97229004e-02],
                        [ -1.02416992e-01,  -1.02142334e-01],
                        [ -1.28631592e-01,  -1.28753662e-01],
                        [ -1.24755859e-01,  -1.25091553e-01],
                        [ -9.65576172e-02,  -9.65270996e-02],
                        [ -6.83898926e-02,  -6.80541992e-02],
                        [ -5.79223633e-02,  -5.78308105e-02],
                        [ -5.83190918e-02,  -5.85937500e-02],
                        [ -4.95605469e-02,  -4.97741699e-02],
                        [ -2.03552246e-02,  -2.02026367e-02],
                        [  2.61535645e-02,   2.64282227e-02],
                        [  8.19396973e-02,   8.19091797e-02],
                        [  1.40716553e-01,   1.40472412e-01],
                        [  1.94549561e-01,   1.94458008e-01],
                        [  2.28393555e-01,   2.28576660e-01],
                        [  2.24945068e-01,   2.25128174e-01],
                        [  1.75018311e-01,   1.74987793e-01],
                        [  8.08105469e-02,   8.05969238e-02],
                        [ -4.68444824e-02,  -4.69055176e-02],
                        [ -1.86065674e-01,  -1.85913086e-01],
                        [ -3.02856445e-01,  -3.02703857e-01],
                        [ -3.63494873e-01,  -3.63555908e-01],
                        [ -3.55895996e-01,  -3.56048584e-01],
                        [ -3.00811768e-01,  -3.00842285e-01],
                        [ -2.37823486e-01,  -2.37701416e-01],
                        [ -1.94641113e-01,  -1.94519043e-01],
                        [ -1.69342041e-01,  -1.69403076e-01],
                        [ -1.41693115e-01,  -1.41876221e-01],
                        [ -9.64050293e-02,  -9.64660645e-02],
                        [ -3.40270996e-02,  -3.38439941e-02],
                        [  3.36608887e-02,   3.37829590e-02],
                        [  9.35058594e-02,   9.33532715e-02],
                        [  1.36474609e-01,   1.36260986e-01],
                        [  1.57714844e-01,   1.57836914e-01],
                        [  1.58813477e-01,   1.59057617e-01],
                        [  1.51336670e-01,   1.51275635e-01],
                        [  1.49169922e-01,   1.48864746e-01],
                        [  1.51519775e-01,   1.51519775e-01],
                        [  1.43066406e-01,   1.43402100e-01],
                        [  1.17767334e-01,   1.17828369e-01],
                        [  9.01794434e-02,   8.98437500e-02],
                        [  7.32727051e-02,   7.31811523e-02],
                        [  5.99060059e-02,   6.02111816e-02],
                        [  3.97949219e-02,   3.99169922e-02],
                        [  2.02636719e-02,   1.99890137e-02],
                        [  1.54113770e-02,   1.52282715e-02],
                        [  2.45666504e-02,   2.47802734e-02],
                        [  3.54003906e-02,   3.55834961e-02],
                        [  4.13513184e-02,   4.11682129e-02],
                        [  4.56237793e-02,   4.54101562e-02],
                        [  5.14221191e-02,   5.15441895e-02],
                        [  5.71899414e-02,   5.74035645e-02],
                        [  6.16149902e-02,   6.15539551e-02],
                        [  6.64062500e-02,   6.62231445e-02],
                        [  7.18078613e-02,   7.18078613e-02],
                        [  7.45239258e-02,   7.46765137e-02],
                        [  7.16552734e-02,   7.17163086e-02],
                        [  6.31713867e-02,   6.30798340e-02],
                        [  5.02014160e-02,   5.01098633e-02],
                        [  3.40270996e-02,   3.40881348e-02],
                        [  1.78527832e-02,   1.79748535e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -3.66210938e-04,  -5.18798828e-04],
                        [ -3.81469727e-03,  -3.87573242e-03],
                        [ -9.24682617e-03,  -9.12475586e-03],
                        [ -1.86462402e-02,  -1.85241699e-02],
                        [ -2.76489258e-02,  -2.77404785e-02],
                        [ -2.91137695e-02,  -2.92663574e-02],
                        [ -2.23693848e-02,  -2.23388672e-02],
                        [ -1.49536133e-02,  -1.47705078e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -9.27734375e-03,  -9.42993164e-03],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [  9.91821289e-03,   1.00402832e-02],
                        [  1.79443359e-02,   1.79748535e-02],
                        [  2.19421387e-02,   2.18200684e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.45056152e-02,   2.45666504e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  9.30786133e-03,   9.24682617e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  9.15527344e-05,   1.52587891e-04],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -1.25122070e-03,  -1.31225586e-03],
                        [ -2.99072266e-03,  -3.02124023e-03],
                        [ -7.59887695e-03,  -7.56835938e-03],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -2.19726562e-02,  -2.19421387e-02],
                        [ -2.78015137e-02,  -2.78320312e-02],
                        [ -3.08532715e-02,  -3.09143066e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.16467285e-02,  -3.15246582e-02],
                        [ -3.30810547e-02,  -3.30505371e-02],
                        [ -3.45153809e-02,  -3.46679688e-02],
                        [ -3.52783203e-02,  -3.53393555e-02],
                        [ -3.61633301e-02,  -3.60107422e-02],
                        [ -3.57055664e-02,  -3.55834961e-02],
                        [ -2.82287598e-02,  -2.83508301e-02],
                        [ -9.70458984e-03,  -9.82666016e-03],
                        [  1.48620605e-02,   1.49230957e-02],
                        [  3.48815918e-02,   3.50036621e-02],
                        [  4.42504883e-02,   4.42199707e-02],
                        [  4.22363281e-02,   4.21447754e-02],
                        [  2.66418457e-02,   2.66113281e-02],
                        [ -6.34765625e-03,  -6.31713867e-03],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -1.06384277e-01,  -1.06323242e-01],
                        [ -1.42150879e-01,  -1.42150879e-01],
                        [ -1.46881104e-01,  -1.46972656e-01],
                        [ -1.21246338e-01,  -1.21307373e-01],
                        [ -8.36181641e-02,  -8.35266113e-02],
                        [ -5.45654297e-02,  -5.44433594e-02],
                        [ -3.78112793e-02,  -3.78723145e-02],
                        [ -2.10266113e-02,  -2.11791992e-02],
                        [  6.50024414e-03,   6.46972656e-03],
                        [  4.48608398e-02,   4.50134277e-02],
                        [  8.97216797e-02,   8.98437500e-02],
                        [  1.36962891e-01,   1.36871338e-01],
                        [  1.81030273e-01,   1.80816650e-01],
                        [  2.10754395e-01,   2.10784912e-01],
                        [  2.08312988e-01,   2.08557129e-01],
                        [  1.58508301e-01,   1.58630371e-01],
                        [  6.24084473e-02,   6.21643066e-02],
                        [ -6.35375977e-02,  -6.37817383e-02],
                        [ -1.96197510e-01,  -1.96014404e-01],
                        [ -3.06701660e-01,  -3.06365967e-01],
                        [ -3.62976074e-01,  -3.63067627e-01],
                        [ -3.48724365e-01,  -3.49090576e-01],
                        [ -2.83996582e-01,  -2.84027100e-01],
                        [ -2.16430664e-01,  -2.16064453e-01],
                        [ -1.80938721e-01,  -1.80786133e-01],
                        [ -1.70227051e-01,  -1.70501709e-01],
                        [ -1.51153564e-01,  -1.51397705e-01],
                        [ -1.02996826e-01,  -1.02813721e-01],
                        [ -3.09448242e-02,  -3.07006836e-02],
                        [  4.65087891e-02,   4.64172363e-02],
                        [  1.11114502e-01,   1.10900879e-01],
                        [  1.50238037e-01,   1.50268555e-01],
                        [  1.62139893e-01,   1.62261963e-01],
                        [  1.59576416e-01,   1.59576416e-01],
                        [  1.60339355e-01,   1.60247803e-01],
                        [  1.67602539e-01,   1.67633057e-01],
                        [  1.67144775e-01,   1.67236328e-01],
                        [  1.47247314e-01,   1.47186279e-01],
                        [  1.12762451e-01,   1.12640381e-01],
                        [  7.71179199e-02,   7.71789551e-02],
                        [  4.89501953e-02,   4.91027832e-02],
                        [  2.99377441e-02,   2.98767090e-02],
                        [  1.98669434e-02,   1.96838379e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.95922852e-02,   1.97448730e-02],
                        [  2.33459473e-02,   2.34680176e-02],
                        [  3.01513672e-02,   3.00292969e-02],
                        [  4.01916504e-02,   4.00390625e-02],
                        [  5.13305664e-02,   5.13916016e-02],
                        [  6.25610352e-02,   6.27441406e-02],
                        [  7.31811523e-02,   7.32116699e-02],
                        [  8.00781250e-02,   7.99255371e-02],
                        [  8.04748535e-02,   8.04138184e-02],
                        [  7.37609863e-02,   7.38220215e-02],
                        [  6.09130859e-02,   6.09741211e-02],
                        [  4.55017090e-02,   4.55322266e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  2.15148926e-02,   2.14538574e-02],
                        [  1.65100098e-02,   1.64489746e-02],
                        [  1.71813965e-02,   1.72424316e-02],
                        [  1.75476074e-02,   1.77001953e-02],
                        [  9.42993164e-03,   9.39941406e-03],
                        [ -5.27954102e-03,  -5.49316406e-03],
                        [ -1.60217285e-02,  -1.60827637e-02],
                        [ -1.77612305e-02,  -1.75170898e-02],
                        [ -1.35192871e-02,  -1.33972168e-02],
                        [ -5.64575195e-03,  -5.85937500e-03],
                        [  3.93676758e-03,   3.81469727e-03],
                        [  9.67407227e-03,   9.82666016e-03],
                        [  8.23974609e-03,   8.30078125e-03],
                        [  3.44848633e-03,   3.35693359e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -4.85229492e-03,  -4.73022461e-03],
                        [ -7.96508789e-03,  -8.02612305e-03],
                        [ -4.57763672e-03,  -4.73022461e-03],
                        [  6.92749023e-03,   7.04956055e-03],
                        [  1.95312500e-02,   1.97448730e-02],
                        [  2.54516602e-02,   2.53601074e-02],
                        [  2.45056152e-02,   2.42309570e-02],
                        [  1.92260742e-02,   1.92565918e-02],
                        [  9.18579102e-03,   9.49096680e-03],
                        [ -4.15039062e-03,  -4.11987305e-03],
                        [ -1.37023926e-02,  -1.39770508e-02],
                        [ -1.55639648e-02,  -1.56555176e-02],
                        [ -1.61437988e-02,  -1.58996582e-02],
                        [ -2.32238770e-02,  -2.31018066e-02],
                        [ -3.35083008e-02,  -3.36914062e-02],
                        [ -3.79333496e-02,  -3.80859375e-02],
                        [ -3.61633301e-02,  -3.60412598e-02],
                        [ -3.46984863e-02,  -3.45764160e-02],
                        [ -3.38439941e-02,  -3.39355469e-02],
                        [ -2.89611816e-02,  -2.90832520e-02],
                        [ -2.15454102e-02,  -2.14538574e-02],
                        [ -1.80358887e-02,  -1.79138184e-02],
                        [ -1.96228027e-02,  -1.97143555e-02],
                        [ -2.02941895e-02,  -2.04772949e-02],
                        [ -1.52282715e-02,  -1.51672363e-02],
                        [ -6.28662109e-03,  -6.04248047e-03],
                        [  3.54003906e-03,   3.50952148e-03],
                        [  1.65405273e-02,   1.62963867e-02],
                        [  3.39965820e-02,   3.39660645e-02],
                        [  4.64172363e-02,   4.66613770e-02],
                        [  3.92150879e-02,   3.92761230e-02],
                        [  6.80541992e-03,   6.59179688e-03],
                        [ -4.35485840e-02,  -4.36401367e-02],
                        [ -9.75341797e-02,  -9.73815918e-02],
                        [ -1.37878418e-01,  -1.37756348e-01],
                        [ -1.49658203e-01,  -1.49749756e-01],
                        [ -1.31256104e-01,  -1.31347656e-01],
                        [ -9.59167480e-02,  -9.58557129e-02],
                        [ -5.87158203e-02,  -5.86853027e-02],
                        [ -2.77404785e-02,  -2.77709961e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [  1.45568848e-02,   1.45874023e-02],
                        [  4.45251465e-02,   4.44946289e-02],
                        [  9.19494629e-02,   9.19189453e-02],
                        [  1.47857666e-01,   1.47918701e-01],
                        [  1.94580078e-01,   1.94580078e-01],
                        [  2.16156006e-01,   2.16094971e-01],
                        [  1.98669434e-01,   1.98699951e-01],
                        [  1.30767822e-01,   1.30859375e-01],
                        [  1.33972168e-02,   1.33361816e-02],
                        [ -1.31774902e-01,  -1.31896973e-01],
                        [ -2.68402100e-01,  -2.68310547e-01],
                        [ -3.59405518e-01,  -3.59252930e-01],
                        [ -3.81134033e-01,  -3.81195068e-01],
                        [ -3.37860107e-01,  -3.38043213e-01],
                        [ -2.65411377e-01,  -2.65350342e-01],
                        [ -2.06481934e-01,  -2.06298828e-01],
                        [ -1.76116943e-01,  -1.76177979e-01],
                        [ -1.54998779e-01,  -1.55181885e-01],
                        [ -1.15936279e-01,  -1.15905762e-01],
                        [ -5.17883301e-02,  -5.16662598e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  9.08203125e-02,   9.07287598e-02],
                        [  1.35711670e-01,   1.35742188e-01],
                        [  1.52587891e-01,   1.52648926e-01],
                        [  1.51702881e-01,   1.51641846e-01],
                        [  1.51275635e-01,   1.51184082e-01],
                        [  1.56677246e-01,   1.56768799e-01],
                        [  1.57226562e-01,   1.57348633e-01],
                        [  1.43585205e-01,   1.43493652e-01],
                        [  1.19110107e-01,   1.18927002e-01],
                        [  9.35363770e-02,   9.35668945e-02],
                        [  7.25708008e-02,   7.27233887e-02],
                        [  5.60607910e-02,   5.61218262e-02],
                        [  4.32739258e-02,   4.31213379e-02],
                        [  3.36608887e-02,   3.35693359e-02],
                        [  2.53601074e-02,   2.54211426e-02],
                        [  1.87988281e-02,   1.89514160e-02],
                        [  1.94091797e-02,   1.94396973e-02],
                        [  3.05175781e-02,   3.03955078e-02],
                        [  4.71801758e-02,   4.71191406e-02],
                        [  6.07299805e-02,   6.07910156e-02],
                        [  6.78100586e-02,   6.78405762e-02],
                        [  7.15637207e-02,   7.15637207e-02],
                        [  7.42797852e-02,   7.43103027e-02],
                        [  7.35778809e-02,   7.35168457e-02],
                        [  6.68945312e-02,   6.68029785e-02],
                        [  5.42602539e-02,   5.43212891e-02],
                        [  3.66821289e-02,   3.68347168e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  6.10351562e-03,   5.92041016e-03],
                        [  2.96020508e-03,   2.86865234e-03],
                        [  3.17382812e-03,   3.29589844e-03],
                        [  6.10351562e-04,   7.62939453e-04],
                        [ -4.73022461e-03,  -4.76074219e-03],
                        [ -9.88769531e-03,  -1.00402832e-02],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.36718750e-02,  -1.36108398e-02],
                        [ -1.09558105e-02,  -1.08947754e-02],
                        [ -5.34057617e-03,  -5.31005859e-03],
                        [  1.52587891e-03,   1.49536133e-03],
                        [  7.75146484e-03,   7.62939453e-03],
                        [  1.25122070e-02,   1.25122070e-02],
                        [  1.61132812e-02,   1.62658691e-02],
                        [  1.79443359e-02,   1.80358887e-02],
                        [  1.70898438e-02,   1.69067383e-02],
                        [  1.48620605e-02,   1.46789551e-02],
                        [  1.32141113e-02,   1.33056641e-02],
                        [  1.13220215e-02,   1.15051270e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  7.44628906e-03,   7.29370117e-03],
                        [  7.96508789e-03,   7.90405273e-03],
                        [  5.58471680e-03,   5.67626953e-03],
                        [ -1.34277344e-03,  -1.31225586e-03],
                        [ -8.81958008e-03,  -8.78906250e-03],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.66931152e-02,  -1.68151855e-02],
                        [ -1.90429688e-02,  -1.91345215e-02],
                        [ -2.12097168e-02,  -2.10876465e-02],
                        [ -2.41699219e-02,  -2.39868164e-02],
                        [ -2.57568359e-02,  -2.58483887e-02],
                        [ -2.20642090e-02,  -2.22778320e-02],
                        [ -1.59301758e-02,  -1.58996582e-02],
                        [ -1.56250000e-02,  -1.54113770e-02],
                        [ -2.26135254e-02,  -2.25830078e-02],
                        [ -2.99987793e-02,  -3.01513672e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.51867676e-02,  -3.51257324e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -2.08740234e-02,  -2.07824707e-02],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [  1.67541504e-02,   1.66015625e-02],
                        [  3.85131836e-02,   3.84521484e-02],
                        [  4.95300293e-02,   4.97436523e-02],
                        [  3.54919434e-02,   3.56140137e-02],
                        [ -4.33349609e-03,  -4.54711914e-03],
                        [ -5.55114746e-02,  -5.56945801e-02],
                        [ -1.02050781e-01,  -1.01898193e-01],
                        [ -1.33361816e-01,  -1.33148193e-01],
                        [ -1.41601562e-01,  -1.41662598e-01],
                        [ -1.23535156e-01,  -1.23779297e-01],
                        [ -8.68225098e-02,  -8.68530273e-02],
                        [ -4.75769043e-02,  -4.73327637e-02],
                        [ -1.66625977e-02,  -1.65710449e-02],
                        [  9.39941406e-03,   9.15527344e-03],
                        [  4.09240723e-02,   4.07714844e-02],
                        [  8.18176270e-02,   8.20007324e-02],
                        [  1.26800537e-01,   1.26953125e-01],
                        [  1.68029785e-01,   1.67877197e-01],
                        [  1.96868896e-01,   1.96685791e-01],
                        [  1.98455811e-01,   1.98547363e-01],
                        [  1.55151367e-01,   1.55364990e-01],
                        [  6.26220703e-02,   6.26220703e-02],
                        [ -6.34765625e-02,  -6.36901855e-02],
                        [ -1.96716309e-01,  -1.96746826e-01],
                        [ -3.06915283e-01,  -3.06732178e-01],
                        [ -3.65539551e-01,  -3.65478516e-01],
                        [ -3.59924316e-01,  -3.60076904e-01],
                        [ -3.04595947e-01,  -3.04718018e-01],
                        [ -2.33978271e-01,  -2.33886719e-01],
                        [ -1.79412842e-01,  -1.79290771e-01],
                        [ -1.46972656e-01,  -1.47033691e-01],
                        [ -1.17248535e-01,  -1.17370605e-01],
                        [ -7.09228516e-02,  -7.09228516e-02],
                        [ -9.91821289e-03,  -9.82666016e-03],
                        [  4.91638184e-02,   4.91638184e-02],
                        [  9.34448242e-02,   9.33532715e-02],
                        [  1.20361328e-01,   1.20361328e-01],
                        [  1.33789062e-01,   1.33850098e-01],
                        [  1.39892578e-01,   1.39862061e-01],
                        [  1.44409180e-01,   1.44348145e-01],
                        [  1.47979736e-01,   1.48040771e-01],
                        [  1.45080566e-01,   1.45141602e-01],
                        [  1.33422852e-01,   1.33361816e-01],
                        [  1.18530273e-01,   1.18469238e-01],
                        [  1.04949951e-01,   1.04980469e-01],
                        [  8.93859863e-02,   8.94470215e-02],
                        [  6.70776367e-02,   6.70471191e-02],
                        [  3.82080078e-02,   3.81469727e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [ -1.44653320e-02,  -1.44042969e-02],
                        [ -2.10266113e-02,  -2.09960938e-02],
                        [ -8.60595703e-03,  -8.63647461e-03],
                        [  1.73034668e-02,   1.72424316e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  6.94274902e-02,   6.94580078e-02],
                        [  8.57849121e-02,   8.58154297e-02],
                        [  9.63745117e-02,   9.63439941e-02],
                        [  1.00860596e-01,   1.00830078e-01],
                        [  9.71984863e-02,   9.72595215e-02],
                        [  8.49914551e-02,   8.50219727e-02],
                        [  6.78100586e-02,   6.77490234e-02],
                        [  4.96826172e-02,   4.96520996e-02],
                        [  3.01818848e-02,   3.02429199e-02],
                        [  8.97216797e-03,   9.03320312e-03],
                        [ -8.08715820e-03,  -8.20922852e-03],
                        [ -1.62353516e-02,  -1.62963867e-02],
                        [ -1.89208984e-02,  -1.87988281e-02],
                        [ -2.10266113e-02,  -2.09655762e-02],
                        [ -2.14233398e-02,  -2.15148926e-02],
                        [ -1.76391602e-02,  -1.77307129e-02],
                        [ -1.16271973e-02,  -1.15661621e-02],
                        [ -6.04248047e-03,  -5.95092773e-03],
                        [  3.05175781e-04,   2.74658203e-04],
                        [  9.64355469e-03,   9.58251953e-03],
                        [  2.04772949e-02,   2.04467773e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  3.02734375e-02,   3.03039551e-02],
                        [  2.57568359e-02,   2.57873535e-02],
                        [  1.85546875e-02,   1.85241699e-02],
                        [  1.51062012e-02,   1.50146484e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.31628418e-02,   2.32849121e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  1.80969238e-02,   1.79443359e-02],
                        [  9.24682617e-03,   9.21630859e-03],
                        [ -1.37329102e-03,  -1.28173828e-03],
                        [ -1.25122070e-02,  -1.24816895e-02],
                        [ -2.05688477e-02,  -2.06604004e-02],
                        [ -2.33459473e-02,  -2.33764648e-02],
                        [ -2.49023438e-02,  -2.48413086e-02],
                        [ -3.01208496e-02,  -3.00903320e-02],
                        [ -3.65905762e-02,  -3.66516113e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.50646973e-02,  -3.50036621e-02],
                        [ -2.72827148e-02,  -2.72521973e-02],
                        [ -1.79443359e-02,  -1.80358887e-02],
                        [ -1.08337402e-02,  -1.08642578e-02],
                        [ -9.30786133e-03,  -9.18579102e-03],
                        [ -1.43127441e-02,  -1.42517090e-02],
                        [ -2.34680176e-02,  -2.35900879e-02],
                        [ -3.10363770e-02,  -3.11279297e-02],
                        [ -3.13110352e-02,  -3.12500000e-02],
                        [ -2.28881836e-02,  -2.27355957e-02],
                        [ -8.02612305e-03,  -8.05664062e-03],
                        [  8.78906250e-03,   8.63647461e-03],
                        [  2.28576660e-02,   2.27966309e-02],
                        [  3.17077637e-02,   3.18603516e-02],
                        [  3.38745117e-02,   3.39660645e-02],
                        [  2.41394043e-02,   2.40478516e-02],
                        [ -3.99780273e-03,  -4.11987305e-03],
                        [ -4.86450195e-02,  -4.86450195e-02],
                        [ -9.52148438e-02,  -9.51232910e-02],
                        [ -1.24938965e-01,  -1.24847412e-01],
                        [ -1.27380371e-01,  -1.27471924e-01],
                        [ -1.04461670e-01,  -1.04614258e-01],
                        [ -6.75048828e-02,  -6.74743652e-02],
                        [ -3.31420898e-02,  -3.29895020e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [  2.22778320e-03,   2.10571289e-03],
                        [  2.42919922e-02,   2.42309570e-02],
                        [  6.19812012e-02,   6.20422363e-02],
                        [  1.12091064e-01,   1.12182617e-01],
                        [  1.62200928e-01,   1.62200928e-01],
                        [  1.93389893e-01,   1.93328857e-01],
                        [  1.89178467e-01,   1.89178467e-01],
                        [  1.41632080e-01,   1.41662598e-01],
                        [  5.01098633e-02,   5.01098633e-02],
                        [ -7.54089355e-02,  -7.53784180e-02],
                        [ -2.09777832e-01,  -2.09747314e-01],
                        [ -3.18603516e-01,  -3.18664551e-01],
                        [ -3.71459961e-01,  -3.71551514e-01],
                        [ -3.58520508e-01,  -3.58459473e-01],
                        [ -3.01696777e-01,  -3.01544189e-01],
                        [ -2.42156982e-01,  -2.42187500e-01],
                        [ -2.05261230e-01,  -2.05413818e-01],
                        [ -1.80358887e-01,  -1.80358887e-01],
                        [ -1.39373779e-01,  -1.39251709e-01],
                        [ -6.89392090e-02,  -6.89086914e-02],
                        [  1.93481445e-02,   1.92565918e-02],
                        [  9.84191895e-02,   9.84191895e-02],
                        [  1.43798828e-01,   1.43859863e-01],
                        [  1.52404785e-01,   1.52404785e-01],
                        [  1.44073486e-01,   1.44012451e-01],
                        [  1.39282227e-01,   1.39343262e-01],
                        [  1.42639160e-01,   1.42700195e-01],
                        [  1.47216797e-01,   1.47125244e-01],
                        [  1.43798828e-01,   1.43737793e-01],
                        [  1.27777100e-01,   1.27838135e-01],
                        [  1.03515625e-01,   1.03607178e-01],
                        [  8.04443359e-02,   8.04138184e-02],
                        [  6.35681152e-02,   6.34460449e-02],
                        [  5.02319336e-02,   5.01708984e-02],
                        [  3.45458984e-02,   3.46374512e-02],
                        [  1.53503418e-02,   1.54724121e-02],
                        [  7.01904297e-04,   6.40869141e-04],
                        [  4.57763672e-04,   3.35693359e-04],
                        [  1.45874023e-02,   1.45568848e-02],
                        [  3.29895020e-02,   3.31115723e-02],
                        [  4.76379395e-02,   4.76989746e-02],
                        [  5.90515137e-02,   5.89904785e-02],
                        [  7.05261230e-02,   7.04650879e-02],
                        [  8.19091797e-02,   8.18786621e-02],
                        [  9.10949707e-02,   9.11254883e-02],
                        [  9.49096680e-02,   9.49707031e-02],
                        [  8.91418457e-02,   8.91418457e-02],
                        [  7.40051270e-02,   7.39135742e-02],
                        [  5.55419922e-02,   5.54504395e-02],
                        [  3.81774902e-02,   3.82385254e-02],
                        [  2.12097168e-02,   2.13317871e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -1.77612305e-02,  -1.78833008e-02],
                        [ -3.57971191e-02,  -3.58276367e-02],
                        [ -4.62951660e-02,  -4.61730957e-02],
                        [ -4.71496582e-02,  -4.70581055e-02],
                        [ -3.87878418e-02,  -3.88793945e-02],
                        [ -2.42309570e-02,  -2.42919922e-02],
                        [ -1.11999512e-02,  -1.11694336e-02],
                        [ -5.21850586e-03,  -5.15747070e-03],
                        [ -5.49316406e-04,  -6.10351562e-04],
                        [  1.13525391e-02,   1.13220215e-02],
                        [  2.87170410e-02,   2.87780762e-02],
                        [  4.26635742e-02,   4.26635742e-02],
                        [  4.85534668e-02,   4.84619141e-02],
                        [  4.76989746e-02,   4.77294922e-02],
                        [  4.15954590e-02,   4.16870117e-02],
                        [  3.02429199e-02,   3.02124023e-02],
                        [  1.54724121e-02,   1.53503418e-02],
                        [  9.76562500e-04,   1.00708008e-03],
                        [ -1.01013184e-02,  -1.00097656e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [ -2.02636719e-02,  -2.03857422e-02],
                        [ -2.21252441e-02,  -2.21557617e-02],
                        [ -2.37731934e-02,  -2.36511230e-02],
                        [ -2.57263184e-02,  -2.56347656e-02],
                        [ -2.59704590e-02,  -2.60925293e-02],
                        [ -2.07824707e-02,  -2.09045410e-02],
                        [ -1.14746094e-02,  -1.13525391e-02],
                        [ -5.37109375e-03,  -5.24902344e-03],
                        [ -6.10351562e-03,  -6.22558594e-03],
                        [ -9.73510742e-03,  -9.88769531e-03],
                        [ -1.26953125e-02,  -1.26342773e-02],
                        [ -1.72424316e-02,  -1.70593262e-02],
                        [ -2.63366699e-02,  -2.63671875e-02],
                        [ -3.64379883e-02,  -3.66210938e-02],
                        [ -3.98254395e-02,  -3.98559570e-02],
                        [ -3.46984863e-02,  -3.45458984e-02],
                        [ -2.60620117e-02,  -2.59704590e-02],
                        [ -1.62658691e-02,  -1.63574219e-02],
                        [ -3.72314453e-03,  -3.84521484e-03],
                        [  1.03759766e-02,   1.04064941e-02],
                        [  2.20642090e-02,   2.21557617e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.74658203e-02,   2.74353027e-02],
                        [  1.04370117e-02,   1.03759766e-02],
                        [ -2.81982422e-02,  -2.82592773e-02],
                        [ -8.12072754e-02,  -8.11767578e-02],
                        [ -1.27685547e-01,  -1.27593994e-01],
                        [ -1.47491455e-01,  -1.47430420e-01],
                        [ -1.33422852e-01,  -1.33544922e-01],
                        [ -9.36584473e-02,  -9.37500000e-02],
                        [ -4.69970703e-02,  -4.69055176e-02],
                        [ -1.03149414e-02,  -1.01928711e-02],
                        [  1.42517090e-02,   1.41906738e-02],
                        [  3.78417969e-02,   3.77197266e-02],
                        [  7.22961426e-02,   7.22656250e-02],
                        [  1.19903564e-01,   1.19995117e-01],
                        [  1.69342041e-01,   1.69403076e-01],
                        [  2.01141357e-01,   2.01110840e-01],
                        [  1.98791504e-01,   1.98699951e-01],
                        [  1.52496338e-01,   1.52496338e-01],
                        [  5.83190918e-02,   5.83801270e-02],
                        [ -7.52868652e-02,  -7.52563477e-02],
                        [ -2.20092773e-01,  -2.20153809e-01],
                        [ -3.35540771e-01,  -3.35540771e-01],
                        [ -3.89038086e-01,  -3.89038086e-01],
                        [ -3.73992920e-01,  -3.74023438e-01],
                        [ -3.12347412e-01,  -3.12377930e-01],
                        [ -2.41760254e-01,  -2.41668701e-01],
                        [ -1.91986084e-01,  -1.91894531e-01],
                        [ -1.63421631e-01,  -1.63513184e-01],
                        [ -1.30126953e-01,  -1.30249023e-01],
                        [ -7.07092285e-02,  -7.06787109e-02],
                        [  6.13403320e-03,   6.28662109e-03],
                        [  7.22045898e-02,   7.22351074e-02],
                        [  1.08978271e-01,   1.08825684e-01],
                        [  1.21032715e-01,   1.20971680e-01],
                        [  1.26251221e-01,   1.26373291e-01],
                        [  1.37573242e-01,   1.37634277e-01],
                        [  1.52587891e-01,   1.52526855e-01],
                        [  1.58660889e-01,   1.58599854e-01],
                        [  1.48223877e-01,   1.48193359e-01],
                        [  1.27105713e-01,   1.27075195e-01],
                        [  1.05468750e-01,   1.05529785e-01],
                        [  8.43200684e-02,   8.44116211e-02],
                        [  5.85632324e-02,   5.85021973e-02],
                        [  3.05175781e-02,   3.03649902e-02],
                        [  9.85717773e-03,   9.88769531e-03],
                        [  1.28173828e-03,   1.43432617e-03],
                        [  1.67846680e-03,   1.73950195e-03],
                        [  8.45336914e-03,   8.33129883e-03],
                        [  2.15759277e-02,   2.15148926e-02],
                        [  3.91540527e-02,   3.92456055e-02],
                        [  5.81359863e-02,   5.81970215e-02],
                        [  7.73010254e-02,   7.72399902e-02],
                        [  9.52758789e-02,   9.52453613e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  8.95996094e-02,   8.96301270e-02],
                        [  7.04956055e-02,   7.05261230e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  1.07116699e-02,   1.06506348e-02],
                        [ -1.70288086e-02,  -1.70898438e-02],
                        [ -3.25012207e-02,  -3.24401855e-02],
                        [ -3.96728516e-02,  -3.95812988e-02],
                        [ -4.39453125e-02,  -4.39758301e-02],
                        [ -4.27856445e-02,  -4.29077148e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -1.91040039e-02,  -1.89819336e-02],
                        [ -6.10351562e-03,  -6.04248047e-03],
                        [  4.54711914e-03,   4.48608398e-03],
                        [  1.35498047e-02,   1.34582520e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.32543945e-02,   2.33459473e-02],
                        [  2.50854492e-02,   2.51464844e-02],
                        [  2.88085938e-02,   2.87475586e-02],
                        [  3.47290039e-02,   3.46679688e-02],
                        [  3.97949219e-02,   3.97949219e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.11376953e-02,   4.11682129e-02],
                        [  3.52172852e-02,   3.52478027e-02],
                        [  2.33764648e-02,   2.33154297e-02],
                        [  1.05590820e-02,   1.04675293e-02],
                        [  4.08935547e-03,   4.15039062e-03],
                        [  4.27246094e-03,   4.39453125e-03],
                        [  3.23486328e-03,   3.20434570e-03],
                        [ -5.76782227e-03,  -5.92041016e-03],
                        [ -2.16064453e-02,  -2.16369629e-02],
                        [ -3.81164551e-02,  -3.79638672e-02],
                        [ -4.98657227e-02,  -4.98046875e-02],
                        [ -5.41381836e-02,  -5.42602539e-02],
                        [ -5.04760742e-02,  -5.05371094e-02],
                        [ -4.12292480e-02,  -4.11376953e-02],
                        [ -3.15551758e-02,  -3.14941406e-02],
                        [ -2.57568359e-02,  -2.57873535e-02],
                        [ -2.25524902e-02,  -2.26440430e-02],
                        [ -1.80664062e-02,  -1.80358887e-02],
                        [ -1.30615234e-02,  -1.29394531e-02],
                        [ -1.15966797e-02,  -1.16271973e-02],
                        [ -1.39160156e-02,  -1.40380859e-02],
                        [ -1.66931152e-02,  -1.66625977e-02],
                        [ -1.80053711e-02,  -1.79138184e-02],
                        [ -1.74255371e-02,  -1.74560547e-02],
                        [ -1.42822266e-02,  -1.43737793e-02],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [  5.76782227e-03,   5.82885742e-03],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  1.98364258e-02,   1.97753906e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -3.46679688e-02,  -3.46374512e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -8.90197754e-02,  -8.90502930e-02],
                        [ -8.59069824e-02,  -8.58764648e-02],
                        [ -6.30493164e-02,  -6.29882812e-02],
                        [ -3.50646973e-02,  -3.50952148e-02],
                        [ -1.37023926e-02,  -1.37634277e-02],
                        [  3.05175781e-03,   3.08227539e-03],
                        [  2.39868164e-02,   2.41088867e-02],
                        [  5.37109375e-02,   5.36804199e-02],
                        [  9.04541016e-02,   9.03320312e-02],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.57501221e-01,   1.57592773e-01],
                        [  1.61834717e-01,   1.61865234e-01],
                        [  1.24725342e-01,   1.24694824e-01],
                        [  3.76281738e-02,   3.75976562e-02],
                        [ -8.87145996e-02,  -8.87451172e-02],
                        [ -2.22717285e-01,  -2.22686768e-01],
                        [ -3.24401855e-01,  -3.24340820e-01],
                        [ -3.63800049e-01,  -3.63830566e-01],
                        [ -3.35601807e-01,  -3.35662842e-01],
                        [ -2.64892578e-01,  -2.64892578e-01],
                        [ -1.93847656e-01,  -1.93817139e-01],
                        [ -1.50970459e-01,  -1.50909424e-01],
                        [ -1.30401611e-01,  -1.30401611e-01],
                        [ -1.05133057e-01,  -1.05194092e-01],
                        [ -5.81665039e-02,  -5.81970215e-02],
                        [  1.77001953e-03,   1.80053711e-03],
                        [  5.17272949e-02,   5.17883301e-02],
                        [  7.82775879e-02,   7.82470703e-02],
                        [  8.84399414e-02,   8.83483887e-02],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  1.13586426e-01,   1.13647461e-01],
                        [  1.29638672e-01,   1.29669189e-01],
                        [  1.38916016e-01,   1.38854980e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  9.14611816e-02,   9.14611816e-02],
                        [  7.01293945e-02,   7.01293945e-02],
                        [  4.87365723e-02,   4.87670898e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.50146484e-02,   1.49841309e-02],
                        [  1.75170898e-02,   1.74865723e-02],
                        [  3.46984863e-02,   3.47595215e-02],
                        [  5.45349121e-02,   5.45654297e-02],
                        [  6.91223145e-02,   6.90307617e-02],
                        [  8.10241699e-02,   8.09936523e-02],
                        [  9.13391113e-02,   9.14306641e-02],
                        [  9.41162109e-02,   9.41772461e-02],
                        [  8.66394043e-02,   8.65783691e-02],
                        [  7.35778809e-02,   7.35473633e-02],
                        [  5.83190918e-02,   5.83801270e-02],
                        [  4.07714844e-02,   4.08020020e-02],
                        [  2.36206055e-02,   2.35900879e-02],
                        [  1.02233887e-02,   1.02539062e-02],
                        [ -7.01904297e-04,  -6.71386719e-04],
                        [ -8.75854492e-03,  -8.81958008e-03],
                        [ -8.91113281e-03,  -8.94165039e-03],
                        [ -1.55639648e-03,  -1.46484375e-03],
                        [  5.46264648e-03,   5.49316406e-03],
                        [  8.20922852e-03,   8.14819336e-03],
                        [  9.36889648e-03,   9.30786133e-03],
                        [  1.15661621e-02,   1.15966797e-02],
                        [  1.48315430e-02,   1.48620605e-02],
                        [  1.65100098e-02,   1.65405273e-02],
                        [  1.28784180e-02,   1.28479004e-02],
                        [  4.88281250e-03,   4.82177734e-03],
                        [ -1.03759766e-03,  -1.00708008e-03],
                        [ -9.76562500e-04,  -8.85009766e-04],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  1.17797852e-02,   1.16882324e-02],
                        [  2.15454102e-02,   2.15148926e-02],
                        [  2.65808105e-02,   2.66113281e-02],
                        [  2.15148926e-02,   2.15759277e-02],
                        [  1.12915039e-02,   1.12609863e-02],
                        [  5.31005859e-03,   5.24902344e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.20922852e-03,   8.27026367e-03],
                        [  7.65991211e-03,   7.69042969e-03],
                        [  1.80053711e-03,   1.77001953e-03],
                        [ -9.09423828e-03,  -9.15527344e-03],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.83508301e-02,  -2.82897949e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.02941895e-02,  -2.03552246e-02],
                        [ -1.27868652e-02,  -1.27868652e-02],
                        [ -9.79614258e-03,  -9.76562500e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -8.54492188e-03,  -8.57543945e-03],
                        [ -2.92968750e-03,  -2.92968750e-03],
                        [  1.03759766e-03,   1.06811523e-03],
                        [ -2.56347656e-03,  -2.59399414e-03],
                        [ -1.37634277e-02,  -1.38244629e-02],
                        [ -3.04260254e-02,  -3.03955078e-02],
                        [ -4.93469238e-02,  -4.92858887e-02],
                        [ -6.17675781e-02,  -6.17980957e-02],
                        [ -5.84716797e-02,  -5.85021973e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -1.35498047e-02,  -1.34887695e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.65808105e-02,   2.65502930e-02],
                        [  3.01208496e-02,   3.00903320e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -6.09436035e-02,  -6.09436035e-02],
                        [ -7.24487305e-02,  -7.24792480e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -3.98254395e-02,  -3.97949219e-02],
                        [ -1.59301758e-02,  -1.58996582e-02],
                        [  5.06591797e-03,   5.00488281e-03],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  5.61218262e-02,   5.61523438e-02],
                        [  9.04235840e-02,   9.04541016e-02],
                        [  1.24145508e-01,   1.24114990e-01],
                        [  1.44134521e-01,   1.44104004e-01],
                        [  1.33422852e-01,   1.33453369e-01],
                        [  8.03527832e-02,   8.03833008e-02],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -1.27532959e-01,  -1.27563477e-01],
                        [ -2.40203857e-01,  -2.40173340e-01],
                        [ -3.22875977e-01,  -3.22845459e-01],
                        [ -3.53546143e-01,  -3.53546143e-01],
                        [ -3.30963135e-01,  -3.30963135e-01],
                        [ -2.78137207e-01,  -2.78137207e-01],
                        [ -2.22595215e-01,  -2.22595215e-01],
                        [ -1.76208496e-01,  -1.76208496e-01],
                        [ -1.33148193e-01,  -1.33148193e-01],
                        [ -8.03222656e-02,  -8.03527832e-02],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [  5.85632324e-02,   5.85937500e-02],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.33605957e-01,   1.33544922e-01],
                        [  1.31591797e-01,   1.31591797e-01],
                        [  1.22558594e-01,   1.22619629e-01],
                        [  1.22161865e-01,   1.22131348e-01],
                        [  1.29241943e-01,   1.29211426e-01],
                        [  1.27990723e-01,   1.28021240e-01],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  8.75549316e-02,   8.75549316e-02],
                        [  7.17773438e-02,   7.17773438e-02],
                        [  6.18591309e-02,   6.18286133e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.32238770e-02,   2.32543945e-02],
                        [  3.57666016e-02,   3.57971191e-02],
                        [  5.02014160e-02,   5.01708984e-02],
                        [  6.38732910e-02,   6.38427734e-02],
                        [  7.56225586e-02,   7.56835938e-02],
                        [  8.29772949e-02,   8.30383301e-02],
                        [  8.42285156e-02,   8.41979980e-02],
                        [  7.93762207e-02,   7.93457031e-02],
                        [  6.99462891e-02,   6.99768066e-02],
                        [  5.96008301e-02,   5.96618652e-02],
                        [  5.13916016e-02,   5.13610840e-02],
                        [  4.44030762e-02,   4.43420410e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.03955078e-02,   3.04565430e-02],
                        [  2.65808105e-02,   2.66113281e-02],
                        [  2.42309570e-02,   2.41699219e-02],
                        [  1.80053711e-02,   1.79748535e-02],
                        [  3.90625000e-03,   3.96728516e-03],
                        [ -1.40075684e-02,  -1.39770508e-02],
                        [ -2.58483887e-02,  -2.58789062e-02],
                        [ -2.56958008e-02,  -2.57568359e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -4.66918945e-03,  -4.57763672e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  3.50952148e-03,   3.41796875e-03],
                        [  4.54711914e-03,   4.51660156e-03],
                        [  7.47680664e-03,   7.56835938e-03],
                        [  1.13220215e-02,   1.13525391e-02],
                        [  1.44958496e-02,   1.44042969e-02],
                        [  1.46179199e-02,   1.45874023e-02],
                        [  1.10168457e-02,   1.10473633e-02],
                        [  8.17871094e-03,   8.20922852e-03],
                        [  9.09423828e-03,   9.06372070e-03],
                        [  9.55200195e-03,   9.52148438e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.82287598e-02,   2.82287598e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  7.90405273e-03,   7.90405273e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -1.22070312e-02,  -1.21765137e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.36303711e-02,  -3.36608887e-02],
                        [ -4.26940918e-02,  -4.27246094e-02],
                        [ -4.91027832e-02,  -4.90722656e-02],
                        [ -5.40466309e-02,  -5.40161133e-02],
                        [ -5.49926758e-02,  -5.50231934e-02],
                        [ -4.98352051e-02,  -4.98962402e-02],
                        [ -4.33654785e-02,  -4.33349609e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -1.94091797e-02,  -1.94702148e-02],
                        [ -2.86865234e-03,  -2.89916992e-03],
                        [  1.75170898e-02,   1.75781250e-02],
                        [  3.28674316e-02,   3.28979492e-02],
                        [  3.77197266e-02,   3.76586914e-02],
                        [  2.90222168e-02,   2.89916992e-02],
                        [  3.57055664e-03,   3.60107422e-03],
                        [ -3.42102051e-02,  -3.41796875e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -8.52050781e-02,  -8.52050781e-02],
                        [ -7.89489746e-02,  -7.89794922e-02],
                        [ -5.69763184e-02,  -5.69458008e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  9.83581543e-02,   9.83276367e-02],
                        [  1.37786865e-01,   1.37817383e-01],
                        [  1.58752441e-01,   1.58782959e-01],
                        [  1.45935059e-01,   1.45904541e-01],
                        [  9.14306641e-02,   9.13696289e-02],
                        [ -6.89697266e-03,  -6.86645508e-03],
                        [ -1.39221191e-01,  -1.39190674e-01],
                        [ -2.73559570e-01,  -2.73590088e-01],
                        [ -3.66729736e-01,  -3.66729736e-01],
                        [ -3.92517090e-01,  -3.92517090e-01],
                        [ -3.55926514e-01,  -3.55926514e-01],
                        [ -2.85858154e-01,  -2.85858154e-01],
                        [ -2.16491699e-01,  -2.16461182e-01],
                        [ -1.63970947e-01,  -1.63940430e-01],
                        [ -1.17126465e-01,  -1.17156982e-01],
                        [ -5.62133789e-02,  -5.62438965e-02],
                        [  1.96533203e-02,   1.96838379e-02],
                        [  8.86230469e-02,   8.86535645e-02],
                        [  1.28540039e-01,   1.28540039e-01],
                        [  1.36993408e-01,   1.36993408e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.24359131e-01,   1.24359131e-01],
                        [  1.23809814e-01,   1.23840332e-01],
                        [  1.15600586e-01,   1.15570068e-01],
                        [  1.02172852e-01,   1.02111816e-01],
                        [  8.57849121e-02,   8.58154297e-02],
                        [  6.38732910e-02,   6.39038086e-02],
                        [  3.80554199e-02,   3.80249023e-02],
                        [  1.61132812e-02,   1.60827637e-02],
                        [  2.68554688e-03,   2.74658203e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  5.37109375e-03,   5.31005859e-03],
                        [  2.32849121e-02,   2.33154297e-02],
                        [  4.46166992e-02,   4.46472168e-02],
                        [  6.28356934e-02,   6.28051758e-02],
                        [  7.91625977e-02,   7.91320801e-02],
                        [  9.53063965e-02,   9.53369141e-02],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  1.11938477e-01,   1.11938477e-01],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  8.76770020e-02,   8.76770020e-02],
                        [  6.32019043e-02,   6.32019043e-02],
                        [  3.88488770e-02,   3.88793945e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  5.21850586e-03,   5.21850586e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.22070312e-04,  -9.15527344e-05],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -3.47900391e-03,  -3.50952148e-03],
                        [  0.00000000e+00,  -3.05175781e-05],
                        [  1.02539062e-02,   1.02844238e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  2.32543945e-02,   2.32543945e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  1.04980469e-02,   1.04675293e-02],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -1.13830566e-02,  -1.13525391e-02],
                        [ -1.91040039e-02,  -1.91345215e-02],
                        [ -1.57470703e-02,  -1.57775879e-02],
                        [ -2.62451172e-03,  -2.59399414e-03],
                        [  1.26037598e-02,   1.26342773e-02],
                        [  2.49023438e-02,   2.48718262e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -2.15759277e-02,  -2.16064453e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -1.94396973e-02,  -1.94702148e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -2.14843750e-02,  -2.14538574e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.99890137e-02,  -1.99890137e-02],
                        [ -2.07824707e-02,  -2.07824707e-02],
                        [ -2.56347656e-02,  -2.56042480e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -4.21447754e-02,  -4.22058105e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -2.45361328e-02,  -2.45056152e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  3.60107422e-03,   3.57055664e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.77612305e-02,   1.77612305e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  7.93457031e-03,   7.93457031e-03],
                        [ -1.32141113e-02,  -1.32141113e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -9.04235840e-02,  -9.03930664e-02],
                        [ -7.87658691e-02,  -7.87658691e-02],
                        [ -4.56542969e-02,  -4.56848145e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  1.21704102e-01,   1.21673584e-01],
                        [  1.44775391e-01,   1.44744873e-01],
                        [  1.45538330e-01,   1.45568848e-01],
                        [  1.09924316e-01,   1.09954834e-01],
                        [  2.81372070e-02,   2.81372070e-02],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -2.24121094e-01,  -2.24121094e-01],
                        [ -3.24981689e-01,  -3.24981689e-01],
                        [ -3.63220215e-01,  -3.63250732e-01],
                        [ -3.34777832e-01,  -3.34747314e-01],
                        [ -2.67150879e-01,  -2.67150879e-01],
                        [ -2.00347900e-01,  -2.00378418e-01],
                        [ -1.56768799e-01,  -1.56768799e-01],
                        [ -1.26495361e-01,  -1.26464844e-01],
                        [ -8.37402344e-02,  -8.37402344e-02],
                        [ -1.94396973e-02,  -1.94702148e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  8.36181641e-02,   8.36486816e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  7.97119141e-02,   7.97424316e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  9.20410156e-02,   9.20410156e-02],
                        [  1.10351562e-01,   1.10351562e-01],
                        [  1.18103027e-01,   1.18133545e-01],
                        [  1.11450195e-01,   1.11419678e-01],
                        [  9.88464355e-02,   9.88159180e-02],
                        [  8.82873535e-02,   8.83178711e-02],
                        [  7.92236328e-02,   7.92236328e-02],
                        [  6.64672852e-02,   6.64367676e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  2.48107910e-02,   2.48413086e-02],
                        [  9.00268555e-03,   8.97216797e-03],
                        [  5.79833984e-03,   5.76782227e-03],
                        [  1.58081055e-02,   1.58386230e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  6.45141602e-02,   6.45141602e-02],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  9.58251953e-02,   9.58251953e-02],
                        [  9.73815918e-02,   9.73510742e-02],
                        [  9.71069336e-02,   9.71374512e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  8.75549316e-02,   8.75244141e-02],
                        [  7.47375488e-02,   7.47375488e-02],
                        [  5.57250977e-02,   5.57556152e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  8.27026367e-03,   8.23974609e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.41296387e-02,  -1.40991211e-02],
                        [ -1.12609863e-02,  -1.12915039e-02],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -3.78417969e-03,  -3.75366211e-03],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -1.49230957e-02,  -1.49536133e-02],
                        [ -1.84936523e-02,  -1.84631348e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -1.77001953e-02,  -1.77307129e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  5.20935059e-02,   5.20935059e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  4.92553711e-02,   4.92248535e-02],
                        [  3.60412598e-02,   3.60717773e-02],
                        [  2.52380371e-02,   2.52380371e-02],
                        [  1.80664062e-02,   1.80358887e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -1.49230957e-02,  -1.48925781e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -3.01513672e-02,  -3.01818848e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.19006348e-02,  -4.18701172e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -1.40380859e-03,  -1.37329102e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -9.61303711e-03,  -9.61303711e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -2.72827148e-02,  -2.73132324e-02],
                        [ -3.33862305e-02,  -3.33862305e-02],
                        [ -4.26940918e-02,  -4.26635742e-02],
                        [ -5.38635254e-02,  -5.38940430e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -3.14331055e-03,  -3.17382812e-03],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.61834717e-01,   1.61804199e-01],
                        [  1.82739258e-01,   1.82769775e-01],
                        [  1.65496826e-01,   1.65496826e-01],
                        [  9.67712402e-02,   9.67407227e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.70196533e-01,  -1.70196533e-01],
                        [ -2.99774170e-01,  -2.99804688e-01],
                        [ -3.66546631e-01,  -3.66546631e-01],
                        [ -3.58642578e-01,  -3.58642578e-01],
                        [ -3.01300049e-01,  -3.01330566e-01],
                        [ -2.33703613e-01,  -2.33703613e-01],
                        [ -1.83746338e-01,  -1.83746338e-01],
                        [ -1.52557373e-01,  -1.52557373e-01],
                        [ -1.18164062e-01,  -1.18164062e-01],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  5.59387207e-02,   5.59082031e-02],
                        [  7.58361816e-02,   7.58666992e-02],
                        [  7.23266602e-02,   7.23266602e-02],
                        [  6.86035156e-02,   6.85729980e-02],
                        [  8.01696777e-02,   8.01696777e-02],
                        [  1.03149414e-01,   1.03179932e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.29394531e-01,   1.29364014e-01],
                        [  1.24542236e-01,   1.24542236e-01],
                        [  1.15264893e-01,   1.15264893e-01],
                        [  1.02752686e-01,   1.02752686e-01],
                        [  8.25195312e-02,   8.24890137e-02],
                        [  5.39855957e-02,   5.39855957e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  5.31005859e-03,   5.27954102e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  1.87377930e-02,   1.87377930e-02],
                        [  4.16870117e-02,   4.16564941e-02],
                        [  6.37512207e-02,   6.37207031e-02],
                        [  8.16345215e-02,   8.16650391e-02],
                        [  9.69543457e-02,   9.69543457e-02],
                        [  1.09802246e-01,   1.09771729e-01],
                        [  1.14562988e-01,   1.14593506e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.02099609e-02,   9.01794434e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  4.22058105e-02,   4.22363281e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -1.67846680e-02,  -1.68151855e-02],
                        [ -7.69042969e-03,  -7.69042969e-03],
                        [  5.49316406e-04,   5.79833984e-04],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  7.90405273e-03,   7.87353516e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -3.93676758e-03,  -3.96728516e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  7.32421875e-04,   7.01904297e-04],
                        [  5.92041016e-03,   5.88989258e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.61425781e-02,   4.61120605e-02],
                        [  3.73535156e-02,   3.73229980e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [ -2.08129883e-02,  -2.08435059e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -8.18481445e-02,  -8.18481445e-02],
                        [ -8.46557617e-02,  -8.46557617e-02],
                        [ -7.81555176e-02,  -7.81555176e-02],
                        [ -6.19506836e-02,  -6.19812012e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -9.52148438e-03,  -9.55200195e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.87683105e-02,   1.87683105e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  7.38525391e-03,   7.38525391e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -7.12280273e-02,  -7.12280273e-02],
                        [ -8.89892578e-02,  -8.89892578e-02],
                        [ -9.06066895e-02,  -9.05761719e-02],
                        [ -6.82067871e-02,  -6.82067871e-02],
                        [ -2.37121582e-02,  -2.37426758e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.67694092e-01,   1.67694092e-01],
                        [  1.85424805e-01,   1.85424805e-01],
                        [  1.79016113e-01,   1.79016113e-01],
                        [  1.35742188e-01,   1.35742188e-01],
                        [  4.34875488e-02,   4.35180664e-02],
                        [ -9.48486328e-02,  -9.48486328e-02],
                        [ -2.51007080e-01,  -2.51007080e-01],
                        [ -3.79394531e-01,  -3.79364014e-01],
                        [ -4.40643311e-01,  -4.40643311e-01],
                        [ -4.24468994e-01,  -4.24468994e-01],
                        [ -3.55316162e-01,  -3.55316162e-01],
                        [ -2.73803711e-01,  -2.73834229e-01],
                        [ -2.06756592e-01,  -2.06756592e-01],
                        [ -1.50634766e-01,  -1.50634766e-01],
                        [ -8.39233398e-02,  -8.39233398e-02],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  9.21630859e-02,   9.21936035e-02],
                        [  1.52282715e-01,   1.52282715e-01],
                        [  1.69158936e-01,   1.69158936e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.34338379e-01,   1.34338379e-01],
                        [  1.22009277e-01,   1.22009277e-01],
                        [  1.16455078e-01,   1.16485596e-01],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  9.17053223e-02,   9.16748047e-02],
                        [  7.64465332e-02,   7.64465332e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  6.45141602e-02,   6.44836426e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  1.78527832e-02,   1.78833008e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  6.05468750e-02,   6.05468750e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  1.11114502e-01,   1.11114502e-01],
                        [  1.26007080e-01,   1.26007080e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  1.17645264e-01,   1.17645264e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.89404297e-02,  -3.89404297e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  4.60815430e-03,   4.57763672e-03],
                        [  1.06811523e-02,   1.06811523e-02],
                        [  1.77917480e-02,   1.77917480e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  1.37329102e-03,   1.34277344e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [  8.69750977e-03,   8.69750977e-03],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  3.93371582e-02,   3.93066406e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  8.54492188e-04,   8.54492188e-04],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.83813477e-02,  -2.83508301e-02],
                        [ -3.61633301e-02,  -3.61938477e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.26940918e-02,  -4.26635742e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -3.18603516e-02,  -3.18298340e-02],
                        [ -3.65905762e-02,  -3.66210938e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -5.50231934e-02,  -5.49926758e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -2.83508301e-02,  -2.83508301e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  9.52148438e-03,   9.55200195e-03],
                        [  2.13317871e-02,   2.13012695e-02],
                        [  2.91137695e-02,   2.91137695e-02],
                        [  3.03344727e-02,   3.03649902e-02],
                        [  2.48718262e-02,   2.48718262e-02],
                        [  1.37634277e-02,   1.37634277e-02],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -7.73925781e-02,  -7.73620605e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -5.34057617e-02,  -5.34362793e-02],
                        [ -1.00402832e-02,  -1.00097656e-02],
                        [  4.28771973e-02,   4.29077148e-02],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  1.72393799e-01,   1.72424316e-01],
                        [  1.80694580e-01,   1.80694580e-01],
                        [  1.51367188e-01,   1.51336670e-01],
                        [  6.77490234e-02,   6.77795410e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -2.25036621e-01,  -2.25036621e-01],
                        [ -3.52203369e-01,  -3.52203369e-01],
                        [ -4.12750244e-01,  -4.12750244e-01],
                        [ -3.99749756e-01,  -3.99749756e-01],
                        [ -3.36303711e-01,  -3.36303711e-01],
                        [ -2.60070801e-01,  -2.60070801e-01],
                        [ -1.97998047e-01,  -1.97967529e-01],
                        [ -1.47369385e-01,  -1.47369385e-01],
                        [ -8.68530273e-02,  -8.68530273e-02],
                        [ -1.00708008e-02,  -1.00402832e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  1.00036621e-01,   1.00006104e-01],
                        [  1.05895996e-01,   1.05895996e-01],
                        [  9.99145508e-02,   9.99450684e-02],
                        [  1.01928711e-01,   1.01928711e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  1.19995117e-01,   1.19995117e-01],
                        [  1.09527588e-01,   1.09527588e-01],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  7.82775879e-02,   7.82775879e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  2.84423828e-02,   2.84423828e-02],
                        [  5.33752441e-02,   5.33752441e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  1.16638184e-01,   1.16668701e-01],
                        [  1.15325928e-01,   1.15295410e-01],
                        [  1.04492188e-01,   1.04492188e-01],
                        [  7.75756836e-02,   7.76062012e-02],
                        [  3.67126465e-02,   3.66821289e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [ -3.00292969e-02,  -2.99987793e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.52380371e-02,  -2.52075195e-02],
                        [ -1.89819336e-02,  -1.89819336e-02],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  5.42297363e-02,   5.41992188e-02],
                        [  7.04040527e-02,   7.04345703e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  1.95312500e-02,   1.95312500e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -7.50732422e-03,  -7.50732422e-03],
                        [  2.44140625e-04,   2.44140625e-04],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.87976074e-02,  -4.88281250e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -3.22570801e-02,  -3.22265625e-02],
                        [ -2.77709961e-02,  -2.77709961e-02],
                        [ -2.35595703e-02,  -2.35595703e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -1.40991211e-02,  -1.40991211e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -7.84301758e-03,  -7.87353516e-03],
                        [  7.41577148e-03,   7.41577148e-03],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  1.12121582e-01,   1.12121582e-01],
                        [  1.22589111e-01,   1.22589111e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  7.45544434e-02,   7.45544434e-02],
                        [ -1.86157227e-03,  -1.86157227e-03],
                        [ -1.16821289e-01,  -1.16821289e-01],
                        [ -2.45544434e-01,  -2.45544434e-01],
                        [ -3.46252441e-01,  -3.46252441e-01],
                        [ -3.85498047e-01,  -3.85498047e-01],
                        [ -3.59893799e-01,  -3.59893799e-01],
                        [ -2.95501709e-01,  -2.95501709e-01],
                        [ -2.26867676e-01,  -2.26867676e-01],
                        [ -1.70593262e-01,  -1.70593262e-01],
                        [ -1.18804932e-01,  -1.18804932e-01],
                        [ -5.81054688e-02,  -5.81054688e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  8.41674805e-02,   8.41674805e-02],
                        [  8.08105469e-02,   8.08105469e-02],
                        [  7.21130371e-02,   7.21130371e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  1.01226807e-01,   1.01226807e-01],
                        [  1.08093262e-01,   1.08093262e-01],
                        [  1.06384277e-01,   1.06384277e-01],
                        [  9.80834961e-02,   9.80834961e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  5.38024902e-02,   5.38024902e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  5.87158203e-02,   5.86853027e-02],
                        [  7.75756836e-02,   7.76062012e-02],
                        [  8.86840820e-02,   8.86840820e-02],
                        [  9.04846191e-02,   9.04846191e-02],
                        [  8.47167969e-02,   8.47167969e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  3.49121094e-02,   3.49121094e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  3.11279297e-02,   3.10974121e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  1.95617676e-02,   1.95617676e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.25415039e-02,  -4.25415039e-02],
                        [ -4.39147949e-02,  -4.39453125e-02],
                        [ -3.65905762e-02,  -3.66210938e-02],
                        [ -2.15148926e-02,  -2.14843750e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [  1.39160156e-02,   1.39160156e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  4.52575684e-02,   4.52575684e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  2.76489258e-02,   2.76489258e-02],
                        [  2.48107910e-02,   2.48107910e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  4.50439453e-02,   4.50744629e-02],
                        [  5.35583496e-02,   5.35888672e-02],
                        [  4.94384766e-02,   4.94079590e-02],
                        [  3.36608887e-02,   3.36303711e-02],
                        [  1.26953125e-02,   1.27258301e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -7.87963867e-02,  -7.87963867e-02],
                        [ -9.45129395e-02,  -9.45129395e-02],
                        [ -1.00494385e-01,  -1.00494385e-01],
                        [ -9.50012207e-02,  -9.50012207e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -6.28967285e-02,  -6.29272461e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -2.46887207e-02,  -2.47192383e-02],
                        [ -1.80969238e-02,  -1.81274414e-02],
                        [ -7.50732422e-03,  -7.47680664e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.78210449e-02,   4.78210449e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.52368164e-02,   5.52368164e-02],
                        [  3.91235352e-02,   3.91235352e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -6.36596680e-02,  -6.36596680e-02],
                        [ -8.02917480e-02,  -8.02917480e-02],
                        [ -7.12890625e-02,  -7.12890625e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  7.00073242e-02,   7.00073242e-02],
                        [  1.18041992e-01,   1.18041992e-01],
                        [  1.40777588e-01,   1.40777588e-01],
                        [  1.31622314e-01,   1.31622314e-01],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [ -1.04553223e-01,  -1.04583740e-01],
                        [ -2.26684570e-01,  -2.26684570e-01],
                        [ -3.17230225e-01,  -3.17230225e-01],
                        [ -3.44390869e-01,  -3.44390869e-01],
                        [ -3.09478760e-01,  -3.09478760e-01],
                        [ -2.44689941e-01,  -2.44689941e-01],
                        [ -1.87164307e-01,  -1.87164307e-01],
                        [ -1.52435303e-01,  -1.52465820e-01],
                        [ -1.28295898e-01,  -1.28295898e-01],
                        [ -9.42077637e-02,  -9.42077637e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.72521973e-02,   2.72216797e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  8.57849121e-02,   8.57849121e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.28692627e-01,   1.28692627e-01],
                        [  1.25427246e-01,   1.25427246e-01],
                        [  1.14074707e-01,   1.14074707e-01],
                        [  1.02661133e-01,   1.02661133e-01],
                        [  9.25292969e-02,   9.25292969e-02],
                        [  8.12377930e-02,   8.12377930e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  5.91735840e-02,   5.91735840e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  5.45043945e-02,   5.45043945e-02],
                        [  5.57861328e-02,   5.57556152e-02],
                        [  5.61218262e-02,   5.60913086e-02],
                        [  5.56945801e-02,   5.56945801e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  5.65490723e-02,   5.65185547e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  6.13098145e-02,   6.13403320e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  7.03430176e-02,   7.03125000e-02],
                        [  7.23876953e-02,   7.24182129e-02],
                        [  6.61926270e-02,   6.61926270e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  4.48608398e-03,   4.48608398e-03],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.19628906e-02,  -1.19628906e-02],
                        [ -1.73950195e-03,  -1.70898438e-03],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.58691406e-02,   1.58386230e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  2.57568359e-02,   2.57263184e-02],
                        [  2.76184082e-02,   2.76184082e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.40173340e-02,   2.39868164e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.89001465e-02,   2.88696289e-02],
                        [  2.96630859e-02,   2.96325684e-02],
                        [  2.46582031e-02,   2.46887207e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [ -2.01416016e-03,  -1.98364258e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -8.39233398e-03,  -8.42285156e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -6.04248047e-03,  -6.07299805e-03],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -9.55200195e-03,  -9.52148438e-03],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.65197754e-02,  -2.65197754e-02],
                        [ -3.65295410e-02,  -3.65295410e-02],
                        [ -4.66003418e-02,  -4.66308594e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -6.03027344e-02,  -6.03027344e-02],
                        [ -6.10046387e-02,  -6.09741211e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -5.36193848e-02,  -5.36193848e-02],
                        [ -3.83300781e-02,  -3.83300781e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.05480957e-02,   3.05480957e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -5.63964844e-02,  -5.64270020e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -4.91027832e-02,  -4.90722656e-02],
                        [ -2.98156738e-02,  -2.98461914e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [  1.85241699e-02,   1.85241699e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  7.13806152e-02,   7.13806152e-02],
                        [  9.70153809e-02,   9.70153809e-02],
                        [  1.18865967e-01,   1.18896484e-01],
                        [  1.32843018e-01,   1.32843018e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.25762939e-01,   1.25793457e-01],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  3.32031250e-02,   3.31726074e-02],
                        [ -6.00585938e-02,  -6.00585938e-02],
                        [ -1.73492432e-01,  -1.73492432e-01],
                        [ -2.75604248e-01,  -2.75604248e-01],
                        [ -3.30718994e-01,  -3.30688477e-01],
                        [ -3.23852539e-01,  -3.23822021e-01],
                        [ -2.71484375e-01,  -2.71514893e-01],
                        [ -2.08892822e-01,  -2.08892822e-01],
                        [ -1.61071777e-01,  -1.61071777e-01],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -8.39233398e-02,  -8.39538574e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  6.51855469e-02,   6.51550293e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  6.40258789e-02,   6.40563965e-02],
                        [  5.77697754e-02,   5.77697754e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  6.18286133e-02,   6.18591309e-02],
                        [  6.22558594e-02,   6.22558594e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  8.18786621e-02,   8.18786621e-02],
                        [  8.62121582e-02,   8.62121582e-02],
                        [  8.30688477e-02,   8.30383301e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  6.26525879e-02,   6.26525879e-02],
                        [  5.43212891e-02,   5.43212891e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -2.59399414e-03,  -2.62451172e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  5.92041016e-03,   5.95092773e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.23901367e-02,   1.24206543e-02],
                        [  2.05078125e-02,   2.05078125e-02],
                        [  2.75573730e-02,   2.75268555e-02],
                        [  3.31420898e-02,   3.31726074e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.75061035e-02,   3.74755859e-02],
                        [  3.37219238e-02,   3.37219238e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.21862793e-02,   2.21557617e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  1.77001953e-03,   1.77001953e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -9.91821289e-03,  -9.91821289e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -7.59887695e-03,  -7.59887695e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  4.76074219e-03,   4.76074219e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.28173828e-02,  -1.27868652e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.40173340e-02,  -2.40173340e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.82690430e-02,  -3.82995605e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -8.81347656e-02,  -8.81347656e-02],
                        [ -9.32617188e-02,  -9.32617188e-02],
                        [ -8.88061523e-02,  -8.88061523e-02],
                        [ -7.76062012e-02,  -7.76367188e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  2.85949707e-02,   2.85949707e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  4.00390625e-02,   4.00390625e-02],
                        [  4.57763672e-02,   4.57763672e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.99780273e-02,   3.99780273e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  2.36206055e-02,   2.35900879e-02],
                        [  2.70996094e-02,   2.71301270e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  6.87561035e-02,   6.87561035e-02],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.41204834e-01,   1.41204834e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  9.70764160e-02,   9.70764160e-02],
                        [  2.22167969e-02,   2.22167969e-02],
                        [ -8.16345215e-02,  -8.16345215e-02],
                        [ -1.91131592e-01,  -1.91162109e-01],
                        [ -2.78869629e-01,  -2.78869629e-01],
                        [ -3.22662354e-01,  -3.22662354e-01],
                        [ -3.15124512e-01,  -3.15124512e-01],
                        [ -2.71392822e-01,  -2.71392822e-01],
                        [ -2.18963623e-01,  -2.18963623e-01],
                        [ -1.74652100e-01,  -1.74652100e-01],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -8.97521973e-02,  -8.97521973e-02],
                        [ -3.73229980e-02,  -3.73229980e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  6.76879883e-02,   6.76879883e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  9.73510742e-02,   9.73510742e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.75659180e-02,   6.75659180e-02],
                        [  5.93261719e-02,   5.93566895e-02],
                        [  5.12390137e-02,   5.12390137e-02],
                        [  4.10156250e-02,   4.09851074e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.12915039e-03,   1.12915039e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  7.11059570e-02,   7.11364746e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  5.61523438e-02,   5.61523438e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -4.69970703e-03,  -4.69970703e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -6.34765625e-03,  -6.37817383e-03],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  4.63867188e-02,   4.63867188e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.23693848e-02,   2.23999023e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -2.40478516e-02,  -2.40478516e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.21948242e-02,  -6.21948242e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -4.92858887e-02,  -4.92858887e-02],
                        [ -3.67431641e-02,  -3.67126465e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  2.08435059e-02,   2.08435059e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.29089355e-02,  -1.29394531e-02],
                        [ -3.02429199e-02,  -3.02124023e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -6.57348633e-02,  -6.57653809e-02],
                        [ -7.88269043e-02,  -7.88269043e-02],
                        [ -8.34960938e-02,  -8.34960938e-02],
                        [ -7.45849609e-02,  -7.45849609e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  2.42309570e-02,   2.42309570e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  5.12695312e-02,   5.12695312e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  6.33850098e-02,   6.33850098e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.13281250e-01,   1.13281250e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.51153564e-01,   1.51153564e-01],
                        [  1.46545410e-01,   1.46545410e-01],
                        [  1.16210938e-01,   1.16241455e-01],
                        [  5.13916016e-02,   5.13916016e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -1.67999268e-01,  -1.67999268e-01],
                        [ -2.76794434e-01,  -2.76794434e-01],
                        [ -3.45672607e-01,  -3.45672607e-01],
                        [ -3.58978271e-01,  -3.58978271e-01],
                        [ -3.23822021e-01,  -3.23822021e-01],
                        [ -2.66479492e-01,  -2.66479492e-01],
                        [ -2.12432861e-01,  -2.12432861e-01],
                        [ -1.67480469e-01,  -1.67480469e-01],
                        [ -1.19110107e-01,  -1.19110107e-01],
                        [ -5.72509766e-02,  -5.72509766e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  8.16955566e-02,   8.16955566e-02],
                        [  8.07189941e-02,   8.07495117e-02],
                        [  7.28149414e-02,   7.28149414e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  6.58264160e-02,   6.57958984e-02],
                        [  5.03234863e-02,   5.03234863e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  4.20532227e-02,   4.20532227e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.17578125e-02,   5.17578125e-02],
                        [  5.93261719e-02,   5.93261719e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  6.09741211e-02,   6.09741211e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  9.97924805e-03,   1.00097656e-02],
                        [ -2.83813477e-03,  -2.83813477e-03],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.49938965e-02,   2.49938965e-02],
                        [  2.26440430e-02,   2.26440430e-02],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.48925781e-02,  -1.48620605e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  1.83105469e-04,   1.83105469e-04],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -5.38024902e-02,  -5.38024902e-02],
                        [ -4.71801758e-02,  -4.71801758e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -9.73510742e-03,  -9.73510742e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.77001953e-03,   1.77001953e-03],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -4.57763672e-03,  -4.57763672e-03],
                        [ -1.22070312e-03,  -1.22070312e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  8.08715820e-03,   8.08715820e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  3.10363770e-02,   3.10363770e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  1.11755371e-01,   1.11755371e-01],
                        [  1.20788574e-01,   1.20788574e-01],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  9.34448242e-02,   9.34448242e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [ -4.41589355e-02,  -4.41589355e-02],
                        [ -1.52313232e-01,  -1.52313232e-01],
                        [ -2.56591797e-01,  -2.56591797e-01],
                        [ -3.24005127e-01,  -3.24005127e-01],
                        [ -3.37005615e-01,  -3.37005615e-01],
                        [ -3.04473877e-01,  -3.04443359e-01],
                        [ -2.51342773e-01,  -2.51342773e-01],
                        [ -2.00286865e-01,  -2.00286865e-01],
                        [ -1.58447266e-01,  -1.58447266e-01],
                        [ -1.17858887e-01,  -1.17858887e-01],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  8.62426758e-02,   8.62426758e-02],
                        [  1.06445312e-01,   1.06445312e-01],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.25122070e-01,   1.25122070e-01],
                        [  1.27990723e-01,   1.27990723e-01],
                        [  1.18896484e-01,   1.18896484e-01],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  7.75146484e-02,   7.75146484e-02],
                        [  5.93566895e-02,   5.93566895e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  2.13623047e-04,   2.13623047e-04],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.38549805e-02,   1.38549805e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  6.57958984e-02,   6.57958984e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  7.84301758e-03,   7.84301758e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  2.43835449e-02,   2.43835449e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.84936523e-02,  -1.84936523e-02],
                        [ -1.59606934e-02,  -1.59606934e-02],
                        [ -1.33972168e-02,  -1.33972168e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.09753418e-02,  -3.09753418e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -2.02636719e-02,  -2.02636719e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  1.83410645e-02,   1.83410645e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  6.94885254e-02,   6.94885254e-02],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  8.64562988e-02,   8.64562988e-02],
                        [  9.86328125e-02,   9.86328125e-02],
                        [  1.09863281e-01,   1.09863281e-01],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  7.57751465e-02,   7.57751465e-02],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -1.08917236e-01,  -1.08917236e-01],
                        [ -2.24731445e-01,  -2.24731445e-01],
                        [ -3.13140869e-01,  -3.13140869e-01],
                        [ -3.49243164e-01,  -3.49243164e-01],
                        [ -3.30657959e-01,  -3.30657959e-01],
                        [ -2.80426025e-01,  -2.80426025e-01],
                        [ -2.28210449e-01,  -2.28210449e-01],
                        [ -1.86645508e-01,  -1.86645508e-01],
                        [ -1.47247314e-01,  -1.47247314e-01],
                        [ -9.71984863e-02,  -9.71984863e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  6.75964355e-02,   6.75964355e-02],
                        [  8.84704590e-02,   8.84704590e-02],
                        [  9.07287598e-02,   9.07287598e-02],
                        [  8.63952637e-02,   8.63952637e-02],
                        [  8.56018066e-02,   8.56018066e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  8.95996094e-02,   8.95996094e-02],
                        [  8.29772949e-02,   8.29772949e-02],
                        [  7.15637207e-02,   7.15637207e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  5.52062988e-02,   5.52062988e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  3.64074707e-02,   3.64074707e-02],
                        [  1.85241699e-02,   1.85241699e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  7.16552734e-02,   7.16552734e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  3.33251953e-02,   3.33251953e-02],
                        [  1.68762207e-02,   1.68762207e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -8.97216797e-03,  -8.97216797e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  4.60205078e-02,   4.60205078e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.61743164e-03,  -1.58691406e-03],
                        [  5.00488281e-03,   5.03540039e-03],
                        [  1.21765137e-02,   1.22070312e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  1.40380859e-03,   1.43432617e-03],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -1.38854980e-02,  -1.39160156e-02],
                        [ -1.37329102e-02,  -1.37634277e-02],
                        [ -1.50146484e-02,  -1.50451660e-02],
                        [ -1.61743164e-02,  -1.62048340e-02],
                        [ -1.61132812e-02,  -1.61437988e-02],
                        [ -1.51977539e-02,  -1.52282715e-02],
                        [ -1.77612305e-02,  -1.77612305e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -4.35791016e-02,  -4.35791016e-02],
                        [ -5.50537109e-02,  -5.50231934e-02],
                        [ -5.46875000e-02,  -5.46569824e-02],
                        [ -4.42810059e-02,  -4.42504883e-02],
                        [ -3.26843262e-02,  -3.26538086e-02],
                        [ -2.54211426e-02,  -2.53906250e-02],
                        [ -2.18505859e-02,  -2.18200684e-02],
                        [ -1.94091797e-02,  -1.93786621e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [ -2.41088867e-03,  -2.44140625e-03],
                        [ -7.50732422e-03,  -7.53784180e-03],
                        [ -1.35498047e-02,  -1.35803223e-02],
                        [ -1.81884766e-02,  -1.82189941e-02],
                        [ -2.15148926e-02,  -2.15454102e-02],
                        [ -2.35290527e-02,  -2.35595703e-02],
                        [ -2.32238770e-02,  -2.32543945e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  4.09240723e-02,   4.08935547e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  8.02307129e-02,   8.02001953e-02],
                        [  9.26818848e-02,   9.26818848e-02],
                        [  1.00708008e-01,   1.00708008e-01],
                        [  1.07788086e-01,   1.07818604e-01],
                        [  1.16485596e-01,   1.16516113e-01],
                        [  1.25061035e-01,   1.25091553e-01],
                        [  1.29455566e-01,   1.29516602e-01],
                        [  1.25518799e-01,   1.25610352e-01],
                        [  1.07910156e-01,   1.08001709e-01],
                        [  6.73217773e-02,   6.74133301e-02],
                        [ -5.27954102e-03,  -5.18798828e-03],
                        [ -1.06628418e-01,  -1.06567383e-01],
                        [ -2.16003418e-01,  -2.15972900e-01],
                        [ -3.02795410e-01,  -3.02825928e-01],
                        [ -3.43048096e-01,  -3.43109131e-01],
                        [ -3.33251953e-01,  -3.33343506e-01],
                        [ -2.89886475e-01,  -2.90069580e-01],
                        [ -2.36968994e-01,  -2.37182617e-01],
                        [ -1.91650391e-01,  -1.91864014e-01],
                        [ -1.54479980e-01,  -1.54693604e-01],
                        [ -1.13861084e-01,  -1.14044189e-01],
                        [ -6.12487793e-02,  -6.13708496e-02],
                        [ -8.85009766e-04,  -9.46044922e-04],
                        [  5.17883301e-02,   5.18188477e-02],
                        [  8.27941895e-02,   8.28857422e-02],
                        [  9.17968750e-02,   9.19799805e-02],
                        [  9.08508301e-02,   9.10949707e-02],
                        [  9.31701660e-02,   9.34753418e-02],
                        [  1.03027344e-01,   1.03332520e-01],
                        [  1.13281250e-01,   1.13616943e-01],
                        [  1.13433838e-01,   1.13708496e-01],
                        [  1.00311279e-01,   1.00524902e-01],
                        [  8.02917480e-02,   8.04138184e-02],
                        [  6.25000000e-02,   6.25000000e-02],
                        [  5.06896973e-02,   5.05676270e-02],
                        [  4.10766602e-02,   4.08630371e-02],
                        [  2.82897949e-02,   2.79846191e-02],
                        [  1.37634277e-02,   1.34277344e-02],
                        [  3.87573242e-03,   3.50952148e-03],
                        [  9.15527344e-04,   5.49316406e-04],
                        [  3.02124023e-03,   2.68554688e-03],
                        [  7.87353516e-03,   7.62939453e-03],
                        [  1.30920410e-02,   1.29394531e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  2.79541016e-02,   2.80456543e-02],
                        [  4.24499512e-02,   4.26635742e-02],
                        [  5.96923828e-02,   5.99975586e-02],
                        [  7.43408203e-02,   7.46765137e-02],
                        [  8.25195312e-02,   8.28552246e-02],
                        [  8.41979980e-02,   8.45336914e-02],
                        [  7.90710449e-02,   7.93457031e-02],
                        [  6.54602051e-02,   6.56738281e-02],
                        [  4.52575684e-02,   4.53796387e-02],
                        [  2.34375000e-02,   2.34680176e-02],
                        [  3.72314453e-03,   3.66210938e-03],
                        [ -1.32446289e-02,  -1.33666992e-02],
                        [ -2.70385742e-02,  -2.72216797e-02],
                        [ -3.44543457e-02,  -3.46374512e-02],
                        [ -3.19519043e-02,  -3.21350098e-02],
                        [ -2.02331543e-02,  -2.03857422e-02],
                        [ -3.32641602e-03,  -3.44848633e-03],
                        [  1.46179199e-02,   1.45568848e-02],
                        [  2.89001465e-02,   2.88696289e-02],
                        [  3.46984863e-02,   3.47290039e-02],
                        [  3.24707031e-02,   3.25012207e-02],
                        [  2.81066895e-02,   2.81066895e-02],
                        [  2.52990723e-02,   2.52685547e-02],
                        [  2.27355957e-02,   2.26745605e-02],
                        [  1.79443359e-02,   1.78222656e-02],
                        [  9.88769531e-03,   9.73510742e-03],
                        [ -3.35693359e-04,  -5.18798828e-04],
                        [ -8.78906250e-03,  -9.00268555e-03],
                        [ -1.11694336e-02,  -1.13525391e-02],
                        [ -7.90405273e-03,  -8.02612305e-03],
                        [ -3.26538086e-03,  -3.29589844e-03],
                        [  1.92260742e-03,   2.01416016e-03],
                        [  9.88769531e-03,   1.01318359e-02],
                        [  1.85546875e-02,   1.89208984e-02],
                        [  2.21862793e-02,   2.26745605e-02],
                        [  1.81274414e-02,   1.87377930e-02],
                        [  8.05664062e-03,   8.69750977e-03],
                        [ -5.52368164e-03,  -4.94384766e-03],
                        [ -1.99890137e-02,  -1.95312500e-02],
                        [ -3.10668945e-02,  -3.07617188e-02],
                        [ -3.47290039e-02,  -3.46374512e-02],
                        [ -3.06091309e-02,  -3.07922363e-02],
                        [ -2.16674805e-02,  -2.21252441e-02],
                        [ -1.10778809e-02,  -1.17797852e-02],
                        [ -1.73950195e-03,  -2.62451172e-03],
                        [  2.99072266e-03,   1.98364258e-03],
                        [  1.43432617e-03,   3.66210938e-04],
                        [ -3.87573242e-03,  -4.88281250e-03],
                        [ -9.39941406e-03,  -1.02233887e-02],
                        [ -1.42822266e-02,  -1.48620605e-02],
                        [ -1.92871094e-02,  -1.95312500e-02],
                        [ -2.38952637e-02,  -2.37426758e-02],
                        [ -2.78015137e-02,  -2.72827148e-02],
                        [ -3.31726074e-02,  -3.22570801e-02],
                        [ -3.99475098e-02,  -3.87573242e-02],
                        [ -4.21752930e-02,  -4.08020020e-02],
                        [ -3.63464355e-02,  -3.49121094e-02],
                        [ -2.78930664e-02,  -2.65197754e-02],
                        [ -2.28271484e-02,  -2.16369629e-02],
                        [ -1.96228027e-02,  -1.87377930e-02],
                        [ -1.34582520e-02,  -1.29699707e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  1.73950195e-03,   1.25122070e-03],
                        [  3.54003906e-03,   2.62451172e-03],
                        [  3.41796875e-03,   2.13623047e-03],
                        [  3.75366211e-03,   2.19726562e-03],
                        [  6.07299805e-03,   4.39453125e-03],
                        [  1.18408203e-02,   1.02233887e-02],
                        [  2.02941895e-02,   1.88293457e-02],
                        [  2.69775391e-02,   2.57873535e-02],
                        [  2.70996094e-02,   2.63366699e-02],
                        [  2.11791992e-02,   2.08740234e-02],
                        [  1.35498047e-02,   1.37329102e-02],
                        [  6.53076172e-03,   7.20214844e-03],
                        [  6.40869141e-04,   1.73950195e-03],
                        [ -1.80053711e-03,  -3.96728516e-04],
                        [  2.04467773e-03,   3.66210938e-03],
                        [  1.37023926e-02,   1.53808594e-02],
                        [  3.19824219e-02,   3.35693359e-02],
                        [  5.30700684e-02,   5.44738770e-02],
                        [  7.29675293e-02,   7.40356445e-02],
                        [  8.96911621e-02,   9.03625488e-02],
                        [  1.02874756e-01,   1.03118896e-01],
                        [  1.10656738e-01,   1.10443115e-01],
                        [  1.07055664e-01,   1.06414795e-01],
                        [  8.07189941e-02,   7.97119141e-02],
                        [  1.92871094e-02,   1.80053711e-02],
                        [ -7.67517090e-02,  -7.81860352e-02],
                        [ -1.84143066e-01,  -1.85638428e-01],
                        [ -2.67272949e-01,  -2.68707275e-01],
                        [ -3.01391602e-01,  -3.02673340e-01],
                        [ -2.88299561e-01,  -2.89337158e-01],
                        [ -2.52410889e-01,  -2.53143311e-01],
                        [ -2.20367432e-01,  -2.20764160e-01],
                        [ -2.00927734e-01,  -2.00958252e-01],
                        [ -1.80664062e-01,  -1.80328369e-01],
                        [ -1.41113281e-01,  -1.40472412e-01],
                        [ -8.01086426e-02,  -7.91931152e-02],
                        [ -1.29699707e-02,  -1.18408203e-02],
                        [  4.24499512e-02,   4.37316895e-02],
                        [  7.73620605e-02,   7.87048340e-02],
                        [  9.41467285e-02,   9.54589844e-02],
                        [  1.00616455e-01,   1.01806641e-01],
                        [  1.03210449e-01,   1.04217529e-01],
                        [  1.05834961e-01,   1.06567383e-01],
                        [  1.09558105e-01,   1.10015869e-01],
                        [  1.11999512e-01,   1.12091064e-01],
                        [  1.08459473e-01,   1.08184814e-01],
                        [  9.53063965e-02,   9.46960449e-02],
                        [  7.27233887e-02,   7.17773438e-02],
                        [  4.45556641e-02,   4.33654785e-02],
                        [  1.68762207e-02,   1.55029297e-02],
                        [ -3.32641602e-03,  -4.79125977e-03],
                        [ -1.22680664e-02,  -1.37329102e-02],
                        [ -1.10473633e-02,  -1.23901367e-02],
                        [ -2.19726562e-03,  -3.32641602e-03],
                        [  1.13220215e-02,   1.04980469e-02],
                        [  2.61535645e-02,   2.57263184e-02],
                        [  4.12597656e-02,   4.12902832e-02],
                        [  5.68542480e-02,   5.73120117e-02],
                        [  6.99768066e-02,   7.08618164e-02],
                        [  7.55310059e-02,   7.67822266e-02],
                        [  7.12890625e-02,   7.27844238e-02],
                        [  5.99060059e-02,   6.15539551e-02],
                        [  4.57763672e-02,   4.74548340e-02],
                        [  3.05480957e-02,   3.20739746e-02],
                        [  1.36108398e-02,   1.48925781e-02],
                        [ -3.32641602e-03,  -2.41088867e-03],
                        [ -1.65100098e-02,  -1.60217285e-02],
                        [ -2.39562988e-02,  -2.39257812e-02],
                        [ -2.53601074e-02,  -2.57873535e-02],
                        [ -2.02636719e-02,  -2.11181641e-02],
                        [ -1.13525391e-02,  -1.25427246e-02],
                        [ -4.05883789e-03,  -5.46264648e-03],
                        [  3.05175781e-05,  -1.49536133e-03],
                        [  3.75366211e-03,   2.25830078e-03],
                        [  9.27734375e-03,   7.96508789e-03],
                        [  1.61437988e-02,   1.50451660e-02],
                        [  2.34069824e-02,   2.26745605e-02],
                        [  3.21044922e-02,   3.17077637e-02],
                        [  4.11987305e-02,   4.11682129e-02],
                        [  4.57763672e-02,   4.60510254e-02],
                        [  4.47082520e-02,   4.52575684e-02],
                        [  4.24499512e-02,   4.32434082e-02],
                        [  4.12597656e-02,   4.21142578e-02],
                        [  3.96423340e-02,   4.05578613e-02],
                        [  3.59802246e-02,   3.68652344e-02],
                        [  2.97241211e-02,   3.05175781e-02],
                        [  2.19726562e-02,   2.26135254e-02],
                        [  1.32141113e-02,   1.37634277e-02],
                        [  3.66210938e-03,   4.08935547e-03],
                        [ -3.75366211e-03,  -3.44848633e-03],
                        [ -5.88989258e-03,  -5.64575195e-03],
                        [ -3.23486328e-03,  -3.02124023e-03],
                        [  1.28173828e-03,   1.46484375e-03],
                        [  4.39453125e-03,   4.51660156e-03],
                        [  4.45556641e-03,   4.54711914e-03],
                        [  1.89208984e-03,   1.86157227e-03],
                        [ -3.02124023e-03,  -3.20434570e-03],
                        [ -1.11999512e-02,  -1.15661621e-02],
                        [ -2.34069824e-02,  -2.40478516e-02],
                        [ -3.75671387e-02,  -3.84521484e-02],
                        [ -4.88281250e-02,  -4.99877930e-02],
                        [ -5.47180176e-02,  -5.60913086e-02],
                        [ -5.67932129e-02,  -5.83190918e-02],
                        [ -5.67016602e-02,  -5.82275391e-02],
                        [ -5.34362793e-02,  -5.48095703e-02],
                        [ -4.53796387e-02,  -4.64782715e-02],
                        [ -3.37829590e-02,  -3.44543457e-02],
                        [ -2.21557617e-02,  -2.22167969e-02],
                        [ -1.25122070e-02,  -1.18713379e-02],
                        [ -4.88281250e-03,  -3.57055664e-03],
                        [  1.12915039e-03,   3.08227539e-03],
                        [  6.71386719e-03,   9.24682617e-03],
                        [  1.21154785e-02,   1.49841309e-02],
                        [  1.34887695e-02,   1.64489746e-02],
                        [  6.65283203e-03,   9.46044922e-03],
                        [ -6.19506836e-03,  -3.81469727e-03],
                        [ -1.76696777e-02,  -1.60522461e-02],
                        [ -2.40173340e-02,  -2.33154297e-02],
                        [ -2.88085938e-02,  -2.91748047e-02],
                        [ -3.64074707e-02,  -3.79028320e-02],
                        [ -4.41284180e-02,  -4.66613770e-02],
                        [ -4.50134277e-02,  -4.84313965e-02],
                        [ -3.60107422e-02,  -4.00085449e-02],
                        [ -1.89514160e-02,  -2.31933594e-02],
                        [  3.90625000e-03,  -2.13623047e-04],
                        [  2.98461914e-02,   2.63366699e-02],
                        [  5.32226562e-02,   5.06286621e-02],
                        [  6.68640137e-02,   6.54602051e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  5.31005859e-02,   5.45349121e-02],
                        [  3.29589844e-02,   3.57666016e-02],
                        [  1.40991211e-02,   1.80358887e-02],
                        [  2.65502930e-03,   7.35473633e-03],
                        [ -6.10351562e-05,   5.00488281e-03],
                        [  3.02124023e-03,   7.93457031e-03],
                        [  9.73510742e-03,   1.40686035e-02],
                        [  2.35290527e-02,   2.68249512e-02],
                        [  4.90112305e-02,   5.09643555e-02],
                        [  8.32824707e-02,   8.36791992e-02],
                        [  1.16333008e-01,   1.15112305e-01],
                        [  1.38671875e-01,   1.35955811e-01],
                        [  1.44409180e-01,   1.40441895e-01],
                        [  1.26647949e-01,   1.21765137e-01],
                        [  7.54699707e-02,   7.02209473e-02],
                        [ -1.33666992e-02,  -1.85241699e-02],
                        [ -1.27349854e-01,  -1.31927490e-01],
                        [ -2.36511230e-01,  -2.40081787e-01],
                        [ -3.08471680e-01,  -3.10699463e-01],
                        [ -3.28826904e-01,  -3.29528809e-01],
                        [ -3.07983398e-01,  -3.07128906e-01],
                        [ -2.70355225e-01,  -2.68005371e-01],
                        [ -2.37304688e-01,  -2.33764648e-01],
                        [ -2.14721680e-01,  -2.10357666e-01],
                        [ -1.90063477e-01,  -1.85272217e-01],
                        [ -1.45385742e-01,  -1.40686035e-01],
                        [ -7.79418945e-02,  -7.37609863e-02],
                        [ -4.82177734e-03,  -1.52587891e-03],
                        [  5.39550781e-02,   5.61218262e-02],
                        [  9.11254883e-02,   9.19494629e-02],
                        [  1.11480713e-01,   1.10961914e-01],
                        [  1.23901367e-01,   1.22192383e-01],
                        [  1.34674072e-01,   1.31958008e-01],
                        [  1.44012451e-01,   1.40625000e-01],
                        [  1.46820068e-01,   1.43127441e-01],
                        [  1.37329102e-01,   1.33697510e-01],
                        [  1.15692139e-01,   1.12457275e-01],
                        [  8.93249512e-02,   8.67614746e-02],
                        [  6.57348633e-02,   6.39953613e-02],
                        [  4.40673828e-02,   4.33044434e-02],
                        [  1.87377930e-02,   1.88903809e-02],
                        [ -7.99560547e-03,  -7.01904297e-03],
                        [ -2.52685547e-02,  -2.36511230e-02],
                        [ -2.70996094e-02,  -2.50549316e-02],
                        [ -1.65405273e-02,  -1.43432617e-02],
                        [  5.18798828e-04,   2.68554688e-03],
                        [  1.87377930e-02,   2.06604004e-02],
                        [  3.48815918e-02,   3.64379883e-02],
                        [  4.87670898e-02,   4.98352051e-02],
                        [  6.15234375e-02,   6.21032715e-02],
                        [  7.28759766e-02,   7.30285645e-02],
                        [  7.94372559e-02,   7.92236328e-02],
                        [  7.81860352e-02,   7.76977539e-02],
                        [  7.02209473e-02,   6.95800781e-02],
                        [  5.85327148e-02,   5.78613281e-02],
                        [  4.51965332e-02,   4.45861816e-02],
                        [  2.93884277e-02,   2.88391113e-02],
                        [  9.55200195e-03,   9.09423828e-03],
                        [ -1.08337402e-02,  -1.11999512e-02],
                        [ -2.54211426e-02,  -2.57568359e-02],
                        [ -3.11279297e-02,  -3.14636230e-02],
                        [ -2.89916992e-02,  -2.93884277e-02],
                        [ -2.29492188e-02,  -2.34680176e-02],
                        [ -1.75170898e-02,  -1.81274414e-02],
                        [ -1.59301758e-02,  -1.66015625e-02],
                        [ -1.87072754e-02,  -1.94091797e-02],
                        [ -2.05993652e-02,  -2.12402344e-02],
                        [ -1.31530762e-02,  -1.36108398e-02],
                        [  7.35473633e-03,   7.11059570e-03],
                        [  3.51562500e-02,   3.52478027e-02],
                        [  5.91125488e-02,   5.95703125e-02],
                        [  7.34252930e-02,   7.42797852e-02],
                        [  7.82470703e-02,   7.94372559e-02],
                        [  7.32421875e-02,   7.46459961e-02],
                        [  6.14624023e-02,   6.29882812e-02],
                        [  4.92858887e-02,   5.07812500e-02],
                        [  3.84521484e-02,   3.97644043e-02],
                        [  2.68859863e-02,   2.78625488e-02],
                        [  1.31225586e-02,   1.36413574e-02],
                        [ -7.01904297e-04,  -7.32421875e-04],
                        [ -1.11083984e-02,  -1.16577148e-02],
                        [ -1.96533203e-02,  -2.06909180e-02],
                        [ -2.70080566e-02,  -2.84118652e-02],
                        [ -2.85644531e-02,  -3.02124023e-02],
                        [ -2.29187012e-02,  -2.46582031e-02],
                        [ -1.34277344e-02,  -1.50451660e-02],
                        [ -5.67626953e-03,  -7.04956055e-03],
                        [ -5.46264648e-03,  -6.40869141e-03],
                        [ -1.21154785e-02,  -1.25732422e-02],
                        [ -2.13012695e-02,  -2.12097168e-02],
                        [ -2.96325684e-02,  -2.91137695e-02],
                        [ -3.37829590e-02,  -3.28674316e-02],
                        [ -3.52478027e-02,  -3.40881348e-02],
                        [ -3.88793945e-02,  -3.75671387e-02],
                        [ -4.19921875e-02,  -4.07409668e-02],
                        [ -3.79638672e-02,  -3.69262695e-02],
                        [ -2.72827148e-02,  -2.65502930e-02],
                        [ -1.70898438e-02,  -1.66625977e-02],
                        [ -1.28479004e-02,  -1.27868652e-02],
                        [ -1.44348145e-02,  -1.46789551e-02],
                        [ -1.92260742e-02,  -1.96533203e-02],
                        [ -2.31628418e-02,  -2.36816406e-02],
                        [ -2.04772949e-02,  -2.09655762e-02],
                        [ -1.01928711e-02,  -1.05285645e-02],
                        [  7.01904297e-04,   5.49316406e-04],
                        [  4.94384766e-03,   5.03540039e-03],
                        [  3.66210938e-03,   3.96728516e-03],
                        [  3.50952148e-03,   3.96728516e-03],
                        [  7.84301758e-03,   8.33129883e-03],
                        [  1.52893066e-02,   1.56860352e-02],
                        [  2.29492188e-02,   2.31323242e-02],
                        [  2.63366699e-02,   2.61535645e-02],
                        [  2.16979980e-02,   2.11181641e-02],
                        [  1.20239258e-02,   1.10473633e-02],
                        [  5.61523438e-03,   4.30297852e-03],
                        [  7.38525391e-03,   5.82885742e-03],
                        [  1.36108398e-02,   1.20239258e-02],
                        [  1.74865723e-02,   1.61132812e-02],
                        [  1.66320801e-02,   1.56555176e-02],
                        [  1.33666992e-02,   1.29394531e-02],
                        [  1.21765137e-02,   1.25122070e-02],
                        [  1.68762207e-02,   1.80053711e-02],
                        [  2.71301270e-02,   2.90222168e-02],
                        [  4.01611328e-02,   4.26635742e-02],
                        [  5.71289062e-02,   6.00280762e-02],
                        [  8.21533203e-02,   8.51440430e-02],
                        [  1.13525391e-01,   1.16271973e-01],
                        [  1.41510010e-01,   1.43676758e-01],
                        [  1.53045654e-01,   1.54327393e-01],
                        [  1.31988525e-01,   1.32141113e-01],
                        [  6.34460449e-02,   6.24084473e-02],
                        [ -4.99572754e-02,  -5.21545410e-02],
                        [ -1.79962158e-01,  -1.83197021e-01],
                        [ -2.86132812e-01,  -2.90069580e-01],
                        [ -3.38989258e-01,  -3.43231201e-01],
                        [ -3.35083008e-01,  -3.39202881e-01],
                        [ -2.96325684e-01,  -2.99865723e-01],
                        [ -2.53326416e-01,  -2.55798340e-01],
                        [ -2.20825195e-01,  -2.21954346e-01],
                        [ -1.89819336e-01,  -1.89422607e-01],
                        [ -1.43463135e-01,  -1.41540527e-01],
                        [ -7.67211914e-02,  -7.33947754e-02],
                        [ -2.34985352e-03,   2.04467773e-03],
                        [  5.95397949e-02,   6.45446777e-02],
                        [  9.61608887e-02,   1.01287842e-01],
                        [  1.07269287e-01,   1.11938477e-01],
                        [  1.03210449e-01,   1.06872559e-01],
                        [  9.83581543e-02,   1.00616455e-01],
                        [  9.94567871e-02,   1.00067139e-01],
                        [  1.01867676e-01,   1.00708008e-01],
                        [  9.94873047e-02,   9.66491699e-02],
                        [  9.26513672e-02,   8.84094238e-02],
                        [  8.43811035e-02,   7.92236328e-02],
                        [  7.34558105e-02,   6.79321289e-02],
                        [  5.70373535e-02,   5.17272949e-02],
                        [  3.72009277e-02,   3.27148438e-02],
                        [  1.93786621e-02,   1.62048340e-02],
                        [  7.01904297e-03,   5.49316406e-03],
                        [  1.95312500e-03,   2.25830078e-03],
                        [  6.68334961e-03,   8.75854492e-03],
                        [  2.11791992e-02,   2.48107910e-02],
                        [  3.92150879e-02,   4.39758301e-02],
                        [  5.29479980e-02,   5.83190918e-02],
                        [  5.98449707e-02,   6.52160645e-02],
                        [  6.15539551e-02,   6.63452148e-02],
                        [  6.07910156e-02,   6.44226074e-02],
                        [  6.00585938e-02,   6.21948242e-02],
                        [  5.90209961e-02,   5.94177246e-02],
                        [  5.27343750e-02,   5.13916016e-02],
                        [  3.58276367e-02,   3.29284668e-02],
                        [  1.03454590e-02,   6.25610352e-03],
                        [ -1.35803223e-02,  -1.84020996e-02],
                        [ -2.69165039e-02,  -3.18603516e-02],
                        [ -2.89306641e-02,  -3.34472656e-02],
                        [ -2.63671875e-02,  -2.99377441e-02],
                        [ -2.64282227e-02,  -2.87170410e-02],
                        [ -3.02124023e-02,  -3.09448242e-02],
                        [ -3.21960449e-02,  -3.13415527e-02],
                        [ -2.72827148e-02,  -2.50244141e-02],
                        [ -1.75476074e-02,  -1.41906738e-02],
                        [ -8.81958008e-03,  -4.79125977e-03],
                        [ -3.63159180e-03,   6.10351562e-04],
                        [ -1.64794922e-03,   2.25830078e-03],
                        [  1.15966797e-03,   4.24194336e-03],
                        [  1.25732422e-02,   1.45568848e-02],
                        [  3.22570801e-02,   3.29284668e-02],
                        [  4.76379395e-02,   4.69970703e-02],
                        [  4.97436523e-02,   4.78820801e-02],
                        [  4.29992676e-02,   4.02221680e-02],
                        [  3.75061035e-02,   3.41796875e-02],
                        [  3.77197266e-02,   3.43322754e-02],
                        [  4.15954590e-02,   3.85437012e-02],
                        [  4.50439453e-02,   4.27246094e-02],
                        [  4.38537598e-02,   4.24804688e-02],
                        [  3.64379883e-02,   3.61938477e-02],
                        [  2.51770020e-02,   2.60009766e-02],
                        [  1.30615234e-02,   1.48315430e-02],
                        [  3.11279297e-03,   5.49316406e-03],
                        [ -3.44848633e-03,  -7.62939453e-04],
                        [ -8.27026367e-03,  -5.67626953e-03],
                        [ -1.23901367e-02,  -1.02539062e-02],
                        [ -1.44348145e-02,  -1.30310059e-02],
                        [ -1.20544434e-02,  -1.15051270e-02],
                        [ -6.71386719e-03,  -7.11059570e-03],
                        [ -4.88281250e-03,  -6.16455078e-03],
                        [ -8.91113281e-03,  -1.07727051e-02],
                        [ -1.51367188e-02,  -1.73645020e-02],
                        [ -2.12707520e-02,  -2.34985352e-02],
                        [ -2.57873535e-02,  -2.76489258e-02],
                        [ -2.74047852e-02,  -2.86560059e-02],
                        [ -2.54821777e-02,  -2.59094238e-02],
                        [ -2.02331543e-02,  -1.97753906e-02],
                        [ -1.70288086e-02,  -1.57775879e-02],
                        [ -2.03857422e-02,  -1.84936523e-02],
                        [ -2.65197754e-02,  -2.42614746e-02],
                        [ -3.10363770e-02,  -2.87475586e-02],
                        [ -3.24096680e-02,  -3.04565430e-02],
                        [ -2.85949707e-02,  -2.73132324e-02],
                        [ -1.92871094e-02,  -1.88598633e-02],
                        [ -8.81958008e-03,  -9.36889648e-03],
                        [ -5.00488281e-03,  -6.50024414e-03],
                        [ -1.05895996e-02,  -1.28479004e-02],
                        [ -1.91650391e-02,  -2.19116211e-02],
                        [ -2.55126953e-02,  -2.83508301e-02],
                        [ -2.96630859e-02,  -3.21960449e-02],
                        [ -3.04565430e-02,  -3.23486328e-02],
                        [ -2.59704590e-02,  -2.68554688e-02],
                        [ -1.67236328e-02,  -1.64489746e-02],
                        [ -6.68334961e-03,  -5.18798828e-03],
                        [ -3.35693359e-04,   2.22778320e-03],
                        [  2.56347656e-03,   5.92041016e-03],
                        [  5.34057617e-03,   9.06372070e-03],
                        [  1.01623535e-02,   1.38244629e-02],
                        [  1.81884766e-02,   2.12707520e-02],
                        [  2.81372070e-02,   3.02124023e-02],
                        [  3.51867676e-02,   3.59191895e-02],
                        [  3.45458984e-02,   3.38134766e-02],
                        [  2.70385742e-02,   2.47497559e-02],
                        [  1.87683105e-02,   1.51977539e-02],
                        [  1.44958496e-02,   1.00402832e-02],
                        [  1.43127441e-02,   9.42993164e-03],
                        [  1.68762207e-02,   1.22070312e-02],
                        [  2.24914551e-02,   1.85546875e-02],
                        [  3.39660645e-02,   3.13415527e-02],
                        [  5.49621582e-02,   5.39855957e-02],
                        [  8.52966309e-02,   8.61816406e-02],
                        [  1.17523193e-01,   1.20208740e-01],
                        [  1.38305664e-01,   1.42578125e-01],
                        [  1.34979248e-01,   1.40411377e-01],
                        [  9.85412598e-02,   1.04492188e-01],
                        [  2.34985352e-02,   2.93273926e-02],
                        [ -8.41369629e-02,  -7.91625977e-02],
                        [ -2.00012207e-01,  -1.96441650e-01],
                        [ -2.90069580e-01,  -2.88421631e-01],
                        [ -3.30322266e-01,  -3.30810547e-01],
                        [ -3.19976807e-01,  -3.22631836e-01],
                        [ -2.76153564e-01,  -2.80700684e-01],
                        [ -2.20397949e-01,  -2.26348877e-01],
                        [ -1.71356201e-01,  -1.78131104e-01],
                        [ -1.36932373e-01,  -1.43737793e-01],
                        [ -1.07391357e-01,  -1.13464355e-01],
                        [ -6.71081543e-02,  -7.17773438e-02],
                        [ -1.50146484e-02,  -1.77001953e-02],
                        [  3.31420898e-02,   3.27758789e-02],
                        [  6.20117188e-02,   6.39953613e-02],
                        [  6.97326660e-02,   7.38830566e-02],
                        [  6.56433105e-02,   7.15026855e-02],
                        [  6.27441406e-02,   6.97021484e-02],
                        [  6.99157715e-02,   7.72399902e-02],
                        [  8.46252441e-02,   9.14916992e-02],
                        [  9.58251953e-02,   1.01470947e-01],
                        [  9.61608887e-02,   9.99755859e-02],
                        [  8.79821777e-02,   8.95690918e-02],
                        [  7.71484375e-02,   7.63549805e-02],
                        [  6.54602051e-02,   6.23474121e-02],
                        [  5.20935059e-02,   4.70581055e-02],
                        [  3.87268066e-02,   3.23181152e-02],
                        [  2.99987793e-02,   2.29187012e-02],
                        [  2.99377441e-02,   2.29797363e-02],
                        [  3.82080078e-02,   3.20739746e-02],
                        [  4.96520996e-02,   4.50134277e-02],
                        [  5.92956543e-02,   5.65795898e-02],
                        [  6.60400391e-02,   6.55212402e-02],
                        [  7.12280273e-02,   7.28454590e-02],
                        [  7.47070312e-02,   7.82775879e-02],
                        [  7.36083984e-02,   7.86743164e-02],
                        [  6.43310547e-02,   7.02819824e-02],
                        [  4.62036133e-02,   5.23986816e-02],
                        [  2.18505859e-02,   2.76184082e-02],
                        [ -5.18798828e-03,  -4.27246094e-04],
                        [ -2.93884277e-02,  -2.61230469e-02],
                        [ -4.35485840e-02,  -4.19921875e-02],
                        [ -4.51660156e-02,  -4.54101562e-02],
                        [ -4.05578613e-02,  -4.24499512e-02],
                        [ -3.83605957e-02,  -4.16259766e-02],
                        [ -4.04052734e-02,  -4.45556641e-02],
                        [ -4.19006348e-02,  -4.64477539e-02],
                        [ -3.91845703e-02,  -4.36096191e-02],
                        [ -3.10058594e-02,  -3.48510742e-02],
                        [ -1.64184570e-02,  -1.93481445e-02],
                        [  7.01904297e-04,  -1.06811523e-03],
                        [  1.24511719e-02,   1.19323730e-02],
                        [  1.68457031e-02,   1.74865723e-02],
                        [  2.00195312e-02,   2.16064453e-02],
                        [  2.77099609e-02,   2.99377441e-02],
                        [  3.95812988e-02,   4.20837402e-02],
                        [  5.24902344e-02,   5.49926758e-02],
                        [  6.47277832e-02,   6.68640137e-02],
                        [  7.34252930e-02,   7.50122070e-02],
                        [  7.41577148e-02,   7.51342773e-02],
                        [  6.63757324e-02,   6.66809082e-02],
                        [  5.43212891e-02,   5.40771484e-02],
                        [  4.17480469e-02,   4.11071777e-02],
                        [  2.94189453e-02,   2.86254883e-02],
                        [  1.82189941e-02,   1.74560547e-02],
                        [  1.12304688e-02,   1.07116699e-02],
                        [  9.27734375e-03,   9.12475586e-03],
                        [  7.32421875e-03,   7.56835938e-03],
                        [ -1.52587891e-04,   4.57763672e-04],
                        [ -1.11389160e-02,  -1.03149414e-02],
                        [ -1.74560547e-02,  -1.65710449e-02],
                        [ -1.57165527e-02,  -1.49841309e-02],
                        [ -1.08032227e-02,  -1.04064941e-02],
                        [ -7.26318359e-03,  -7.38525391e-03],
                        [ -6.83593750e-03,  -7.56835938e-03],
                        [ -1.08947754e-02,  -1.22375488e-02],
                        [ -1.81579590e-02,  -2.00195312e-02],
                        [ -2.39868164e-02,  -2.62145996e-02],
                        [ -2.52990723e-02,  -2.76184082e-02],
                        [ -2.42614746e-02,  -2.63977051e-02],
                        [ -2.52990723e-02,  -2.70080566e-02],
                        [ -2.85644531e-02,  -2.95715332e-02],
                        [ -3.13720703e-02,  -3.14941406e-02],
                        [ -3.32641602e-02,  -3.24401855e-02],
                        [ -3.42407227e-02,  -3.24707031e-02],
                        [ -3.37219238e-02,  -3.12194824e-02],
                        [ -3.28979492e-02,  -2.98767090e-02],
                        [ -3.34472656e-02,  -3.01818848e-02],
                        [ -3.50952148e-02,  -3.19519043e-02],
                        [ -3.52783203e-02,  -3.25927734e-02],
                        [ -3.25012207e-02,  -3.05175781e-02],
                        [ -2.75878906e-02,  -2.65502930e-02],
                        [ -2.09960938e-02,  -2.09655762e-02],
                        [ -1.26953125e-02,  -1.37023926e-02],
                        [ -4.42504883e-03,  -6.31713867e-03],
                        [  1.77001953e-03,  -7.93457031e-04],
                        [  4.54711914e-03,   1.58691406e-03],
                        [  4.02832031e-03,   9.76562500e-04],
                        [  2.04467773e-03,  -7.93457031e-04],
                        [  5.18798828e-04,  -1.86157227e-03],
                        [ -1.22070312e-04,  -1.83105469e-03],
                        [ -1.52587891e-04,  -1.09863281e-03],
                        [  2.44140625e-04,   6.10351562e-05],
                        [  1.34277344e-03,   1.80053711e-03],
                        [  3.32641602e-03,   4.30297852e-03],
                        [  6.71386719e-03,   8.02612305e-03],
                        [  1.19628906e-02,   1.34277344e-02],
                        [  1.80358887e-02,   1.94702148e-02],
                        [  2.38952637e-02,   2.51770020e-02],
                        [  3.03039551e-02,   3.13720703e-02],
                        [  3.80554199e-02,   3.89099121e-02],
                        [  4.61730957e-02,   4.69055176e-02],
                        [  5.42297363e-02,   5.49316406e-02],
                        [  6.30798340e-02,   6.38427734e-02],
                        [  7.22961426e-02,   7.32421875e-02],
                        [  8.04138184e-02,   8.16040039e-02],
                        [  8.91723633e-02,   9.05456543e-02],
                        [  1.00402832e-01,   1.01867676e-01],
                        [  1.06201172e-01,   1.07604980e-01],
                        [  8.81958008e-02,   8.92944336e-02],
                        [  3.03955078e-02,   3.09143066e-02],
                        [ -6.69250488e-02,  -6.72302246e-02],
                        [ -1.84020996e-01,  -1.85333252e-01],
                        [ -2.87445068e-01,  -2.89886475e-01],
                        [ -3.43109131e-01,  -3.46679688e-01],
                        [ -3.38012695e-01,  -3.42498779e-01],
                        [ -2.91259766e-01,  -2.96356201e-01],
                        [ -2.36663818e-01,  -2.41882324e-01],
                        [ -1.95312500e-01,  -2.00164795e-01],
                        [ -1.64642334e-01,  -1.68487549e-01],
                        [ -1.28540039e-01,  -1.30889893e-01],
                        [ -7.55615234e-02,  -7.58972168e-02],
                        [ -9.30786133e-03,  -7.41577148e-03],
                        [  5.27343750e-02,   5.69152832e-02],
                        [  9.22241211e-02,   9.85717773e-02],
                        [  1.05041504e-01,   1.13067627e-01],
                        [  1.02416992e-01,   1.11419678e-01],
                        [  9.95483398e-02,   1.08795166e-01],
                        [  1.04461670e-01,   1.12945557e-01],
                        [  1.13647461e-01,   1.20452881e-01],
                        [  1.18194580e-01,   1.22528076e-01],
                        [  1.12243652e-01,   1.13525391e-01],
                        [  9.48486328e-02,   9.27124023e-02],
                        [  6.90002441e-02,   6.34155273e-02],
                        [  4.11071777e-02,   3.24707031e-02],
                        [  1.75781250e-02,   6.56127930e-03],
                        [  2.01416016e-03,  -1.04064941e-02],
                        [ -3.35693359e-03,  -1.60217285e-02],
                        [  2.28881836e-03,  -9.36889648e-03],
                        [  1.51367188e-02,   5.61523438e-03],
                        [  2.88085938e-02,   2.24914551e-02],
                        [  4.15039062e-02,   3.91235352e-02],
                        [  5.46264648e-02,   5.65185547e-02],
                        [  6.72912598e-02,   7.34252930e-02],
                        [  7.73925781e-02,   8.73107910e-02],
                        [  8.17871094e-02,   9.46044922e-02],
                        [  7.51953125e-02,   8.96911621e-02],
                        [  5.61523438e-02,   7.10144043e-02],
                        [  3.09143066e-02,   4.47387695e-02],
                        [  6.68334961e-03,   1.80664062e-02],
                        [ -1.44348145e-02,  -6.56127930e-03],
                        [ -3.09143066e-02,  -2.73437500e-02],
                        [ -3.83911133e-02,  -3.95202637e-02],
                        [ -3.57971191e-02,  -4.15039062e-02],
                        [ -2.94189453e-02,  -3.91845703e-02],
                        [ -2.66113281e-02,  -3.94897461e-02],
                        [ -2.85644531e-02,  -4.33654785e-02],
                        [ -2.97241211e-02,  -4.50134277e-02],
                        [ -2.23083496e-02,  -3.66210938e-02],
                        [ -4.79125977e-03,  -1.68457031e-02],
                        [  1.60522461e-02,   7.41577148e-03],
                        [  3.24707031e-02,   2.79541016e-02],
                        [  3.97644043e-02,   3.97338867e-02],
                        [  3.72314453e-02,   4.15954590e-02],
                        [  2.96020508e-02,   3.78417969e-02],
                        [  2.39868164e-02,   3.52172852e-02],
                        [  2.38342285e-02,   3.68957520e-02],
                        [  2.70080566e-02,   4.07104492e-02],
                        [  2.85949707e-02,   4.15954590e-02],
                        [  2.63977051e-02,   3.75366211e-02],
                        [  2.33764648e-02,   3.17382812e-02],
                        [  2.30712891e-02,   2.80456543e-02],
                        [  2.52990723e-02,   2.65197754e-02],
                        [  2.84423828e-02,   2.60925293e-02],
                        [  3.24401855e-02,   2.69165039e-02],
                        [  3.60107422e-02,   2.79541016e-02],
                        [  3.50952148e-02,   2.54211426e-02],
                        [  2.79235840e-02,   1.76696777e-02],
                        [  1.79138184e-02,   7.99560547e-03],
                        [  9.18579102e-03,   3.96728516e-04],
                        [  3.11279297e-03,  -3.78417969e-03],
                        [ -8.23974609e-04,  -5.40161133e-03],
                        [ -4.73022461e-03,  -6.89697266e-03],
                        [ -1.00708008e-02,  -9.82666016e-03],
                        [ -1.58386230e-02,  -1.34582520e-02],
                        [ -2.14233398e-02,  -1.74560547e-02],
                        [ -2.75878906e-02,  -2.25219727e-02],
                        [ -3.39965820e-02,  -2.83508301e-02],
                        [ -3.83911133e-02,  -3.28063965e-02],
                        [ -3.68957520e-02,  -3.17687988e-02],
                        [ -2.61535645e-02,  -2.17895508e-02],
                        [ -9.94873047e-03,  -6.53076172e-03],
                        [  1.80053711e-03,   4.18090820e-03],
                        [  4.18090820e-03,   5.61523438e-03],
                        [  4.57763672e-04,   1.12915039e-03],
                        [ -6.77490234e-03,  -6.68334961e-03],
                        [ -1.69982910e-02,  -1.73034668e-02],
                        [ -2.62756348e-02,  -2.68249512e-02],
                        [ -3.08837891e-02,  -3.15856934e-02],
                        [ -3.36608887e-02,  -3.45153809e-02],
                        [ -3.87268066e-02,  -3.97644043e-02],
                        [ -4.24499512e-02,  -4.37622070e-02],
                        [ -3.95812988e-02,  -4.13208008e-02],
                        [ -3.28369141e-02,  -3.50646973e-02],
                        [ -2.71301270e-02,  -2.98767090e-02],
                        [ -2.19116211e-02,  -2.52075195e-02],
                        [ -1.56250000e-02,  -1.93481445e-02],
                        [ -8.08715820e-03,  -1.19934082e-02],
                        [  2.01416016e-03,  -1.80053711e-03],
                        [  1.30004883e-02,   9.64355469e-03],
                        [  1.88293457e-02,   1.62963867e-02],
                        [  1.71203613e-02,   1.58081055e-02],
                        [  1.38549805e-02,   1.39770508e-02],
                        [  1.62048340e-02,   1.79748535e-02],
                        [  2.34375000e-02,   2.68554688e-02],
                        [  2.85034180e-02,   3.34167480e-02],
                        [  2.74658203e-02,   3.35998535e-02],
                        [  2.19726562e-02,   2.88391113e-02],
                        [  1.46179199e-02,   2.16674805e-02],
                        [  8.11767578e-03,   1.47705078e-02],
                        [  5.67626953e-03,   1.13220215e-02],
                        [  9.61303711e-03,   1.36718750e-02],
                        [  2.09045410e-02,   2.30102539e-02],
                        [  3.94897461e-02,   3.93981934e-02],
                        [  6.35070801e-02,   6.10961914e-02],
                        [  8.99963379e-02,   8.54187012e-02],
                        [  1.15051270e-01,   1.08703613e-01],
                        [  1.30889893e-01,   1.23199463e-01],
                        [  1.25732422e-01,   1.17340088e-01],
                        [  9.12780762e-02,   8.28857422e-02],
                        [  2.63366699e-02,   1.86157227e-02],
                        [ -6.54296875e-02,  -7.18688965e-02],
                        [ -1.71722412e-01,  -1.76361084e-01],
                        [ -2.66479492e-01,  -2.68920898e-01],
                        [ -3.19763184e-01,  -3.19854736e-01],
                        [ -3.19824219e-01,  -3.17565918e-01],
                        [ -2.82928467e-01,  -2.78533936e-01],
                        [ -2.38616943e-01,  -2.32452393e-01],
                        [ -2.05383301e-01,  -1.97875977e-01],
                        [ -1.79870605e-01,  -1.71630859e-01],
                        [ -1.45568848e-01,  -1.37237549e-01],
                        [ -9.06982422e-02,  -8.27941895e-02],
                        [ -2.15759277e-02,  -1.47094727e-02],
                        [  4.08325195e-02,   4.62036133e-02],
                        [  8.01086426e-02,   8.36791992e-02],
                        [  9.71374512e-02,   9.86633301e-02],
                        [  1.02386475e-01,   1.01776123e-01],
                        [  1.03515625e-01,   1.00830078e-01],
                        [  1.04431152e-01,   9.98840332e-02],
                        [  1.07391357e-01,   1.01257324e-01],
                        [  1.08947754e-01,   1.01562500e-01],
                        [  1.01654053e-01,   9.35363770e-02],
                        [  8.34350586e-02,   7.50732422e-02],
                        [  6.01196289e-02,   5.20324707e-02],
                        [  4.01916504e-02,   3.28979492e-02],
                        [  2.75878906e-02,   2.16674805e-02],
                        [  2.03552246e-02,   1.61437988e-02],
                        [  1.72424316e-02,   1.51062012e-02],
                        [  2.14538574e-02,   2.16674805e-02],
                        [  3.30200195e-02,   3.56445312e-02],
                        [  4.41589355e-02,   4.91333008e-02],
                        [  4.94079590e-02,   5.65185547e-02],
                        [  5.33142090e-02,   6.21337891e-02],
                        [  6.07299805e-02,   7.06787109e-02],
                        [  6.72912598e-02,   7.77282715e-02],
                        [  6.52770996e-02,   7.54394531e-02],
                        [  5.22460938e-02,   6.12792969e-02],
                        [  3.10363770e-02,   3.82080078e-02],
                        [  8.30078125e-03,   1.29394531e-02],
                        [ -8.94165039e-03,  -7.32421875e-03],
                        [ -1.79138184e-02,  -1.96228027e-02],
                        [ -2.09960938e-02,  -2.60620117e-02],
                        [ -2.21862793e-02,  -3.03344727e-02],
                        [ -2.40783691e-02,  -3.47290039e-02],
                        [ -2.67944336e-02,  -3.92150879e-02],
                        [ -2.79846191e-02,  -4.11682129e-02],
                        [ -2.34680176e-02,  -3.63159180e-02],
                        [ -1.21459961e-02,  -2.35290527e-02],
                        [  1.55639648e-03,  -7.35473633e-03],
                        [  1.35803223e-02,   8.02612305e-03],
                        [  2.34985352e-02,   2.18505859e-02],
                        [  3.08532715e-02,   3.33862305e-02],
                        [  3.47595215e-02,   4.13208008e-02],
                        [  3.44543457e-02,   4.45556641e-02],
                        [  2.95410156e-02,   4.23583984e-02],
                        [  2.30712891e-02,   3.75061035e-02],
                        [  2.08129883e-02,   3.55834961e-02],
                        [  2.42614746e-02,   3.80859375e-02],
                        [  2.75268555e-02,   3.91235352e-02],
                        [  2.49938965e-02,   3.33251953e-02],
                        [  2.13317871e-02,   2.56347656e-02],
                        [  2.62451172e-02,   2.61535645e-02],
                        [  3.84521484e-02,   3.39355469e-02],
                        [  4.66308594e-02,   3.81774902e-02],
                        [  4.58374023e-02,   3.42407227e-02],
                        [  4.05883789e-02,   2.69165039e-02],
                        [  3.53088379e-02,   2.08129883e-02],
                        [  3.05480957e-02,   1.66015625e-02],
                        [  2.47802734e-02,   1.26342773e-02],
                        [  1.60522461e-02,   6.74438477e-03],
                        [  5.43212891e-03,  -2.13623047e-04],
                        [ -2.65502930e-03,  -4.24194336e-03],
                        [ -6.71386719e-03,  -4.27246094e-03],
                        [ -1.07116699e-02,  -4.60815430e-03],
                        [ -1.77917480e-02,  -8.66699219e-03],
                        [ -2.61840820e-02,  -1.50756836e-02],
                        [ -3.28369141e-02,  -2.08740234e-02],
                        [ -3.58886719e-02,  -2.41699219e-02],
                        [ -3.45764160e-02,  -2.42004395e-02],
                        [ -2.97546387e-02,  -2.16064453e-02],
                        [ -2.38342285e-02,  -1.85241699e-02],
                        [ -2.00805664e-02,  -1.78833008e-02],
                        [ -2.06298828e-02,  -2.15454102e-02],
                        [ -2.52380371e-02,  -2.89001465e-02],
                        [ -3.10058594e-02,  -3.68347168e-02],
                        [ -3.29589844e-02,  -4.02221680e-02],
                        [ -2.74047852e-02,  -3.52478027e-02],
                        [ -1.56250000e-02,  -2.31933594e-02],
                        [ -2.62451172e-03,  -9.27734375e-03],
                        [  5.00488281e-03,  -1.83105469e-04],
                        [  2.74658203e-03,  -6.40869141e-04],
                        [ -6.34765625e-03,  -7.87353516e-03],
                        [ -1.32446289e-02,  -1.30920410e-02],
                        [ -1.33666992e-02,  -1.18408203e-02],
                        [ -1.05590820e-02,  -8.08715820e-03],
                        [ -9.39941406e-03,  -6.50024414e-03],
                        [ -8.97216797e-03,  -6.13403320e-03],
                        [ -6.10351562e-03,  -3.66210938e-03],
                        [ -7.62939453e-04,   1.00708008e-03],
                        [  5.98144531e-03,   6.98852539e-03],
                        [  1.36108398e-02,   1.39465332e-02],
                        [  1.88903809e-02,   1.87683105e-02],
                        [  1.83105469e-02,   1.80358887e-02],
                        [  1.31530762e-02,   1.30615234e-02],
                        [  6.92749023e-03,   7.35473633e-03],
                        [  1.00708008e-03,   2.13623047e-03],
                        [ -3.84521484e-03,  -1.92260742e-03],
                        [ -4.82177734e-03,  -2.13623047e-03],
                        [ -7.01904297e-04,   2.53295898e-03],
                        [  5.37109375e-03,   8.75854492e-03],
                        [  1.21154785e-02,   1.52282715e-02],
                        [  2.32543945e-02,   2.55432129e-02],
                        [  4.08325195e-02,   4.19006348e-02],
                        [  6.27746582e-02,   6.22253418e-02],
                        [  8.58459473e-02,   8.34655762e-02],
                        [  1.07360840e-01,   1.03179932e-01],
                        [  1.25122070e-01,   1.19415283e-01],
                        [  1.35742188e-01,   1.28906250e-01],
                        [  1.31927490e-01,   1.24633789e-01],
                        [  1.02783203e-01,   9.57641602e-02],
                        [  3.85131836e-02,   3.24707031e-02],
                        [ -6.00585938e-02,  -6.44226074e-02],
                        [ -1.75384521e-01,  -1.77429199e-01],
                        [ -2.79144287e-01,  -2.78564453e-01],
                        [ -3.42407227e-01,  -3.39172363e-01],
                        [ -3.48114014e-01,  -3.42346191e-01],
                        [ -3.07586670e-01,  -2.99774170e-01],
                        [ -2.56835938e-01,  -2.47741699e-01],
                        [ -2.22869873e-01,  -2.13287354e-01],
                        [ -1.99188232e-01,  -1.90002441e-01],
                        [ -1.62811279e-01,  -1.55029297e-01],
                        [ -1.04492188e-01,  -9.89074707e-02],
                        [ -3.31115723e-02,  -3.02124023e-02],
                        [  3.58581543e-02,   3.57360840e-02],
                        [  8.66394043e-02,   8.34655762e-02],
                        [  1.11236572e-01,   1.05346680e-01],
                        [  1.17248535e-01,   1.09252930e-01],
                        [  1.18957520e-01,   1.09619141e-01],
                        [  1.22650146e-01,   1.12854004e-01],
                        [  1.25488281e-01,   1.16241455e-01],
                        [  1.22314453e-01,   1.14440918e-01],
                        [  1.10015869e-01,   1.04217529e-01],
                        [  8.98437500e-02,   8.66699219e-02],
                        [  6.74438477e-02,   6.70776367e-02],
                        [  4.78210449e-02,   5.01708984e-02],
                        [  3.03039551e-02,   3.50341797e-02],
                        [  1.34582520e-02,   2.00195312e-02],
                        [  2.80761719e-03,   1.04675293e-02],
                        [  5.40161133e-03,   1.33361816e-02],
                        [  1.99279785e-02,   2.73742676e-02],
                        [  3.89404297e-02,   4.52880859e-02],
                        [  5.74951172e-02,   6.21643066e-02],
                        [  7.40356445e-02,   7.67517090e-02],
                        [  8.51745605e-02,   8.58764648e-02],
                        [  8.46557617e-02,   8.34655762e-02],
                        [  6.88476562e-02,   6.60400391e-02],
                        [  4.07409668e-02,   3.68041992e-02],
                        [  8.94165039e-03,   4.39453125e-03],
                        [ -1.63879395e-02,  -2.10571289e-02],
                        [ -2.96325684e-02,  -3.39355469e-02],
                        [ -3.37219238e-02,  -3.72924805e-02],
                        [ -3.68347168e-02,  -3.94592285e-02],
                        [ -4.40063477e-02,  -4.56237793e-02],
                        [ -5.26733398e-02,  -5.33447266e-02],
                        [ -5.70373535e-02,  -5.69458008e-02],
                        [ -5.47485352e-02,  -5.41076660e-02],
                        [ -4.56237793e-02,  -4.47387695e-02],
                        [ -2.93884277e-02,  -2.84423828e-02],
                        [ -8.75854492e-03,  -7.96508789e-03],
                        [  9.39941406e-03,   9.91821289e-03],
                        [  2.15148926e-02,   2.18200684e-02],
                        [  3.19213867e-02,   3.20739746e-02],
                        [  4.39758301e-02,   4.41589355e-02],
                        [  5.33752441e-02,   5.37414551e-02],
                        [  5.62438965e-02,   5.70068359e-02],
                        [  5.63964844e-02,   5.76782227e-02],
                        [  5.66711426e-02,   5.85021973e-02],
                        [  5.32531738e-02,   5.55725098e-02],
                        [  4.34875488e-02,   4.62036133e-02],
                        [  3.19824219e-02,   3.48205566e-02],
                        [  2.48718262e-02,   2.74963379e-02],
                        [  2.38952637e-02,   2.59704590e-02],
                        [  2.71606445e-02,   2.83508301e-02],
                        [  3.07006836e-02,   3.07312012e-02],
                        [  2.92358398e-02,   2.79541016e-02],
                        [  2.07519531e-02,   1.81884766e-02],
                        [  9.24682617e-03,   5.49316406e-03],
                        [  7.62939453e-04,  -3.87573242e-03],
                        [ -1.25122070e-03,  -6.28662109e-03],
                        [  2.22778320e-03,  -2.77709961e-03],
                        [  6.68334961e-03,   2.22778320e-03],
                        [  8.30078125e-03,   4.91333008e-03],
                        [  5.18798828e-03,   3.23486328e-03],
                        [ -2.89916992e-03,  -3.17382812e-03],
                        [ -1.25122070e-02,  -1.10168457e-02],
                        [ -1.91345215e-02,  -1.59912109e-02],
                        [ -2.30102539e-02,  -1.84936523e-02],
                        [ -2.76184082e-02,  -2.21862793e-02],
                        [ -3.45764160e-02,  -2.87780762e-02],
                        [ -4.23889160e-02,  -3.68347168e-02],
                        [ -4.83398438e-02,  -4.35791016e-02],
                        [ -5.06896973e-02,  -4.71801758e-02],
                        [ -4.87060547e-02,  -4.68139648e-02],
                        [ -4.12902832e-02,  -4.11071777e-02],
                        [ -2.76794434e-02,  -2.92358398e-02],
                        [ -1.15966797e-02,  -1.46484375e-02],
                        [ -1.15966797e-03,  -5.34057617e-03],
                        [ -8.85009766e-04,  -5.70678711e-03],
                        [ -5.37109375e-03,  -1.02539062e-02],
                        [ -6.95800781e-03,  -1.14135742e-02],
                        [ -6.31713867e-03,  -9.91821289e-03],
                        [ -7.32421875e-03,  -9.70458984e-03],
                        [ -7.90405273e-03,  -8.91113281e-03],
                        [ -4.33349609e-03,  -3.93676758e-03],
                        [  8.23974609e-04,   2.41088867e-03],
                        [  1.80053711e-03,   4.30297852e-03],
                        [ -1.40380859e-03,   1.64794922e-03],
                        [ -2.77709961e-03,   3.66210938e-04],
                        [  9.76562500e-04,   3.81469727e-03],
                        [  5.46264648e-03,   7.59887695e-03],
                        [  4.02832031e-03,   5.31005859e-03],
                        [ -2.86865234e-03,  -2.53295898e-03],
                        [ -8.23974609e-03,  -8.81958008e-03],
                        [ -7.93457031e-03,  -9.21630859e-03],
                        [ -4.91333008e-03,  -6.62231445e-03],
                        [ -2.65502930e-03,  -4.45556641e-03],
                        [ -5.79833984e-04,  -2.13623047e-03],
                        [  2.68554688e-03,   1.67846680e-03],
                        [  6.74438477e-03,   6.46972656e-03],
                        [  1.19323730e-02,   1.24816895e-02],
                        [  1.95617676e-02,   2.09045410e-02],
                        [  3.01208496e-02,   3.20739746e-02],
                        [  4.41284180e-02,   4.63562012e-02],
                        [  6.30493164e-02,   6.52770996e-02],
                        [  8.68835449e-02,   8.87451172e-02],
                        [  1.11053467e-01,   1.12182617e-01],
                        [  1.28021240e-01,   1.28173828e-01],
                        [  1.31652832e-01,   1.30737305e-01],
                        [  1.18255615e-01,   1.16333008e-01],
                        [  8.38623047e-02,   8.10241699e-02],
                        [  2.40478516e-02,   2.06298828e-02],
                        [ -6.14624023e-02,  -6.51245117e-02],
                        [ -1.62719727e-01,  -1.66168213e-01],
                        [ -2.56988525e-01,  -2.59826660e-01],
                        [ -3.16864014e-01,  -3.18695068e-01],
                        [ -3.27331543e-01,  -3.27941895e-01],
                        [ -2.96630859e-01,  -2.95928955e-01],
                        [ -2.49877930e-01,  -2.47894287e-01],
                        [ -2.10693359e-01,  -2.07580566e-01],
                        [ -1.85089111e-01,  -1.81213379e-01],
                        [ -1.58874512e-01,  -1.54663086e-01],
                        [ -1.13891602e-01,  -1.09741211e-01],
                        [ -4.92248535e-02,  -4.56237793e-02],
                        [  1.73950195e-02,   2.01110840e-02],
                        [  7.03430176e-02,   7.18994141e-02],
                        [  1.06536865e-01,   1.06811523e-01],
                        [  1.26800537e-01,   1.25854492e-01],
                        [  1.31286621e-01,   1.29241943e-01],
                        [  1.25000000e-01,   1.22161865e-01],
                        [  1.16790771e-01,   1.13525391e-01],
                        [  1.09771729e-01,   1.06475830e-01],
                        [  9.91821289e-02,   9.61914062e-02],
                        [  8.18176270e-02,   7.94372559e-02],
                        [  6.23168945e-02,   6.06994629e-02],
                        [  4.67834473e-02,   4.60205078e-02],
                        [  3.51562500e-02,   3.51867676e-02],
                        [  2.42919922e-02,   2.49328613e-02],
                        [  1.49841309e-02,   1.60217285e-02],
                        [  1.25732422e-02,   1.37023926e-02],
                        [  2.09655762e-02,   2.19726562e-02],
                        [  3.92150879e-02,   3.98864746e-02],
                        [  6.17980957e-02,   6.20422363e-02],
                        [  8.02612305e-02,   8.00781250e-02],
                        [  8.59680176e-02,   8.54797363e-02],
                        [  7.55004883e-02,   7.49206543e-02],
                        [  5.29785156e-02,   5.25817871e-02],
                        [  2.59399414e-02,   2.60009766e-02],
                        [  1.19018555e-03,   1.95312500e-03],
                        [ -1.48010254e-02,  -1.32141113e-02],
                        [ -1.80969238e-02,  -1.56555176e-02],
                        [ -1.34887695e-02,  -1.02844238e-02],
                        [ -1.27258301e-02,  -9.06372070e-03],
                        [ -2.21862793e-02,  -1.84631348e-02],
                        [ -3.56445312e-02,  -3.23486328e-02],
                        [ -4.29077148e-02,  -4.05273438e-02],
                        [ -4.07409668e-02,  -3.97949219e-02],
                        [ -3.15856934e-02,  -3.23791504e-02],
                        [ -1.71203613e-02,  -1.98669434e-02],
                        [ -3.05175781e-04,  -4.97436523e-03],
                        [  1.40991211e-02,   7.78198242e-03],
                        [  2.57873535e-02,   1.83410645e-02],
                        [  3.69262695e-02,   2.90222168e-02],
                        [  4.50439453e-02,   3.74755859e-02],
                        [  4.68139648e-02,   4.04357910e-02],
                        [  4.49523926e-02,   4.05883789e-02],
                        [  4.40979004e-02,   4.23278809e-02],
                        [  4.45251465e-02,   4.58068848e-02],
                        [  4.39147949e-02,   4.83093262e-02],
                        [  4.14123535e-02,   4.87365723e-02],
                        [  3.69873047e-02,   4.66003418e-02],
                        [  2.97851562e-02,   4.09240723e-02],
                        [  2.19116211e-02,   3.35083008e-02],
                        [  1.76696777e-02,   2.85339355e-02],
                        [  1.67236328e-02,   2.57568359e-02],
                        [  1.49536133e-02,   2.11486816e-02],
                        [  1.22985840e-02,   1.49536133e-02],
                        [  1.36108398e-02,   1.22985840e-02],
                        [  2.05993652e-02,   1.53198242e-02],
                        [  2.81372070e-02,   1.92871094e-02],
                        [  3.03955078e-02,   1.87988281e-02],
                        [  2.69470215e-02,   1.36108398e-02],
                        [  2.03552246e-02,   6.62231445e-03],
                        [  1.21154785e-02,  -7.01904297e-04],
                        [  2.25830078e-03,  -8.39233398e-03],
                        [ -7.78198242e-03,  -1.51977539e-02],
                        [ -1.52587891e-02,  -1.86767578e-02],
                        [ -2.14538574e-02,  -2.05078125e-02],
                        [ -3.03039551e-02,  -2.51159668e-02],
                        [ -3.90014648e-02,  -3.00598145e-02],
                        [ -4.06799316e-02,  -2.89001465e-02],
                        [ -3.70788574e-02,  -2.35900879e-02],
                        [ -3.57360840e-02,  -2.18811035e-02],
                        [ -3.66210938e-02,  -2.37121582e-02],
                        [ -3.29284668e-02,  -2.21557617e-02],
                        [ -2.48718262e-02,  -1.72729492e-02],
                        [ -2.04467773e-02,  -1.66931152e-02],
                        [ -2.08435059e-02,  -2.11181641e-02],
                        [ -1.98364258e-02,  -2.40478516e-02],
                        [ -1.69067383e-02,  -2.45056152e-02],
                        [ -1.52587891e-02,  -2.53295898e-02],
                        [ -1.30310059e-02,  -2.45971680e-02],
                        [ -8.51440430e-03,  -2.03857422e-02],
                        [ -4.66918945e-03,  -1.56860352e-02],
                        [ -3.38745117e-03,  -1.25427246e-02],
                        [ -2.38037109e-03,  -8.97216797e-03],
                        [  8.23974609e-04,  -2.68554688e-03],
                        [  5.58471680e-03,   5.27954102e-03],
                        [  1.01318359e-02,   1.27868652e-02],
                        [  1.40686035e-02,   1.91955566e-02],
                        [  1.68151855e-02,   2.37426758e-02],
                        [  1.62353516e-02,   2.41699219e-02],
                        [  1.16882324e-02,   1.97143555e-02],
                        [  5.95092773e-03,   1.33361816e-02],
                        [  1.70898438e-03,   7.78198242e-03],
                        [ -2.25830078e-03,   2.13623047e-03],
                        [ -6.46972656e-03,  -4.02832031e-03],
                        [ -7.62939453e-03,  -7.04956055e-03],
                        [ -4.36401367e-03,  -5.43212891e-03],
                        [ -1.31225586e-03,  -3.63159180e-03],
                        [ -5.18798828e-04,  -3.66210938e-03],
                        [  4.66918945e-03,   1.28173828e-03],
                        [  2.07519531e-02,   1.75170898e-02],
                        [  4.23278809e-02,   3.95812988e-02],
                        [  5.89294434e-02,   5.68847656e-02],
                        [  7.13500977e-02,   7.00988770e-02],
                        [  8.88061523e-02,   8.81958008e-02],
                        [  1.11968994e-01,   1.11816406e-01],
                        [  1.30920410e-01,   1.30920410e-01],
                        [  1.35284424e-01,   1.35192871e-01],
                        [  1.16912842e-01,   1.16455078e-01],
                        [  6.63452148e-02,   6.53686523e-02],
                        [ -2.16064453e-02,  -2.31018066e-02],
                        [ -1.35467529e-01,  -1.37481689e-01],
                        [ -2.46002197e-01,  -2.48260498e-01],
                        [ -3.19213867e-01,  -3.21411133e-01],
                        [ -3.33496094e-01,  -3.35266113e-01],
                        [ -2.94464111e-01,  -2.95440674e-01],
                        [ -2.36114502e-01,  -2.35961914e-01],
                        [ -1.96624756e-01,  -1.95129395e-01],
                        [ -1.85516357e-01,  -1.82647705e-01],
                        [ -1.77825928e-01,  -1.73614502e-01],
                        [ -1.44409180e-01,  -1.39160156e-01],
                        [ -8.32519531e-02,  -7.73925781e-02],
                        [ -1.38549805e-02,  -7.93457031e-03],
                        [  4.71496582e-02,   5.26123047e-02],
                        [  9.26818848e-02,   9.70458984e-02],
                        [  1.19750977e-01,   1.22528076e-01],
                        [  1.28692627e-01,   1.29516602e-01],
                        [  1.23840332e-01,   1.22467041e-01],
                        [  1.12854004e-01,   1.09283447e-01],
                        [  1.04003906e-01,   9.85107422e-02],
                        [  9.95788574e-02,   9.25292969e-02],
                        [  9.43603516e-02,   8.63037109e-02],
                        [  8.39233398e-02,   7.55920410e-02],
                        [  7.11059570e-02,   6.32324219e-02],
                        [  5.96923828e-02,   5.29479980e-02],
                        [  4.72717285e-02,   4.22668457e-02],
                        [  3.24401855e-02,   2.97241211e-02],
                        [  2.23999023e-02,   2.21557617e-02],
                        [  2.46582031e-02,   2.69470215e-02],
                        [  3.83911133e-02,   4.30908203e-02],
                        [  5.62133789e-02,   6.29272461e-02],
                        [  6.82983398e-02,   7.64770508e-02],
                        [  6.60400391e-02,   7.50427246e-02],
                        [  4.70275879e-02,   5.61218262e-02],
                        [  1.70593262e-02,   2.55126953e-02],
                        [ -1.22680664e-02,  -5.09643555e-03],
                        [ -2.95410156e-02,  -2.42309570e-02],
                        [ -3.02124023e-02,  -2.71606445e-02],
                        [ -1.98364258e-02,  -1.92871094e-02],
                        [ -1.00402832e-02,  -1.19934082e-02],
                        [ -8.97216797e-03,  -1.32751465e-02],
                        [ -1.73339844e-02,  -2.36511230e-02],
                        [ -3.13720703e-02,  -3.92761230e-02],
                        [ -4.45251465e-02,  -5.33752441e-02],
                        [ -4.87976074e-02,  -5.80139160e-02],
                        [ -3.94592285e-02,  -4.83703613e-02],
                        [ -1.79138184e-02,  -2.58789062e-02],
                        [  7.72094727e-03,   1.28173828e-03],
                        [  2.67639160e-02,   2.23388672e-02],
                        [  3.45764160e-02,   3.24707031e-02],
                        [  3.46679688e-02,   3.50952148e-02],
                        [  3.31115723e-02,   3.60412598e-02],
                        [  3.29589844e-02,   3.82690430e-02],
                        [  3.39050293e-02,   4.12292480e-02],
                        [  3.52172852e-02,   4.40979004e-02],
                        [  3.79333496e-02,   4.77600098e-02],
                        [  4.15344238e-02,   5.16357422e-02],
                        [  4.25415039e-02,   5.21240234e-02],
                        [  3.90014648e-02,   4.73937988e-02],
                        [  3.28369141e-02,   3.93371582e-02],
                        [  2.70996094e-02,   3.10974121e-02],
                        [  2.43835449e-02,   2.55737305e-02],
                        [  2.65808105e-02,   2.47497559e-02],
                        [  3.18603516e-02,   2.70080566e-02],
                        [  3.55224609e-02,   2.79541016e-02],
                        [  3.64990234e-02,   2.67639160e-02],
                        [  3.73535156e-02,   2.61230469e-02],
                        [  3.64074707e-02,   2.45361328e-02],
                        [  2.88391113e-02,   1.73034668e-02],
                        [  1.55944824e-02,   5.37109375e-03],
                        [  2.34985352e-03,  -5.70678711e-03],
                        [ -8.51440430e-03,  -1.36718750e-02],
                        [ -1.86767578e-02,  -2.03857422e-02],
                        [ -2.93273926e-02,  -2.73742676e-02],
                        [ -4.04663086e-02,  -3.49731445e-02],
                        [ -5.09033203e-02,  -4.22363281e-02],
                        [ -5.71289062e-02,  -4.59594727e-02],
                        [ -5.63354492e-02,  -4.36096191e-02],
                        [ -4.96826172e-02,  -3.64990234e-02],
                        [ -4.04968262e-02,  -2.79541016e-02],
                        [ -3.24401855e-02,  -2.16979980e-02],
                        [ -2.84729004e-02,  -2.04467773e-02],
                        [ -2.67639160e-02,  -2.21557617e-02],
                        [ -2.30407715e-02,  -2.23083496e-02],
                        [ -1.77612305e-02,  -2.09350586e-02],
                        [ -1.40686035e-02,  -2.09045410e-02],
                        [ -1.09252930e-02,  -2.07214355e-02],
                        [ -5.18798828e-03,  -1.71508789e-02],
                        [  1.03759766e-03,  -1.19628906e-02],
                        [  3.14331055e-03,  -9.73510742e-03],
                        [  1.40380859e-03,  -1.01928711e-02],
                        [ -8.23974609e-04,  -1.01623535e-02],
                        [ -5.03540039e-03,  -1.12915039e-02],
                        [ -1.42517090e-02,  -1.69372559e-02],
                        [ -2.44140625e-02,  -2.33764648e-02],
                        [ -2.66113281e-02,  -2.20947266e-02],
                        [ -1.77917480e-02,  -1.02844238e-02],
                        [ -3.99780273e-03,   5.76782227e-03],
                        [  7.65991211e-03,   1.86767578e-02],
                        [  1.44348145e-02,   2.56652832e-02],
                        [  1.42211914e-02,   2.46887207e-02],
                        [  5.98144531e-03,   1.47399902e-02],
                        [ -4.48608398e-03,   1.89208984e-03],
                        [ -8.11767578e-03,  -4.54711914e-03],
                        [ -4.11987305e-03,  -3.50952148e-03],
                        [  3.96728516e-04,  -1.89208984e-03],
                        [  2.65502930e-03,  -2.04467773e-03],
                        [  7.93457031e-03,   1.37329102e-03],
                        [  1.80053711e-02,   1.03149414e-02],
                        [  2.67944336e-02,   1.87683105e-02],
                        [  3.11584473e-02,   2.35595703e-02],
                        [  3.58276367e-02,   2.92663574e-02],
                        [  4.50744629e-02,   4.00390625e-02],
                        [  5.93872070e-02,   5.61523438e-02],
                        [  7.90710449e-02,   7.77282715e-02],
                        [  1.03271484e-01,   1.03668213e-01],
                        [  1.24847412e-01,   1.26739502e-01],
                        [  1.30950928e-01,   1.33941650e-01],
                        [  1.10504150e-01,   1.14135742e-01],
                        [  6.02416992e-02,   6.41174316e-02],
                        [ -1.88598633e-02,  -1.51672363e-02],
                        [ -1.22772217e-01,  -1.19567871e-01],
                        [ -2.32940674e-01,  -2.30377197e-01],
                        [ -3.13629150e-01,  -3.11767578e-01],
                        [ -3.36456299e-01,  -3.35266113e-01],
                        [ -3.06427002e-01,  -3.05725098e-01],
                        [ -2.54852295e-01,  -2.54455566e-01],
                        [ -2.10296631e-01,  -2.10021973e-01],
                        [ -1.80480957e-01,  -1.80206299e-01],
                        [ -1.57470703e-01,  -1.57043457e-01],
                        [ -1.29760742e-01,  -1.29180908e-01],
                        [ -8.95996094e-02,  -8.89587402e-02],
                        [ -3.72314453e-02,  -3.66821289e-02],
                        [  1.87072754e-02,   1.89514160e-02],
                        [  6.75659180e-02,   6.72912598e-02],
                        [  1.03698730e-01,   1.02722168e-01],
                        [  1.26556396e-01,   1.24755859e-01],
                        [  1.37298584e-01,   1.34613037e-01],
                        [  1.38061523e-01,   1.34582520e-01],
                        [  1.32690430e-01,   1.28631592e-01],
                        [  1.23809814e-01,   1.19476318e-01],
                        [  1.09710693e-01,   1.05499268e-01],
                        [  8.95996094e-02,   8.59680176e-02],
                        [  6.96411133e-02,   6.70166016e-02],
                        [  5.73425293e-02,   5.60913086e-02],
                        [  5.33142090e-02,   5.37414551e-02],
                        [  5.38635254e-02,   5.60913086e-02],
                        [  5.66406250e-02,   6.05773926e-02],
                        [  5.96923828e-02,   6.51550293e-02],
                        [  5.90209961e-02,   6.55517578e-02],
                        [  5.14221191e-02,   5.84716797e-02],
                        [  3.77502441e-02,   4.47082520e-02],
                        [  2.05383301e-02,   2.67639160e-02],
                        [  1.40380859e-03,   6.22558594e-03],
                        [ -1.64184570e-02,  -1.34582520e-02],
                        [ -2.62756348e-02,  -2.55432129e-02],
                        [ -2.41088867e-02,  -2.58178711e-02],
                        [ -1.40380859e-02,  -1.80664062e-02],
                        [ -3.75366211e-03,  -9.76562500e-03],
                        [  2.44140625e-03,  -5.09643555e-03],
                        [  3.23486328e-03,  -5.18798828e-03],
                        [ -1.15966797e-03,  -9.70458984e-03],
                        [ -7.62939453e-03,  -1.55029297e-02],
                        [ -1.22680664e-02,  -1.87988281e-02],
                        [ -1.34582520e-02,  -1.79748535e-02],
                        [ -1.03454590e-02,  -1.24511719e-02],
                        [ -2.62451172e-03,  -2.13623047e-03],
                        [  7.11059570e-03,   1.01318359e-02],
                        [  1.48925781e-02,   2.02636719e-02],
                        [  1.98059082e-02,   2.70080566e-02],
                        [  2.29187012e-02,   3.12805176e-02],
                        [  2.38647461e-02,   3.26538086e-02],
                        [  2.27661133e-02,   3.12500000e-02],
                        [  2.27355957e-02,   3.01513672e-02],
                        [  2.52380371e-02,   3.09448242e-02],
                        [  2.84118652e-02,   3.19519043e-02],
                        [  3.23486328e-02,   3.34472656e-02],
                        [  3.78723145e-02,   3.64379883e-02],
                        [  4.22668457e-02,   3.84826660e-02],
                        [  4.27856445e-02,   3.70483398e-02],
                        [  4.10461426e-02,   3.38439941e-02],
                        [  3.97644043e-02,   3.17382812e-02],
                        [  3.88793945e-02,   3.07617188e-02],
                        [  3.68957520e-02,   2.93579102e-02],
                        [  3.38439941e-02,   2.74963379e-02],
                        [  3.09448242e-02,   2.62756348e-02],
                        [  2.91442871e-02,   2.65197754e-02],
                        [  2.86865234e-02,   2.82897949e-02],
                        [  2.87475586e-02,   3.05480957e-02],
                        [  2.63061523e-02,   3.00598145e-02],
                        [  1.86462402e-02,   2.39868164e-02],
                        [  8.08715820e-03,   1.45263672e-02],
                        [ -7.32421875e-04,   6.28662109e-03],
                        [ -8.60595703e-03,  -1.64794922e-03],
                        [ -1.95922852e-02,  -1.32141113e-02],
                        [ -3.14025879e-02,  -2.61535645e-02],
                        [ -3.76892090e-02,  -3.39355469e-02],
                        [ -3.69873047e-02,  -3.49426270e-02],
                        [ -3.34472656e-02,  -3.32641602e-02],
                        [ -3.06091309e-02,  -3.22265625e-02],
                        [ -2.77404785e-02,  -3.10058594e-02],
                        [ -2.24609375e-02,  -2.70080566e-02],
                        [ -1.48620605e-02,  -2.03247070e-02],
                        [ -8.33129883e-03,  -1.42211914e-02],
                        [ -6.77490234e-03,  -1.26037598e-02],
                        [ -1.11694336e-02,  -1.64794922e-02],
                        [ -1.81884766e-02,  -2.26135254e-02],
                        [ -2.36816406e-02,  -2.68554688e-02],
                        [ -2.61535645e-02,  -2.78320312e-02],
                        [ -2.63061523e-02,  -2.64587402e-02],
                        [ -2.60925293e-02,  -2.47497559e-02],
                        [ -2.63061523e-02,  -2.35900879e-02],
                        [ -2.51464844e-02,  -2.13317871e-02],
                        [ -2.14843750e-02,  -1.69677734e-02],
                        [ -1.53808594e-02,  -1.04980469e-02],
                        [ -6.68334961e-03,  -1.83105469e-03],
                        [  2.59399414e-03,   6.98852539e-03],
                        [  9.21630859e-03,   1.28173828e-02],
                        [  1.26953125e-02,   1.52893066e-02],
                        [  1.40075684e-02,   1.53808594e-02],
                        [  1.36413574e-02,   1.36718750e-02],
                        [  1.24206543e-02,   1.12304688e-02],
                        [  1.10778809e-02,   8.78906250e-03],
                        [  9.49096680e-03,   6.34765625e-03],
                        [  7.65991211e-03,   3.93676758e-03],
                        [  6.59179688e-03,   2.65502930e-03],
                        [  7.62939453e-03,   3.78417969e-03],
                        [  9.70458984e-03,   6.25610352e-03],
                        [  1.18408203e-02,   9.09423828e-03],
                        [  1.73645020e-02,   1.55334473e-02],
                        [  2.99072266e-02,   2.90527344e-02],
                        [  4.72717285e-02,   4.74243164e-02],
                        [  6.42089844e-02,   6.53076172e-02],
                        [  7.92236328e-02,   8.11157227e-02],
                        [  9.50622559e-02,   9.75341797e-02],
                        [  1.12945557e-01,   1.15753174e-01],
                        [  1.27471924e-01,   1.30371094e-01],
                        [  1.28692627e-01,   1.31378174e-01],
                        [  1.07391357e-01,   1.09680176e-01],
                        [  5.72814941e-02,   5.90209961e-02],
                        [ -2.51464844e-02,  -2.40478516e-02],
                        [ -1.34002686e-01,  -1.33636475e-01],
                        [ -2.44995117e-01,  -2.45269775e-01],
                        [ -3.21014404e-01,  -3.21838379e-01],
                        [ -3.35998535e-01,  -3.37249756e-01],
                        [ -2.95440674e-01,  -2.96966553e-01],
                        [ -2.34313965e-01,  -2.35961914e-01],
                        [ -1.90734863e-01,  -1.92321777e-01],
                        [ -1.76849365e-01,  -1.78283691e-01],
                        [ -1.74072266e-01,  -1.75262451e-01],
                        [ -1.54724121e-01,  -1.55578613e-01],
                        [ -1.08001709e-01,  -1.08520508e-01],
                        [ -4.57153320e-02,  -4.59594727e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  6.81457520e-02,   6.82983398e-02],
                        [  1.10198975e-01,   1.10473633e-01],
                        [  1.37817383e-01,   1.38122559e-01],
                        [  1.49017334e-01,   1.49322510e-01],
                        [  1.45935059e-01,   1.46240234e-01],
                        [  1.33148193e-01,   1.33453369e-01],
                        [  1.16363525e-01,   1.16699219e-01],
                        [  1.00402832e-01,   1.00830078e-01],
                        [  8.63952637e-02,   8.69140625e-02],
                        [  7.32116699e-02,   7.38525391e-02],
                        [  6.25610352e-02,   6.33544922e-02],
                        [  5.84106445e-02,   5.93261719e-02],
                        [  5.96923828e-02,   6.06689453e-02],
                        [  6.00891113e-02,   6.10351562e-02],
                        [  5.54199219e-02,   5.62744141e-02],
                        [  4.68750000e-02,   4.74853516e-02],
                        [  3.72924805e-02,   3.75671387e-02],
                        [  2.66723633e-02,   2.65502930e-02],
                        [  1.30310059e-02,   1.24206543e-02],
                        [ -1.67846680e-03,  -2.77709961e-03],
                        [ -9.79614258e-03,  -1.13525391e-02],
                        [ -6.07299805e-03,  -7.96508789e-03],
                        [  4.45556641e-03,   2.34985352e-03],
                        [  1.08947754e-02,   8.75854492e-03],
                        [  7.93457031e-03,   6.01196289e-03],
                        [ -1.98364258e-03,  -3.50952148e-03],
                        [ -1.58691406e-02,  -1.68151855e-02],
                        [ -3.11584473e-02,  -3.13415527e-02],
                        [ -4.18701172e-02,  -4.12597656e-02],
                        [ -4.09240723e-02,  -3.94897461e-02],
                        [ -2.66723633e-02,  -2.45361328e-02],
                        [ -5.12695312e-03,  -2.44140625e-03],
                        [  1.50756836e-02,   1.81274414e-02],
                        [  2.83203125e-02,   3.13720703e-02],
                        [  3.17382812e-02,   3.45764160e-02],
                        [  2.61230469e-02,   2.84118652e-02],
                        [  1.80358887e-02,   1.95312500e-02],
                        [  1.55944824e-02,   1.61132812e-02],
                        [  2.05688477e-02,   2.00195312e-02],
                        [  2.78320312e-02,   2.62145996e-02],
                        [  3.25317383e-02,   2.99682617e-02],
                        [  3.57666016e-02,   3.24707031e-02],
                        [  3.98559570e-02,   3.61328125e-02],
                        [  4.23278809e-02,   3.85131836e-02],
                        [  4.00695801e-02,   3.65600586e-02],
                        [  3.50036621e-02,   3.21350098e-02],
                        [  3.15856934e-02,   2.96325684e-02],
                        [  3.18908691e-02,   3.10668945e-02],
                        [  3.46984863e-02,   3.51562500e-02],
                        [  3.70483398e-02,   3.87268066e-02],
                        [  3.57055664e-02,   3.85131836e-02],
                        [  2.95715332e-02,   3.31726074e-02],
                        [  2.18505859e-02,   2.60009766e-02],
                        [  1.60827637e-02,   2.03857422e-02],
                        [  1.01623535e-02,   1.41601562e-02],
                        [  1.43432617e-03,   4.73022461e-03],
                        [ -6.77490234e-03,  -4.45556641e-03],
                        [ -1.04980469e-02,  -9.42993164e-03],
                        [ -1.17797852e-02,  -1.20544434e-02],
                        [ -1.47705078e-02,  -1.63879395e-02],
                        [ -1.95007324e-02,  -2.23083496e-02],
                        [ -2.33459473e-02,  -2.70996094e-02],
                        [ -2.61840820e-02,  -3.04870605e-02],
                        [ -2.96630859e-02,  -3.41186523e-02],
                        [ -3.32336426e-02,  -3.74450684e-02],
                        [ -3.52172852e-02,  -3.87878418e-02],
                        [ -3.55834961e-02,  -3.81164551e-02],
                        [ -3.51257324e-02,  -3.64379883e-02],
                        [ -3.45764160e-02,  -3.45458984e-02],
                        [ -3.42407227e-02,  -3.28674316e-02],
                        [ -3.33862305e-02,  -3.07617188e-02],
                        [ -3.10668945e-02,  -2.74963379e-02],
                        [ -2.67944336e-02,  -2.26135254e-02],
                        [ -1.98059082e-02,  -1.54113770e-02],
                        [ -1.07116699e-02,  -6.50024414e-03],
                        [ -2.96020508e-03,   6.10351562e-04],
                        [  2.74658203e-04,   2.92968750e-03],
                        [ -7.62939453e-04,   7.32421875e-04],
                        [ -4.76074219e-03,  -4.54711914e-03],
                        [ -1.04064941e-02,  -1.15051270e-02],
                        [ -1.48620605e-02,  -1.70898438e-02],
                        [ -1.51672363e-02,  -1.83410645e-02],
                        [ -1.24511719e-02,  -1.62353516e-02],
                        [ -1.15966797e-02,  -1.56250000e-02],
                        [ -1.46179199e-02,  -1.84936523e-02],
                        [ -1.59606934e-02,  -1.93481445e-02],
                        [ -9.85717773e-03,  -1.24816895e-02],
                        [ -3.96728516e-04,  -1.98364258e-03],
                        [  3.75366211e-03,   3.29589844e-03],
                        [  2.28881836e-03,   2.99072266e-03],
                        [  2.62451172e-03,   4.33349609e-03],
                        [  7.81250000e-03,   1.03759766e-02],
                        [  1.33972168e-02,   1.65405273e-02],
                        [  1.62963867e-02,   1.96838379e-02],
                        [  1.93481445e-02,   2.27050781e-02],
                        [  2.39562988e-02,   2.69470215e-02],
                        [  2.76794434e-02,   2.99987793e-02],
                        [  3.12805176e-02,   3.28063965e-02],
                        [  3.99780273e-02,   4.05883789e-02],
                        [  5.72204590e-02,   5.69152832e-02],
                        [  8.33129883e-02,   8.21533203e-02],
                        [  1.14105225e-01,   1.12243652e-01],
                        [  1.38214111e-01,   1.35894775e-01],
                        [  1.41815186e-01,   1.39251709e-01],
                        [  1.17370605e-01,   1.14807129e-01],
                        [  6.28356934e-02,   6.05163574e-02],
                        [ -2.35900879e-02,  -2.54516602e-02],
                        [ -1.35650635e-01,  -1.36901855e-01],
                        [ -2.46856689e-01,  -2.47467041e-01],
                        [ -3.19824219e-01,  -3.19763184e-01],
                        [ -3.33648682e-01,  -3.33007812e-01],
                        [ -2.98217773e-01,  -2.97088623e-01],
                        [ -2.43682861e-01,  -2.42218018e-01],
                        [ -1.99401855e-01,  -1.97784424e-01],
                        [ -1.76086426e-01,  -1.74499512e-01],
                        [ -1.61529541e-01,  -1.60095215e-01],
                        [ -1.36291504e-01,  -1.35131836e-01],
                        [ -9.48486328e-02,  -9.40246582e-02],
                        [ -4.55322266e-02,  -4.51049805e-02],
                        [  5.49316406e-03,   5.55419922e-03],
                        [  5.70678711e-02,   5.68542480e-02],
                        [  1.02050781e-01,   1.01562500e-01],
                        [  1.29028320e-01,   1.28448486e-01],
                        [  1.36199951e-01,   1.35620117e-01],
                        [  1.32232666e-01,   1.31652832e-01],
                        [  1.25457764e-01,   1.25000000e-01],
                        [  1.18652344e-01,   1.18347168e-01],
                        [  1.09375000e-01,   1.09191895e-01],
                        [  9.41162109e-02,   9.40246582e-02],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  8.34655762e-02,   8.33740234e-02],
                        [  9.13085938e-02,   9.11254883e-02],
                        [  8.20922852e-02,   8.17871094e-02],
                        [  5.79833984e-02,   5.75256348e-02],
                        [  2.94799805e-02,   2.89306641e-02],
                        [  2.68554688e-03,   2.10571289e-03],
                        [ -1.99279785e-02,  -2.04772949e-02],
                        [ -3.48205566e-02,  -3.52783203e-02],
                        [ -3.81774902e-02,  -3.83911133e-02],
                        [ -2.98461914e-02,  -2.97546387e-02],
                        [ -1.55334473e-02,  -1.51367188e-02],
                        [ -4.18090820e-03,  -3.41796875e-03],
                        [ -1.43432617e-03,  -3.35693359e-04],
                        [ -5.46264648e-03,  -4.11987305e-03],
                        [ -9.30786133e-03,  -7.81250000e-03],
                        [ -9.00268555e-03,  -7.50732422e-03],
                        [ -7.20214844e-03,  -5.85937500e-03],
                        [ -6.34765625e-03,  -5.31005859e-03],
                        [ -2.47192383e-03,  -1.89208984e-03],
                        [  8.20922852e-03,   8.27026367e-03],
                        [  2.03247070e-02,   1.97753906e-02],
                        [  2.49023438e-02,   2.37426758e-02],
                        [  2.18811035e-02,   2.02331543e-02],
                        [  1.90734863e-02,   1.70288086e-02],
                        [  2.11486816e-02,   1.88903809e-02],
                        [  2.69775391e-02,   2.47192383e-02],
                        [  3.35388184e-02,   3.14941406e-02],
                        [  3.67126465e-02,   3.50952148e-02],
                        [  3.39660645e-02,   3.29589844e-02],
                        [  2.77099609e-02,   2.74353027e-02],
                        [  2.24609375e-02,   2.29797363e-02],
                        [  2.15759277e-02,   2.28881836e-02],
                        [  2.71301270e-02,   2.91137695e-02],
                        [  3.70178223e-02,   3.94897461e-02],
                        [  4.52270508e-02,   4.80651855e-02],
                        [  4.76684570e-02,   5.05371094e-02],
                        [  4.44030762e-02,   4.69970703e-02],
                        [  3.68347168e-02,   3.89709473e-02],
                        [  2.61230469e-02,   2.75573730e-02],
                        [  1.46484375e-02,   1.51977539e-02],
                        [  6.68334961e-03,   6.31713867e-03],
                        [  3.75366211e-03,   2.47192383e-03],
                        [  1.95312500e-03,  -1.52587891e-04],
                        [ -1.92260742e-03,  -4.66918945e-03],
                        [ -5.61523438e-03,  -8.72802734e-03],
                        [ -6.71386719e-03,  -9.91821289e-03],
                        [ -7.08007812e-03,  -1.01013184e-02],
                        [ -8.11767578e-03,  -1.06201172e-02],
                        [ -8.51440430e-03,  -1.02539062e-02],
                        [ -9.61303711e-03,  -1.04370117e-02],
                        [ -1.48925781e-02,  -1.47399902e-02],
                        [ -2.23388672e-02,  -2.11486816e-02],
                        [ -2.56347656e-02,  -2.35595703e-02],
                        [ -2.41699219e-02,  -2.14233398e-02],
                        [ -2.18811035e-02,  -1.86767578e-02],
                        [ -2.02026367e-02,  -1.68457031e-02],
                        [ -2.05383301e-02,  -1.73645020e-02],
                        [ -2.62451172e-02,  -2.35900879e-02],
                        [ -3.46679688e-02,  -3.27148438e-02],
                        [ -3.82080078e-02,  -3.71704102e-02],
                        [ -3.62243652e-02,  -3.61938477e-02],
                        [ -3.33251953e-02,  -3.43017578e-02],
                        [ -2.96936035e-02,  -3.15551758e-02],
                        [ -2.43225098e-02,  -2.69470215e-02],
                        [ -2.00195312e-02,  -2.31018066e-02],
                        [ -1.69372559e-02,  -2.01721191e-02],
                        [ -1.16271973e-02,  -1.47399902e-02],
                        [ -4.60815430e-03,  -7.29370117e-03],
                        [ -2.74658203e-04,  -2.25830078e-03],
                        [  1.83105469e-04,  -9.46044922e-04],
                        [ -8.54492188e-04,  -1.03759766e-03],
                        [ -2.86865234e-03,  -2.10571289e-03],
                        [ -6.50024414e-03,  -4.88281250e-03],
                        [ -9.27734375e-03,  -6.98852539e-03],
                        [ -8.02612305e-03,  -5.27954102e-03],
                        [ -3.02124023e-03,  -6.10351562e-05],
                        [  3.29589844e-03,   6.13403320e-03],
                        [  8.30078125e-03,   1.07727051e-02],
                        [  1.00708008e-02,   1.19323730e-02],
                        [  9.55200195e-03,   1.06811523e-02],
                        [  9.24682617e-03,   9.52148438e-03],
                        [  9.09423828e-03,   8.54492188e-03],
                        [  7.59887695e-03,   6.28662109e-03],
                        [  6.04248047e-03,   4.15039062e-03],
                        [  7.81250000e-03,   5.46264648e-03],
                        [  1.36413574e-02,   1.11389160e-02],
                        [  2.30712891e-02,   2.06604004e-02],
                        [  3.86352539e-02,   3.65295410e-02],
                        [  6.35986328e-02,   6.19506836e-02],
                        [  9.58251953e-02,   9.47875977e-02],
                        [  1.26678467e-01,   1.26312256e-01],
                        [  1.44989014e-01,   1.45294189e-01],
                        [  1.42272949e-01,   1.43218994e-01],
                        [  1.13677979e-01,   1.15142822e-01],
                        [  5.42602539e-02,   5.59997559e-02],
                        [ -3.86657715e-02,  -3.67736816e-02],
                        [ -1.54327393e-01,  -1.52435303e-01],
                        [ -2.64373779e-01,  -2.62725830e-01],
                        [ -3.34564209e-01,  -3.33282471e-01],
                        [ -3.44390869e-01,  -3.43505859e-01],
                        [ -3.01879883e-01,  -3.01513672e-01],
                        [ -2.40447998e-01,  -2.40570068e-01],
                        [ -1.94488525e-01,  -1.95068359e-01],
                        [ -1.73828125e-01,  -1.74713135e-01],
                        [ -1.62902832e-01,  -1.64062500e-01],
                        [ -1.42974854e-01,  -1.44256592e-01],
                        [ -1.07696533e-01,  -1.08917236e-01],
                        [ -6.00280762e-02,  -6.11267090e-02],
                        [ -3.72314453e-03,  -4.63867188e-03],
                        [  5.86242676e-02,   5.79833984e-02],
                        [  1.18347168e-01,   1.18011475e-01],
                        [  1.58233643e-01,   1.58172607e-01],
                        [  1.67480469e-01,   1.67633057e-01],
                        [  1.56005859e-01,   1.56372070e-01],
                        [  1.42303467e-01,   1.42791748e-01],
                        [  1.31774902e-01,   1.32324219e-01],
                        [  1.19140625e-01,   1.19689941e-01],
                        [  1.04461670e-01,   1.04980469e-01],
                        [  9.40246582e-02,   9.44519043e-02],
                        [  8.97827148e-02,   9.01489258e-02],
                        [  8.88671875e-02,   8.91418457e-02],
                        [  8.57849121e-02,   8.60290527e-02],
                        [  7.13195801e-02,   7.15026855e-02],
                        [  3.92150879e-02,   3.93676758e-02],
                        [ -3.41796875e-03,  -3.26538086e-03],
                        [ -4.07409668e-02,  -4.05578613e-02],
                        [ -6.05163574e-02,  -6.03637695e-02],
                        [ -5.82580566e-02,  -5.81054688e-02],
                        [ -3.68347168e-02,  -3.67431641e-02],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [  1.18103027e-02,   1.16882324e-02],
                        [  1.65405273e-02,   1.62658691e-02],
                        [  1.32751465e-02,   1.28479004e-02],
                        [  1.06201172e-02,   1.00097656e-02],
                        [  8.72802734e-03,   8.02612305e-03],
                        [  4.94384766e-03,   4.15039062e-03],
                        [  7.32421875e-04,  -9.15527344e-05],
                        [ -2.44140625e-04,  -1.03759766e-03],
                        [  4.48608398e-03,   3.87573242e-03],
                        [  1.46789551e-02,   1.42822266e-02],
                        [  2.58789062e-02,   2.57263184e-02],
                        [  3.21655273e-02,   3.23791504e-02],
                        [  3.21655273e-02,   3.27148438e-02],
                        [  2.85339355e-02,   2.93884277e-02],
                        [  2.31628418e-02,   2.42614746e-02],
                        [  1.73034668e-02,   1.85852051e-02],
                        [  1.39465332e-02,   1.53198242e-02],
                        [  1.61437988e-02,   1.74560547e-02],
                        [  2.42309570e-02,   2.53906250e-02],
                        [  3.59191895e-02,   3.68041992e-02],
                        [  4.62951660e-02,   4.68139648e-02],
                        [  5.03845215e-02,   5.04455566e-02],
                        [  4.71801758e-02,   4.68139648e-02],
                        [  4.06799316e-02,   3.98559570e-02],
                        [  3.53088379e-02,   3.40576172e-02],
                        [  3.21350098e-02,   3.06091309e-02],
                        [  3.05786133e-02,   2.88696289e-02],
                        [  2.97546387e-02,   2.79846191e-02],
                        [  2.78930664e-02,   2.62451172e-02],
                        [  2.36511230e-02,   2.22778320e-02],
                        [  1.77612305e-02,   1.67541504e-02],
                        [  1.27563477e-02,   1.22375488e-02],
                        [  1.06506348e-02,   1.06811523e-02],
                        [  9.33837891e-03,   9.91821289e-03],
                        [  3.60107422e-03,   4.69970703e-03],
                        [ -7.44628906e-03,  -5.88989258e-03],
                        [ -1.93176270e-02,  -1.74255371e-02],
                        [ -2.91748047e-02,  -2.71606445e-02],
                        [ -3.73535156e-02,  -3.53088379e-02],
                        [ -4.26940918e-02,  -4.08020020e-02],
                        [ -4.28161621e-02,  -4.12597656e-02],
                        [ -3.79333496e-02,  -3.68347168e-02],
                        [ -3.09448242e-02,  -3.03955078e-02],
                        [ -2.50854492e-02,  -2.51464844e-02],
                        [ -2.25830078e-02,  -2.32849121e-02],
                        [ -2.34069824e-02,  -2.46887207e-02],
                        [ -2.53295898e-02,  -2.70690918e-02],
                        [ -2.70385742e-02,  -2.91442871e-02],
                        [ -2.94799805e-02,  -3.17993164e-02],
                        [ -3.15246582e-02,  -3.38134766e-02],
                        [ -2.98461914e-02,  -3.19824219e-02],
                        [ -2.39868164e-02,  -2.57568359e-02],
                        [ -1.69067383e-02,  -1.81579590e-02],
                        [ -1.17797852e-02,  -1.23901367e-02],
                        [ -1.07421875e-02,  -1.06506348e-02],
                        [ -1.33361816e-02,  -1.25732422e-02],
                        [ -1.53198242e-02,  -1.39160156e-02],
                        [ -1.27868652e-02,  -1.08337402e-02],
                        [ -7.35473633e-03,  -5.00488281e-03],
                        [ -2.89916992e-03,  -3.66210938e-04],
                        [ -4.27246094e-04,   2.13623047e-03],
                        [  1.83105469e-04,   2.50244141e-03],
                        [ -2.38037109e-03,  -4.57763672e-04],
                        [ -6.62231445e-03,  -5.27954102e-03],
                        [ -7.72094727e-03,  -7.08007812e-03],
                        [ -4.27246094e-03,  -4.42504883e-03],
                        [ -2.74658203e-04,  -1.19018555e-03],
                        [  1.37329102e-03,  -2.44140625e-04],
                        [  1.06811523e-03,  -1.12915039e-03],
                        [  9.15527344e-05,  -2.53295898e-03],
                        [ -1.83105469e-04,  -2.96020508e-03],
                        [  1.83105469e-03,  -8.85009766e-04],
                        [  5.31005859e-03,   2.86865234e-03],
                        [  8.08715820e-03,   6.13403320e-03],
                        [  1.07116699e-02,   9.46044922e-03],
                        [  1.64794922e-02,   1.59912109e-02],
                        [  2.76489258e-02,   2.79846191e-02],
                        [  4.42504883e-02,   4.54101562e-02],
                        [  6.46972656e-02,   6.65588379e-02],
                        [  8.65783691e-02,   8.89587402e-02],
                        [  1.06903076e-01,   1.09619141e-01],
                        [  1.20727539e-01,   1.23565674e-01],
                        [  1.20086670e-01,   1.22741699e-01],
                        [  9.49707031e-02,   9.72290039e-02],
                        [  3.82385254e-02,   3.99169922e-02],
                        [ -4.85229492e-02,  -4.75769043e-02],
                        [ -1.51977539e-01,  -1.51824951e-01],
                        [ -2.48107910e-01,  -2.48779297e-01],
                        [ -3.07830811e-01,  -3.09204102e-01],
                        [ -3.12500000e-01,  -3.14453125e-01],
                        [ -2.71575928e-01,  -2.73956299e-01],
                        [ -2.18353271e-01,  -2.20886230e-01],
                        [ -1.81793213e-01,  -1.84295654e-01],
                        [ -1.65435791e-01,  -1.67663574e-01],
                        [ -1.53717041e-01,  -1.55487061e-01],
                        [ -1.32873535e-01,  -1.34033203e-01],
                        [ -1.00921631e-01,  -1.01409912e-01],
                        [ -6.12487793e-02,  -6.10351562e-02],
                        [ -1.38854980e-02,  -1.30310059e-02],
                        [  4.13818359e-02,   4.27551270e-02],
                        [  9.64965820e-02,   9.82360840e-02],
                        [  1.36505127e-01,   1.38427734e-01],
                        [  1.52404785e-01,   1.54357910e-01],
                        [  1.49414062e-01,   1.51214600e-01],
                        [  1.40502930e-01,   1.41967773e-01],
                        [  1.34338379e-01,   1.35406494e-01],
                        [  1.31011963e-01,   1.31622314e-01],
                        [  1.26007080e-01,   1.26129150e-01],
                        [  1.16333008e-01,   1.15997314e-01],
                        [  1.03576660e-01,   1.02905273e-01],
                        [  9.02709961e-02,   8.93249512e-02],
                        [  7.44628906e-02,   7.33642578e-02],
                        [  5.20935059e-02,   5.09643555e-02],
                        [  2.25219727e-02,   2.14843750e-02],
                        [ -1.03454590e-02,  -1.12609863e-02],
                        [ -3.91845703e-02,  -3.98559570e-02],
                        [ -5.59082031e-02,  -5.63354492e-02],
                        [ -5.74951172e-02,  -5.77392578e-02],
                        [ -4.70275879e-02,  -4.71191406e-02],
                        [ -2.98461914e-02,  -2.97546387e-02],
                        [ -1.27868652e-02,  -1.26342773e-02],
                        [ -2.71606445e-03,  -2.56347656e-03],
                        [ -6.10351562e-05,   6.10351562e-05],
                        [  2.74658203e-04,   3.96728516e-04],
                        [  3.05175781e-05,   9.15527344e-05],
                        [ -2.77709961e-03,  -2.71606445e-03],
                        [ -4.91333008e-03,  -4.82177734e-03],
                        [  7.93457031e-04,   9.76562500e-04],
                        [  1.58691406e-02,   1.61132812e-02],
                        [  3.45153809e-02,   3.49426270e-02],
                        [  5.01098633e-02,   5.06896973e-02],
                        [  5.74340820e-02,   5.81359863e-02],
                        [  5.41992188e-02,   5.49926758e-02],
                        [  4.44030762e-02,   4.52880859e-02],
                        [  3.54919434e-02,   3.62854004e-02],
                        [  3.07006836e-02,   3.13415527e-02],
                        [  2.90527344e-02,   2.94799805e-02],
                        [  2.93884277e-02,   2.94799805e-02],
                        [  2.99987793e-02,   2.96936035e-02],
                        [  2.93884277e-02,   2.87170410e-02],
                        [  2.85034180e-02,   2.74353027e-02],
                        [  2.85339355e-02,   2.71911621e-02],
                        [  2.81982422e-02,   2.66418457e-02],
                        [  2.63061523e-02,   2.46887207e-02],
                        [  2.50854492e-02,   2.35290527e-02],
                        [  2.67028809e-02,   2.53906250e-02],
                        [  2.96936035e-02,   2.87475586e-02],
                        [  3.20129395e-02,   3.15551758e-02],
                        [  3.44238281e-02,   3.45458984e-02],
                        [  3.70178223e-02,   3.76892090e-02],
                        [  3.67736816e-02,   3.79943848e-02],
                        [  3.26538086e-02,   3.43017578e-02],
                        [  2.72827148e-02,   2.92663574e-02],
                        [  2.09350586e-02,   2.30407715e-02],
                        [  9.67407227e-03,   1.16882324e-02],
                        [ -6.68334961e-03,  -4.88281250e-03],
                        [ -2.10571289e-02,  -1.96838379e-02],
                        [ -2.80761719e-02,  -2.72827148e-02],
                        [ -3.03649902e-02,  -3.01818848e-02],
                        [ -3.21044922e-02,  -3.25927734e-02],
                        [ -3.32336426e-02,  -3.43322754e-02],
                        [ -3.21960449e-02,  -3.38439941e-02],
                        [ -2.87475586e-02,  -3.07312012e-02],
                        [ -2.29797363e-02,  -2.51770020e-02],
                        [ -1.67846680e-02,  -1.89819336e-02],
                        [ -1.42211914e-02,  -1.62048340e-02],
                        [ -1.70898438e-02,  -1.87072754e-02],
                        [ -2.27355957e-02,  -2.38647461e-02],
                        [ -2.71301270e-02,  -2.76794434e-02],
                        [ -2.78015137e-02,  -2.76794434e-02],
                        [ -2.39868164e-02,  -2.32543945e-02],
                        [ -1.76696777e-02,  -1.64184570e-02],
                        [ -1.32446289e-02,  -1.15661621e-02],
                        [ -1.33972168e-02,  -1.14135742e-02],
                        [ -1.55639648e-02,  -1.35498047e-02],
                        [ -1.45568848e-02,  -1.26342773e-02],
                        [ -8.42285156e-03,  -6.71386719e-03],
                        [ -1.12915039e-03,   1.83105469e-04],
                        [  2.38037109e-03,   3.17382812e-03],
                        [  2.99072266e-03,   3.26538086e-03],
                        [  5.61523438e-03,   5.40161133e-03],
                        [  9.67407227e-03,   8.94165039e-03],
                        [  8.17871094e-03,   7.01904297e-03],
                        [ -1.83105469e-03,  -3.23486328e-03],
                        [ -1.44958496e-02,  -1.60827637e-02],
                        [ -2.27661133e-02,  -2.44445801e-02],
                        [ -2.42919922e-02,  -2.58178711e-02],
                        [ -2.10571289e-02,  -2.23388672e-02],
                        [ -1.68457031e-02,  -1.78527832e-02],
                        [ -1.20849609e-02,  -1.27258301e-02],
                        [ -2.92968750e-03,  -3.14331055e-03],
                        [  9.70458984e-03,   9.85717773e-03],
                        [  1.77307129e-02,   1.82189941e-02],
                        [  1.86462402e-02,   1.94702148e-02],
                        [  2.03552246e-02,   2.14233398e-02],
                        [  2.80761719e-02,   2.92663574e-02],
                        [  3.77807617e-02,   3.90319824e-02],
                        [  4.60815430e-02,   4.73022461e-02],
                        [  5.71899414e-02,   5.82580566e-02],
                        [  7.63244629e-02,   7.71789551e-02],
                        [  1.01928711e-01,   1.02569580e-01],
                        [  1.24969482e-01,   1.25305176e-01],
                        [  1.31500244e-01,   1.31530762e-01],
                        [  1.08154297e-01,   1.07910156e-01],
                        [  4.93164062e-02,   4.88281250e-02],
                        [ -4.03137207e-02,  -4.10156250e-02],
                        [ -1.46789551e-01,  -1.47674561e-01],
                        [ -2.46704102e-01,  -2.47680664e-01],
                        [ -3.10272217e-01,  -3.11279297e-01],
                        [ -3.17230225e-01,  -3.18176270e-01],
                        [ -2.75482178e-01,  -2.76306152e-01],
                        [ -2.19055176e-01,  -2.19696045e-01],
                        [ -1.80328369e-01,  -1.80786133e-01],
                        [ -1.64794922e-01,  -1.64978027e-01],
                        [ -1.56372070e-01,  -1.56311035e-01],
                        [ -1.41357422e-01,  -1.41052246e-01],
                        [ -1.16912842e-01,  -1.16394043e-01],
                        [ -8.30688477e-02,  -8.23669434e-02],
                        [ -3.81469727e-02,  -3.73229980e-02],
                        [  1.80053711e-02,   1.88598633e-02],
                        [  8.00170898e-02,   8.08715820e-02],
                        [  1.35467529e-01,   1.36199951e-01],
                        [  1.69860840e-01,   1.70471191e-01],
                        [  1.77978516e-01,   1.78405762e-01],
                        [  1.67907715e-01,   1.68090820e-01],
                        [  1.52587891e-01,   1.52557373e-01],
                        [  1.40808105e-01,   1.40594482e-01],
                        [  1.33575439e-01,   1.33148193e-01],
                        [  1.25366211e-01,   1.24786377e-01],
                        [  1.09375000e-01,   1.08703613e-01],
                        [  8.41674805e-02,   8.34960938e-02],
                        [  5.30700684e-02,   5.23986816e-02],
                        [  1.77917480e-02,   1.72119141e-02],
                        [ -2.10571289e-02,  -2.14843750e-02],
                        [ -5.64270020e-02,  -5.67016602e-02],
                        [ -7.58056641e-02,  -7.59277344e-02],
                        [ -7.36083984e-02,  -7.35168457e-02],
                        [ -5.66711426e-02,  -5.64575195e-02],
                        [ -3.59191895e-02,  -3.56140137e-02],
                        [ -1.72424316e-02,  -1.68457031e-02],
                        [ -3.11279297e-03,  -2.68554688e-03],
                        [  3.93676758e-03,   4.36401367e-03],
                        [  4.76074219e-03,   5.09643555e-03],
                        [  4.51660156e-03,   4.82177734e-03],
                        [  5.85937500e-03,   6.07299805e-03],
                        [  8.02612305e-03,   8.08715820e-03],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  2.87780762e-02,   2.87170410e-02],
                        [  4.86755371e-02,   4.85534668e-02],
                        [  6.33239746e-02,   6.32019043e-02],
                        [  6.58569336e-02,   6.57348633e-02],
                        [  5.57556152e-02,   5.56030273e-02],
                        [  3.71704102e-02,   3.70483398e-02],
                        [  1.97448730e-02,   1.97143555e-02],
                        [  1.26647949e-02,   1.26342773e-02],
                        [  1.46789551e-02,   1.46484375e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.82800293e-02,   1.83105469e-02],
                        [  1.73339844e-02,   1.73034668e-02],
                        [  1.58386230e-02,   1.57470703e-02],
                        [  1.79138184e-02,   1.78222656e-02],
                        [  2.80456543e-02,   2.78930664e-02],
                        [  4.11987305e-02,   4.09851074e-02],
                        [  4.75769043e-02,   4.74243164e-02],
                        [  4.62951660e-02,   4.61730957e-02],
                        [  4.27246094e-02,   4.26025391e-02],
                        [  3.85131836e-02,   3.84521484e-02],
                        [  3.38134766e-02,   3.38439941e-02],
                        [  3.10363770e-02,   3.11584473e-02],
                        [  2.98461914e-02,   3.00292969e-02],
                        [  2.65808105e-02,   2.68554688e-02],
                        [  2.13012695e-02,   2.16674805e-02],
                        [  1.66931152e-02,   1.70288086e-02],
                        [  1.07727051e-02,   1.11083984e-02],
                        [ -2.44140625e-04,   6.10351562e-05],
                        [ -1.44042969e-02,  -1.41906738e-02],
                        [ -2.60925293e-02,  -2.60009766e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -3.46374512e-02,  -3.47595215e-02],
                        [ -3.10668945e-02,  -3.13415527e-02],
                        [ -2.48718262e-02,  -2.52075195e-02],
                        [ -2.12402344e-02,  -2.16369629e-02],
                        [ -2.16979980e-02,  -2.21252441e-02],
                        [ -2.28576660e-02,  -2.32543945e-02],
                        [ -2.27661133e-02,  -2.31018066e-02],
                        [ -2.35595703e-02,  -2.38037109e-02],
                        [ -2.58483887e-02,  -2.60009766e-02],
                        [ -2.68554688e-02,  -2.68554688e-02],
                        [ -2.60009766e-02,  -2.58789062e-02],
                        [ -2.56347656e-02,  -2.53906250e-02],
                        [ -2.46887207e-02,  -2.43530273e-02],
                        [ -2.10266113e-02,  -2.06298828e-02],
                        [ -1.80358887e-02,  -1.76391602e-02],
                        [ -1.86462402e-02,  -1.82495117e-02],
                        [ -1.87988281e-02,  -1.84631348e-02],
                        [ -1.58081055e-02,  -1.55944824e-02],
                        [ -1.34277344e-02,  -1.33056641e-02],
                        [ -1.35803223e-02,  -1.35192871e-02],
                        [ -1.33056641e-02,  -1.33972168e-02],
                        [ -1.08032227e-02,  -1.10168457e-02],
                        [ -6.34765625e-03,  -6.59179688e-03],
                        [ -1.61743164e-03,  -1.89208984e-03],
                        [ -1.55639648e-03,  -1.89208984e-03],
                        [ -8.27026367e-03,  -8.54492188e-03],
                        [ -1.35803223e-02,  -1.37939453e-02],
                        [ -9.06372070e-03,  -9.27734375e-03],
                        [  2.13623047e-04,   9.15527344e-05],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -1.06811523e-03,  -1.00708008e-03],
                        [ -5.88989258e-03,  -5.76782227e-03],
                        [ -6.53076172e-03,  -6.37817383e-03],
                        [ -3.23486328e-03,  -3.02124023e-03],
                        [  1.86157227e-03,   2.04467773e-03],
                        [  6.95800781e-03,   7.11059570e-03],
                        [  1.31225586e-02,   1.32751465e-02],
                        [  2.18811035e-02,   2.20031738e-02],
                        [  3.16467285e-02,   3.17077637e-02],
                        [  4.14733887e-02,   4.15039062e-02],
                        [  5.54504395e-02,   5.54504395e-02],
                        [  7.78503418e-02,   7.77587891e-02],
                        [  1.06658936e-01,   1.06567383e-01],
                        [  1.32293701e-01,   1.32202148e-01],
                        [  1.39709473e-01,   1.39617920e-01],
                        [  1.15081787e-01,   1.14959717e-01],
                        [  5.34057617e-02,   5.33447266e-02],
                        [ -4.02526855e-02,  -4.02832031e-02],
                        [ -1.51489258e-01,  -1.51550293e-01],
                        [ -2.53875732e-01,  -2.53875732e-01],
                        [ -3.15399170e-01,  -3.15368652e-01],
                        [ -3.19427490e-01,  -3.19396973e-01],
                        [ -2.78106689e-01,  -2.78076172e-01],
                        [ -2.21893311e-01,  -2.21832275e-01],
                        [ -1.78161621e-01,  -1.78131104e-01],
                        [ -1.56646729e-01,  -1.56616211e-01],
                        [ -1.48437500e-01,  -1.48406982e-01],
                        [ -1.38427734e-01,  -1.38427734e-01],
                        [ -1.19567871e-01,  -1.19567871e-01],
                        [ -9.18884277e-02,  -9.18884277e-02],
                        [ -5.27343750e-02,  -5.27038574e-02],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  6.65588379e-02,   6.65588379e-02],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.65069580e-01,   1.65069580e-01],
                        [  1.84234619e-01,   1.84234619e-01],
                        [  1.88323975e-01,   1.88354492e-01],
                        [  1.83715820e-01,   1.83715820e-01],
                        [  1.73034668e-01,   1.73034668e-01],
                        [  1.55151367e-01,   1.55151367e-01],
                        [  1.29302979e-01,   1.29302979e-01],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  6.64062500e-02,   6.63757324e-02],
                        [  3.27758789e-02,   3.27758789e-02],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -6.03637695e-02,  -6.03942871e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [  0.00000000e+00,   0.00000000e+00],
                        [  4.60815430e-03,   4.63867188e-03],
                        [  2.77709961e-03,   2.77709961e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  3.05480957e-02,   3.05786133e-02],
                        [  4.57153320e-02,   4.56848145e-02],
                        [  5.83496094e-02,   5.83801270e-02],
                        [  6.26831055e-02,   6.27136230e-02],
                        [  5.63354492e-02,   5.63049316e-02],
                        [  4.33349609e-02,   4.33349609e-02],
                        [  3.12194824e-02,   3.12500000e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  9.18579102e-03,   9.18579102e-03],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  1.50146484e-02,   1.49841309e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  2.22778320e-02,   2.23083496e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.68554688e-02,   2.68249512e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  3.45458984e-02,   3.45458984e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  3.82385254e-02,   3.82385254e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.85644531e-02,   2.85644531e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  5.52368164e-03,   5.49316406e-03],
                        [ -2.22778320e-03,  -2.19726562e-03],
                        [ -7.26318359e-03,  -7.23266602e-03],
                        [ -1.09863281e-02,  -1.10168457e-02],
                        [ -1.34277344e-02,  -1.34277344e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.47094727e-02,  -1.47094727e-02],
                        [ -2.23083496e-02,  -2.23388672e-02],
                        [ -3.43627930e-02,  -3.43322754e-02],
                        [ -4.23278809e-02,  -4.23278809e-02],
                        [ -4.38537598e-02,  -4.38842773e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.94897461e-02,  -3.94592285e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -2.01721191e-02,  -2.01721191e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -2.70385742e-02,  -2.70385742e-02],
                        [ -1.91345215e-02,  -1.91040039e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -4.76074219e-03,  -4.73022461e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.36108398e-02,  -1.36413574e-02],
                        [ -9.46044922e-03,  -9.46044922e-03],
                        [ -2.04467773e-03,  -2.04467773e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.38793945e-01,   1.38793945e-01],
                        [  1.09039307e-01,   1.09039307e-01],
                        [  4.72717285e-02,   4.72717285e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -1.51367188e-01,  -1.51367188e-01],
                        [ -2.57080078e-01,  -2.57080078e-01],
                        [ -3.26080322e-01,  -3.26080322e-01],
                        [ -3.36059570e-01,  -3.36090088e-01],
                        [ -2.94769287e-01,  -2.94769287e-01],
                        [ -2.33337402e-01,  -2.33337402e-01],
                        [ -1.82281494e-01,  -1.82281494e-01],
                        [ -1.53137207e-01,  -1.53137207e-01],
                        [ -1.38092041e-01,  -1.38092041e-01],
                        [ -1.23962402e-01,  -1.23962402e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.74377441e-01,   1.74407959e-01],
                        [  2.03094482e-01,   2.03094482e-01],
                        [  2.05352783e-01,   2.05352783e-01],
                        [  1.92382812e-01,   1.92382812e-01],
                        [  1.75231934e-01,   1.75231934e-01],
                        [  1.53656006e-01,   1.53656006e-01],
                        [  1.22100830e-01,   1.22131348e-01],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  3.50341797e-02,   3.50036621e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -5.53894043e-02,  -5.54199219e-02],
                        [ -4.94384766e-02,  -4.94384766e-02],
                        [ -3.51257324e-02,  -3.50952148e-02],
                        [ -2.56042480e-02,  -2.56042480e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [  4.27246094e-04,   4.27246094e-04],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  2.09655762e-02,   2.09350586e-02],
                        [  3.10363770e-02,   3.10668945e-02],
                        [  4.32434082e-02,   4.32434082e-02],
                        [  5.40771484e-02,   5.40466309e-02],
                        [  5.92041016e-02,   5.92041016e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  3.85437012e-02,   3.85131836e-02],
                        [  2.60620117e-02,   2.60620117e-02],
                        [  1.62048340e-02,   1.62353516e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  2.44445801e-02,   2.44750977e-02],
                        [  3.28674316e-02,   3.28674316e-02],
                        [  4.28466797e-02,   4.28466797e-02],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  5.48706055e-02,   5.48706055e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  4.26330566e-02,   4.26330566e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  3.90625000e-03,   3.90625000e-03],
                        [  1.61743164e-03,   1.58691406e-03],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.70593262e-02,  -1.70898438e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -4.24804688e-02,  -4.24499512e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -4.13818359e-02,  -4.13818359e-02],
                        [ -2.57263184e-02,  -2.57263184e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.74353027e-02,  -2.74353027e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -2.77709961e-02,  -2.78015137e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -3.29589844e-03,  -3.26538086e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [ -3.63159180e-03,  -3.66210938e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -1.17797852e-02,  -1.18103027e-02],
                        [ -1.13830566e-02,  -1.13830566e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  9.76562500e-03,   9.76562500e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  1.05895996e-02,   1.06201172e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  4.59289551e-02,   4.58984375e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  9.64355469e-02,   9.64355469e-02],
                        [  1.22741699e-01,   1.22741699e-01],
                        [  1.39190674e-01,   1.39190674e-01],
                        [  1.35253906e-01,   1.35284424e-01],
                        [  1.03332520e-01,   1.03332520e-01],
                        [  4.03747559e-02,   4.03747559e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -1.55883789e-01,  -1.55853271e-01],
                        [ -2.50915527e-01,  -2.50915527e-01],
                        [ -3.07067871e-01,  -3.07067871e-01],
                        [ -3.08074951e-01,  -3.08044434e-01],
                        [ -2.64099121e-01,  -2.64099121e-01],
                        [ -2.07366943e-01,  -2.07366943e-01],
                        [ -1.67633057e-01,  -1.67633057e-01],
                        [ -1.52160645e-01,  -1.52130127e-01],
                        [ -1.48437500e-01,  -1.48437500e-01],
                        [ -1.40655518e-01,  -1.40655518e-01],
                        [ -1.21826172e-01,  -1.21795654e-01],
                        [ -9.31701660e-02,  -9.31701660e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.79351807e-01,   1.79321289e-01],
                        [  2.08892822e-01,   2.08923340e-01],
                        [  2.11853027e-01,   2.11853027e-01],
                        [  1.98364258e-01,   1.98333740e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  1.50238037e-01,   1.50268555e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  5.44433594e-02,   5.44128418e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -5.72204590e-02,  -5.72509766e-02],
                        [ -5.39550781e-02,  -5.39550781e-02],
                        [ -3.95507812e-02,  -3.95202637e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.39257812e-02,  -2.39257812e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  4.47692871e-02,   4.47692871e-02],
                        [  5.62438965e-02,   5.62438965e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  5.76782227e-02,   5.76477051e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  2.43530273e-02,   2.43835449e-02],
                        [  2.98461914e-02,   2.98156738e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  3.13720703e-02,   3.14025879e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  3.75671387e-02,   3.75366211e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  3.68041992e-02,   3.68041992e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  4.48913574e-02,   4.49218750e-02],
                        [  4.19311523e-02,   4.19006348e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.21862793e-02,   2.22167969e-02],
                        [  8.91113281e-03,   8.91113281e-03],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.41601562e-02,  -1.41296387e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.01721191e-02,  -2.01416016e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -4.34265137e-02,  -4.33959961e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -2.77404785e-02,  -2.77099609e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.01318359e-02,  -1.01013184e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [ -1.48620605e-02,  -1.48925781e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -3.14331055e-03,  -3.11279297e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -1.54724121e-02,  -1.54724121e-02],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  2.59399414e-03,   2.56347656e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.26135254e-02,   2.26440430e-02],
                        [  3.40881348e-02,   3.40576172e-02],
                        [  4.30908203e-02,   4.30908203e-02],
                        [  5.18798828e-02,   5.18798828e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  8.73107910e-02,   8.73107910e-02],
                        [  1.11328125e-01,   1.11358643e-01],
                        [  1.31072998e-01,   1.31072998e-01],
                        [  1.35162354e-01,   1.35162354e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  4.67224121e-02,   4.67224121e-02],
                        [ -4.74243164e-02,  -4.74548340e-02],
                        [ -1.53686523e-01,  -1.53656006e-01],
                        [ -2.46520996e-01,  -2.46520996e-01],
                        [ -3.01452637e-01,  -3.01452637e-01],
                        [ -3.04534912e-01,  -3.04534912e-01],
                        [ -2.63336182e-01,  -2.63305664e-01],
                        [ -2.06848145e-01,  -2.06848145e-01],
                        [ -1.65649414e-01,  -1.65649414e-01],
                        [ -1.47949219e-01,  -1.47918701e-01],
                        [ -1.39709473e-01,  -1.39709473e-01],
                        [ -1.27288818e-01,  -1.27288818e-01],
                        [ -1.10321045e-01,  -1.10321045e-01],
                        [ -9.19799805e-02,  -9.19799805e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  1.16821289e-01,   1.16821289e-01],
                        [  1.84783936e-01,   1.84753418e-01],
                        [  2.21374512e-01,   2.21374512e-01],
                        [  2.20275879e-01,   2.20275879e-01],
                        [  1.93695068e-01,   1.93664551e-01],
                        [  1.59149170e-01,   1.59149170e-01],
                        [  1.23107910e-01,   1.23107910e-01],
                        [  7.97424316e-02,   7.97424316e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [ -2.40783691e-02,  -2.40478516e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -6.80541992e-03,  -6.80541992e-03],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  1.16882324e-02,   1.16577148e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  4.40368652e-02,   4.40673828e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  6.78710938e-02,   6.78710938e-02],
                        [  7.26928711e-02,   7.26928711e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  5.76477051e-02,   5.76171875e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  2.71606445e-02,   2.71911621e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  1.58691406e-02,   1.58691406e-02],
                        [  2.67944336e-02,   2.68249512e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  4.85229492e-02,   4.85229492e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  4.32739258e-02,   4.32739258e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  5.88989258e-03,   5.88989258e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.86462402e-02,  -1.86767578e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -2.39562988e-02,  -2.39257812e-02],
                        [ -2.54516602e-02,  -2.54516602e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -3.00598145e-02,  -3.00903320e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -2.41088867e-02,  -2.41088867e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.56042480e-02,  -2.56347656e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -7.38525391e-03,  -7.41577148e-03],
                        [ -8.85009766e-03,  -8.85009766e-03],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -1.45263672e-02,  -1.45568848e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -3.44848633e-03,  -3.41796875e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  6.43920898e-03,   6.43920898e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [  1.92260742e-03,   1.95312500e-03],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  3.43017578e-02,   3.42712402e-02],
                        [  5.42602539e-02,   5.42602539e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  9.60998535e-02,   9.60693359e-02],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.27685547e-01,   1.27685547e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  9.96398926e-02,   9.96398926e-02],
                        [  4.33959961e-02,   4.33959961e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -1.33178711e-01,  -1.33178711e-01],
                        [ -2.22320557e-01,  -2.22320557e-01],
                        [ -2.79479980e-01,  -2.79510498e-01],
                        [ -2.83966064e-01,  -2.83966064e-01],
                        [ -2.42034912e-01,  -2.42004395e-01],
                        [ -1.88690186e-01,  -1.88690186e-01],
                        [ -1.57043457e-01,  -1.57043457e-01],
                        [ -1.51214600e-01,  -1.51214600e-01],
                        [ -1.53991699e-01,  -1.53991699e-01],
                        [ -1.50360107e-01,  -1.50390625e-01],
                        [ -1.36871338e-01,  -1.36871338e-01],
                        [ -1.15142822e-01,  -1.15112305e-01],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  9.53369141e-02,   9.53369141e-02],
                        [  1.68548584e-01,   1.68548584e-01],
                        [  2.21618652e-01,   2.21649170e-01],
                        [  2.42187500e-01,   2.42187500e-01],
                        [  2.25891113e-01,   2.25891113e-01],
                        [  1.76696777e-01,   1.76696777e-01],
                        [  1.06567383e-01,   1.06567383e-01],
                        [  3.36608887e-02,   3.36608887e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -4.66613770e-02,  -4.66308594e-02],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -1.04980469e-02,  -1.04980469e-02],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  8.94165039e-03,   8.91113281e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  8.78906250e-03,   8.75854492e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  8.20922852e-03,   8.20922852e-03],
                        [  1.02539062e-02,   1.02233887e-02],
                        [  1.65710449e-02,   1.65710449e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  7.11059570e-02,   7.11059570e-02],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  9.60693359e-02,   9.60693359e-02],
                        [  8.67309570e-02,   8.67309570e-02],
                        [  6.85729980e-02,   6.85729980e-02],
                        [  4.89501953e-02,   4.89807129e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  1.05285645e-02,   1.05285645e-02],
                        [  1.21459961e-02,   1.21154785e-02],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.55334473e-02,   1.55639648e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  2.12707520e-02,   2.12402344e-02],
                        [  2.80456543e-02,   2.80761719e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  3.68347168e-02,   3.68347168e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  4.75769043e-02,   4.75769043e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  3.57055664e-02,   3.57055664e-02],
                        [  2.89916992e-02,   2.89916992e-02],
                        [  2.42614746e-02,   2.42614746e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.45666504e-02,  -2.45666504e-02],
                        [ -3.75366211e-02,  -3.75366211e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -4.11682129e-02,  -4.11682129e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -1.51367188e-02,  -1.51367188e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -1.91345215e-02,  -1.91345215e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.52893066e-02,  -1.52587891e-02],
                        [ -1.17492676e-02,  -1.17492676e-02],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  3.87573242e-03,   3.90625000e-03],
                        [  4.11987305e-03,   4.11987305e-03],
                        [ -4.24194336e-03,  -4.24194336e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  1.64794922e-03,   1.64794922e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  5.22460938e-02,   5.22460938e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  1.20391846e-01,   1.20391846e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.29425049e-01,   1.29425049e-01],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  5.54504395e-02,   5.54504395e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -1.29730225e-01,  -1.29730225e-01],
                        [ -2.29156494e-01,  -2.29156494e-01],
                        [ -2.93914795e-01,  -2.93914795e-01],
                        [ -3.00506592e-01,  -3.00506592e-01],
                        [ -2.55615234e-01,  -2.55615234e-01],
                        [ -1.94793701e-01,  -1.94793701e-01],
                        [ -1.51214600e-01,  -1.51184082e-01],
                        [ -1.30828857e-01,  -1.30828857e-01],
                        [ -1.21093750e-01,  -1.21093750e-01],
                        [ -1.12396240e-01,  -1.12365723e-01],
                        [ -1.03851318e-01,  -1.03851318e-01],
                        [ -9.59472656e-02,  -9.59472656e-02],
                        [ -8.23364258e-02,  -8.23364258e-02],
                        [ -4.97741699e-02,  -4.97741699e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  9.06677246e-02,   9.06677246e-02],
                        [  1.70471191e-01,   1.70471191e-01],
                        [  2.26867676e-01,   2.26867676e-01],
                        [  2.42706299e-01,   2.42706299e-01],
                        [  2.12371826e-01,   2.12402344e-01],
                        [  1.46423340e-01,   1.46423340e-01],
                        [  6.72302246e-02,   6.72302246e-02],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -4.41284180e-02,  -4.41284180e-02],
                        [ -5.52368164e-02,  -5.52368164e-02],
                        [ -4.47692871e-02,  -4.47692871e-02],
                        [ -2.74658203e-02,  -2.74353027e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.80358887e-02,   1.80664062e-02],
                        [  2.32849121e-02,   2.33154297e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  1.30615234e-02,   1.30615234e-02],
                        [  2.53295898e-02,   2.53295898e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  8.20922852e-02,   8.20922852e-02],
                        [  5.94787598e-02,   5.94787598e-02],
                        [  4.22363281e-02,   4.22058105e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  2.72521973e-02,   2.72827148e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.62451172e-02,   2.62451172e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  4.04663086e-02,   4.04663086e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  5.27954102e-02,   5.27954102e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.62854004e-02,   3.62854004e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.60522461e-02,   1.60522461e-02],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [ -5.58471680e-03,  -5.58471680e-03],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.21862793e-02,  -2.22167969e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [ -2.51159668e-02,  -2.51464844e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.03454590e-02,  -1.03454590e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  6.81457520e-02,   6.81457520e-02],
                        [  8.77685547e-02,   8.77685547e-02],
                        [  1.10015869e-01,   1.10015869e-01],
                        [  1.24084473e-01,   1.24084473e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  9.19494629e-02,   9.19494629e-02],
                        [  3.34167480e-02,   3.34167480e-02],
                        [ -5.26428223e-02,  -5.26428223e-02],
                        [ -1.52740479e-01,  -1.52740479e-01],
                        [ -2.42706299e-01,  -2.42706299e-01],
                        [ -2.94830322e-01,  -2.94830322e-01],
                        [ -2.91961670e-01,  -2.91961670e-01],
                        [ -2.43713379e-01,  -2.43713379e-01],
                        [ -1.83197021e-01,  -1.83197021e-01],
                        [ -1.40319824e-01,  -1.40319824e-01],
                        [ -1.21582031e-01,  -1.21582031e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -1.10382080e-01,  -1.10382080e-01],
                        [ -1.03118896e-01,  -1.03118896e-01],
                        [ -9.38110352e-02,  -9.38110352e-02],
                        [ -7.87963867e-02,  -7.88269043e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  1.56402588e-01,   1.56402588e-01],
                        [  2.16247559e-01,   2.16247559e-01],
                        [  2.29583740e-01,   2.29614258e-01],
                        [  1.87988281e-01,   1.87957764e-01],
                        [  1.06994629e-01,   1.06964111e-01],
                        [  2.09045410e-02,   2.09045410e-02],
                        [ -3.53698730e-02,  -3.53698730e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  1.09863281e-03,   1.09863281e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -9.33837891e-03,  -9.33837891e-03],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  5.92651367e-02,   5.92651367e-02],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  1.03424072e-01,   1.03424072e-01],
                        [  9.59777832e-02,   9.59777832e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  2.60925293e-02,   2.60925293e-02],
                        [  2.45666504e-02,   2.45666504e-02],
                        [  2.19116211e-02,   2.19116211e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.55029297e-02,   1.55334473e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  3.70178223e-02,   3.70178223e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.54724121e-02,   1.54418945e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.37329102e-03,   1.37329102e-03],
                        [ -6.31713867e-03,  -6.31713867e-03],
                        [ -1.50146484e-02,  -1.50146484e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -1.68762207e-02,  -1.68762207e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -3.58276367e-02,  -3.58276367e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -3.86352539e-02,  -3.86352539e-02],
                        [ -3.04870605e-02,  -3.04870605e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -1.79138184e-02,  -1.79138184e-02],
                        [ -1.87072754e-02,  -1.87072754e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [ -2.43225098e-02,  -2.43225098e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.97753906e-02,  -1.97753906e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.52990723e-02,  -2.52990723e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [  3.05175781e-04,   3.05175781e-04],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  1.83105469e-03,   1.83105469e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [  2.01416016e-03,   2.01416016e-03],
                        [  1.89819336e-02,   1.89819336e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  5.30700684e-02,   5.30700684e-02],
                        [  6.31713867e-02,   6.31713867e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.11968994e-01,   1.11968994e-01],
                        [  1.19323730e-01,   1.19323730e-01],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  5.07202148e-02,   5.07202148e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -1.25732422e-01,  -1.25732422e-01],
                        [ -2.22564697e-01,  -2.22564697e-01],
                        [ -2.85614014e-01,  -2.85614014e-01],
                        [ -2.87902832e-01,  -2.87902832e-01],
                        [ -2.35656738e-01,  -2.35656738e-01],
                        [ -1.67633057e-01,  -1.67633057e-01],
                        [ -1.22222900e-01,  -1.22222900e-01],
                        [ -1.08489990e-01,  -1.08489990e-01],
                        [ -1.10290527e-01,  -1.10290527e-01],
                        [ -1.10656738e-01,  -1.10687256e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -9.11560059e-02,  -9.11560059e-02],
                        [ -7.53784180e-02,  -7.53784180e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [  3.91540527e-02,   3.91540527e-02],
                        [  1.03027344e-01,   1.02996826e-01],
                        [  1.53778076e-01,   1.53778076e-01],
                        [  1.69830322e-01,   1.69830322e-01],
                        [  1.42395020e-01,   1.42395020e-01],
                        [  8.28857422e-02,   8.28857422e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [ -1.65100098e-02,  -1.65100098e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  5.64270020e-02,   5.64270020e-02],
                        [  4.13513184e-02,   4.13513184e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.74658203e-03,  -2.74658203e-03],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.27551270e-02,   4.27246094e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.75573730e-02,   2.75573730e-02],
                        [  2.97241211e-02,   2.96936035e-02],
                        [  3.28979492e-02,   3.28979492e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  1.57775879e-02,   1.57775879e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  3.65905762e-02,   3.65905762e-02],
                        [  4.01306152e-02,   4.01306152e-02],
                        [  4.09240723e-02,   4.09240723e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -8.14819336e-03,  -8.14819336e-03],
                        [ -4.15039062e-03,  -4.15039062e-03],
                        [ -5.79833984e-03,  -5.79833984e-03],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.11486816e-02,  -2.11486816e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -3.44238281e-02,  -3.44238281e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.15344238e-02,  -4.15344238e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -4.45556641e-03,  -4.45556641e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [ -3.87573242e-03,  -3.87573242e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -7.90405273e-03,  -7.90405273e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  1.14776611e-01,   1.14776611e-01],
                        [  1.31225586e-01,   1.31225586e-01],
                        [  1.31225586e-01,   1.31225586e-01],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  5.19714355e-02,   5.19714355e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -1.23504639e-01,  -1.23504639e-01],
                        [ -2.17620850e-01,  -2.17620850e-01],
                        [ -2.77435303e-01,  -2.77435303e-01],
                        [ -2.81677246e-01,  -2.81677246e-01],
                        [ -2.40173340e-01,  -2.40173340e-01],
                        [ -1.86523438e-01,  -1.86523438e-01],
                        [ -1.48223877e-01,  -1.48223877e-01],
                        [ -1.28295898e-01,  -1.28295898e-01],
                        [ -1.15997314e-01,  -1.15997314e-01],
                        [ -1.04858398e-01,  -1.04858398e-01],
                        [ -9.39025879e-02,  -9.39025879e-02],
                        [ -8.10546875e-02,  -8.10852051e-02],
                        [ -6.48498535e-02,  -6.48498535e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -2.16369629e-02,  -2.16369629e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  5.50537109e-02,   5.50537109e-02],
                        [  9.16137695e-02,   9.16137695e-02],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  1.00830078e-01,   1.00830078e-01],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.22167969e-02,   2.22473145e-02],
                        [  2.62145996e-02,   2.61840820e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  8.40759277e-02,   8.40759277e-02],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  8.39843750e-02,   8.39843750e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.03332520e-02,   6.03332520e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  6.39343262e-02,   6.39343262e-02],
                        [  5.70373535e-02,   5.70373535e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  2.50854492e-02,   2.50854492e-02],
                        [  2.13623047e-02,   2.13623047e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  2.04467773e-02,   2.04467773e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  3.71398926e-02,   3.71398926e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.53198242e-02,   1.53198242e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.48620605e-02,  -1.48620605e-02],
                        [ -1.53198242e-02,  -1.53198242e-02],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  2.68554688e-03,   2.68554688e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [ -2.66723633e-02,  -2.66723633e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.34265137e-02,  -4.34265137e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -2.97546387e-02,  -2.97546387e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.62548828e-02,  -3.62548828e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -1.86157227e-02,  -1.86157227e-02],
                        [ -2.08435059e-02,  -2.08435059e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  1.01623535e-02,   1.01623535e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.06933594e-01,   1.06933594e-01],
                        [  1.23077393e-01,   1.23077393e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -2.22808838e-01,  -2.22808838e-01],
                        [ -2.83325195e-01,  -2.83325195e-01],
                        [ -2.89672852e-01,  -2.89672852e-01],
                        [ -2.48413086e-01,  -2.48413086e-01],
                        [ -1.88018799e-01,  -1.88018799e-01],
                        [ -1.39434814e-01,  -1.39434814e-01],
                        [ -1.13372803e-01,  -1.13372803e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -8.33435059e-02,  -8.33435059e-02],
                        [ -6.89697266e-02,  -6.89697266e-02],
                        [ -6.05773926e-02,  -6.05773926e-02],
                        [ -5.47790527e-02,  -5.47790527e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -1.93176270e-02,  -1.93176270e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  6.07910156e-02,   6.07910156e-02],
                        [  7.10144043e-02,   7.10144043e-02],
                        [  7.40051270e-02,   7.40051270e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  3.39355469e-02,   3.39355469e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  3.17077637e-02,   3.17077637e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  5.01708984e-02,   5.01708984e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  1.16851807e-01,   1.16851807e-01],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  4.99877930e-02,   4.99877930e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  3.34472656e-02,   3.34472656e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  8.85009766e-04,   8.85009766e-04],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.88793945e-02,   3.88793945e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  3.69262695e-03,   3.69262695e-03],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -2.15148926e-02,  -2.15148926e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.62854004e-02,  -3.62854004e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -1.06811523e-02,  -1.06811523e-02],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -4.22058105e-02,  -4.22058105e-02],
                        [ -5.03234863e-02,  -5.03234863e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -3.79333496e-02,  -3.79333496e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.85546875e-02,  -1.85546875e-02],
                        [ -1.25427246e-02,  -1.25427246e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.70898438e-02,  -1.70898438e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  3.23486328e-02,   3.23486328e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  4.54711914e-02,   4.54711914e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  1.26098633e-01,   1.26098633e-01],
                        [  1.34429932e-01,   1.34429932e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -1.42333984e-01,  -1.42333984e-01],
                        [ -2.30163574e-01,  -2.30163574e-01],
                        [ -2.81341553e-01,  -2.81341553e-01],
                        [ -2.79418945e-01,  -2.79418945e-01],
                        [ -2.31750488e-01,  -2.31750488e-01],
                        [ -1.70898438e-01,  -1.70898438e-01],
                        [ -1.30828857e-01,  -1.30828857e-01],
                        [ -1.15814209e-01,  -1.15814209e-01],
                        [ -1.04949951e-01,  -1.04949951e-01],
                        [ -8.42285156e-02,  -8.42285156e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.38842773e-02,  -4.38842773e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.03747559e-02,  -4.03747559e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.93469238e-02,  -4.93469238e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  8.06579590e-02,   8.06579590e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  5.89294434e-02,   5.89294434e-02],
                        [  4.41284180e-02,   4.41284180e-02],
                        [  3.54309082e-02,   3.54309082e-02],
                        [  3.21044922e-02,   3.21044922e-02],
                        [  3.33862305e-02,   3.33862305e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  4.22363281e-02,   4.22363281e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  9.89685059e-02,   9.89685059e-02],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  9.19799805e-02,   9.19799805e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  7.07092285e-02,   7.07092285e-02],
                        [  5.63659668e-02,   5.63659668e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  3.85131836e-02,   3.85131836e-02],
                        [  4.27551270e-02,   4.27551270e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.59802246e-02,   3.59802246e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  2.55737305e-02,   2.55737305e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  2.48413086e-02,   2.48413086e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.23901367e-02,   1.23901367e-02],
                        [  1.42822266e-02,   1.42822266e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  3.08227539e-03,   3.08227539e-03],
                        [ -9.27734375e-03,  -9.27734375e-03],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.36413574e-02,  -1.36413574e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  4.18090820e-03,   4.18090820e-03],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.78222656e-02,  -1.78222656e-02],
                        [ -3.03649902e-02,  -3.03649902e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.86755371e-02,  -4.86755371e-02],
                        [ -4.98352051e-02,  -4.98352051e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -4.61120605e-02,  -4.61120605e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -4.15954590e-02,  -4.15954590e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -3.63159180e-03,  -3.63159180e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -8.02612305e-03,  -8.02612305e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.07727051e-02,   1.07727051e-02],
                        [  1.66015625e-02,   1.66015625e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  3.39660645e-02,   3.39660645e-02],
                        [  4.01000977e-02,   4.01000977e-02],
                        [  4.67834473e-02,   4.67834473e-02],
                        [  6.25915527e-02,   6.25915527e-02],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  1.29730225e-01,   1.29730225e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  4.51660156e-02,   4.51660156e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -1.23413086e-01,  -1.23413086e-01],
                        [ -2.18444824e-01,  -2.18444824e-01],
                        [ -2.83264160e-01,  -2.83264160e-01],
                        [ -2.87597656e-01,  -2.87597656e-01],
                        [ -2.34619141e-01,  -2.34619141e-01],
                        [ -1.62139893e-01,  -1.62139893e-01],
                        [ -1.08459473e-01,  -1.08459473e-01],
                        [ -8.35876465e-02,  -8.35876465e-02],
                        [ -7.28149414e-02,  -7.28149414e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -9.51232910e-02,  -9.51232910e-02],
                        [ -9.90905762e-02,  -9.90905762e-02],
                        [ -8.05664062e-02,  -8.05664062e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  8.03527832e-02,   8.03527832e-02],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  1.14959717e-01,   1.14959717e-01],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  5.76477051e-02,   5.76477051e-02],
                        [  4.73937988e-02,   4.73937988e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  3.87878418e-02,   3.87878418e-02],
                        [  4.74853516e-02,   4.74853516e-02],
                        [  5.37719727e-02,   5.37719727e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  6.90612793e-02,   6.90612793e-02],
                        [  8.60290527e-02,   8.60290527e-02],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  1.14410400e-01,   1.14410400e-01],
                        [  1.09222412e-01,   1.09222412e-01],
                        [  9.45739746e-02,   9.45739746e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.04052734e-02,   4.04052734e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.87780762e-02,   2.87780762e-02],
                        [  3.11279297e-02,   3.11279297e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.37731934e-02,   2.37731934e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  2.31018066e-02,   2.31018066e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  8.94165039e-03,   8.94165039e-03],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.78222656e-02,   1.78222656e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  2.50244141e-03,   2.50244141e-03],
                        [ -5.03540039e-03,  -5.03540039e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.70483398e-02,  -3.70483398e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -3.77502441e-02,  -3.77197266e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -1.93481445e-02,  -1.93481445e-02],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  1.98364258e-03,   1.98364258e-03],
                        [  1.36718750e-02,   1.36718750e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  5.56640625e-02,   5.56640625e-02],
                        [  7.36694336e-02,   7.36694336e-02],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  1.20727539e-01,   1.20727539e-01],
                        [  1.35559082e-01,   1.35559082e-01],
                        [  1.33941650e-01,   1.33941650e-01],
                        [  1.05102539e-01,   1.05102539e-01],
                        [  4.27246094e-02,   4.27246094e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -1.38916016e-01,  -1.38916016e-01],
                        [ -2.17559814e-01,  -2.17559814e-01],
                        [ -2.60894775e-01,  -2.60894775e-01],
                        [ -2.56408691e-01,  -2.56408691e-01],
                        [ -2.10906982e-01,  -2.10906982e-01],
                        [ -1.51977539e-01,  -1.51947021e-01],
                        [ -1.08337402e-01,  -1.08337402e-01],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -6.20422363e-02,  -6.20422363e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -4.44641113e-02,  -4.44641113e-02],
                        [ -7.33642578e-02,  -7.33642578e-02],
                        [ -1.07971191e-01,  -1.07971191e-01],
                        [ -1.34735107e-01,  -1.34735107e-01],
                        [ -1.41296387e-01,  -1.41296387e-01],
                        [ -1.18438721e-01,  -1.18438721e-01],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [  4.27246094e-03,   4.27246094e-03],
                        [  7.03430176e-02,   7.03430176e-02],
                        [  1.11297607e-01,   1.11297607e-01],
                        [  1.19567871e-01,   1.19567871e-01],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  4.59594727e-02,   4.59594727e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  5.68542480e-02,   5.68542480e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  6.59179688e-02,   6.59179688e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  1.05804443e-01,   1.05804443e-01],
                        [  1.15325928e-01,   1.15325928e-01],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  5.51452637e-02,   5.51452637e-02],
                        [  5.34667969e-02,   5.34667969e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  4.13818359e-02,   4.13818359e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  2.49328613e-02,   2.49328613e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  1.69982910e-02,   1.69982910e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  3.23486328e-03,   3.23486328e-03],
                        [  3.63159180e-03,   3.63159180e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.10351562e-03,  -6.10351562e-03],
                        [ -9.42993164e-03,  -9.42993164e-03],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [ -2.38037109e-02,  -2.38037109e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.71093750e-02,  -3.71093750e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.25317383e-02,  -3.25317383e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -4.35180664e-02,  -4.35180664e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -4.64477539e-02,  -4.64477539e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -2.63977051e-02,  -2.63977051e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.12304688e-02,  -1.12304688e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -4.55932617e-02,  -4.55932617e-02],
                        [ -4.42199707e-02,  -4.42199707e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  7.78198242e-03,   7.78198242e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  5.78918457e-02,   5.78918457e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  8.68835449e-02,   8.68835449e-02],
                        [  1.12945557e-01,   1.12945557e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.35345459e-01,   1.35345459e-01],
                        [  1.12426758e-01,   1.12457275e-01],
                        [  5.99670410e-02,   5.99670410e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [ -1.17919922e-01,  -1.17919922e-01],
                        [ -2.09442139e-01,  -2.09442139e-01],
                        [ -2.69561768e-01,  -2.69561768e-01],
                        [ -2.79541016e-01,  -2.79541016e-01],
                        [ -2.41851807e-01,  -2.41851807e-01],
                        [ -1.81671143e-01,  -1.81671143e-01],
                        [ -1.27258301e-01,  -1.27258301e-01],
                        [ -8.84704590e-02,  -8.84704590e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -7.16552734e-02,  -7.16552734e-02],
                        [ -1.16241455e-01,  -1.16241455e-01],
                        [ -1.56799316e-01,  -1.56799316e-01],
                        [ -1.76544189e-01,  -1.76544189e-01],
                        [ -1.64428711e-01,  -1.64428711e-01],
                        [ -1.19293213e-01,  -1.19293213e-01],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  8.77075195e-02,   8.77075195e-02],
                        [  1.28082275e-01,   1.28082275e-01],
                        [  1.43920898e-01,   1.43920898e-01],
                        [  1.39495850e-01,   1.39495850e-01],
                        [  1.22070312e-01,   1.22070312e-01],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  6.29882812e-02,   6.29882812e-02],
                        [  5.13916016e-02,   5.13916016e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  5.88684082e-02,   5.88684082e-02],
                        [  7.53784180e-02,   7.53784180e-02],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  1.07269287e-01,   1.07269287e-01],
                        [  1.21276855e-01,   1.21276855e-01],
                        [  1.26251221e-01,   1.26251221e-01],
                        [  1.15386963e-01,   1.15386963e-01],
                        [  9.27734375e-02,   9.27734375e-02],
                        [  6.97937012e-02,   6.97937012e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  6.99462891e-02,   6.99462891e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  6.93359375e-02,   6.93359375e-02],
                        [  5.74951172e-02,   5.74951172e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  3.56445312e-02,   3.56445312e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  1.28173828e-02,   1.28173828e-02],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  2.38647461e-02,   2.38647461e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  3.63769531e-02,   3.63769531e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.64489746e-02,   1.64489746e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  4.97436523e-03,   4.97436523e-03],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -3.02429199e-02,  -3.02429199e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.62145996e-02,  -2.62145996e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -4.93774414e-02,  -4.93774414e-02],
                        [ -5.30090332e-02,  -5.29785156e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.51965332e-02,  -4.51965332e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -3.75671387e-02,  -3.75671387e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -4.32128906e-02,  -4.32128906e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.57470703e-02,  -1.57470703e-02],
                        [ -1.39465332e-02,  -1.39465332e-02],
                        [ -1.00708008e-02,  -1.00708008e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  6.86645508e-03,   6.86645508e-03],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  4.97741699e-02,   4.97741699e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  1.02447510e-01,   1.02447510e-01],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  1.43249512e-01,   1.43249512e-01],
                        [  1.45812988e-01,   1.45812988e-01],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  6.75659180e-02,   6.75659180e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -1.08032227e-01,  -1.08032227e-01],
                        [ -2.03063965e-01,  -2.03063965e-01],
                        [ -2.69409180e-01,  -2.69409180e-01],
                        [ -2.84667969e-01,  -2.84667969e-01],
                        [ -2.48565674e-01,  -2.48565674e-01],
                        [ -1.86340332e-01,  -1.86340332e-01],
                        [ -1.30126953e-01,  -1.30126953e-01],
                        [ -9.46350098e-02,  -9.46350098e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -5.80749512e-02,  -5.80749512e-02],
                        [ -5.17272949e-02,  -5.17272949e-02],
                        [ -6.68334961e-02,  -6.68334961e-02],
                        [ -1.06048584e-01,  -1.06048584e-01],
                        [ -1.54418945e-01,  -1.54418945e-01],
                        [ -1.89849854e-01,  -1.89849854e-01],
                        [ -1.97540283e-01,  -1.97540283e-01],
                        [ -1.74987793e-01,  -1.74987793e-01],
                        [ -1.28387451e-01,  -1.28387451e-01],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [  5.47485352e-02,   5.47485352e-02],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  1.36535645e-01,   1.36535645e-01],
                        [  1.46057129e-01,   1.46057129e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  7.86743164e-02,   7.86743164e-02],
                        [  8.86230469e-02,   8.86230469e-02],
                        [  9.40856934e-02,   9.40856934e-02],
                        [  1.01379395e-01,   1.01379395e-01],
                        [  1.14044189e-01,   1.14044189e-01],
                        [  1.26220703e-01,   1.26220703e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.20635986e-01,   1.20635986e-01],
                        [  1.06170654e-01,   1.06170654e-01],
                        [  9.14306641e-02,   9.14306641e-02],
                        [  7.86743164e-02,   7.86743164e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.71594238e-02,   5.71594238e-02],
                        [  5.23376465e-02,   5.23376465e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.58386230e-02,   1.58386230e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  5.06591797e-03,   5.06591797e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [  6.95800781e-03,   6.95800781e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  4.57763672e-03,   4.57763672e-03],
                        [  9.61303711e-03,   9.61303711e-03],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  7.29370117e-03,   7.32421875e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  3.44848633e-03,   3.44848633e-03],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [ -1.72729492e-02,  -1.72729492e-02],
                        [ -1.99279785e-02,  -1.99279785e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -2.34375000e-02,  -2.34375000e-02],
                        [ -2.74658203e-02,  -2.74658203e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.83911133e-02,  -3.83911133e-02],
                        [ -4.36096191e-02,  -4.36096191e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.51354980e-02,  -4.51354980e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.11376953e-02,  -4.11376953e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.89599609e-02,  -5.89599609e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.09130859e-02,  -6.09130859e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  2.06909180e-02,   2.06909180e-02],
                        [  3.52783203e-02,   3.52783203e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  6.87866211e-02,   6.87866211e-02],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.46209717e-01,   1.46209717e-01],
                        [  1.53991699e-01,   1.53991699e-01],
                        [  1.33636475e-01,   1.33636475e-01],
                        [  8.07189941e-02,   8.07189941e-02],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.03363037e-01,  -1.03363037e-01],
                        [ -2.04650879e-01,  -2.04650879e-01],
                        [ -2.73468018e-01,  -2.73468018e-01],
                        [ -2.84454346e-01,  -2.84454346e-01],
                        [ -2.38616943e-01,  -2.38616943e-01],
                        [ -1.63726807e-01,  -1.63726807e-01],
                        [ -9.53979492e-02,  -9.53979492e-02],
                        [ -5.42602539e-02,  -5.42602539e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [ -4.17175293e-02,  -4.17175293e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -9.33532715e-02,  -9.33532715e-02],
                        [ -1.40777588e-01,  -1.40777588e-01],
                        [ -1.85943604e-01,  -1.85943604e-01],
                        [ -2.09350586e-01,  -2.09350586e-01],
                        [ -1.98638916e-01,  -1.98638916e-01],
                        [ -1.58721924e-01,  -1.58721924e-01],
                        [ -1.09069824e-01,  -1.09069824e-01],
                        [ -6.56738281e-02,  -6.56738281e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  1.00067139e-01,   1.00067139e-01],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.33728027e-01,   1.33728027e-01],
                        [  1.17431641e-01,   1.17431641e-01],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  8.32824707e-02,   8.32824707e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.09008789e-01,   1.09008789e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  1.44958496e-01,   1.44958496e-01],
                        [  1.50970459e-01,   1.50970459e-01],
                        [  1.42242432e-01,   1.42242432e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  8.40454102e-02,   8.40454102e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  8.40454102e-02,   8.40454102e-02],
                        [  8.04443359e-02,   8.04443359e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.79626465e-02,   6.79626465e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -4.88281250e-03,  -4.88281250e-03],
                        [ -5.67626953e-03,  -5.67626953e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  9.58251953e-03,   9.58251953e-03],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  2.12402344e-02,   2.12402344e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  1.83105469e-04,   1.83105469e-04],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  9.03320312e-03,   9.03320312e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  1.40380859e-02,   1.40380859e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -2.45361328e-02,  -2.45361328e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -4.46166992e-02,  -4.46166992e-02],
                        [ -4.65393066e-02,  -4.65393066e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -5.26123047e-02,  -5.26123047e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -5.16357422e-02,  -5.16357422e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -4.59899902e-02,  -4.59899902e-02],
                        [ -4.76074219e-02,  -4.76074219e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -5.23986816e-02,  -5.23986816e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.73132324e-02,  -2.73132324e-02],
                        [ -2.31323242e-02,  -2.31323242e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -1.39160156e-02,  -1.39160156e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  1.70898438e-03,   1.70898438e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  4.92858887e-02,   4.92858887e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  1.21551514e-01,   1.21551514e-01],
                        [  1.49047852e-01,   1.49047852e-01],
                        [  1.58081055e-01,   1.58081055e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  9.18884277e-02,   9.18884277e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [ -8.56323242e-02,  -8.56323242e-02],
                        [ -1.88720703e-01,  -1.88720703e-01],
                        [ -2.60437012e-01,  -2.60437012e-01],
                        [ -2.76031494e-01,  -2.76031494e-01],
                        [ -2.35717773e-01,  -2.35717773e-01],
                        [ -1.64123535e-01,  -1.64123535e-01],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -5.34973145e-02,  -5.34667969e-02],
                        [ -4.03442383e-02,  -4.03442383e-02],
                        [ -4.74853516e-02,  -4.74853516e-02],
                        [ -7.05566406e-02,  -7.05566406e-02],
                        [ -1.09497070e-01,  -1.09497070e-01],
                        [ -1.57409668e-01,  -1.57409668e-01],
                        [ -1.97570801e-01,  -1.97570801e-01],
                        [ -2.13012695e-01,  -2.13012695e-01],
                        [ -1.98150635e-01,  -1.98150635e-01],
                        [ -1.61926270e-01,  -1.61926270e-01],
                        [ -1.20208740e-01,  -1.20208740e-01],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -4.71191406e-02,  -4.71191406e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  5.16357422e-02,   5.16357422e-02],
                        [  1.05438232e-01,   1.05438232e-01],
                        [  1.43280029e-01,   1.43280029e-01],
                        [  1.55731201e-01,   1.55731201e-01],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  9.26513672e-02,   9.26513672e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  9.01184082e-02,   9.01184082e-02],
                        [  9.52453613e-02,   9.52453613e-02],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  1.03881836e-01,   1.03881836e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.36322021e-01,   1.36322021e-01],
                        [  1.47888184e-01,   1.47888184e-01],
                        [  1.45324707e-01,   1.45324707e-01],
                        [  1.28509521e-01,   1.28509521e-01],
                        [  1.06079102e-01,   1.06048584e-01],
                        [  8.91113281e-02,   8.91113281e-02],
                        [  8.19702148e-02,   8.19702148e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  7.77282715e-02,   7.77282715e-02],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  4.80041504e-02,   4.80041504e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  1.69677734e-02,   1.69982910e-02],
                        [  1.97753906e-02,   1.97753906e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.86865234e-03,   2.86865234e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -2.25524902e-02,  -2.25219727e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -2.83813477e-02,  -2.83813477e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -4.54101562e-02,  -4.54101562e-02],
                        [ -5.63659668e-02,  -5.63659668e-02],
                        [ -6.32629395e-02,  -6.32629395e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -6.43310547e-02,  -6.43310547e-02],
                        [ -5.86547852e-02,  -5.86547852e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -3.13110352e-02,  -3.13110352e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -2.39868164e-02,  -2.39562988e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -3.47900391e-03,  -3.47900391e-03],
                        [ -7.20214844e-03,  -7.20214844e-03],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -9.58251953e-03,  -9.58251953e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  6.09130859e-02,   6.09130859e-02],
                        [  7.90710449e-02,   7.90710449e-02],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.41601562e-01,   1.41601562e-01],
                        [  1.44165039e-01,   1.44165039e-01],
                        [  1.21185303e-01,   1.21185303e-01],
                        [  7.11669922e-02,   7.11669922e-02],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [ -9.12475586e-02,  -9.12475586e-02],
                        [ -1.82037354e-01,  -1.82037354e-01],
                        [ -2.46765137e-01,  -2.46765137e-01],
                        [ -2.57720947e-01,  -2.57720947e-01],
                        [ -2.12066650e-01,  -2.12066650e-01],
                        [ -1.40716553e-01,  -1.40716553e-01],
                        [ -8.52966309e-02,  -8.52966309e-02],
                        [ -6.57348633e-02,  -6.57348633e-02],
                        [ -7.29675293e-02,  -7.29675293e-02],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -1.39251709e-01,  -1.39251709e-01],
                        [ -1.69250488e-01,  -1.69250488e-01],
                        [ -1.85882568e-01,  -1.85882568e-01],
                        [ -1.79840088e-01,  -1.79840088e-01],
                        [ -1.57592773e-01,  -1.57592773e-01],
                        [ -1.32293701e-01,  -1.32293701e-01],
                        [ -1.10076904e-01,  -1.10076904e-01],
                        [ -8.70666504e-02,  -8.70666504e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -1.56555176e-02,  -1.56555176e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  8.31604004e-02,   8.31604004e-02],
                        [  1.21276855e-01,   1.21276855e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.17889404e-01,   1.17889404e-01],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  8.42895508e-02,   8.42895508e-02],
                        [  8.46862793e-02,   8.46862793e-02],
                        [  9.10644531e-02,   9.10644531e-02],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.40838623e-01,   1.40838623e-01],
                        [  1.37847900e-01,   1.37847900e-01],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.04797363e-01,   1.04797363e-01],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  7.48596191e-02,   7.48596191e-02],
                        [  6.94274902e-02,   6.94274902e-02],
                        [  6.78405762e-02,   6.78405762e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  6.53381348e-02,   6.53381348e-02],
                        [  6.08520508e-02,   6.08520508e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  3.32641602e-02,   3.32641602e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  7.87353516e-03,   7.87353516e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -3.54003906e-03,  -3.54003906e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  8.88061523e-03,   8.88061523e-03],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.73034668e-02,   1.73034668e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -4.02832031e-03,  -4.02832031e-03],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -1.48315430e-02,  -1.48315430e-02],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -2.14538574e-02,  -2.14538574e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -4.08325195e-02,  -4.08325195e-02],
                        [ -5.13000488e-02,  -5.13000488e-02],
                        [ -5.31005859e-02,  -5.31005859e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.84826660e-02,  -3.84826660e-02],
                        [ -4.01611328e-02,  -4.01611328e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -4.21447754e-02,  -4.21447754e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  1.12915039e-03,   1.12915039e-03],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  3.54003906e-02,   3.53698730e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  9.56726074e-02,   9.56726074e-02],
                        [  1.33911133e-01,   1.33911133e-01],
                        [  1.62994385e-01,   1.62994385e-01],
                        [  1.62963867e-01,   1.62963867e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  6.53686523e-02,   6.53686523e-02],
                        [ -1.66625977e-02,  -1.66625977e-02],
                        [ -1.08581543e-01,  -1.08581543e-01],
                        [ -1.92382812e-01,  -1.92382812e-01],
                        [ -2.41699219e-01,  -2.41699219e-01],
                        [ -2.37762451e-01,  -2.37762451e-01],
                        [ -1.86859131e-01,  -1.86859131e-01],
                        [ -1.19750977e-01,  -1.19750977e-01],
                        [ -7.22961426e-02,  -7.22961426e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -8.56018066e-02,  -8.56018066e-02],
                        [ -1.22619629e-01,  -1.22619629e-01],
                        [ -1.59057617e-01,  -1.59057617e-01],
                        [ -1.84967041e-01,  -1.84967041e-01],
                        [ -1.91955566e-01,  -1.91955566e-01],
                        [ -1.77398682e-01,  -1.77398682e-01],
                        [ -1.49261475e-01,  -1.49261475e-01],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -1.00494385e-01,  -1.00494385e-01],
                        [ -8.59375000e-02,  -8.59375000e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -5.05981445e-02,  -5.05981445e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  1.37786865e-01,   1.37786865e-01],
                        [  1.52984619e-01,   1.52984619e-01],
                        [  1.43859863e-01,   1.43859863e-01],
                        [  1.22497559e-01,   1.22497559e-01],
                        [  1.04064941e-01,   1.04064941e-01],
                        [  9.40551758e-02,   9.40551758e-02],
                        [  9.14001465e-02,   9.14001465e-02],
                        [  9.80529785e-02,   9.80529785e-02],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.58538818e-01,   1.58538818e-01],
                        [  1.65527344e-01,   1.65527344e-01],
                        [  1.57684326e-01,   1.57684326e-01],
                        [  1.35040283e-01,   1.35040283e-01],
                        [  1.05346680e-01,   1.05346680e-01],
                        [  8.16345215e-02,   8.16345215e-02],
                        [  6.99768066e-02,   6.99768066e-02],
                        [  6.56433105e-02,   6.56433105e-02],
                        [  6.21948242e-02,   6.21948242e-02],
                        [  5.81970215e-02,   5.81970215e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  5.38635254e-02,   5.38635254e-02],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  8.88061523e-03,   8.85009766e-03],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  1.48315430e-02,   1.48315430e-02],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  1.38244629e-02,   1.37939453e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -1.60827637e-02,  -1.60827637e-02],
                        [ -2.27355957e-02,  -2.27355957e-02],
                        [ -2.86254883e-02,  -2.86254883e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -4.78820801e-02,  -4.78820801e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -6.07299805e-02,  -6.07299805e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -6.14929199e-02,  -6.14929199e-02],
                        [ -6.22253418e-02,  -6.22253418e-02],
                        [ -6.30187988e-02,  -6.30187988e-02],
                        [ -6.17370605e-02,  -6.17370605e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.20324707e-02,  -5.20324707e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -3.78723145e-02,  -3.78723145e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.84631348e-02,  -1.84936523e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -1.77917480e-02,  -1.77917480e-02],
                        [ -1.01013184e-02,  -1.00708008e-02],
                        [  3.99780273e-03,   3.99780273e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  4.03137207e-02,   4.03137207e-02],
                        [  4.98046875e-02,   4.98046875e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  7.42187500e-02,   7.42187500e-02],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  1.23352051e-01,   1.23352051e-01],
                        [  1.41906738e-01,   1.41906738e-01],
                        [  1.44165039e-01,   1.44165039e-01],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  6.89697266e-02,   6.89697266e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -9.02404785e-02,  -9.02404785e-02],
                        [ -1.73278809e-01,  -1.73278809e-01],
                        [ -2.29797363e-01,  -2.29797363e-01],
                        [ -2.35992432e-01,  -2.35992432e-01],
                        [ -1.91101074e-01,  -1.91101074e-01],
                        [ -1.26373291e-01,  -1.26373291e-01],
                        [ -8.37402344e-02,  -8.37402344e-02],
                        [ -8.42285156e-02,  -8.42285156e-02],
                        [ -1.16973877e-01,  -1.16973877e-01],
                        [ -1.56463623e-01,  -1.56463623e-01],
                        [ -1.84265137e-01,  -1.84265137e-01],
                        [ -1.93725586e-01,  -1.93725586e-01],
                        [ -1.84478760e-01,  -1.84478760e-01],
                        [ -1.61651611e-01,  -1.61651611e-01],
                        [ -1.35162354e-01,  -1.35162354e-01],
                        [ -1.12670898e-01,  -1.12670898e-01],
                        [ -9.59472656e-02,  -9.59472656e-02],
                        [ -8.36181641e-02,  -8.36181641e-02],
                        [ -7.26318359e-02,  -7.26318359e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -3.82995605e-02,  -3.82995605e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [  3.81469727e-02,   3.81469727e-02],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.59088135e-01,   1.59088135e-01],
                        [  1.51489258e-01,   1.51489258e-01],
                        [  1.30554199e-01,   1.30554199e-01],
                        [  1.12640381e-01,   1.12640381e-01],
                        [  1.04248047e-01,   1.04248047e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.46087646e-01,   1.46087646e-01],
                        [  1.62292480e-01,   1.62292480e-01],
                        [  1.72271729e-01,   1.72271729e-01],
                        [  1.70715332e-01,   1.70715332e-01],
                        [  1.56677246e-01,   1.56677246e-01],
                        [  1.34338379e-01,   1.34338379e-01],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  5.60913086e-02,   5.60913086e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.91333008e-02,   4.91333008e-02],
                        [  5.47790527e-02,   5.47790527e-02],
                        [  5.86853027e-02,   5.86853027e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  4.60815430e-03,   4.60815430e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.61437988e-02,   1.61437988e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.22558594e-03,   6.22558594e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  3.16162109e-02,   3.16162109e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  3.35693359e-03,   3.35693359e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.94799805e-02,  -2.94799805e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.87780762e-02,  -2.87780762e-02],
                        [ -3.17077637e-02,  -3.17077637e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.72412109e-02,  -4.72412109e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -6.71997070e-02,  -6.71997070e-02],
                        [ -6.85119629e-02,  -6.85119629e-02],
                        [ -6.38732910e-02,  -6.38732910e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.57763672e-02,  -4.57763672e-02],
                        [ -3.82690430e-02,  -3.82690430e-02],
                        [ -3.29284668e-02,  -3.29284668e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.53393555e-02,  -3.53088379e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.91040039e-02,  -1.91040039e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [  7.20214844e-03,   7.20214844e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  1.91955566e-02,   1.91955566e-02],
                        [  2.57873535e-02,   2.57873535e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  1.11816406e-01,   1.11816406e-01],
                        [  1.33666992e-01,   1.33666992e-01],
                        [  1.48559570e-01,   1.48559570e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.25976562e-01,   1.25976562e-01],
                        [  7.56530762e-02,   7.56530762e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -9.27429199e-02,  -9.27429199e-02],
                        [ -1.77368164e-01,  -1.77368164e-01],
                        [ -2.28546143e-01,  -2.28546143e-01],
                        [ -2.28210449e-01,  -2.28210449e-01],
                        [ -1.83074951e-01,  -1.83074951e-01],
                        [ -1.27563477e-01,  -1.27563477e-01],
                        [ -9.98229980e-02,  -9.98229980e-02],
                        [ -1.12121582e-01,  -1.12121582e-01],
                        [ -1.47857666e-01,  -1.47857666e-01],
                        [ -1.82342529e-01,  -1.82342529e-01],
                        [ -1.98486328e-01,  -1.98486328e-01],
                        [ -1.90979004e-01,  -1.90979004e-01],
                        [ -1.66259766e-01,  -1.66259766e-01],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -1.14410400e-01,  -1.14410400e-01],
                        [ -1.00555420e-01,  -1.00555420e-01],
                        [ -9.22241211e-02,  -9.22241211e-02],
                        [ -8.42590332e-02,  -8.42590332e-02],
                        [ -7.36389160e-02,  -7.36389160e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -4.13513184e-02,  -4.13818359e-02],
                        [ -1.35498047e-02,  -1.35498047e-02],
                        [  2.90832520e-02,   2.90832520e-02],
                        [  8.33740234e-02,   8.33740234e-02],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.61041260e-01,   1.61041260e-01],
                        [  1.61102295e-01,   1.61102295e-01],
                        [  1.44317627e-01,   1.44317627e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.22955322e-01,   1.22955322e-01],
                        [  1.38488770e-01,   1.38458252e-01],
                        [  1.53808594e-01,   1.53808594e-01],
                        [  1.63818359e-01,   1.63818359e-01],
                        [  1.64245605e-01,   1.64245605e-01],
                        [  1.52862549e-01,   1.52862549e-01],
                        [  1.34246826e-01,   1.34246826e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  1.04003906e-01,   1.04003906e-01],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  7.03735352e-02,   7.03735352e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  6.16760254e-02,   6.16760254e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.96520996e-02,   4.96520996e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.62145996e-02,   2.62145996e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  1.75170898e-02,   1.75170898e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  2.44140625e-03,   2.44140625e-03],
                        [ -5.18798828e-03,  -5.18798828e-03],
                        [ -5.98144531e-03,  -5.98144531e-03],
                        [ -2.07519531e-03,  -2.07519531e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -3.59802246e-02,  -3.60107422e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -5.20019531e-02,  -5.20019531e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.61218262e-02,  -5.61523438e-02],
                        [ -5.42297363e-02,  -5.42297363e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.08422852e-02,  -5.08422852e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -4.99267578e-02,  -4.99267578e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.90515137e-02,  -5.90209961e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -5.25817871e-02,  -5.25817871e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.53503418e-02,  -1.53503418e-02],
                        [ -1.51062012e-02,  -1.51062012e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  1.34277344e-02,   1.34277344e-02],
                        [  2.01416016e-02,   2.01721191e-02],
                        [  2.87475586e-02,   2.87475586e-02],
                        [  4.37622070e-02,   4.37622070e-02],
                        [  6.15539551e-02,   6.15844727e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  1.27136230e-01,   1.27136230e-01],
                        [  1.41876221e-01,   1.41876221e-01],
                        [  1.42425537e-01,   1.42425537e-01],
                        [  1.19598389e-01,   1.19598389e-01],
                        [  6.67419434e-02,   6.67419434e-02],
                        [ -1.34887695e-02,  -1.34887695e-02],
                        [ -1.04492188e-01,  -1.04492188e-01],
                        [ -1.82128906e-01,  -1.82128906e-01],
                        [ -2.25280762e-01,  -2.25280762e-01],
                        [ -2.23083496e-01,  -2.23083496e-01],
                        [ -1.84967041e-01,  -1.84967041e-01],
                        [ -1.44165039e-01,  -1.44165039e-01],
                        [ -1.36108398e-01,  -1.36108398e-01],
                        [ -1.67053223e-01,  -1.67053223e-01],
                        [ -2.10479736e-01,  -2.10449219e-01],
                        [ -2.32879639e-01,  -2.32879639e-01],
                        [ -2.20855713e-01,  -2.20855713e-01],
                        [ -1.86065674e-01,  -1.86065674e-01],
                        [ -1.49108887e-01,  -1.49108887e-01],
                        [ -1.21948242e-01,  -1.21948242e-01],
                        [ -1.03820801e-01,  -1.03820801e-01],
                        [ -8.71582031e-02,  -8.71582031e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -5.06591797e-02,  -5.06591797e-02],
                        [ -4.45251465e-02,  -4.44946289e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [  1.31835938e-02,   1.31835938e-02],
                        [  6.49108887e-02,   6.49108887e-02],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  1.56585693e-01,   1.56585693e-01],
                        [  1.69616699e-01,   1.69616699e-01],
                        [  1.56250000e-01,   1.56280518e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  1.05316162e-01,   1.05285645e-01],
                        [  9.85107422e-02,   9.84802246e-02],
                        [  1.11267090e-01,   1.11267090e-01],
                        [  1.37756348e-01,   1.37756348e-01],
                        [  1.66290283e-01,   1.66259766e-01],
                        [  1.84722900e-01,   1.84753418e-01],
                        [  1.87896729e-01,   1.87896729e-01],
                        [  1.77124023e-01,   1.77124023e-01],
                        [  1.55303955e-01,   1.55303955e-01],
                        [  1.26281738e-01,   1.26281738e-01],
                        [  9.69848633e-02,   9.69543457e-02],
                        [  7.43408203e-02,   7.43408203e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  6.11877441e-02,   6.11877441e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.62963867e-02,   1.63269043e-02],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  8.45336914e-03,   8.42285156e-03],
                        [  5.15747070e-03,   5.15747070e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  5.67626953e-03,   5.70678711e-03],
                        [  4.02832031e-03,   4.05883789e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  1.21154785e-02,   1.21154785e-02],
                        [  1.85852051e-02,   1.85852051e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.65808105e-02,   2.65808105e-02],
                        [  2.53906250e-02,   2.53906250e-02],
                        [  1.91345215e-02,   1.91345215e-02],
                        [  8.57543945e-03,   8.57543945e-03],
                        [ -2.13623047e-03,  -2.13623047e-03],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -1.07116699e-02,  -1.07116699e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.03149414e-02,  -1.03149414e-02],
                        [ -1.41601562e-02,  -1.41601562e-02],
                        [ -1.71508789e-02,  -1.71813965e-02],
                        [ -1.95617676e-02,  -1.95922852e-02],
                        [ -2.47192383e-02,  -2.46887207e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -4.44946289e-02,  -4.44946289e-02],
                        [ -5.57250977e-02,  -5.56945801e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -6.32934570e-02,  -6.33239746e-02],
                        [ -5.75561523e-02,  -5.75561523e-02],
                        [ -5.45654297e-02,  -5.45349121e-02],
                        [ -5.68237305e-02,  -5.68237305e-02],
                        [ -5.83496094e-02,  -5.83496094e-02],
                        [ -5.62744141e-02,  -5.62744141e-02],
                        [ -5.47485352e-02,  -5.47485352e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -5.76782227e-02,  -5.76782227e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -5.43518066e-02,  -5.43518066e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [  2.83813477e-03,   2.86865234e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.27050781e-02,   2.26745605e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  6.83593750e-02,   6.83593750e-02],
                        [  9.73510742e-02,   9.73205566e-02],
                        [  1.28936768e-01,   1.28967285e-01],
                        [  1.53198242e-01,   1.53228760e-01],
                        [  1.59362793e-01,   1.59362793e-01],
                        [  1.41265869e-01,   1.41265869e-01],
                        [  9.82055664e-02,   9.82360840e-02],
                        [  3.33557129e-02,   3.33557129e-02],
                        [ -4.67224121e-02,  -4.67224121e-02],
                        [ -1.29821777e-01,  -1.29791260e-01],
                        [ -1.95678711e-01,  -1.95678711e-01],
                        [ -2.24517822e-01,  -2.24517822e-01],
                        [ -2.18017578e-01,  -2.18017578e-01],
                        [ -2.04284668e-01,  -2.04284668e-01],
                        [ -2.08801270e-01,  -2.08801270e-01],
                        [ -2.27600098e-01,  -2.27600098e-01],
                        [ -2.38098145e-01,  -2.38098145e-01],
                        [ -2.26715088e-01,  -2.26715088e-01],
                        [ -1.96929932e-01,  -1.96929932e-01],
                        [ -1.60217285e-01,  -1.60217285e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -1.11022949e-01,  -1.11022949e-01],
                        [ -9.99755859e-02,  -9.99755859e-02],
                        [ -8.28552246e-02,  -8.28552246e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -1.72119141e-02,  -1.72424316e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  4.41589355e-02,   4.41589355e-02],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  1.25701904e-01,   1.25701904e-01],
                        [  1.42333984e-01,   1.42333984e-01],
                        [  1.41754150e-01,   1.41754150e-01],
                        [  1.34429932e-01,   1.34429932e-01],
                        [  1.30371094e-01,   1.30371094e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  1.59576416e-01,   1.59545898e-01],
                        [  1.88934326e-01,   1.88934326e-01],
                        [  2.08953857e-01,   2.08984375e-01],
                        [  2.09808350e-01,   2.09777832e-01],
                        [  1.94335938e-01,   1.94305420e-01],
                        [  1.69891357e-01,   1.69891357e-01],
                        [  1.42547607e-01,   1.42578125e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  9.50927734e-02,   9.50927734e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  5.81359863e-02,   5.81054688e-02],
                        [  4.90722656e-02,   4.90722656e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  2.23693848e-02,   2.23388672e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.04064941e-02,   1.04370117e-02],
                        [  9.46044922e-03,   9.42993164e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  7.26318359e-03,   7.29370117e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  9.18579102e-03,   9.15527344e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.98669434e-02,   1.98669434e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  2.73132324e-02,   2.73132324e-02],
                        [  1.89514160e-02,   1.89514160e-02],
                        [  5.70678711e-03,   5.70678711e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  7.47680664e-03,   7.47680664e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [ -2.71606445e-03,  -2.71606445e-03],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -3.60717773e-02,  -3.61022949e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -4.47082520e-02,  -4.46777344e-02],
                        [ -5.10559082e-02,  -5.10559082e-02],
                        [ -5.31311035e-02,  -5.31311035e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -4.75463867e-02,  -4.75463867e-02],
                        [ -4.69360352e-02,  -4.69665527e-02],
                        [ -4.96215820e-02,  -4.96215820e-02],
                        [ -5.53588867e-02,  -5.53588867e-02],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -6.21337891e-02,  -6.21337891e-02],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -4.14428711e-02,  -4.14428711e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.25109863e-02,  -4.24804688e-02],
                        [ -5.09948730e-02,  -5.09948730e-02],
                        [ -5.78613281e-02,  -5.78918457e-02],
                        [ -5.90209961e-02,  -5.90209961e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.79125977e-02,  -4.79125977e-02],
                        [ -3.98864746e-02,  -3.99169922e-02],
                        [ -2.94189453e-02,  -2.93884277e-02],
                        [ -1.62963867e-02,  -1.62963867e-02],
                        [ -3.78417969e-03,  -3.81469727e-03],
                        [  3.20434570e-03,   3.23486328e-03],
                        [  3.29589844e-03,   3.29589844e-03],
                        [  1.46484375e-03,   1.43432617e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  3.93676758e-03,   3.96728516e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  8.39538574e-02,   8.39538574e-02],
                        [  1.16027832e-01,   1.16027832e-01],
                        [  1.48376465e-01,   1.48376465e-01],
                        [  1.71997070e-01,   1.71997070e-01],
                        [  1.76818848e-01,   1.76818848e-01],
                        [  1.57897949e-01,   1.57897949e-01],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  4.18701172e-02,   4.18701172e-02],
                        [ -5.05065918e-02,  -5.05065918e-02],
                        [ -1.45172119e-01,  -1.45172119e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -2.58392334e-01,  -2.58392334e-01],
                        [ -2.67700195e-01,  -2.67700195e-01],
                        [ -2.60406494e-01,  -2.60406494e-01],
                        [ -2.49816895e-01,  -2.49816895e-01],
                        [ -2.41760254e-01,  -2.41760254e-01],
                        [ -2.29827881e-01,  -2.29827881e-01],
                        [ -2.02819824e-01,  -2.02819824e-01],
                        [ -1.62445068e-01,  -1.62445068e-01],
                        [ -1.25885010e-01,  -1.25885010e-01],
                        [ -1.05316162e-01,  -1.05316162e-01],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -7.64465332e-02,  -7.64465332e-02],
                        [ -5.64880371e-02,  -5.64880371e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -4.54711914e-02,  -4.54406738e-02],
                        [ -4.82482910e-02,  -4.82482910e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -4.44030762e-02,  -4.44030762e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  4.85534668e-02,   4.85534668e-02],
                        [  8.49304199e-02,   8.49304199e-02],
                        [  1.18743896e-01,   1.18743896e-01],
                        [  1.47521973e-01,   1.47552490e-01],
                        [  1.66992188e-01,   1.67022705e-01],
                        [  1.76544189e-01,   1.76544189e-01],
                        [  1.82373047e-01,   1.82373047e-01],
                        [  1.91497803e-01,   1.91497803e-01],
                        [  2.02789307e-01,   2.02758789e-01],
                        [  2.07611084e-01,   2.07611084e-01],
                        [  1.99798584e-01,   1.99829102e-01],
                        [  1.81945801e-01,   1.81945801e-01],
                        [  1.59973145e-01,   1.59973145e-01],
                        [  1.36627197e-01,   1.36627197e-01],
                        [  1.13647461e-01,   1.13616943e-01],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  5.87463379e-02,   5.87463379e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.83508301e-02,   2.83203125e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  1.74560547e-02,   1.74560547e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.33666992e-02,   1.33666992e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  5.64575195e-03,   5.67626953e-03],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  3.08227539e-03,   3.08227539e-03],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.28881836e-02,   2.28881836e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.24609375e-02,   2.24609375e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  8.54492188e-03,   8.57543945e-03],
                        [  3.41796875e-03,   3.38745117e-03],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [ -2.02941895e-02,  -2.02941895e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.86254883e-02,  -2.86560059e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.58789062e-02,  -2.58789062e-02],
                        [ -2.81372070e-02,  -2.81372070e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -5.21545410e-02,  -5.21545410e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -6.37817383e-02,  -6.37512207e-02],
                        [ -6.75659180e-02,  -6.75659180e-02],
                        [ -6.37512207e-02,  -6.37817383e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -5.32836914e-02,  -5.32531738e-02],
                        [ -5.52978516e-02,  -5.53283691e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -4.90722656e-02,  -4.90722656e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -1.94702148e-02,  -1.95007324e-02],
                        [ -8.72802734e-03,  -8.72802734e-03],
                        [ -1.80053711e-03,  -1.77001953e-03],
                        [  6.40869141e-04,   6.40869141e-04],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.49230957e-02,  -1.49230957e-02],
                        [ -1.30004883e-02,  -1.30004883e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  1.79443359e-02,   1.79443359e-02],
                        [  2.65197754e-02,   2.65197754e-02],
                        [  3.70788574e-02,   3.70483398e-02],
                        [  4.58068848e-02,   4.58068848e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  6.34155273e-02,   6.33850098e-02],
                        [  8.81958008e-02,   8.81958008e-02],
                        [  1.24359131e-01,   1.24359131e-01],
                        [  1.63482666e-01,   1.63482666e-01],
                        [  1.94702148e-01,   1.94702148e-01],
                        [  2.02392578e-01,   2.02423096e-01],
                        [  1.70471191e-01,   1.70501709e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -2.44598389e-01,  -2.44598389e-01],
                        [ -3.17016602e-01,  -3.17016602e-01],
                        [ -3.38989258e-01,  -3.38989258e-01],
                        [ -3.17871094e-01,  -3.17871094e-01],
                        [ -2.76214600e-01,  -2.76214600e-01],
                        [ -2.34161377e-01,  -2.34161377e-01],
                        [ -1.98028564e-01,  -1.98028564e-01],
                        [ -1.65740967e-01,  -1.65740967e-01],
                        [ -1.38275146e-01,  -1.38275146e-01],
                        [ -1.20269775e-01,  -1.20269775e-01],
                        [ -1.10992432e-01,  -1.10992432e-01],
                        [ -1.01226807e-01,  -1.01257324e-01],
                        [ -8.41979980e-02,  -8.41979980e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -4.46777344e-02,  -4.47082520e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -2.54211426e-02,  -2.53906250e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -2.58789062e-02,  -2.59094238e-02],
                        [ -2.32238770e-02,  -2.32238770e-02],
                        [ -1.54418945e-02,  -1.54418945e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  1.80969238e-02,   1.81274414e-02],
                        [  5.27648926e-02,   5.27648926e-02],
                        [  9.96704102e-02,   9.96704102e-02],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.80541992e-01,   1.80541992e-01],
                        [  1.97937012e-01,   1.97937012e-01],
                        [  2.06604004e-01,   2.06604004e-01],
                        [  2.13104248e-01,   2.13104248e-01],
                        [  2.16186523e-01,   2.16156006e-01],
                        [  2.09777832e-01,   2.09777832e-01],
                        [  1.91253662e-01,   1.91253662e-01],
                        [  1.67205811e-01,   1.67205811e-01],
                        [  1.48803711e-01,   1.48803711e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.32720947e-01,   1.32690430e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  9.00268555e-02,   8.99963379e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  1.08642578e-02,   1.08642578e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.15148926e-02,   2.15148926e-02],
                        [  2.44750977e-02,   2.44750977e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  5.58471680e-03,   5.58471680e-03],
                        [ -1.09863281e-03,  -1.09863281e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  1.86157227e-02,   1.86462402e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  3.17382812e-02,   3.17382812e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -1.37329102e-02,  -1.37634277e-02],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  1.61743164e-03,   1.61743164e-03],
                        [ -1.61743164e-03,  -1.64794922e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -3.04870605e-02,  -3.05175781e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.73937988e-02,  -4.73632812e-02],
                        [ -4.98046875e-02,  -4.98046875e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -4.47387695e-02,  -4.47387695e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -5.00793457e-02,  -5.00793457e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -6.88781738e-02,  -6.88781738e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -7.29675293e-02,  -7.29675293e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -6.22253418e-02,  -6.21948242e-02],
                        [ -5.80444336e-02,  -5.80749512e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -5.45959473e-02,  -5.45959473e-02],
                        [ -4.63256836e-02,  -4.63256836e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -8.33129883e-03,  -8.33129883e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [  9.46044922e-04,   9.46044922e-04],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  1.73339844e-02,   1.73339844e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  2.18200684e-02,   2.17895508e-02],
                        [  3.03649902e-02,   3.03649902e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  8.49609375e-02,   8.49609375e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.68975830e-01,   1.68975830e-01],
                        [  2.06054688e-01,   2.06054688e-01],
                        [  2.13562012e-01,   2.13562012e-01],
                        [  1.81884766e-01,   1.81884766e-01],
                        [  1.08947754e-01,   1.08947754e-01],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -1.39709473e-01,  -1.39709473e-01],
                        [ -2.74017334e-01,  -2.74017334e-01],
                        [ -3.68377686e-01,  -3.68377686e-01],
                        [ -3.96087646e-01,  -3.96087646e-01],
                        [ -3.61175537e-01,  -3.61175537e-01],
                        [ -2.95440674e-01,  -2.95440674e-01],
                        [ -2.31842041e-01,  -2.31842041e-01],
                        [ -1.85455322e-01,  -1.85455322e-01],
                        [ -1.55883789e-01,  -1.55883789e-01],
                        [ -1.35742188e-01,  -1.35742188e-01],
                        [ -1.17218018e-01,  -1.17218018e-01],
                        [ -9.79614258e-02,  -9.79309082e-02],
                        [ -8.16650391e-02,  -8.16650391e-02],
                        [ -7.10754395e-02,  -7.10754395e-02],
                        [ -6.09741211e-02,  -6.09741211e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.62048340e-02,  -1.62048340e-02],
                        [ -2.91442871e-02,  -2.91442871e-02],
                        [ -3.69567871e-02,  -3.69873047e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [  1.05895996e-02,   1.05590820e-02],
                        [  6.37207031e-02,   6.37207031e-02],
                        [  1.25305176e-01,   1.25305176e-01],
                        [  1.80877686e-01,   1.80847168e-01],
                        [  2.21923828e-01,   2.21923828e-01],
                        [  2.45605469e-01,   2.45605469e-01],
                        [  2.52044678e-01,   2.52044678e-01],
                        [  2.45452881e-01,   2.45422363e-01],
                        [  2.31170654e-01,   2.31170654e-01],
                        [  2.12066650e-01,   2.12066650e-01],
                        [  1.90124512e-01,   1.90093994e-01],
                        [  1.68609619e-01,   1.68640137e-01],
                        [  1.50543213e-01,   1.50543213e-01],
                        [  1.35314941e-01,   1.35284424e-01],
                        [  1.18682861e-01,   1.18652344e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  7.75756836e-02,   7.75756836e-02],
                        [  5.91125488e-02,   5.91125488e-02],
                        [  4.12902832e-02,   4.12902832e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  7.99560547e-03,   7.96508789e-03],
                        [ -7.32421875e-04,  -7.32421875e-04],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [  1.25427246e-02,   1.25427246e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  4.46166992e-02,   4.46166992e-02],
                        [  4.04357910e-02,   4.04357910e-02],
                        [  3.45764160e-02,   3.45764160e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.95312500e-02,   1.95617676e-02],
                        [  1.04064941e-02,   1.03759766e-02],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  3.72314453e-03,   3.72314453e-03],
                        [  5.18798828e-03,   5.15747070e-03],
                        [  7.72094727e-03,   7.75146484e-03],
                        [  8.85009766e-03,   8.88061523e-03],
                        [  6.01196289e-03,   5.98144531e-03],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -6.28662109e-03,  -6.28662109e-03],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [ -8.11767578e-03,  -8.08715820e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  3.75366211e-03,   3.75366211e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -6.36291504e-02,  -6.35986328e-02],
                        [ -5.82275391e-02,  -5.81970215e-02],
                        [ -5.15747070e-02,  -5.16052246e-02],
                        [ -5.04760742e-02,  -5.04760742e-02],
                        [ -5.43518066e-02,  -5.43212891e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -6.94274902e-02,  -6.94274902e-02],
                        [ -6.79931641e-02,  -6.80236816e-02],
                        [ -6.32934570e-02,  -6.32934570e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -4.91333008e-02,  -4.91333008e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -2.68859863e-02,  -2.68554688e-02],
                        [ -2.17895508e-02,  -2.17895508e-02],
                        [ -2.23083496e-02,  -2.23388672e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -2.42614746e-02,  -2.42919922e-02],
                        [ -2.37731934e-02,  -2.37731934e-02],
                        [ -2.36511230e-02,  -2.36206055e-02],
                        [ -2.11791992e-02,  -2.11791992e-02],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -8.33129883e-03,  -8.30078125e-03],
                        [  1.15966797e-03,   1.12915039e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  3.04870605e-02,   3.04870605e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  5.01403809e-02,   5.01098633e-02],
                        [  5.70983887e-02,   5.71289062e-02],
                        [  6.62536621e-02,   6.62841797e-02],
                        [  8.04138184e-02,   8.04138184e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.34796143e-01,   1.34796143e-01],
                        [  1.70562744e-01,   1.70562744e-01],
                        [  1.99859619e-01,   1.99859619e-01],
                        [  2.07153320e-01,   2.07153320e-01],
                        [  1.77337646e-01,   1.77337646e-01],
                        [  1.01226807e-01,   1.01196289e-01],
                        [ -2.10266113e-02,  -2.10266113e-02],
                        [ -1.72821045e-01,  -1.72821045e-01],
                        [ -3.16619873e-01,  -3.16619873e-01],
                        [ -4.07073975e-01,  -4.07073975e-01],
                        [ -4.19342041e-01,  -4.19311523e-01],
                        [ -3.65417480e-01,  -3.65417480e-01],
                        [ -2.82318115e-01,  -2.82318115e-01],
                        [ -2.07580566e-01,  -2.07550049e-01],
                        [ -1.60430908e-01,  -1.60430908e-01],
                        [ -1.35131836e-01,  -1.35162354e-01],
                        [ -1.13555908e-01,  -1.13525391e-01],
                        [ -8.72497559e-02,  -8.72497559e-02],
                        [ -6.43920898e-02,  -6.43920898e-02],
                        [ -5.55419922e-02,  -5.55419922e-02],
                        [ -5.79833984e-02,  -5.79528809e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -1.30920410e-02,  -1.30615234e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  6.16455078e-03,   6.13403320e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -5.33752441e-02,  -5.34057617e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -5.18493652e-02,  -5.18188477e-02],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [  3.57666016e-02,   3.57360840e-02],
                        [  1.04187012e-01,   1.04217529e-01],
                        [  1.77032471e-01,   1.77032471e-01],
                        [  2.38403320e-01,   2.38403320e-01],
                        [  2.72918701e-01,   2.72918701e-01],
                        [  2.78350830e-01,   2.78381348e-01],
                        [  2.67395020e-01,   2.67395020e-01],
                        [  2.51953125e-01,   2.51953125e-01],
                        [  2.32818604e-01,   2.32818604e-01],
                        [  2.07763672e-01,   2.07763672e-01],
                        [  1.80389404e-01,   1.80358887e-01],
                        [  1.55120850e-01,   1.55120850e-01],
                        [  1.30950928e-01,   1.30950928e-01],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  8.29772949e-02,   8.29467773e-02],
                        [  6.36291504e-02,   6.36291504e-02],
                        [  4.74243164e-02,   4.74243164e-02],
                        [  3.43627930e-02,   3.43627930e-02],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  1.90124512e-02,   1.90429688e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.67846680e-02,   1.67846680e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.10266113e-02,   2.10266113e-02],
                        [  1.68457031e-02,   1.68151855e-02],
                        [  1.30004883e-02,   1.30004883e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  1.29089355e-02,   1.29089355e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.67541504e-02,   1.67846680e-02],
                        [  7.62939453e-03,   7.62939453e-03],
                        [ -4.88281250e-03,  -4.91333008e-03],
                        [ -1.31530762e-02,  -1.31530762e-02],
                        [ -1.73034668e-02,  -1.72729492e-02],
                        [ -1.98364258e-02,  -1.98669434e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -4.94384766e-03,  -4.97436523e-03],
                        [ -3.57055664e-03,  -3.57055664e-03],
                        [ -1.19018555e-02,  -1.18713379e-02],
                        [ -2.64282227e-02,  -2.64282227e-02],
                        [ -3.94897461e-02,  -3.95202637e-02],
                        [ -4.56848145e-02,  -4.56848145e-02],
                        [ -4.66613770e-02,  -4.66308594e-02],
                        [ -4.74548340e-02,  -4.74853516e-02],
                        [ -4.97131348e-02,  -4.97436523e-02],
                        [ -5.20629883e-02,  -5.20324707e-02],
                        [ -5.41076660e-02,  -5.41076660e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -6.08825684e-02,  -6.08825684e-02],
                        [ -6.41479492e-02,  -6.41479492e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -6.69860840e-02,  -6.69860840e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -7.05871582e-02,  -7.06176758e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -6.35681152e-02,  -6.35681152e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -4.98962402e-02,  -4.98657227e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -3.05480957e-02,  -3.05480957e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [ -1.01013184e-02,  -1.00708008e-02],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  2.63061523e-02,   2.63061523e-02],
                        [  3.19824219e-02,   3.19824219e-02],
                        [  3.49426270e-02,   3.49121094e-02],
                        [  4.07714844e-02,   4.07714844e-02],
                        [  4.91638184e-02,   4.91943359e-02],
                        [  5.96313477e-02,   5.96313477e-02],
                        [  7.94982910e-02,   7.94982910e-02],
                        [  1.13891602e-01,   1.13891602e-01],
                        [  1.54174805e-01,   1.54174805e-01],
                        [  1.85394287e-01,   1.85394287e-01],
                        [  1.95648193e-01,   1.95617676e-01],
                        [  1.74743652e-01,   1.74743652e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.69067383e-02,   1.69067383e-02],
                        [ -1.09954834e-01,  -1.09954834e-01],
                        [ -2.46826172e-01,  -2.46795654e-01],
                        [ -3.59619141e-01,  -3.59649658e-01],
                        [ -4.07806396e-01,  -4.07806396e-01],
                        [ -3.77410889e-01,  -3.77410889e-01],
                        [ -2.99255371e-01,  -2.99255371e-01],
                        [ -2.22808838e-01,  -2.22808838e-01],
                        [ -1.76483154e-01,  -1.76483154e-01],
                        [ -1.55120850e-01,  -1.55120850e-01],
                        [ -1.37664795e-01,  -1.37695312e-01],
                        [ -1.12792969e-01,  -1.12792969e-01],
                        [ -8.74633789e-02,  -8.74633789e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -5.99975586e-02,  -5.99975586e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -2.46887207e-02,  -2.47192383e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -1.69677734e-02,  -1.69677734e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  9.90295410e-02,   9.90295410e-02],
                        [  1.71752930e-01,   1.71752930e-01],
                        [  2.38433838e-01,   2.38433838e-01],
                        [  2.81066895e-01,   2.81066895e-01],
                        [  2.89428711e-01,   2.89428711e-01],
                        [  2.69531250e-01,   2.69531250e-01],
                        [  2.36968994e-01,   2.36999512e-01],
                        [  2.05902100e-01,   2.05871582e-01],
                        [  1.82037354e-01,   1.82037354e-01],
                        [  1.63421631e-01,   1.63452148e-01],
                        [  1.46453857e-01,   1.46423340e-01],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  1.01715088e-01,   1.01745605e-01],
                        [  8.43200684e-02,   8.42895508e-02],
                        [  6.38427734e-02,   6.38427734e-02],
                        [  4.34875488e-02,   4.34875488e-02],
                        [  2.83203125e-02,   2.83203125e-02],
                        [  2.14233398e-02,   2.14233398e-02],
                        [  1.90124512e-02,   1.90124512e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  5.43212891e-03,   5.43212891e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [  4.60815430e-03,   4.57763672e-03],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.80761719e-02,   2.80456543e-02],
                        [  3.01818848e-02,   3.01818848e-02],
                        [  3.09753418e-02,   3.10058594e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.51062012e-02,   1.51062012e-02],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -6.74438477e-03,  -6.71386719e-03],
                        [ -2.19726562e-03,  -2.22778320e-03],
                        [  2.44140625e-03,   2.41088867e-03],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  2.59399414e-03,   2.59399414e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -1.55029297e-02,  -1.54724121e-02],
                        [ -2.08129883e-02,  -2.08435059e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.64990234e-02,  -3.65295410e-02],
                        [ -3.42102051e-02,  -3.42407227e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.75976562e-02,  -3.76281738e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -6.08520508e-02,  -6.08215332e-02],
                        [ -6.70166016e-02,  -6.70471191e-02],
                        [ -6.40258789e-02,  -6.40258789e-02],
                        [ -5.58166504e-02,  -5.57861328e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -4.48608398e-02,  -4.48608398e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -5.36499023e-02,  -5.36499023e-02],
                        [ -5.69152832e-02,  -5.69152832e-02],
                        [ -6.10351562e-02,  -6.10046387e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.26440430e-02,  -2.26440430e-02],
                        [ -1.63269043e-02,  -1.63269043e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.27050781e-02,  -2.27050781e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -5.85937500e-03,  -5.85937500e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  3.23181152e-02,   3.23181152e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  5.71289062e-02,   5.71289062e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  9.20104980e-02,   9.20104980e-02],
                        [  1.12365723e-01,   1.12365723e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.66503906e-01,   1.66503906e-01],
                        [  1.86706543e-01,   1.86706543e-01],
                        [  1.83776855e-01,   1.83776855e-01],
                        [  1.47979736e-01,   1.47979736e-01],
                        [  7.51342773e-02,   7.51342773e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -1.69006348e-01,  -1.69006348e-01],
                        [ -2.97912598e-01,  -2.97912598e-01],
                        [ -3.82019043e-01,  -3.81988525e-01],
                        [ -3.97155762e-01,  -3.97155762e-01],
                        [ -3.51074219e-01,  -3.51074219e-01],
                        [ -2.76306152e-01,  -2.76275635e-01],
                        [ -2.07672119e-01,  -2.07672119e-01],
                        [ -1.62597656e-01,  -1.62597656e-01],
                        [ -1.36749268e-01,  -1.36749268e-01],
                        [ -1.16851807e-01,  -1.16821289e-01],
                        [ -9.68017578e-02,  -9.68322754e-02],
                        [ -8.05358887e-02,  -8.05358887e-02],
                        [ -7.06176758e-02,  -7.05871582e-02],
                        [ -6.07604980e-02,  -6.07604980e-02],
                        [ -4.37927246e-02,  -4.38232422e-02],
                        [ -2.21252441e-02,  -2.20947266e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  1.08642578e-02,   1.08337402e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -4.37316895e-02,  -4.37011719e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -5.44433594e-02,  -5.44738770e-02],
                        [ -2.81066895e-02,  -2.81066895e-02],
                        [  2.74353027e-02,   2.74353027e-02],
                        [  1.05468750e-01,   1.05468750e-01],
                        [  1.90368652e-01,   1.90368652e-01],
                        [  2.61871338e-01,   2.61871338e-01],
                        [  3.02062988e-01,   3.02062988e-01],
                        [  3.03161621e-01,   3.03131104e-01],
                        [  2.73498535e-01,   2.73498535e-01],
                        [  2.34863281e-01,   2.34863281e-01],
                        [  2.05535889e-01,   2.05535889e-01],
                        [  1.86828613e-01,   1.86828613e-01],
                        [  1.71081543e-01,   1.71081543e-01],
                        [  1.55609131e-01,   1.55609131e-01],
                        [  1.41418457e-01,   1.41418457e-01],
                        [  1.25549316e-01,   1.25549316e-01],
                        [  1.03210449e-01,   1.03210449e-01],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  4.48303223e-02,   4.48608398e-02],
                        [  1.88293457e-02,   1.87988281e-02],
                        [  2.31933594e-03,   2.31933594e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  1.02539062e-02,   1.02539062e-02],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.00195312e-02,   2.00195312e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  3.45458984e-02,   3.45764160e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  3.10974121e-02,   3.10668945e-02],
                        [  2.63061523e-02,   2.63366699e-02],
                        [  2.15759277e-02,   2.16064453e-02],
                        [  1.75170898e-02,   1.74865723e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.54418945e-02,   1.54113770e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  1.25732422e-02,   1.25732422e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -5.73730469e-03,  -5.73730469e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.96228027e-02,  -1.96228027e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -4.03137207e-02,  -4.03137207e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -4.17480469e-02,  -4.17175293e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -5.67932129e-02,  -5.67932129e-02],
                        [ -6.42395020e-02,  -6.42395020e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -7.14721680e-02,  -7.14721680e-02],
                        [ -6.81152344e-02,  -6.81152344e-02],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -6.38122559e-02,  -6.38122559e-02],
                        [ -6.31408691e-02,  -6.31103516e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.46875000e-02,  -5.46875000e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -6.02416992e-02,  -6.02722168e-02],
                        [ -5.78613281e-02,  -5.78613281e-02],
                        [ -5.22460938e-02,  -5.22155762e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -3.49731445e-02,  -3.50036621e-02],
                        [ -2.34069824e-02,  -2.34069824e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -1.40991211e-02,  -1.41296387e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -8.66699219e-03,  -8.69750977e-03],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  1.03454590e-02,   1.03759766e-02],
                        [  2.23388672e-02,   2.23083496e-02],
                        [  3.30505371e-02,   3.30505371e-02],
                        [  4.11987305e-02,   4.12292480e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  5.85327148e-02,   5.85021973e-02],
                        [  7.26623535e-02,   7.26928711e-02],
                        [  8.91723633e-02,   8.91723633e-02],
                        [  1.08978271e-01,   1.08947754e-01],
                        [  1.35406494e-01,   1.35406494e-01],
                        [  1.65954590e-01,   1.65954590e-01],
                        [  1.88079834e-01,   1.88049316e-01],
                        [  1.85424805e-01,   1.85394287e-01],
                        [  1.45416260e-01,   1.45416260e-01],
                        [  6.31713867e-02,   6.31713867e-02],
                        [ -5.48706055e-02,  -5.48706055e-02],
                        [ -1.88415527e-01,  -1.88415527e-01],
                        [ -3.06335449e-01,  -3.06335449e-01],
                        [ -3.77380371e-01,  -3.77380371e-01],
                        [ -3.85498047e-01,  -3.85498047e-01],
                        [ -3.39721680e-01,  -3.39721680e-01],
                        [ -2.69042969e-01,  -2.69042969e-01],
                        [ -2.04956055e-01,  -2.04956055e-01],
                        [ -1.62628174e-01,  -1.62628174e-01],
                        [ -1.36932373e-01,  -1.36932373e-01],
                        [ -1.15997314e-01,  -1.15997314e-01],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -7.70874023e-02,  -7.70874023e-02],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -2.70996094e-02,  -2.71301270e-02],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.69372559e-02,   1.69372559e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -1.22070312e-02,  -1.22070312e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -5.94787598e-02,  -5.94787598e-02],
                        [ -7.12280273e-02,  -7.12280273e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  1.87255859e-01,   1.87255859e-01],
                        [  2.68218994e-01,   2.68218994e-01],
                        [  3.19061279e-01,   3.19061279e-01],
                        [  3.26110840e-01,   3.26110840e-01],
                        [  2.95654297e-01,   2.95654297e-01],
                        [  2.48443604e-01,   2.48443604e-01],
                        [  2.03094482e-01,   2.03094482e-01],
                        [  1.67419434e-01,   1.67419434e-01],
                        [  1.41662598e-01,   1.41662598e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.12670898e-01,   1.12670898e-01],
                        [  1.05926514e-01,   1.05926514e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  9.48791504e-02,   9.48791504e-02],
                        [  7.84301758e-02,   7.84606934e-02],
                        [  5.35888672e-02,   5.35583496e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  1.92260742e-02,   1.92565918e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  1.55029297e-02,   1.54724121e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.55334473e-02,   1.55029297e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  2.23083496e-02,   2.23388672e-02],
                        [  2.54516602e-02,   2.54211426e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.49328613e-02,   2.49633789e-02],
                        [  2.43225098e-02,   2.43225098e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.73437500e-02,   2.73742676e-02],
                        [  2.19421387e-02,   2.19116211e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.36413574e-02,   1.36413574e-02],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -1.24511719e-02,  -1.24511719e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -3.30810547e-02,  -3.30810547e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -3.75061035e-02,  -3.75061035e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -6.31713867e-02,  -6.31713867e-02],
                        [ -6.80541992e-02,  -6.80541992e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.61926270e-02,  -6.61926270e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.19812012e-02,  -6.19812012e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -5.55725098e-02,  -5.56030273e-02],
                        [ -4.87670898e-02,  -4.87670898e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -2.99682617e-02,  -2.99987793e-02],
                        [ -2.59399414e-02,  -2.59094238e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -2.36206055e-02,  -2.35900879e-02],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  1.01928711e-02,   1.01928711e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  3.36608887e-02,   3.36608887e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  9.05456543e-02,   9.05456543e-02],
                        [  1.17736816e-01,   1.17706299e-01],
                        [  1.48284912e-01,   1.48284912e-01],
                        [  1.69250488e-01,   1.69250488e-01],
                        [  1.67266846e-01,   1.67236328e-01],
                        [  1.36291504e-01,   1.36291504e-01],
                        [  7.69958496e-02,   7.69958496e-02],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -1.02447510e-01,  -1.02447510e-01],
                        [ -2.01934814e-01,  -2.01904297e-01],
                        [ -2.88818359e-01,  -2.88818359e-01],
                        [ -3.45092773e-01,  -3.45092773e-01],
                        [ -3.56781006e-01,  -3.56750488e-01],
                        [ -3.23638916e-01,  -3.23638916e-01],
                        [ -2.63214111e-01,  -2.63214111e-01],
                        [ -2.01965332e-01,  -2.01995850e-01],
                        [ -1.57928467e-01,  -1.57928467e-01],
                        [ -1.29699707e-01,  -1.29699707e-01],
                        [ -1.05010986e-01,  -1.05010986e-01],
                        [ -7.94372559e-02,  -7.94372559e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -4.65087891e-02,  -4.65393066e-02],
                        [ -3.34167480e-02,  -3.34167480e-02],
                        [ -1.67541504e-02,  -1.67541504e-02],
                        [ -2.22778320e-03,  -2.22778320e-03],
                        [  5.88989258e-03,   5.88989258e-03],
                        [  8.51440430e-03,   8.51440430e-03],
                        [  5.98144531e-03,   5.98144531e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -2.18505859e-02,  -2.18505859e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -6.15234375e-02,  -6.15539551e-02],
                        [ -6.91223145e-02,  -6.91223145e-02],
                        [ -5.74035645e-02,  -5.73730469e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  1.07818604e-01,   1.07818604e-01],
                        [  1.86981201e-01,   1.86981201e-01],
                        [  2.56988525e-01,   2.56988525e-01],
                        [  2.97882080e-01,   2.97882080e-01],
                        [  2.99743652e-01,   2.99774170e-01],
                        [  2.72033691e-01,   2.72003174e-01],
                        [  2.33428955e-01,   2.33428955e-01],
                        [  1.97418213e-01,   1.97418213e-01],
                        [  1.68762207e-01,   1.68762207e-01],
                        [  1.47399902e-01,   1.47399902e-01],
                        [  1.30493164e-01,   1.30493164e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  9.76867676e-02,   9.76867676e-02],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  5.10559082e-02,   5.10559082e-02],
                        [  3.84521484e-02,   3.84521484e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  2.77709961e-02,   2.77709961e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  2.43225098e-02,   2.42919922e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.17895508e-02,   2.18200684e-02],
                        [  1.98974609e-02,   1.98974609e-02],
                        [  1.65405273e-02,   1.65100098e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.20239258e-02,   1.20239258e-02],
                        [  5.18798828e-03,   5.15747070e-03],
                        [ -3.75366211e-03,  -3.75366211e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.61743164e-03,  -1.64794922e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  6.77490234e-03,   6.80541992e-03],
                        [ -6.10351562e-05,  -9.15527344e-05],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -8.17871094e-03,  -8.17871094e-03],
                        [ -7.59887695e-03,  -7.56835938e-03],
                        [ -7.78198242e-03,  -7.81250000e-03],
                        [ -9.88769531e-03,  -9.88769531e-03],
                        [ -1.46179199e-02,  -1.45874023e-02],
                        [ -2.03552246e-02,  -2.03857422e-02],
                        [ -2.48718262e-02,  -2.48718262e-02],
                        [ -2.98156738e-02,  -2.97851562e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.67932129e-02,  -5.67626953e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.97534180e-02,  -5.97534180e-02],
                        [ -6.55212402e-02,  -6.55212402e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -7.67211914e-02,  -7.66906738e-02],
                        [ -7.36694336e-02,  -7.36694336e-02],
                        [ -6.74438477e-02,  -6.74438477e-02],
                        [ -6.34765625e-02,  -6.34765625e-02],
                        [ -6.27441406e-02,  -6.27441406e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -3.53393555e-02,  -3.53393555e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -2.95104980e-02,  -2.95410156e-02],
                        [ -2.67333984e-02,  -2.67333984e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.82897949e-02,  -2.82897949e-02],
                        [ -2.96630859e-02,  -2.96630859e-02],
                        [ -2.68859863e-02,  -2.68554688e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -1.11694336e-02,  -1.11999512e-02],
                        [  1.40380859e-03,   1.40380859e-03],
                        [  1.52893066e-02,   1.53198242e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  4.96215820e-02,   4.96520996e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  1.22283936e-01,   1.22283936e-01],
                        [  1.38763428e-01,   1.38763428e-01],
                        [  1.49810791e-01,   1.49780273e-01],
                        [  1.47491455e-01,   1.47521973e-01],
                        [  1.23260498e-01,   1.23260498e-01],
                        [  7.61413574e-02,   7.61108398e-02],
                        [  1.17492676e-02,   1.17492676e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -1.48437500e-01,  -1.48437500e-01],
                        [ -2.33825684e-01,  -2.33825684e-01],
                        [ -3.08044434e-01,  -3.08013916e-01],
                        [ -3.52264404e-01,  -3.52294922e-01],
                        [ -3.50250244e-01,  -3.50250244e-01],
                        [ -3.03314209e-01,  -3.03283691e-01],
                        [ -2.35473633e-01,  -2.35473633e-01],
                        [ -1.77124023e-01,  -1.77154541e-01],
                        [ -1.42242432e-01,  -1.42211914e-01],
                        [ -1.21154785e-01,  -1.21154785e-01],
                        [ -9.75952148e-02,  -9.76257324e-02],
                        [ -7.05261230e-02,  -7.05261230e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [  9.85717773e-03,   9.85717773e-03],
                        [  2.74963379e-02,   2.74963379e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [ -1.77001953e-03,  -1.77001953e-03],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -4.84619141e-02,  -4.84619141e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  1.07849121e-01,   1.07849121e-01],
                        [  1.85852051e-01,   1.85852051e-01],
                        [  2.54272461e-01,   2.54272461e-01],
                        [  2.96936035e-01,   2.96936035e-01],
                        [  3.07403564e-01,   3.07403564e-01],
                        [  2.88726807e-01,   2.88757324e-01],
                        [  2.51098633e-01,   2.51068115e-01],
                        [  2.07641602e-01,   2.07641602e-01],
                        [  1.68457031e-01,   1.68457031e-01],
                        [  1.38275146e-01,   1.38275146e-01],
                        [  1.18560791e-01,   1.18560791e-01],
                        [  1.06842041e-01,   1.06842041e-01],
                        [  9.72900391e-02,   9.73205566e-02],
                        [  8.69750977e-02,   8.69750977e-02],
                        [  7.72705078e-02,   7.72705078e-02],
                        [  6.78710938e-02,   6.79016113e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  3.72009277e-02,   3.71704102e-02],
                        [  2.03247070e-02,   2.03552246e-02],
                        [  1.10473633e-02,   1.10778809e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [  1.68151855e-02,   1.68151855e-02],
                        [  2.58178711e-02,   2.58178711e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  4.08325195e-02,   4.08325195e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  2.66418457e-02,   2.66113281e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -5.12695312e-03,  -5.09643555e-03],
                        [ -7.38525391e-03,  -7.35473633e-03],
                        [ -6.13403320e-03,  -6.13403320e-03],
                        [ -4.18090820e-03,  -4.18090820e-03],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -8.05664062e-03,  -8.05664062e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -8.30078125e-03,  -8.27026367e-03],
                        [ -3.44848633e-03,  -3.47900391e-03],
                        [ -7.01904297e-04,  -7.01904297e-04],
                        [ -2.53295898e-03,  -2.50244141e-03],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -2.15759277e-02,  -2.16064453e-02],
                        [ -3.28674316e-02,  -3.28369141e-02],
                        [ -4.36706543e-02,  -4.36706543e-02],
                        [ -5.52673340e-02,  -5.52978516e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -7.16857910e-02,  -7.16552734e-02],
                        [ -7.11975098e-02,  -7.12280273e-02],
                        [ -6.79321289e-02,  -6.79626465e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -6.73217773e-02,  -6.73217773e-02],
                        [ -6.76879883e-02,  -6.77185059e-02],
                        [ -6.67419434e-02,  -6.67419434e-02],
                        [ -6.57653809e-02,  -6.57653809e-02],
                        [ -6.47277832e-02,  -6.47583008e-02],
                        [ -6.25915527e-02,  -6.25915527e-02],
                        [ -6.00585938e-02,  -6.00280762e-02],
                        [ -5.90209961e-02,  -5.90515137e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.78613281e-02,  -5.78308105e-02],
                        [ -5.30395508e-02,  -5.30395508e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -3.79943848e-02,  -3.79638672e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.23791504e-02,  -3.23791504e-02],
                        [ -2.85644531e-02,  -2.85644531e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -1.84326172e-02,  -1.84326172e-02],
                        [ -1.18713379e-02,  -1.18408203e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -2.74658203e-04,  -3.05175781e-04],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  3.14331055e-02,   3.14331055e-02],
                        [  4.57153320e-02,   4.57153320e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  7.41577148e-02,   7.41577148e-02],
                        [  9.35974121e-02,   9.35974121e-02],
                        [  1.15661621e-01,   1.15661621e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  1.45935059e-01,   1.45935059e-01],
                        [  1.43127441e-01,   1.43127441e-01],
                        [  1.23840332e-01,   1.23840332e-01],
                        [  8.78601074e-02,   8.78601074e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -9.11254883e-02,  -9.11254883e-02],
                        [ -1.59973145e-01,  -1.59942627e-01],
                        [ -2.30163574e-01,  -2.30163574e-01],
                        [ -2.95776367e-01,  -2.95776367e-01],
                        [ -3.38989258e-01,  -3.38989258e-01],
                        [ -3.38867188e-01,  -3.38867188e-01],
                        [ -2.92449951e-01,  -2.92480469e-01],
                        [ -2.23480225e-01,  -2.23480225e-01],
                        [ -1.63360596e-01,  -1.63360596e-01],
                        [ -1.24908447e-01,  -1.24908447e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -7.27844238e-02,  -7.27539062e-02],
                        [ -4.76989746e-02,  -4.76989746e-02],
                        [ -3.03039551e-02,  -3.03344727e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -2.00195312e-02,  -2.00195312e-02],
                        [ -1.66625977e-02,  -1.66931152e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -1.40380859e-03,  -1.40380859e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.48815918e-02,  -3.49121094e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.93579102e-02,  -2.93273926e-02],
                        [ -1.80664062e-02,  -1.80969238e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  3.57360840e-02,   3.57666016e-02],
                        [  8.81652832e-02,   8.81652832e-02],
                        [  1.53900146e-01,   1.53869629e-01],
                        [  2.20397949e-01,   2.20397949e-01],
                        [  2.71026611e-01,   2.71026611e-01],
                        [  2.94006348e-01,   2.94006348e-01],
                        [  2.87384033e-01,   2.87384033e-01],
                        [  2.58209229e-01,   2.58239746e-01],
                        [  2.19726562e-01,   2.19726562e-01],
                        [  1.85363770e-01,   1.85363770e-01],
                        [  1.60705566e-01,   1.60705566e-01],
                        [  1.42028809e-01,   1.42028809e-01],
                        [  1.23962402e-01,   1.23962402e-01],
                        [  1.06384277e-01,   1.06414795e-01],
                        [  9.16748047e-02,   9.16748047e-02],
                        [  7.76977539e-02,   7.76977539e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  3.91235352e-02,   3.91540527e-02],
                        [  2.37121582e-02,   2.37121582e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [  2.77709961e-03,   2.74658203e-03],
                        [  9.55200195e-03,   9.55200195e-03],
                        [  2.25830078e-02,   2.26135254e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  3.95202637e-02,   3.95507812e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [ -1.01928711e-02,  -1.01928711e-02],
                        [ -7.96508789e-03,  -7.96508789e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -1.55944824e-02,  -1.55944824e-02],
                        [ -1.79443359e-02,  -1.79443359e-02],
                        [ -1.87377930e-02,  -1.87072754e-02],
                        [ -2.01110840e-02,  -2.01110840e-02],
                        [ -2.43530273e-02,  -2.43835449e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -5.46875000e-02,  -5.47180176e-02],
                        [ -5.35278320e-02,  -5.34973145e-02],
                        [ -5.00488281e-02,  -5.00488281e-02],
                        [ -4.94689941e-02,  -4.94689941e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -5.56640625e-02,  -5.56945801e-02],
                        [ -5.89294434e-02,  -5.89599609e-02],
                        [ -6.13098145e-02,  -6.13098145e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -6.24389648e-02,  -6.24389648e-02],
                        [ -6.72302246e-02,  -6.72302246e-02],
                        [ -7.02209473e-02,  -7.02209473e-02],
                        [ -6.86950684e-02,  -6.86645508e-02],
                        [ -6.30493164e-02,  -6.30493164e-02],
                        [ -5.45043945e-02,  -5.45349121e-02],
                        [ -4.56542969e-02,  -4.56542969e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -1.23901367e-02,  -1.23901367e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -1.30920410e-02,  -1.30920410e-02],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  4.40368652e-02,   4.40063477e-02],
                        [  6.27136230e-02,   6.27136230e-02],
                        [  7.74230957e-02,   7.74230957e-02],
                        [  9.12170410e-02,   9.11865234e-02],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  1.18286133e-01,   1.18286133e-01],
                        [  1.24908447e-01,   1.24908447e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  9.95483398e-02,   9.95788574e-02],
                        [  6.15844727e-02,   6.15844727e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [ -3.11584473e-02,  -3.11584473e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -9.28039551e-02,  -9.28039551e-02],
                        [ -1.26556396e-01,  -1.26586914e-01],
                        [ -1.84356689e-01,  -1.84356689e-01],
                        [ -2.59277344e-01,  -2.59277344e-01],
                        [ -3.14392090e-01,  -3.14422607e-01],
                        [ -3.15643311e-01,  -3.15643311e-01],
                        [ -2.65808105e-01,  -2.65808105e-01],
                        [ -1.98944092e-01,  -1.98944092e-01],
                        [ -1.48101807e-01,  -1.48101807e-01],
                        [ -1.22772217e-01,  -1.22772217e-01],
                        [ -1.09252930e-01,  -1.09252930e-01],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -2.33459473e-02,  -2.33764648e-02],
                        [ -1.66015625e-02,  -1.66015625e-02],
                        [ -4.60815430e-03,  -4.60815430e-03],
                        [  1.04370117e-02,   1.04370117e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  1.13220215e-02,   1.13220215e-02],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [ -1.79748535e-02,  -1.79748535e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -4.10766602e-02,  -4.10461426e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [  1.60522461e-02,   1.60827637e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  1.09252930e-01,   1.09222412e-01],
                        [  1.59301758e-01,   1.59301758e-01],
                        [  2.05413818e-01,   2.05413818e-01],
                        [  2.44262695e-01,   2.44262695e-01],
                        [  2.71270752e-01,   2.71270752e-01],
                        [  2.78533936e-01,   2.78564453e-01],
                        [  2.62756348e-01,   2.62756348e-01],
                        [  2.32055664e-01,   2.32055664e-01],
                        [  1.98333740e-01,   1.98364258e-01],
                        [  1.67602539e-01,   1.67633057e-01],
                        [  1.41571045e-01,   1.41540527e-01],
                        [  1.20544434e-01,   1.20544434e-01],
                        [  1.02691650e-01,   1.02722168e-01],
                        [  8.55712891e-02,   8.55407715e-02],
                        [  6.91833496e-02,   6.91833496e-02],
                        [  5.54809570e-02,   5.55114746e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.51562500e-02,   3.51257324e-02],
                        [  2.23083496e-02,   2.23388672e-02],
                        [  8.75854492e-03,   8.75854492e-03],
                        [  3.17382812e-03,   3.17382812e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  2.53601074e-02,   2.53295898e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.37426758e-02,   2.37731934e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  2.72827148e-02,   2.72827148e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  3.35693359e-02,   3.35693359e-02],
                        [  3.07922363e-02,   3.07922363e-02],
                        [  2.13317871e-02,   2.13317871e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -4.21142578e-03,  -4.21142578e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.22070312e-02,  -1.22375488e-02],
                        [ -1.29089355e-02,  -1.29089355e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -2.08435059e-02,  -2.08740234e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -2.07214355e-02,  -2.07519531e-02],
                        [ -2.27050781e-02,  -2.26745605e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.04565430e-02,  -3.04565430e-02],
                        [ -3.73535156e-02,  -3.73840332e-02],
                        [ -4.86145020e-02,  -4.86450195e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -6.09741211e-02,  -6.09436035e-02],
                        [ -6.28356934e-02,  -6.28356934e-02],
                        [ -6.61315918e-02,  -6.61315918e-02],
                        [ -6.86340332e-02,  -6.86340332e-02],
                        [ -6.65283203e-02,  -6.65283203e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.50842285e-02,  -5.50537109e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.41381836e-02,  -5.41687012e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -6.26831055e-02,  -6.26525879e-02],
                        [ -6.63452148e-02,  -6.63757324e-02],
                        [ -6.73828125e-02,  -6.73828125e-02],
                        [ -6.70776367e-02,  -6.70776367e-02],
                        [ -6.59484863e-02,  -6.59484863e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -4.26330566e-02,  -4.26330566e-02],
                        [ -2.92053223e-02,  -2.92053223e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -1.21459961e-02,  -1.21154785e-02],
                        [ -7.23266602e-03,  -7.23266602e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  1.01318359e-02,   1.01623535e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  2.24304199e-02,   2.24304199e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  4.77905273e-02,   4.77905273e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  8.40454102e-02,   8.40454102e-02],
                        [  1.02722168e-01,   1.02722168e-01],
                        [  1.17004395e-01,   1.17004395e-01],
                        [  1.20849609e-01,   1.20819092e-01],
                        [  1.09466553e-01,   1.09497070e-01],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -3.24096680e-02,  -3.24096680e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -1.08184814e-01,  -1.08184814e-01],
                        [ -1.87866211e-01,  -1.87866211e-01],
                        [ -2.72857666e-01,  -2.72857666e-01],
                        [ -3.24707031e-01,  -3.24707031e-01],
                        [ -3.17321777e-01,  -3.17321777e-01],
                        [ -2.59277344e-01,  -2.59277344e-01],
                        [ -1.87683105e-01,  -1.87683105e-01],
                        [ -1.35650635e-01,  -1.35650635e-01],
                        [ -1.08154297e-01,  -1.08154297e-01],
                        [ -8.98437500e-02,  -8.98437500e-02],
                        [ -6.85729980e-02,  -6.85729980e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [  8.72802734e-03,   8.72802734e-03],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.03149414e-02,   1.03149414e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -1.45263672e-02,  -1.45263672e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  5.09033203e-02,   5.09033203e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  1.13464355e-01,   1.13464355e-01],
                        [  1.47186279e-01,   1.47186279e-01],
                        [  1.81427002e-01,   1.81427002e-01],
                        [  2.18139648e-01,   2.18139648e-01],
                        [  2.55798340e-01,   2.55798340e-01],
                        [  2.81066895e-01,   2.81066895e-01],
                        [  2.77130127e-01,   2.77130127e-01],
                        [  2.42797852e-01,   2.42797852e-01],
                        [  1.95648193e-01,   1.95648193e-01],
                        [  1.54327393e-01,   1.54327393e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  9.04235840e-02,   9.04235840e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  6.75354004e-02,   6.75354004e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.11181641e-02,   2.11181641e-02],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  3.25927734e-02,   3.25622559e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.42407227e-02,   3.42407227e-02],
                        [  3.59497070e-02,   3.59191895e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  1.92871094e-02,   1.92871094e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  4.76074219e-03,   4.76074219e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -6.65283203e-03,  -6.65283203e-03],
                        [ -8.30078125e-03,  -8.27026367e-03],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [ -1.70898438e-03,  -1.70898438e-03],
                        [  6.10351562e-04,   6.10351562e-04],
                        [ -3.81469727e-03,  -3.81469727e-03],
                        [ -1.11083984e-02,  -1.11389160e-02],
                        [ -1.50451660e-02,  -1.50451660e-02],
                        [ -1.61437988e-02,  -1.61437988e-02],
                        [ -1.80053711e-02,  -1.80053711e-02],
                        [ -1.99279785e-02,  -1.99584961e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -3.93066406e-02,  -3.92761230e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -5.70678711e-02,  -5.70678711e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -6.03637695e-02,  -6.03637695e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -6.76574707e-02,  -6.76574707e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -6.62536621e-02,  -6.62841797e-02],
                        [ -6.73522949e-02,  -6.73522949e-02],
                        [ -7.28759766e-02,  -7.28759766e-02],
                        [ -7.52563477e-02,  -7.52868652e-02],
                        [ -6.90612793e-02,  -6.90612793e-02],
                        [ -5.99670410e-02,  -5.99670410e-02],
                        [ -5.59387207e-02,  -5.59692383e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -5.49011230e-02,  -5.48706055e-02],
                        [ -5.18493652e-02,  -5.18798828e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -4.71496582e-02,  -4.71191406e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -3.71398926e-02,  -3.71398926e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.09143066e-02,  -3.09143066e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -1.46484375e-02,  -1.46179199e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  4.25720215e-02,   4.25720215e-02],
                        [  6.87255859e-02,   6.87255859e-02],
                        [  8.87756348e-02,   8.87756348e-02],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.13525391e-01,   1.13525391e-01],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  1.11511230e-01,   1.11541748e-01],
                        [  7.81860352e-02,   7.81555176e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [ -1.22070312e-02,  -1.21765137e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -4.93774414e-02,  -4.94079590e-02],
                        [ -4.40368652e-02,  -4.40368652e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -1.01379395e-01,  -1.01379395e-01],
                        [ -1.82495117e-01,  -1.82495117e-01],
                        [ -2.62084961e-01,  -2.62084961e-01],
                        [ -3.03588867e-01,  -3.03619385e-01],
                        [ -2.90893555e-01,  -2.90893555e-01],
                        [ -2.38342285e-01,  -2.38342285e-01],
                        [ -1.77825928e-01,  -1.77825928e-01],
                        [ -1.34460449e-01,  -1.34460449e-01],
                        [ -1.10778809e-01,  -1.10778809e-01],
                        [ -9.18273926e-02,  -9.17968750e-02],
                        [ -6.58264160e-02,  -6.58264160e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.64794922e-02,  -1.64794922e-02],
                        [ -8.54492188e-03,  -8.51440430e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  8.91113281e-03,   8.91113281e-03],
                        [  8.17871094e-03,   8.17871094e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [  1.86157227e-03,   1.86157227e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  6.05773926e-02,   6.05773926e-02],
                        [  8.54492188e-02,   8.54187012e-02],
                        [  1.06292725e-01,   1.06292725e-01],
                        [  1.25122070e-01,   1.25152588e-01],
                        [  1.49597168e-01,   1.49597168e-01],
                        [  1.86279297e-01,   1.86279297e-01],
                        [  2.29644775e-01,   2.29644775e-01],
                        [  2.61566162e-01,   2.61566162e-01],
                        [  2.66571045e-01,   2.66571045e-01],
                        [  2.46032715e-01,   2.46032715e-01],
                        [  2.13073730e-01,   2.13073730e-01],
                        [  1.78070068e-01,   1.78070068e-01],
                        [  1.45202637e-01,   1.45202637e-01],
                        [  1.17706299e-01,   1.17706299e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  6.38427734e-02,   6.38122559e-02],
                        [  5.19714355e-02,   5.19714355e-02],
                        [  4.66308594e-02,   4.66308594e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  3.29895020e-02,   3.29895020e-02],
                        [  3.13720703e-02,   3.13720703e-02],
                        [  3.32336426e-02,   3.32031250e-02],
                        [  3.52783203e-02,   3.53088379e-02],
                        [  3.63464355e-02,   3.63464355e-02],
                        [  3.73840332e-02,   3.73535156e-02],
                        [  3.86962891e-02,   3.86962891e-02],
                        [  3.85437012e-02,   3.85437012e-02],
                        [  3.39965820e-02,   3.39965820e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  2.44140625e-04,   2.44140625e-04],
                        [ -3.38745117e-03,  -3.38745117e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.30615234e-02,  -1.30615234e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -1.58691406e-03,  -1.55639648e-03],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -2.17285156e-02,  -2.17590332e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -3.22570801e-02,  -3.22265625e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -5.13610840e-02,  -5.13610840e-02],
                        [ -5.99670410e-02,  -5.99365234e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.25610352e-02,  -6.25610352e-02],
                        [ -5.73120117e-02,  -5.73120117e-02],
                        [ -5.19104004e-02,  -5.18798828e-02],
                        [ -5.01708984e-02,  -5.01708984e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.22155762e-02,  -5.21850586e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.01098633e-02,  -5.01098633e-02],
                        [ -5.24291992e-02,  -5.24291992e-02],
                        [ -5.63049316e-02,  -5.63049316e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -5.68237305e-02,  -5.67932129e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.78918457e-02,  -5.78918457e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.62951660e-02,  -4.63256836e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.27453613e-02,  -3.27453613e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [  5.55419922e-03,   5.58471680e-03],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  1.33056641e-02,   1.32751465e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [  4.06188965e-02,   4.06494141e-02],
                        [  6.21948242e-02,   6.21643066e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.82971191e-02,   9.83276367e-02],
                        [  1.05651855e-01,   1.05621338e-01],
                        [  9.69238281e-02,   9.69238281e-02],
                        [  6.68640137e-02,   6.68640137e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -6.93054199e-02,  -6.92749023e-02],
                        [ -7.56225586e-02,  -7.56225586e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [ -5.88989258e-03,  -5.88989258e-03],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -1.61254883e-01,  -1.61224365e-01],
                        [ -2.51739502e-01,  -2.51739502e-01],
                        [ -3.06365967e-01,  -3.06365967e-01],
                        [ -3.03466797e-01,  -3.03466797e-01],
                        [ -2.51922607e-01,  -2.51922607e-01],
                        [ -1.82617188e-01,  -1.82617188e-01],
                        [ -1.24114990e-01,  -1.24084473e-01],
                        [ -8.71887207e-02,  -8.71887207e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -5.18493652e-02,  -5.18493652e-02],
                        [ -3.83911133e-02,  -3.83605957e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.94396973e-02,  -1.94396973e-02],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -1.22070312e-04,  -1.22070312e-04],
                        [  7.99560547e-03,   7.96508789e-03],
                        [  9.42993164e-03,   9.46044922e-03],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  4.06188965e-02,   4.06494141e-02],
                        [  6.31713867e-02,   6.31408691e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  1.30798340e-01,   1.30828857e-01],
                        [  1.72668457e-01,   1.72668457e-01],
                        [  2.15423584e-01,   2.15423584e-01],
                        [  2.38464355e-01,   2.38464355e-01],
                        [  2.32025146e-01,   2.32025146e-01],
                        [  2.03826904e-01,   2.03826904e-01],
                        [  1.70471191e-01,   1.70501709e-01],
                        [  1.45172119e-01,   1.45172119e-01],
                        [  1.31469727e-01,   1.31469727e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.09313965e-01,   1.09313965e-01],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.51855469e-02,   6.52160645e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  3.62243652e-02,   3.62243652e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  1.96228027e-02,   1.96228027e-02],
                        [  1.69677734e-02,   1.69677734e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  1.43127441e-02,   1.43432617e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -6.92749023e-03,  -6.92749023e-03],
                        [ -1.02233887e-02,  -1.02233887e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -2.26135254e-02,  -2.26135254e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.06701660e-02,  -3.06396484e-02],
                        [ -3.55224609e-02,  -3.55224609e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -5.38940430e-02,  -5.38940430e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -6.38427734e-02,  -6.38427734e-02],
                        [ -6.33544922e-02,  -6.33544922e-02],
                        [ -6.06384277e-02,  -6.06689453e-02],
                        [ -5.85632324e-02,  -5.85632324e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -5.06286621e-02,  -5.06286621e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -5.27343750e-02,  -5.27648926e-02],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -5.23681641e-02,  -5.23376465e-02],
                        [ -5.65795898e-02,  -5.65795898e-02],
                        [ -5.71899414e-02,  -5.71899414e-02],
                        [ -5.88684082e-02,  -5.88378906e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [ -5.83190918e-02,  -5.83190918e-02],
                        [ -5.27038574e-02,  -5.27038574e-02],
                        [ -4.60205078e-02,  -4.60205078e-02],
                        [ -3.40576172e-02,  -3.40576172e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [  1.11389160e-02,   1.11083984e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.88391113e-02,   2.88085938e-02],
                        [  3.73229980e-02,   3.73229980e-02],
                        [  5.32226562e-02,   5.32531738e-02],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  9.31091309e-02,   9.31091309e-02],
                        [  1.03851318e-01,   1.03881836e-01],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  6.67419434e-02,   6.67114258e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [ -4.49218750e-02,  -4.49218750e-02],
                        [ -9.13085938e-02,  -9.13085938e-02],
                        [ -1.01837158e-01,  -1.01837158e-01],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [ -2.08129883e-02,  -2.08129883e-02],
                        [  1.74255371e-02,   1.73950195e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [ -1.36718750e-02,  -1.36413574e-02],
                        [ -7.63549805e-02,  -7.63854980e-02],
                        [ -1.52954102e-01,  -1.52954102e-01],
                        [ -2.23205566e-01,  -2.23175049e-01],
                        [ -2.63092041e-01,  -2.63092041e-01],
                        [ -2.58270264e-01,  -2.58270264e-01],
                        [ -2.16918945e-01,  -2.16918945e-01],
                        [ -1.64520264e-01,  -1.64489746e-01],
                        [ -1.22283936e-01,  -1.22283936e-01],
                        [ -9.44213867e-02,  -9.44519043e-02],
                        [ -7.51647949e-02,  -7.51342773e-02],
                        [ -6.01501465e-02,  -6.01501465e-02],
                        [ -4.85839844e-02,  -4.85839844e-02],
                        [ -4.00085449e-02,  -4.00085449e-02],
                        [ -3.39965820e-02,  -3.39660645e-02],
                        [ -2.90222168e-02,  -2.90527344e-02],
                        [ -2.11791992e-02,  -2.12097168e-02],
                        [ -7.78198242e-03,  -7.75146484e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  1.58691406e-02,   1.58386230e-02],
                        [  1.74560547e-02,   1.74865723e-02],
                        [  1.71813965e-02,   1.71813965e-02],
                        [  1.87683105e-02,   1.87377930e-02],
                        [  2.17590332e-02,   2.17590332e-02],
                        [  2.79541016e-02,   2.79846191e-02],
                        [  4.33349609e-02,   4.33044434e-02],
                        [  6.79626465e-02,   6.79321289e-02],
                        [  9.06066895e-02,   9.06372070e-02],
                        [  1.01013184e-01,   1.01013184e-01],
                        [  1.00799561e-01,   1.00769043e-01],
                        [  9.82360840e-02,   9.82666016e-02],
                        [  1.01318359e-01,   1.01348877e-01],
                        [  1.18530273e-01,   1.18530273e-01],
                        [  1.54022217e-01,   1.54022217e-01],
                        [  1.97998047e-01,   1.98028564e-01],
                        [  2.31842041e-01,   2.31842041e-01],
                        [  2.43072510e-01,   2.43041992e-01],
                        [  2.29980469e-01,   2.30010986e-01],
                        [  1.98120117e-01,   1.98120117e-01],
                        [  1.59851074e-01,   1.59851074e-01],
                        [  1.28784180e-01,   1.28784180e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  8.97827148e-02,   8.97521973e-02],
                        [  7.33032227e-02,   7.33032227e-02],
                        [  6.29577637e-02,   6.29577637e-02],
                        [  6.12182617e-02,   6.12182617e-02],
                        [  6.48193359e-02,   6.48193359e-02],
                        [  6.71081543e-02,   6.71386719e-02],
                        [  6.11572266e-02,   6.11572266e-02],
                        [  4.52880859e-02,   4.52880859e-02],
                        [  2.69165039e-02,   2.69165039e-02],
                        [  1.47705078e-02,   1.48010254e-02],
                        [  9.39941406e-03,   9.36889648e-03],
                        [  6.22558594e-03,   6.19506836e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  6.10351562e-03,   6.10351562e-03],
                        [  9.79614258e-03,   9.76562500e-03],
                        [  1.20544434e-02,   1.20544434e-02],
                        [  1.28479004e-02,   1.28479004e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  1.48925781e-02,   1.49230957e-02],
                        [  1.19628906e-02,   1.19323730e-02],
                        [  9.91821289e-03,   9.88769531e-03],
                        [  8.14819336e-03,   8.17871094e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -2.39562988e-02,  -2.39562988e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -5.07202148e-02,  -5.07202148e-02],
                        [ -5.02624512e-02,  -5.02624512e-02],
                        [ -4.95605469e-02,  -4.95605469e-02],
                        [ -4.96520996e-02,  -4.96520996e-02],
                        [ -5.03845215e-02,  -5.03845215e-02],
                        [ -5.11169434e-02,  -5.11169434e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -5.98754883e-02,  -5.98754883e-02],
                        [ -5.92651367e-02,  -5.92346191e-02],
                        [ -6.08215332e-02,  -6.08215332e-02],
                        [ -6.68640137e-02,  -6.68640137e-02],
                        [ -7.37915039e-02,  -7.37915039e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -7.60192871e-02,  -7.60192871e-02],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -5.97839355e-02,  -5.97839355e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.68041992e-02,  -3.68041992e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -2.44750977e-02,  -2.44750977e-02],
                        [ -1.47705078e-02,  -1.47705078e-02],
                        [ -9.52148438e-03,  -9.55200195e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  5.18798828e-02,   5.19104004e-02],
                        [  8.19702148e-02,   8.19702148e-02],
                        [  1.01806641e-01,   1.01776123e-01],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  5.63049316e-02,   5.62744141e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [ -4.53796387e-02,  -4.53491211e-02],
                        [ -8.76464844e-02,  -8.76464844e-02],
                        [ -9.97009277e-02,  -9.97009277e-02],
                        [ -7.53173828e-02,  -7.52868652e-02],
                        [ -2.79541016e-02,  -2.79541016e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [  3.83300781e-02,   3.83605957e-02],
                        [  2.56347656e-02,   2.56042480e-02],
                        [ -2.07214355e-02,  -2.07519531e-02],
                        [ -9.57336426e-02,  -9.57031250e-02],
                        [ -1.86096191e-01,  -1.86096191e-01],
                        [ -2.64160156e-01,  -2.64190674e-01],
                        [ -2.97668457e-01,  -2.97637939e-01],
                        [ -2.73223877e-01,  -2.73223877e-01],
                        [ -2.08068848e-01,  -2.08068848e-01],
                        [ -1.37145996e-01,  -1.37145996e-01],
                        [ -8.99353027e-02,  -8.99047852e-02],
                        [ -7.24182129e-02,  -7.24487305e-02],
                        [ -6.71691895e-02,  -6.71691895e-02],
                        [ -5.56945801e-02,  -5.56640625e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -3.35388184e-02,  -3.35388184e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -2.50244141e-02,  -2.50549316e-02],
                        [ -7.29370117e-03,  -7.29370117e-03],
                        [  4.85229492e-03,   4.88281250e-03],
                        [  9.06372070e-03,   9.03320312e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  9.33837891e-03,   9.36889648e-03],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  2.12402344e-02,   2.12097168e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  6.65283203e-02,   6.65588379e-02],
                        [  9.17053223e-02,   9.16748047e-02],
                        [  1.05773926e-01,   1.05773926e-01],
                        [  1.03576660e-01,   1.03607178e-01],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  7.93762207e-02,   7.93762207e-02],
                        [  8.52050781e-02,   8.52050781e-02],
                        [  1.11877441e-01,   1.11877441e-01],
                        [  1.54235840e-01,   1.54235840e-01],
                        [  2.00042725e-01,   2.00042725e-01],
                        [  2.32330322e-01,   2.32330322e-01],
                        [  2.38128662e-01,   2.38128662e-01],
                        [  2.18750000e-01,   2.18750000e-01],
                        [  1.87591553e-01,   1.87561035e-01],
                        [  1.58111572e-01,   1.58111572e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  1.03820801e-01,   1.03820801e-01],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  6.61010742e-02,   6.61010742e-02],
                        [  5.56640625e-02,   5.56335449e-02],
                        [  5.17883301e-02,   5.17883301e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.35388184e-02,   3.35388184e-02],
                        [  2.78625488e-02,   2.78930664e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [  1.48620605e-02,   1.48315430e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  2.75268555e-02,   2.75268555e-02],
                        [  1.80969238e-02,   1.80969238e-02],
                        [  5.46264648e-03,   5.43212891e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.82495117e-02,  -1.82495117e-02],
                        [ -2.85644531e-02,  -2.85949707e-02],
                        [ -3.51562500e-02,  -3.51562500e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.87573242e-02,  -3.87878418e-02],
                        [ -3.90625000e-02,  -3.90625000e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -4.11071777e-02,  -4.11071777e-02],
                        [ -4.06494141e-02,  -4.06494141e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.50341797e-02,  -3.50341797e-02],
                        [ -3.96118164e-02,  -3.96118164e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.93969727e-02,  -6.93969727e-02],
                        [ -6.64672852e-02,  -6.64672852e-02],
                        [ -6.06689453e-02,  -6.06689453e-02],
                        [ -5.68542480e-02,  -5.68542480e-02],
                        [ -5.61523438e-02,  -5.61523438e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -6.63146973e-02,  -6.63146973e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -7.86132812e-02,  -7.86132812e-02],
                        [ -7.19604492e-02,  -7.19909668e-02],
                        [ -5.74340820e-02,  -5.74340820e-02],
                        [ -4.37011719e-02,  -4.37011719e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -2.87475586e-02,  -2.87475586e-02],
                        [ -1.81579590e-02,  -1.81274414e-02],
                        [ -9.09423828e-03,  -9.09423828e-03],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -7.08007812e-03,  -7.04956055e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  3.74145508e-02,   3.73840332e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  9.32312012e-02,   9.32006836e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  6.66809082e-02,   6.67114258e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [ -2.51770020e-02,  -2.52075195e-02],
                        [ -7.65380859e-02,  -7.65075684e-02],
                        [ -1.09375000e-01,  -1.09375000e-01],
                        [ -1.05987549e-01,  -1.05987549e-01],
                        [ -6.45751953e-02,  -6.45446777e-02],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [  3.82385254e-02,   3.82080078e-02],
                        [  5.06591797e-02,   5.06591797e-02],
                        [  2.91442871e-02,   2.91442871e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -9.06677246e-02,  -9.06982422e-02],
                        [ -1.68792725e-01,  -1.68762207e-01],
                        [ -2.33001709e-01,  -2.33001709e-01],
                        [ -2.59399414e-01,  -2.59429932e-01],
                        [ -2.39776611e-01,  -2.39776611e-01],
                        [ -1.90765381e-01,  -1.90765381e-01],
                        [ -1.40502930e-01,  -1.40533447e-01],
                        [ -1.06658936e-01,  -1.06658936e-01],
                        [ -8.77990723e-02,  -8.77990723e-02],
                        [ -7.28759766e-02,  -7.29064941e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -1.64184570e-02,  -1.64489746e-02],
                        [ -1.04064941e-02,  -1.04064941e-02],
                        [ -1.08947754e-02,  -1.08947754e-02],
                        [ -8.81958008e-03,  -8.81958008e-03],
                        [ -3.05175781e-05,  -6.10351562e-05],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  2.60009766e-02,   2.60009766e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.98767090e-02,   2.98767090e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  6.85119629e-02,   6.85119629e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.03515625e-01,   1.03485107e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  9.33532715e-02,   9.33532715e-02],
                        [  8.17565918e-02,   8.17565918e-02],
                        [  7.97424316e-02,   7.97424316e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  1.30554199e-01,   1.30584717e-01],
                        [  1.72973633e-01,   1.72973633e-01],
                        [  2.07092285e-01,   2.07092285e-01],
                        [  2.21221924e-01,   2.21221924e-01],
                        [  2.13714600e-01,   2.13714600e-01],
                        [  1.91253662e-01,   1.91253662e-01],
                        [  1.63513184e-01,   1.63513184e-01],
                        [  1.39251709e-01,   1.39251709e-01],
                        [  1.22253418e-01,   1.22253418e-01],
                        [  1.08306885e-01,   1.08306885e-01],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  7.23571777e-02,   7.23571777e-02],
                        [  6.06994629e-02,   6.06689453e-02],
                        [  5.74951172e-02,   5.75256348e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  4.11071777e-02,   4.11071777e-02],
                        [  3.38745117e-02,   3.38745117e-02],
                        [  2.96936035e-02,   2.96936035e-02],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  1.42211914e-02,   1.41906738e-02],
                        [  1.40991211e-02,   1.40991211e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.27453613e-02,   3.27453613e-02],
                        [  2.65197754e-02,   2.65502930e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -3.48510742e-02,  -3.48510742e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -4.07104492e-02,  -4.07104492e-02],
                        [ -4.28466797e-02,  -4.28466797e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -3.96728516e-02,  -3.96728516e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -5.39245605e-02,  -5.39245605e-02],
                        [ -6.53381348e-02,  -6.53381348e-02],
                        [ -7.51647949e-02,  -7.51647949e-02],
                        [ -7.92846680e-02,  -7.92846680e-02],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -6.72302246e-02,  -6.71997070e-02],
                        [ -5.43212891e-02,  -5.43212891e-02],
                        [ -4.44946289e-02,  -4.45251465e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -5.96618652e-02,  -5.96313477e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.94177246e-02,  -5.94177246e-02],
                        [ -5.96618652e-02,  -5.96618652e-02],
                        [ -5.78002930e-02,  -5.78002930e-02],
                        [ -5.20629883e-02,  -5.20935059e-02],
                        [ -4.25109863e-02,  -4.24804688e-02],
                        [ -3.08227539e-02,  -3.08227539e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  2.31323242e-02,   2.31323242e-02],
                        [  3.55224609e-02,   3.55224609e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  6.71691895e-02,   6.71691895e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.36584473e-02,   9.36584473e-02],
                        [  8.52966309e-02,   8.53271484e-02],
                        [  5.28259277e-02,   5.28259277e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -6.20117188e-02,  -6.19812012e-02],
                        [ -1.11602783e-01,  -1.11602783e-01],
                        [ -1.31256104e-01,  -1.31256104e-01],
                        [ -1.12548828e-01,  -1.12548828e-01],
                        [ -6.45141602e-02,  -6.45141602e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  3.21044922e-02,   3.21350098e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  4.22058105e-02,   4.21752930e-02],
                        [  9.97924805e-03,   9.97924805e-03],
                        [ -4.88281250e-02,  -4.87976074e-02],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -2.09716797e-01,  -2.09716797e-01],
                        [ -2.59216309e-01,  -2.59216309e-01],
                        [ -2.58636475e-01,  -2.58636475e-01],
                        [ -2.14935303e-01,  -2.14935303e-01],
                        [ -1.53594971e-01,  -1.53594971e-01],
                        [ -1.00891113e-01,  -1.00891113e-01],
                        [ -6.97021484e-02,  -6.97021484e-02],
                        [ -5.61218262e-02,  -5.61218262e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -4.24499512e-02,  -4.24499512e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -3.89709473e-02,  -3.89709473e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -2.78625488e-02,  -2.78625488e-02],
                        [ -6.77490234e-03,  -6.80541992e-03],
                        [  1.41296387e-02,   1.41601562e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  2.61535645e-02,   2.61230469e-02],
                        [  2.20031738e-02,   2.20031738e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  3.52478027e-02,   3.52783203e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  9.80834961e-02,   9.80529785e-02],
                        [  1.23291016e-01,   1.23321533e-01],
                        [  1.32263184e-01,   1.32263184e-01],
                        [  1.22711182e-01,   1.22680664e-01],
                        [  9.83276367e-02,   9.83276367e-02],
                        [  7.16857910e-02,   7.16857910e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  7.26623535e-02,   7.26623535e-02],
                        [  1.06231689e-01,   1.06262207e-01],
                        [  1.47735596e-01,   1.47735596e-01],
                        [  1.85485840e-01,   1.85455322e-01],
                        [  2.11273193e-01,   2.11273193e-01],
                        [  2.17102051e-01,   2.17102051e-01],
                        [  1.98760986e-01,   1.98760986e-01],
                        [  1.65405273e-01,   1.65405273e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  9.87243652e-02,   9.87243652e-02],
                        [  8.56018066e-02,   8.56323242e-02],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  8.51440430e-02,   8.51440430e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  8.13293457e-02,   8.13598633e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  4.03747559e-02,   4.03747559e-02],
                        [  1.84326172e-02,   1.84326172e-02],
                        [  4.63867188e-03,   4.66918945e-03],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  7.56835938e-03,   7.56835938e-03],
                        [  1.54113770e-02,   1.54418945e-02],
                        [  1.86157227e-02,   1.85852051e-02],
                        [  1.85546875e-02,   1.85241699e-02],
                        [  2.09960938e-02,   2.10266113e-02],
                        [  2.25219727e-02,   2.24914551e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  5.49316406e-04,   5.49316406e-04],
                        [  2.16674805e-03,   2.13623047e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -1.18103027e-02,  -1.18103027e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.75268555e-02,  -2.75268555e-02],
                        [ -2.80456543e-02,  -2.80761719e-02],
                        [ -3.20739746e-02,  -3.20434570e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -4.08020020e-02,  -4.08325195e-02],
                        [ -4.08325195e-02,  -4.08630371e-02],
                        [ -4.09240723e-02,  -4.08935547e-02],
                        [ -4.44030762e-02,  -4.44335938e-02],
                        [ -5.05371094e-02,  -5.05371094e-02],
                        [ -5.36499023e-02,  -5.36193848e-02],
                        [ -5.18798828e-02,  -5.18798828e-02],
                        [ -5.15136719e-02,  -5.15441895e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -6.88476562e-02,  -6.88476562e-02],
                        [ -6.95190430e-02,  -6.95495605e-02],
                        [ -6.94580078e-02,  -6.94580078e-02],
                        [ -6.80847168e-02,  -6.80847168e-02],
                        [ -6.31408691e-02,  -6.31408691e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -4.16870117e-02,  -4.16870117e-02],
                        [ -4.05883789e-02,  -4.05578613e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -3.90319824e-02,  -3.90625000e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -3.92150879e-02,  -3.92150879e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -1.65100098e-02,  -1.65405273e-02],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  2.56347656e-02,   2.56347656e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  8.71582031e-02,   8.71582031e-02],
                        [  1.00860596e-01,   1.00860596e-01],
                        [  1.02508545e-01,   1.02478027e-01],
                        [  8.11767578e-02,   8.11767578e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -1.08734131e-01,  -1.08734131e-01],
                        [ -1.51977539e-01,  -1.51977539e-01],
                        [ -1.49291992e-01,  -1.49291992e-01],
                        [ -1.03393555e-01,  -1.03393555e-01],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  7.75451660e-02,   7.75451660e-02],
                        [  6.24694824e-02,   6.25000000e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [ -7.53173828e-02,  -7.53173828e-02],
                        [ -1.73980713e-01,  -1.73980713e-01],
                        [ -2.52868652e-01,  -2.52868652e-01],
                        [ -2.82135010e-01,  -2.82135010e-01],
                        [ -2.54577637e-01,  -2.54577637e-01],
                        [ -1.92016602e-01,  -1.91986084e-01],
                        [ -1.30493164e-01,  -1.30493164e-01],
                        [ -9.39941406e-02,  -9.39941406e-02],
                        [ -7.96203613e-02,  -7.95898438e-02],
                        [ -6.97631836e-02,  -6.97937012e-02],
                        [ -5.49316406e-02,  -5.49316406e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -3.08837891e-02,  -3.09143066e-02],
                        [ -2.67639160e-02,  -2.67639160e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.19323730e-02,   1.19323730e-02],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  3.72619629e-02,   3.72619629e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  1.20849609e-01,   1.20819092e-01],
                        [  1.29180908e-01,   1.29211426e-01],
                        [  1.18591309e-01,   1.18591309e-01],
                        [  9.75341797e-02,   9.75036621e-02],
                        [  7.73010254e-02,   7.73010254e-02],
                        [  6.70776367e-02,   6.70776367e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  1.37268066e-01,   1.37268066e-01],
                        [  1.80480957e-01,   1.80480957e-01],
                        [  2.13592529e-01,   2.13592529e-01],
                        [  2.26379395e-01,   2.26379395e-01],
                        [  2.14843750e-01,   2.14843750e-01],
                        [  1.83898926e-01,   1.83898926e-01],
                        [  1.48040771e-01,   1.48040771e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.06384277e-01,   1.06353760e-01],
                        [  9.45434570e-02,   9.45434570e-02],
                        [  8.16345215e-02,   8.16650391e-02],
                        [  6.97937012e-02,   6.97937012e-02],
                        [  6.18896484e-02,   6.18896484e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  5.39245605e-02,   5.39245605e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  3.28063965e-02,   3.28063965e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  2.28881836e-02,   2.28576660e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.31225586e-02,   1.31530762e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.27563477e-02,   1.27563477e-02],
                        [  7.96508789e-03,   7.96508789e-03],
                        [ -2.56347656e-03,  -2.56347656e-03],
                        [ -1.55029297e-02,  -1.55029297e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -2.95104980e-02,  -2.95104980e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.61633301e-02,  -3.61633301e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.86962891e-02,  -3.87268066e-02],
                        [ -3.86047363e-02,  -3.86047363e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.86145020e-02,  -4.86145020e-02],
                        [ -5.20935059e-02,  -5.20935059e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.76782227e-02,  -5.76782227e-02],
                        [ -5.72814941e-02,  -5.72814941e-02],
                        [ -5.71594238e-02,  -5.71289062e-02],
                        [ -5.87463379e-02,  -5.87463379e-02],
                        [ -6.11572266e-02,  -6.11572266e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -6.30798340e-02,  -6.30798340e-02],
                        [ -6.21643066e-02,  -6.21643066e-02],
                        [ -6.13708496e-02,  -6.13708496e-02],
                        [ -6.08215332e-02,  -6.07910156e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.41687012e-02,  -5.41687012e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -4.01306152e-02,  -4.01306152e-02],
                        [ -3.26843262e-02,  -3.27148438e-02],
                        [ -2.64282227e-02,  -2.63977051e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -2.06298828e-02,  -2.06604004e-02],
                        [ -1.69982910e-02,  -1.69982910e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  5.21240234e-02,   5.21240234e-02],
                        [  6.29882812e-02,   6.29882812e-02],
                        [  7.02819824e-02,   7.03125000e-02],
                        [  7.22351074e-02,   7.22656250e-02],
                        [  6.22863770e-02,   6.22558594e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -1.32720947e-01,  -1.32720947e-01],
                        [ -1.43768311e-01,  -1.43768311e-01],
                        [ -1.11053467e-01,  -1.11022949e-01],
                        [ -5.00488281e-02,  -5.00793457e-02],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  5.36193848e-02,   5.36499023e-02],
                        [  7.06787109e-02,   7.06481934e-02],
                        [  6.28662109e-02,   6.28662109e-02],
                        [  2.77099609e-02,   2.77404785e-02],
                        [ -3.81164551e-02,  -3.81469727e-02],
                        [ -1.28112793e-01,  -1.28112793e-01],
                        [ -2.16735840e-01,  -2.16735840e-01],
                        [ -2.69104004e-01,  -2.69104004e-01],
                        [ -2.65808105e-01,  -2.65838623e-01],
                        [ -2.17254639e-01,  -2.17224121e-01],
                        [ -1.54388428e-01,  -1.54388428e-01],
                        [ -1.06445312e-01,  -1.06445312e-01],
                        [ -8.25195312e-02,  -8.25195312e-02],
                        [ -7.29980469e-02,  -7.29980469e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -5.58166504e-02,  -5.58166504e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -3.79638672e-02,  -3.79638672e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -1.64489746e-02,  -1.64489746e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  2.65502930e-02,   2.65502930e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.35083008e-02,   3.35083008e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  4.65393066e-02,   4.65698242e-02],
                        [  7.50732422e-02,   7.50732422e-02],
                        [  1.05712891e-01,   1.05712891e-01],
                        [  1.27197266e-01,   1.27197266e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  9.64660645e-02,   9.64660645e-02],
                        [  7.29370117e-02,   7.29370117e-02],
                        [  6.23474121e-02,   6.23474121e-02],
                        [  6.91833496e-02,   6.91528320e-02],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  1.29760742e-01,   1.29760742e-01],
                        [  1.73400879e-01,   1.73400879e-01],
                        [  2.09716797e-01,   2.09716797e-01],
                        [  2.25524902e-01,   2.25524902e-01],
                        [  2.15484619e-01,   2.15484619e-01],
                        [  1.85577393e-01,   1.85577393e-01],
                        [  1.50329590e-01,   1.50329590e-01],
                        [  1.22802734e-01,   1.22802734e-01],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  8.99963379e-02,   8.99963379e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  7.19604492e-02,   7.19604492e-02],
                        [  7.06176758e-02,   7.06176758e-02],
                        [  6.66809082e-02,   6.67114258e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.53808594e-02,   1.53808594e-02],
                        [  4.08935547e-03,   4.05883789e-03],
                        [ -5.15747070e-03,  -5.12695312e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  1.03759766e-02,   1.03759766e-02],
                        [  1.81579590e-02,   1.81884766e-02],
                        [  2.11791992e-02,   2.11791992e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.38244629e-02,   1.38549805e-02],
                        [  3.66210938e-03,   3.66210938e-03],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -4.16564941e-02,  -4.16564941e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -5.44433594e-02,  -5.44433594e-02],
                        [ -5.60913086e-02,  -5.60913086e-02],
                        [ -5.57556152e-02,  -5.57556152e-02],
                        [ -5.10253906e-02,  -5.10559082e-02],
                        [ -4.28466797e-02,  -4.28161621e-02],
                        [ -3.72314453e-02,  -3.72009277e-02],
                        [ -3.86657715e-02,  -3.86657715e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -5.10864258e-02,  -5.10559082e-02],
                        [ -5.74035645e-02,  -5.74035645e-02],
                        [ -6.50634766e-02,  -6.50939941e-02],
                        [ -7.00683594e-02,  -7.00378418e-02],
                        [ -6.86035156e-02,  -6.86035156e-02],
                        [ -6.47277832e-02,  -6.47277832e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -6.10656738e-02,  -6.10656738e-02],
                        [ -5.70068359e-02,  -5.70068359e-02],
                        [ -5.34362793e-02,  -5.34362793e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -5.55114746e-02,  -5.55114746e-02],
                        [ -5.91430664e-02,  -5.91735840e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -5.92041016e-02,  -5.92346191e-02],
                        [ -5.66711426e-02,  -5.66711426e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -3.79028320e-02,  -3.79028320e-02],
                        [ -2.21252441e-02,  -2.21252441e-02],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  2.29187012e-02,   2.29187012e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  3.69873047e-02,   3.69873047e-02],
                        [  5.01403809e-02,   5.01708984e-02],
                        [  6.93054199e-02,   6.93054199e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  5.98449707e-02,   5.98449707e-02],
                        [  1.08032227e-02,   1.08032227e-02],
                        [ -5.70373535e-02,  -5.70373535e-02],
                        [ -1.21551514e-01,  -1.21551514e-01],
                        [ -1.56860352e-01,  -1.56860352e-01],
                        [ -1.47094727e-01,  -1.47094727e-01],
                        [ -9.93652344e-02,  -9.93652344e-02],
                        [ -3.94287109e-02,  -3.94287109e-02],
                        [  9.64355469e-03,   9.64355469e-03],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  5.81665039e-02,   5.81665039e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  2.54821777e-02,   2.54821777e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -2.14569092e-01,  -2.14538574e-01],
                        [ -2.62756348e-01,  -2.62756348e-01],
                        [ -2.54974365e-01,  -2.54974365e-01],
                        [ -2.02178955e-01,  -2.02178955e-01],
                        [ -1.39770508e-01,  -1.39770508e-01],
                        [ -9.80224609e-02,  -9.80224609e-02],
                        [ -7.98034668e-02,  -7.97729492e-02],
                        [ -7.08618164e-02,  -7.08618164e-02],
                        [ -6.26525879e-02,  -6.26525879e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -5.22460938e-02,  -5.22460938e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -3.29895020e-02,  -3.29895020e-02],
                        [ -1.33056641e-02,  -1.33056641e-02],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  2.91442871e-02,   2.91137695e-02],
                        [  4.23583984e-02,   4.23889160e-02],
                        [  4.59899902e-02,   4.60205078e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.59704590e-02,   2.59399414e-02],
                        [  1.71203613e-02,   1.71508789e-02],
                        [  2.45361328e-02,   2.45361328e-02],
                        [  5.20629883e-02,   5.20629883e-02],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.53869629e-01,   1.53869629e-01],
                        [  1.44165039e-01,   1.44165039e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  7.62939453e-02,   7.62634277e-02],
                        [  5.38940430e-02,   5.38940430e-02],
                        [  4.90112305e-02,   4.90112305e-02],
                        [  6.04553223e-02,   6.04553223e-02],
                        [  8.74938965e-02,   8.74938965e-02],
                        [  1.28173828e-01,   1.28204346e-01],
                        [  1.74560547e-01,   1.74560547e-01],
                        [  2.11975098e-01,   2.11975098e-01],
                        [  2.26959229e-01,   2.26959229e-01],
                        [  2.15545654e-01,   2.15545654e-01],
                        [  1.84814453e-01,   1.84783936e-01],
                        [  1.47796631e-01,   1.47796631e-01],
                        [  1.17095947e-01,   1.17095947e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  8.81347656e-02,   8.81347656e-02],
                        [  7.94372559e-02,   7.94677734e-02],
                        [  7.02819824e-02,   7.02819824e-02],
                        [  6.43920898e-02,   6.43920898e-02],
                        [  6.31713867e-02,   6.32019043e-02],
                        [  6.18591309e-02,   6.18591309e-02],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  3.67736816e-02,   3.68041992e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  2.10571289e-02,   2.10571289e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  2.80761719e-03,   2.80761719e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  6.19506836e-03,   6.19506836e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -8.66699219e-03,  -8.69750977e-03],
                        [ -9.94873047e-03,  -9.97924805e-03],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.75769043e-02,  -4.75769043e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -4.50744629e-02,  -4.50744629e-02],
                        [ -4.68444824e-02,  -4.68444824e-02],
                        [ -5.57861328e-02,  -5.57556152e-02],
                        [ -6.57348633e-02,  -6.57043457e-02],
                        [ -6.87561035e-02,  -6.87255859e-02],
                        [ -6.48803711e-02,  -6.48803711e-02],
                        [ -5.91735840e-02,  -5.91430664e-02],
                        [ -5.29479980e-02,  -5.29479980e-02],
                        [ -4.48913574e-02,  -4.49218750e-02],
                        [ -3.84216309e-02,  -3.84521484e-02],
                        [ -3.97338867e-02,  -3.97644043e-02],
                        [ -4.76379395e-02,  -4.76684570e-02],
                        [ -5.38940430e-02,  -5.39245605e-02],
                        [ -5.53588867e-02,  -5.53894043e-02],
                        [ -5.62744141e-02,  -5.63354492e-02],
                        [ -5.89599609e-02,  -5.89904785e-02],
                        [ -6.10961914e-02,  -6.10961914e-02],
                        [ -6.17370605e-02,  -6.17675781e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -5.01098633e-02,  -5.00793457e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -2.82287598e-02,  -2.81982422e-02],
                        [ -2.44140625e-02,  -2.43835449e-02],
                        [ -2.32543945e-02,  -2.32238770e-02],
                        [ -2.03552246e-02,  -2.02941895e-02],
                        [ -1.14746094e-02,  -1.14135742e-02],
                        [  6.22558594e-03,   6.25610352e-03],
                        [  3.07617188e-02,   3.07922363e-02],
                        [  5.52978516e-02,   5.53283691e-02],
                        [  7.42797852e-02,   7.43103027e-02],
                        [  8.61511230e-02,   8.61206055e-02],
                        [  8.70971680e-02,   8.70666504e-02],
                        [  6.71386719e-02,   6.71081543e-02],
                        [  1.74865723e-02,   1.74255371e-02],
                        [ -5.57861328e-02,  -5.58471680e-02],
                        [ -1.26892090e-01,  -1.26953125e-01],
                        [ -1.65283203e-01,  -1.65344238e-01],
                        [ -1.57928467e-01,  -1.57989502e-01],
                        [ -1.15539551e-01,  -1.15570068e-01],
                        [ -6.03637695e-02,  -6.03942871e-02],
                        [ -1.13220215e-02,  -1.13525391e-02],
                        [  2.40478516e-02,   2.40478516e-02],
                        [  4.70886230e-02,   4.71191406e-02],
                        [  5.80139160e-02,   5.80444336e-02],
                        [  4.94384766e-02,   4.94689941e-02],
                        [  9.88769531e-03,   9.94873047e-03],
                        [ -6.30493164e-02,  -6.29882812e-02],
                        [ -1.51550293e-01,  -1.51489258e-01],
                        [ -2.22808838e-01,  -2.22747803e-01],
                        [ -2.50213623e-01,  -2.50122070e-01],
                        [ -2.30621338e-01,  -2.30560303e-01],
                        [ -1.82312012e-01,  -1.82281494e-01],
                        [ -1.28906250e-01,  -1.28875732e-01],
                        [ -8.75549316e-02,  -8.75549316e-02],
                        [ -6.57958984e-02,  -6.58264160e-02],
                        [ -6.00891113e-02,  -6.01196289e-02],
                        [ -5.96008301e-02,  -5.96618652e-02],
                        [ -5.67626953e-02,  -5.68542480e-02],
                        [ -5.01708984e-02,  -5.02624512e-02],
                        [ -3.88183594e-02,  -3.89099121e-02],
                        [ -2.17895508e-02,  -2.19116211e-02],
                        [ -1.95312500e-03,  -2.04467773e-03],
                        [  1.54724121e-02,   1.54113770e-02],
                        [  2.74658203e-02,   2.74047852e-02],
                        [  3.43322754e-02,   3.43017578e-02],
                        [  3.72009277e-02,   3.72314453e-02],
                        [  3.57971191e-02,   3.58276367e-02],
                        [  3.09143066e-02,   3.09753418e-02],
                        [  2.84118652e-02,   2.85034180e-02],
                        [  3.67431641e-02,   3.68347168e-02],
                        [  5.92346191e-02,   5.93566895e-02],
                        [  9.06066895e-02,   9.07287598e-02],
                        [  1.21154785e-01,   1.21276855e-01],
                        [  1.40350342e-01,   1.40441895e-01],
                        [  1.38946533e-01,   1.39038086e-01],
                        [  1.16333008e-01,   1.16394043e-01],
                        [  8.50524902e-02,   8.50524902e-02],
                        [  6.12182617e-02,   6.11877441e-02],
                        [  5.24597168e-02,   5.24291992e-02],
                        [  5.85327148e-02,   5.84716797e-02],
                        [  7.89489746e-02,   7.88269043e-02],
                        [  1.12884521e-01,   1.12762451e-01],
                        [  1.53656006e-01,   1.53533936e-01],
                        [  1.89147949e-01,   1.88995361e-01],
                        [  2.09014893e-01,   2.08862305e-01],
                        [  2.08312988e-01,   2.08190918e-01],
                        [  1.88262939e-01,   1.88171387e-01],
                        [  1.58386230e-01,   1.58325195e-01],
                        [  1.33544922e-01,   1.33544922e-01],
                        [  1.20208740e-01,   1.20239258e-01],
                        [  1.09130859e-01,   1.09161377e-01],
                        [  9.05151367e-02,   9.06066895e-02],
                        [  6.92749023e-02,   6.93969727e-02],
                        [  5.52673340e-02,   5.54199219e-02],
                        [  4.83703613e-02,   4.85229492e-02],
                        [  4.30297852e-02,   4.31823730e-02],
                        [  3.74145508e-02,   3.75671387e-02],
                        [  3.21044922e-02,   3.21960449e-02],
                        [  2.70690918e-02,   2.71911621e-02],
                        [  2.18505859e-02,   2.19116211e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.21765137e-02,   1.21459961e-02],
                        [  1.48925781e-02,   1.48315430e-02],
                        [  2.33459473e-02,   2.32238770e-02],
                        [  2.97241211e-02,   2.95715332e-02],
                        [  2.76184082e-02,   2.74658203e-02],
                        [  1.77307129e-02,   1.75476074e-02],
                        [  3.50952148e-03,   3.32641602e-03],
                        [ -1.22680664e-02,  -1.24511719e-02],
                        [ -2.46582031e-02,  -2.47802734e-02],
                        [ -2.91748047e-02,  -2.92968750e-02],
                        [ -2.87170410e-02,  -2.87780762e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -3.36914062e-02,  -3.36303711e-02],
                        [ -3.87268066e-02,  -3.86352539e-02],
                        [ -4.45861816e-02,  -4.44335938e-02],
                        [ -5.07812500e-02,  -5.05981445e-02],
                        [ -5.35278320e-02,  -5.33447266e-02],
                        [ -5.08728027e-02,  -5.06591797e-02],
                        [ -4.79736328e-02,  -4.77600098e-02],
                        [ -4.92248535e-02,  -4.90417480e-02],
                        [ -5.03845215e-02,  -5.02319336e-02],
                        [ -4.70275879e-02,  -4.69055176e-02],
                        [ -4.42810059e-02,  -4.42199707e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -5.86547852e-02,  -5.87158203e-02],
                        [ -6.66503906e-02,  -6.67724609e-02],
                        [ -6.89086914e-02,  -6.90612793e-02],
                        [ -6.54907227e-02,  -6.57043457e-02],
                        [ -5.92041016e-02,  -5.94482422e-02],
                        [ -5.45043945e-02,  -5.47485352e-02],
                        [ -5.49926758e-02,  -5.52368164e-02],
                        [ -6.13098145e-02,  -6.15234375e-02],
                        [ -7.10144043e-02,  -7.11975098e-02],
                        [ -7.96813965e-02,  -7.98034668e-02],
                        [ -8.25195312e-02,  -8.26110840e-02],
                        [ -7.67211914e-02,  -7.67211914e-02],
                        [ -6.25610352e-02,  -6.25000000e-02],
                        [ -4.38842773e-02,  -4.37316895e-02],
                        [ -2.67333984e-02,  -2.65502930e-02],
                        [ -1.58691406e-02,  -1.56250000e-02],
                        [ -1.22375488e-02,  -1.19628906e-02],
                        [ -1.40075684e-02,  -1.37634277e-02],
                        [ -1.68762207e-02,  -1.66015625e-02],
                        [ -1.55639648e-02,  -1.53198242e-02],
                        [ -7.41577148e-03,  -7.23266602e-03],
                        [  8.17871094e-03,   8.30078125e-03],
                        [  3.14941406e-02,   3.15551758e-02],
                        [  5.96923828e-02,   5.96618652e-02],
                        [  8.43811035e-02,   8.42895508e-02],
                        [  9.49401855e-02,   9.47875977e-02],
                        [  8.19091797e-02,   8.16955566e-02],
                        [  3.82690430e-02,   3.79943848e-02],
                        [ -3.36608887e-02,  -3.39660645e-02],
                        [ -1.13525391e-01,  -1.13830566e-01],
                        [ -1.70104980e-01,  -1.70379639e-01],
                        [ -1.82159424e-01,  -1.82434082e-01],
                        [ -1.50878906e-01,  -1.51062012e-01],
                        [ -9.39636230e-02,  -9.40856934e-02],
                        [ -3.21960449e-02,  -3.22570801e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [  6.14013672e-02,   6.15234375e-02],
                        [  8.42590332e-02,   8.44421387e-02],
                        [  8.22448730e-02,   8.25195312e-02],
                        [  4.71191406e-02,   4.74243164e-02],
                        [ -2.21862793e-02,  -2.18200684e-02],
                        [ -1.12457275e-01,  -1.12121582e-01],
                        [ -1.99249268e-01,  -1.98944092e-01],
                        [ -2.56713867e-01,  -2.56439209e-01],
                        [ -2.67364502e-01,  -2.67150879e-01],
                        [ -2.31414795e-01,  -2.31292725e-01],
                        [ -1.70166016e-01,  -1.70104980e-01],
                        [ -1.13342285e-01,  -1.13403320e-01],
                        [ -7.89794922e-02,  -7.91320801e-02],
                        [ -6.41784668e-02,  -6.44226074e-02],
                        [ -5.51757812e-02,  -5.54809570e-02],
                        [ -4.47998047e-02,  -4.51354980e-02],
                        [ -3.68347168e-02,  -3.72314453e-02],
                        [ -3.43017578e-02,  -3.46679688e-02],
                        [ -3.05175781e-02,  -3.08532715e-02],
                        [ -1.65710449e-02,  -1.68762207e-02],
                        [  6.62231445e-03,   6.37817383e-03],
                        [  2.87170410e-02,   2.85949707e-02],
                        [  4.06494141e-02,   4.06188965e-02],
                        [  4.15649414e-02,   4.16259766e-02],
                        [  3.63464355e-02,   3.65295410e-02],
                        [  2.95410156e-02,   2.98156738e-02],
                        [  2.31628418e-02,   2.34985352e-02],
                        [  2.19116211e-02,   2.23083496e-02],
                        [  3.52478027e-02,   3.56750488e-02],
                        [  6.79626465e-02,   6.83898926e-02],
                        [  1.11083984e-01,   1.11450195e-01],
                        [  1.46881104e-01,   1.47186279e-01],
                        [  1.60034180e-01,   1.60247803e-01],
                        [  1.44500732e-01,   1.44622803e-01],
                        [  1.07696533e-01,   1.07696533e-01],
                        [  6.83593750e-02,   6.82678223e-02],
                        [  4.37011719e-02,   4.34875488e-02],
                        [  3.82995605e-02,   3.79943848e-02],
                        [  4.96826172e-02,   4.92858887e-02],
                        [  7.80334473e-02,   7.76062012e-02],
                        [  1.22894287e-01,   1.22406006e-01],
                        [  1.74255371e-01,   1.73828125e-01],
                        [  2.14843750e-01,   2.14447021e-01],
                        [  2.30651855e-01,   2.30316162e-01],
                        [  2.19573975e-01,   2.19360352e-01],
                        [  1.90765381e-01,   1.90643311e-01],
                        [  1.56524658e-01,   1.56555176e-01],
                        [  1.26007080e-01,   1.26129150e-01],
                        [  1.03088379e-01,   1.03363037e-01],
                        [  8.69140625e-02,   8.72802734e-02],
                        [  7.44628906e-02,   7.48901367e-02],
                        [  6.38427734e-02,   6.43310547e-02],
                        [  5.59082031e-02,   5.63964844e-02],
                        [  5.29785156e-02,   5.34362793e-02],
                        [  5.46569824e-02,   5.50842285e-02],
                        [  5.53894043e-02,   5.57250977e-02],
                        [  5.00183105e-02,   5.02624512e-02],
                        [  3.94592285e-02,   3.95507812e-02],
                        [  2.72216797e-02,   2.71911621e-02],
                        [  1.45874023e-02,   1.44042969e-02],
                        [  2.53295898e-03,   2.22778320e-03],
                        [ -4.33349609e-03,  -4.73022461e-03],
                        [ -2.92968750e-03,  -3.38745117e-03],
                        [  2.10571289e-03,   1.58691406e-03],
                        [  4.21142578e-03,   3.69262695e-03],
                        [  4.02832031e-03,   3.50952148e-03],
                        [  4.91333008e-03,   4.45556641e-03],
                        [  5.43212891e-03,   5.09643555e-03],
                        [  1.46484375e-03,   1.25122070e-03],
                        [ -9.18579102e-03,  -9.27734375e-03],
                        [ -2.54211426e-02,  -2.53601074e-02],
                        [ -4.28161621e-02,  -4.26025391e-02],
                        [ -5.52368164e-02,  -5.49316406e-02],
                        [ -5.88989258e-02,  -5.84411621e-02],
                        [ -5.55114746e-02,  -5.49621582e-02],
                        [ -5.11169434e-02,  -5.05371094e-02],
                        [ -4.92858887e-02,  -4.87060547e-02],
                        [ -4.77294922e-02,  -4.72106934e-02],
                        [ -4.37927246e-02,  -4.33044434e-02],
                        [ -3.98254395e-02,  -3.94897461e-02],
                        [ -4.01000977e-02,  -3.98864746e-02],
                        [ -4.39758301e-02,  -4.39147949e-02],
                        [ -4.82177734e-02,  -4.83093262e-02],
                        [ -5.32836914e-02,  -5.35278320e-02],
                        [ -6.17065430e-02,  -6.20727539e-02],
                        [ -7.24182129e-02,  -7.29064941e-02],
                        [ -8.11157227e-02,  -8.16955566e-02],
                        [ -8.34960938e-02,  -8.41064453e-02],
                        [ -7.77893066e-02,  -7.83996582e-02],
                        [ -6.73522949e-02,  -6.79321289e-02],
                        [ -5.87463379e-02,  -5.92346191e-02],
                        [ -5.60607910e-02,  -5.63964844e-02],
                        [ -5.88684082e-02,  -5.90820312e-02],
                        [ -6.35375977e-02,  -6.35986328e-02],
                        [ -6.48803711e-02,  -6.47277832e-02],
                        [ -6.09436035e-02,  -6.06384277e-02],
                        [ -5.53588867e-02,  -5.49621582e-02],
                        [ -5.10864258e-02,  -5.05371094e-02],
                        [ -4.50439453e-02,  -4.44030762e-02],
                        [ -3.42407227e-02,  -3.35998535e-02],
                        [ -2.17285156e-02,  -2.10876465e-02],
                        [ -1.15051270e-02,  -1.09252930e-02],
                        [ -3.26538086e-03,  -2.77709961e-03],
                        [  5.73730469e-03,   6.07299805e-03],
                        [  1.82189941e-02,   1.84326172e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.68237305e-02,   5.66711426e-02],
                        [  7.56835938e-02,   7.53784180e-02],
                        [  8.59069824e-02,   8.54187012e-02],
                        [  7.95288086e-02,   7.89184570e-02],
                        [  4.87670898e-02,   4.80957031e-02],
                        [ -8.30078125e-03,  -9.00268555e-03],
                        [ -8.16650391e-02,  -8.23364258e-02],
                        [ -1.49078369e-01,  -1.49688721e-01],
                        [ -1.84417725e-01,  -1.84906006e-01],
                        [ -1.71325684e-01,  -1.71661377e-01],
                        [ -1.15692139e-01,  -1.15875244e-01],
                        [ -4.56542969e-02,  -4.56237793e-02],
                        [  9.79614258e-03,   1.00097656e-02],
                        [  4.31518555e-02,   4.35485840e-02],
                        [  6.36596680e-02,   6.41784668e-02],
                        [  7.53784180e-02,   7.60192871e-02],
                        [  6.82983398e-02,   6.90307617e-02],
                        [  2.77709961e-02,   2.85339355e-02],
                        [ -4.94079590e-02,  -4.86755371e-02],
                        [ -1.44897461e-01,  -1.44256592e-01],
                        [ -2.25341797e-01,  -2.24822998e-01],
                        [ -2.62420654e-01,  -2.62084961e-01],
                        [ -2.49023438e-01,  -2.48870850e-01],
                        [ -1.99676514e-01,  -1.99707031e-01],
                        [ -1.40411377e-01,  -1.40655518e-01],
                        [ -9.56726074e-02,  -9.61303711e-02],
                        [ -7.41271973e-02,  -7.47070312e-02],
                        [ -6.46667480e-02,  -6.53686523e-02],
                        [ -5.35888672e-02,  -5.43823242e-02],
                        [ -4.03442383e-02,  -4.11376953e-02],
                        [ -3.12194824e-02,  -3.19519043e-02],
                        [ -2.74963379e-02,  -2.81372070e-02],
                        [ -2.46582031e-02,  -2.51770020e-02],
                        [ -1.69372559e-02,  -1.72729492e-02],
                        [ -1.37329102e-03,  -1.49536133e-03],
                        [  1.89819336e-02,   1.90429688e-02],
                        [  3.75366211e-02,   3.78112793e-02],
                        [  4.90722656e-02,   4.95910645e-02],
                        [  5.11779785e-02,   5.18188477e-02],
                        [  4.46166992e-02,   4.53796387e-02],
                        [  3.52478027e-02,   3.61022949e-02],
                        [  3.27453613e-02,   3.35693359e-02],
                        [  4.47082520e-02,   4.54711914e-02],
                        [  7.17773438e-02,   7.24487305e-02],
                        [  1.06170654e-01,   1.06689453e-01],
                        [  1.34216309e-01,   1.34521484e-01],
                        [  1.44531250e-01,   1.44653320e-01],
                        [  1.35284424e-01,   1.35192871e-01],
                        [  1.12792969e-01,   1.12426758e-01],
                        [  8.56323242e-02,   8.50830078e-02],
                        [  6.10046387e-02,   6.03027344e-02],
                        [  4.36401367e-02,   4.28161621e-02],
                        [  3.89099121e-02,   3.80249023e-02],
                        [  5.35278320e-02,   5.26428223e-02],
                        [  8.98132324e-02,   8.90197754e-02],
                        [  1.40625000e-01,   1.39953613e-01],
                        [  1.91192627e-01,   1.90673828e-01],
                        [  2.24731445e-01,   2.24456787e-01],
                        [  2.29888916e-01,   2.29797363e-01],
                        [  2.08251953e-01,   2.08404541e-01],
                        [  1.74133301e-01,   1.74560547e-01],
                        [  1.43005371e-01,   1.43615723e-01],
                        [  1.20208740e-01,   1.20971680e-01],
                        [  1.02050781e-01,   1.02935791e-01],
                        [  8.42590332e-02,   8.52050781e-02],
                        [  6.71081543e-02,   6.80236816e-02],
                        [  5.49926758e-02,   5.58166504e-02],
                        [  5.23071289e-02,   5.30090332e-02],
                        [  5.74035645e-02,   5.78918457e-02],
                        [  6.14929199e-02,   6.17675781e-02],
                        [  5.60607910e-02,   5.60913086e-02],
                        [  4.01611328e-02,   3.99475098e-02],
                        [  1.99584961e-02,   1.95007324e-02],
                        [  3.08227539e-03,   2.41088867e-03],
                        [ -5.40161133e-03,  -6.22558594e-03],
                        [ -4.33349609e-03,  -5.27954102e-03],
                        [  2.31933594e-03,   1.34277344e-03],
                        [  8.51440430e-03,   7.56835938e-03],
                        [  1.17797852e-02,   1.09252930e-02],
                        [  1.26037598e-02,   1.19018555e-02],
                        [  1.10168457e-02,   1.04980469e-02],
                        [  6.56127930e-03,   6.31713867e-03],
                        [ -2.04467773e-03,  -2.01416016e-03],
                        [ -1.56250000e-02,  -1.53503418e-02],
                        [ -2.94799805e-02,  -2.89306641e-02],
                        [ -3.68652344e-02,  -3.61328125e-02],
                        [ -3.94897461e-02,  -3.86047363e-02],
                        [ -4.35180664e-02,  -4.25415039e-02],
                        [ -4.84008789e-02,  -4.73632812e-02],
                        [ -5.01098633e-02,  -4.91333008e-02],
                        [ -5.02014160e-02,  -4.93469238e-02],
                        [ -5.21850586e-02,  -5.14831543e-02],
                        [ -5.47180176e-02,  -5.42602539e-02],
                        [ -5.55725098e-02,  -5.53894043e-02],
                        [ -5.62133789e-02,  -5.62438965e-02],
                        [ -5.78918457e-02,  -5.81970215e-02],
                        [ -5.94787598e-02,  -6.00891113e-02],
                        [ -6.03332520e-02,  -6.11572266e-02],
                        [ -6.06079102e-02,  -6.15234375e-02],
                        [ -5.93261719e-02,  -6.03942871e-02],
                        [ -5.58471680e-02,  -5.69152832e-02],
                        [ -5.15136719e-02,  -5.24902344e-02],
                        [ -4.95910645e-02,  -5.04760742e-02],
                        [ -5.21240234e-02,  -5.28259277e-02],
                        [ -5.68847656e-02,  -5.73425293e-02],
                        [ -6.00891113e-02,  -6.02722168e-02],
                        [ -6.15844727e-02,  -6.14929199e-02],
                        [ -6.26525879e-02,  -6.22558594e-02],
                        [ -6.13098145e-02,  -6.06689453e-02],
                        [ -5.63049316e-02,  -5.54504395e-02],
                        [ -5.09948730e-02,  -5.00183105e-02],
                        [ -4.77905273e-02,  -4.66918945e-02],
                        [ -4.33044434e-02,  -4.22058105e-02],
                        [ -3.43627930e-02,  -3.33251953e-02],
                        [ -2.26440430e-02,  -2.17590332e-02],
                        [ -1.17187500e-02,  -1.10473633e-02],
                        [ -2.25830078e-03,  -1.83105469e-03],
                        [  9.73510742e-03,   9.88769531e-03],
                        [  2.94494629e-02,   2.92968750e-02],
                        [  5.53894043e-02,   5.49621582e-02],
                        [  7.79724121e-02,   7.72399902e-02],
                        [  8.79516602e-02,   8.70361328e-02],
                        [  8.18786621e-02,   8.08105469e-02],
                        [  5.63049316e-02,   5.51452637e-02],
                        [  6.40869141e-03,   5.24902344e-03],
                        [ -6.35986328e-02,  -6.46362305e-02],
                        [ -1.33575439e-01,  -1.34460449e-01],
                        [ -1.77398682e-01,  -1.78100586e-01],
                        [ -1.78741455e-01,  -1.79138184e-01],
                        [ -1.39770508e-01,  -1.39862061e-01],
                        [ -8.00781250e-02,  -7.98645020e-02],
                        [ -2.36816406e-02,  -2.31933594e-02],
                        [  1.74560547e-02,   1.82189941e-02],
                        [  4.58374023e-02,   4.68444824e-02],
                        [  6.57348633e-02,   6.68640137e-02],
                        [  7.30590820e-02,   7.42492676e-02],
                        [  5.80139160e-02,   5.92041016e-02],
                        [  1.41601562e-02,   1.51977539e-02],
                        [ -5.47485352e-02,  -5.38635254e-02],
                        [ -1.33880615e-01,  -1.33209229e-01],
                        [ -2.01141357e-01,  -2.00775146e-01],
                        [ -2.34130859e-01,  -2.34069824e-01],
                        [ -2.21954346e-01,  -2.22198486e-01],
                        [ -1.76300049e-01,  -1.76879883e-01],
                        [ -1.26525879e-01,  -1.27380371e-01],
                        [ -9.57946777e-02,  -9.68627930e-02],
                        [ -8.36791992e-02,  -8.48693848e-02],
                        [ -7.61718750e-02,  -7.74230957e-02],
                        [ -6.54602051e-02,  -6.66503906e-02],
                        [ -5.28564453e-02,  -5.39245605e-02],
                        [ -4.02526855e-02,  -4.11682129e-02],
                        [ -2.75573730e-02,  -2.81982422e-02],
                        [ -1.42822266e-02,  -1.45874023e-02],
                        [ -2.13623047e-04,  -2.13623047e-04],
                        [  1.37939453e-02,   1.41296387e-02],
                        [  2.57568359e-02,   2.63977051e-02],
                        [  3.45764160e-02,   3.54919434e-02],
                        [  4.04052734e-02,   4.15344238e-02],
                        [  4.35485840e-02,   4.47692871e-02],
                        [  4.56848145e-02,   4.69665527e-02],
                        [  4.94079590e-02,   5.06591797e-02],
                        [  5.53588867e-02,   5.64270020e-02],
                        [  6.42700195e-02,   6.51550293e-02],
                        [  7.93151855e-02,   7.99255371e-02],
                        [  1.00006104e-01,   1.00250244e-01],
                        [  1.18804932e-01,   1.18743896e-01],
                        [  1.27990723e-01,   1.27593994e-01],
                        [  1.24969482e-01,   1.24237061e-01],
                        [  1.11633301e-01,   1.10626221e-01],
                        [  9.27429199e-02,   9.15832520e-02],
                        [  7.41271973e-02,   7.28454590e-02],
                        [  5.87158203e-02,   5.74035645e-02],
                        [  4.84008789e-02,   4.71496582e-02],
                        [  4.95605469e-02,   4.84619141e-02],
                        [  7.04345703e-02,   6.95495605e-02],
                        [  1.11022949e-01,   1.10443115e-01],
                        [  1.60736084e-01,   1.60491943e-01],
                        [  2.04742432e-01,   2.04864502e-01],
                        [  2.29400635e-01,   2.29858398e-01],
                        [  2.27020264e-01,   2.27783203e-01],
                        [  1.99798584e-01,   2.00866699e-01],
                        [  1.58264160e-01,   1.59515381e-01],
                        [  1.15936279e-01,   1.17279053e-01],
                        [  8.40454102e-02,   8.54187012e-02],
                        [  6.65588379e-02,   6.78405762e-02],
                        [  6.04248047e-02,   6.15234375e-02],
                        [  6.16760254e-02,   6.25305176e-02],
                        [  6.77185059e-02,   6.82373047e-02],
                        [  7.36999512e-02,   7.38830566e-02],
                        [  7.12585449e-02,   7.10754395e-02],
                        [  5.50231934e-02,   5.44738770e-02],
                        [  3.00903320e-02,   2.92053223e-02],
                        [  8.57543945e-03,   7.44628906e-03],
                        [ -1.98364258e-03,  -3.26538086e-03],
                        [ -3.44848633e-03,  -4.85229492e-03],
                        [ -1.70898438e-03,  -3.08227539e-03],
                        [ -6.40869141e-04,  -1.92260742e-03],
                        [ -7.62939453e-04,  -1.86157227e-03],
                        [ -1.06811523e-03,  -1.89208984e-03],
                        [ -1.25122070e-03,  -1.77001953e-03],
                        [ -2.50244141e-03,  -2.62451172e-03],
                        [ -5.92041016e-03,  -5.67626953e-03],
                        [ -1.03454590e-02,  -9.76562500e-03],
                        [ -1.37329102e-02,  -1.27868652e-02],
                        [ -1.62963867e-02,  -1.51062012e-02],
                        [ -1.96228027e-02,  -1.82800293e-02],
                        [ -2.38952637e-02,  -2.24609375e-02],
                        [ -2.93273926e-02,  -2.79235840e-02],
                        [ -3.74145508e-02,  -3.61022949e-02],
                        [ -4.80651855e-02,  -4.69665527e-02],
                        [ -5.85937500e-02,  -5.78002930e-02],
                        [ -6.64062500e-02,  -6.59484863e-02],
                        [ -7.09533691e-02,  -7.08618164e-02],
                        [ -7.26013184e-02,  -7.29370117e-02],
                        [ -7.11059570e-02,  -7.17773438e-02],
                        [ -6.68029785e-02,  -6.78100586e-02],
                        [ -6.17675781e-02,  -6.30187988e-02],
                        [ -5.64575195e-02,  -5.78613281e-02],
                        [ -4.94995117e-02,  -5.09948730e-02],
                        [ -4.25720215e-02,  -4.40368652e-02],
                        [ -4.09545898e-02,  -4.22668457e-02],
                        [ -4.68444824e-02,  -4.79125977e-02],
                        [ -5.56335449e-02,  -5.63964844e-02],
                        [ -6.06079102e-02,  -6.10351562e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -4.94995117e-02,  -4.91027832e-02],
                        [ -4.05273438e-02,  -3.97949219e-02],
                        [ -3.74450684e-02,  -3.63769531e-02],
                        [ -3.93981934e-02,  -3.80554199e-02],
                        [ -4.20532227e-02,  -4.05883789e-02],
                        [ -4.45861816e-02,  -4.30603027e-02],
                        [ -4.69360352e-02,  -4.54711914e-02],
                        [ -4.60205078e-02,  -4.47082520e-02],
                        [ -3.94592285e-02,  -3.84216309e-02],
                        [ -2.85949707e-02,  -2.78930664e-02],
                        [ -1.55639648e-02,  -1.52282715e-02],
                        [  3.05175781e-05,  -3.05175781e-05],
                        [  1.95312500e-02,   1.90734863e-02],
                        [  4.12902832e-02,   4.04663086e-02],
                        [  6.03942871e-02,   5.92346191e-02],
                        [  7.22961426e-02,   7.09228516e-02],
                        [  7.25708008e-02,   7.10449219e-02],
                        [  5.39855957e-02,   5.24597168e-02],
                        [  9.70458984e-03,   8.20922852e-03],
                        [ -5.67932129e-02,  -5.81054688e-02],
                        [ -1.25305176e-01,  -1.26312256e-01],
                        [ -1.68121338e-01,  -1.68792725e-01],
                        [ -1.69128418e-01,  -1.69403076e-01],
                        [ -1.34490967e-01,  -1.34338379e-01],
                        [ -8.59680176e-02,  -8.54187012e-02],
                        [ -4.25720215e-02,  -4.16870117e-02],
                        [ -8.17871094e-03,  -6.95800781e-03],
                        [  2.33154297e-02,   2.47802734e-02],
                        [  5.52062988e-02,   5.67626953e-02],
                        [  8.25500488e-02,   8.41064453e-02],
                        [  9.37194824e-02,   9.52148438e-02],
                        [  7.59582520e-02,   7.72705078e-02],
                        [  2.42004395e-02,   2.51770020e-02],
                        [ -5.39550781e-02,  -5.33447266e-02],
                        [ -1.39251709e-01,  -1.39007568e-01],
                        [ -2.06176758e-01,  -2.06390381e-01],
                        [ -2.33276367e-01,  -2.33886719e-01],
                        [ -2.14385986e-01,  -2.15362549e-01],
                        [ -1.64001465e-01,  -1.65283203e-01],
                        [ -1.10809326e-01,  -1.12335205e-01],
                        [ -7.89794922e-02,  -8.05969238e-02],
                        [ -7.09533691e-02,  -7.25402832e-02],
                        [ -7.08007812e-02,  -7.22961426e-02],
                        [ -6.29272461e-02,  -6.41784668e-02],
                        [ -4.47082520e-02,  -4.56542969e-02],
                        [ -2.28576660e-02,  -2.34680176e-02],
                        [ -4.02832031e-03,  -4.18090820e-03],
                        [  9.61303711e-03,   9.88769531e-03],
                        [  1.93176270e-02,   1.99890137e-02],
                        [  2.76794434e-02,   2.87475586e-02],
                        [  3.51867676e-02,   3.65295410e-02],
                        [  3.84521484e-02,   4.00085449e-02],
                        [  3.40881348e-02,   3.57360840e-02],
                        [  2.31323242e-02,   2.47497559e-02],
                        [  1.19323730e-02,   1.34277344e-02],
                        [  9.12475586e-03,   1.03759766e-02],
                        [  2.15148926e-02,   2.24304199e-02],
                        [  5.05371094e-02,   5.10559082e-02],
                        [  8.92333984e-02,   8.93249512e-02],
                        [  1.23870850e-01,   1.23504639e-01],
                        [  1.42974854e-01,   1.42211914e-01],
                        [  1.43798828e-01,   1.42669678e-01],
                        [  1.29699707e-01,   1.28295898e-01],
                        [  1.06353760e-01,   1.04736328e-01],
                        [  8.12377930e-02,   7.95593262e-02],
                        [  6.09741211e-02,   5.93261719e-02],
                        [  4.72106934e-02,   4.57458496e-02],
                        [  3.88183594e-02,   3.75976562e-02],
                        [  3.95812988e-02,   3.87268066e-02],
                        [  5.90515137e-02,   5.85937500e-02],
                        [  1.00677490e-01,   1.00646973e-01],
                        [  1.53076172e-01,   1.53503418e-01],
                        [  1.96655273e-01,   1.97509766e-01],
                        [  2.15972900e-01,   2.17163086e-01],
                        [  2.06634521e-01,   2.08129883e-01],
                        [  1.76727295e-01,   1.78375244e-01],
                        [  1.41876221e-01,   1.43585205e-01],
                        [  1.14257812e-01,   1.15905762e-01],
                        [  9.55505371e-02,   9.70153809e-02],
                        [  8.21228027e-02,   8.33129883e-02],
                        [  7.29980469e-02,   7.38220215e-02],
                        [  6.77185059e-02,   6.81152344e-02],
                        [  6.23474121e-02,   6.23168945e-02],
                        [  5.37109375e-02,   5.32226562e-02],
                        [  4.25109863e-02,   4.15954590e-02],
                        [  2.98156738e-02,   2.85339355e-02],
                        [  1.61743164e-02,   1.46484375e-02],
                        [  4.97436523e-03,   3.29589844e-03],
                        [  1.37329102e-03,  -3.66210938e-04],
                        [  5.43212891e-03,   3.78417969e-03],
                        [  1.01013184e-02,   8.66699219e-03],
                        [  9.49096680e-03,   8.36181641e-03],
                        [  5.21850586e-03,   4.45556641e-03],
                        [  7.01904297e-04,   3.96728516e-04],
                        [ -4.15039062e-03,  -4.02832031e-03],
                        [ -1.01928711e-02,  -9.61303711e-03],
                        [ -1.59912109e-02,  -1.49841309e-02],
                        [ -2.00195312e-02,  -1.87072754e-02],
                        [ -2.31628418e-02,  -2.15759277e-02],
                        [ -2.78930664e-02,  -2.61840820e-02],
                        [ -3.45458984e-02,  -3.28063965e-02],
                        [ -4.04357910e-02,  -3.87878418e-02],
                        [ -4.51049805e-02,  -4.36706543e-02],
                        [ -5.15441895e-02,  -5.04455566e-02],
                        [ -5.94177246e-02,  -5.87158203e-02],
                        [ -6.32934570e-02,  -6.30187988e-02],
                        [ -6.09130859e-02,  -6.10961914e-02],
                        [ -5.72814941e-02,  -5.79528809e-02],
                        [ -5.70678711e-02,  -5.81359863e-02],
                        [ -5.83496094e-02,  -5.97534180e-02],
                        [ -5.81970215e-02,  -5.98449707e-02],
                        [ -5.76477051e-02,  -5.94177246e-02],
                        [ -5.78308105e-02,  -5.96008301e-02],
                        [ -5.75561523e-02,  -5.92041016e-02],
                        [ -5.72814941e-02,  -5.86853027e-02],
                        [ -5.89294434e-02,  -5.99975586e-02],
                        [ -6.12792969e-02,  -6.19201660e-02],
                        [ -6.12182617e-02,  -6.14013672e-02],
                        [ -5.94482422e-02,  -5.91735840e-02],
                        [ -5.96923828e-02,  -5.89599609e-02],
                        [ -6.23779297e-02,  -6.12487793e-02],
                        [ -6.29272461e-02,  -6.14624023e-02],
                        [ -5.65490723e-02,  -5.48706055e-02],
                        [ -4.36096191e-02,  -4.18090820e-02],
                        [ -3.01513672e-02,  -2.83813477e-02],
                        [ -2.37426758e-02,  -2.20947266e-02],
                        [ -2.62451172e-02,  -2.49023438e-02],
                        [ -3.19213867e-02,  -3.09143066e-02],
                        [ -3.29895020e-02,  -3.24096680e-02],
                        [ -2.60314941e-02,  -2.59094238e-02],
                        [ -1.16271973e-02,  -1.19934082e-02],
                        [  7.99560547e-03,   7.17163086e-03],
                        [  2.91442871e-02,   2.79235840e-02],
                        [  4.79125977e-02,   4.63867188e-02],
                        [  6.18896484e-02,   6.01501465e-02],
                        [  6.59484863e-02,   6.41479492e-02],
                        [  4.98046875e-02,   4.80346680e-02],
                        [  6.68334961e-03,   5.06591797e-03],
                        [ -5.70373535e-02,  -5.83496094e-02],
                        [ -1.24542236e-01,  -1.25488281e-01],
                        [ -1.75048828e-01,  -1.75567627e-01],
                        [ -1.89575195e-01,  -1.89605713e-01],
                        [ -1.62750244e-01,  -1.62292480e-01],
                        [ -1.11053467e-01,  -1.10168457e-01],
                        [ -6.03332520e-02,  -5.90515137e-02],
                        [ -2.50244141e-02,  -2.34375000e-02],
                        [ -1.77001953e-03,   0.00000000e+00],
                        [  2.05078125e-02,   2.23388672e-02],
                        [  4.69360352e-02,   4.87060547e-02],
                        [  7.10144043e-02,   7.26013184e-02],
                        [  7.94677734e-02,   8.07495117e-02],
                        [  6.13098145e-02,   6.21948242e-02],
                        [  1.30615234e-02,   1.34887695e-02],
                        [ -5.90209961e-02,  -5.90515137e-02],
                        [ -1.38641357e-01,  -1.39160156e-01],
                        [ -2.02301025e-01,  -2.03277588e-01],
                        [ -2.28637695e-01,  -2.29980469e-01],
                        [ -2.11639404e-01,  -2.13287354e-01],
                        [ -1.67297363e-01,  -1.69097900e-01],
                        [ -1.22741699e-01,  -1.24572754e-01],
                        [ -9.48791504e-02,  -9.66491699e-02],
                        [ -8.01391602e-02,  -8.16955566e-02],
                        [ -6.58874512e-02,  -6.71386719e-02],
                        [ -4.69665527e-02,  -4.77905273e-02],
                        [ -2.80761719e-02,  -2.84423828e-02],
                        [ -1.42822266e-02,  -1.41601562e-02],
                        [ -4.69970703e-03,  -4.08935547e-03],
                        [  5.37109375e-03,   6.40869141e-03],
                        [  1.94702148e-02,   2.09045410e-02],
                        [  3.73229980e-02,   3.90014648e-02],
                        [  5.20629883e-02,   5.38940430e-02],
                        [  5.30395508e-02,   5.49011230e-02],
                        [  3.69262695e-02,   3.86657715e-02],
                        [  1.36108398e-02,   1.51367188e-02],
                        [ -2.50244141e-03,  -1.31225586e-03],
                        [ -2.19726562e-03,  -1.46484375e-03],
                        [  1.78222656e-02,   1.81274414e-02],
                        [  5.55114746e-02,   5.52978516e-02],
                        [  1.00891113e-01,   1.00219727e-01],
                        [  1.38275146e-01,   1.37145996e-01],
                        [  1.55181885e-01,   1.53717041e-01],
                        [  1.50115967e-01,   1.48406982e-01],
                        [  1.29760742e-01,   1.27899170e-01],
                        [  1.01501465e-01,   9.96398926e-02],
                        [  7.29370117e-02,   7.11975098e-02],
                        [  5.30395508e-02,   5.15441895e-02],
                        [  4.61425781e-02,   4.50134277e-02],
                        [  4.69055176e-02,   4.62341309e-02],
                        [  4.90417480e-02,   4.88281250e-02],
                        [  5.80139160e-02,   5.82885742e-02],
                        [  8.50219727e-02,   8.57849121e-02],
                        [  1.28112793e-01,   1.29302979e-01],
                        [  1.70471191e-01,   1.71997070e-01],
                        [  1.96838379e-01,   1.98608398e-01],
                        [  2.01446533e-01,   2.03338623e-01],
                        [  1.84295654e-01,   1.86157227e-01],
                        [  1.52465820e-01,   1.54174805e-01],
                        [  1.20513916e-01,   1.21978760e-01],
                        [  1.00280762e-01,   1.01348877e-01],
                        [  9.13085938e-02,   9.19494629e-02],
                        [  8.58764648e-02,   8.59985352e-02],
                        [  7.90405273e-02,   7.86743164e-02],
                        [  7.01599121e-02,   6.93054199e-02],
                        [  5.83801270e-02,   5.71289062e-02],
                        [  4.36401367e-02,   4.20532227e-02],
                        [  2.97241211e-02,   2.79235840e-02],
                        [  2.05688477e-02,   1.86462402e-02],
                        [  1.49536133e-02,   1.30920410e-02],
                        [  9.85717773e-03,   8.17871094e-03],
                        [  6.25610352e-03,   4.85229492e-03],
                        [  5.24902344e-03,   4.24194336e-03],
                        [  3.17382812e-03,   2.62451172e-03],
                        [ -1.86157227e-03,  -1.92260742e-03],
                        [ -4.51660156e-03,  -4.08935547e-03],
                        [ -1.64794922e-03,  -7.01904297e-04],
                        [  1.15966797e-03,   2.47192383e-03],
                        [ -1.22070312e-03,   4.27246094e-04],
                        [ -5.43212891e-03,  -3.60107422e-03],
                        [ -7.38525391e-03,  -5.49316406e-03],
                        [ -9.82666016e-03,  -7.99560547e-03],
                        [ -1.72424316e-02,  -1.55944824e-02],
                        [ -2.92663574e-02,  -2.79235840e-02],
                        [ -4.33349609e-02,  -4.23889160e-02],
                        [ -5.72814941e-02,  -5.68237305e-02],
                        [ -6.75354004e-02,  -6.75659180e-02],
                        [ -7.07702637e-02,  -7.12890625e-02],
                        [ -6.86340332e-02,  -6.96105957e-02],
                        [ -6.47888184e-02,  -6.61926270e-02],
                        [ -6.05773926e-02,  -6.22863770e-02],
                        [ -5.67321777e-02,  -5.86242676e-02],
                        [ -5.46569824e-02,  -5.65795898e-02],
                        [ -5.37414551e-02,  -5.55725098e-02],
                        [ -5.18188477e-02,  -5.34362793e-02],
                        [ -4.86145020e-02,  -4.98962402e-02],
                        [ -4.59899902e-02,  -4.68444824e-02],
                        [ -4.57153320e-02,  -4.61120605e-02],
                        [ -4.88891602e-02,  -4.87670898e-02],
                        [ -5.52062988e-02,  -5.45959473e-02],
                        [ -6.14929199e-02,  -6.04248047e-02],
                        [ -6.51245117e-02,  -6.36901855e-02],
                        [ -6.82678223e-02,  -6.65588379e-02],
                        [ -7.19909668e-02,  -7.00988770e-02],
                        [ -7.00988770e-02,  -6.81762695e-02],
                        [ -5.72814941e-02,  -5.54809570e-02],
                        [ -3.86047363e-02,  -3.70483398e-02],
                        [ -2.43530273e-02,  -2.31323242e-02],
                        [ -1.85546875e-02,  -1.77612305e-02],
                        [ -1.61132812e-02,  -1.58081055e-02],
                        [ -9.85717773e-03,  -1.00402832e-02],
                        [  2.31933594e-03,   1.61743164e-03],
                        [  1.75781250e-02,   1.64489746e-02],
                        [  3.35083008e-02,   3.20129395e-02],
                        [  4.86450195e-02,   4.68750000e-02],
                        [  5.91125488e-02,   5.71899414e-02],
                        [  5.86547852e-02,   5.67321777e-02],
                        [  4.23889160e-02,   4.06188965e-02],
                        [  7.96508789e-03,   6.43920898e-03],
                        [ -4.44641113e-02,  -4.56237793e-02],
                        [ -1.08184814e-01,  -1.08917236e-01],
                        [ -1.66259766e-01,  -1.66503906e-01],
                        [ -1.95373535e-01,  -1.95098877e-01],
                        [ -1.80755615e-01,  -1.79992676e-01],
                        [ -1.32690430e-01,  -1.31469727e-01],
                        [ -8.07495117e-02,  -7.91625977e-02],
                        [ -4.46472168e-02,  -4.28466797e-02],
                        [ -1.98364258e-02,  -1.79138184e-02],
                        [  5.92041016e-03,   7.84301758e-03],
                        [  3.62243652e-02,   3.79943848e-02],
                        [  6.69860840e-02,   6.84814453e-02],
                        [  9.00573730e-02,   9.11560059e-02],
                        [  9.38415527e-02,   9.44824219e-02],
                        [  6.81152344e-02,   6.82678223e-02],
                        [  1.15661621e-02,   1.11999512e-02],
                        [ -6.57958984e-02,  -6.66503906e-02],
                        [ -1.45599365e-01,  -1.46881104e-01],
                        [ -2.05352783e-01,  -2.06970215e-01],
                        [ -2.26013184e-01,  -2.27874756e-01],
                        [ -2.04589844e-01,  -2.06542969e-01],
                        [ -1.59149170e-01,  -1.61041260e-01],
                        [ -1.14593506e-01,  -1.16302490e-01],
                        [ -8.38623047e-02,  -8.52966309e-02],
                        [ -6.43005371e-02,  -6.53686523e-02],
                        [ -4.78820801e-02,  -4.84619141e-02],
                        [ -3.13110352e-02,  -3.13720703e-02],
                        [ -1.68762207e-02,  -1.64489746e-02],
                        [ -7.11059570e-03,  -6.19506836e-03],
                        [ -5.79833984e-04,   7.62939453e-04],
                        [  6.10351562e-03,   7.78198242e-03],
                        [  1.40075684e-02,   1.58691406e-02],
                        [  2.04467773e-02,   2.23999023e-02],
                        [  2.22473145e-02,   2.41394043e-02],
                        [  1.95617676e-02,   2.12707520e-02],
                        [  1.82189941e-02,   1.95922852e-02],
                        [  2.48413086e-02,   2.58178711e-02],
                        [  3.81164551e-02,   3.86047363e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  5.88989258e-02,   5.83496094e-02],
                        [  7.30895996e-02,   7.21130371e-02],
                        [  9.90295410e-02,   9.76257324e-02],
                        [  1.28936768e-01,   1.27227783e-01],
                        [  1.46545410e-01,   1.44653320e-01],
                        [  1.44195557e-01,   1.42242432e-01],
                        [  1.29119873e-01,   1.27258301e-01],
                        [  1.11785889e-01,   1.10137939e-01],
                        [  9.49401855e-02,   9.35974121e-02],
                        [  7.62634277e-02,   7.53784180e-02],
                        [  5.65795898e-02,   5.61828613e-02],
                        [  4.16870117e-02,   4.17785645e-02],
                        [  3.68652344e-02,   3.74450684e-02],
                        [  4.33654785e-02,   4.44335938e-02],
                        [  6.18286133e-02,   6.32934570e-02],
                        [  9.29870605e-02,   9.47265625e-02],
                        [  1.32141113e-01,   1.34063721e-01],
                        [  1.67388916e-01,   1.69342041e-01],
                        [  1.85577393e-01,   1.87408447e-01],
                        [  1.80755615e-01,   1.82342529e-01],
                        [  1.58752441e-01,   1.60034180e-01],
                        [  1.33544922e-01,   1.34368896e-01],
                        [  1.16180420e-01,   1.16516113e-01],
                        [  1.06811523e-01,   1.06628418e-01],
                        [  9.69848633e-02,   9.62829590e-02],
                        [  8.08715820e-02,   7.97424316e-02],
                        [  6.22558594e-02,   6.07299805e-02],
                        [  4.78820801e-02,   4.60815430e-02],
                        [  3.84826660e-02,   3.65600586e-02],
                        [  3.05480957e-02,   2.85949707e-02],
                        [  2.31018066e-02,   2.12707520e-02],
                        [  1.80969238e-02,   1.65100098e-02],
                        [  1.56555176e-02,   1.44348145e-02],
                        [  1.31835938e-02,   1.24206543e-02],
                        [  8.33129883e-03,   8.08715820e-03],
                        [  1.52587891e-03,   1.80053711e-03],
                        [ -4.54711914e-03,  -3.78417969e-03],
                        [ -8.02612305e-03,  -6.83593750e-03],
                        [ -1.03149414e-02,  -8.72802734e-03],
                        [ -1.39465332e-02,  -1.21154785e-02],
                        [ -1.89819336e-02,  -1.70288086e-02],
                        [ -2.29492188e-02,  -2.10266113e-02],
                        [ -2.44750977e-02,  -2.27050781e-02],
                        [ -2.50244141e-02,  -2.35290527e-02],
                        [ -2.73742676e-02,  -2.62451172e-02],
                        [ -3.17382812e-02,  -3.10668945e-02],
                        [ -3.62548828e-02,  -3.61022949e-02],
                        [ -4.03747559e-02,  -4.07409668e-02],
                        [ -4.39453125e-02,  -4.47998047e-02],
                        [ -4.58984375e-02,  -4.71801758e-02],
                        [ -4.77294922e-02,  -4.93469238e-02],
                        [ -5.23986816e-02,  -5.42602539e-02],
                        [ -5.85021973e-02,  -6.04553223e-02],
                        [ -6.21337891e-02,  -6.40563965e-02],
                        [ -6.30798340e-02,  -6.48498535e-02],
                        [ -6.40563965e-02,  -6.55212402e-02],
                        [ -6.66503906e-02,  -6.77185059e-02],
                        [ -6.96411133e-02,  -7.02209473e-02],
                        [ -6.95190430e-02,  -6.96105957e-02],
                        [ -6.36901855e-02,  -6.32629395e-02],
                        [ -5.37109375e-02,  -5.27648926e-02],
                        [ -4.46166992e-02,  -4.32739258e-02],
                        [ -3.98864746e-02,  -3.82080078e-02],
                        [ -3.83605957e-02,  -3.64990234e-02],
                        [ -3.86962891e-02,  -3.67431641e-02],
                        [ -4.26025391e-02,  -4.06799316e-02],
                        [ -4.96215820e-02,  -4.79125977e-02],
                        [ -5.32531738e-02,  -5.18493652e-02],
                        [ -4.81567383e-02,  -4.71496582e-02],
                        [ -3.75061035e-02,  -3.69873047e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -1.48010254e-02,  -1.53198242e-02],
                        [  1.34277344e-03,   3.66210938e-04],
                        [  1.95617676e-02,   1.81579590e-02],
                        [  3.54309082e-02,   3.37219238e-02],
                        [  4.78515625e-02,   4.59594727e-02],
                        [  5.63659668e-02,   5.44128418e-02],
                        [  5.69152832e-02,   5.50231934e-02],
                        [  4.25720215e-02,   4.09240723e-02],
                        [  6.10351562e-03,   4.76074219e-03],
                        [ -5.53283691e-02,  -5.62438965e-02],
                        [ -1.30493164e-01,  -1.30920410e-01],
                        [ -1.91925049e-01,  -1.91833496e-01],
                        [ -2.12890625e-01,  -2.12280273e-01],
                        [ -1.89910889e-01,  -1.88842773e-01],
                        [ -1.42425537e-01,  -1.40960693e-01],
                        [ -9.28039551e-02,  -9.10644531e-02],
                        [ -5.40771484e-02,  -5.21545410e-02],
                        [ -2.91137695e-02,  -2.71606445e-02],
                        [ -1.06811523e-02,  -8.81958008e-03],
                        [  1.26953125e-02,   1.43127441e-02],
                        [  4.41894531e-02,   4.54711914e-02],
                        [  7.53784180e-02,   7.62329102e-02],
                        [  9.52453613e-02,   9.56115723e-02],
                        [  9.80834961e-02,   9.79003906e-02],
                        [  8.12988281e-02,   8.06274414e-02],
                        [  4.01611328e-02,   3.90319824e-02],
                        [ -2.91442871e-02,  -3.06701660e-02],
                        [ -1.17309570e-01,  -1.19079590e-01],
                        [ -1.96136475e-01,  -1.98059082e-01],
                        [ -2.34008789e-01,  -2.35961914e-01],
                        [ -2.21069336e-01,  -2.22900391e-01],
                        [ -1.75048828e-01,  -1.76605225e-01],
                        [ -1.23291016e-01,  -1.24511719e-01],
                        [ -8.51135254e-02,  -8.58764648e-02],
                        [ -6.58874512e-02,  -6.61621094e-02],
                        [ -5.74035645e-02,  -5.71594238e-02],
                        [ -4.68139648e-02,  -4.60510254e-02],
                        [ -3.09448242e-02,  -2.97241211e-02],
                        [ -1.68762207e-02,  -1.53198242e-02],
                        [ -8.48388672e-03,  -6.65283203e-03],
                        [ -1.00708008e-03,   9.46044922e-04],
                        [  9.79614258e-03,   1.17492676e-02],
                        [  2.11791992e-02,   2.29797363e-02],
                        [  2.87170410e-02,   3.02429199e-02],
                        [  3.26232910e-02,   3.37829590e-02],
                        [  3.55834961e-02,   3.62854004e-02],
                        [  3.82385254e-02,   3.84216309e-02],
                        [  4.04663086e-02,   4.01306152e-02],
                        [  4.52575684e-02,   4.44335938e-02],
                        [  5.77697754e-02,   5.64880371e-02],
                        [  7.93457031e-02,   7.77282715e-02],
                        [  1.04461670e-01,   1.02630615e-01],
                        [  1.24755859e-01,   1.22802734e-01],
                        [  1.34063721e-01,   1.32110596e-01],
                        [  1.30523682e-01,   1.28753662e-01],
                        [  1.17950439e-01,   1.16485596e-01],
                        [  1.04492188e-01,   1.03424072e-01],
                        [  9.60693359e-02,   9.54589844e-02],
                        [  9.03015137e-02,   9.02099609e-02],
                        [  7.97119141e-02,   8.01086426e-02],
                        [  6.11877441e-02,   6.21032715e-02],
                        [  4.04052734e-02,   4.17480469e-02],
                        [  2.73132324e-02,   2.89916992e-02],
                        [  3.05480957e-02,   3.24401855e-02],
                        [  5.31005859e-02,   5.50842285e-02],
                        [  9.03625488e-02,   9.22546387e-02],
                        [  1.33605957e-01,   1.35314941e-01],
                        [  1.72149658e-01,   1.73583984e-01],
                        [  1.91131592e-01,   1.92138672e-01],
                        [  1.80847168e-01,   1.81365967e-01],
                        [  1.51763916e-01,   1.51763916e-01],
                        [  1.25701904e-01,   1.25183105e-01],
                        [  1.11175537e-01,   1.10198975e-01],
                        [  1.00860596e-01,   9.94873047e-02],
                        [  8.95690918e-02,   8.78601074e-02],
                        [  7.95288086e-02,   7.76367188e-02],
                        [  7.08618164e-02,   6.89086914e-02],
                        [  5.95092773e-02,   5.76171875e-02],
                        [  4.42199707e-02,   4.25415039e-02],
                        [  2.83203125e-02,   2.69775391e-02],
                        [  1.56250000e-02,   1.46789551e-02],
                        [  7.90405273e-03,   7.44628906e-03],
                        [  4.02832031e-03,   4.11987305e-03],
                        [  1.46484375e-03,   2.04467773e-03],
                        [ -7.32421875e-04,   3.35693359e-04],
                        [ -2.22778320e-03,  -7.62939453e-04],
                        [ -3.72314453e-03,  -1.98364258e-03],
                        [ -5.52368164e-03,  -3.60107422e-03],
                        [ -6.77490234e-03,  -4.79125977e-03],
                        [ -7.99560547e-03,  -6.13403320e-03],
                        [ -9.79614258e-03,  -8.14819336e-03],
                        [ -1.07421875e-02,  -9.46044922e-03],
                        [ -1.07421875e-02,  -9.88769531e-03],
                        [ -1.40686035e-02,  -1.37329102e-02],
                        [ -2.38342285e-02,  -2.39868164e-02],
                        [ -3.58886719e-02,  -3.65600586e-02],
                        [ -4.41284180e-02,  -4.52575684e-02],
                        [ -4.84008789e-02,  -4.98962402e-02],
                        [ -5.30090332e-02,  -5.48095703e-02],
                        [ -5.99975586e-02,  -6.19506836e-02],
                        [ -6.69555664e-02,  -6.89086914e-02],
                        [ -7.04345703e-02,  -7.22656250e-02],
                        [ -6.96105957e-02,  -7.11975098e-02],
                        [ -6.59484863e-02,  -6.71691895e-02],
                        [ -6.14929199e-02,  -6.22558594e-02],
                        [ -5.85937500e-02,  -5.88989258e-02],
                        [ -5.74340820e-02,  -5.71899414e-02],
                        [ -5.47485352e-02,  -5.40161133e-02],
                        [ -4.93774414e-02,  -4.81872559e-02],
                        [ -4.48913574e-02,  -4.33349609e-02],
                        [ -4.37011719e-02,  -4.18701172e-02],
                        [ -4.36096191e-02,  -4.16564941e-02],
                        [ -4.11071777e-02,  -3.91540527e-02],
                        [ -3.49731445e-02,  -3.31726074e-02],
                        [ -2.84423828e-02,  -2.69165039e-02],
                        [ -2.78015137e-02,  -2.66418457e-02],
                        [ -3.46984863e-02,  -3.39965820e-02],
                        [ -4.13513184e-02,  -4.11376953e-02],
                        [ -3.82080078e-02,  -3.85131836e-02],
                        [ -2.48413086e-02,  -2.56652832e-02],
                        [ -8.54492188e-03,  -9.79614258e-03],
                        [  6.46972656e-03,   4.85229492e-03],
                        [  2.14843750e-02,   1.96228027e-02],
                        [  3.69262695e-02,   3.49731445e-02],
                        [  4.99267578e-02,   4.79736328e-02],
                        [  5.63354492e-02,   5.45654297e-02],
                        [  4.87060547e-02,   4.72412109e-02],
                        [  1.57470703e-02,   1.46789551e-02],
                        [ -4.72412109e-02,  -4.78515625e-02],
                        [ -1.25854492e-01,  -1.25946045e-01],
                        [ -1.89819336e-01,  -1.89422607e-01],
                        [ -2.13226318e-01,  -2.12341309e-01],
                        [ -1.92443848e-01,  -1.91101074e-01],
                        [ -1.46789551e-01,  -1.45141602e-01],
                        [ -1.02508545e-01,  -1.00646973e-01],
                        [ -7.29064941e-02,  -7.09533691e-02],
                        [ -5.23376465e-02,  -5.04150391e-02],
                        [ -2.78320312e-02,  -2.60925293e-02],
                        [  5.27954102e-03,   6.71386719e-03],
                        [  3.92761230e-02,   4.02832031e-02],
                        [  6.52160645e-02,   6.57653809e-02],
                        [  8.49609375e-02,   8.49914551e-02],
                        [  1.04187012e-01,   1.03698730e-01],
                        [  1.15539551e-01,   1.14562988e-01],
                        [  9.95788574e-02,   9.82055664e-02],
                        [  4.41894531e-02,   4.24804688e-02],
                        [ -4.25720215e-02,  -4.44641113e-02],
                        [ -1.36230469e-01,  -1.38214111e-01],
                        [ -2.07519531e-01,  -2.09411621e-01],
                        [ -2.34497070e-01,  -2.36175537e-01],
                        [ -2.13684082e-01,  -2.15026855e-01],
                        [ -1.64489746e-01,  -1.65435791e-01],
                        [ -1.17309570e-01,  -1.17767334e-01],
                        [ -9.01794434e-02,  -9.01184082e-02],
                        [ -7.75146484e-02,  -7.69653320e-02],
                        [ -6.28356934e-02,  -6.17980957e-02],
                        [ -4.04663086e-02,  -3.90319824e-02],
                        [ -2.04467773e-02,  -1.87072754e-02],
                        [ -1.23901367e-02,  -1.04980469e-02],
                        [ -1.28173828e-02,  -1.08642578e-02],
                        [ -1.15661621e-02,  -9.70458984e-03],
                        [ -3.23486328e-03,  -1.58691406e-03],
                        [  1.07727051e-02,   1.20544434e-02],
                        [  2.49633789e-02,   2.58178711e-02],
                        [  3.39965820e-02,   3.43627930e-02],
                        [  3.67736816e-02,   3.66210938e-02],
                        [  3.69262695e-02,   3.62548828e-02],
                        [  3.97644043e-02,   3.86657715e-02],
                        [  5.03540039e-02,   4.88281250e-02],
                        [  7.14111328e-02,   6.96105957e-02],
                        [  9.97314453e-02,   9.78088379e-02],
                        [  1.25366211e-01,   1.23413086e-01],
                        [  1.38610840e-01,   1.36779785e-01],
                        [  1.38488770e-01,   1.36901855e-01],
                        [  1.31408691e-01,   1.30157471e-01],
                        [  1.22192383e-01,   1.21398926e-01],
                        [  1.10076904e-01,   1.09771729e-01],
                        [  9.42687988e-02,   9.44824219e-02],
                        [  7.79724121e-02,   7.87048340e-02],
                        [  6.37512207e-02,   6.49414062e-02],
                        [  5.01403809e-02,   5.16967773e-02],
                        [  3.67126465e-02,   3.85131836e-02],
                        [  2.74963379e-02,   2.94494629e-02],
                        [  2.79235840e-02,   2.98767090e-02],
                        [  4.24804688e-02,   4.43115234e-02],
                        [  7.18078613e-02,   7.33642578e-02],
                        [  1.10198975e-01,   1.11358643e-01],
                        [  1.49719238e-01,   1.50421143e-01],
                        [  1.82067871e-01,   1.82281494e-01],
                        [  1.95251465e-01,   1.94946289e-01],
                        [  1.81030273e-01,   1.80206299e-01],
                        [  1.47979736e-01,   1.46728516e-01],
                        [  1.14715576e-01,   1.13098145e-01],
                        [  9.08508301e-02,   8.90197754e-02],
                        [  7.46459961e-02,   7.26928711e-02],
                        [  6.41174316e-02,   6.21948242e-02],
                        [  5.97229004e-02,   5.79528809e-02],
                        [  5.82580566e-02,   5.67626953e-02],
                        [  5.31005859e-02,   5.20019531e-02],
                        [  4.12902832e-02,   4.06799316e-02],
                        [  2.63366699e-02,   2.61840820e-02],
                        [  1.36718750e-02,   1.40686035e-02],
                        [  4.82177734e-03,   5.70678711e-03],
                        [ -3.50952148e-03,  -2.19726562e-03],
                        [ -1.35803223e-02,  -1.19323730e-02],
                        [ -2.26440430e-02,  -2.07824707e-02],
                        [ -2.63977051e-02,  -2.44445801e-02],
                        [ -2.31323242e-02,  -2.12097168e-02],
                        [ -1.52282715e-02,  -1.35192871e-02],
                        [ -7.41577148e-03,  -5.98144531e-03],
                        [ -3.29589844e-03,  -2.25830078e-03],
                        [ -4.39453125e-03,  -3.84521484e-03],
                        [ -1.01928711e-02,  -1.01623535e-02],
                        [ -1.75476074e-02,  -1.80053711e-02],
                        [ -2.31323242e-02,  -2.40783691e-02],
                        [ -2.73742676e-02,  -2.87475586e-02],
                        [ -3.27453613e-02,  -3.44238281e-02],
                        [ -4.00390625e-02,  -4.19311523e-02],
                        [ -4.90722656e-02,  -5.10559082e-02],
                        [ -5.92651367e-02,  -6.11572266e-02],
                        [ -6.81152344e-02,  -6.97937012e-02],
                        [ -7.25402832e-02,  -7.39135742e-02],
                        [ -7.31811523e-02,  -7.41577148e-02],
                        [ -7.43408203e-02,  -7.47985840e-02],
                        [ -7.68127441e-02,  -7.67822266e-02],
                        [ -7.51037598e-02,  -7.45544434e-02],
                        [ -6.46362305e-02,  -6.36291504e-02],
                        [ -4.94689941e-02,  -4.80346680e-02],
                        [ -3.86962891e-02,  -3.69567871e-02],
                        [ -3.64074707e-02,  -3.44848633e-02],
                        [ -3.86352539e-02,  -3.66821289e-02],
                        [ -4.01306152e-02,  -3.82690430e-02],
                        [ -4.00390625e-02,  -3.83911133e-02],
                        [ -3.96728516e-02,  -3.83605957e-02],
                        [ -3.96118164e-02,  -3.87268066e-02],
                        [ -3.85437012e-02,  -3.81469727e-02],
                        [ -3.36608887e-02,  -3.37829590e-02],
                        [ -2.40173340e-02,  -2.46582031e-02],
                        [ -1.23291016e-02,  -1.34277344e-02],
                        [ -6.71386719e-04,  -2.16674805e-03],
                        [  1.14440918e-02,   9.67407227e-03],
                        [  2.35290527e-02,   2.16064453e-02],
                        [  3.32946777e-02,   3.13415527e-02],
                        [  4.01611328e-02,   3.83300781e-02],
                        [  4.45861816e-02,   4.29687500e-02],
                        [  4.10461426e-02,   3.97949219e-02],
                        [  1.66015625e-02,   1.58081055e-02],
                        [ -3.63159180e-02,  -3.66210938e-02],
                        [ -1.06506348e-01,  -1.06292725e-01],
                        [ -1.68640137e-01,  -1.67907715e-01],
                        [ -2.01202393e-01,  -2.00042725e-01],
                        [ -1.98028564e-01,  -1.96502686e-01],
                        [ -1.67114258e-01,  -1.65313721e-01],
                        [ -1.24053955e-01,  -1.22131348e-01],
                        [ -8.47778320e-02,  -8.28247070e-02],
                        [ -5.66711426e-02,  -5.48706055e-02],
                        [ -3.58276367e-02,  -3.42712402e-02],
                        [ -1.53808594e-02,  -1.41906738e-02],
                        [  6.92749023e-03,   7.65991211e-03],
                        [  3.18298340e-02,   3.20434570e-02],
                        [  6.08825684e-02,   6.05773926e-02],
                        [  9.12475586e-02,   9.04846191e-02],
                        [  1.14318848e-01,   1.13067627e-01],
                        [  1.20788574e-01,   1.19201660e-01],
                        [  1.02478027e-01,   1.00646973e-01],
                        [  5.11169434e-02,   4.91943359e-02],
                        [ -3.38745117e-02,  -3.57971191e-02],
                        [ -1.33972168e-01,  -1.35742188e-01],
                        [ -2.14691162e-01,  -2.16186523e-01],
                        [ -2.46307373e-01,  -2.47436523e-01],
                        [ -2.23083496e-01,  -2.23724365e-01],
                        [ -1.66473389e-01,  -1.66625977e-01],
                        [ -1.10260010e-01,  -1.09893799e-01],
                        [ -7.60192871e-02,  -7.51342773e-02],
                        [ -6.09130859e-02,  -5.96313477e-02],
                        [ -5.07202148e-02,  -4.90722656e-02],
                        [ -3.91540527e-02,  -3.72924805e-02],
                        [ -2.96020508e-02,  -2.76489258e-02],
                        [ -2.31323242e-02,  -2.12402344e-02],
                        [ -1.49841309e-02,  -1.32446289e-02],
                        [ -2.53295898e-03,  -1.09863281e-03],
                        [  1.04980469e-02,   1.15356445e-02],
                        [  2.06298828e-02,   2.11791992e-02],
                        [  2.83508301e-02,   2.84118652e-02],
                        [  3.45764160e-02,   3.41186523e-02],
                        [  3.75976562e-02,   3.66516113e-02],
                        [  3.66210938e-02,   3.52783203e-02],
                        [  3.61022949e-02,   3.44238281e-02],
                        [  4.30603027e-02,   4.11987305e-02],
                        [  6.07299805e-02,   5.87768555e-02],
                        [  8.70056152e-02,   8.51135254e-02],
                        [  1.15692139e-01,   1.14013672e-01],
                        [  1.36352539e-01,   1.34979248e-01],
                        [  1.39373779e-01,   1.38397217e-01],
                        [  1.25610352e-01,   1.25122070e-01],
                        [  1.06231689e-01,   1.06262207e-01],
                        [  9.20715332e-02,   9.25903320e-02],
                        [  8.62426758e-02,   8.72497559e-02],
                        [  8.49304199e-02,   8.63342285e-02],
                        [  8.07495117e-02,   8.24584961e-02],
                        [  6.79321289e-02,   6.98242188e-02],
                        [  4.84008789e-02,   5.03540039e-02],
                        [  3.19824219e-02,   3.38439941e-02],
                        [  2.73437500e-02,   2.89611816e-02],
                        [  3.58581543e-02,   3.71704102e-02],
                        [  5.57250977e-02,   5.66406250e-02],
                        [  8.65478516e-02,   8.69445801e-02],
                        [  1.25396729e-01,   1.25305176e-01],
                        [  1.61346436e-01,   1.60736084e-01],
                        [  1.79290771e-01,   1.78192139e-01],
                        [  1.72637939e-01,   1.71173096e-01],
                        [  1.48864746e-01,   1.47125244e-01],
                        [  1.20086670e-01,   1.18164062e-01],
                        [  9.32617188e-02,   9.13391113e-02],
                        [  7.09533691e-02,   6.91223145e-02],
                        [  5.48400879e-02,   5.32531738e-02],
                        [  4.60815430e-02,   4.48608398e-02],
                        [  4.37927246e-02,   4.29687500e-02],
                        [  4.46166992e-02,   4.43115234e-02],
                        [  4.43115234e-02,   4.44946289e-02],
                        [  4.01306152e-02,   4.08020020e-02],
                        [  3.21655273e-02,   3.33251953e-02],
                        [  2.13623047e-02,   2.28881836e-02],
                        [  7.41577148e-03,   9.21630859e-03],
                        [ -8.39233398e-03,  -6.50024414e-03],
                        [ -2.08740234e-02,  -1.89514160e-02],
                        [ -2.60009766e-02,  -2.42004395e-02],
                        [ -2.60925293e-02,  -2.45361328e-02],
                        [ -2.54211426e-02,  -2.42309570e-02],
                        [ -2.51464844e-02,  -2.44140625e-02],
                        [ -2.48107910e-02,  -2.45666504e-02],
                        [ -2.48718262e-02,  -2.51464844e-02],
                        [ -2.51159668e-02,  -2.58789062e-02],
                        [ -2.32238770e-02,  -2.44140625e-02],
                        [ -1.86767578e-02,  -2.02331543e-02],
                        [ -1.64794922e-02,  -1.82800293e-02],
                        [ -2.17285156e-02,  -2.36511230e-02],
                        [ -3.26232910e-02,  -3.45458984e-02],
                        [ -4.38537598e-02,  -4.55932617e-02],
                        [ -5.35583496e-02,  -5.50537109e-02],
                        [ -6.27136230e-02,  -6.38122559e-02],
                        [ -7.11059570e-02,  -7.17773438e-02],
                        [ -7.75756836e-02,  -7.77282715e-02],
                        [ -8.08715820e-02,  -8.05358887e-02],
                        [ -7.97119141e-02,  -7.88879395e-02],
                        [ -7.38525391e-02,  -7.25708008e-02],
                        [ -6.54296875e-02,  -6.38427734e-02],
                        [ -5.76171875e-02,  -5.57861328e-02],
                        [ -5.22155762e-02,  -5.02929688e-02],
                        [ -4.91943359e-02,  -4.73022461e-02],
                        [ -4.57763672e-02,  -4.40673828e-02],
                        [ -3.92456055e-02,  -3.78417969e-02],
                        [ -3.22875977e-02,  -3.12500000e-02],
                        [ -3.07922363e-02,  -3.02429199e-02],
                        [ -3.52478027e-02,  -3.51867676e-02],
                        [ -4.02526855e-02,  -4.06799316e-02],
                        [ -4.08325195e-02,  -4.17480469e-02],
                        [ -3.52172852e-02,  -3.65295410e-02],
                        [ -2.43225098e-02,  -2.59399414e-02],
                        [ -1.06506348e-02,  -1.24816895e-02],
                        [  4.33349609e-03,   2.44140625e-03],
                        [  2.06604004e-02,   1.87988281e-02],
                        [  3.80249023e-02,   3.63464355e-02],
                        [  5.51452637e-02,   5.37719727e-02],
                        [  6.67724609e-02,   6.57958984e-02],
                        [  6.02111816e-02,   5.97229004e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [ -4.35791016e-02,  -4.30908203e-02],
                        [ -1.19323730e-01,  -1.18347168e-01],
                        [ -1.81671143e-01,  -1.80297852e-01],
                        [ -2.14538574e-01,  -2.12860107e-01],
                        [ -2.10693359e-01,  -2.08862305e-01],
                        [ -1.75750732e-01,  -1.73828125e-01],
                        [ -1.28143311e-01,  -1.26312256e-01],
                        [ -8.73413086e-02,  -8.57238770e-02],
                        [ -6.04248047e-02,  -5.91430664e-02],
                        [ -4.21142578e-02,  -4.12292480e-02],
                        [ -2.54516602e-02,  -2.50244141e-02],
                        [ -7.20214844e-03,  -7.29370117e-03],
                        [  1.56555176e-02,   1.50451660e-02],
                        [  4.58068848e-02,   4.47692871e-02],
                        [  8.01086426e-02,   7.87048340e-02],
                        [  1.11145020e-01,   1.09436035e-01],
                        [  1.32110596e-01,   1.30249023e-01],
                        [  1.33026123e-01,   1.31164551e-01],
                        [  9.93041992e-02,   9.75341797e-02],
                        [  2.38952637e-02,   2.23388672e-02],
                        [ -7.98034668e-02,  -8.10241699e-02],
                        [ -1.79626465e-01,  -1.80419922e-01],
                        [ -2.39898682e-01,  -2.40234375e-01],
                        [ -2.41271973e-01,  -2.41088867e-01],
                        [ -1.94366455e-01,  -1.93695068e-01],
                        [ -1.34246826e-01,  -1.33148193e-01],
                        [ -9.31396484e-02,  -9.16748047e-02],
                        [ -7.51037598e-02,  -7.33642578e-02],
                        [ -6.18286133e-02,  -5.99670410e-02],
                        [ -4.16870117e-02,  -3.97949219e-02],
                        [ -2.27050781e-02,  -2.09655762e-02],
                        [ -1.56860352e-02,  -1.41601562e-02],
                        [ -1.56860352e-02,  -1.45568848e-02],
                        [ -9.70458984e-03,  -9.00268555e-03],
                        [  5.34057617e-03,   5.58471680e-03],
                        [  2.13928223e-02,   2.11486816e-02],
                        [  3.16162109e-02,   3.08837891e-02],
                        [  3.58886719e-02,   3.47290039e-02],
                        [  3.69873047e-02,   3.54919434e-02],
                        [  3.76281738e-02,   3.58886719e-02],
                        [  4.07714844e-02,   3.89099121e-02],
                        [  4.95300293e-02,   4.76684570e-02],
                        [  6.50634766e-02,   6.33544922e-02],
                        [  8.59069824e-02,   8.44726562e-02],
                        [  1.08306885e-01,   1.07238770e-01],
                        [  1.25885010e-01,   1.25213623e-01],
                        [  1.32171631e-01,   1.32019043e-01],
                        [  1.26861572e-01,   1.27197266e-01],
                        [  1.15966797e-01,   1.16760254e-01],
                        [  1.06781006e-01,   1.08001709e-01],
                        [  1.03637695e-01,   1.05194092e-01],
                        [  1.03820801e-01,   1.05560303e-01],
                        [  9.70458984e-02,   9.88769531e-02],
                        [  7.67211914e-02,   7.85522461e-02],
                        [  5.06286621e-02,   5.22766113e-02],
                        [  3.28674316e-02,   3.42407227e-02],
                        [  2.77709961e-02,   2.87780762e-02],
                        [  2.93273926e-02,   2.99072266e-02],
                        [  3.56140137e-02,   3.57055664e-02],
                        [  5.37109375e-02,   5.33142090e-02],
                        [  8.83483887e-02,   8.74938965e-02],
                        [  1.31958008e-01,   1.30706787e-01],
                        [  1.68395996e-01,   1.66839600e-01],
                        [  1.83410645e-01,   1.81640625e-01],
                        [  1.73553467e-01,   1.71722412e-01],
                        [  1.48345947e-01,   1.46575928e-01],
                        [  1.22833252e-01,   1.21215820e-01],
                        [  1.05010986e-01,   1.03698730e-01],
                        [  9.11865234e-02,   9.02709961e-02],
                        [  7.51342773e-02,   7.46459961e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  3.92761230e-02,   3.97644043e-02],
                        [  2.28271484e-02,   2.37731934e-02],
                        [  9.33837891e-03,   1.06201172e-02],
                        [  2.80761719e-03,   4.39453125e-03],
                        [  2.53295898e-03,   4.30297852e-03],
                        [  1.77001953e-03,   3.60107422e-03],
                        [ -2.22778320e-03,  -4.88281250e-04],
                        [ -4.45556641e-03,  -2.89916992e-03],
                        [ -1.61743164e-03,  -3.66210938e-04],
                        [  2.13623047e-03,   2.99072266e-03],
                        [  2.41088867e-03,   2.83813477e-03],
                        [ -6.10351562e-05,  -1.22070312e-04],
                        [ -3.02124023e-03,  -3.57055664e-03],
                        [ -5.61523438e-03,  -6.59179688e-03],
                        [ -7.53784180e-03,  -8.88061523e-03],
                        [ -9.70458984e-03,  -1.12915039e-02],
                        [ -1.60827637e-02,  -1.78527832e-02],
                        [ -3.04565430e-02,  -3.22570801e-02],
                        [ -4.91943359e-02,  -5.09033203e-02],
                        [ -6.34765625e-02,  -6.49719238e-02],
                        [ -7.12280273e-02,  -7.24182129e-02],
                        [ -7.76367188e-02,  -7.83996582e-02],
                        [ -8.13598633e-02,  -8.16650391e-02],
                        [ -7.47375488e-02,  -7.45849609e-02],
                        [ -5.97534180e-02,  -5.91430664e-02],
                        [ -4.91333008e-02,  -4.80957031e-02],
                        [ -4.98962402e-02,  -4.85229492e-02],
                        [ -5.61218262e-02,  -5.45043945e-02],
                        [ -5.78002930e-02,  -5.60302734e-02],
                        [ -5.20324707e-02,  -5.02624512e-02],
                        [ -4.47387695e-02,  -4.30603027e-02],
                        [ -4.31518555e-02,  -4.17175293e-02],
                        [ -4.80041504e-02,  -4.69055176e-02],
                        [ -5.43212891e-02,  -5.36193848e-02],
                        [ -5.81665039e-02,  -5.79223633e-02],
                        [ -5.88684082e-02,  -5.90820312e-02],
                        [ -5.54199219e-02,  -5.60913086e-02],
                        [ -4.64782715e-02,  -4.75769043e-02],
                        [ -3.30810547e-02,  -3.45153809e-02],
                        [ -1.83105469e-02,  -1.99584961e-02],
                        [ -5.03540039e-03,  -6.77490234e-03],
                        [  5.55419922e-03,   3.81469727e-03],
                        [  1.58386230e-02,   1.42211914e-02],
                        [  3.00292969e-02,   2.86865234e-02],
                        [  4.86450195e-02,   4.76074219e-02],
                        [  6.39343262e-02,   6.33239746e-02],
                        [  6.28051758e-02,   6.26220703e-02],
                        [  3.46374512e-02,   3.49426270e-02],
                        [ -2.16979980e-02,  -2.09655762e-02],
                        [ -9.64660645e-02,  -9.53369141e-02],
                        [ -1.70288086e-01,  -1.68853760e-01],
                        [ -2.18872070e-01,  -2.17224121e-01],
                        [ -2.24670410e-01,  -2.22930908e-01],
                        [ -1.90277100e-01,  -1.88568115e-01],
                        [ -1.39343262e-01,  -1.37786865e-01],
                        [ -9.84191895e-02,  -9.71374512e-02],
                        [ -7.57446289e-02,  -7.47985840e-02],
                        [ -6.13098145e-02,  -6.07604980e-02],
                        [ -4.46166992e-02,  -4.45251465e-02],
                        [ -2.42004395e-02,  -2.45666504e-02],
                        [ -2.92968750e-03,  -3.72314453e-03],
                        [  1.80664062e-02,   1.69067383e-02],
                        [  4.12597656e-02,   3.97949219e-02],
                        [  7.01904297e-02,   6.85424805e-02],
                        [  1.03576660e-01,   1.01867676e-01],
                        [  1.31591797e-01,   1.29913330e-01],
                        [  1.38824463e-01,   1.37329102e-01],
                        [  1.12091064e-01,   1.10839844e-01],
                        [  4.72106934e-02,   4.63256836e-02],
                        [ -4.66613770e-02,  -4.71191406e-02],
                        [ -1.46057129e-01,  -1.46057129e-01],
                        [ -2.19543457e-01,  -2.19116211e-01],
                        [ -2.44384766e-01,  -2.43530273e-01],
                        [ -2.20275879e-01,  -2.19085693e-01],
                        [ -1.67785645e-01,  -1.66290283e-01],
                        [ -1.14807129e-01,  -1.13159180e-01],
                        [ -7.95593262e-02,  -7.78503418e-02],
                        [ -6.02111816e-02,  -5.85937500e-02],
                        [ -4.42199707e-02,  -4.27856445e-02],
                        [ -2.78320312e-02,  -2.66723633e-02],
                        [ -1.81884766e-02,  -1.73950195e-02],
                        [ -1.78222656e-02,  -1.74560547e-02],
                        [ -1.89514160e-02,  -1.90124512e-02],
                        [ -1.42517090e-02,  -1.47399902e-02],
                        [ -3.63159180e-03,  -4.51660156e-03],
                        [  8.94165039e-03,   7.72094727e-03],
                        [  1.87377930e-02,   1.72729492e-02],
                        [  2.29187012e-02,   2.12707520e-02],
                        [  2.38647461e-02,   2.22167969e-02],
                        [  2.86254883e-02,   2.70385742e-02],
                        [  4.36401367e-02,   4.22668457e-02],
                        [  7.08007812e-02,   6.97021484e-02],
                        [  1.05041504e-01,   1.04339600e-01],
                        [  1.35040283e-01,   1.34735107e-01],
                        [  1.48803711e-01,   1.48925781e-01],
                        [  1.41815186e-01,   1.42333984e-01],
                        [  1.20788574e-01,   1.21704102e-01],
                        [  9.97314453e-02,   1.01013184e-01],
                        [  9.01184082e-02,   9.15832520e-02],
                        [  9.23461914e-02,   9.39331055e-02],
                        [  9.67102051e-02,   9.83276367e-02],
                        [  9.36584473e-02,   9.51538086e-02],
                        [  8.23364258e-02,   8.36486816e-02],
                        [  6.73828125e-02,   6.83898926e-02],
                        [  5.15136719e-02,   5.21545410e-02],
                        [  3.56750488e-02,   3.58886719e-02],
                        [  2.20336914e-02,   2.18505859e-02],
                        [  1.50451660e-02,   1.44348145e-02],
                        [  2.13623047e-02,   2.03857422e-02],
                        [  4.69665527e-02,   4.56848145e-02],
                        [  9.04846191e-02,   8.89892578e-02],
                        [  1.39831543e-01,   1.38244629e-01],
                        [  1.77124023e-01,   1.75537109e-01],
                        [  1.88201904e-01,   1.86737061e-01],
                        [  1.70806885e-01,   1.69555664e-01],
                        [  1.36444092e-01,   1.35498047e-01],
                        [  1.03302002e-01,   1.02722168e-01],
                        [  8.26721191e-02,   8.24890137e-02],
                        [  7.28454590e-02,   7.31201172e-02],
                        [  6.69250488e-02,   6.75659180e-02],
                        [  6.02416992e-02,   6.12487793e-02],
                        [  4.89807129e-02,   5.02929688e-02],
                        [  3.21350098e-02,   3.36303711e-02],
                        [  1.56860352e-02,   1.72424316e-02],
                        [  6.40869141e-03,   7.93457031e-03],
                        [  3.14331055e-03,   4.54711914e-03],
                        [  2.13623047e-04,   1.37329102e-03],
                        [ -4.11987305e-03,  -3.26538086e-03],
                        [ -6.71386719e-03,  -6.19506836e-03],
                        [ -5.43212891e-03,  -5.34057617e-03],
                        [ -2.44140625e-03,  -2.74658203e-03],
                        [ -1.00708008e-03,  -1.70898438e-03],
                        [ -1.83105469e-03,  -2.86865234e-03],
                        [ -4.45556641e-03,  -5.76782227e-03],
                        [ -1.00097656e-02,  -1.14746094e-02],
                        [ -1.96838379e-02,  -2.12402344e-02],
                        [ -3.17687988e-02,  -3.32641602e-02],
                        [ -4.20837402e-02,  -4.34265137e-02],
                        [ -4.71191406e-02,  -4.82177734e-02],
                        [ -4.66613770e-02,  -4.74548340e-02],
                        [ -4.52880859e-02,  -4.57153320e-02],
                        [ -4.85229492e-02,  -4.85534668e-02],
                        [ -5.52062988e-02,  -5.48400879e-02],
                        [ -5.88073730e-02,  -5.80444336e-02],
                        [ -5.67626953e-02,  -5.57250977e-02],
                        [ -5.21240234e-02,  -5.08422852e-02],
                        [ -4.89196777e-02,  -4.74548340e-02],
                        [ -5.05371094e-02,  -4.90417480e-02],
                        [ -5.76477051e-02,  -5.62133789e-02],
                        [ -6.58264160e-02,  -6.45446777e-02],
                        [ -7.01599121e-02,  -6.91223145e-02],
                        [ -6.94885254e-02,  -6.87866211e-02],
                        [ -6.41479492e-02,  -6.38122559e-02],
                        [ -5.45654297e-02,  -5.45959473e-02],
                        [ -4.35485840e-02,  -4.39758301e-02],
                        [ -3.53393555e-02,  -3.61022949e-02],
                        [ -3.11889648e-02,  -3.22570801e-02],
                        [ -2.81066895e-02,  -2.94189453e-02],
                        [ -2.20947266e-02,  -2.35290527e-02],
                        [ -1.15966797e-02,  -1.30615234e-02],
                        [  2.19726562e-03,   7.93457031e-04],
                        [  1.70288086e-02,   1.58081055e-02],
                        [  3.11279297e-02,   3.01513672e-02],
                        [  4.37622070e-02,   4.31213379e-02],
                        [  5.38635254e-02,   5.35583496e-02],
                        [  5.54809570e-02,   5.55725098e-02],
                        [  3.78723145e-02,   3.83605957e-02],
                        [ -4.85229492e-03,  -4.05883789e-03],
                        [ -6.66809082e-02,  -6.55822754e-02],
                        [ -1.34613037e-01,  -1.33300781e-01],
                        [ -1.92840576e-01,  -1.91436768e-01],
                        [ -2.22045898e-01,  -2.20611572e-01],
                        [ -2.10266113e-01,  -2.08953857e-01],
                        [ -1.68792725e-01,  -1.67633057e-01],
                        [ -1.24389648e-01,  -1.23474121e-01],
                        [ -9.46655273e-02,  -9.40856934e-02],
                        [ -7.82470703e-02,  -7.80334473e-02],
                        [ -6.56738281e-02,  -6.58264160e-02],
                        [ -4.97131348e-02,  -5.02319336e-02],
                        [ -2.79846191e-02,  -2.88085938e-02],
                        [ -2.99072266e-03,  -4.08935547e-03],
                        [  2.19726562e-02,   2.06909180e-02],
                        [  4.96520996e-02,   4.82788086e-02],
                        [  8.47167969e-02,   8.33435059e-02],
                        [  1.21582031e-01,   1.20300293e-01],
                        [  1.45599365e-01,   1.44500732e-01],
                        [  1.44409180e-01,   1.43585205e-01],
                        [  1.10870361e-01,   1.10351562e-01],
                        [  4.17785645e-02,   4.16259766e-02],
                        [ -5.54199219e-02,  -5.52062988e-02],
                        [ -1.56188965e-01,  -1.55639648e-01],
                        [ -2.27416992e-01,  -2.26562500e-01],
                        [ -2.46368408e-01,  -2.45269775e-01],
                        [ -2.14660645e-01,  -2.13378906e-01],
                        [ -1.56890869e-01,  -1.55548096e-01],
                        [ -1.03881836e-01,  -1.02569580e-01],
                        [ -7.18994141e-02,  -7.06787109e-02],
                        [ -5.59692383e-02,  -5.49621582e-02],
                        [ -4.31213379e-02,  -4.23583984e-02],
                        [ -2.77709961e-02,  -2.73437500e-02],
                        [ -1.34887695e-02,  -1.33972168e-02],
                        [ -4.73022461e-03,  -5.00488281e-03],
                        [ -1.12915039e-03,  -1.73950195e-03],
                        [  1.86157227e-03,   1.00708008e-03],
                        [  7.99560547e-03,   6.89697266e-03],
                        [  1.62963867e-02,   1.50451660e-02],
                        [  2.30712891e-02,   2.17590332e-02],
                        [  2.63671875e-02,   2.50854492e-02],
                        [  2.75268555e-02,   2.63671875e-02],
                        [  3.02429199e-02,   2.92968750e-02],
                        [  3.95507812e-02,   3.88793945e-02],
                        [  5.96008301e-02,   5.92041016e-02],
                        [  8.94470215e-02,   8.94165039e-02],
                        [  1.21612549e-01,   1.21917725e-01],
                        [  1.45385742e-01,   1.45996094e-01],
                        [  1.51916504e-01,   1.52801514e-01],
                        [  1.40380859e-01,   1.41479492e-01],
                        [  1.20880127e-01,   1.22100830e-01],
                        [  1.07025146e-01,   1.08306885e-01],
                        [  1.02722168e-01,   1.03942871e-01],
                        [  9.97619629e-02,   1.00860596e-01],
                        [  8.99658203e-02,   9.08508301e-02],
                        [  7.51342773e-02,   7.57446289e-02],
                        [  6.10656738e-02,   6.13708496e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  3.09753418e-02,   3.06396484e-02],
                        [  1.61743164e-02,   1.55334473e-02],
                        [  9.91821289e-03,   9.03320312e-03],
                        [  1.51672363e-02,   1.40991211e-02],
                        [  3.32336426e-02,   3.20434570e-02],
                        [  6.52465820e-02,   6.40258789e-02],
                        [  1.06781006e-01,   1.05621338e-01],
                        [  1.46423340e-01,   1.45385742e-01],
                        [  1.70501709e-01,   1.69677734e-01],
                        [  1.70257568e-01,   1.69708252e-01],
                        [  1.48071289e-01,   1.47827148e-01],
                        [  1.16760254e-01,   1.16851807e-01],
                        [  8.95690918e-02,   8.99658203e-02],
                        [  7.15942383e-02,   7.22656250e-02],
                        [  6.03332520e-02,   6.12182617e-02],
                        [  5.08728027e-02,   5.19409180e-02],
                        [  4.00695801e-02,   4.12292480e-02],
                        [  2.89611816e-02,   3.01208496e-02],
                        [  2.24609375e-02,   2.35595703e-02],
                        [  2.35290527e-02,   2.44750977e-02],
                        [  2.73742676e-02,   2.81372070e-02],
                        [  2.49633789e-02,   2.54516602e-02],
                        [  1.29089355e-02,   1.30615234e-02],
                        [ -3.20434570e-03,  -3.32641602e-03],
                        [ -1.58386230e-02,  -1.62658691e-02],
                        [ -2.27966309e-02,  -2.34680176e-02],
                        [ -2.61840820e-02,  -2.70690918e-02],
                        [ -2.65197754e-02,  -2.75573730e-02],
                        [ -2.07824707e-02,  -2.19116211e-02],
                        [ -8.85009766e-03,  -9.97924805e-03],
                        [  1.86157227e-03,   8.23974609e-04],
                        [  2.77709961e-03,   1.89208984e-03],
                        [ -6.65283203e-03,  -7.35473633e-03],
                        [ -2.02331543e-02,  -2.06298828e-02],
                        [ -3.27758789e-02,  -3.28979492e-02],
                        [ -4.27856445e-02,  -4.26330566e-02],
                        [ -5.07202148e-02,  -5.02929688e-02],
                        [ -5.88073730e-02,  -5.81054688e-02],
                        [ -6.96105957e-02,  -6.86950684e-02],
                        [ -8.10546875e-02,  -8.00170898e-02],
                        [ -8.49609375e-02,  -8.38623047e-02],
                        [ -7.59582520e-02,  -7.48901367e-02],
                        [ -5.99060059e-02,  -5.89294434e-02],
                        [ -4.73022461e-02,  -4.64782715e-02],
                        [ -4.23278809e-02,  -4.17175293e-02],
                        [ -4.27551270e-02,  -4.23889160e-02],
                        [ -4.48608398e-02,  -4.47692871e-02],
                        [ -4.46777344e-02,  -4.48608398e-02],
                        [ -4.03137207e-02,  -4.07714844e-02],
                        [ -3.57360840e-02,  -3.64379883e-02],
                        [ -3.75061035e-02,  -3.83911133e-02],
                        [ -4.59289551e-02,  -4.69055176e-02],
                        [ -5.23071289e-02,  -5.33447266e-02],
                        [ -4.76989746e-02,  -4.87060547e-02],
                        [ -3.16162109e-02,  -3.25622559e-02],
                        [ -1.03149414e-02,  -1.10778809e-02],
                        [  1.09558105e-02,   1.04370117e-02],
                        [  3.05480957e-02,   3.02429199e-02],
                        [  4.83703613e-02,   4.83398438e-02],
                        [  6.31408691e-02,   6.33850098e-02],
                        [  6.98852539e-02,   7.03430176e-02],
                        [  5.87158203e-02,   5.93872070e-02],
                        [  1.87377930e-02,   1.95922852e-02],
                        [ -5.08728027e-02,  -4.98962402e-02],
                        [ -1.33087158e-01,  -1.32110596e-01],
                        [ -2.00927734e-01,  -1.99951172e-01],
                        [ -2.33215332e-01,  -2.32360840e-01],
                        [ -2.23937988e-01,  -2.23236084e-01],
                        [ -1.82830811e-01,  -1.82342529e-01],
                        [ -1.31347656e-01,  -1.31103516e-01],
                        [ -9.16748047e-02,  -9.17053223e-02],
                        [ -7.24487305e-02,  -7.26928711e-02],
                        [ -6.43615723e-02,  -6.48498535e-02],
                        [ -5.37719727e-02,  -5.44738770e-02],
                        [ -3.75671387e-02,  -3.84216309e-02],
                        [ -1.83410645e-02,  -1.92565918e-02],
                        [  8.36181641e-03,   7.38525391e-03],
                        [  4.78820801e-02,   4.69665527e-02],
                        [  9.32312012e-02,   9.24377441e-02],
                        [  1.31500244e-01,   1.30859375e-01],
                        [  1.56311035e-01,   1.55853271e-01],
                        [  1.61193848e-01,   1.60980225e-01],
                        [  1.31072998e-01,   1.31134033e-01],
                        [  5.67626953e-02,   5.70373535e-02],
                        [ -4.80651855e-02,  -4.75769043e-02],
                        [ -1.52587891e-01,  -1.51885986e-01],
                        [ -2.26074219e-01,  -2.25250244e-01],
                        [ -2.48474121e-01,  -2.47589111e-01],
                        [ -2.18566895e-01,  -2.17681885e-01],
                        [ -1.58477783e-01,  -1.57623291e-01],
                        [ -1.00677490e-01,  -9.99450684e-02],
                        [ -6.43005371e-02,  -6.37512207e-02],
                        [ -4.54101562e-02,  -4.50439453e-02],
                        [ -3.09143066e-02,  -3.07922363e-02],
                        [ -1.72424316e-02,  -1.73339844e-02],
                        [ -1.03454590e-02,  -1.06506348e-02],
                        [ -1.16271973e-02,  -1.21154785e-02],
                        [ -1.31225586e-02,  -1.37939453e-02],
                        [ -7.04956055e-03,  -7.81250000e-03],
                        [  7.32421875e-03,   6.46972656e-03],
                        [  2.52380371e-02,   2.43835449e-02],
                        [  3.98864746e-02,   3.90930176e-02],
                        [  4.58679199e-02,   4.51965332e-02],
                        [  4.31518555e-02,   4.26330566e-02],
                        [  3.58886719e-02,   3.55529785e-02],
                        [  2.92053223e-02,   2.90832520e-02],
                        [  3.10363770e-02,   3.11584473e-02],
                        [  5.09338379e-02,   5.12695312e-02],
                        [  8.83789062e-02,   8.88671875e-02],
                        [  1.27227783e-01,   1.27899170e-01],
                        [  1.49566650e-01,   1.50329590e-01],
                        [  1.50756836e-01,   1.51550293e-01],
                        [  1.38000488e-01,   1.38824463e-01],
                        [  1.20635986e-01,   1.21368408e-01],
                        [  1.05743408e-01,   1.06384277e-01],
                        [  9.68017578e-02,   9.72595215e-02],
                        [  9.21325684e-02,   9.24072266e-02],
                        [  8.83483887e-02,   8.84399414e-02],
                        [  8.45947266e-02,   8.44421387e-02],
                        [  7.94372559e-02,   7.91015625e-02],
                        [  6.86645508e-02,   6.81457520e-02],
                        [  5.04760742e-02,   4.98352051e-02],
                        [  2.94494629e-02,   2.87170410e-02],
                        [  1.28173828e-02,   1.20544434e-02],
                        [  7.56835938e-03,   6.83593750e-03],
                        [  1.99584961e-02,   1.92871094e-02],
                        [  5.15136719e-02,   5.09338379e-02],
                        [  9.43298340e-02,   9.39331055e-02],
                        [  1.34094238e-01,   1.33880615e-01],
                        [  1.57257080e-01,   1.57226562e-01],
                        [  1.56768799e-01,   1.56951904e-01],
                        [  1.36383057e-01,   1.36749268e-01],
                        [  1.10412598e-01,   1.10900879e-01],
                        [  9.20715332e-02,   9.26818848e-02],
                        [  8.15429688e-02,   8.22448730e-02],
                        [  7.15332031e-02,   7.22656250e-02],
                        [  5.99060059e-02,   6.05773926e-02],
                        [  4.81262207e-02,   4.87365723e-02],
                        [  3.53698730e-02,   3.58886719e-02],
                        [  2.20031738e-02,   2.23693848e-02],
                        [  1.22985840e-02,   1.24816895e-02],
                        [  7.69042969e-03,   7.72094727e-03],
                        [  4.39453125e-03,   4.21142578e-03],
                        [ -2.13623047e-04,  -6.10351562e-04],
                        [ -5.64575195e-03,  -6.13403320e-03],
                        [ -1.20849609e-02,  -1.26647949e-02],
                        [ -1.89208984e-02,  -1.95922852e-02],
                        [ -2.19116211e-02,  -2.26135254e-02],
                        [ -1.80969238e-02,  -1.87377930e-02],
                        [ -1.09558105e-02,  -1.15051270e-02],
                        [ -6.92749023e-03,  -7.41577148e-03],
                        [ -9.76562500e-03,  -1.00708008e-02],
                        [ -1.76086426e-02,  -1.77307129e-02],
                        [ -2.56958008e-02,  -2.56652832e-02],
                        [ -3.26843262e-02,  -3.25012207e-02],
                        [ -4.14733887e-02,  -4.11071777e-02],
                        [ -5.20324707e-02,  -5.15441895e-02],
                        [ -6.02111816e-02,  -5.96618652e-02],
                        [ -6.41479492e-02,  -6.35375977e-02],
                        [ -6.43615723e-02,  -6.37207031e-02],
                        [ -6.02111816e-02,  -5.96313477e-02],
                        [ -5.31921387e-02,  -5.27038574e-02],
                        [ -4.96215820e-02,  -4.91943359e-02],
                        [ -5.29785156e-02,  -5.27343750e-02],
                        [ -5.81665039e-02,  -5.80749512e-02],
                        [ -5.96008301e-02,  -5.96313477e-02],
                        [ -5.92956543e-02,  -5.95092773e-02],
                        [ -6.12182617e-02,  -6.15844727e-02],
                        [ -6.45446777e-02,  -6.50329590e-02],
                        [ -6.62841797e-02,  -6.68334961e-02],
                        [ -6.33544922e-02,  -6.39648438e-02],
                        [ -5.32836914e-02,  -5.38635254e-02],
                        [ -3.71093750e-02,  -3.76586914e-02],
                        [ -1.90734863e-02,  -1.95617676e-02],
                        [ -1.43432617e-03,  -1.80053711e-03],
                        [  1.56860352e-02,   1.54724121e-02],
                        [  3.14636230e-02,   3.13720703e-02],
                        [  4.49218750e-02,   4.49829102e-02],
                        [  5.55419922e-02,   5.57861328e-02],
                        [  6.03332520e-02,   6.06689453e-02],
                        [  5.27343750e-02,   5.31616211e-02],
                        [  2.60314941e-02,   2.65502930e-02],
                        [ -2.20947266e-02,  -2.15454102e-02],
                        [ -8.70971680e-02,  -8.65478516e-02],
                        [ -1.56982422e-01,  -1.56494141e-01],
                        [ -2.12951660e-01,  -2.12524414e-01],
                        [ -2.34741211e-01,  -2.34405518e-01],
                        [ -2.14721680e-01,  -2.14538574e-01],
                        [ -1.68670654e-01,  -1.68640137e-01],
                        [ -1.24389648e-01,  -1.24481201e-01],
                        [ -9.68933105e-02,  -9.71374512e-02],
                        [ -8.02001953e-02,  -8.05358887e-02],
                        [ -6.30187988e-02,  -6.34460449e-02],
                        [ -4.34570312e-02,  -4.39453125e-02],
                        [ -2.48718262e-02,  -2.53906250e-02],
                        [ -6.16455078e-03,  -6.65283203e-03],
                        [  1.66015625e-02,   1.61437988e-02],
                        [  4.40673828e-02,   4.37011719e-02],
                        [  7.41271973e-02,   7.38525391e-02],
                        [  1.03790283e-01,   1.03668213e-01],
                        [  1.27441406e-01,   1.27410889e-01],
                        [  1.36199951e-01,   1.36322021e-01],
                        [  1.21826172e-01,   1.22070312e-01],
                        [  7.92541504e-02,   7.95593262e-02],
                        [  7.50732422e-03,   7.90405273e-03],
                        [ -8.48388672e-02,  -8.43811035e-02],
                        [ -1.73187256e-01,  -1.72698975e-01],
                        [ -2.24945068e-01,  -2.24487305e-01],
                        [ -2.23419189e-01,  -2.22991943e-01],
                        [ -1.81854248e-01,  -1.81518555e-01],
                        [ -1.30828857e-01,  -1.30615234e-01],
                        [ -9.35058594e-02,  -9.33532715e-02],
                        [ -7.18383789e-02,  -7.18383789e-02],
                        [ -5.45043945e-02,  -5.46264648e-02],
                        [ -3.43933105e-02,  -3.46069336e-02],
                        [ -1.46789551e-02,  -1.49841309e-02],
                        [ -3.05175781e-05,  -4.57763672e-04],
                        [  8.78906250e-03,   8.36181641e-03],
                        [  1.37939453e-02,   1.33666992e-02],
                        [  1.83410645e-02,   1.79138184e-02],
                        [  2.43225098e-02,   2.39562988e-02],
                        [  2.87475586e-02,   2.84729004e-02],
                        [  2.74658203e-02,   2.72521973e-02],
                        [  2.14233398e-02,   2.13012695e-02],
                        [  1.70288086e-02,   1.70593262e-02],
                        [  2.18505859e-02,   2.19726562e-02],
                        [  3.93676758e-02,   3.95812988e-02],
                        [  6.53381348e-02,   6.56433105e-02],
                        [  9.12780762e-02,   9.16442871e-02],
                        [  1.12487793e-01,   1.12854004e-01],
                        [  1.27532959e-01,   1.27929688e-01],
                        [  1.33392334e-01,   1.33758545e-01],
                        [  1.29425049e-01,   1.29760742e-01],
                        [  1.22833252e-01,   1.23046875e-01],
                        [  1.19415283e-01,   1.19598389e-01],
                        [  1.15936279e-01,   1.16027832e-01],
                        [  1.09619141e-01,   1.09558105e-01],
                        [  1.05346680e-01,   1.05224609e-01],
                        [  1.05255127e-01,   1.05041504e-01],
                        [  1.01959229e-01,   1.01654053e-01],
                        [  8.87145996e-02,   8.83789062e-02],
                        [  6.70166016e-02,   6.66503906e-02],
                        [  4.17785645e-02,   4.14123535e-02],
                        [  1.67846680e-02,   1.64489746e-02],
                        [ -2.99072266e-03,  -3.29589844e-03],
                        [ -8.78906250e-03,  -9.00268555e-03],
                        [  8.57543945e-03,   8.45336914e-03],
                        [  5.04760742e-02,   5.04455566e-02],
                        [  1.04858398e-01,   1.04919434e-01],
                        [  1.50817871e-01,   1.50970459e-01],
                        [  1.71203613e-01,   1.71417236e-01],
                        [  1.62353516e-01,   1.62597656e-01],
                        [  1.33941650e-01,   1.34246826e-01],
                        [  1.01837158e-01,   1.02172852e-01],
                        [  7.87963867e-02,   7.91320801e-02],
                        [  6.69860840e-02,   6.72607422e-02],
                        [  5.90820312e-02,   5.93261719e-02],
                        [  4.93774414e-02,   4.95605469e-02],
                        [  4.07409668e-02,   4.08325195e-02],
                        [  3.72924805e-02,   3.73229980e-02],
                        [  3.54003906e-02,   3.53698730e-02],
                        [  2.79541016e-02,   2.78320312e-02],
                        [  1.34582520e-02,   1.32751465e-02],
                        [ -3.57055664e-03,  -3.78417969e-03],
                        [ -1.83410645e-02,  -1.86157227e-02],
                        [ -2.80151367e-02,  -2.83203125e-02],
                        [ -3.03649902e-02,  -3.06396484e-02],
                        [ -2.54211426e-02,  -2.56652832e-02],
                        [ -1.83410645e-02,  -1.85546875e-02],
                        [ -1.54113770e-02,  -1.55639648e-02],
                        [ -1.69677734e-02,  -1.70593262e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.19421387e-02,  -2.18811035e-02],
                        [ -2.70080566e-02,  -2.68859863e-02],
                        [ -3.23791504e-02,  -3.21960449e-02],
                        [ -3.54309082e-02,  -3.51867676e-02],
                        [ -4.00085449e-02,  -3.97644043e-02],
                        [ -4.99267578e-02,  -4.96520996e-02],
                        [ -5.92041016e-02,  -5.89599609e-02],
                        [ -6.04858398e-02,  -6.02416992e-02],
                        [ -5.78613281e-02,  -5.76782227e-02],
                        [ -5.99060059e-02,  -5.97839355e-02],
                        [ -6.45141602e-02,  -6.44531250e-02],
                        [ -6.32324219e-02,  -6.32324219e-02],
                        [ -5.63659668e-02,  -5.64270020e-02],
                        [ -5.16357422e-02,  -5.17578125e-02],
                        [ -5.10253906e-02,  -5.12084961e-02],
                        [ -5.08117676e-02,  -5.10253906e-02],
                        [ -5.06896973e-02,  -5.09033203e-02],
                        [ -5.31005859e-02,  -5.33142090e-02],
                        [ -5.62438965e-02,  -5.64575195e-02],
                        [ -5.58471680e-02,  -5.60302734e-02],
                        [ -4.90112305e-02,  -4.91638184e-02],
                        [ -3.41491699e-02,  -3.42407227e-02],
                        [ -1.28479004e-02,  -1.28784180e-02],
                        [  8.45336914e-03,   8.45336914e-03],
                        [  2.49328613e-02,   2.49938965e-02],
                        [  3.83911133e-02,   3.85131836e-02],
                        [  5.04150391e-02,   5.05676270e-02],
                        [  5.56335449e-02,   5.58166504e-02],
                        [  4.48913574e-02,   4.50744629e-02],
                        [  1.06201172e-02,   1.08032227e-02],
                        [ -5.05371094e-02,  -5.03540039e-02],
                        [ -1.30828857e-01,  -1.30676270e-01],
                        [ -2.05261230e-01,  -2.05139160e-01],
                        [ -2.42706299e-01,  -2.42614746e-01],
                        [ -2.30194092e-01,  -2.30163574e-01],
                        [ -1.84234619e-01,  -1.84265137e-01],
                        [ -1.34765625e-01,  -1.34826660e-01],
                        [ -1.00799561e-01,  -1.00891113e-01],
                        [ -8.20617676e-02,  -8.22143555e-02],
                        [ -6.96411133e-02,  -6.97937012e-02],
                        [ -5.81665039e-02,  -5.83496094e-02],
                        [ -4.78515625e-02,  -4.80346680e-02],
                        [ -3.95507812e-02,  -3.97033691e-02],
                        [ -3.01818848e-02,  -3.03039551e-02],
                        [ -1.27563477e-02,  -1.28784180e-02],
                        [  1.80358887e-02,   1.79748535e-02],
                        [  5.99975586e-02,   5.99670410e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.38702393e-01,   1.38763428e-01],
                        [  1.56524658e-01,   1.56616211e-01],
                        [  1.49780273e-01,   1.49902344e-01],
                        [  1.08978271e-01,   1.09100342e-01],
                        [  2.85034180e-02,   2.86560059e-02],
                        [ -7.83386230e-02,  -7.81860352e-02],
                        [ -1.76849365e-01,  -1.76727295e-01],
                        [ -2.32238770e-01,  -2.32116699e-01],
                        [ -2.32055664e-01,  -2.31964111e-01],
                        [ -1.89361572e-01,  -1.89331055e-01],
                        [ -1.31286621e-01,  -1.31286621e-01],
                        [ -8.41064453e-02,  -8.41369629e-02],
                        [ -5.90209961e-02,  -5.90820312e-02],
                        [ -4.82482910e-02,  -4.83398438e-02],
                        [ -3.75976562e-02,  -3.76892090e-02],
                        [ -2.17895508e-02,  -2.19116211e-02],
                        [ -5.85937500e-03,  -5.98144531e-03],
                        [  4.66918945e-03,   4.54711914e-03],
                        [  9.18579102e-03,   9.06372070e-03],
                        [  1.14746094e-02,   1.13830566e-02],
                        [  1.69372559e-02,   1.68762207e-02],
                        [  2.63366699e-02,   2.62756348e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  3.02429199e-02,   3.02734375e-02],
                        [  2.40173340e-02,   2.40478516e-02],
                        [  2.28576660e-02,   2.29187012e-02],
                        [  3.05480957e-02,   3.06396484e-02],
                        [  4.77294922e-02,   4.78210449e-02],
                        [  7.50122070e-02,   7.51342773e-02],
                        [  1.07360840e-01,   1.07452393e-01],
                        [  1.31256104e-01,   1.31347656e-01],
                        [  1.35894775e-01,   1.35955811e-01],
                        [  1.25213623e-01,   1.25244141e-01],
                        [  1.13891602e-01,   1.13922119e-01],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.16546631e-01,   1.16516113e-01],
                        [  1.18591309e-01,   1.18560791e-01],
                        [  1.13189697e-01,   1.13159180e-01],
                        [  1.02783203e-01,   1.02722168e-01],
                        [  9.11560059e-02,   9.10644531e-02],
                        [  7.83386230e-02,   7.82470703e-02],
                        [  6.29272461e-02,   6.28662109e-02],
                        [  4.56237793e-02,   4.55627441e-02],
                        [  2.79541016e-02,   2.78930664e-02],
                        [  1.23596191e-02,   1.23291016e-02],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  9.30786133e-03,   9.30786133e-03],
                        [  3.41796875e-02,   3.42102051e-02],
                        [  7.71179199e-02,   7.71484375e-02],
                        [  1.24542236e-01,   1.24603271e-01],
                        [  1.55334473e-01,   1.55395508e-01],
                        [  1.57043457e-01,   1.57135010e-01],
                        [  1.36260986e-01,   1.36352539e-01],
                        [  1.09893799e-01,   1.09954834e-01],
                        [  8.93249512e-02,   8.93859863e-02],
                        [  7.61718750e-02,   7.62329102e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.41174316e-02,   6.41174316e-02],
                        [  5.79528809e-02,   5.79833984e-02],
                        [  4.75158691e-02,   4.75158691e-02],
                        [  3.55224609e-02,   3.54919434e-02],
                        [  2.51159668e-02,   2.50549316e-02],
                        [  1.51977539e-02,   1.51672363e-02],
                        [  3.72314453e-03,   3.66210938e-03],
                        [ -8.94165039e-03,  -9.00268555e-03],
                        [ -2.00500488e-02,  -2.00805664e-02],
                        [ -2.60009766e-02,  -2.60314941e-02],
                        [ -2.49633789e-02,  -2.49938965e-02],
                        [ -2.02331543e-02,  -2.02636719e-02],
                        [ -1.82800293e-02,  -1.82800293e-02],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.87170410e-02,  -2.87170410e-02],
                        [ -3.03039551e-02,  -3.02429199e-02],
                        [ -2.91442871e-02,  -2.91137695e-02],
                        [ -2.52075195e-02,  -2.51770020e-02],
                        [ -2.36816406e-02,  -2.36206055e-02],
                        [ -2.84729004e-02,  -2.84423828e-02],
                        [ -3.62548828e-02,  -3.62243652e-02],
                        [ -4.37011719e-02,  -4.36706543e-02],
                        [ -5.23376465e-02,  -5.23071289e-02],
                        [ -6.14013672e-02,  -6.14013672e-02],
                        [ -6.56433105e-02,  -6.56433105e-02],
                        [ -6.41174316e-02,  -6.41174316e-02],
                        [ -6.20422363e-02,  -6.20727539e-02],
                        [ -6.08520508e-02,  -6.08825684e-02],
                        [ -5.48706055e-02,  -5.49011230e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -2.92053223e-02,  -2.92358398e-02],
                        [ -2.47497559e-02,  -2.48107910e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.63769531e-02,  -3.64074707e-02],
                        [ -3.60717773e-02,  -3.60717773e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [ -4.54711914e-03,  -4.54711914e-03],
                        [  2.42309570e-02,   2.42614746e-02],
                        [  4.94995117e-02,   4.95300293e-02],
                        [  6.42395020e-02,   6.42700195e-02],
                        [  6.49719238e-02,   6.49719238e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  6.86645508e-03,   6.89697266e-03],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -1.24389648e-01,  -1.24389648e-01],
                        [ -1.90277100e-01,  -1.90277100e-01],
                        [ -2.29736328e-01,  -2.29736328e-01],
                        [ -2.25189209e-01,  -2.25189209e-01],
                        [ -1.79779053e-01,  -1.79809570e-01],
                        [ -1.20941162e-01,  -1.20941162e-01],
                        [ -7.87963867e-02,  -7.87963867e-02],
                        [ -6.19506836e-02,  -6.19812012e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -5.07507324e-02,  -5.07812500e-02],
                        [ -4.21752930e-02,  -4.22058105e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -1.19018555e-03,  -1.15966797e-03],
                        [  3.47900391e-02,   3.47595215e-02],
                        [  7.33947754e-02,   7.33947754e-02],
                        [  1.05560303e-01,   1.05590820e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.28753662e-01,   1.28753662e-01],
                        [  1.12396240e-01,   1.12426758e-01],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  1.17797852e-02,   1.17797852e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -1.44470215e-01,  -1.44470215e-01],
                        [ -1.99737549e-01,  -1.99737549e-01],
                        [ -2.11425781e-01,  -2.11425781e-01],
                        [ -1.80664062e-01,  -1.80633545e-01],
                        [ -1.30371094e-01,  -1.30371094e-01],
                        [ -8.69750977e-02,  -8.69750977e-02],
                        [ -6.17675781e-02,  -6.17675781e-02],
                        [ -4.84313965e-02,  -4.84313965e-02],
                        [ -3.56750488e-02,  -3.57055664e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [  1.15966797e-03,   1.15966797e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  2.01110840e-02,   2.01110840e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.28271484e-02,   2.28576660e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  2.57568359e-02,   2.57568359e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  8.81042480e-02,   8.81042480e-02],
                        [  1.25366211e-01,   1.25366211e-01],
                        [  1.46270752e-01,   1.46240234e-01],
                        [  1.45599365e-01,   1.45599365e-01],
                        [  1.34094238e-01,   1.34094238e-01],
                        [  1.25762939e-01,   1.25762939e-01],
                        [  1.23413086e-01,   1.23413086e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  8.61816406e-02,   8.61816406e-02],
                        [  7.44323730e-02,   7.44323730e-02],
                        [  5.59082031e-02,   5.58776855e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  1.51977539e-02,   1.51977539e-02],
                        [  6.71386719e-04,   6.71386719e-04],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  6.38122559e-02,   6.38122559e-02],
                        [  1.04766846e-01,   1.04766846e-01],
                        [  1.39526367e-01,   1.39526367e-01],
                        [  1.57806396e-01,   1.57806396e-01],
                        [  1.53686523e-01,   1.53686523e-01],
                        [  1.31866455e-01,   1.31896973e-01],
                        [  1.03485107e-01,   1.03485107e-01],
                        [  7.56530762e-02,   7.56530762e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  2.83203125e-02,   2.83508301e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.65502930e-03,   2.65502930e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.65502930e-02,  -2.65502930e-02],
                        [ -2.84423828e-02,  -2.84423828e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [ -2.70690918e-02,  -2.70996094e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.78222656e-02,  -1.78527832e-02],
                        [ -1.97448730e-02,  -1.97448730e-02],
                        [ -3.02124023e-02,  -3.02124023e-02],
                        [ -4.45251465e-02,  -4.45556641e-02],
                        [ -5.54199219e-02,  -5.54199219e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -6.19506836e-02,  -6.19506836e-02],
                        [ -6.16149902e-02,  -6.16455078e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.92041016e-02,  -5.92041016e-02],
                        [ -5.92346191e-02,  -5.92346191e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -5.52062988e-02,  -5.52062988e-02],
                        [ -4.82788086e-02,  -4.82788086e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.59802246e-02,  -3.59802246e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.39660645e-02,  -3.39660645e-02],
                        [ -2.90222168e-02,  -2.90527344e-02],
                        [ -1.30004883e-02,  -1.29699707e-02],
                        [  1.08947754e-02,   1.08947754e-02],
                        [  3.26538086e-02,   3.26538086e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  2.89001465e-02,   2.89001465e-02],
                        [  8.23974609e-04,   7.93457031e-04],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -1.11480713e-01,  -1.11480713e-01],
                        [ -1.75048828e-01,  -1.75079346e-01],
                        [ -2.13531494e-01,  -2.13531494e-01],
                        [ -2.12341309e-01,  -2.12310791e-01],
                        [ -1.75598145e-01,  -1.75598145e-01],
                        [ -1.24725342e-01,  -1.24725342e-01],
                        [ -8.58764648e-02,  -8.58764648e-02],
                        [ -7.08923340e-02,  -7.08618164e-02],
                        [ -6.93054199e-02,  -6.93359375e-02],
                        [ -6.49719238e-02,  -6.49719238e-02],
                        [ -5.50231934e-02,  -5.50231934e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -3.61633301e-02,  -3.61938477e-02],
                        [ -2.10571289e-02,  -2.10571289e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  3.50646973e-02,   3.50341797e-02],
                        [  7.32421875e-02,   7.32727051e-02],
                        [  1.09710693e-01,   1.09710693e-01],
                        [  1.32324219e-01,   1.32324219e-01],
                        [  1.32202148e-01,   1.32202148e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  5.51757812e-02,   5.51452637e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -1.90277100e-01,  -1.90277100e-01],
                        [ -2.23144531e-01,  -2.23144531e-01],
                        [ -2.03857422e-01,  -2.03857422e-01],
                        [ -1.53350830e-01,  -1.53350830e-01],
                        [ -1.03912354e-01,  -1.03912354e-01],
                        [ -7.50122070e-02,  -7.50122070e-02],
                        [ -6.21032715e-02,  -6.20727539e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -4.85229492e-03,  -4.85229492e-03],
                        [  5.21850586e-03,   5.21850586e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.85339355e-02,   2.85339355e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  1.01287842e-01,   1.01257324e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.40258789e-01,   1.40258789e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.19018555e-01,   1.19049072e-01],
                        [  1.17553711e-01,   1.17553711e-01],
                        [  1.14166260e-01,   1.14166260e-01],
                        [  1.06872559e-01,   1.06872559e-01],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  8.07189941e-02,   8.07189941e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  5.62744141e-02,   5.62438965e-02],
                        [  5.07507324e-02,   5.07507324e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  3.15551758e-02,   3.15551758e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  1.09161377e-01,   1.09161377e-01],
                        [  1.34460449e-01,   1.34490967e-01],
                        [  1.37481689e-01,   1.37481689e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  9.83581543e-02,   9.83581543e-02],
                        [  8.05969238e-02,   8.06274414e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  6.22558594e-02,   6.22253418e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  3.06091309e-02,   3.06396484e-02],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.67846680e-03,   1.64794922e-03],
                        [  1.43432617e-03,   1.46484375e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -2.30712891e-02,  -2.30712891e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -3.95507812e-02,  -3.95507812e-02],
                        [ -5.01403809e-02,  -5.01403809e-02],
                        [ -5.48095703e-02,  -5.48095703e-02],
                        [ -5.17883301e-02,  -5.17578125e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -4.25109863e-02,  -4.25109863e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.66613770e-02,  -4.66308594e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -5.62133789e-02,  -5.62438965e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -5.62438965e-02,  -5.62744141e-02],
                        [ -4.17480469e-02,  -4.17480469e-02],
                        [ -3.19824219e-02,  -3.19824219e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [ -4.05273438e-02,  -4.05578613e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -3.13720703e-02,  -3.13720703e-02],
                        [ -1.56860352e-02,  -1.56860352e-02],
                        [  8.05664062e-03,   8.05664062e-03],
                        [  3.76281738e-02,   3.76281738e-02],
                        [  6.30187988e-02,   6.30187988e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  5.88073730e-02,   5.88073730e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -1.24755859e-01,  -1.24755859e-01],
                        [ -1.95037842e-01,  -1.95037842e-01],
                        [ -2.34436035e-01,  -2.34436035e-01],
                        [ -2.31475830e-01,  -2.31445312e-01],
                        [ -1.92901611e-01,  -1.92901611e-01],
                        [ -1.39801025e-01,  -1.39831543e-01],
                        [ -9.56115723e-02,  -9.55810547e-02],
                        [ -7.20520020e-02,  -7.20214844e-02],
                        [ -6.43005371e-02,  -6.43310547e-02],
                        [ -6.07299805e-02,  -6.07604980e-02],
                        [ -5.45349121e-02,  -5.45043945e-02],
                        [ -4.40368652e-02,  -4.40063477e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -7.26318359e-03,  -7.29370117e-03],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  6.96411133e-02,   6.96411133e-02],
                        [  1.00433350e-01,   1.00433350e-01],
                        [  1.28112793e-01,   1.28112793e-01],
                        [  1.39617920e-01,   1.39617920e-01],
                        [  1.21643066e-01,   1.21643066e-01],
                        [  6.85119629e-02,   6.85119629e-02],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -1.07452393e-01,  -1.07421875e-01],
                        [ -1.88232422e-01,  -1.88201904e-01],
                        [ -2.30773926e-01,  -2.30804443e-01],
                        [ -2.23114014e-01,  -2.23144531e-01],
                        [ -1.76940918e-01,  -1.76910400e-01],
                        [ -1.19628906e-01,  -1.19598389e-01],
                        [ -7.40051270e-02,  -7.40356445e-02],
                        [ -4.60510254e-02,  -4.60815430e-02],
                        [ -2.84729004e-02,  -2.84729004e-02],
                        [ -1.33056641e-02,  -1.32751465e-02],
                        [ -1.73950195e-03,  -1.73950195e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.36108398e-02,  -1.36108398e-02],
                        [ -8.57543945e-03,  -8.60595703e-03],
                        [  6.37817383e-03,   6.37817383e-03],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.44848633e-02,   3.44848633e-02],
                        [  2.77404785e-02,   2.77404785e-02],
                        [  2.46582031e-02,   2.46582031e-02],
                        [  3.27148438e-02,   3.27148438e-02],
                        [  5.50842285e-02,   5.50842285e-02],
                        [  8.71276855e-02,   8.70971680e-02],
                        [  1.18499756e-01,   1.18499756e-01],
                        [  1.39617920e-01,   1.39648438e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.42547607e-01,   1.42517090e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.24114990e-01,   1.24145508e-01],
                        [  1.17645264e-01,   1.17675781e-01],
                        [  1.11419678e-01,   1.11419678e-01],
                        [  1.02539062e-01,   1.02539062e-01],
                        [  9.02709961e-02,   9.02709961e-02],
                        [  7.61413574e-02,   7.61718750e-02],
                        [  6.23779297e-02,   6.23779297e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.49536133e-03,   1.52587891e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  1.05285645e-02,   1.05590820e-02],
                        [  3.83911133e-02,   3.83911133e-02],
                        [  7.47375488e-02,   7.47070312e-02],
                        [  1.10198975e-01,   1.10198975e-01],
                        [  1.33422852e-01,   1.33422852e-01],
                        [  1.38214111e-01,   1.38214111e-01],
                        [  1.26464844e-01,   1.26434326e-01],
                        [  1.04827881e-01,   1.04827881e-01],
                        [  8.16650391e-02,   8.17260742e-02],
                        [  6.41784668e-02,   6.41784668e-02],
                        [  5.36804199e-02,   5.36499023e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  3.21350098e-02,   3.21960449e-02],
                        [  1.98669434e-02,   1.98974609e-02],
                        [  1.36413574e-02,   1.36108398e-02],
                        [  1.21154785e-02,   1.20849609e-02],
                        [  7.99560547e-03,   7.99560547e-03],
                        [ -2.89916992e-03,  -2.83813477e-03],
                        [ -1.78222656e-02,  -1.77917480e-02],
                        [ -3.01208496e-02,  -3.01818848e-02],
                        [ -3.46374512e-02,  -3.46679688e-02],
                        [ -3.18298340e-02,  -3.17993164e-02],
                        [ -2.67028809e-02,  -2.66723633e-02],
                        [ -2.31018066e-02,  -2.31323242e-02],
                        [ -2.12707520e-02,  -2.13317871e-02],
                        [ -2.11791992e-02,  -2.11486816e-02],
                        [ -2.31323242e-02,  -2.31018066e-02],
                        [ -2.54516602e-02,  -2.54821777e-02],
                        [ -2.66113281e-02,  -2.66418457e-02],
                        [ -2.99377441e-02,  -2.99072266e-02],
                        [ -3.97033691e-02,  -3.96728516e-02],
                        [ -5.30090332e-02,  -5.30090332e-02],
                        [ -6.13708496e-02,  -6.14013672e-02],
                        [ -6.14013672e-02,  -6.13708496e-02],
                        [ -5.74340820e-02,  -5.74035645e-02],
                        [ -5.39550781e-02,  -5.39855957e-02],
                        [ -5.06896973e-02,  -5.07507324e-02],
                        [ -4.67834473e-02,  -4.67529297e-02],
                        [ -4.35485840e-02,  -4.34875488e-02],
                        [ -4.29382324e-02,  -4.29382324e-02],
                        [ -4.59289551e-02,  -4.59899902e-02],
                        [ -5.15136719e-02,  -5.15136719e-02],
                        [ -5.52673340e-02,  -5.52368164e-02],
                        [ -5.17578125e-02,  -5.17578125e-02],
                        [ -3.96118164e-02,  -3.96423340e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [  6.40869141e-04,   6.71386719e-04],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  5.02624512e-02,   5.02014160e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  6.92749023e-02,   6.93054199e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  9.82666016e-03,   9.76562500e-03],
                        [ -5.14221191e-02,  -5.14831543e-02],
                        [ -1.24267578e-01,  -1.24237061e-01],
                        [ -1.91589355e-01,  -1.91497803e-01],
                        [ -2.31994629e-01,  -2.31994629e-01],
                        [ -2.31628418e-01,  -2.31750488e-01],
                        [ -1.95373535e-01,  -1.95373535e-01],
                        [ -1.45874023e-01,  -1.45782471e-01],
                        [ -1.07543945e-01,  -1.07513428e-01],
                        [ -8.74023438e-02,  -8.74938965e-02],
                        [ -7.41882324e-02,  -7.42492676e-02],
                        [ -5.65185547e-02,  -5.64575195e-02],
                        [ -3.69873047e-02,  -3.69567871e-02],
                        [ -2.42309570e-02,  -2.42919922e-02],
                        [ -1.71813965e-02,  -1.72424316e-02],
                        [ -5.18798828e-03,  -5.12695312e-03],
                        [  1.83715820e-02,   1.84020996e-02],
                        [  5.03234863e-02,   5.02319336e-02],
                        [  8.38623047e-02,   8.38317871e-02],
                        [  1.14013672e-01,   1.14105225e-01],
                        [  1.35925293e-01,   1.35955811e-01],
                        [  1.41387939e-01,   1.41265869e-01],
                        [  1.19201660e-01,   1.19171143e-01],
                        [  6.25915527e-02,   6.27136230e-02],
                        [ -2.22473145e-02,  -2.21862793e-02],
                        [ -1.15722656e-01,  -1.15814209e-01],
                        [ -1.91558838e-01,  -1.91619873e-01],
                        [ -2.25921631e-01,  -2.25860596e-01],
                        [ -2.09747314e-01,  -2.09686279e-01],
                        [ -1.58630371e-01,  -1.58691406e-01],
                        [ -1.04461670e-01,  -1.04522705e-01],
                        [ -6.95800781e-02,  -6.95800781e-02],
                        [ -5.16967773e-02,  -5.16662598e-02],
                        [ -3.64685059e-02,  -3.64990234e-02],
                        [ -1.80358887e-02,  -1.80664062e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  6.74438477e-03,   6.77490234e-03],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  8.85009766e-03,   8.78906250e-03],
                        [  1.46789551e-02,   1.46789551e-02],
                        [  2.55126953e-02,   2.55737305e-02],
                        [  3.59802246e-02,   3.59497070e-02],
                        [  4.00695801e-02,   3.99780273e-02],
                        [  3.43933105e-02,   3.43933105e-02],
                        [  1.91955566e-02,   1.92565918e-02],
                        [  7.62939453e-04,   7.93457031e-04],
                        [ -8.11767578e-03,  -8.17871094e-03],
                        [  3.84521484e-03,   3.81469727e-03],
                        [  3.72009277e-02,   3.72314453e-02],
                        [  8.13598633e-02,   8.13903809e-02],
                        [  1.22924805e-01,   1.22863770e-01],
                        [  1.52526855e-01,   1.52496338e-01],
                        [  1.67297363e-01,   1.67358398e-01],
                        [  1.69036865e-01,   1.69067383e-01],
                        [  1.60217285e-01,   1.60156250e-01],
                        [  1.42974854e-01,   1.42913818e-01],
                        [  1.22955322e-01,   1.23016357e-01],
                        [  1.08459473e-01,   1.08520508e-01],
                        [  1.01501465e-01,   1.01440430e-01],
                        [  9.60388184e-02,   9.59472656e-02],
                        [  8.63952637e-02,   8.64257812e-02],
                        [  7.23876953e-02,   7.25402832e-02],
                        [  5.64270020e-02,   5.63964844e-02],
                        [  3.97644043e-02,   3.96118164e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  2.16674805e-03,   2.31933594e-03],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [ -1.29394531e-02,  -1.30310059e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  3.45764160e-02,   3.46679688e-02],
                        [  7.62939453e-02,   7.62939453e-02],
                        [  1.20727539e-01,   1.20635986e-01],
                        [  1.53137207e-01,   1.53167725e-01],
                        [  1.59729004e-01,   1.59790039e-01],
                        [  1.40472412e-01,   1.40441895e-01],
                        [  1.10260010e-01,   1.10168457e-01],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  7.14111328e-02,   7.15026855e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  5.36193848e-02,   5.34973145e-02],
                        [  3.86657715e-02,   3.86352539e-02],
                        [  2.19116211e-02,   2.20336914e-02],
                        [  7.11059570e-03,   7.17163086e-03],
                        [ -4.54711914e-03,  -4.63867188e-03],
                        [ -1.31225586e-02,  -1.31835938e-02],
                        [ -1.93176270e-02,  -1.92260742e-02],
                        [ -2.39868164e-02,  -2.39257812e-02],
                        [ -2.64282227e-02,  -2.64892578e-02],
                        [ -2.41394043e-02,  -2.42309570e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -1.09863281e-02,  -1.08947754e-02],
                        [ -1.04980469e-02,  -1.05285645e-02],
                        [ -1.42822266e-02,  -1.43737793e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.59399414e-02,  -2.58483887e-02],
                        [ -3.26843262e-02,  -3.27148438e-02],
                        [ -3.44238281e-02,  -3.45153809e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.97851562e-02,  -2.96936035e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -5.01403809e-02,  -5.02319336e-02],
                        [ -6.28967285e-02,  -6.29272461e-02],
                        [ -7.08618164e-02,  -7.07702637e-02],
                        [ -7.36389160e-02,  -7.36083984e-02],
                        [ -7.17773438e-02,  -7.18994141e-02],
                        [ -6.58264160e-02,  -6.59179688e-02],
                        [ -5.83801270e-02,  -5.82885742e-02],
                        [ -5.36499023e-02,  -5.35583496e-02],
                        [ -5.28259277e-02,  -5.29174805e-02],
                        [ -5.22155762e-02,  -5.23071289e-02],
                        [ -4.76074219e-02,  -4.75158691e-02],
                        [ -3.83300781e-02,  -3.82385254e-02],
                        [ -2.57873535e-02,  -2.58483887e-02],
                        [ -9.91821289e-03,  -9.97924805e-03],
                        [  9.76562500e-03,   9.79614258e-03],
                        [  3.06396484e-02,   3.07006836e-02],
                        [  4.80957031e-02,   4.80957031e-02],
                        [  5.94482422e-02,   5.94177246e-02],
                        [  6.21032715e-02,   6.21032715e-02],
                        [  4.87365723e-02,   4.87670898e-02],
                        [  1.02539062e-02,   1.02539062e-02],
                        [ -5.42907715e-02,  -5.43212891e-02],
                        [ -1.32293701e-01,  -1.32293701e-01],
                        [ -2.01873779e-01,  -2.01843262e-01],
                        [ -2.40753174e-01,  -2.40753174e-01],
                        [ -2.37426758e-01,  -2.37457275e-01],
                        [ -1.99890137e-01,  -1.99920654e-01],
                        [ -1.51123047e-01,  -1.51092529e-01],
                        [ -1.11785889e-01,  -1.11724854e-01],
                        [ -8.74328613e-02,  -8.74633789e-02],
                        [ -7.07397461e-02,  -7.08312988e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -3.49121094e-02,  -3.48205566e-02],
                        [ -2.27355957e-02,  -2.26745605e-02],
                        [ -1.70898438e-02,  -1.72119141e-02],
                        [ -8.33129883e-03,  -8.42285156e-03],
                        [  1.23596191e-02,   1.24206543e-02],
                        [  4.36706543e-02,   4.37927246e-02],
                        [  7.71484375e-02,   7.71179199e-02],
                        [  1.04553223e-01,   1.04492188e-01],
                        [  1.21612549e-01,   1.21612549e-01],
                        [  1.25518799e-01,   1.25579834e-01],
                        [  1.10290527e-01,   1.10290527e-01],
                        [  6.56738281e-02,   6.56433105e-02],
                        [ -1.30004883e-02,  -1.30310059e-02],
                        [ -1.10565186e-01,  -1.10595703e-01],
                        [ -1.93511963e-01,  -1.93481445e-01],
                        [ -2.31323242e-01,  -2.31292725e-01],
                        [ -2.15148926e-01,  -2.15179443e-01],
                        [ -1.59820557e-01,  -1.59851074e-01],
                        [ -9.55810547e-02,  -9.55810547e-02],
                        [ -4.99572754e-02,  -4.98962402e-02],
                        [ -2.81372070e-02,  -2.81677246e-02],
                        [ -1.58691406e-02,  -1.59301758e-02],
                        [ -2.56347656e-03,  -2.53295898e-03],
                        [  7.38525391e-03,   7.41577148e-03],
                        [  8.08715820e-03,   8.02612305e-03],
                        [  5.12695312e-03,   5.06591797e-03],
                        [  8.30078125e-03,   8.33129883e-03],
                        [  1.87683105e-02,   1.87988281e-02],
                        [  2.85034180e-02,   2.84729004e-02],
                        [  2.96325684e-02,   2.96325684e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  6.40869141e-03,   6.40869141e-03],
                        [  1.42517090e-02,   1.42211914e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  1.06353760e-01,   1.06384277e-01],
                        [  1.39495850e-01,   1.39556885e-01],
                        [  1.59881592e-01,   1.59851074e-01],
                        [  1.61071777e-01,   1.61010742e-01],
                        [  1.48986816e-01,   1.48956299e-01],
                        [  1.35406494e-01,   1.35498047e-01],
                        [  1.26007080e-01,   1.26068115e-01],
                        [  1.20239258e-01,   1.20117188e-01],
                        [  1.17248535e-01,   1.17187500e-01],
                        [  1.14654541e-01,   1.14746094e-01],
                        [  1.05682373e-01,   1.05773926e-01],
                        [  8.64562988e-02,   8.63952637e-02],
                        [  6.28967285e-02,   6.28356934e-02],
                        [  4.36096191e-02,   4.36401367e-02],
                        [  2.79235840e-02,   2.79846191e-02],
                        [  9.12475586e-03,   9.09423828e-03],
                        [ -1.16271973e-02,  -1.16271973e-02],
                        [ -2.22167969e-02,  -2.21557617e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  1.44042969e-02,   1.43432617e-02],
                        [  5.27954102e-02,   5.27648926e-02],
                        [  9.78088379e-02,   9.78393555e-02],
                        [  1.41296387e-01,   1.41326904e-01],
                        [  1.67053223e-01,   1.67022705e-01],
                        [  1.64276123e-01,   1.64215088e-01],
                        [  1.40350342e-01,   1.40350342e-01],
                        [  1.11083984e-01,   1.11145020e-01],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  5.56945801e-02,   5.56640625e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  1.35498047e-02,   1.35803223e-02],
                        [  2.89916992e-03,   2.89916992e-03],
                        [ -2.92968750e-03,  -2.96020508e-03],
                        [ -2.41088867e-03,  -2.38037109e-03],
                        [  3.69262695e-03,   3.72314453e-03],
                        [  9.39941406e-03,   9.33837891e-03],
                        [  9.09423828e-03,   9.06372070e-03],
                        [  2.47192383e-03,   2.56347656e-03],
                        [ -5.52368164e-03,  -5.49316406e-03],
                        [ -9.33837891e-03,  -9.39941406e-03],
                        [ -9.55200195e-03,  -9.58251953e-03],
                        [ -1.24511719e-02,  -1.24206543e-02],
                        [ -2.18200684e-02,  -2.17895508e-02],
                        [ -3.52478027e-02,  -3.52783203e-02],
                        [ -4.77905273e-02,  -4.78210449e-02],
                        [ -5.46264648e-02,  -5.45959473e-02],
                        [ -5.27038574e-02,  -5.26733398e-02],
                        [ -4.44030762e-02,  -4.44335938e-02],
                        [ -3.70788574e-02,  -3.71093750e-02],
                        [ -3.62548828e-02,  -3.61938477e-02],
                        [ -4.15954590e-02,  -4.15649414e-02],
                        [ -5.06896973e-02,  -5.07507324e-02],
                        [ -6.14624023e-02,  -6.15539551e-02],
                        [ -7.05871582e-02,  -7.05261230e-02],
                        [ -7.45849609e-02,  -7.44934082e-02],
                        [ -7.36083984e-02,  -7.36389160e-02],
                        [ -7.03430176e-02,  -7.04345703e-02],
                        [ -6.65588379e-02,  -6.65588379e-02],
                        [ -6.13403320e-02,  -6.12792969e-02],
                        [ -5.24902344e-02,  -5.24597168e-02],
                        [ -4.08935547e-02,  -4.09545898e-02],
                        [ -3.10974121e-02,  -3.11279297e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.55334473e-02,  -1.55029297e-02],
                        [  3.96728516e-04,   3.96728516e-04],
                        [  2.05688477e-02,   2.05688477e-02],
                        [  3.84216309e-02,   3.84216309e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  5.26733398e-02,   5.26428223e-02],
                        [  4.01611328e-02,   4.01611328e-02],
                        [  6.28662109e-03,   6.31713867e-03],
                        [ -4.98352051e-02,  -4.98657227e-02],
                        [ -1.19995117e-01,  -1.20025635e-01],
                        [ -1.86431885e-01,  -1.86431885e-01],
                        [ -2.26562500e-01,  -2.26531982e-01],
                        [ -2.25799561e-01,  -2.25738525e-01],
                        [ -1.90826416e-01,  -1.90856934e-01],
                        [ -1.46453857e-01,  -1.46484375e-01],
                        [ -1.14746094e-01,  -1.14715576e-01],
                        [ -9.95178223e-02,  -9.94567871e-02],
                        [ -9.05456543e-02,  -9.05761719e-02],
                        [ -7.83996582e-02,  -7.84301758e-02],
                        [ -6.23779297e-02,  -6.23474121e-02],
                        [ -4.61120605e-02,  -4.60815430e-02],
                        [ -3.02124023e-02,  -3.02429199e-02],
                        [ -1.22985840e-02,  -1.23596191e-02],
                        [  1.02844238e-02,   1.03149414e-02],
                        [  4.05273438e-02,   4.05578613e-02],
                        [  7.77893066e-02,   7.77893066e-02],
                        [  1.14318848e-01,   1.14257812e-01],
                        [  1.40441895e-01,   1.40380859e-01],
                        [  1.50573730e-01,   1.50604248e-01],
                        [  1.38427734e-01,   1.38519287e-01],
                        [  9.30786133e-02,   9.31396484e-02],
                        [  1.02233887e-02,   1.01013184e-02],
                        [ -9.26818848e-02,  -9.27734375e-02],
                        [ -1.81304932e-01,  -1.81182861e-01],
                        [ -2.26715088e-01,  -2.26593018e-01],
                        [ -2.20520020e-01,  -2.20581055e-01],
                        [ -1.75231934e-01,  -1.75384521e-01],
                        [ -1.17553711e-01,  -1.17553711e-01],
                        [ -7.36389160e-02,  -7.35168457e-02],
                        [ -5.17883301e-02,  -5.17578125e-02],
                        [ -4.08020020e-02,  -4.09240723e-02],
                        [ -2.72216797e-02,  -2.72827148e-02],
                        [ -1.05590820e-02,  -1.04980469e-02],
                        [  3.35693359e-04,   3.96728516e-04],
                        [  3.20434570e-03,   3.17382812e-03],
                        [  7.35473633e-03,   7.32421875e-03],
                        [  2.11486816e-02,   2.11486816e-02],
                        [  4.04663086e-02,   4.05273438e-02],
                        [  5.31616211e-02,   5.31616211e-02],
                        [  5.17578125e-02,   5.17272949e-02],
                        [  3.90625000e-02,   3.90625000e-02],
                        [  2.19421387e-02,   2.20031738e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [ -5.37109375e-03,  -5.46264648e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [  1.34887695e-02,   1.36108398e-02],
                        [  4.37622070e-02,   4.38537598e-02],
                        [  8.11462402e-02,   8.10241699e-02],
                        [  1.19781494e-01,   1.19659424e-01],
                        [  1.50756836e-01,   1.50878906e-01],
                        [  1.62963867e-01,   1.63116455e-01],
                        [  1.54602051e-01,   1.54479980e-01],
                        [  1.38153076e-01,   1.37969971e-01],
                        [  1.26892090e-01,   1.26983643e-01],
                        [  1.22589111e-01,   1.22772217e-01],
                        [  1.21734619e-01,   1.21673584e-01],
                        [  1.23809814e-01,   1.23626709e-01],
                        [  1.26251221e-01,   1.26312256e-01],
                        [  1.21490479e-01,   1.21643066e-01],
                        [  1.05102539e-01,   1.05072021e-01],
                        [  7.94067383e-02,   7.92541504e-02],
                        [  4.79125977e-02,   4.79431152e-02],
                        [  1.39465332e-02,   1.40991211e-02],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -4.08325195e-02,  -4.09545898e-02],
                        [ -5.09033203e-02,  -5.09033203e-02],
                        [ -4.07409668e-02,  -4.05883789e-02],
                        [ -5.98144531e-03,  -5.95092773e-03],
                        [  4.81872559e-02,   4.80346680e-02],
                        [  1.05926514e-01,   1.05865479e-01],
                        [  1.47369385e-01,   1.47521973e-01],
                        [  1.59027100e-01,   1.59118652e-01],
                        [  1.42669678e-01,   1.42547607e-01],
                        [  1.14318848e-01,   1.14166260e-01],
                        [  8.99047852e-02,   9.00268555e-02],
                        [  7.23571777e-02,   7.25402832e-02],
                        [  5.52978516e-02,   5.52368164e-02],
                        [  3.69567871e-02,   3.67431641e-02],
                        [  2.34680176e-02,   2.34680176e-02],
                        [  1.93786621e-02,   1.95922852e-02],
                        [  2.08129883e-02,   2.08435059e-02],
                        [  2.05688477e-02,   2.03247070e-02],
                        [  1.48925781e-02,   1.48315430e-02],
                        [  2.65502930e-03,   2.86865234e-03],
                        [ -1.58996582e-02,  -1.58386230e-02],
                        [ -3.56445312e-02,  -3.58276367e-02],
                        [ -4.86755371e-02,  -4.87060547e-02],
                        [ -5.12084961e-02,  -5.10559082e-02],
                        [ -4.52880859e-02,  -4.52880859e-02],
                        [ -3.54003906e-02,  -3.55834961e-02],
                        [ -2.61535645e-02,  -2.61230469e-02],
                        [ -1.94091797e-02,  -1.92260742e-02],
                        [ -1.35192871e-02,  -1.35498047e-02],
                        [ -7.87353516e-03,  -8.11767578e-03],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [ -1.73034668e-02,  -1.70593262e-02],
                        [ -3.50646973e-02,  -3.50036621e-02],
                        [ -5.18188477e-02,  -5.20629883e-02],
                        [ -6.20117188e-02,  -6.21337891e-02],
                        [ -6.64978027e-02,  -6.62841797e-02],
                        [ -6.83898926e-02,  -6.82373047e-02],
                        [ -7.01904297e-02,  -7.03430176e-02],
                        [ -7.24182129e-02,  -7.25708008e-02],
                        [ -7.31506348e-02,  -7.30590820e-02],
                        [ -6.90612793e-02,  -6.89086914e-02],
                        [ -5.82885742e-02,  -5.83801270e-02],
                        [ -4.45556641e-02,  -4.46777344e-02],
                        [ -3.50646973e-02,  -3.50036621e-02],
                        [ -3.24096680e-02,  -3.23181152e-02],
                        [ -3.20739746e-02,  -3.21350098e-02],
                        [ -2.74963379e-02,  -2.76184082e-02],
                        [ -1.34887695e-02,  -1.34277344e-02],
                        [  1.14440918e-02,   1.15966797e-02],
                        [  4.15649414e-02,   4.14733887e-02],
                        [  6.54907227e-02,   6.53381348e-02],
                        [  7.31201172e-02,   7.31811523e-02],
                        [  5.94177246e-02,   5.96008301e-02],
                        [  2.14843750e-02,   2.14843750e-02],
                        [ -4.31823730e-02,  -4.33349609e-02],
                        [ -1.27410889e-01,  -1.27441406e-01],
                        [ -2.07061768e-01,  -2.06939697e-01],
                        [ -2.53723145e-01,  -2.53662109e-01],
                        [ -2.55554199e-01,  -2.55615234e-01],
                        [ -2.22351074e-01,  -2.22412109e-01],
                        [ -1.74530029e-01,  -1.74468994e-01],
                        [ -1.30645752e-01,  -1.30615234e-01],
                        [ -1.00158691e-01,  -1.00219727e-01],
                        [ -8.08105469e-02,  -8.08715820e-02],
                        [ -6.31408691e-02,  -6.30187988e-02],
                        [ -4.13818359e-02,  -4.12597656e-02],
                        [ -1.97448730e-02,  -1.98974609e-02],
                        [ -4.48608398e-03,  -4.66918945e-03],
                        [  5.92041016e-03,   6.10351562e-03],
                        [  1.84020996e-02,   1.86157227e-02],
                        [  3.78723145e-02,   3.77197266e-02],
                        [  6.47583008e-02,   6.44836426e-02],
                        [  9.50012207e-02,   9.50927734e-02],
                        [  1.21490479e-01,   1.21765137e-01],
                        [  1.37145996e-01,   1.37084961e-01],
                        [  1.34094238e-01,   1.33850098e-01],
                        [  1.00708008e-01,   1.00769043e-01],
                        [  2.93273926e-02,   2.95104980e-02],
                        [ -6.92443848e-02,  -6.93054199e-02],
                        [ -1.63543701e-01,  -1.63696289e-01],
                        [ -2.19543457e-01,  -2.19451904e-01],
                        [ -2.22259521e-01,  -2.22106934e-01],
                        [ -1.82342529e-01,  -1.82495117e-01],
                        [ -1.26495361e-01,  -1.26678467e-01],
                        [ -7.99560547e-02,  -7.98339844e-02],
                        [ -5.13610840e-02,  -5.11474609e-02],
                        [ -3.25012207e-02,  -3.26232910e-02],
                        [ -1.45263672e-02,  -1.47705078e-02],
                        [  8.85009766e-04,   9.15527344e-04],
                        [  8.33129883e-03,   8.60595703e-03],
                        [  8.42285156e-03,   8.45336914e-03],
                        [  6.92749023e-03,   6.71386719e-03],
                        [  1.07421875e-02,   1.06506348e-02],
                        [  2.39257812e-02,   2.40783691e-02],
                        [  4.24194336e-02,   4.25415039e-02],
                        [  5.44738770e-02,   5.43823242e-02],
                        [  5.03845215e-02,   5.02624512e-02],
                        [  3.22265625e-02,   3.22875977e-02],
                        [  1.06506348e-02,   1.07727051e-02],
                        [ -5.64575195e-03,  -5.67626953e-03],
                        [ -1.13525391e-02,  -1.14440918e-02],
                        [  9.15527344e-05,   1.22070312e-04],
                        [  3.21350098e-02,   3.22570801e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  1.26403809e-01,   1.26281738e-01],
                        [  1.63085938e-01,   1.63085938e-01],
                        [  1.80664062e-01,   1.80786133e-01],
                        [  1.77856445e-01,   1.77886963e-01],
                        [  1.60797119e-01,   1.60614014e-01],
                        [  1.40869141e-01,   1.40808105e-01],
                        [  1.27593994e-01,   1.27746582e-01],
                        [  1.19964600e-01,   1.20025635e-01],
                        [  1.10137939e-01,   1.10015869e-01],
                        [  9.65576172e-02,   9.64660645e-02],
                        [  8.57238770e-02,   8.58154297e-02],
                        [  8.02001953e-02,   8.02917480e-02],
                        [  7.34558105e-02,   7.33642578e-02],
                        [  5.85021973e-02,   5.84411621e-02],
                        [  3.65295410e-02,   3.66210938e-02],
                        [  1.28479004e-02,   1.29089355e-02],
                        [ -8.75854492e-03,  -8.88061523e-03],
                        [ -2.38952637e-02,  -2.39562988e-02],
                        [ -2.58178711e-02,  -2.56652832e-02],
                        [ -9.06372070e-03,  -8.97216797e-03],
                        [  2.74963379e-02,   2.73742676e-02],
                        [  7.72399902e-02,   7.70874023e-02],
                        [  1.23626709e-01,   1.23718262e-01],
                        [  1.48651123e-01,   1.48834229e-01],
                        [  1.46575928e-01,   1.46545410e-01],
                        [  1.27136230e-01,   1.26922607e-01],
                        [  1.04431152e-01,   1.04370117e-01],
                        [  8.34655762e-02,   8.36791992e-02],
                        [  5.92651367e-02,   5.93872070e-02],
                        [  2.96020508e-02,   2.94799805e-02],
                        [  4.33349609e-03,   4.18090820e-03],
                        [ -4.88281250e-03,  -4.82177734e-03],
                        [  1.83105469e-04,   3.35693359e-04],
                        [  7.93457031e-03,   7.90405273e-03],
                        [  1.17187500e-02,   1.15661621e-02],
                        [  1.08337402e-02,   1.08032227e-02],
                        [  3.75366211e-03,   3.87573242e-03],
                        [ -8.78906250e-03,  -8.75854492e-03],
                        [ -2.03552246e-02,  -2.04162598e-02],
                        [ -2.55737305e-02,  -2.56042480e-02],
                        [ -2.54821777e-02,  -2.54516602e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [ -2.20336914e-02,  -2.20642090e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.96533203e-02,  -1.96228027e-02],
                        [ -1.80053711e-02,  -1.80358887e-02],
                        [ -1.80969238e-02,  -1.81579590e-02],
                        [ -2.28881836e-02,  -2.28576660e-02],
                        [ -3.19824219e-02,  -3.18908691e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.95605469e-02,  -4.96520996e-02],
                        [ -5.28869629e-02,  -5.29479980e-02],
                        [ -5.44128418e-02,  -5.43212891e-02],
                        [ -5.81970215e-02,  -5.81054688e-02],
                        [ -6.29577637e-02,  -6.30493164e-02],
                        [ -6.32019043e-02,  -6.33850098e-02],
                        [ -5.82580566e-02,  -5.82275391e-02],
                        [ -5.26733398e-02,  -5.25207520e-02],
                        [ -4.90417480e-02,  -4.90112305e-02],
                        [ -4.54406738e-02,  -4.55932617e-02],
                        [ -3.90319824e-02,  -3.91235352e-02],
                        [ -2.85644531e-02,  -2.84729004e-02],
                        [ -1.36718750e-02,  -1.35803223e-02],
                        [  5.52368164e-03,   5.49316406e-03],
                        [  2.70690918e-02,   2.69775391e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  5.90820312e-02,   5.91125488e-02],
                        [  5.82580566e-02,   5.82885742e-02],
                        [  3.63159180e-02,   3.63159180e-02],
                        [ -1.16882324e-02,  -1.17187500e-02],
                        [ -8.09936523e-02,  -8.09936523e-02],
                        [ -1.54968262e-01,  -1.54937744e-01],
                        [ -2.11242676e-01,  -2.11242676e-01],
                        [ -2.31323242e-01,  -2.31323242e-01],
                        [ -2.10571289e-01,  -2.10540771e-01],
                        [ -1.64703369e-01,  -1.64703369e-01],
                        [ -1.20819092e-01,  -1.20910645e-01],
                        [ -9.60693359e-02,  -9.60693359e-02],
                        [ -8.75244141e-02,  -8.74328613e-02],
                        [ -8.29772949e-02,  -8.29162598e-02],
                        [ -7.39135742e-02,  -7.40051270e-02],
                        [ -5.90209961e-02,  -5.90820312e-02],
                        [ -4.13208008e-02,  -4.12597656e-02],
                        [ -2.31933594e-02,  -2.31018066e-02],
                        [ -2.92968750e-03,  -2.99072266e-03],
                        [  2.21862793e-02,   2.20947266e-02],
                        [  5.12390137e-02,   5.12695312e-02],
                        [  8.07495117e-02,   8.08410645e-02],
                        [  1.07147217e-01,   1.07116699e-01],
                        [  1.26586914e-01,   1.26525879e-01],
                        [  1.34582520e-01,   1.34643555e-01],
                        [  1.23443604e-01,   1.23504639e-01],
                        [  7.96813965e-02,   7.96203613e-02],
                        [ -4.82177734e-03,  -4.91333008e-03],
                        [ -1.12731934e-01,  -1.12701416e-01],
                        [ -2.02819824e-01,  -2.02697754e-01],
                        [ -2.39135742e-01,  -2.39135742e-01],
                        [ -2.16339111e-01,  -2.16461182e-01],
                        [ -1.57745361e-01,  -1.57806396e-01],
                        [ -9.53369141e-02,  -9.52453613e-02],
                        [ -5.19714355e-02,  -5.18493652e-02],
                        [ -3.35083008e-02,  -3.35693359e-02],
                        [ -2.99987793e-02,  -3.01513672e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -1.87988281e-02,  -1.86767578e-02],
                        [ -1.19934082e-02,  -1.19628906e-02],
                        [ -1.04675293e-02,  -1.05895996e-02],
                        [ -7.84301758e-03,  -7.84301758e-03],
                        [  4.36401367e-03,   4.42504883e-03],
                        [  2.36816406e-02,   2.36816406e-02],
                        [  4.04357910e-02,   4.04052734e-02],
                        [  4.96520996e-02,   4.96826172e-02],
                        [  5.10864258e-02,   5.11474609e-02],
                        [  4.42810059e-02,   4.42199707e-02],
                        [  3.11584473e-02,   3.10974121e-02],
                        [  1.83410645e-02,   1.83715820e-02],
                        [  1.25122070e-02,   1.26037598e-02],
                        [  1.69372559e-02,   1.69067383e-02],
                        [  3.21350098e-02,   3.20434570e-02],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  9.60083008e-02,   9.60998535e-02],
                        [  1.34399414e-01,   1.34399414e-01],
                        [  1.58386230e-01,   1.58325195e-01],
                        [  1.60644531e-01,   1.60675049e-01],
                        [  1.49780273e-01,   1.49841309e-01],
                        [  1.39068604e-01,   1.39007568e-01],
                        [  1.32476807e-01,   1.32415771e-01],
                        [  1.26068115e-01,   1.26129150e-01],
                        [  1.17492676e-01,   1.17614746e-01],
                        [  1.07513428e-01,   1.07452393e-01],
                        [  9.56115723e-02,   9.54589844e-02],
                        [  8.07495117e-02,   8.07800293e-02],
                        [  6.29882812e-02,   6.31713867e-02],
                        [  4.26025391e-02,   4.26025391e-02],
                        [  2.02026367e-02,   2.00195312e-02],
                        [ -2.22778320e-03,  -2.31933594e-03],
                        [ -2.06298828e-02,  -2.05078125e-02],
                        [ -2.97241211e-02,  -2.96020508e-02],
                        [ -2.65197754e-02,  -2.65808105e-02],
                        [ -9.91821289e-03,  -1.00708008e-02],
                        [  2.17285156e-02,   2.17895508e-02],
                        [  6.61926270e-02,   6.63146973e-02],
                        [  1.10992432e-01,   1.10961914e-01],
                        [  1.39709473e-01,   1.39587402e-01],
                        [  1.44561768e-01,   1.44592285e-01],
                        [  1.29882812e-01,   1.29974365e-01],
                        [  1.05834961e-01,   1.05773926e-01],
                        [  8.13903809e-02,   8.12988281e-02],
                        [  6.00585938e-02,   6.01501465e-02],
                        [  3.97338867e-02,   3.98864746e-02],
                        [  1.86462402e-02,   1.85852051e-02],
                        [  1.25122070e-03,   1.06811523e-03],
                        [ -6.46972656e-03,  -6.37817383e-03],
                        [ -4.85229492e-03,  -4.66918945e-03],
                        [ -3.05175781e-04,  -3.35693359e-04],
                        [  1.61743164e-03,   1.40380859e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -2.62451172e-03,  -2.44140625e-03],
                        [ -4.30297852e-03,  -4.27246094e-03],
                        [ -7.96508789e-03,  -8.11767578e-03],
                        [ -1.74255371e-02,  -1.74255371e-02],
                        [ -3.07006836e-02,  -3.05786133e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -4.37011719e-02,  -4.38232422e-02],
                        [ -4.11071777e-02,  -4.10766602e-02],
                        [ -3.80859375e-02,  -3.79638672e-02],
                        [ -3.68957520e-02,  -3.68957520e-02],
                        [ -3.80554199e-02,  -3.81774902e-02],
                        [ -4.27856445e-02,  -4.27856445e-02],
                        [ -5.03845215e-02,  -5.02319336e-02],
                        [ -5.65185547e-02,  -5.64880371e-02],
                        [ -5.81970215e-02,  -5.83190918e-02],
                        [ -5.70678711e-02,  -5.71289062e-02],
                        [ -5.56335449e-02,  -5.55419922e-02],
                        [ -5.39550781e-02,  -5.38940430e-02],
                        [ -5.21850586e-02,  -5.22766113e-02],
                        [ -5.14526367e-02,  -5.15136719e-02],
                        [ -5.14526367e-02,  -5.13610840e-02],
                        [ -5.00793457e-02,  -5.00183105e-02],
                        [ -4.61730957e-02,  -4.62341309e-02],
                        [ -4.01916504e-02,  -4.02526855e-02],
                        [ -3.18908691e-02,  -3.18298340e-02],
                        [ -1.91345215e-02,  -1.90429688e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [  2.14538574e-02,   2.13623047e-02],
                        [  4.31823730e-02,   4.31518555e-02],
                        [  5.98449707e-02,   5.99060059e-02],
                        [  6.40258789e-02,   6.41174316e-02],
                        [  4.53491211e-02,   4.52575684e-02],
                        [ -2.53295898e-03,  -2.65502930e-03],
                        [ -7.29064941e-02,  -7.28759766e-02],
                        [ -1.47888184e-01,  -1.47766113e-01],
                        [ -2.06359863e-01,  -2.06359863e-01],
                        [ -2.30010986e-01,  -2.30133057e-01],
                        [ -2.14447021e-01,  -2.14477539e-01],
                        [ -1.77551270e-01,  -1.77459717e-01],
                        [ -1.45263672e-01,  -1.45233154e-01],
                        [ -1.27258301e-01,  -1.27349854e-01],
                        [ -1.14929199e-01,  -1.14959717e-01],
                        [ -9.74121094e-02,  -9.73510742e-02],
                        [ -7.24182129e-02,  -7.24182129e-02],
                        [ -4.57763672e-02,  -4.58374023e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -1.08947754e-02,  -1.08642578e-02],
                        [ -8.54492188e-04,  -8.85009766e-04],
                        [  1.15966797e-02,   1.15661621e-02],
                        [  2.93273926e-02,   2.93273926e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  1.14135742e-01,   1.14166260e-01],
                        [  1.38275146e-01,   1.38275146e-01],
                        [  1.41479492e-01,   1.41418457e-01],
                        [  1.09436035e-01,   1.09405518e-01],
                        [  3.46984863e-02,   3.47900391e-02],
                        [ -6.91833496e-02,  -6.90917969e-02],
                        [ -1.66473389e-01,  -1.66564941e-01],
                        [ -2.19207764e-01,  -2.19299316e-01],
                        [ -2.13073730e-01,  -2.12982178e-01],
                        [ -1.66656494e-01,  -1.66564941e-01],
                        [ -1.13525391e-01,  -1.13586426e-01],
                        [ -7.51037598e-02,  -7.51647949e-02],
                        [ -5.27954102e-02,  -5.27343750e-02],
                        [ -3.78417969e-02,  -3.77807617e-02],
                        [ -2.22473145e-02,  -2.23693848e-02],
                        [ -5.58471680e-03,  -5.61523438e-03],
                        [  5.79833984e-03,   5.98144531e-03],
                        [  8.78906250e-03,   8.85009766e-03],
                        [  1.09252930e-02,   1.07116699e-02],
                        [  2.10266113e-02,   2.09350586e-02],
                        [  3.50341797e-02,   3.52783203e-02],
                        [  4.18395996e-02,   4.19921875e-02],
                        [  4.08020020e-02,   4.05273438e-02],
                        [  3.99475098e-02,   3.97338867e-02],
                        [  4.01000977e-02,   4.02832031e-02],
                        [  3.43627930e-02,   3.46069336e-02],
                        [  2.11486816e-02,   2.10266113e-02],
                        [  7.14111328e-03,   6.89697266e-03],
                        [  5.49316406e-04,   6.40869141e-04],
                        [  7.47680664e-03,   7.69042969e-03],
                        [  3.07006836e-02,   3.07006836e-02],
                        [  6.81152344e-02,   6.79321289e-02],
                        [  1.11724854e-01,   1.11694336e-01],
                        [  1.49291992e-01,   1.49444580e-01],
                        [  1.69586182e-01,   1.69647217e-01],
                        [  1.70043945e-01,   1.69921875e-01],
                        [  1.59667969e-01,   1.59606934e-01],
                        [  1.50634766e-01,   1.50756836e-01],
                        [  1.47094727e-01,   1.47155762e-01],
                        [  1.42822266e-01,   1.42700195e-01],
                        [  1.29669189e-01,   1.29608154e-01],
                        [  1.06811523e-01,   1.06933594e-01],
                        [  8.14819336e-02,   8.15429688e-02],
                        [  6.18286133e-02,   6.17065430e-02],
                        [  4.96215820e-02,   4.95605469e-02],
                        [  3.91235352e-02,   3.92761230e-02],
                        [  2.34985352e-02,   2.35900879e-02],
                        [  2.13623047e-03,   1.98364258e-03],
                        [ -1.92565918e-02,  -1.93786621e-02],
                        [ -3.37829590e-02,  -3.36303711e-02],
                        [ -3.60107422e-02,  -3.58276367e-02],
                        [ -2.11791992e-02,  -2.13317871e-02],
                        [  1.35803223e-02,   1.33666992e-02],
                        [  6.38122559e-02,   6.39038086e-02],
                        [  1.13281250e-01,   1.13525391e-01],
                        [  1.41754150e-01,   1.41723633e-01],
                        [  1.40594482e-01,   1.40350342e-01],
                        [  1.18408203e-01,   1.18377686e-01],
                        [  9.08508301e-02,   9.11254883e-02],
                        [  6.80541992e-02,   6.81457520e-02],
                        [  5.07507324e-02,   5.05371094e-02],
                        [  3.66516113e-02,   3.65295410e-02],
                        [  2.63061523e-02,   2.64587402e-02],
                        [  2.11181641e-02,   2.12402344e-02],
                        [  2.02331543e-02,   2.01110840e-02],
                        [  2.06604004e-02,   2.05688477e-02],
                        [  1.77001953e-02,   1.77917480e-02],
                        [  6.43920898e-03,   6.50024414e-03],
                        [ -1.38549805e-02,  -1.39770508e-02],
                        [ -3.69262695e-02,  -3.70178223e-02],
                        [ -5.33447266e-02,  -5.32226562e-02],
                        [ -5.81054688e-02,  -5.79833984e-02],
                        [ -5.28259277e-02,  -5.29479980e-02],
                        [ -4.07714844e-02,  -4.09545898e-02],
                        [ -2.48413086e-02,  -2.47497559e-02],
                        [ -1.11389160e-02,  -1.09252930e-02],
                        [ -7.56835938e-03,  -7.59887695e-03],
                        [ -1.52282715e-02,  -1.54418945e-02],
                        [ -2.60620117e-02,  -2.60925293e-02],
                        [ -3.29284668e-02,  -3.27453613e-02],
                        [ -3.78417969e-02,  -3.77807617e-02],
                        [ -4.55322266e-02,  -4.56848145e-02],
                        [ -5.41992188e-02,  -5.42602539e-02],
                        [ -5.89599609e-02,  -5.88378906e-02],
                        [ -6.02111816e-02,  -6.01501465e-02],
                        [ -6.10351562e-02,  -6.11877441e-02],
                        [ -6.10961914e-02,  -6.11267090e-02],
                        [ -5.81665039e-02,  -5.80139160e-02],
                        [ -5.37719727e-02,  -5.37414551e-02],
                        [ -5.10864258e-02,  -5.12695312e-02],
                        [ -4.94689941e-02,  -4.95300293e-02],
                        [ -4.57458496e-02,  -4.55322266e-02],
                        [ -3.75671387e-02,  -3.74755859e-02],
                        [ -2.23388672e-02,  -2.25524902e-02],
                        [  2.80761719e-03,   2.68554688e-03],
                        [  3.55834961e-02,   3.57971191e-02],
                        [  6.61315918e-02,   6.62841797e-02],
                        [  8.24279785e-02,   8.22448730e-02],
                        [  7.57751465e-02,   7.56225586e-02],
                        [  4.02221680e-02,   4.03747559e-02],
                        [ -2.62756348e-02,  -2.61230469e-02],
                        [ -1.12854004e-01,  -1.13037109e-01],
                        [ -1.93542480e-01,  -1.93695068e-01],
                        [ -2.41333008e-01,  -2.41119385e-01],
                        [ -2.44689941e-01,  -2.44537354e-01],
                        [ -2.12524414e-01,  -2.12768555e-01],
                        [ -1.67083740e-01,  -1.67266846e-01],
                        [ -1.29730225e-01,  -1.29486084e-01],
                        [ -1.08581543e-01,  -1.08367920e-01],
                        [ -9.75952148e-02,  -9.77783203e-02],
                        [ -8.62121582e-02,  -8.65173340e-02],
                        [ -7.10449219e-02,  -7.08923340e-02],
                        [ -5.59082031e-02,  -5.56030273e-02],
                        [ -4.22668457e-02,  -4.23583984e-02],
                        [ -2.53906250e-02,  -2.56347656e-02],
                        [ -6.40869141e-04,  -6.10351562e-04],
                        [  3.09448242e-02,   3.11584473e-02],
                        [  6.48193359e-02,   6.47888184e-02],
                        [  9.62219238e-02,   9.60388184e-02],
                        [  1.21643066e-01,   1.21673584e-01],
                        [  1.38702393e-01,   1.38885498e-01],
                        [  1.44958496e-01,   1.44866943e-01],
                        [  1.33117676e-01,   1.32904053e-01],
                        [  8.95996094e-02,   8.96911621e-02],
                        [  7.26318359e-03,   7.50732422e-03],
                        [ -9.77478027e-02,  -9.78393555e-02],
                        [ -1.88537598e-01,  -1.88842773e-01],
                        [ -2.30682373e-01,  -2.30651855e-01],
                        [ -2.15179443e-01,  -2.14904785e-01],
                        [ -1.62780762e-01,  -1.62750244e-01],
                        [ -1.06903076e-01,  -1.07177734e-01],
                        [ -6.97021484e-02,  -6.97937012e-02],
                        [ -5.14221191e-02,  -5.12390137e-02],
                        [ -3.86352539e-02,  -3.85131836e-02],
                        [ -2.11486816e-02,  -2.13012695e-02],
                        [ -1.83105469e-03,  -1.98364258e-03],
                        [  9.55200195e-03,   9.64355469e-03],
                        [  1.04675293e-02,   1.05895996e-02],
                        [  9.49096680e-03,   9.39941406e-03],
                        [  1.54418945e-02,   1.53198242e-02],
                        [  2.71606445e-02,   2.72521973e-02],
                        [  3.62243652e-02,   3.63464355e-02],
                        [  3.75671387e-02,   3.74755859e-02],
                        [  3.30810547e-02,   3.29284668e-02],
                        [  2.67639160e-02,   2.68249512e-02],
                        [  1.90734863e-02,   1.92565918e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [ -2.56347656e-03,  -2.77709961e-03],
                        [ -6.80541992e-03,  -6.83593750e-03],
                        [  4.21142578e-03,   4.39453125e-03],
                        [  3.43627930e-02,   3.44543457e-02],
                        [  7.99560547e-02,   7.98034668e-02],
                        [  1.29760742e-01,   1.29638672e-01],
                        [  1.69708252e-01,   1.69769287e-01],
                        [  1.89636230e-01,   1.89758301e-01],
                        [  1.88385010e-01,   1.88354492e-01],
                        [  1.73187256e-01,   1.73095703e-01],
                        [  1.54022217e-01,   1.53991699e-01],
                        [  1.36871338e-01,   1.36932373e-01],
                        [  1.20574951e-01,   1.20574951e-01],
                        [  1.01501465e-01,   1.01470947e-01],
                        [  8.13903809e-02,   8.14208984e-02],
                        [  6.68334961e-02,   6.68029785e-02],
                        [  6.08215332e-02,   6.07604980e-02],
                        [  5.83801270e-02,   5.83801270e-02],
                        [  5.01403809e-02,   5.02014160e-02],
                        [  3.10974121e-02,   3.10974121e-02],
                        [  5.64575195e-03,   5.58471680e-03],
                        [ -1.70593262e-02,  -1.70593262e-02],
                        [ -3.08532715e-02,  -3.07922363e-02],
                        [ -3.30810547e-02,  -3.30505371e-02],
                        [ -2.13928223e-02,  -2.14233398e-02],
                        [  5.34057617e-03,   5.27954102e-03],
                        [  4.39758301e-02,   4.40063477e-02],
                        [  8.65783691e-02,   8.66088867e-02],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  1.36260986e-01,   1.36230469e-01],
                        [  1.26312256e-01,   1.26312256e-01],
                        [  1.00982666e-01,   1.01013184e-01],
                        [  7.73010254e-02,   7.73010254e-02],
                        [  6.39343262e-02,   6.39038086e-02],
                        [  5.53283691e-02,   5.52978516e-02],
                        [  4.22058105e-02,   4.22363281e-02],
                        [  2.45666504e-02,   2.45971680e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  7.75146484e-03,   7.69042969e-03],
                        [  8.11767578e-03,   8.14819336e-03],
                        [  3.26538086e-03,   3.32641602e-03],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [ -2.22778320e-02,  -2.23693848e-02],
                        [ -3.10668945e-02,  -3.10668945e-02],
                        [ -3.41796875e-02,  -3.40576172e-02],
                        [ -3.38439941e-02,  -3.38134766e-02],
                        [ -3.09448242e-02,  -3.10668945e-02],
                        [ -2.68859863e-02,  -2.69775391e-02],
                        [ -2.66113281e-02,  -2.65197754e-02],
                        [ -3.35998535e-02,  -3.34472656e-02],
                        [ -4.37316895e-02,  -4.37622070e-02],
                        [ -4.88891602e-02,  -4.90417480e-02],
                        [ -4.65393066e-02,  -4.65698242e-02],
                        [ -4.23583984e-02,  -4.22058105e-02],
                        [ -4.25720215e-02,  -4.24499512e-02],
                        [ -4.82177734e-02,  -4.83398438e-02],
                        [ -5.64880371e-02,  -5.66711426e-02],
                        [ -6.27136230e-02,  -6.26831055e-02],
                        [ -6.36901855e-02,  -6.35070801e-02],
                        [ -6.02722168e-02,  -6.02111816e-02],
                        [ -5.40771484e-02,  -5.42602539e-02],
                        [ -4.58374023e-02,  -4.59594727e-02],
                        [ -3.80859375e-02,  -3.79638672e-02],
                        [ -3.32031250e-02,  -3.31115723e-02],
                        [ -2.84118652e-02,  -2.85034180e-02],
                        [ -1.74560547e-02,  -1.75476074e-02],
                        [  1.95312500e-03,   2.04467773e-03],
                        [  2.56347656e-02,   2.56958008e-02],
                        [  4.70581055e-02,   4.69665527e-02],
                        [  6.13098145e-02,   6.12792969e-02],
                        [  6.17370605e-02,   6.18896484e-02],
                        [  3.82080078e-02,   3.82385254e-02],
                        [ -1.60217285e-02,  -1.62353516e-02],
                        [ -9.53369141e-02,  -9.54284668e-02],
                        [ -1.79687500e-01,  -1.79443359e-01],
                        [ -2.41394043e-01,  -2.41241455e-01],
                        [ -2.59582520e-01,  -2.59826660e-01],
                        [ -2.33428955e-01,  -2.33673096e-01],
                        [ -1.83593750e-01,  -1.83410645e-01],
                        [ -1.38305664e-01,  -1.38031006e-01],
                        [ -1.12976074e-01,  -1.13067627e-01],
                        [ -1.00921631e-01,  -1.01196289e-01],
                        [ -8.63037109e-02,  -8.62731934e-02],
                        [ -6.35986328e-02,  -6.33544922e-02],
                        [ -4.09545898e-02,  -4.09240723e-02],
                        [ -2.74963379e-02,  -2.77099609e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -1.53198242e-02,  -1.51977539e-02],
                        [  2.47192383e-03,   2.47192383e-03],
                        [  3.19213867e-02,   3.18298340e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  9.68933105e-02,   9.69848633e-02],
                        [  1.20483398e-01,   1.20483398e-01],
                        [  1.35375977e-01,   1.35284424e-01],
                        [  1.37908936e-01,   1.37908936e-01],
                        [  1.20300293e-01,   1.20361328e-01],
                        [  7.33642578e-02,   7.33947754e-02],
                        [ -6.59179688e-03,  -6.65283203e-03],
                        [ -1.06048584e-01,  -1.06109619e-01],
                        [ -1.90338135e-01,  -1.90307617e-01],
                        [ -2.24426270e-01,  -2.24365234e-01],
                        [ -2.02087402e-01,  -2.02087402e-01],
                        [ -1.47247314e-01,  -1.47277832e-01],
                        [ -9.02099609e-02,  -9.02099609e-02],
                        [ -4.91638184e-02,  -4.91943359e-02],
                        [ -2.70080566e-02,  -2.70690918e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -7.87353516e-03,  -7.78198242e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [  2.01416016e-03,   1.86157227e-03],
                        [ -2.86865234e-03,  -2.92968750e-03],
                        [ -7.29370117e-03,  -7.17163086e-03],
                        [ -9.76562500e-04,  -8.54492188e-04],
                        [  1.63269043e-02,   1.62353516e-02],
                        [  3.34167480e-02,   3.32641602e-02],
                        [  3.98559570e-02,   3.99169922e-02],
                        [  3.70483398e-02,   3.72009277e-02],
                        [  3.25012207e-02,   3.24707031e-02],
                        [  2.64892578e-02,   2.63977051e-02],
                        [  1.51367188e-02,   1.51672363e-02],
                        [  4.30297852e-03,   4.36401367e-03],
                        [  7.11059570e-03,   7.04956055e-03],
                        [  2.94189453e-02,   2.93884277e-02],
                        [  6.63757324e-02,   6.64978027e-02],
                        [  1.09771729e-01,   1.09832764e-01],
                        [  1.51641846e-01,   1.51489258e-01],
                        [  1.82556152e-01,   1.82434082e-01],
                        [  1.92565918e-01,   1.92687988e-01],
                        [  1.79229736e-01,   1.79412842e-01],
                        [  1.52801514e-01,   1.52740479e-01],
                        [  1.27868652e-01,   1.27624512e-01],
                        [  1.11480713e-01,   1.11480713e-01],
                        [  1.01745605e-01,   1.01989746e-01],
                        [  9.47570801e-02,   9.48181152e-02],
                        [  9.01794434e-02,   8.99658203e-02],
                        [  8.91418457e-02,   8.89892578e-02],
                        [  8.93554688e-02,   8.94775391e-02],
                        [  8.51440430e-02,   8.53271484e-02],
                        [  7.07397461e-02,   7.06481934e-02],
                        [  4.42810059e-02,   4.40979004e-02],
                        [  1.10778809e-02,   1.11083984e-02],
                        [ -2.01721191e-02,  -2.00195312e-02],
                        [ -4.37927246e-02,  -4.38232422e-02],
                        [ -5.54809570e-02,  -5.56030273e-02],
                        [ -4.80957031e-02,  -4.80957031e-02],
                        [ -1.72119141e-02,  -1.70593262e-02],
                        [  3.13415527e-02,   3.13720703e-02],
                        [  8.33435059e-02,   8.31909180e-02],
                        [  1.23962402e-01,   1.23901367e-01],
                        [  1.42456055e-01,   1.42639160e-01],
                        [  1.34948730e-01,   1.35040283e-01],
                        [  1.08367920e-01,   1.08184814e-01],
                        [  7.81555176e-02,   7.80334473e-02],
                        [  5.58166504e-02,   5.59692383e-02],
                        [  4.12292480e-02,   4.13818359e-02],
                        [  2.98461914e-02,   2.97546387e-02],
                        [  2.28881836e-02,   2.27355957e-02],
                        [  2.43835449e-02,   2.44140625e-02],
                        [  3.10363770e-02,   3.11889648e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  2.01721191e-02,   2.00500488e-02],
                        [ -1.06811523e-03,  -1.06811523e-03],
                        [ -2.27050781e-02,  -2.26135254e-02],
                        [ -3.85131836e-02,  -3.85131836e-02],
                        [ -4.55627441e-02,  -4.56542969e-02],
                        [ -4.24194336e-02,  -4.23889160e-02],
                        [ -3.24096680e-02,  -3.23181152e-02],
                        [ -2.40173340e-02,  -2.40478516e-02],
                        [ -2.27050781e-02,  -2.27966309e-02],
                        [ -2.62756348e-02,  -2.62451172e-02],
                        [ -3.08532715e-02,  -3.07617188e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -4.11682129e-02,  -4.12597656e-02],
                        [ -4.62341309e-02,  -4.62341309e-02],
                        [ -4.86755371e-02,  -4.86145020e-02],
                        [ -4.85229492e-02,  -4.84924316e-02],
                        [ -4.83703613e-02,  -4.84313965e-02],
                        [ -4.95605469e-02,  -4.95910645e-02],
                        [ -5.00488281e-02,  -5.00183105e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -4.26330566e-02,  -4.26635742e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -2.85034180e-02,  -2.85034180e-02],
                        [ -1.82800293e-02,  -1.82495117e-02],
                        [ -6.71386719e-04,  -6.40869141e-04],
                        [  2.33154297e-02,   2.32543945e-02],
                        [  4.67224121e-02,   4.66918945e-02],
                        [  5.92956543e-02,   5.93872070e-02],
                        [  5.15747070e-02,   5.16357422e-02],
                        [  1.78527832e-02,   1.77307129e-02],
                        [ -4.19616699e-02,  -4.20837402e-02],
                        [ -1.19628906e-01,  -1.19537354e-01],
                        [ -1.95556641e-01,  -1.95404053e-01],
                        [ -2.42492676e-01,  -2.42523193e-01],
                        [ -2.42370605e-01,  -2.42553711e-01],
                        [ -2.04162598e-01,  -2.04162598e-01],
                        [ -1.58599854e-01,  -1.58447266e-01],
                        [ -1.30157471e-01,  -1.30126953e-01],
                        [ -1.17462158e-01,  -1.17584229e-01],
                        [ -1.04919434e-01,  -1.04980469e-01],
                        [ -8.60595703e-02,  -8.59985352e-02],
                        [ -6.84814453e-02,  -6.84204102e-02],
                        [ -5.92956543e-02,  -5.92956543e-02],
                        [ -5.37414551e-02,  -5.38024902e-02],
                        [ -4.06188965e-02,  -4.06494141e-02],
                        [ -1.40075684e-02,  -1.40075684e-02],
                        [  2.26745605e-02,   2.27355957e-02],
                        [  6.14318848e-02,   6.14624023e-02],
                        [  9.54284668e-02,   9.53979492e-02],
                        [  1.21337891e-01,   1.21276855e-01],
                        [  1.37939453e-01,   1.37939453e-01],
                        [  1.44226074e-01,   1.44287109e-01],
                        [  1.36016846e-01,   1.36016846e-01],
                        [  1.02233887e-01,   1.02172852e-01],
                        [  3.26232910e-02,   3.26232910e-02],
                        [ -6.53381348e-02,  -6.52770996e-02],
                        [ -1.62170410e-01,  -1.62170410e-01],
                        [ -2.22473145e-01,  -2.22534180e-01],
                        [ -2.26287842e-01,  -2.26318359e-01],
                        [ -1.81243896e-01,  -1.81152344e-01],
                        [ -1.17187500e-01,  -1.17156982e-01],
                        [ -6.62536621e-02,  -6.63452148e-02],
                        [ -4.16259766e-02,  -4.16870117e-02],
                        [ -3.25317383e-02,  -3.24401855e-02],
                        [ -2.14538574e-02,  -2.13623047e-02],
                        [ -4.48608398e-03,  -4.57763672e-03],
                        [  8.30078125e-03,   8.20922852e-03],
                        [  9.39941406e-03,   9.42993164e-03],
                        [  4.39453125e-03,   4.51660156e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  1.67846680e-02,   1.66931152e-02],
                        [  3.11584473e-02,   3.11279297e-02],
                        [  4.06188965e-02,   4.07104492e-02],
                        [  4.17175293e-02,   4.17480469e-02],
                        [  3.39355469e-02,   3.38745117e-02],
                        [  2.08740234e-02,   2.08435059e-02],
                        [  8.94165039e-03,   9.00268555e-03],
                        [  8.54492188e-04,   8.85009766e-04],
                        [ -4.51660156e-03,  -4.60815430e-03],
                        [ -3.81469727e-03,  -3.84521484e-03],
                        [  1.12609863e-02,   1.14135742e-02],
                        [  4.42504883e-02,   4.43115234e-02],
                        [  8.92639160e-02,   8.90808105e-02],
                        [  1.36352539e-01,   1.36230469e-01],
                        [  1.74194336e-01,   1.74346924e-01],
                        [  1.90795898e-01,   1.90948486e-01],
                        [  1.82250977e-01,   1.82098389e-01],
                        [  1.59454346e-01,   1.59271240e-01],
                        [  1.39251709e-01,   1.39343262e-01],
                        [  1.29211426e-01,   1.29425049e-01],
                        [  1.23779297e-01,   1.23718262e-01],
                        [  1.13464355e-01,   1.13281250e-01],
                        [  9.64050293e-02,   9.64355469e-02],
                        [  7.89184570e-02,   7.90710449e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  5.74340820e-02,   5.73120117e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  2.56958008e-02,   2.57873535e-02],
                        [ -2.22778320e-03,  -2.19726562e-03],
                        [ -3.27453613e-02,  -3.28369141e-02],
                        [ -5.57250977e-02,  -5.57556152e-02],
                        [ -6.15234375e-02,  -6.14624023e-02],
                        [ -4.79431152e-02,  -4.79125977e-02],
                        [ -1.98974609e-02,  -1.98974609e-02],
                        [  1.80969238e-02,   1.80664062e-02],
                        [  6.27136230e-02,   6.26831055e-02],
                        [  1.05163574e-01,   1.05133057e-01],
                        [  1.30737305e-01,   1.30767822e-01],
                        [  1.31134033e-01,   1.31164551e-01],
                        [  1.13128662e-01,   1.13128662e-01],
                        [  9.00878906e-02,   9.00573730e-02],
                        [  6.87866211e-02,   6.87561035e-02],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  3.79638672e-02,   3.80249023e-02],
                        [  3.25012207e-02,   3.25317383e-02],
                        [  2.83203125e-02,   2.82287598e-02],
                        [  1.87683105e-02,   1.86462402e-02],
                        [  4.69970703e-03,   4.79125977e-03],
                        [ -8.60595703e-03,  -8.42285156e-03],
                        [ -1.89208984e-02,  -1.89819336e-02],
                        [ -2.62145996e-02,  -2.64587402e-02],
                        [ -2.93884277e-02,  -2.94189453e-02],
                        [ -2.84118652e-02,  -2.81677246e-02],
                        [ -2.64892578e-02,  -2.63977051e-02],
                        [ -2.66723633e-02,  -2.68554688e-02],
                        [ -2.83813477e-02,  -2.85034180e-02],
                        [ -3.02124023e-02,  -3.01208496e-02],
                        [ -3.30810547e-02,  -3.29284668e-02],
                        [ -3.74145508e-02,  -3.74450684e-02],
                        [ -4.02526855e-02,  -4.03442383e-02],
                        [ -3.90625000e-02,  -3.90319824e-02],
                        [ -3.64074707e-02,  -3.63464355e-02],
                        [ -3.64990234e-02,  -3.65295410e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.04968262e-02,  -4.04052734e-02],
                        [ -4.26635742e-02,  -4.26940918e-02],
                        [ -4.92248535e-02,  -4.93469238e-02],
                        [ -5.70678711e-02,  -5.70983887e-02],
                        [ -5.87158203e-02,  -5.85632324e-02],
                        [ -5.30700684e-02,  -5.30090332e-02],
                        [ -4.61730957e-02,  -4.63562012e-02],
                        [ -4.14428711e-02,  -4.15039062e-02],
                        [ -3.43627930e-02,  -3.41796875e-02],
                        [ -1.82189941e-02,  -1.81274414e-02],
                        [  7.72094727e-03,   7.56835938e-03],
                        [  3.67736816e-02,   3.66821289e-02],
                        [  5.92956543e-02,   5.94482422e-02],
                        [  6.59484863e-02,   6.61010742e-02],
                        [  4.93774414e-02,   4.92248535e-02],
                        [  5.06591797e-03,   4.91333008e-03],
                        [ -6.55822754e-02,  -6.54907227e-02],
                        [ -1.48590088e-01,  -1.48406982e-01],
                        [ -2.16766357e-01,  -2.16857910e-01],
                        [ -2.44781494e-01,  -2.44964600e-01],
                        [ -2.27264404e-01,  -2.27233887e-01],
                        [ -1.83441162e-01,  -1.83258057e-01],
                        [ -1.41632080e-01,  -1.41601562e-01],
                        [ -1.16882324e-01,  -1.17034912e-01],
                        [ -1.04125977e-01,  -1.04156494e-01],
                        [ -9.21325684e-02,  -9.20410156e-02],
                        [ -7.79418945e-02,  -7.79418945e-02],
                        [ -6.69555664e-02,  -6.70471191e-02],
                        [ -6.22863770e-02,  -6.22558594e-02],
                        [ -5.67321777e-02,  -5.66406250e-02],
                        [ -3.93981934e-02,  -3.94897461e-02],
                        [ -8.54492188e-03,  -8.63647461e-03],
                        [  2.75878906e-02,   2.77099609e-02],
                        [  5.99365234e-02,   6.01196289e-02],
                        [  8.55712891e-02,   8.54797363e-02],
                        [  1.07177734e-01,   1.06964111e-01],
                        [  1.26220703e-01,   1.26251221e-01],
                        [  1.38488770e-01,   1.38732910e-01],
                        [  1.36077881e-01,   1.36108398e-01],
                        [  1.08489990e-01,   1.08276367e-01],
                        [  4.65698242e-02,   4.64782715e-02],
                        [ -4.52880859e-02,  -4.51354980e-02],
                        [ -1.42150879e-01,  -1.41998291e-01],
                        [ -2.09289551e-01,  -2.09381104e-01],
                        [ -2.24090576e-01,  -2.24243164e-01],
                        [ -1.90795898e-01,  -1.90765381e-01],
                        [ -1.36413574e-01,  -1.36291504e-01],
                        [ -9.01794434e-02,  -9.01794434e-02],
                        [ -6.35986328e-02,  -6.36901855e-02],
                        [ -4.72717285e-02,  -4.72717285e-02],
                        [ -2.71911621e-02,  -2.70996094e-02],
                        [ -2.59399414e-03,  -2.62451172e-03],
                        [  1.58081055e-02,   1.57470703e-02],
                        [  2.12402344e-02,   2.12707520e-02],
                        [  1.83105469e-02,   1.83715820e-02],
                        [  1.79748535e-02,   1.79443359e-02],
                        [  2.68249512e-02,   2.67639160e-02],
                        [  4.01916504e-02,   4.02221680e-02],
                        [  4.80957031e-02,   4.81872559e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  4.12597656e-02,   4.11682129e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  1.95617676e-02,   1.96533203e-02],
                        [  5.79833984e-03,   5.82885742e-03],
                        [ -3.17382812e-03,  -3.26538086e-03],
                        [ -1.25122070e-03,  -1.31225586e-03],
                        [  1.47094727e-02,   1.47705078e-02],
                        [  4.47387695e-02,   4.48303223e-02],
                        [  8.67614746e-02,   8.67004395e-02],
                        [  1.35345459e-01,   1.35253906e-01],
                        [  1.78375244e-01,   1.78405762e-01],
                        [  1.99493408e-01,   1.99615479e-01],
                        [  1.91162109e-01,   1.91162109e-01],
                        [  1.64093018e-01,   1.63940430e-01],
                        [  1.38397217e-01,   1.38336182e-01],
                        [  1.25000000e-01,   1.25122070e-01],
                        [  1.19689941e-01,   1.19812012e-01],
                        [  1.13342285e-01,   1.13250732e-01],
                        [  1.02844238e-01,   1.02661133e-01],
                        [  9.15222168e-02,   9.15527344e-02],
                        [  8.13598633e-02,   8.15429688e-02],
                        [  6.83593750e-02,   6.83898926e-02],
                        [  4.86145020e-02,   4.84313965e-02],
                        [  2.44750977e-02,   2.43835449e-02],
                        [ -1.52587891e-04,   0.00000000e+00],
                        [ -2.42919922e-02,  -2.41394043e-02],
                        [ -4.60205078e-02,  -4.61120605e-02],
                        [ -5.98449707e-02,  -6.00585938e-02],
                        [ -5.97229004e-02,  -5.96923828e-02],
                        [ -4.11682129e-02,  -4.09545898e-02],
                        [ -3.20434570e-03,  -3.17382812e-03],
                        [  4.85229492e-02,   4.83398438e-02],
                        [  1.00555420e-01,   1.00463867e-01],
                        [  1.35711670e-01,   1.35864258e-01],
                        [  1.43157959e-01,   1.43280029e-01],
                        [  1.26739502e-01,   1.26647949e-01],
                        [  1.01745605e-01,   1.01623535e-01],
                        [  8.16040039e-02,   8.16345215e-02],
                        [  6.82067871e-02,   6.82983398e-02],
                        [  5.56335449e-02,   5.56335449e-02],
                        [  4.07714844e-02,   4.07104492e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.73645020e-02,   1.73950195e-02],
                        [  1.34582520e-02,   1.34277344e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.77001953e-03,   1.83105469e-03],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -3.17077637e-02,  -3.17993164e-02],
                        [ -4.40063477e-02,  -4.40673828e-02],
                        [ -4.74853516e-02,  -4.73632812e-02],
                        [ -4.40063477e-02,  -4.39147949e-02],
                        [ -3.86657715e-02,  -3.87573242e-02],
                        [ -3.46984863e-02,  -3.48510742e-02],
                        [ -3.08532715e-02,  -3.08227539e-02],
                        [ -2.53295898e-02,  -2.51770020e-02],
                        [ -2.09045410e-02,  -2.08435059e-02],
                        [ -2.27050781e-02,  -2.28576660e-02],
                        [ -3.14331055e-02,  -3.15551758e-02],
                        [ -4.26330566e-02,  -4.24804688e-02],
                        [ -5.19104004e-02,  -5.17272949e-02],
                        [ -5.70068359e-02,  -5.70983887e-02],
                        [ -5.69152832e-02,  -5.71289062e-02],
                        [ -5.30090332e-02,  -5.29785156e-02],
                        [ -4.93469238e-02,  -4.91638184e-02],
                        [ -4.86755371e-02,  -4.87060547e-02],
                        [ -4.81872559e-02,  -4.83093262e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -2.75268555e-02,  -2.74353027e-02],
                        [ -6.77490234e-03,  -6.80541992e-03],
                        [  1.76696777e-02,   1.75781250e-02],
                        [  4.15039062e-02,   4.15649414e-02],
                        [  5.84106445e-02,   5.84716797e-02],
                        [  6.28967285e-02,   6.28356934e-02],
                        [  4.93774414e-02,   4.92858887e-02],
                        [  1.07421875e-02,   1.08032227e-02],
                        [ -5.42602539e-02,  -5.41687012e-02],
                        [ -1.33148193e-01,  -1.33178711e-01],
                        [ -2.03277588e-01,  -2.03399658e-01],
                        [ -2.43713379e-01,  -2.43682861e-01],
                        [ -2.44812012e-01,  -2.44750977e-01],
                        [ -2.13226318e-01,  -2.13256836e-01],
                        [ -1.70593262e-01,  -1.70654297e-01],
                        [ -1.39892578e-01,  -1.39862061e-01],
                        [ -1.25305176e-01,  -1.25244141e-01],
                        [ -1.12518311e-01,  -1.12579346e-01],
                        [ -9.14001465e-02,  -9.14611816e-02],
                        [ -6.80541992e-02,  -6.79931641e-02],
                        [ -5.25207520e-02,  -5.24291992e-02],
                        [ -4.52575684e-02,  -4.52880859e-02],
                        [ -3.89099121e-02,  -3.90319824e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -5.12695312e-03,  -4.97436523e-03],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  5.63354492e-02,   5.62133789e-02],
                        [  8.30688477e-02,   8.29772949e-02],
                        [  1.03668213e-01,   1.03729248e-01],
                        [  1.20513916e-01,   1.20605469e-01],
                        [  1.30981445e-01,   1.30950928e-01],
                        [  1.26342773e-01,   1.26281738e-01],
                        [  9.81750488e-02,   9.81750488e-02],
                        [  4.18395996e-02,   4.18701172e-02],
                        [ -3.97949219e-02,  -3.97949219e-02],
                        [ -1.29119873e-01,  -1.29119873e-01],
                        [ -1.93572998e-01,  -1.93542480e-01],
                        [ -2.05871582e-01,  -2.05871582e-01],
                        [ -1.68426514e-01,  -1.68487549e-01],
                        [ -1.12884521e-01,  -1.12915039e-01],
                        [ -7.25708008e-02,  -7.25097656e-02],
                        [ -5.67321777e-02,  -5.66711426e-02],
                        [ -5.11169434e-02,  -5.12084961e-02],
                        [ -3.95202637e-02,  -3.96423340e-02],
                        [ -2.11181641e-02,  -2.10876465e-02],
                        [ -6.43920898e-03,  -6.28662109e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -9.76562500e-04,  -1.09863281e-03],
                        [  2.92968750e-03,   2.89916992e-03],
                        [  1.33056641e-02,   1.33972168e-02],
                        [  2.71911621e-02,   2.72521973e-02],
                        [  3.85437012e-02,   3.84521484e-02],
                        [  4.14428711e-02,   4.13818359e-02],
                        [  3.55834961e-02,   3.56445312e-02],
                        [  2.62756348e-02,   2.63366699e-02],
                        [  1.65710449e-02,   1.65100098e-02],
                        [  5.55419922e-03,   5.52368164e-03],
                        [ -3.26538086e-03,  -3.17382812e-03],
                        [ -3.66210938e-04,  -3.35693359e-04],
                        [  1.95922852e-02,   1.95007324e-02],
                        [  5.38330078e-02,   5.37719727e-02],
                        [  9.75952148e-02,   9.76867676e-02],
                        [  1.44683838e-01,   1.44744873e-01],
                        [  1.81945801e-01,   1.81854248e-01],
                        [  1.94641113e-01,   1.94549561e-01],
                        [  1.81396484e-01,   1.81457520e-01],
                        [  1.57409668e-01,   1.57470703e-01],
                        [  1.38671875e-01,   1.38610840e-01],
                        [  1.27502441e-01,   1.27471924e-01],
                        [  1.17126465e-01,   1.17218018e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  9.21325684e-02,   9.20410156e-02],
                        [  8.27331543e-02,   8.27026367e-02],
                        [  7.47070312e-02,   7.48596191e-02],
                        [  6.59179688e-02,   6.59484863e-02],
                        [  5.39550781e-02,   5.38024902e-02],
                        [  3.47595215e-02,   3.46679688e-02],
                        [  6.13403320e-03,   6.25610352e-03],
                        [ -2.58483887e-02,  -2.57263184e-02],
                        [ -4.95300293e-02,  -4.96520996e-02],
                        [ -5.87158203e-02,  -5.88684082e-02],
                        [ -5.58471680e-02,  -5.58166504e-02],
                        [ -4.35180664e-02,  -4.33654785e-02],
                        [ -1.81884766e-02,  -1.81579590e-02],
                        [  2.31933594e-02,   2.30712891e-02],
                        [  7.25708008e-02,   7.25097656e-02],
                        [  1.12731934e-01,   1.12792969e-01],
                        [  1.30645752e-01,   1.30706787e-01],
                        [  1.25366211e-01,   1.25335693e-01],
                        [  1.04370117e-01,   1.04309082e-01],
                        [  7.78503418e-02,   7.78503418e-02],
                        [  5.46875000e-02,   5.47180176e-02],
                        [  3.83300781e-02,   3.83300781e-02],
                        [  2.73437500e-02,   2.73437500e-02],
                        [  1.95617676e-02,   1.95922852e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.11389160e-02,   1.11083984e-02],
                        [  8.27026367e-03,   8.27026367e-03],
                        [  4.21142578e-03,   4.27246094e-03],
                        [ -1.83105469e-03,  -1.80053711e-03],
                        [ -9.73510742e-03,  -9.82666016e-03],
                        [ -1.73950195e-02,  -1.74865723e-02],
                        [ -2.31018066e-02,  -2.30407715e-02],
                        [ -2.89001465e-02,  -2.88085938e-02],
                        [ -3.63769531e-02,  -3.64379883e-02],
                        [ -4.11071777e-02,  -4.12292480e-02],
                        [ -3.78112793e-02,  -3.77807617e-02],
                        [ -2.87170410e-02,  -2.85644531e-02],
                        [ -2.17895508e-02,  -2.17590332e-02],
                        [ -2.15148926e-02,  -2.16674805e-02],
                        [ -2.49328613e-02,  -2.49938965e-02],
                        [ -2.78930664e-02,  -2.77709961e-02],
                        [ -3.11584473e-02,  -3.10363770e-02],
                        [ -3.72314453e-02,  -3.72924805e-02],
                        [ -4.56848145e-02,  -4.58374023e-02],
                        [ -5.36193848e-02,  -5.35888672e-02],
                        [ -5.79223633e-02,  -5.78002930e-02],
                        [ -5.61828613e-02,  -5.61523438e-02],
                        [ -4.59594727e-02,  -4.60510254e-02],
                        [ -2.71301270e-02,  -2.71911621e-02],
                        [ -4.73022461e-03,  -4.63867188e-03],
                        [  1.57470703e-02,   1.58386230e-02],
                        [  3.50341797e-02,   3.50036621e-02],
                        [  5.50231934e-02,   5.49316406e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  6.22863770e-02,   6.23474121e-02],
                        [  2.64892578e-02,   2.65197754e-02],
                        [ -3.72009277e-02,  -3.72619629e-02],
                        [ -1.17675781e-01,  -1.17706299e-01],
                        [ -1.96594238e-01,  -1.96533203e-01],
                        [ -2.51159668e-01,  -2.51129150e-01],
                        [ -2.63763428e-01,  -2.63793945e-01],
                        [ -2.35412598e-01,  -2.35443115e-01],
                        [ -1.87194824e-01,  -1.87164307e-01],
                        [ -1.43432617e-01,  -1.43371582e-01],
                        [ -1.14105225e-01,  -1.14135742e-01],
                        [ -9.40856934e-02,  -9.41467285e-02],
                        [ -7.62023926e-02,  -7.62023926e-02],
                        [ -6.08825684e-02,  -6.08520508e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [ -5.04150391e-02,  -5.04455566e-02],
                        [ -4.78210449e-02,  -4.78515625e-02],
                        [ -3.73535156e-02,  -3.73229980e-02],
                        [ -1.71508789e-02,  -1.71203613e-02],
                        [  8.57543945e-03,   8.54492188e-03],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  5.87768555e-02,   5.88378906e-02],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  1.14837646e-01,   1.14776611e-01],
                        [  1.41235352e-01,   1.41265869e-01],
                        [  1.52465820e-01,   1.52557373e-01],
                        [  1.39556885e-01,   1.39556885e-01],
                        [  1.00402832e-01,   1.00311279e-01],
                        [  3.64074707e-02,   3.63464355e-02],
                        [ -4.73327637e-02,  -4.72412109e-02],
                        [ -1.34124756e-01,  -1.34033203e-01],
                        [ -1.94946289e-01,  -1.95007324e-01],
                        [ -2.06176758e-01,  -2.06298828e-01],
                        [ -1.70562744e-01,  -1.70532227e-01],
                        [ -1.16546631e-01,  -1.16394043e-01],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -5.35888672e-02,  -5.36804199e-02],
                        [ -4.31823730e-02,  -4.32434082e-02],
                        [ -3.15856934e-02,  -3.14941406e-02],
                        [ -1.85546875e-02,  -1.84936523e-02],
                        [ -1.02233887e-02,  -1.02844238e-02],
                        [ -8.33129883e-03,  -8.39233398e-03],
                        [ -6.89697266e-03,  -6.83593750e-03],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  1.92565918e-02,   1.92260742e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  4.37622070e-02,   4.38232422e-02],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  3.54614258e-02,   3.54003906e-02],
                        [  2.82592773e-02,   2.82592773e-02],
                        [  1.95617676e-02,   1.96533203e-02],
                        [  1.11999512e-02,   1.12304688e-02],
                        [  7.14111328e-03,   7.04956055e-03],
                        [  9.97924805e-03,   9.94873047e-03],
                        [  2.17895508e-02,   2.18811035e-02],
                        [  4.56237793e-02,   4.56848145e-02],
                        [  8.20312500e-02,   8.19702148e-02],
                        [  1.24389648e-01,   1.24328613e-01],
                        [  1.60430908e-01,   1.60491943e-01],
                        [  1.79962158e-01,   1.80023193e-01],
                        [  1.81060791e-01,   1.81030273e-01],
                        [  1.70318604e-01,   1.70227051e-01],
                        [  1.56524658e-01,   1.56555176e-01],
                        [  1.44287109e-01,   1.44378662e-01],
                        [  1.32324219e-01,   1.32293701e-01],
                        [  1.18041992e-01,   1.17980957e-01],
                        [  1.02630615e-01,   1.02630615e-01],
                        [  8.87756348e-02,   8.88366699e-02],
                        [  7.59277344e-02,   7.59277344e-02],
                        [  6.05163574e-02,   6.04553223e-02],
                        [  4.08935547e-02,   4.08935547e-02],
                        [  1.96533203e-02,   1.96838379e-02],
                        [  1.52587891e-04,   1.52587891e-04],
                        [ -1.70288086e-02,  -1.70593262e-02],
                        [ -3.25622559e-02,  -3.25317383e-02],
                        [ -4.36401367e-02,  -4.36096191e-02],
                        [ -4.54406738e-02,  -4.55017090e-02],
                        [ -3.78112793e-02,  -3.78112793e-02],
                        [ -2.42919922e-02,  -2.42309570e-02],
                        [ -3.05175781e-03,  -2.99072266e-03],
                        [  3.34472656e-02,   3.33862305e-02],
                        [  8.37707520e-02,   8.37097168e-02],
                        [  1.29180908e-01,   1.29241943e-01],
                        [  1.48162842e-01,   1.48254395e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  1.05804443e-01,   1.05712891e-01],
                        [  7.30895996e-02,   7.30590820e-02],
                        [  4.77600098e-02,   4.78210449e-02],
                        [  3.16772461e-02,   3.17077637e-02],
                        [  2.09960938e-02,   2.09350586e-02],
                        [  1.24511719e-02,   1.23901367e-02],
                        [  6.34765625e-03,   6.34765625e-03],
                        [  2.96020508e-03,   2.99072266e-03],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [ -8.63647461e-03,  -8.63647461e-03],
                        [ -2.14843750e-02,  -2.15148926e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.15039062e-02,  -4.14733887e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -2.62451172e-02,  -2.62756348e-02],
                        [ -2.15759277e-02,  -2.15454102e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.38647461e-02,  -2.38647461e-02],
                        [ -2.42309570e-02,  -2.42614746e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -3.00903320e-02,  -3.00598145e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -4.46472168e-02,  -4.47082520e-02],
                        [ -5.20629883e-02,  -5.20629883e-02],
                        [ -5.46875000e-02,  -5.46264648e-02],
                        [ -4.83398438e-02,  -4.83093262e-02],
                        [ -3.34167480e-02,  -3.34777832e-02],
                        [ -1.45568848e-02,  -1.45874023e-02],
                        [  5.03540039e-03,   5.09643555e-03],
                        [  2.53295898e-02,   2.53601074e-02],
                        [  4.35791016e-02,   4.34875488e-02],
                        [  5.07812500e-02,   5.07202148e-02],
                        [  3.63159180e-02,   3.63464355e-02],
                        [ -5.24902344e-03,  -5.21850586e-03],
                        [ -7.04650879e-02,  -7.04956055e-02],
                        [ -1.46087646e-01,  -1.46148682e-01],
                        [ -2.11273193e-01,  -2.11242676e-01],
                        [ -2.45666504e-01,  -2.45635986e-01],
                        [ -2.40783691e-01,  -2.40814209e-01],
                        [ -2.05413818e-01,  -2.05444336e-01],
                        [ -1.61254883e-01,  -1.61254883e-01],
                        [ -1.29638672e-01,  -1.29608154e-01],
                        [ -1.15661621e-01,  -1.15661621e-01],
                        [ -1.06506348e-01,  -1.06536865e-01],
                        [ -8.95385742e-02,  -8.95080566e-02],
                        [ -6.72302246e-02,  -6.71997070e-02],
                        [ -5.10253906e-02,  -5.10253906e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -4.83398438e-02,  -4.83398438e-02],
                        [ -4.57153320e-02,  -4.56848145e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [  4.88281250e-04,   4.57763672e-04],
                        [  3.79943848e-02,   3.79638672e-02],
                        [  7.13500977e-02,   7.13806152e-02],
                        [  9.50012207e-02,   9.50317383e-02],
                        [  1.11328125e-01,   1.11328125e-01],
                        [  1.23046875e-01,   1.23016357e-01],
                        [  1.28204346e-01,   1.28204346e-01],
                        [  1.21673584e-01,   1.21704102e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  4.17175293e-02,   4.17175293e-02],
                        [ -4.09545898e-02,  -4.09545898e-02],
                        [ -1.33911133e-01,  -1.33911133e-01],
                        [ -2.01690674e-01,  -2.01690674e-01],
                        [ -2.14874268e-01,  -2.14874268e-01],
                        [ -1.76208496e-01,  -1.76208496e-01],
                        [ -1.18499756e-01,  -1.18499756e-01],
                        [ -7.47680664e-02,  -7.47680664e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -3.42712402e-02,  -3.42407227e-02],
                        [ -2.22473145e-02,  -2.22167969e-02],
                        [ -1.38549805e-02,  -1.38549805e-02],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -2.04467773e-03,  -2.07519531e-03],
                        [  1.14746094e-02,   1.14746094e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  4.96826172e-02,   4.96520996e-02],
                        [  3.93066406e-02,   3.92761230e-02],
                        [  2.09655762e-02,   2.09655762e-02],
                        [  3.02124023e-03,   3.05175781e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -1.54418945e-02,  -1.55029297e-02],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [  1.51672363e-02,   1.51977539e-02],
                        [  5.02014160e-02,   5.02014160e-02],
                        [  9.26208496e-02,   9.25903320e-02],
                        [  1.37084961e-01,   1.37054443e-01],
                        [  1.72607422e-01,   1.72637939e-01],
                        [  1.87072754e-01,   1.87072754e-01],
                        [  1.79656982e-01,   1.79626465e-01],
                        [  1.62048340e-01,   1.62048340e-01],
                        [  1.46362305e-01,   1.46362305e-01],
                        [  1.36566162e-01,   1.36566162e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.20605469e-01,   1.20605469e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  9.56115723e-02,   9.56115723e-02],
                        [  8.38012695e-02,   8.38012695e-02],
                        [  7.03125000e-02,   7.03125000e-02],
                        [  5.54199219e-02,   5.54504395e-02],
                        [  4.33654785e-02,   4.33654785e-02],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [ -5.12695312e-03,  -5.09643555e-03],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -5.04760742e-02,  -5.05065918e-02],
                        [ -5.63354492e-02,  -5.63354492e-02],
                        [ -5.46569824e-02,  -5.46264648e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [  1.61132812e-02,   1.61132812e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  1.13250732e-01,   1.13250732e-01],
                        [  1.38519287e-01,   1.38488770e-01],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.15356445e-01,   1.15356445e-01],
                        [  8.99047852e-02,   8.99047852e-02],
                        [  7.04956055e-02,   7.04650879e-02],
                        [  5.27343750e-02,   5.27343750e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  8.08715820e-03,   8.11767578e-03],
                        [ -3.87573242e-03,  -3.90625000e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -5.82885742e-03,  -5.82885742e-03],
                        [ -9.67407227e-03,  -9.67407227e-03],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.88085938e-02,  -2.87780762e-02],
                        [ -3.12805176e-02,  -3.13110352e-02],
                        [ -2.97241211e-02,  -2.97546387e-02],
                        [ -2.80151367e-02,  -2.80151367e-02],
                        [ -2.82287598e-02,  -2.81982422e-02],
                        [ -2.92663574e-02,  -2.92663574e-02],
                        [ -3.24707031e-02,  -3.25012207e-02],
                        [ -3.93676758e-02,  -3.93676758e-02],
                        [ -4.48303223e-02,  -4.47998047e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.74450684e-02,  -3.74755859e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [ -3.17077637e-02,  -3.16772461e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.68859863e-02,  -2.68859863e-02],
                        [ -2.69775391e-02,  -2.70080566e-02],
                        [ -2.43225098e-02,  -2.42919922e-02],
                        [ -1.32446289e-02,  -1.32141113e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  2.51464844e-02,   2.51159668e-02],
                        [  3.70788574e-02,   3.70483398e-02],
                        [  3.81164551e-02,   3.81469727e-02],
                        [  2.72827148e-02,   2.73132324e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [ -6.24694824e-02,  -6.24694824e-02],
                        [ -1.44836426e-01,  -1.44805908e-01],
                        [ -2.20123291e-01,  -2.20123291e-01],
                        [ -2.56652832e-01,  -2.56652832e-01],
                        [ -2.44659424e-01,  -2.44659424e-01],
                        [ -1.98944092e-01,  -1.98944092e-01],
                        [ -1.46331787e-01,  -1.46331787e-01],
                        [ -1.09710693e-01,  -1.09710693e-01],
                        [ -9.39941406e-02,  -9.39941406e-02],
                        [ -8.82263184e-02,  -8.82263184e-02],
                        [ -8.18786621e-02,  -8.18786621e-02],
                        [ -7.30285645e-02,  -7.30590820e-02],
                        [ -6.34460449e-02,  -6.34460449e-02],
                        [ -5.34057617e-02,  -5.34057617e-02],
                        [ -4.02526855e-02,  -4.02526855e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [  5.40161133e-03,   5.40161133e-03],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  7.19299316e-02,   7.19299316e-02],
                        [  9.00573730e-02,   9.00573730e-02],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  1.15447998e-01,   1.15447998e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.11968994e-01,   1.11968994e-01],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [ -8.56323242e-02,  -8.56323242e-02],
                        [ -1.67083740e-01,  -1.67083740e-01],
                        [ -2.06878662e-01,  -2.06848145e-01],
                        [ -1.93603516e-01,  -1.93603516e-01],
                        [ -1.42425537e-01,  -1.42425537e-01],
                        [ -8.29772949e-02,  -8.30078125e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.50549316e-02,  -2.50549316e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -2.69470215e-02,  -2.69470215e-02],
                        [ -2.97851562e-02,  -2.97851562e-02],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -2.13317871e-02,  -2.13623047e-02],
                        [  3.05175781e-05,   3.05175781e-05],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  2.84118652e-02,   2.83813477e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  5.46264648e-03,   5.49316406e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -5.18798828e-03,  -5.21850586e-03],
                        [ -2.92968750e-03,  -2.96020508e-03],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  4.58068848e-02,   4.58374023e-02],
                        [  9.35058594e-02,   9.35058594e-02],
                        [  1.40258789e-01,   1.40258789e-01],
                        [  1.71112061e-01,   1.71112061e-01],
                        [  1.81854248e-01,   1.81854248e-01],
                        [  1.78314209e-01,   1.78314209e-01],
                        [  1.67907715e-01,   1.67907715e-01],
                        [  1.55212402e-01,   1.55212402e-01],
                        [  1.42883301e-01,   1.42913818e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  1.11083984e-01,   1.11083984e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  7.59887695e-02,   7.59887695e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [ -1.22680664e-02,  -1.22985840e-02],
                        [ -1.52282715e-02,  -1.52282715e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -2.46276855e-02,  -2.46276855e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -4.83093262e-02,  -4.83093262e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -2.80761719e-02,  -2.80761719e-02],
                        [  3.02124023e-03,   2.99072266e-03],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  7.79113770e-02,   7.79113770e-02],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.25030518e-01,   1.25030518e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  9.15527344e-02,   9.15527344e-02],
                        [  6.71386719e-02,   6.71386719e-02],
                        [  4.89501953e-02,   4.89501953e-02],
                        [  3.31726074e-02,   3.31726074e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  5.03540039e-03,   5.03540039e-03],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  4.73022461e-03,   4.73022461e-03],
                        [  1.73950195e-03,   1.77001953e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -2.04772949e-02,  -2.04772949e-02],
                        [ -2.72827148e-02,  -2.72827148e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.27551270e-02,  -4.27551270e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -3.38439941e-02,  -3.38439941e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -4.14733887e-02,  -4.14733887e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [  1.49536133e-02,   1.49536133e-02],
                        [  3.29589844e-02,   3.29589844e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [ -1.00341797e-01,  -1.00341797e-01],
                        [ -1.80236816e-01,  -1.80236816e-01],
                        [ -2.43072510e-01,  -2.43072510e-01],
                        [ -2.66540527e-01,  -2.66540527e-01],
                        [ -2.41729736e-01,  -2.41729736e-01],
                        [ -1.88049316e-01,  -1.88049316e-01],
                        [ -1.39190674e-01,  -1.39190674e-01],
                        [ -1.11755371e-01,  -1.11724854e-01],
                        [ -9.78698730e-02,  -9.78698730e-02],
                        [ -8.61816406e-02,  -8.61816406e-02],
                        [ -7.48291016e-02,  -7.48291016e-02],
                        [ -6.47888184e-02,  -6.47888184e-02],
                        [ -5.48400879e-02,  -5.48400879e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  4.37927246e-02,   4.37927246e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  8.06884766e-02,   8.06884766e-02],
                        [  9.09729004e-02,   9.09729004e-02],
                        [  1.01043701e-01,   1.01043701e-01],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  7.39135742e-02,   7.39135742e-02],
                        [  1.15661621e-02,   1.15661621e-02],
                        [ -7.40966797e-02,  -7.40966797e-02],
                        [ -1.53961182e-01,  -1.53961182e-01],
                        [ -1.95587158e-01,  -1.95587158e-01],
                        [ -1.83990479e-01,  -1.83990479e-01],
                        [ -1.33483887e-01,  -1.33483887e-01],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.23583984e-02,  -4.23583984e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  1.15966797e-02,   1.15966797e-02],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  8.54492188e-04,   8.54492188e-04],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  5.09643555e-03,   5.09643555e-03],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  5.79223633e-02,   5.79223633e-02],
                        [  9.41162109e-02,   9.41162109e-02],
                        [  1.32476807e-01,   1.32476807e-01],
                        [  1.63299561e-01,   1.63299561e-01],
                        [  1.79016113e-01,   1.79016113e-01],
                        [  1.77490234e-01,   1.77490234e-01],
                        [  1.64306641e-01,   1.64306641e-01],
                        [  1.50238037e-01,   1.50238037e-01],
                        [  1.42822266e-01,   1.42822266e-01],
                        [  1.39160156e-01,   1.39160156e-01],
                        [  1.32080078e-01,   1.32080078e-01],
                        [  1.21917725e-01,   1.21917725e-01],
                        [  1.13525391e-01,   1.13525391e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  6.64062500e-02,   6.64062500e-02],
                        [  4.47998047e-02,   4.47998047e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [ -7.87353516e-03,  -7.87353516e-03],
                        [ -1.81274414e-02,  -1.81274414e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -2.25219727e-02,  -2.25219727e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -3.87268066e-02,  -3.87268066e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.43420410e-02,  -4.43420410e-02],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  7.31811523e-02,   7.31811523e-02],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  1.14624023e-01,   1.14624023e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  4.14123535e-02,   4.14123535e-02],
                        [  3.52478027e-02,   3.52478027e-02],
                        [  3.25622559e-02,   3.25622559e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -4.66918945e-02,  -4.66918945e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -3.90014648e-02,  -3.90014648e-02],
                        [ -2.96936035e-02,  -2.96936035e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.24609375e-02,  -2.24609375e-02],
                        [ -2.21862793e-02,  -2.21862793e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -4.57458496e-02,  -4.57458496e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [  1.19018555e-03,   1.19018555e-03],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -1.43463135e-01,  -1.43463135e-01],
                        [ -2.17895508e-01,  -2.17895508e-01],
                        [ -2.58453369e-01,  -2.58453369e-01],
                        [ -2.55432129e-01,  -2.55432129e-01],
                        [ -2.18444824e-01,  -2.18444824e-01],
                        [ -1.69372559e-01,  -1.69372559e-01],
                        [ -1.30218506e-01,  -1.30218506e-01],
                        [ -1.08886719e-01,  -1.08886719e-01],
                        [ -9.55810547e-02,  -9.55810547e-02],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -5.09643555e-02,  -5.09643555e-02],
                        [ -4.74548340e-02,  -4.74548340e-02],
                        [ -3.35693359e-02,  -3.35693359e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  3.08532715e-02,   3.08532715e-02],
                        [  5.58166504e-02,   5.58166504e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  9.70458984e-02,   9.70458984e-02],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.09558105e-01,   1.09558105e-01],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  7.44934082e-02,   7.44934082e-02],
                        [  1.72424316e-02,   1.72424316e-02],
                        [ -6.26220703e-02,  -6.26220703e-02],
                        [ -1.42456055e-01,  -1.42456055e-01],
                        [ -1.90917969e-01,  -1.90917969e-01],
                        [ -1.91436768e-01,  -1.91436768e-01],
                        [ -1.55853271e-01,  -1.55853271e-01],
                        [ -1.10595703e-01,  -1.10595703e-01],
                        [ -7.41882324e-02,  -7.41882324e-02],
                        [ -5.03540039e-02,  -5.03540039e-02],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -2.63671875e-02,  -2.63671875e-02],
                        [ -2.20642090e-02,  -2.20642090e-02],
                        [ -1.97143555e-02,  -1.97143555e-02],
                        [ -1.54113770e-02,  -1.54113770e-02],
                        [ -7.72094727e-03,  -7.72094727e-03],
                        [  1.34277344e-03,   1.34277344e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  8.39233398e-03,   8.39233398e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  4.39758301e-02,   4.39758301e-02],
                        [  8.63647461e-02,   8.63647461e-02],
                        [  1.28631592e-01,   1.28631592e-01],
                        [  1.62658691e-01,   1.62658691e-01],
                        [  1.81304932e-01,   1.81304932e-01],
                        [  1.81396484e-01,   1.81396484e-01],
                        [  1.67449951e-01,   1.67449951e-01],
                        [  1.50238037e-01,   1.50238037e-01],
                        [  1.38336182e-01,   1.38336182e-01],
                        [  1.31134033e-01,   1.31134033e-01],
                        [  1.22955322e-01,   1.22955322e-01],
                        [  1.12274170e-01,   1.12274170e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  9.48181152e-02,   9.48181152e-02],
                        [  8.70361328e-02,   8.70361328e-02],
                        [  7.63549805e-02,   7.63549805e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  1.59912109e-02,   1.59912109e-02],
                        [  8.63647461e-03,   8.63647461e-03],
                        [  2.71606445e-03,   2.71606445e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -2.02026367e-02,  -2.02026367e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -3.88793945e-02,  -3.88793945e-02],
                        [ -4.40979004e-02,  -4.40979004e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -2.90527344e-02,  -2.90527344e-02],
                        [ -7.62939453e-04,  -7.62939453e-04],
                        [  3.63159180e-02,   3.63159180e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  9.39941406e-02,   9.39941406e-02],
                        [  9.77478027e-02,   9.77478027e-02],
                        [  8.54492188e-02,   8.54492188e-02],
                        [  6.74438477e-02,   6.74438477e-02],
                        [  5.32226562e-02,   5.32226562e-02],
                        [  4.42199707e-02,   4.42199707e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [  2.82897949e-02,   2.82897949e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -3.54919434e-02,  -3.54919434e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -5.45654297e-02,  -5.45654297e-02],
                        [ -5.05676270e-02,  -5.05676270e-02],
                        [ -4.20532227e-02,  -4.20532227e-02],
                        [ -3.49426270e-02,  -3.49426270e-02],
                        [ -3.21044922e-02,  -3.21044922e-02],
                        [ -3.21350098e-02,  -3.21350098e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.77099609e-02,  -2.77099609e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.27966309e-02,  -2.27966309e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [  9.97924805e-03,   9.97924805e-03],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  5.00488281e-02,   5.00488281e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -1.53839111e-01,  -1.53839111e-01],
                        [ -2.28729248e-01,  -2.28729248e-01],
                        [ -2.68402100e-01,  -2.68402100e-01],
                        [ -2.57629395e-01,  -2.57629395e-01],
                        [ -2.07275391e-01,  -2.07275391e-01],
                        [ -1.49353027e-01,  -1.49353027e-01],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -9.83581543e-02,  -9.83581543e-02],
                        [ -9.57336426e-02,  -9.57336426e-02],
                        [ -9.04235840e-02,  -9.04235840e-02],
                        [ -7.84606934e-02,  -7.84606934e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -5.37414551e-02,  -5.37414551e-02],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.35693359e-03,  -3.35693359e-03],
                        [  2.20336914e-02,   2.20336914e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  7.71484375e-02,   7.71484375e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  1.03149414e-01,   1.03149414e-01],
                        [  1.13403320e-01,   1.13403320e-01],
                        [  1.17218018e-01,   1.17218018e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  6.49108887e-02,   6.49108887e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -9.57031250e-02,  -9.57031250e-02],
                        [ -1.74560547e-01,  -1.74560547e-01],
                        [ -2.10540771e-01,  -2.10540771e-01],
                        [ -1.91406250e-01,  -1.91406250e-01],
                        [ -1.37268066e-01,  -1.37268066e-01],
                        [ -8.36791992e-02,  -8.36791992e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -2.65808105e-02,  -2.65808105e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.42822266e-02,  -1.42822266e-02],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -4.57763672e-04,  -4.57763672e-04],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  1.48925781e-02,   1.48925781e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  1.07727051e-02,   1.07727051e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  4.38842773e-02,   4.38842773e-02],
                        [  9.54589844e-02,   9.54589844e-02],
                        [  1.41754150e-01,   1.41754150e-01],
                        [  1.68823242e-01,   1.68823242e-01],
                        [  1.73004150e-01,   1.73004150e-01],
                        [  1.62689209e-01,   1.62689209e-01],
                        [  1.51733398e-01,   1.51733398e-01],
                        [  1.46575928e-01,   1.46575928e-01],
                        [  1.41967773e-01,   1.41967773e-01],
                        [  1.31103516e-01,   1.31103516e-01],
                        [  1.16271973e-01,   1.16271973e-01],
                        [  1.03973389e-01,   1.03973389e-01],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  8.87451172e-02,   8.87451172e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  7.02209473e-02,   7.02209473e-02],
                        [  5.52978516e-02,   5.52978516e-02],
                        [  3.75671387e-02,   3.75671387e-02],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  1.50756836e-02,   1.50756836e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.20214844e-03,   7.20214844e-03],
                        [ -5.55419922e-03,  -5.55419922e-03],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -4.29992676e-02,  -4.29992676e-02],
                        [ -4.63562012e-02,  -4.63562012e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  1.04888916e-01,   1.04888916e-01],
                        [  1.15875244e-01,   1.15875244e-01],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  7.36999512e-02,   7.36999512e-02],
                        [  5.00793457e-02,   5.00793457e-02],
                        [  3.70788574e-02,   3.70788574e-02],
                        [  3.20434570e-02,   3.20434570e-02],
                        [  2.84118652e-02,   2.84118652e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  9.39941406e-03,   9.39941406e-03],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -1.77001953e-02,  -1.77001953e-02],
                        [ -2.41394043e-02,  -2.41394043e-02],
                        [ -2.92968750e-02,  -2.92968750e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.50646973e-02,  -3.50646973e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -2.89001465e-02,  -2.89001465e-02],
                        [ -2.69775391e-02,  -2.69775391e-02],
                        [ -2.83203125e-02,  -2.83203125e-02],
                        [ -3.16162109e-02,  -3.16162109e-02],
                        [ -3.52783203e-02,  -3.52783203e-02],
                        [ -3.91845703e-02,  -3.91845703e-02],
                        [ -4.24804688e-02,  -4.24804688e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [ -6.46972656e-03,  -6.46972656e-03],
                        [  2.05993652e-02,   2.05993652e-02],
                        [  4.51354980e-02,   4.51354980e-02],
                        [  6.08825684e-02,   6.08825684e-02],
                        [  5.97534180e-02,   5.97534180e-02],
                        [  3.40270996e-02,   3.40270996e-02],
                        [ -1.80969238e-02,  -1.80969238e-02],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -1.69128418e-01,  -1.69128418e-01],
                        [ -2.34771729e-01,  -2.34771729e-01],
                        [ -2.65930176e-01,  -2.65930176e-01],
                        [ -2.51251221e-01,  -2.51251221e-01],
                        [ -2.01721191e-01,  -2.01721191e-01],
                        [ -1.48132324e-01,  -1.48132324e-01],
                        [ -1.16760254e-01,  -1.16760254e-01],
                        [ -1.08093262e-01,  -1.08093262e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -9.27429199e-02,  -9.27429199e-02],
                        [ -7.59582520e-02,  -7.59582520e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -2.89611816e-02,  -2.89611816e-02],
                        [ -5.49316406e-03,  -5.49316406e-03],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  5.20324707e-02,   5.20324707e-02],
                        [  5.54809570e-02,   5.54809570e-02],
                        [  6.22863770e-02,   6.22863770e-02],
                        [  7.71484375e-02,   7.71484375e-02],
                        [  9.76562500e-02,   9.76562500e-02],
                        [  1.17187500e-01,   1.17187500e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.17218018e-01,   1.17218018e-01],
                        [  7.52868652e-02,   7.52868652e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [ -1.01531982e-01,  -1.01531982e-01],
                        [ -1.85424805e-01,  -1.85424805e-01],
                        [ -2.17864990e-01,  -2.17864990e-01],
                        [ -1.91101074e-01,  -1.91101074e-01],
                        [ -1.32781982e-01,  -1.32781982e-01],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  5.55419922e-03,   5.55419922e-03],
                        [  5.27954102e-03,   5.27954102e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  4.88281250e-04,   4.88281250e-04],
                        [  1.95312500e-03,   1.95312500e-03],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  1.09863281e-02,   1.09863281e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  5.72204590e-02,   5.72204590e-02],
                        [  9.79919434e-02,   9.79919434e-02],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.59729004e-01,   1.59729004e-01],
                        [  1.57745361e-01,   1.57745361e-01],
                        [  1.41510010e-01,   1.41510010e-01],
                        [  1.29547119e-01,   1.29547119e-01],
                        [  1.29882812e-01,   1.29882812e-01],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.35742188e-01,   1.35742188e-01],
                        [  1.30676270e-01,   1.30676270e-01],
                        [  1.20452881e-01,   1.20452881e-01],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  7.80639648e-02,   7.80639648e-02],
                        [  6.40258789e-02,   6.40258789e-02],
                        [  4.70886230e-02,   4.70886230e-02],
                        [  2.95715332e-02,   2.95715332e-02],
                        [  1.36108398e-02,   1.36108398e-02],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.06506348e-02,  -1.06506348e-02],
                        [ -1.76696777e-02,  -1.76696777e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -2.92358398e-02,  -2.92358398e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.90417480e-02,  -4.90417480e-02],
                        [ -5.47180176e-02,  -5.47180176e-02],
                        [ -4.60815430e-02,  -4.60815430e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [  3.76892090e-02,   3.76892090e-02],
                        [  9.28955078e-02,   9.28955078e-02],
                        [  1.25305176e-01,   1.25305176e-01],
                        [  1.22467041e-01,   1.22467041e-01],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  6.32934570e-02,   6.32934570e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  2.98156738e-02,   2.98156738e-02],
                        [  2.08129883e-02,   2.08129883e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [  7.38525391e-03,   7.38525391e-03],
                        [  8.81958008e-03,   8.81958008e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -2.30407715e-02,  -2.30407715e-02],
                        [ -2.14843750e-02,  -2.14843750e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -2.26745605e-02,  -2.26745605e-02],
                        [ -2.59094238e-02,  -2.59094238e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -2.45056152e-02,  -2.45056152e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.66210938e-02,  -3.66210938e-02],
                        [ -4.46472168e-02,  -4.46472168e-02],
                        [ -5.07812500e-02,  -5.07812500e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -4.45861816e-02,  -4.45861816e-02],
                        [ -3.10974121e-02,  -3.10974121e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  2.80151367e-02,   2.80151367e-02],
                        [  4.60510254e-02,   4.60510254e-02],
                        [  5.52673340e-02,   5.52673340e-02],
                        [  5.01098633e-02,   5.01098633e-02],
                        [  2.58789062e-02,   2.58789062e-02],
                        [ -2.13317871e-02,  -2.13317871e-02],
                        [ -9.01489258e-02,  -9.01489258e-02],
                        [ -1.68121338e-01,  -1.68121338e-01],
                        [ -2.33154297e-01,  -2.33154297e-01],
                        [ -2.62329102e-01,  -2.62329102e-01],
                        [ -2.44873047e-01,  -2.44873047e-01],
                        [ -1.93847656e-01,  -1.93847656e-01],
                        [ -1.40747070e-01,  -1.40747070e-01],
                        [ -1.10382080e-01,  -1.10382080e-01],
                        [ -1.02203369e-01,  -1.02203369e-01],
                        [ -9.96093750e-02,  -9.96093750e-02],
                        [ -9.12780762e-02,  -9.12780762e-02],
                        [ -7.73620605e-02,  -7.73620605e-02],
                        [ -6.14318848e-02,  -6.14318848e-02],
                        [ -4.54406738e-02,  -4.54406738e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.62658691e-02,   1.62658691e-02],
                        [  3.66516113e-02,   3.66516113e-02],
                        [  5.47180176e-02,   5.47180176e-02],
                        [  6.72912598e-02,   6.72912598e-02],
                        [  7.53173828e-02,   7.53173828e-02],
                        [  8.28552246e-02,   8.28552246e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  1.08673096e-01,   1.08673096e-01],
                        [  1.18560791e-01,   1.18560791e-01],
                        [  1.05865479e-01,   1.05865479e-01],
                        [  5.70983887e-02,   5.70983887e-02],
                        [ -2.20336914e-02,  -2.20336914e-02],
                        [ -1.07879639e-01,  -1.07879639e-01],
                        [ -1.71142578e-01,  -1.71142578e-01],
                        [ -1.89727783e-01,  -1.89727783e-01],
                        [ -1.61315918e-01,  -1.61315918e-01],
                        [ -1.08795166e-01,  -1.08795166e-01],
                        [ -6.50024414e-02,  -6.50024414e-02],
                        [ -4.58068848e-02,  -4.58068848e-02],
                        [ -4.10156250e-02,  -4.10156250e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.88293457e-02,  -1.88293457e-02],
                        [ -2.31933594e-02,  -2.31933594e-02],
                        [ -3.17382812e-02,  -3.17382812e-02],
                        [ -3.85437012e-02,  -3.85437012e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  6.55822754e-02,   6.55822754e-02],
                        [  1.07604980e-01,   1.07604980e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.68487549e-01,   1.68487549e-01],
                        [  1.67388916e-01,   1.67388916e-01],
                        [  1.51672363e-01,   1.51672363e-01],
                        [  1.36260986e-01,   1.36260986e-01],
                        [  1.29241943e-01,   1.29241943e-01],
                        [  1.26556396e-01,   1.26556396e-01],
                        [  1.22192383e-01,   1.22192383e-01],
                        [  1.17431641e-01,   1.17431641e-01],
                        [  1.15783691e-01,   1.15783691e-01],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.00982666e-01,   1.00982666e-01],
                        [  8.98132324e-02,   8.98132324e-02],
                        [  7.80334473e-02,   7.80334473e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  3.69262695e-03,   3.69262695e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.11083984e-02,  -1.11083984e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -2.42919922e-02,  -2.42919922e-02],
                        [ -4.41894531e-02,  -4.41894531e-02],
                        [ -6.26831055e-02,  -6.26831055e-02],
                        [ -6.71386719e-02,  -6.71386719e-02],
                        [ -5.30700684e-02,  -5.30700684e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  7.77587891e-02,   7.77587891e-02],
                        [  1.13708496e-01,   1.13708496e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  1.02478027e-01,   1.02478027e-01],
                        [  7.35168457e-02,   7.35168457e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  3.21350098e-02,   3.21350098e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [  9.09423828e-03,   9.09423828e-03],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  1.45568848e-02,   1.45568848e-02],
                        [  3.11279297e-03,   3.11279297e-03],
                        [ -1.11694336e-02,  -1.11694336e-02],
                        [ -2.10876465e-02,  -2.10876465e-02],
                        [ -2.58483887e-02,  -2.58483887e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.27148438e-02,  -3.27148438e-02],
                        [ -3.59191895e-02,  -3.59191895e-02],
                        [ -3.80859375e-02,  -3.80859375e-02],
                        [ -4.05578613e-02,  -4.05578613e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -3.55834961e-02,  -3.55834961e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.06701660e-02,  -3.06701660e-02],
                        [ -3.34472656e-02,  -3.34472656e-02],
                        [ -3.15246582e-02,  -3.15246582e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  3.71704102e-02,   3.71704102e-02],
                        [  5.87768555e-02,   5.87768555e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -1.44439697e-01,  -1.44439697e-01],
                        [ -2.26867676e-01,  -2.26867676e-01],
                        [ -2.75329590e-01,  -2.75329590e-01],
                        [ -2.73895264e-01,  -2.73895264e-01],
                        [ -2.33551025e-01,  -2.33551025e-01],
                        [ -1.83502197e-01,  -1.83502197e-01],
                        [ -1.45721436e-01,  -1.45721436e-01],
                        [ -1.20758057e-01,  -1.20758057e-01],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -7.53173828e-02,  -7.53173828e-02],
                        [ -5.58471680e-02,  -5.58471680e-02],
                        [ -4.37316895e-02,  -4.37316895e-02],
                        [ -3.84216309e-02,  -3.84216309e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  4.38537598e-02,   4.38537598e-02],
                        [  5.77392578e-02,   5.77392578e-02],
                        [  7.29675293e-02,   7.29675293e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  3.76281738e-02,   3.76281738e-02],
                        [ -3.98864746e-02,  -3.98864746e-02],
                        [ -1.20208740e-01,  -1.20208740e-01],
                        [ -1.70471191e-01,  -1.70471191e-01],
                        [ -1.73126221e-01,  -1.73126221e-01],
                        [ -1.40808105e-01,  -1.40808105e-01],
                        [ -1.00738525e-01,  -1.00738525e-01],
                        [ -7.13806152e-02,  -7.13806152e-02],
                        [ -5.51147461e-02,  -5.51147461e-02],
                        [ -4.58374023e-02,  -4.58374023e-02],
                        [ -3.69873047e-02,  -3.69873047e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -4.57153320e-02,  -4.57153320e-02],
                        [ -5.26733398e-02,  -5.26733398e-02],
                        [ -4.34875488e-02,  -4.34875488e-02],
                        [ -2.28881836e-02,  -2.28881836e-02],
                        [  3.60107422e-03,   3.60107422e-03],
                        [  3.69567871e-02,   3.69567871e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  1.22436523e-01,   1.22436523e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  1.84753418e-01,   1.84753418e-01],
                        [  1.91375732e-01,   1.91375732e-01],
                        [  1.77490234e-01,   1.77490234e-01],
                        [  1.48590088e-01,   1.48590088e-01],
                        [  1.20025635e-01,   1.20025635e-01],
                        [  1.04736328e-01,   1.04736328e-01],
                        [  1.02355957e-01,   1.02355957e-01],
                        [  1.05407715e-01,   1.05407715e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  1.10870361e-01,   1.10870361e-01],
                        [  1.06506348e-01,   1.06506348e-01],
                        [  9.39636230e-02,   9.39636230e-02],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  5.39550781e-02,   5.39550781e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  2.66418457e-02,   2.66418457e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  4.39453125e-03,   4.39453125e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.94702148e-02,  -1.94702148e-02],
                        [ -3.96423340e-02,  -3.96423340e-02],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [ -6.00280762e-02,  -6.00280762e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -6.53076172e-03,  -6.53076172e-03],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  7.68127441e-02,   7.68127441e-02],
                        [  1.04156494e-01,   1.04156494e-01],
                        [  1.06048584e-01,   1.06048584e-01],
                        [  8.59375000e-02,   8.59375000e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  4.87060547e-02,   4.87060547e-02],
                        [  4.68750000e-02,   4.68750000e-02],
                        [  4.69665527e-02,   4.69665527e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  3.38745117e-03,   3.38745117e-03],
                        [  4.88281250e-04,   4.88281250e-04],
                        [ -3.93676758e-03,  -3.93676758e-03],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -2.34680176e-02,  -2.34680176e-02],
                        [ -3.39050293e-02,  -3.39050293e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -3.64074707e-02,  -3.64074707e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.70690918e-02,  -2.70690918e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -3.48205566e-02,  -3.48205566e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -4.45251465e-02,  -4.45251465e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.04260254e-02,  -3.04260254e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -1.95617676e-02,  -1.95617676e-02],
                        [ -1.93786621e-02,  -1.93786621e-02],
                        [ -1.43127441e-02,  -1.43127441e-02],
                        [  1.43432617e-03,   1.43432617e-03],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  5.22155762e-02,   5.22155762e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  6.64367676e-02,   6.64367676e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [ -2.03247070e-02,  -2.03247070e-02],
                        [ -1.03454590e-01,  -1.03454590e-01],
                        [ -1.93969727e-01,  -1.93969727e-01],
                        [ -2.63977051e-01,  -2.63977051e-01],
                        [ -2.88238525e-01,  -2.88238525e-01],
                        [ -2.62298584e-01,  -2.62298584e-01],
                        [ -2.06878662e-01,  -2.06878662e-01],
                        [ -1.52465820e-01,  -1.52465820e-01],
                        [ -1.17736816e-01,  -1.17736816e-01],
                        [ -1.00250244e-01,  -1.00250244e-01],
                        [ -8.78295898e-02,  -8.78295898e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -6.77490234e-02,  -6.77490234e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -5.59692383e-02,  -5.59692383e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  4.17480469e-02,   4.17480469e-02],
                        [  4.69055176e-02,   4.69055176e-02],
                        [  4.39453125e-02,   4.39453125e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  1.00158691e-01,   1.00158691e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  1.09069824e-01,   1.09069824e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  5.51452637e-02,   5.51452637e-02],
                        [ -1.05590820e-02,  -1.05590820e-02],
                        [ -8.65173340e-02,  -8.65173340e-02],
                        [ -1.46240234e-01,  -1.46240234e-01],
                        [ -1.69006348e-01,  -1.69006348e-01],
                        [ -1.52252197e-01,  -1.52252197e-01],
                        [ -1.11297607e-01,  -1.11297607e-01],
                        [ -6.91833496e-02,  -6.91833496e-02],
                        [ -4.46777344e-02,  -4.46777344e-02],
                        [ -4.26635742e-02,  -4.26635742e-02],
                        [ -5.23376465e-02,  -5.23376465e-02],
                        [ -5.77392578e-02,  -5.77392578e-02],
                        [ -5.35583496e-02,  -5.35583496e-02],
                        [ -4.77600098e-02,  -4.77600098e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  2.27050781e-02,   2.27050781e-02],
                        [  5.57250977e-02,   5.57250977e-02],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  1.43737793e-01,   1.43737793e-01],
                        [  1.72912598e-01,   1.72912598e-01],
                        [  1.76605225e-01,   1.76605225e-01],
                        [  1.58782959e-01,   1.58782959e-01],
                        [  1.32629395e-01,   1.32629395e-01],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  9.72595215e-02,   9.72595215e-02],
                        [  9.22851562e-02,   9.22851562e-02],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  1.15753174e-01,   1.15753174e-01],
                        [  1.24328613e-01,   1.24328613e-01],
                        [  1.24938965e-01,   1.24938965e-01],
                        [  1.15875244e-01,   1.15875244e-01],
                        [  9.75646973e-02,   9.75646973e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  5.23681641e-02,   5.23681641e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  5.92041016e-03,   5.92041016e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -9.64355469e-03,  -9.64355469e-03],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -4.28771973e-02,  -4.28771973e-02],
                        [ -4.30603027e-02,  -4.30603027e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.17382812e-03,  -3.17382812e-03],
                        [  3.36303711e-02,   3.36303711e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  1.03515625e-01,   1.03515625e-01],
                        [  1.15722656e-01,   1.15722656e-01],
                        [  1.05072021e-01,   1.05072021e-01],
                        [  8.13903809e-02,   8.13903809e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  4.25415039e-02,   4.25415039e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [  6.31713867e-03,   6.31713867e-03],
                        [  2.22778320e-03,   2.22778320e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -3.02124023e-03,  -3.02124023e-03],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -3.64685059e-02,  -3.64685059e-02],
                        [ -3.24401855e-02,  -3.24401855e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.34777832e-02,  -3.34777832e-02],
                        [ -3.28369141e-02,  -3.28369141e-02],
                        [ -3.08837891e-02,  -3.08837891e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -3.90319824e-02,  -3.90319824e-02],
                        [ -3.62243652e-02,  -3.62243652e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -1.80358887e-02,  -1.80358887e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  2.56958008e-02,   2.56958008e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  4.66003418e-02,   4.66003418e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  1.01623535e-02,   1.01623535e-02],
                        [ -5.04455566e-02,  -5.04455566e-02],
                        [ -1.35162354e-01,  -1.35162354e-01],
                        [ -2.19726562e-01,  -2.19726562e-01],
                        [ -2.73712158e-01,  -2.73712158e-01],
                        [ -2.78503418e-01,  -2.78503418e-01],
                        [ -2.39807129e-01,  -2.39807129e-01],
                        [ -1.82006836e-01,  -1.82006836e-01],
                        [ -1.30371094e-01,  -1.30371094e-01],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -8.64257812e-02,  -8.64257812e-02],
                        [ -8.49609375e-02,  -8.49609375e-02],
                        [ -8.42895508e-02,  -8.42895508e-02],
                        [ -7.96813965e-02,  -7.96813965e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -2.51464844e-02,  -2.51464844e-02],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  5.91430664e-02,   5.91430664e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  1.14501953e-01,   1.14501953e-01],
                        [  1.24328613e-01,   1.24328613e-01],
                        [  1.23687744e-01,   1.23687744e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  4.32434082e-02,   4.32434082e-02],
                        [ -4.65698242e-02,  -4.65698242e-02],
                        [ -1.38275146e-01,  -1.38275146e-01],
                        [ -1.91650391e-01,  -1.91650391e-01],
                        [ -1.88201904e-01,  -1.88201904e-01],
                        [ -1.42761230e-01,  -1.42761230e-01],
                        [ -8.72192383e-02,  -8.72192383e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -2.78320312e-02,  -2.78320312e-02],
                        [ -2.98767090e-02,  -2.98767090e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -4.29687500e-02,  -4.29687500e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -7.57141113e-02,  -7.57141113e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  6.35070801e-02,   6.35070801e-02],
                        [  1.24206543e-01,   1.24206543e-01],
                        [  1.77062988e-01,   1.77062988e-01],
                        [  2.07794189e-01,   2.07794189e-01],
                        [  2.06573486e-01,   2.06573486e-01],
                        [  1.77917480e-01,   1.77917480e-01],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  6.80236816e-02,   6.80236816e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  9.47875977e-02,   9.47875977e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.21826172e-01,   1.21826172e-01],
                        [  1.22344971e-01,   1.22344971e-01],
                        [  1.15539551e-01,   1.15539551e-01],
                        [  9.88464355e-02,   9.88464355e-02],
                        [  7.28759766e-02,   7.28759766e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -3.54003906e-02,  -3.54003906e-02],
                        [ -6.36901855e-02,  -6.36901855e-02],
                        [ -7.68737793e-02,  -7.68737793e-02],
                        [ -7.31811523e-02,  -7.31811523e-02],
                        [ -5.40161133e-02,  -5.40161133e-02],
                        [ -1.58996582e-02,  -1.58996582e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  8.66699219e-02,   8.66699219e-02],
                        [  1.15539551e-01,   1.15539551e-01],
                        [  1.18804932e-01,   1.18804932e-01],
                        [  1.01501465e-01,   1.01501465e-01],
                        [  7.42797852e-02,   7.42797852e-02],
                        [  4.86755371e-02,   4.86755371e-02],
                        [  2.99377441e-02,   2.99377441e-02],
                        [  1.79748535e-02,   1.79748535e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  1.51672363e-02,   1.51672363e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  3.96728516e-03,   3.96728516e-03],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -1.73339844e-02,  -1.73339844e-02],
                        [ -2.70996094e-02,  -2.70996094e-02],
                        [ -3.02734375e-02,  -3.02734375e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.12402344e-02,  -2.12402344e-02],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.37939453e-02,  -1.37939453e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -2.41699219e-02,  -2.41699219e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.81677246e-02,  -2.81677246e-02],
                        [ -2.16674805e-02,  -2.16674805e-02],
                        [ -1.21765137e-02,  -1.21765137e-02],
                        [  8.85009766e-04,   8.85009766e-04],
                        [  1.85546875e-02,   1.85546875e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  4.82788086e-02,   4.82788086e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  8.33129883e-03,   8.33129883e-03],
                        [ -4.92553711e-02,  -4.92553711e-02],
                        [ -1.25213623e-01,  -1.25213623e-01],
                        [ -2.01629639e-01,  -2.01629639e-01],
                        [ -2.53570557e-01,  -2.53570557e-01],
                        [ -2.63610840e-01,  -2.63610840e-01],
                        [ -2.35595703e-01,  -2.35595703e-01],
                        [ -1.91741943e-01,  -1.91741943e-01],
                        [ -1.53259277e-01,  -1.53259277e-01],
                        [ -1.25488281e-01,  -1.25488281e-01],
                        [ -1.03027344e-01,  -1.03027344e-01],
                        [ -8.30078125e-02,  -8.30078125e-02],
                        [ -6.72912598e-02,  -6.72912598e-02],
                        [ -5.76171875e-02,  -5.76171875e-02],
                        [ -5.33752441e-02,  -5.33752441e-02],
                        [ -5.12390137e-02,  -5.12390137e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  3.12194824e-02,   3.12194824e-02],
                        [  4.45861816e-02,   4.45861816e-02],
                        [  5.69152832e-02,   5.69152832e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  1.25091553e-01,   1.25091553e-01],
                        [  1.33636475e-01,   1.33636475e-01],
                        [  1.19781494e-01,   1.19781494e-01],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  3.72314453e-03,   3.72314453e-03],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -1.45599365e-01,  -1.45599365e-01],
                        [ -1.74468994e-01,  -1.74468994e-01],
                        [ -1.60766602e-01,  -1.60766602e-01],
                        [ -1.22650146e-01,  -1.22650146e-01],
                        [ -8.61816406e-02,  -8.61816406e-02],
                        [ -6.57958984e-02,  -6.57958984e-02],
                        [ -5.81970215e-02,  -5.81970215e-02],
                        [ -5.28869629e-02,  -5.28869629e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.30297852e-02,  -4.30297852e-02],
                        [ -2.36816406e-02,  -2.36816406e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  6.34460449e-02,   6.34460449e-02],
                        [  1.15081787e-01,   1.15081787e-01],
                        [  1.58508301e-01,   1.58508301e-01],
                        [  1.84417725e-01,   1.84417725e-01],
                        [  1.88781738e-01,   1.88781738e-01],
                        [  1.74652100e-01,   1.74652100e-01],
                        [  1.49505615e-01,   1.49505615e-01],
                        [  1.21337891e-01,   1.21337891e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  8.05358887e-02,   8.05358887e-02],
                        [  7.38830566e-02,   7.38830566e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  8.20007324e-02,   8.20007324e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  9.97009277e-02,   9.97009277e-02],
                        [  9.08813477e-02,   9.08813477e-02],
                        [  7.67517090e-02,   7.67517090e-02],
                        [  6.19506836e-02,   6.19506836e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  3.22570801e-02,   3.22570801e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.37329102e-02,   1.37329102e-02],
                        [  5.12695312e-03,   5.12695312e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -3.63159180e-02,  -3.63159180e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.43823242e-02,  -5.43823242e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [  2.83813477e-03,   2.83813477e-03],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  8.50219727e-02,   8.50219727e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  7.98950195e-02,   7.98950195e-02],
                        [  5.94482422e-02,   5.94482422e-02],
                        [  4.95300293e-02,   4.95300293e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  5.55419922e-02,   5.55419922e-02],
                        [  5.05981445e-02,   5.05981445e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  2.74658203e-02,   2.74658203e-02],
                        [  1.82495117e-02,   1.82495117e-02],
                        [  8.08715820e-03,   8.08715820e-03],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -3.16772461e-02,  -3.16772461e-02],
                        [ -4.04357910e-02,  -4.04357910e-02],
                        [ -3.98559570e-02,  -3.98559570e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -1.69067383e-02,  -1.69067383e-02],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.15661621e-02,  -1.15661621e-02],
                        [ -2.23693848e-02,  -2.23693848e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -3.44848633e-02,  -3.44848633e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [ -4.85534668e-02,  -4.85534668e-02],
                        [ -4.98962402e-02,  -4.98962402e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -1.03759766e-02,  -1.03759766e-02],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  3.95202637e-02,   3.95202637e-02],
                        [  4.72412109e-02,   4.72412109e-02],
                        [  4.40063477e-02,   4.40063477e-02],
                        [  2.28576660e-02,   2.28576660e-02],
                        [ -2.22167969e-02,  -2.22167969e-02],
                        [ -8.95996094e-02,  -8.95996094e-02],
                        [ -1.64947510e-01,  -1.64947510e-01],
                        [ -2.23785400e-01,  -2.23785400e-01],
                        [ -2.46093750e-01,  -2.46093750e-01],
                        [ -2.31170654e-01,  -2.31170654e-01],
                        [ -1.96105957e-01,  -1.96105957e-01],
                        [ -1.60583496e-01,  -1.60583496e-01],
                        [ -1.34307861e-01,  -1.34307861e-01],
                        [ -1.15234375e-01,  -1.15234375e-01],
                        [ -9.75952148e-02,  -9.75952148e-02],
                        [ -7.96203613e-02,  -7.96203613e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.21240234e-02,  -5.21240234e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  2.33459473e-02,   2.33459473e-02],
                        [  3.09448242e-02,   3.09448242e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  6.89697266e-02,   6.89697266e-02],
                        [  8.97216797e-02,   8.97216797e-02],
                        [  9.98840332e-02,   9.98840332e-02],
                        [  1.02203369e-01,   1.02203369e-01],
                        [  1.07330322e-01,   1.07330322e-01],
                        [  1.17279053e-01,   1.17279053e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  8.68530273e-02,   8.68530273e-02],
                        [  1.99890137e-02,   1.99890137e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -1.51702881e-01,  -1.51702881e-01],
                        [ -1.95465088e-01,  -1.95465088e-01],
                        [ -1.86798096e-01,  -1.86798096e-01],
                        [ -1.41906738e-01,  -1.41906738e-01],
                        [ -9.25598145e-02,  -9.25598145e-02],
                        [ -5.86853027e-02,  -5.86853027e-02],
                        [ -4.09851074e-02,  -4.09851074e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -3.61022949e-02,  -3.61022949e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -5.56640625e-02,  -5.56640625e-02],
                        [ -5.82275391e-02,  -5.82275391e-02],
                        [ -4.31518555e-02,  -4.31518555e-02],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  1.09680176e-01,   1.09680176e-01],
                        [  1.55670166e-01,   1.55670166e-01],
                        [  1.77368164e-01,   1.77368164e-01],
                        [  1.74591064e-01,   1.74591064e-01],
                        [  1.55944824e-01,   1.55944824e-01],
                        [  1.31988525e-01,   1.31988525e-01],
                        [  1.11511230e-01,   1.11511230e-01],
                        [  1.01654053e-01,   1.01654053e-01],
                        [  1.04370117e-01,   1.04370117e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.16333008e-01,   1.16333008e-01],
                        [  1.02783203e-01,   1.02783203e-01],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  4.81567383e-02,   4.81567383e-02],
                        [  4.48608398e-02,   4.48608398e-02],
                        [  4.92248535e-02,   4.92248535e-02],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  5.53894043e-02,   5.53894043e-02],
                        [  4.73632812e-02,   4.73632812e-02],
                        [  3.32336426e-02,   3.32336426e-02],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -4.63867188e-02,  -4.63867188e-02],
                        [ -6.18286133e-02,  -6.18286133e-02],
                        [ -6.75964355e-02,  -6.75964355e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -2.36511230e-02,  -2.36511230e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  1.28601074e-01,   1.28601074e-01],
                        [  1.28479004e-01,   1.28479004e-01],
                        [  1.00952148e-01,   1.00952148e-01],
                        [  6.81152344e-02,   6.81152344e-02],
                        [  4.42810059e-02,   4.42810059e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  1.59606934e-02,   1.59606934e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -4.48608398e-03,  -4.48608398e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.66931152e-02,  -1.66931152e-02],
                        [ -2.51770020e-02,  -2.51770020e-02],
                        [ -3.41796875e-02,  -3.41796875e-02],
                        [ -4.10461426e-02,  -4.10461426e-02],
                        [ -4.22363281e-02,  -4.22363281e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.52172852e-02,  -3.52172852e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.72924805e-02,  -3.72924805e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.11987305e-02,  -4.11987305e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.72216797e-02,  -2.72216797e-02],
                        [ -1.67846680e-02,  -1.67846680e-02],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  2.52075195e-02,   2.52075195e-02],
                        [  4.71191406e-02,   4.71191406e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  4.58374023e-02,   4.58374023e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [ -4.47998047e-02,  -4.47998047e-02],
                        [ -1.18072510e-01,  -1.18072510e-01],
                        [ -1.93237305e-01,  -1.93237305e-01],
                        [ -2.47528076e-01,  -2.47528076e-01],
                        [ -2.64404297e-01,  -2.64404297e-01],
                        [ -2.46368408e-01,  -2.46368408e-01],
                        [ -2.11303711e-01,  -2.11303711e-01],
                        [ -1.75567627e-01,  -1.75567627e-01],
                        [ -1.43890381e-01,  -1.43890381e-01],
                        [ -1.15509033e-01,  -1.15509033e-01],
                        [ -9.27734375e-02,  -9.27734375e-02],
                        [ -7.81860352e-02,  -7.81860352e-02],
                        [ -6.83593750e-02,  -6.83593750e-02],
                        [ -5.77087402e-02,  -5.77087402e-02],
                        [ -4.55017090e-02,  -4.55017090e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [  1.38854980e-02,   1.38854980e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  3.90014648e-02,   3.90014648e-02],
                        [  4.80346680e-02,   4.80346680e-02],
                        [  6.06079102e-02,   6.06079102e-02],
                        [  7.89184570e-02,   7.89184570e-02],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  1.21398926e-01,   1.21398926e-01],
                        [  1.28570557e-01,   1.28570557e-01],
                        [  1.15600586e-01,   1.15600586e-01],
                        [  7.60803223e-02,   7.60803223e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -7.58666992e-02,  -7.58666992e-02],
                        [ -1.50543213e-01,  -1.50543213e-01],
                        [ -1.87530518e-01,  -1.87530518e-01],
                        [ -1.76513672e-01,  -1.76513672e-01],
                        [ -1.32873535e-01,  -1.32873535e-01],
                        [ -8.56628418e-02,  -8.56628418e-02],
                        [ -5.71594238e-02,  -5.71594238e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -5.60302734e-02,  -5.60302734e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -6.49414062e-02,  -6.49414062e-02],
                        [ -6.68029785e-02,  -6.68029785e-02],
                        [ -6.04553223e-02,  -6.04553223e-02],
                        [ -3.31115723e-02,  -3.31115723e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  1.44561768e-01,   1.44561768e-01],
                        [  1.81274414e-01,   1.81274414e-01],
                        [  1.90948486e-01,   1.90948486e-01],
                        [  1.78527832e-01,   1.78527832e-01],
                        [  1.56005859e-01,   1.56005859e-01],
                        [  1.34216309e-01,   1.34216309e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  9.95178223e-02,   9.95178223e-02],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  7.91320801e-02,   7.91320801e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  8.62731934e-02,   8.62731934e-02],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  8.96911621e-02,   8.96911621e-02],
                        [  8.56628418e-02,   8.56628418e-02],
                        [  7.85217285e-02,   7.85217285e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  4.07409668e-02,   4.07409668e-02],
                        [  3.58886719e-02,   3.58886719e-02],
                        [  3.19213867e-02,   3.19213867e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  1.10168457e-02,   1.10168457e-02],
                        [  7.93457031e-04,   7.93457031e-04],
                        [ -1.75170898e-02,  -1.75170898e-02],
                        [ -3.77197266e-02,  -3.77197266e-02],
                        [ -4.95910645e-02,  -4.95910645e-02],
                        [ -4.69360352e-02,  -4.69360352e-02],
                        [ -2.60009766e-02,  -2.60009766e-02],
                        [  1.44348145e-02,   1.44348145e-02],
                        [  6.57043457e-02,   6.57043457e-02],
                        [  1.07452393e-01,   1.07452393e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.02508545e-01,   1.02508545e-01],
                        [  7.12585449e-02,   7.12585449e-02],
                        [  4.76684570e-02,   4.76684570e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  1.50451660e-02,   1.50451660e-02],
                        [  1.13830566e-02,   1.13830566e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [ -1.85852051e-02,  -1.85852051e-02],
                        [ -2.66113281e-02,  -2.66113281e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -3.29589844e-02,  -3.29589844e-02],
                        [ -3.67126465e-02,  -3.67126465e-02],
                        [ -3.82080078e-02,  -3.82080078e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -1.09558105e-02,  -1.09558105e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -4.32739258e-02,  -4.32739258e-02],
                        [ -4.12597656e-02,  -4.12597656e-02],
                        [ -2.90832520e-02,  -2.90832520e-02],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  5.02929688e-02,   5.02929688e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  7.22351074e-02,   7.22351074e-02],
                        [  5.34973145e-02,   5.34973145e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [ -7.08923340e-02,  -7.08923340e-02],
                        [ -1.61224365e-01,  -1.61224365e-01],
                        [ -2.37976074e-01,  -2.37976074e-01],
                        [ -2.76306152e-01,  -2.76306152e-01],
                        [ -2.67730713e-01,  -2.67730713e-01],
                        [ -2.24487305e-01,  -2.24487305e-01],
                        [ -1.70806885e-01,  -1.70806885e-01],
                        [ -1.27868652e-01,  -1.27868652e-01],
                        [ -1.04187012e-01,  -1.04187012e-01],
                        [ -9.59167480e-02,  -9.59167480e-02],
                        [ -9.14916992e-02,  -9.14916992e-02],
                        [ -7.98034668e-02,  -7.98034668e-02],
                        [ -5.98144531e-02,  -5.98144531e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -2.60314941e-02,  -2.60314941e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [  5.18798828e-03,   5.18798828e-03],
                        [  2.40173340e-02,   2.40173340e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  6.77490234e-02,   6.77490234e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  1.01440430e-01,   1.01440430e-01],
                        [  1.20422363e-01,   1.20422363e-01],
                        [  1.24237061e-01,   1.24237061e-01],
                        [  9.74121094e-02,   9.74121094e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [ -4.91943359e-02,  -4.91943359e-02],
                        [ -1.24328613e-01,  -1.24328613e-01],
                        [ -1.63421631e-01,  -1.63421631e-01],
                        [ -1.59027100e-01,  -1.59027100e-01],
                        [ -1.26708984e-01,  -1.26708984e-01],
                        [ -9.27124023e-02,  -9.27124023e-02],
                        [ -7.40051270e-02,  -7.40051270e-02],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -6.81762695e-02,  -6.81762695e-02],
                        [ -6.51550293e-02,  -6.51550293e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -5.33142090e-02,  -5.33142090e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [  8.23974609e-03,   8.23974609e-03],
                        [  6.33544922e-02,   6.33544922e-02],
                        [  1.18164062e-01,   1.18164062e-01],
                        [  1.58752441e-01,   1.58752441e-01],
                        [  1.78100586e-01,   1.78100586e-01],
                        [  1.77764893e-01,   1.77764893e-01],
                        [  1.64794922e-01,   1.64794922e-01],
                        [  1.46667480e-01,   1.46667480e-01],
                        [  1.27593994e-01,   1.27593994e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  8.09326172e-02,   8.09326172e-02],
                        [  7.72094727e-02,   7.72094727e-02],
                        [  7.87353516e-02,   7.87353516e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  7.65686035e-02,   7.65686035e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  5.22766113e-02,   5.22766113e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  3.73840332e-02,   3.73840332e-02],
                        [  3.65600586e-02,   3.65600586e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  2.39257812e-02,   2.39257812e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [ -5.40466309e-02,  -5.40466309e-02],
                        [ -3.51867676e-02,  -3.51867676e-02],
                        [ -3.99780273e-03,  -3.99780273e-03],
                        [  3.09753418e-02,   3.09753418e-02],
                        [  6.54602051e-02,   6.54602051e-02],
                        [  9.28039551e-02,   9.28039551e-02],
                        [  1.00799561e-01,   1.00799561e-01],
                        [  8.21838379e-02,   8.21838379e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  2.07519531e-02,   2.07519531e-02],
                        [  2.75878906e-02,   2.75878906e-02],
                        [  3.24401855e-02,   3.24401855e-02],
                        [  3.61938477e-02,   3.61938477e-02],
                        [  3.56750488e-02,   3.56750488e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -9.97924805e-03,  -9.97924805e-03],
                        [ -2.79235840e-02,  -2.79235840e-02],
                        [ -3.85742188e-02,  -3.85742188e-02],
                        [ -4.02832031e-02,  -4.02832031e-02],
                        [ -3.67431641e-02,  -3.67431641e-02],
                        [ -3.33251953e-02,  -3.33251953e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -2.82592773e-02,  -2.82592773e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.14233398e-02,  -2.14233398e-02],
                        [ -2.57568359e-02,  -2.57568359e-02],
                        [ -3.46374512e-02,  -3.46374512e-02],
                        [ -4.43725586e-02,  -4.43725586e-02],
                        [ -5.08728027e-02,  -5.08728027e-02],
                        [ -4.97436523e-02,  -4.97436523e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  1.22375488e-02,   1.22375488e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  5.05371094e-02,   5.05371094e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  1.14440918e-02,   1.14440918e-02],
                        [ -4.42810059e-02,  -4.42810059e-02],
                        [ -1.14318848e-01,  -1.14318848e-01],
                        [ -1.86889648e-01,  -1.86889648e-01],
                        [ -2.42004395e-01,  -2.42004395e-01],
                        [ -2.61322021e-01,  -2.61322021e-01],
                        [ -2.43225098e-01,  -2.43225098e-01],
                        [ -2.03094482e-01,  -2.03094482e-01],
                        [ -1.60614014e-01,  -1.60614014e-01],
                        [ -1.28173828e-01,  -1.28173828e-01],
                        [ -1.07421875e-01,  -1.07421875e-01],
                        [ -9.32922363e-02,  -9.32922363e-02],
                        [ -8.06579590e-02,  -8.06579590e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -5.45043945e-02,  -5.45043945e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [ -2.51159668e-02,  -2.51159668e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  1.88598633e-02,   1.88598633e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  3.60412598e-02,   3.60412598e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  6.59790039e-02,   6.59790039e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  1.32690430e-01,   1.32690430e-01],
                        [  1.28845215e-01,   1.28845215e-01],
                        [  8.89892578e-02,   8.89892578e-02],
                        [  1.46789551e-02,   1.46789551e-02],
                        [ -7.67822266e-02,  -7.67822266e-02],
                        [ -1.54205322e-01,  -1.54205322e-01],
                        [ -1.88354492e-01,  -1.88354492e-01],
                        [ -1.73614502e-01,  -1.73614502e-01],
                        [ -1.31530762e-01,  -1.31530762e-01],
                        [ -9.09118652e-02,  -9.09118652e-02],
                        [ -6.63452148e-02,  -6.63452148e-02],
                        [ -5.54504395e-02,  -5.54504395e-02],
                        [ -4.99877930e-02,  -4.99877930e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [  2.32849121e-02,   2.32849121e-02],
                        [  6.81762695e-02,   6.81762695e-02],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.61376953e-01,   1.61376953e-01],
                        [  1.50421143e-01,   1.50421143e-01],
                        [  1.28295898e-01,   1.28295898e-01],
                        [  1.11206055e-01,   1.11206055e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  1.08886719e-01,   1.08886719e-01],
                        [  1.08367920e-01,   1.08367920e-01],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  8.27941895e-02,   8.27941895e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  6.60400391e-02,   6.60400391e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  5.71899414e-02,   5.71899414e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  4.86450195e-02,   4.86450195e-02],
                        [  4.83703613e-02,   4.83703613e-02],
                        [  4.95910645e-02,   4.95910645e-02],
                        [  4.69970703e-02,   4.69970703e-02],
                        [  3.83605957e-02,   3.83605957e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  3.78417969e-03,   3.78417969e-03],
                        [ -1.29394531e-02,  -1.29394531e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [  4.66918945e-03,   4.66918945e-03],
                        [  3.35998535e-02,   3.35998535e-02],
                        [  6.50634766e-02,   6.50634766e-02],
                        [  8.71276855e-02,   8.71276855e-02],
                        [  9.06982422e-02,   9.06982422e-02],
                        [  7.73925781e-02,   7.73925781e-02],
                        [  5.66711426e-02,   5.66711426e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.78320312e-02,   2.78320312e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  6.68334961e-03,   6.68334961e-03],
                        [ -3.90625000e-03,  -3.90625000e-03],
                        [ -1.41296387e-02,  -1.41296387e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -2.04162598e-02,  -2.04162598e-02],
                        [ -1.96838379e-02,  -1.96838379e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -3.82385254e-02,  -3.82385254e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -2.36206055e-02,  -2.36206055e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [ -3.17993164e-02,  -3.17993164e-02],
                        [ -2.71606445e-02,  -2.71606445e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  6.95800781e-02,   6.95800781e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  4.57458496e-02,   4.57458496e-02],
                        [ -1.40686035e-02,  -1.40686035e-02],
                        [ -9.82360840e-02,  -9.82360840e-02],
                        [ -1.85974121e-01,  -1.85974121e-01],
                        [ -2.53387451e-01,  -2.53387451e-01],
                        [ -2.81433105e-01,  -2.81433105e-01],
                        [ -2.63183594e-01,  -2.63183594e-01],
                        [ -2.11761475e-01,  -2.11761475e-01],
                        [ -1.56799316e-01,  -1.56799316e-01],
                        [ -1.23077393e-01,  -1.23077393e-01],
                        [ -1.10717773e-01,  -1.10717773e-01],
                        [ -1.02294922e-01,  -1.02294922e-01],
                        [ -8.71276855e-02,  -8.71276855e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -5.75866699e-02,  -5.75866699e-02],
                        [ -4.85229492e-02,  -4.85229492e-02],
                        [ -3.73840332e-02,  -3.73840332e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -4.66918945e-03,  -4.66918945e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  2.26135254e-02,   2.26135254e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  5.88989258e-02,   5.88989258e-02],
                        [  5.70983887e-02,   5.70983887e-02],
                        [  6.06384277e-02,   6.06384277e-02],
                        [  7.35778809e-02,   7.35778809e-02],
                        [  9.27429199e-02,   9.27429199e-02],
                        [  1.11022949e-01,   1.11022949e-01],
                        [  1.17797852e-01,   1.17797852e-01],
                        [  9.97314453e-02,   9.97314453e-02],
                        [  4.87670898e-02,   4.87670898e-02],
                        [ -2.74963379e-02,  -2.74963379e-02],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -1.56433105e-01,  -1.56433105e-01],
                        [ -1.67022705e-01,  -1.67022705e-01],
                        [ -1.45904541e-01,  -1.45904541e-01],
                        [ -1.17095947e-01,  -1.17095947e-01],
                        [ -1.01013184e-01,  -1.01013184e-01],
                        [ -9.94567871e-02,  -9.94567871e-02],
                        [ -9.76867676e-02,  -9.76867676e-02],
                        [ -8.11767578e-02,  -8.11767578e-02],
                        [ -4.72106934e-02,  -4.72106934e-02],
                        [ -6.10351562e-04,  -6.10351562e-04],
                        [  5.33142090e-02,   5.33142090e-02],
                        [  1.06781006e-01,   1.06781006e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.60614014e-01,   1.60614014e-01],
                        [  1.51977539e-01,   1.51977539e-01],
                        [  1.35742188e-01,   1.35742188e-01],
                        [  1.23901367e-01,   1.23901367e-01],
                        [  1.16302490e-01,   1.16302490e-01],
                        [  1.07666016e-01,   1.07666016e-01],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  8.21533203e-02,   8.21533203e-02],
                        [  7.01904297e-02,   7.01904297e-02],
                        [  6.43310547e-02,   6.43310547e-02],
                        [  6.55212402e-02,   6.55212402e-02],
                        [  7.00683594e-02,   7.00683594e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  7.49816895e-02,   7.49816895e-02],
                        [  7.17468262e-02,   7.17468262e-02],
                        [  6.19812012e-02,   6.19812012e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.22668457e-02,   4.22668457e-02],
                        [  4.55322266e-02,   4.55322266e-02],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  5.15136719e-02,   5.15136719e-02],
                        [  4.21752930e-02,   4.21752930e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  6.53076172e-03,   6.53076172e-03],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -3.30200195e-02,  -3.30200195e-02],
                        [ -4.60510254e-02,  -4.60510254e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -3.42712402e-02,  -3.42712402e-02],
                        [ -1.98364258e-03,  -1.98364258e-03],
                        [  4.02526855e-02,   4.02526855e-02],
                        [  7.62329102e-02,   7.62329102e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  8.32519531e-02,   8.32519531e-02],
                        [  5.89599609e-02,   5.89599609e-02],
                        [  3.52172852e-02,   3.52172852e-02],
                        [  2.47802734e-02,   2.47802734e-02],
                        [  2.78625488e-02,   2.78625488e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  3.64685059e-02,   3.64685059e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  6.77490234e-03,   6.77490234e-03],
                        [ -6.22558594e-03,  -6.22558594e-03],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.21655273e-02,  -3.21655273e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.26342773e-02,  -1.26342773e-02],
                        [ -1.55334473e-02,  -1.55334473e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -2.99377441e-02,  -2.99377441e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -4.61730957e-02,  -4.61730957e-02],
                        [ -5.04150391e-02,  -5.04150391e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -3.58581543e-02,  -3.58581543e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  2.07519531e-03,   2.07519531e-03],
                        [  2.19726562e-02,   2.19726562e-02],
                        [  4.24804688e-02,   4.24804688e-02],
                        [  5.87158203e-02,   5.87158203e-02],
                        [  6.73828125e-02,   6.73828125e-02],
                        [  6.21337891e-02,   6.21337891e-02],
                        [  3.29284668e-02,   3.29284668e-02],
                        [ -2.71301270e-02,  -2.71301270e-02],
                        [ -1.13250732e-01,  -1.13250732e-01],
                        [ -2.05352783e-01,  -2.05352783e-01],
                        [ -2.73803711e-01,  -2.73803711e-01],
                        [ -2.94769287e-01,  -2.94769287e-01],
                        [ -2.65289307e-01,  -2.65289307e-01],
                        [ -2.06481934e-01,  -2.06481934e-01],
                        [ -1.49993896e-01,  -1.49993896e-01],
                        [ -1.16699219e-01,  -1.16699219e-01],
                        [ -1.04919434e-01,  -1.04919434e-01],
                        [ -9.86022949e-02,  -9.86022949e-02],
                        [ -8.66088867e-02,  -8.66088867e-02],
                        [ -7.12585449e-02,  -7.12585449e-02],
                        [ -5.85327148e-02,  -5.85327148e-02],
                        [ -4.73937988e-02,  -4.73937988e-02],
                        [ -3.36303711e-02,  -3.36303711e-02],
                        [ -1.74865723e-02,  -1.74865723e-02],
                        [ -2.25830078e-03,  -2.25830078e-03],
                        [  1.05895996e-02,   1.05895996e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  3.01513672e-02,   3.01513672e-02],
                        [  3.68652344e-02,   3.68652344e-02],
                        [  4.02832031e-02,   4.02832031e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  5.59082031e-02,   5.59082031e-02],
                        [  7.82165527e-02,   7.82165527e-02],
                        [  1.06262207e-01,   1.06262207e-01],
                        [  1.32049561e-01,   1.32049561e-01],
                        [  1.44775391e-01,   1.44775391e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  7.32116699e-02,   7.32116699e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.12609863e-01,  -1.12609863e-01],
                        [ -1.81793213e-01,  -1.81793213e-01],
                        [ -2.03491211e-01,  -2.03491211e-01],
                        [ -1.81640625e-01,  -1.81640625e-01],
                        [ -1.40258789e-01,  -1.40258789e-01],
                        [ -1.05499268e-01,  -1.05499268e-01],
                        [ -8.67309570e-02,  -8.67309570e-02],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -4.65087891e-02,  -4.65087891e-02],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [  5.04760742e-02,   5.04760742e-02],
                        [  9.84497070e-02,   9.84497070e-02],
                        [  1.28692627e-01,   1.28692627e-01],
                        [  1.36688232e-01,   1.36688232e-01],
                        [  1.29119873e-01,   1.29119873e-01],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.05255127e-01,   1.05255127e-01],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  8.23669434e-02,   8.23669434e-02],
                        [  7.83996582e-02,   7.83996582e-02],
                        [  7.52258301e-02,   7.52258301e-02],
                        [  6.78100586e-02,   6.78100586e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  3.72924805e-02,   3.72924805e-02],
                        [  2.95410156e-02,   2.95410156e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  2.96630859e-02,   2.96630859e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  5.48400879e-02,   5.48400879e-02],
                        [  6.67419434e-02,   6.67419434e-02],
                        [  7.15026855e-02,   7.15026855e-02],
                        [  6.54296875e-02,   6.54296875e-02],
                        [  4.53186035e-02,   4.53186035e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -5.50842285e-02,  -5.50842285e-02],
                        [ -6.46972656e-02,  -6.46972656e-02],
                        [ -5.73425293e-02,  -5.73425293e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  7.66601562e-02,   7.66601562e-02],
                        [  9.37805176e-02,   9.37805176e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  6.86645508e-02,   6.86645508e-02],
                        [  4.89807129e-02,   4.89807129e-02],
                        [  3.77502441e-02,   3.77502441e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  3.50952148e-02,   3.50952148e-02],
                        [  3.30200195e-02,   3.30200195e-02],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  6.10351562e-03,   6.10351562e-03],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -6.89697266e-03,  -6.89697266e-03],
                        [ -1.14746094e-02,  -1.14746094e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -2.25524902e-02,  -2.25524902e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.20544434e-02,  -1.20544434e-02],
                        [ -9.52148438e-03,  -9.52148438e-03],
                        [ -1.62353516e-02,  -1.62353516e-02],
                        [ -2.67944336e-02,  -2.67944336e-02],
                        [ -3.49731445e-02,  -3.49731445e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -4.73327637e-02,  -4.73327637e-02],
                        [ -4.91027832e-02,  -4.91027832e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [  1.77001953e-03,   1.77001953e-03],
                        [  2.17895508e-02,   2.17895508e-02],
                        [  4.36096191e-02,   4.36096191e-02],
                        [  6.17065430e-02,   6.17065430e-02],
                        [  7.24182129e-02,   7.24182129e-02],
                        [  7.45849609e-02,   7.45849609e-02],
                        [  6.28967285e-02,   6.28967285e-02],
                        [  2.61535645e-02,   2.61535645e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -1.28631592e-01,  -1.28631592e-01],
                        [ -2.11608887e-01,  -2.11608887e-01],
                        [ -2.65747070e-01,  -2.65747070e-01],
                        [ -2.77496338e-01,  -2.77496338e-01],
                        [ -2.49145508e-01,  -2.49145508e-01],
                        [ -1.98394775e-01,  -1.98394775e-01],
                        [ -1.49993896e-01,  -1.49993896e-01],
                        [ -1.19659424e-01,  -1.19659424e-01],
                        [ -1.05072021e-01,  -1.05072021e-01],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -8.43200684e-02,  -8.43200684e-02],
                        [ -7.07397461e-02,  -7.07397461e-02],
                        [ -5.58776855e-02,  -5.58776855e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -2.47497559e-02,  -2.47497559e-02],
                        [ -7.35473633e-03,  -7.35473633e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  3.49426270e-02,   3.49426270e-02],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  2.62756348e-02,   2.62756348e-02],
                        [  1.52282715e-02,   1.52282715e-02],
                        [  1.45263672e-02,   1.45263672e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  6.46362305e-02,   6.46362305e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  1.12396240e-01,   1.12396240e-01],
                        [  1.34826660e-01,   1.34826660e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.50604248e-01,   1.50604248e-01],
                        [  1.17675781e-01,   1.17675781e-01],
                        [  4.40368652e-02,   4.40368652e-02],
                        [ -5.88073730e-02,  -5.88073730e-02],
                        [ -1.59698486e-01,  -1.59698486e-01],
                        [ -2.23175049e-01,  -2.23175049e-01],
                        [ -2.31414795e-01,  -2.31414795e-01],
                        [ -1.94396973e-01,  -1.94396973e-01],
                        [ -1.38641357e-01,  -1.38641357e-01],
                        [ -8.44116211e-02,  -8.44116211e-02],
                        [ -3.32031250e-02,  -3.32031250e-02],
                        [  2.23388672e-02,   2.23388672e-02],
                        [  7.87048340e-02,   7.87048340e-02],
                        [  1.19750977e-01,   1.19750977e-01],
                        [  1.33880615e-01,   1.33880615e-01],
                        [  1.24938965e-01,   1.24938965e-01],
                        [  1.06842041e-01,   1.06842041e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  8.99658203e-02,   8.99658203e-02],
                        [  9.55810547e-02,   9.55810547e-02],
                        [  1.02386475e-01,   1.02386475e-01],
                        [  1.04217529e-01,   1.04217529e-01],
                        [  1.00463867e-01,   1.00463867e-01],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  7.94372559e-02,   7.94372559e-02],
                        [  6.11267090e-02,   6.11267090e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  3.42102051e-02,   3.42102051e-02],
                        [  3.46069336e-02,   3.46069336e-02],
                        [  3.95507812e-02,   3.95507812e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.70275879e-02,   4.70275879e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  3.55834961e-02,   3.55834961e-02],
                        [  2.99987793e-02,   2.99987793e-02],
                        [  3.04260254e-02,   3.04260254e-02],
                        [  3.43322754e-02,   3.43322754e-02],
                        [  3.60107422e-02,   3.60107422e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -5.61828613e-02,  -5.61828613e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -4.20837402e-02,  -4.20837402e-02],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  9.23767090e-02,   9.23767090e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.00677490e-01,   1.00677490e-01],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  4.27856445e-02,   4.27856445e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  1.94702148e-02,   1.94702148e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  1.35498047e-02,   1.35498047e-02],
                        [  7.56835938e-03,   7.56835938e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -2.11181641e-02,  -2.11181641e-02],
                        [ -2.70080566e-02,  -2.70080566e-02],
                        [ -3.25927734e-02,  -3.25927734e-02],
                        [ -3.80249023e-02,  -3.80249023e-02],
                        [ -4.08020020e-02,  -4.08020020e-02],
                        [ -3.93371582e-02,  -3.93371582e-02],
                        [ -3.48815918e-02,  -3.48815918e-02],
                        [ -2.99987793e-02,  -2.99987793e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [ -2.19116211e-02,  -2.19116211e-02],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [ -3.29589844e-03,  -3.29589844e-03],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  1.38244629e-02,   1.38244629e-02],
                        [  2.83508301e-02,   2.83508301e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  4.94689941e-02,   4.94689941e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  2.50549316e-02,   2.50549316e-02],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -6.93359375e-02,  -6.93359375e-02],
                        [ -1.33270264e-01,  -1.33270264e-01],
                        [ -1.93359375e-01,  -1.93359375e-01],
                        [ -2.37060547e-01,  -2.37060547e-01],
                        [ -2.51129150e-01,  -2.51129150e-01],
                        [ -2.29858398e-01,  -2.29858398e-01],
                        [ -1.87683105e-01,  -1.87683105e-01],
                        [ -1.50939941e-01,  -1.50939941e-01],
                        [ -1.32171631e-01,  -1.32171631e-01],
                        [ -1.23168945e-01,  -1.23168945e-01],
                        [ -1.12915039e-01,  -1.12915039e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -2.99072266e-02,  -2.99072266e-02],
                        [ -1.86767578e-02,  -1.86767578e-02],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [  4.15039062e-03,   4.15039062e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  2.22473145e-02,   2.22473145e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  5.70068359e-02,   5.70068359e-02],
                        [  7.51647949e-02,   7.51647949e-02],
                        [  9.42077637e-02,   9.42077637e-02],
                        [  1.14685059e-01,   1.14685059e-01],
                        [  1.33514404e-01,   1.33514404e-01],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  1.35101318e-01,   1.35101318e-01],
                        [  9.57336426e-02,   9.57336426e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [ -8.39843750e-02,  -8.39843750e-02],
                        [ -1.77673340e-01,  -1.77673340e-01],
                        [ -2.23175049e-01,  -2.23175049e-01],
                        [ -2.03796387e-01,  -2.03796387e-01],
                        [ -1.37939453e-01,  -1.37939453e-01],
                        [ -6.35986328e-02,  -6.35986328e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  2.54821777e-02,   2.54821777e-02],
                        [  4.97436523e-02,   4.97436523e-02],
                        [  7.09533691e-02,   7.09533691e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  8.63342285e-02,   8.63342285e-02],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  7.52563477e-02,   7.52563477e-02],
                        [  7.96813965e-02,   7.96813965e-02],
                        [  9.06066895e-02,   9.06066895e-02],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  1.09283447e-01,   1.09283447e-01],
                        [  1.11450195e-01,   1.11450195e-01],
                        [  1.07025146e-01,   1.07025146e-01],
                        [  9.57946777e-02,   9.57946777e-02],
                        [  7.87658691e-02,   7.87658691e-02],
                        [  5.93261719e-02,   5.93261719e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  3.81164551e-02,   3.81164551e-02],
                        [  3.85742188e-02,   3.85742188e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  3.30810547e-02,   3.30810547e-02],
                        [  3.06091309e-02,   3.06091309e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  3.07312012e-02,   3.07312012e-02],
                        [  3.76586914e-02,   3.76586914e-02],
                        [  4.58984375e-02,   4.58984375e-02],
                        [  4.75463867e-02,   4.75463867e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  1.61437988e-02,   1.61437988e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -4.21752930e-02,  -4.21752930e-02],
                        [ -6.35070801e-02,  -6.35070801e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  1.01867676e-01,   1.01867676e-01],
                        [  1.21429443e-01,   1.21429443e-01],
                        [  1.16180420e-01,   1.16180420e-01],
                        [  9.21936035e-02,   9.21936035e-02],
                        [  6.12487793e-02,   6.12487793e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  2.38952637e-02,   2.38952637e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  2.15759277e-02,   2.15759277e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  4.88281250e-03,   4.88281250e-03],
                        [ -1.19934082e-02,  -1.19934082e-02],
                        [ -2.62451172e-02,  -2.62451172e-02],
                        [ -3.41186523e-02,  -3.41186523e-02],
                        [ -3.46069336e-02,  -3.46069336e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [ -1.78833008e-02,  -1.78833008e-02],
                        [ -2.16979980e-02,  -2.16979980e-02],
                        [ -2.05688477e-02,  -2.05688477e-02],
                        [ -1.55639648e-02,  -1.55639648e-02],
                        [ -8.45336914e-03,  -8.45336914e-03],
                        [ -1.31225586e-03,  -1.31225586e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  9.36889648e-03,   9.36889648e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.16271973e-02,   1.16271973e-02],
                        [  1.43432617e-02,   1.43432617e-02],
                        [  1.82800293e-02,   1.82800293e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [ -3.96728516e-04,  -3.96728516e-04],
                        [ -3.43627930e-02,  -3.43627930e-02],
                        [ -7.96203613e-02,  -7.96203613e-02],
                        [ -1.25671387e-01,  -1.25671387e-01],
                        [ -1.64306641e-01,  -1.64306641e-01],
                        [ -1.90673828e-01,  -1.90673828e-01],
                        [ -2.01843262e-01,  -2.01843262e-01],
                        [ -1.97906494e-01,  -1.97906494e-01],
                        [ -1.83227539e-01,  -1.83227539e-01],
                        [ -1.64031982e-01,  -1.64031982e-01],
                        [ -1.43829346e-01,  -1.43829346e-01],
                        [ -1.23413086e-01,  -1.23413086e-01],
                        [ -1.04217529e-01,  -1.04217529e-01],
                        [ -8.90197754e-02,  -8.90197754e-02],
                        [ -7.81250000e-02,  -7.81250000e-02],
                        [ -6.78710938e-02,  -6.78710938e-02],
                        [ -5.38330078e-02,  -5.38330078e-02],
                        [ -3.57055664e-02,  -3.57055664e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [  1.13525391e-02,   1.13525391e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  3.02429199e-02,   3.02429199e-02],
                        [  2.71606445e-02,   2.71606445e-02],
                        [  1.71203613e-02,   1.71203613e-02],
                        [  5.64575195e-03,   5.64575195e-03],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  5.95092773e-03,   5.95092773e-03],
                        [  2.27966309e-02,   2.27966309e-02],
                        [  4.54406738e-02,   4.54406738e-02],
                        [  6.98852539e-02,   6.98852539e-02],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  1.22161865e-01,   1.22161865e-01],
                        [  1.41204834e-01,   1.41204834e-01],
                        [  1.42089844e-01,   1.42089844e-01],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  6.22863770e-02,   6.22863770e-02],
                        [ -1.62658691e-02,  -1.62658691e-02],
                        [ -1.01959229e-01,  -1.01959229e-01],
                        [ -1.67968750e-01,  -1.67968750e-01],
                        [ -1.89636230e-01,  -1.89636230e-01],
                        [ -1.60675049e-01,  -1.60675049e-01],
                        [ -1.00494385e-01,  -1.00494385e-01],
                        [ -4.01000977e-02,  -4.01000977e-02],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  5.18188477e-02,   5.18188477e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  4.19921875e-02,   4.19921875e-02],
                        [  4.77600098e-02,   4.77600098e-02],
                        [  6.32324219e-02,   6.32324219e-02],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  9.21020508e-02,   9.21020508e-02],
                        [  9.21630859e-02,   9.21630859e-02],
                        [  8.12072754e-02,   8.12072754e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  4.59289551e-02,   4.59289551e-02],
                        [  3.61633301e-02,   3.61633301e-02],
                        [  3.26232910e-02,   3.26232910e-02],
                        [  2.90222168e-02,   2.90222168e-02],
                        [  2.38342285e-02,   2.38342285e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  2.90527344e-02,   2.90527344e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  4.89196777e-02,   4.89196777e-02],
                        [  5.24902344e-02,   5.24902344e-02],
                        [  4.93469238e-02,   4.93469238e-02],
                        [  4.05578613e-02,   4.05578613e-02],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [ -3.07617188e-02,  -3.07617188e-02],
                        [ -4.22973633e-02,  -4.22973633e-02],
                        [ -4.78515625e-02,  -4.78515625e-02],
                        [ -4.62036133e-02,  -4.62036133e-02],
                        [ -3.01513672e-02,  -3.01513672e-02],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  1.07940674e-01,   1.07940674e-01],
                        [  1.28234863e-01,   1.28234863e-01],
                        [  1.17156982e-01,   1.17156982e-01],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  7.08007812e-02,   7.08007812e-02],
                        [  5.80444336e-02,   5.80444336e-02],
                        [  4.38232422e-02,   4.38232422e-02],
                        [  2.59704590e-02,   2.59704590e-02],
                        [  1.26647949e-02,   1.26647949e-02],
                        [  8.36181641e-03,   8.36181641e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  7.29370117e-03,   7.29370117e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [ -7.17163086e-03,  -7.17163086e-03],
                        [ -2.01416016e-02,  -2.01416016e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -3.25012207e-02,  -3.25012207e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -2.38037109e-03,  -2.38037109e-03],
                        [ -9.36889648e-03,  -9.36889648e-03],
                        [ -1.32751465e-02,  -1.32751465e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.30310059e-02,  -1.30310059e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [ -3.96728516e-03,  -3.96728516e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  2.65502930e-03,   2.65502930e-03],
                        [  1.60522461e-02,   1.60827637e-02],
                        [  3.48205566e-02,   3.48205566e-02],
                        [  4.43725586e-02,   4.43725586e-02],
                        [  3.14025879e-02,   3.14025879e-02],
                        [ -4.21142578e-03,  -4.24194336e-03],
                        [ -5.14831543e-02,  -5.14831543e-02],
                        [ -1.01623535e-01,  -1.01654053e-01],
                        [ -1.51885986e-01,  -1.51885986e-01],
                        [ -1.95587158e-01,  -1.95587158e-01],
                        [ -2.20672607e-01,  -2.20672607e-01],
                        [ -2.21099854e-01,  -2.21069336e-01],
                        [ -2.03002930e-01,  -2.02972412e-01],
                        [ -1.77825928e-01,  -1.77825928e-01],
                        [ -1.52130127e-01,  -1.52099609e-01],
                        [ -1.26159668e-01,  -1.26129150e-01],
                        [ -1.00463867e-01,  -1.00463867e-01],
                        [ -7.88574219e-02,  -7.88574219e-02],
                        [ -6.44531250e-02,  -6.44531250e-02],
                        [ -5.62438965e-02,  -5.62744141e-02],
                        [ -4.95300293e-02,  -4.95605469e-02],
                        [ -4.00695801e-02,  -4.01306152e-02],
                        [ -2.71301270e-02,  -2.71606445e-02],
                        [ -1.21765137e-02,  -1.22070312e-02],
                        [  2.07519531e-03,   2.04467773e-03],
                        [  1.14135742e-02,   1.14135742e-02],
                        [  1.35803223e-02,   1.35803223e-02],
                        [  1.03759766e-02,   1.04064941e-02],
                        [  4.66918945e-03,   4.73022461e-03],
                        [ -3.66210938e-04,  -2.74658203e-04],
                        [ -6.71386719e-04,  -6.10351562e-04],
                        [  4.73022461e-03,   4.79125977e-03],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  2.79541016e-02,   2.79235840e-02],
                        [  4.91943359e-02,   4.91333008e-02],
                        [  7.48901367e-02,   7.47985840e-02],
                        [  9.81750488e-02,   9.80834961e-02],
                        [  1.14959717e-01,   1.14868164e-01],
                        [  1.24694824e-01,   1.24664307e-01],
                        [  1.25061035e-01,   1.25091553e-01],
                        [  1.10076904e-01,   1.10137939e-01],
                        [  7.43408203e-02,   7.44628906e-02],
                        [  1.66931152e-02,   1.68151855e-02],
                        [ -5.55419922e-02,  -5.54199219e-02],
                        [ -1.20422363e-01,  -1.20361328e-01],
                        [ -1.47796631e-01,  -1.47766113e-01],
                        [ -1.22253418e-01,  -1.22314453e-01],
                        [ -5.93261719e-02,  -5.94482422e-02],
                        [  4.82177734e-03,   4.63867188e-03],
                        [  4.11071777e-02,   4.09545898e-02],
                        [  4.73022461e-02,   4.71801758e-02],
                        [  4.11376953e-02,   4.11071777e-02],
                        [  3.81469727e-02,   3.82080078e-02],
                        [  3.92456055e-02,   3.93981934e-02],
                        [  3.71398926e-02,   3.73535156e-02],
                        [  2.99377441e-02,   3.01513672e-02],
                        [  2.57568359e-02,   2.59399414e-02],
                        [  3.28674316e-02,   3.29284668e-02],
                        [  4.95910645e-02,   4.95605469e-02],
                        [  6.83593750e-02,   6.82067871e-02],
                        [  8.30993652e-02,   8.28247070e-02],
                        [  8.85925293e-02,   8.83178711e-02],
                        [  8.03527832e-02,   8.00781250e-02],
                        [  6.01501465e-02,   5.99975586e-02],
                        [  3.92456055e-02,   3.91845703e-02],
                        [  3.03955078e-02,   3.04870605e-02],
                        [  3.62243652e-02,   3.64685059e-02],
                        [  4.72106934e-02,   4.75158691e-02],
                        [  5.21240234e-02,   5.24597168e-02],
                        [  4.76684570e-02,   4.79125977e-02],
                        [  3.79943848e-02,   3.81469727e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  2.57568359e-02,   2.56347656e-02],
                        [  2.59094238e-02,   2.56652832e-02],
                        [  2.60009766e-02,   2.57263184e-02],
                        [  2.22167969e-02,   2.19421387e-02],
                        [  1.38854980e-02,   1.37023926e-02],
                        [  3.75366211e-03,   3.63159180e-03],
                        [ -6.68334961e-03,  -6.71386719e-03],
                        [ -1.86157227e-02,  -1.85546875e-02],
                        [ -3.16467285e-02,  -3.15856934e-02],
                        [ -4.12292480e-02,  -4.11376953e-02],
                        [ -4.05273438e-02,  -4.04663086e-02],
                        [ -2.38952637e-02,  -2.38342285e-02],
                        [  9.52148438e-03,   9.58251953e-03],
                        [  5.14221191e-02,   5.14526367e-02],
                        [  8.52355957e-02,   8.53271484e-02],
                        [  9.65576172e-02,   9.66796875e-02],
                        [  8.63037109e-02,   8.64868164e-02],
                        [  7.06481934e-02,   7.08312988e-02],
                        [  6.30493164e-02,   6.32019043e-02],
                        [  6.13708496e-02,   6.14318848e-02],
                        [  5.49011230e-02,   5.48400879e-02],
                        [  3.91235352e-02,   3.89099121e-02],
                        [  1.98364258e-02,   1.94702148e-02],
                        [  6.25610352e-03,   5.79833984e-03],
                        [  1.77001953e-03,   1.31225586e-03],
                        [  1.58691406e-03,   1.19018555e-03],
                        [ -7.62939453e-04,  -9.46044922e-04],
                        [ -6.68334961e-03,  -6.65283203e-03],
                        [ -1.41906738e-02,  -1.38854980e-02],
                        [ -2.10876465e-02,  -2.05688477e-02],
                        [ -2.40783691e-02,  -2.34375000e-02],
                        [ -1.92260742e-02,  -1.85241699e-02],
                        [ -8.39233398e-03,  -7.81250000e-03],
                        [ -3.96728516e-04,  -9.15527344e-05],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -2.89916992e-03,  -3.23486328e-03],
                        [ -2.83813477e-03,  -3.44848633e-03],
                        [ -1.61743164e-03,  -2.41088867e-03],
                        [ -3.08227539e-03,  -3.87573242e-03],
                        [ -6.22558594e-03,  -6.89697266e-03],
                        [ -6.80541992e-03,  -7.23266602e-03],
                        [ -2.99072266e-03,  -3.05175781e-03],
                        [  4.08935547e-03,   4.39453125e-03],
                        [  1.45568848e-02,   1.51977539e-02],
                        [  3.02734375e-02,   3.10974121e-02],
                        [  4.98352051e-02,   5.06896973e-02],
                        [  6.69555664e-02,   6.76574707e-02],
                        [  7.31201172e-02,   7.35473633e-02],
                        [  5.95092773e-02,   5.96008301e-02],
                        [  1.95922852e-02,   1.92871094e-02],
                        [ -4.57153320e-02,  -4.63256836e-02],
                        [ -1.24969482e-01,  -1.25762939e-01],
                        [ -1.99951172e-01,  -2.00775146e-01],
                        [ -2.52197266e-01,  -2.52899170e-01],
                        [ -2.68920898e-01,  -2.69348145e-01],
                        [ -2.48596191e-01,  -2.48687744e-01],
                        [ -2.04223633e-01,  -2.03948975e-01],
                        [ -1.57440186e-01,  -1.56890869e-01],
                        [ -1.24786377e-01,  -1.24084473e-01],
                        [ -1.08154297e-01,  -1.07421875e-01],
                        [ -9.92431641e-02,  -9.86328125e-02],
                        [ -9.17053223e-02,  -9.13391113e-02],
                        [ -8.49304199e-02,  -8.48388672e-02],
                        [ -7.76672363e-02,  -7.78503418e-02],
                        [ -6.60400391e-02,  -6.64367676e-02],
                        [ -5.08117676e-02,  -5.13305664e-02],
                        [ -3.81469727e-02,  -3.86657715e-02],
                        [ -2.94189453e-02,  -2.98767090e-02],
                        [ -1.89514160e-02,  -1.92565918e-02],
                        [ -3.20434570e-03,  -3.35693359e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  2.61535645e-02,   2.62756348e-02],
                        [  2.95715332e-02,   2.97546387e-02],
                        [  2.48413086e-02,   2.50549316e-02],
                        [  1.48925781e-02,   1.51062012e-02],
                        [  3.90625000e-03,   4.11987305e-03],
                        [ -2.44140625e-03,  -2.19726562e-03],
                        [  1.19018555e-03,   1.49536133e-03],
                        [  1.49841309e-02,   1.53198242e-02],
                        [  3.41186523e-02,   3.44238281e-02],
                        [  5.54809570e-02,   5.57556152e-02],
                        [  8.06884766e-02,   8.08105469e-02],
                        [  1.08520508e-01,   1.08428955e-01],
                        [  1.30615234e-01,   1.30249023e-01],
                        [  1.37725830e-01,   1.37084961e-01],
                        [  1.25762939e-01,   1.24908447e-01],
                        [  9.32922363e-02,   9.23767090e-02],
                        [  4.02221680e-02,   3.94287109e-02],
                        [ -2.70690918e-02,  -2.75878906e-02],
                        [ -9.08203125e-02,  -9.09118652e-02],
                        [ -1.24572754e-01,  -1.24145508e-01],
                        [ -1.08947754e-01,  -1.08093262e-01],
                        [ -5.14221191e-02,  -5.02014160e-02],
                        [  1.33666992e-02,   1.47399902e-02],
                        [  4.84619141e-02,   4.97436523e-02],
                        [  4.30908203e-02,   4.39758301e-02],
                        [  1.78222656e-02,   1.81884766e-02],
                        [  1.80053711e-03,   1.55639648e-03],
                        [  4.76074219e-03,   3.93676758e-03],
                        [  1.48010254e-02,   1.35498047e-02],
                        [  2.03552246e-02,   1.88903809e-02],
                        [  2.46887207e-02,   2.32543945e-02],
                        [  3.57666016e-02,   3.46069336e-02],
                        [  5.18493652e-02,   5.11779785e-02],
                        [  6.39343262e-02,   6.38122559e-02],
                        [  6.70166016e-02,   6.74438477e-02],
                        [  6.19812012e-02,   6.28967285e-02],
                        [  5.17578125e-02,   5.29785156e-02],
                        [  4.11071777e-02,   4.24499512e-02],
                        [  3.59802246e-02,   3.72314453e-02],
                        [  3.93981934e-02,   4.03747559e-02],
                        [  4.72412109e-02,   4.78210449e-02],
                        [  4.95605469e-02,   4.96826172e-02],
                        [  4.02221680e-02,   3.98559570e-02],
                        [  2.52075195e-02,   2.44445801e-02],
                        [  1.55639648e-02,   1.45263672e-02],
                        [  1.42517090e-02,   1.30920410e-02],
                        [  1.64184570e-02,   1.53198242e-02],
                        [  1.76696777e-02,   1.68151855e-02],
                        [  1.74560547e-02,   1.69677734e-02],
                        [  1.71203613e-02,   1.70898438e-02],
                        [  1.72119141e-02,   1.76391602e-02],
                        [  1.54113770e-02,   1.62048340e-02],
                        [  7.72094727e-03,   8.66699219e-03],
                        [ -7.90405273e-03,  -6.98852539e-03],
                        [ -2.89916992e-02,  -2.82897949e-02],
                        [ -4.86450195e-02,  -4.83398438e-02],
                        [ -5.64880371e-02,  -5.66101074e-02],
                        [ -4.19311523e-02,  -4.24499512e-02],
                        [ -2.71606445e-03,  -3.41796875e-03],
                        [  4.87976074e-02,   4.80957031e-02],
                        [  9.18579102e-02,   9.14611816e-02],
                        [  1.11328125e-01,   1.11389160e-01],
                        [  1.05041504e-01,   1.05590820e-01],
                        [  8.32214355e-02,   8.41674805e-02],
                        [  6.14929199e-02,   6.25610352e-02],
                        [  4.84313965e-02,   4.92858887e-02],
                        [  3.96728516e-02,   3.99475098e-02],
                        [  2.72216797e-02,   2.67028809e-02],
                        [  1.16882324e-02,   1.03454590e-02],
                        [  1.95312500e-03,   0.00000000e+00],
                        [  3.93676758e-03,   1.73950195e-03],
                        [  1.22985840e-02,   1.04675293e-02],
                        [  1.57775879e-02,   1.48010254e-02],
                        [  8.02612305e-03,   8.30078125e-03],
                        [ -8.11767578e-03,  -6.46972656e-03],
                        [ -2.37731934e-02,  -2.09655762e-02],
                        [ -2.99072266e-02,  -2.64892578e-02],
                        [ -2.49023438e-02,  -2.16064453e-02],
                        [ -1.55639648e-02,  -1.32141113e-02],
                        [ -8.30078125e-03,  -7.47680664e-03],
                        [ -1.98364258e-03,  -3.05175781e-03],
                        [  7.75146484e-03,   4.91333008e-03],
                        [  2.03247070e-02,   1.62963867e-02],
                        [  2.92663574e-02,   2.49023438e-02],
                        [  2.94189453e-02,   2.56652832e-02],
                        [  2.16369629e-02,   1.94091797e-02],
                        [  1.04064941e-02,   1.02233887e-02],
                        [  1.95312500e-03,   3.90625000e-03],
                        [  3.47900391e-03,   7.14111328e-03],
                        [  1.79748535e-02,   2.25219727e-02],
                        [  4.10156250e-02,   4.54101562e-02],
                        [  6.48498535e-02,   6.81152344e-02],
                        [  8.07800293e-02,   8.21838379e-02],
                        [  7.69042969e-02,   7.62023926e-02],
                        [  4.14123535e-02,   3.88183594e-02],
                        [ -2.67333984e-02,  -3.05175781e-02],
                        [ -1.11633301e-01,  -1.15753174e-01],
                        [ -1.89422607e-01,  -1.92901611e-01],
                        [ -2.40936279e-01,  -2.43011475e-01],
                        [ -2.56683350e-01,  -2.56988525e-01],
                        [ -2.38800049e-01,  -2.37426758e-01],
                        [ -2.02392578e-01,  -1.99829102e-01],
                        [ -1.67083740e-01,  -1.64001465e-01],
                        [ -1.43066406e-01,  -1.40258789e-01],
                        [ -1.27899170e-01,  -1.25946045e-01],
                        [ -1.14196777e-01,  -1.13403320e-01],
                        [ -9.81750488e-02,  -9.86022949e-02],
                        [ -8.23974609e-02,  -8.36486816e-02],
                        [ -7.03125000e-02,  -7.19604492e-02],
                        [ -6.10351562e-02,  -6.25915527e-02],
                        [ -5.01098633e-02,  -5.12084961e-02],
                        [ -3.38134766e-02,  -3.43017578e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [  7.14111328e-03,   7.38525391e-03],
                        [  2.07214355e-02,   2.08740234e-02],
                        [  2.59704590e-02,   2.58789062e-02],
                        [  2.33764648e-02,   2.29492188e-02],
                        [  1.49230957e-02,   1.43432617e-02],
                        [  5.24902344e-03,   4.85229492e-03],
                        [ -8.85009766e-04,  -7.93457031e-04],
                        [ -2.86865234e-03,  -2.04467773e-03],
                        [ -2.44140625e-03,  -7.93457031e-04],
                        [  1.40380859e-03,   3.57055664e-03],
                        [  1.18408203e-02,   1.40380859e-02],
                        [  2.88696289e-02,   3.05480957e-02],
                        [  4.93774414e-02,   4.99572754e-02],
                        [  7.08923340e-02,   7.00378418e-02],
                        [  9.07592773e-02,   8.84704590e-02],
                        [  1.05957031e-01,   1.02630615e-01],
                        [  1.17889404e-01,   1.14196777e-01],
                        [  1.29364014e-01,   1.26129150e-01],
                        [  1.34918213e-01,   1.32934570e-01],
                        [  1.21917725e-01,   1.21704102e-01],
                        [  8.13598633e-02,   8.30383301e-02],
                        [  1.62048340e-02,   1.94396973e-02],
                        [ -5.54504395e-02,  -5.13305664e-02],
                        [ -1.05712891e-01,  -1.01623535e-01],
                        [ -1.13006592e-01,  -1.09832764e-01],
                        [ -7.87353516e-02,  -7.71179199e-02],
                        [ -2.78625488e-02,  -2.81066895e-02],
                        [  1.03149414e-02,   8.36181641e-03],
                        [  2.47802734e-02,   2.16369629e-02],
                        [  2.58483887e-02,   2.22473145e-02],
                        [  2.73132324e-02,   2.40478516e-02],
                        [  3.07312012e-02,   2.84423828e-02],
                        [  2.95715332e-02,   2.86254883e-02],
                        [  2.27050781e-02,   2.31018066e-02],
                        [  1.62963867e-02,   1.77612305e-02],
                        [  1.53808594e-02,   1.74255371e-02],
                        [  2.07214355e-02,   2.28271484e-02],
                        [  3.16162109e-02,   3.33557129e-02],
                        [  4.51354980e-02,   4.62341309e-02],
                        [  5.64270020e-02,   5.68237305e-02],
                        [  6.29577637e-02,   6.28051758e-02],
                        [  6.45446777e-02,   6.39953613e-02],
                        [  6.04248047e-02,   5.97229004e-02],
                        [  5.10253906e-02,   5.03540039e-02],
                        [  3.95507812e-02,   3.90319824e-02],
                        [  3.05175781e-02,   3.01208496e-02],
                        [  2.74658203e-02,   2.71911621e-02],
                        [  2.98461914e-02,   2.96630859e-02],
                        [  3.17077637e-02,   3.16467285e-02],
                        [  2.78930664e-02,   2.80151367e-02],
                        [  2.03247070e-02,   2.06298828e-02],
                        [  1.40991211e-02,   1.46179199e-02],
                        [  9.91821289e-03,   1.05285645e-02],
                        [  4.21142578e-03,   4.76074219e-03],
                        [ -4.27246094e-03,  -4.02832031e-03],
                        [ -1.27258301e-02,  -1.30310059e-02],
                        [ -1.90734863e-02,  -2.00195312e-02],
                        [ -2.36206055e-02,  -2.51770020e-02],
                        [ -2.63061523e-02,  -2.81372070e-02],
                        [ -2.46582031e-02,  -2.63061523e-02],
                        [ -1.42822266e-02,  -1.51672363e-02],
                        [  9.00268555e-03,   9.33837891e-03],
                        [  4.33044434e-02,   4.51354980e-02],
                        [  7.74230957e-02,   8.05664062e-02],
                        [  9.71069336e-02,   1.01043701e-01],
                        [  9.57641602e-02,   9.96398926e-02],
                        [  7.91931152e-02,   8.20007324e-02],
                        [  6.01501465e-02,   6.10656738e-02],
                        [  4.70275879e-02,   4.55017090e-02],
                        [  3.89709473e-02,   3.50646973e-02],
                        [  3.20434570e-02,   2.63671875e-02],
                        [  2.54211426e-02,   1.91650391e-02],
                        [  2.11486816e-02,   1.56555176e-02],
                        [  1.98974609e-02,   1.65100098e-02],
                        [  1.74255371e-02,   1.70593262e-02],
                        [  7.29370117e-03,   1.01623535e-02],
                        [ -1.03759766e-02,  -4.76074219e-03],
                        [ -2.67639160e-02,  -1.95922852e-02],
                        [ -3.36914062e-02,  -2.64892578e-02],
                        [ -3.11889648e-02,  -2.55432129e-02],
                        [ -2.48413086e-02,  -2.20031738e-02],
                        [ -1.86462402e-02,  -1.91650391e-02],
                        [ -1.33666992e-02,  -1.70898438e-02],
                        [ -8.17871094e-03,  -1.41601562e-02],
                        [ -7.32421875e-04,  -7.50732422e-03],
                        [  1.06811523e-02,   4.57763672e-03],
                        [  2.23693848e-02,   1.82800293e-02],
                        [  2.72827148e-02,   2.59094238e-02],
                        [  2.22778320e-02,   2.37121582e-02],
                        [  1.18103027e-02,   1.53503418e-02],
                        [  4.63867188e-03,   9.27734375e-03],
                        [  6.95800781e-03,   1.14440918e-02],
                        [  1.80358887e-02,   2.13623047e-02],
                        [  3.44543457e-02,   3.59802246e-02],
                        [  5.25207520e-02,   5.22155762e-02],
                        [  6.37817383e-02,   6.20727539e-02],
                        [  5.61828613e-02,   5.38635254e-02],
                        [  2.43835449e-02,   2.22778320e-02],
                        [ -2.78930664e-02,  -2.91442871e-02],
                        [ -9.46655273e-02,  -9.47875977e-02],
                        [ -1.66809082e-01,  -1.65954590e-01],
                        [ -2.26135254e-01,  -2.24792480e-01],
                        [ -2.53112793e-01,  -2.51922607e-01],
                        [ -2.44293213e-01,  -2.43865967e-01],
                        [ -2.15209961e-01,  -2.15820312e-01],
                        [ -1.84020996e-01,  -1.85607910e-01],
                        [ -1.58142090e-01,  -1.60308838e-01],
                        [ -1.35162354e-01,  -1.37268066e-01],
                        [ -1.10839844e-01,  -1.12213135e-01],
                        [ -8.56018066e-02,  -8.57543945e-02],
                        [ -6.45751953e-02,  -6.33239746e-02],
                        [ -5.20935059e-02,  -4.96826172e-02],
                        [ -4.92553711e-02,  -4.62036133e-02],
                        [ -5.28869629e-02,  -4.99572754e-02],
                        [ -5.44433594e-02,  -5.23376465e-02],
                        [ -4.54101562e-02,  -4.45861816e-02],
                        [ -2.75573730e-02,  -2.82287598e-02],
                        [ -1.07421875e-02,  -1.26647949e-02],
                        [  6.10351562e-04,  -2.13623047e-03],
                        [  9.27734375e-03,   6.34765625e-03],
                        [  1.53503418e-02,   1.28479004e-02],
                        [  1.52587891e-02,   1.36413574e-02],
                        [  1.01928711e-02,   9.64355469e-03],
                        [  5.64575195e-03,   6.13403320e-03],
                        [  3.23486328e-03,   4.54711914e-03],
                        [  6.71386719e-04,   2.50244141e-03],
                        [ -1.25122070e-03,   7.93457031e-04],
                        [  2.19726562e-03,   4.21142578e-03],
                        [  1.38549805e-02,   1.56555176e-02],
                        [  3.17382812e-02,   3.31726074e-02],
                        [  5.13610840e-02,   5.23071289e-02],
                        [  6.98547363e-02,   7.01293945e-02],
                        [  8.84094238e-02,   8.78601074e-02],
                        [  1.10015869e-01,   1.08551025e-01],
                        [  1.33728027e-01,   1.31286621e-01],
                        [  1.51947021e-01,   1.48773193e-01],
                        [  1.53320312e-01,   1.49871826e-01],
                        [  1.27868652e-01,   1.24755859e-01],
                        [  7.47680664e-02,   7.27539062e-02],
                        [  8.54492188e-03,   8.23974609e-03],
                        [ -4.68139648e-02,  -4.50134277e-02],
                        [ -7.28149414e-02,  -6.90307617e-02],
                        [ -6.73522949e-02,  -6.21643066e-02],
                        [ -4.40368652e-02,  -3.84521484e-02],
                        [ -2.09655762e-02,  -1.61743164e-02],
                        [ -6.98852539e-03,  -4.15039062e-03],
                        [  6.40869141e-04,   7.93457031e-04],
                        [  6.83593750e-03,   4.08935547e-03],
                        [  1.08032227e-02,   5.67626953e-03],
                        [  9.03320312e-03,   2.65502930e-03],
                        [  2.96020508e-03,  -3.29589844e-03],
                        [ -3.66210938e-04,  -5.09643555e-03],
                        [  4.57763672e-03,   2.38037109e-03],
                        [  1.67236328e-02,   1.74865723e-02],
                        [  3.07922363e-02,   3.41186523e-02],
                        [  4.17785645e-02,   4.67529297e-02],
                        [  4.85229492e-02,   5.38024902e-02],
                        [  5.32836914e-02,   5.76171875e-02],
                        [  5.76171875e-02,   6.00585938e-02],
                        [  5.84411621e-02,   5.86853027e-02],
                        [  5.13916016e-02,   4.98046875e-02],
                        [  3.76892090e-02,   3.50952148e-02],
                        [  2.42614746e-02,   2.17590332e-02],
                        [  1.58691406e-02,   1.44348145e-02],
                        [  1.14440918e-02,   1.15051270e-02],
                        [  1.01013184e-02,   1.15051270e-02],
                        [  1.37634277e-02,   1.58386230e-02],
                        [  2.07824707e-02,   2.23999023e-02],
                        [  2.34375000e-02,   2.36206055e-02],
                        [  1.59606934e-02,   1.40686035e-02],
                        [  3.96728516e-04,  -3.60107422e-03],
                        [ -1.74865723e-02,  -2.27355957e-02],
                        [ -3.40270996e-02,  -3.92150879e-02],
                        [ -4.76074219e-02,  -5.11779785e-02],
                        [ -5.50842285e-02,  -5.56945801e-02],
                        [ -5.19409180e-02,  -4.88891602e-02],
                        [ -3.45458984e-02,  -2.81372070e-02],
                        [ -1.31225586e-03,   7.26318359e-03],
                        [  4.49829102e-02,   5.38635254e-02],
                        [  9.25903320e-02,   9.96398926e-02],
                        [  1.22222900e-01,   1.25732422e-01],
                        [  1.20361328e-01,   1.19323730e-01],
                        [  9.25598145e-02,   8.70971680e-02],
                        [  6.00891113e-02,   5.14221191e-02],
                        [  4.08935547e-02,   3.09753418e-02],
                        [  3.64379883e-02,   2.74963379e-02],
                        [  3.64074707e-02,   3.03955078e-02],
                        [  3.10974121e-02,   2.91442871e-02],
                        [  1.82189941e-02,   2.04162598e-02],
                        [  4.08935547e-03,   9.52148438e-03],
                        [ -1.19018555e-03,   5.88989258e-03],
                        [  3.84521484e-03,   1.06811523e-02],
                        [  6.71386719e-03,   1.18103027e-02],
                        [ -3.54003906e-03,  -1.00708008e-03],
                        [ -2.05688477e-02,  -2.06604004e-02],
                        [ -2.94799805e-02,  -3.13415527e-02],
                        [ -2.56652832e-02,  -2.80761719e-02],
                        [ -1.70288086e-02,  -1.87988281e-02],
                        [ -1.13830566e-02,  -1.17797852e-02],
                        [ -8.78906250e-03,  -7.78198242e-03],
                        [ -5.34057617e-03,  -3.60107422e-03],
                        [  8.54492188e-04,   2.16674805e-03],
                        [  9.33837891e-03,   8.97216797e-03],
                        [  1.85241699e-02,   1.57165527e-02],
                        [  2.49938965e-02,   1.97448730e-02],
                        [  2.62756348e-02,   1.94702148e-02],
                        [  2.63366699e-02,   1.96228027e-02],
                        [  3.39050293e-02,   2.92053223e-02],
                        [  5.16967773e-02,   5.07202148e-02],
                        [  7.08007812e-02,   7.44628906e-02],
                        [  7.87353516e-02,   8.68530273e-02],
                        [  6.92138672e-02,   8.03527832e-02],
                        [  4.08630371e-02,   5.26428223e-02],
                        [ -6.68334961e-03,   3.08227539e-03],
                        [ -6.99462891e-02,  -6.46057129e-02],
                        [ -1.39282227e-01,  -1.39831543e-01],
                        [ -2.00958252e-01,  -2.07489014e-01],
                        [ -2.40173340e-01,  -2.51403809e-01],
                        [ -2.47192383e-01,  -2.60711670e-01],
                        [ -2.24578857e-01,  -2.37457275e-01],
                        [ -1.87347412e-01,  -1.96777344e-01],
                        [ -1.53106689e-01,  -1.57226562e-01],
                        [ -1.31195068e-01,  -1.29302979e-01],
                        [ -1.19018555e-01,  -1.11816406e-01],
                        [ -1.07360840e-01,  -9.66796875e-02],
                        [ -8.97216797e-02,  -7.79724121e-02],
                        [ -6.87255859e-02,  -5.83801270e-02],
                        [ -5.32836914e-02,  -4.62036133e-02],
                        [ -4.76074219e-02,  -4.47692871e-02],
                        [ -4.62341309e-02,  -4.76074219e-02],
                        [ -4.06188965e-02,  -4.52575684e-02],
                        [ -2.76489258e-02,  -3.42407227e-02],
                        [ -1.08032227e-02,  -1.78833008e-02],
                        [  4.97436523e-03,  -1.43432617e-03],
                        [  1.69677734e-02,   1.19323730e-02],
                        [  2.43530273e-02,   2.09350586e-02],
                        [  2.70690918e-02,   2.51464844e-02],
                        [  2.57873535e-02,   2.51770020e-02],
                        [  2.02636719e-02,   2.08740234e-02],
                        [  9.30786133e-03,   1.12609863e-02],
                        [ -4.21142578e-03,  -7.62939453e-04],
                        [ -1.30920410e-02,  -7.99560547e-03],
                        [ -1.30004883e-02,  -6.46972656e-03],
                        [ -6.46972656e-03,   7.93457031e-04],
                        [  2.19726562e-03,   9.00268555e-03],
                        [  1.24816895e-02,   1.73034668e-02],
                        [  2.65808105e-02,   2.79846191e-02],
                        [  4.53186035e-02,   4.23583984e-02],
                        [  6.81152344e-02,   6.06689453e-02],
                        [  9.56726074e-02,   8.47473145e-02],
                        [  1.30126953e-01,   1.17675781e-01],
                        [  1.70898438e-01,   1.59484863e-01],
                        [  2.09655762e-01,   2.01934814e-01],
                        [  2.28088379e-01,   2.26043701e-01],
                        [  2.04589844e-01,   2.09045410e-01],
                        [  1.31774902e-01,   1.42028809e-01],
                        [  3.07006836e-02,   4.47387695e-02],
                        [ -5.65490723e-02,  -4.17175293e-02],
                        [ -9.51538086e-02,  -8.27636719e-02],
                        [ -8.25195312e-02,  -7.52868652e-02],
                        [ -4.67529297e-02,  -4.61425781e-02],
                        [ -2.09350586e-02,  -2.69165039e-02],
                        [ -1.74255371e-02,  -2.84118652e-02],
                        [ -2.38647461e-02,  -3.72009277e-02],
                        [ -2.24914551e-02,  -3.51257324e-02],
                        [ -1.12915039e-02,  -2.05383301e-02],
                        [ -3.23486328e-03,  -7.44628906e-03],
                        [ -5.88989258e-03,  -4.76074219e-03],
                        [ -1.06201172e-02,  -5.18798828e-03],
                        [ -6.22558594e-03,   1.61743164e-03],
                        [  5.00488281e-03,   1.29699707e-02],
                        [  1.29089355e-02,   1.91040039e-02],
                        [  1.56860352e-02,   1.89819336e-02],
                        [  2.13623047e-02,   2.17895508e-02],
                        [  3.49731445e-02,   3.34472656e-02],
                        [  4.97741699e-02,   4.76989746e-02],
                        [  5.43823242e-02,   5.31616211e-02],
                        [  4.59899902e-02,   4.64782715e-02],
                        [  3.25927734e-02,   3.47595215e-02],
                        [  2.34985352e-02,   2.64282227e-02],
                        [  2.06909180e-02,   2.29797363e-02],
                        [  2.02026367e-02,   2.02941895e-02],
                        [  1.96838379e-02,   1.65710449e-02],
                        [  2.03857422e-02,   1.40380859e-02],
                        [  1.97448730e-02,   1.11389160e-02],
                        [  9.94873047e-03,   1.06811523e-03],
                        [ -1.02844238e-02,  -1.71813965e-02],
                        [ -3.05480957e-02,  -3.33557129e-02],
                        [ -4.09851074e-02,  -3.84826660e-02],
                        [ -4.39758301e-02,  -3.62548828e-02],
                        [ -4.75463867e-02,  -3.60412598e-02],
                        [ -5.04455566e-02,  -3.76281738e-02],
                        [ -4.14428711e-02,  -3.01513672e-02],
                        [ -1.19628906e-02,  -4.85229492e-03],
                        [  3.61633301e-02,   3.75061035e-02],
                        [  9.12475586e-02,   8.66088867e-02],
                        [  1.32995605e-01,   1.23626709e-01],
                        [  1.41265869e-01,   1.29425049e-01],
                        [  1.13739014e-01,   1.02233887e-01],
                        [  7.17163086e-02,   6.30798340e-02],
                        [  4.08935547e-02,   3.67736816e-02],
                        [  2.92053223e-02,   2.99987793e-02],
                        [  2.79235840e-02,   3.28063965e-02],
                        [  2.75268555e-02,   3.46679688e-02],
                        [  2.49633789e-02,   3.22265625e-02],
                        [  2.05078125e-02,   2.60314941e-02],
                        [  1.51062012e-02,   1.77612305e-02],
                        [  9.61303711e-03,   9.36889648e-03],
                        [  3.78417969e-03,   1.46484375e-03],
                        [ -3.50952148e-03,  -6.40869141e-03],
                        [ -1.24816895e-02,  -1.44958496e-02],
                        [ -2.13928223e-02,  -2.14843750e-02],
                        [ -2.67028809e-02,  -2.46276855e-02],
                        [ -2.53906250e-02,  -2.18200684e-02],
                        [ -1.69067383e-02,  -1.31530762e-02],
                        [ -3.96728516e-03,  -1.61743164e-03],
                        [  7.93457031e-03,   7.56835938e-03],
                        [  1.43737793e-02,   1.07421875e-02],
                        [  1.69677734e-02,   1.05590820e-02],
                        [  2.16979980e-02,   1.38244629e-02],
                        [  3.10668945e-02,   2.36206055e-02],
                        [  4.10156250e-02,   3.59802246e-02],
                        [  4.77294922e-02,   4.66003418e-02],
                        [  5.41992188e-02,   5.75256348e-02],
                        [  6.63146973e-02,   7.35473633e-02],
                        [  8.37707520e-02,   9.33837891e-02],
                        [  9.68017578e-02,   1.06658936e-01],
                        [  9.08508301e-02,   9.87548828e-02],
                        [  5.58166504e-02,   6.00891113e-02],
                        [ -7.01904297e-03,  -7.23266602e-03],
                        [ -8.67004395e-02,  -9.11865234e-02],
                        [ -1.69067383e-01,  -1.76635742e-01],
                        [ -2.38220215e-01,  -2.47100830e-01],
                        [ -2.76062012e-01,  -2.84332275e-01],
                        [ -2.71301270e-01,  -2.77374268e-01],
                        [ -2.33520508e-01,  -2.36419678e-01],
                        [ -1.89941406e-01,  -1.89453125e-01],
                        [ -1.60430908e-01,  -1.57135010e-01],
                        [ -1.42639160e-01,  -1.37542725e-01],
                        [ -1.25854492e-01,  -1.20147705e-01],
                        [ -1.08062744e-01,  -1.02813721e-01],
                        [ -9.27124023e-02,  -8.86535645e-02],
                        [ -7.93151855e-02,  -7.68432617e-02],
                        [ -6.44226074e-02,  -6.35375977e-02],
                        [ -4.69665527e-02,  -4.74853516e-02],
                        [ -2.93884277e-02,  -3.09753418e-02],
                        [ -1.51977539e-02,  -1.76696777e-02],
                        [ -7.44628906e-03,  -1.05590820e-02],
                        [ -6.31713867e-03,  -9.82666016e-03],
                        [ -7.01904297e-03,  -1.05895996e-02],
                        [ -4.02832031e-03,  -7.26318359e-03],
                        [  1.83105469e-03,  -4.88281250e-04],
                        [  5.00488281e-03,   4.11987305e-03],
                        [  4.36401367e-03,   5.34057617e-03],
                        [  5.31005859e-03,   8.23974609e-03],
                        [  1.00097656e-02,   1.44958496e-02],
                        [  1.20849609e-02,   1.73645020e-02],
                        [  6.22558594e-03,   1.11999512e-02],
                        [ -3.87573242e-03,  -3.35693359e-04],
                        [ -1.21765137e-02,  -1.09558105e-02],
                        [ -1.64794922e-02,  -1.79748535e-02],
                        [ -1.36413574e-02,  -1.75476074e-02],
                        [  1.92260742e-03,  -3.50952148e-03],
                        [  2.97546387e-02,   2.40783691e-02],
                        [  6.27136230e-02,   5.81665039e-02],
                        [  9.83276367e-02,   9.59777832e-02],
                        [  1.41876221e-01,   1.42181396e-01],
                        [  1.94580078e-01,   1.97204590e-01],
                        [  2.45239258e-01,   2.49298096e-01],
                        [  2.73590088e-01,   2.77801514e-01],
                        [  2.57415771e-01,   2.60528564e-01],
                        [  1.85272217e-01,   1.86462402e-01],
                        [  7.25708008e-02,   7.17163086e-02],
                        [ -4.09545898e-02,  -4.33044434e-02],
                        [ -1.16577148e-01,  -1.19262695e-01],
                        [ -1.39068604e-01,  -1.40777588e-01],
                        [ -1.19110107e-01,  -1.18865967e-01],
                        [ -8.09020996e-02,  -7.83691406e-02],
                        [ -4.53796387e-02,  -4.11071777e-02],
                        [ -2.06604004e-02,  -1.59301758e-02],
                        [ -5.52368164e-03,  -2.01416016e-03],
                        [  6.71386719e-04,   1.31225586e-03],
                        [ -4.73022461e-03,  -7.90405273e-03],
                        [ -2.02941895e-02,  -2.71911621e-02],
                        [ -3.55834961e-02,  -4.50439453e-02],
                        [ -3.88183594e-02,  -4.86145020e-02],
                        [ -2.79235840e-02,  -3.54919434e-02],
                        [ -1.11389160e-02,  -1.41601562e-02],
                        [  4.66918945e-03,   7.56835938e-03],
                        [  2.16674805e-02,   3.05175781e-02],
                        [  4.33654785e-02,   5.65795898e-02],
                        [  6.37512207e-02,   7.86132812e-02],
                        [  7.20214844e-02,   8.51135254e-02],
                        [  6.46667480e-02,   7.29064941e-02],
                        [  4.85839844e-02,   4.98046875e-02],
                        [  3.38745117e-02,   2.75268555e-02],
                        [  2.50549316e-02,   1.23596191e-02],
                        [  1.80969238e-02,   1.80053711e-03],
                        [  7.01904297e-03,  -9.33837891e-03],
                        [ -8.05664062e-03,  -2.09045410e-02],
                        [ -2.14843750e-02,  -2.81066895e-02],
                        [ -2.85949707e-02,  -2.77099609e-02],
                        [ -2.82592773e-02,  -2.03552246e-02],
                        [ -2.33154297e-02,  -1.04675293e-02],
                        [ -2.04162598e-02,  -5.64575195e-03],
                        [ -2.44750977e-02,  -1.10473633e-02],
                        [ -3.28369141e-02,  -2.34680176e-02],
                        [ -3.77807617e-02,  -3.41186523e-02],
                        [ -3.14331055e-02,  -3.35998535e-02],
                        [ -6.86645508e-03,  -1.37329102e-02],
                        [  3.61022949e-02,   2.66113281e-02],
                        [  8.34960938e-02,   7.37915039e-02],
                        [  1.14166260e-01,   1.06384277e-01],
                        [  1.16546631e-01,   1.11999512e-01],
                        [  9.57031250e-02,   9.48181152e-02],
                        [  6.65893555e-02,   6.87866211e-02],
                        [  4.19616699e-02,   4.61120605e-02],
                        [  2.62451172e-02,   3.09448242e-02],
                        [  1.76696777e-02,   2.16674805e-02],
                        [  1.38244629e-02,   1.63574219e-02],
                        [  1.40380859e-02,   1.48620605e-02],
                        [  1.80053711e-02,   1.74255371e-02],
                        [  2.38342285e-02,   2.24304199e-02],
                        [  2.67639160e-02,   2.51464844e-02],
                        [  2.00500488e-02,   1.87072754e-02],
                        [  7.32421875e-04,  -9.15527344e-05],
                        [ -2.41088867e-02,  -2.43835449e-02],
                        [ -4.09851074e-02,  -4.08325195e-02],
                        [ -4.11987305e-02,  -4.07409668e-02],
                        [ -2.58178711e-02,  -2.50549316e-02],
                        [ -3.44848633e-03,  -2.38037109e-03],
                        [  1.39160156e-02,   1.53808594e-02],
                        [  1.88293457e-02,   2.06604004e-02],
                        [  1.47705078e-02,   1.67236328e-02],
                        [  1.21765137e-02,   1.37329102e-02],
                        [  1.83410645e-02,   1.88598633e-02],
                        [  3.36914062e-02,   3.25317383e-02],
                        [  5.53283691e-02,   5.21850586e-02],
                        [  8.04748535e-02,   7.54394531e-02],
                        [  1.04797363e-01,   9.86328125e-02],
                        [  1.20819092e-01,   1.14807129e-01],
                        [  1.20147705e-01,   1.15814209e-01],
                        [  9.89074707e-02,   9.76867676e-02],
                        [  6.03027344e-02,   6.31103516e-02],
                        [  6.77490234e-03,   1.36413574e-02],
                        [ -6.63757324e-02,  -5.65185547e-02],
                        [ -1.57012939e-01,  -1.46057129e-01],
                        [ -2.39868164e-01,  -2.30194092e-01],
                        [ -2.81219482e-01,  -2.75177002e-01],
                        [ -2.69989014e-01,  -2.69256592e-01],
                        [ -2.25891113e-01,  -2.30957031e-01],
                        [ -1.81091309e-01,  -1.91162109e-01],
                        [ -1.56585693e-01,  -1.69616699e-01],
                        [ -1.49749756e-01,  -1.62933350e-01],
                        [ -1.42639160e-01,  -1.53106689e-01],
                        [ -1.23962402e-01,  -1.29394531e-01],
                        [ -9.97619629e-02,  -9.90600586e-02],
                        [ -8.19396973e-02,  -7.54089355e-02],
                        [ -7.26013184e-02,  -6.19201660e-02],
                        [ -6.48803711e-02,  -5.25512695e-02],
                        [ -5.33142090e-02,  -4.21447754e-02],
                        [ -3.81164551e-02,  -3.04260254e-02],
                        [ -2.32543945e-02,  -2.03552246e-02],
                        [ -1.23291016e-02,  -1.43127441e-02],
                        [ -3.81469727e-03,  -9.58251953e-03],
                        [  6.28662109e-03,  -1.43432617e-03],
                        [  1.64184570e-02,   8.88061523e-03],
                        [  2.20947266e-02,   1.63879395e-02],
                        [  2.33459473e-02,   2.03247070e-02],
                        [  2.15148926e-02,   2.11791992e-02],
                        [  1.43432617e-02,   1.58386230e-02],
                        [  2.68554688e-03,   4.76074219e-03],
                        [ -5.67626953e-03,  -4.11987305e-03],
                        [ -5.98144531e-03,  -5.55419922e-03],
                        [ -2.68554688e-03,  -3.29589844e-03],
                        [ -1.37329102e-03,  -2.22778320e-03],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -4.76074219e-03,  -2.89916992e-03],
                        [ -3.08227539e-03,   1.03759766e-03],
                        [  1.43127441e-02,   2.02331543e-02],
                        [  5.92346191e-02,   6.55822754e-02],
                        [  1.30279541e-01,   1.35162354e-01],
                        [  2.11425781e-01,   2.13012695e-01],
                        [  2.82348633e-01,   2.79296875e-01],
                        [  3.25988770e-01,   3.18206787e-01],
                        [  3.29345703e-01,   3.18023682e-01],
                        [  2.83477783e-01,   2.71026611e-01],
                        [  1.88262939e-01,   1.77764893e-01],
                        [  5.87158203e-02,   5.31311035e-02],
                        [ -7.26318359e-02,  -7.12890625e-02],
                        [ -1.64733887e-01,  -1.56097412e-01],
                        [ -1.90246582e-01,  -1.75750732e-01],
                        [ -1.56494141e-01,  -1.39129639e-01],
                        [ -1.01348877e-01,  -8.51440430e-02],
                        [ -6.06689453e-02,  -4.95910645e-02],
                        [ -4.05273438e-02,  -3.75061035e-02],
                        [ -2.62756348e-02,  -3.24401855e-02],
                        [ -1.06201172e-02,  -2.49328613e-02],
                        [ -3.96728516e-04,  -1.98669434e-02],
                        [ -3.14331055e-03,  -2.33764648e-02],
                        [ -1.61743164e-02,  -3.25622559e-02],
                        [ -2.70080566e-02,  -3.57971191e-02],
                        [ -2.32849121e-02,  -2.24304199e-02],
                        [ -4.94384766e-03,   5.34057617e-03],
                        [  1.74865723e-02,   3.48510742e-02],
                        [  3.67126465e-02,   5.71899414e-02],
                        [  5.28869629e-02,   7.18688965e-02],
                        [  6.44836426e-02,   7.78808594e-02],
                        [  6.41784668e-02,   6.92749023e-02],
                        [  4.86755371e-02,   4.47692871e-02],
                        [  2.59094238e-02,   1.43432617e-02],
                        [  7.23266602e-03,  -8.94165039e-03],
                        [ -2.96020508e-03,  -1.99279785e-02],
                        [ -7.56835938e-03,  -2.16064453e-02],
                        [ -1.04980469e-02,  -1.87988281e-02],
                        [ -1.26342773e-02,  -1.40380859e-02],
                        [ -1.38244629e-02,  -8.78906250e-03],
                        [ -1.64794922e-02,  -6.92749023e-03],
                        [ -2.22167969e-02,  -1.08947754e-02],
                        [ -2.70690918e-02,  -1.68151855e-02],
                        [ -2.79235840e-02,  -2.08740234e-02],
                        [ -2.85949707e-02,  -2.59399414e-02],
                        [ -3.25317383e-02,  -3.41186523e-02],
                        [ -3.43322754e-02,  -3.89709473e-02],
                        [ -2.35595703e-02,  -2.94494629e-02],
                        [  7.01904297e-03,   1.80053711e-03],
                        [  5.44128418e-02,   5.13305664e-02],
                        [  1.02111816e-01,   1.01806641e-01],
                        [  1.28692627e-01,   1.31011963e-01],
                        [  1.25152588e-01,   1.29058838e-01],
                        [  1.00250244e-01,   1.04370117e-01],
                        [  6.99462891e-02,   7.29370117e-02],
                        [  4.64477539e-02,   4.71801758e-02],
                        [  3.38745117e-02,   3.20129395e-02],
                        [  2.87475586e-02,   2.45666504e-02],
                        [  2.56347656e-02,   1.99890137e-02],
                        [  2.29187012e-02,   1.70288086e-02],
                        [  2.00195312e-02,   1.52282715e-02],
                        [  1.34582520e-02,   1.08032227e-02],
                        [  1.06811523e-03,   1.22070312e-03],
                        [ -1.38244629e-02,  -1.08032227e-02],
                        [ -2.48718262e-02,  -1.94091797e-02],
                        [ -2.64282227e-02,  -1.93481445e-02],
                        [ -1.68762207e-02,  -9.30786133e-03],
                        [ -1.80053711e-03,   5.03540039e-03],
                        [  8.54492188e-03,   1.36108398e-02],
                        [  8.81958008e-03,   1.12304688e-02],
                        [  4.02832031e-03,   3.29589844e-03],
                        [  3.47900391e-03,  -4.57763672e-04],
                        [  1.15356445e-02,   4.79125977e-03],
                        [  2.55737305e-02,   1.69067383e-02],
                        [  4.07409668e-02,   3.13415527e-02],
                        [  5.67626953e-02,   4.80957031e-02],
                        [  7.83386230e-02,   7.17773438e-02],
                        [  1.05194092e-01,   1.02050781e-01],
                        [  1.27288818e-01,   1.28204346e-01],
                        [  1.31835938e-01,   1.36962891e-01],
                        [  1.10534668e-01,   1.19232178e-01],
                        [  6.18286133e-02,   7.26928711e-02],
                        [ -7.75146484e-03,   3.54003906e-03],
                        [ -8.76159668e-02,  -7.79113770e-02],
                        [ -1.69219971e-01,  -1.62841797e-01],
                        [ -2.40783691e-01,  -2.38922119e-01],
                        [ -2.82135010e-01,  -2.85095215e-01],
                        [ -2.76458740e-01,  -2.83721924e-01],
                        [ -2.29095459e-01,  -2.39257812e-01],
                        [ -1.68243408e-01,  -1.79412842e-01],
                        [ -1.24206543e-01,  -1.34338379e-01],
                        [ -1.08825684e-01,  -1.16180420e-01],
                        [ -1.14715576e-01,  -1.18103027e-01],
                        [ -1.25885010e-01,  -1.25030518e-01],
                        [ -1.27136230e-01,  -1.22558594e-01],
                        [ -1.13220215e-01,  -1.06079102e-01],
                        [ -9.24682617e-02,  -8.43505859e-02],
                        [ -7.32421875e-02,  -6.56738281e-02],
                        [ -5.08728027e-02,  -4.50134277e-02],
                        [ -1.91955566e-02,  -1.58081055e-02],
                        [  1.20544434e-02,   1.29699707e-02],
                        [  2.81982422e-02,   2.69775391e-02],
                        [  2.95104980e-02,   2.69165039e-02],
                        [  2.56347656e-02,   2.23999023e-02],
                        [  1.80969238e-02,   1.48925781e-02],
                        [  4.39453125e-03,   1.52587891e-03],
                        [ -1.02233887e-02,  -1.27258301e-02],
                        [ -1.80969238e-02,  -2.03552246e-02],
                        [ -2.06604004e-02,  -2.28271484e-02],
                        [ -2.34680176e-02,  -2.56042480e-02],
                        [ -2.49328613e-02,  -2.68249512e-02],
                        [ -2.05078125e-02,  -2.17895508e-02],
                        [ -1.44653320e-02,  -1.45568848e-02],
                        [ -1.47399902e-02,  -1.32141113e-02],
                        [ -1.94091797e-02,  -1.59912109e-02],
                        [ -1.84936523e-02,  -1.33972168e-02],
                        [ -5.70678711e-03,   3.66210938e-04],
                        [  2.22167969e-02,   2.82592773e-02],
                        [  7.24182129e-02,   7.71179199e-02],
                        [  1.47735596e-01,   1.49963379e-01],
                        [  2.32635498e-01,   2.31567383e-01],
                        [  2.98645020e-01,   2.94128418e-01],
                        [  3.25927734e-01,   3.18542480e-01],
                        [  3.13262939e-01,   3.04260254e-01],
                        [  2.70019531e-01,   2.61138916e-01],
                        [  2.03948975e-01,   1.96990967e-01],
                        [  1.17065430e-01,   1.13647461e-01],
                        [  1.40686035e-02,   1.51367188e-02],
                        [ -8.65478516e-02,  -8.09631348e-02],
                        [ -1.54693604e-01,  -1.45477295e-01],
                        [ -1.67083740e-01,  -1.55944824e-01],
                        [ -1.29241943e-01,  -1.18347168e-01],
                        [ -7.75146484e-02,  -6.90612793e-02],
                        [ -4.91638184e-02,  -4.50134277e-02],
                        [ -4.96215820e-02,  -5.07202148e-02],
                        [ -5.76477051e-02,  -6.39953613e-02],
                        [ -5.69763184e-02,  -6.74743652e-02],
                        [ -4.94995117e-02,  -6.21948242e-02],
                        [ -4.17480469e-02,  -5.41687012e-02],
                        [ -3.32946777e-02,  -4.29687500e-02],
                        [ -2.08129883e-02,  -2.58178711e-02],
                        [ -3.93676758e-03,  -3.20434570e-03],
                        [  1.56860352e-02,   2.21557617e-02],
                        [  3.59191895e-02,   4.69055176e-02],
                        [  5.28259277e-02,   6.62536621e-02],
                        [  6.20117188e-02,   7.52563477e-02],
                        [  6.07910156e-02,   7.13500977e-02],
                        [  4.87365723e-02,   5.45959473e-02],
                        [  2.76794434e-02,   2.77404785e-02],
                        [  2.62451172e-03,  -3.02124023e-03],
                        [ -1.80969238e-02,  -2.82592773e-02],
                        [ -2.66418457e-02,  -3.92761230e-02],
                        [ -2.25830078e-02,  -3.51867676e-02],
                        [ -1.36718750e-02,  -2.38952637e-02],
                        [ -7.93457031e-03,  -1.39770508e-02],
                        [ -8.33129883e-03,  -9.33837891e-03],
                        [ -1.48925781e-02,  -1.09863281e-02],
                        [ -2.62756348e-02,  -1.86462402e-02],
                        [ -4.03137207e-02,  -3.06701660e-02],
                        [ -5.43212891e-02,  -4.47082520e-02],
                        [ -6.41174316e-02,  -5.63049316e-02],
                        [ -6.25000000e-02,  -5.76782227e-02],
                        [ -4.21142578e-02,  -4.06494141e-02],
                        [ -1.19018555e-03,  -2.74658203e-03],
                        [  5.24597168e-02,   4.88281250e-02],
                        [  1.03179932e-01,   9.87243652e-02],
                        [  1.34277344e-01,   1.30065918e-01],
                        [  1.35955811e-01,   1.32720947e-01],
                        [  1.09802246e-01,   1.07696533e-01],
                        [  6.84814453e-02,   6.72302246e-02],
                        [  3.13415527e-02,   3.03649902e-02],
                        [  1.34277344e-02,   1.21154785e-02],
                        [  1.48010254e-02,   1.28479004e-02],
                        [  2.35900879e-02,   2.10876465e-02],
                        [  2.86865234e-02,   2.63061523e-02],
                        [  2.61840820e-02,   2.48413086e-02],
                        [  1.76391602e-02,   1.83105469e-02],
                        [  6.77490234e-03,   1.00708008e-02],
                        [ -4.21142578e-03,   1.80053711e-03],
                        [ -1.50146484e-02,  -7.08007812e-03],
                        [ -2.39562988e-02,  -1.54724121e-02],
                        [ -2.75878906e-02,  -2.04467773e-02],
                        [ -2.41699219e-02,  -2.01721191e-02],
                        [ -1.48315430e-02,  -1.52893066e-02],
                        [ -3.41796875e-03,  -8.75854492e-03],
                        [  4.85229492e-03,  -4.57763672e-03],
                        [  8.81958008e-03,  -3.02124023e-03],
                        [  1.46789551e-02,   2.86865234e-03],
                        [  2.91442871e-02,   1.99890137e-02],
                        [  5.02624512e-02,   4.58068848e-02],
                        [  7.11669922e-02,   7.25402832e-02],
                        [  8.88671875e-02,   9.58557129e-02],
                        [  1.02416992e-01,   1.13525391e-01],
                        [  1.11053467e-01,   1.23779297e-01],
                        [  1.16363525e-01,   1.27899170e-01],
                        [  1.15112305e-01,   1.22863770e-01],
                        [  9.15222168e-02,   9.38415527e-02],
                        [  3.13720703e-02,   2.78625488e-02],
                        [ -5.99060059e-02,  -6.82067871e-02],
                        [ -1.62353516e-01,  -1.73370361e-01],
                        [ -2.56072998e-01,  -2.67059326e-01],
                        [ -3.21319580e-01,  -3.29620361e-01],
                        [ -3.37127686e-01,  -3.40850830e-01],
                        [ -2.97515869e-01,  -2.95959473e-01],
                        [ -2.26745605e-01,  -2.20489502e-01],
                        [ -1.62170410e-01,  -1.52923584e-01],
                        [ -1.21398926e-01,  -1.11633301e-01],
                        [ -9.65881348e-02,  -8.87756348e-02],
                        [ -7.65075684e-02,  -7.26013184e-02],
                        [ -6.20727539e-02,  -6.29882812e-02],
                        [ -5.99975586e-02,  -6.54296875e-02],
                        [ -6.92138672e-02,  -7.77587891e-02],
                        [ -7.73925781e-02,  -8.69140625e-02],
                        [ -7.00073242e-02,  -7.81250000e-02],
                        [ -4.40368652e-02,  -4.88281250e-02],
                        [ -1.28784180e-02,  -1.32446289e-02],
                        [  5.98144531e-03,   1.01013184e-02],
                        [  7.99560547e-03,   1.55639648e-02],
                        [  2.25830078e-03,   1.15661621e-02],
                        [ -1.86157227e-03,   7.08007812e-03],
                        [ -2.28881836e-03,   4.39453125e-03],
                        [ -8.85009766e-04,   2.19726562e-03],
                        [  3.96728516e-04,  -6.10351562e-04],
                        [ -1.46484375e-03,  -6.16455078e-03],
                        [ -1.06201172e-02,  -1.78833008e-02],
                        [ -2.70690918e-02,  -3.53393555e-02],
                        [ -4.29382324e-02,  -5.05981445e-02],
                        [ -4.93469238e-02,  -5.50231934e-02],
                        [ -4.57458496e-02,  -4.85534668e-02],
                        [ -3.66210938e-02,  -3.63464355e-02],
                        [ -1.93786621e-02,  -1.62963867e-02],
                        [  1.56860352e-02,   2.07824707e-02],
                        [  7.15942383e-02,   7.77282715e-02],
                        [  1.38122559e-01,   1.44226074e-01],
                        [  2.00439453e-01,   2.05566406e-01],
                        [  2.48107910e-01,   2.51586914e-01],
                        [  2.74932861e-01,   2.76367188e-01],
                        [  2.77709961e-01,   2.76977539e-01],
                        [  2.60162354e-01,   2.57507324e-01],
                        [  2.34069824e-01,   2.29949951e-01],
                        [  2.07366943e-01,   2.02453613e-01],
                        [  1.71905518e-01,   1.66961670e-01],
                        [  1.12426758e-01,   1.08276367e-01],
                        [  2.70080566e-02,   2.43835449e-02],
                        [ -6.62231445e-02,  -6.68334961e-02],
                        [ -1.38610840e-01,  -1.37084961e-01],
                        [ -1.67968750e-01,  -1.64550781e-01],
                        [ -1.55670166e-01,  -1.51031494e-01],
                        [ -1.24969482e-01,  -1.20025635e-01],
                        [ -9.92736816e-02,  -9.51538086e-02],
                        [ -8.60290527e-02,  -8.36486816e-02],
                        [ -7.98034668e-02,  -7.98339844e-02],
                        [ -7.26318359e-02,  -7.51037598e-02],
                        [ -5.96313477e-02,  -6.40258789e-02],
                        [ -4.04052734e-02,  -4.57153320e-02],
                        [ -1.95312500e-02,  -2.44445801e-02],
                        [ -3.60107422e-03,  -6.80541992e-03],
                        [  6.62231445e-03,   6.07299805e-03],
                        [  1.73950195e-02,   1.98059082e-02],
                        [  3.12194824e-02,   3.61938477e-02],
                        [  4.19006348e-02,   4.83398438e-02],
                        [  4.41589355e-02,   5.05065918e-02],
                        [  4.13208008e-02,   4.59289551e-02],
                        [  3.73229980e-02,   3.88793945e-02],
                        [  2.89306641e-02,   2.67944336e-02],
                        [  1.40075684e-02,   8.48388672e-03],
                        [  9.15527344e-05,  -7.72094727e-03],
                        [ -6.62231445e-03,  -1.49841309e-02],
                        [ -1.11083984e-02,  -1.80053711e-02],
                        [ -1.80358887e-02,  -2.17590332e-02],
                        [ -2.28576660e-02,  -2.23999023e-02],
                        [ -2.49023438e-02,  -2.02026367e-02],
                        [ -3.35083008e-02,  -2.55432129e-02],
                        [ -5.03845215e-02,  -4.08935547e-02],
                        [ -6.16455078e-02,  -5.27648926e-02],
                        [ -5.66406250e-02,  -5.04150391e-02],
                        [ -4.08935547e-02,  -3.87878418e-02],
                        [ -2.30407715e-02,  -2.55432129e-02],
                        [ -1.40380859e-03,  -7.87353516e-03],
                        [  3.01513672e-02,   2.12097168e-02],
                        [  6.94580078e-02,   6.01196289e-02],
                        [  1.04095459e-01,   9.64965820e-02],
                        [  1.19903564e-01,   1.15753174e-01],
                        [  1.10809326e-01,   1.10931396e-01],
                        [  8.34045410e-02,   8.76159668e-02],
                        [  5.51452637e-02,   6.23474121e-02],
                        [  4.27856445e-02,   5.11169434e-02],
                        [  4.59594727e-02,   5.34057617e-02],
                        [  4.75463867e-02,   5.23986816e-02],
                        [  3.50952148e-02,   3.63769531e-02],
                        [  1.47399902e-02,   1.23291016e-02],
                        [ -1.12915039e-03,  -6.43920898e-03],
                        [ -1.00708008e-02,  -1.68762207e-02],
                        [ -1.66931152e-02,  -2.31933594e-02],
                        [ -2.13317871e-02,  -2.60009766e-02],
                        [ -2.19421387e-02,  -2.38037109e-02],
                        [ -1.98364258e-02,  -1.85852051e-02],
                        [ -1.61132812e-02,  -1.23291016e-02],
                        [ -8.81958008e-03,  -3.57055664e-03],
                        [  2.28881836e-03,   7.56835938e-03],
                        [  1.35192871e-02,   1.75476074e-02],
                        [  2.05688477e-02,   2.24914551e-02],
                        [  2.32543945e-02,   2.28576660e-02],
                        [  2.93884277e-02,   2.70385742e-02],
                        [  4.80346680e-02,   4.45861816e-02],
                        [  7.71789551e-02,   7.36694336e-02],
                        [  1.05224609e-01,   1.02600098e-01],
                        [  1.24938965e-01,   1.23748779e-01],
                        [  1.37298584e-01,   1.37573242e-01],
                        [  1.41571045e-01,   1.42852783e-01],
                        [  1.28967285e-01,   1.30462646e-01],
                        [  8.75854492e-02,   8.85620117e-02],
                        [  1.23291016e-02,   1.22375488e-02],
                        [ -8.95385742e-02,  -9.07592773e-02],
                        [ -1.96685791e-01,  -1.98638916e-01],
                        [ -2.78320312e-01,  -2.80181885e-01],
                        [ -3.08990479e-01,  -3.09814453e-01],
                        [ -2.85614014e-01,  -2.84637451e-01],
                        [ -2.30438232e-01,  -2.27325439e-01],
                        [ -1.75933838e-01,  -1.71051025e-01],
                        [ -1.43402100e-01,  -1.37664795e-01],
                        [ -1.30889893e-01,  -1.25732422e-01],
                        [ -1.20910645e-01,  -1.17858887e-01],
                        [ -1.01440430e-01,  -1.01684570e-01],
                        [ -7.80944824e-02,  -8.21533203e-02],
                        [ -6.34765625e-02,  -7.09533691e-02],
                        [ -5.86242676e-02,  -6.82373047e-02],
                        [ -5.27648926e-02,  -6.25610352e-02],
                        [ -3.92456055e-02,  -4.70581055e-02],
                        [ -2.20031738e-02,  -2.59094238e-02],
                        [ -7.53784180e-03,  -6.37817383e-03],
                        [  2.41088867e-03,   8.72802734e-03],
                        [  9.64355469e-03,   2.00195312e-02],
                        [  1.49536133e-02,   2.74047852e-02],
                        [  1.51672363e-02,   2.71606445e-02],
                        [  5.58471680e-03,   1.46789551e-02],
                        [ -1.16882324e-02,  -7.41577148e-03],
                        [ -2.58789062e-02,  -2.72521973e-02],
                        [ -2.95104980e-02,  -3.61938477e-02],
                        [ -2.85339355e-02,  -3.90014648e-02],
                        [ -3.28979492e-02,  -4.50134277e-02],
                        [ -4.23583984e-02,  -5.36193848e-02],
                        [ -4.71496582e-02,  -5.54504395e-02],
                        [ -4.03442383e-02,  -4.43115234e-02],
                        [ -2.25524902e-02,  -2.18200684e-02],
                        [  6.80541992e-03,   1.15356445e-02],
                        [  5.49316406e-02,   6.23168945e-02],
                        [  1.23382568e-01,   1.31622314e-01],
                        [  1.94458008e-01,   2.01904297e-01],
                        [  2.41271973e-01,   2.46734619e-01],
                        [  2.51373291e-01,   2.54364014e-01],
                        [  2.36816406e-01,   2.37487793e-01],
                        [  2.21160889e-01,   2.20153809e-01],
                        [  2.18078613e-01,   2.16247559e-01],
                        [  2.22198486e-01,   2.20214844e-01],
                        [  2.17742920e-01,   2.16003418e-01],
                        [  1.91284180e-01,   1.89666748e-01],
                        [  1.38122559e-01,   1.36322021e-01],
                        [  6.36901855e-02,   6.11877441e-02],
                        [ -1.99890137e-02,  -2.34985352e-02],
                        [ -9.75036621e-02,  -1.01867676e-01],
                        [ -1.50939941e-01,  -1.55548096e-01],
                        [ -1.65832520e-01,  -1.69647217e-01],
                        [ -1.44927979e-01,  -1.46789551e-01],
                        [ -1.12426758e-01,  -1.11358643e-01],
                        [ -9.42077637e-02,  -8.98132324e-02],
                        [ -9.24987793e-02,  -8.51135254e-02],
                        [ -8.86840820e-02,  -7.94982910e-02],
                        [ -7.02209473e-02,  -6.09741211e-02],
                        [ -4.28161621e-02,  -3.54919434e-02],
                        [ -1.67846680e-02,  -1.31225586e-02],
                        [  5.12695312e-03,   4.08935547e-03],
                        [  2.37731934e-02,   1.80053711e-02],
                        [  3.64074707e-02,   2.69775391e-02],
                        [  3.94592285e-02,   2.82592773e-02],
                        [  3.50036621e-02,   2.43835449e-02],
                        [  2.96936035e-02,   2.18811035e-02],
                        [  2.71301270e-02,   2.36816406e-02],
                        [  2.64282227e-02,   2.79235840e-02],
                        [  2.73437500e-02,   3.33251953e-02],
                        [  2.92663574e-02,   3.82385254e-02],
                        [  2.57568359e-02,   3.57360840e-02],
                        [  9.55200195e-03,   1.84020996e-02],
                        [ -1.59912109e-02,  -9.91821289e-03],
                        [ -3.85437012e-02,  -3.61938477e-02],
                        [ -5.06896973e-02,  -5.20629883e-02],
                        [ -5.49621582e-02,  -5.93261719e-02],
                        [ -5.68542480e-02,  -6.29272461e-02],
                        [ -5.87768555e-02,  -6.51550293e-02],
                        [ -5.93261719e-02,  -6.47888184e-02],
                        [ -5.45349121e-02,  -5.83801270e-02],
                        [ -4.03137207e-02,  -4.22973633e-02],
                        [ -1.54724121e-02,  -1.58691406e-02],
                        [  1.62963867e-02,   1.70898438e-02],
                        [  4.92858887e-02,   5.08117676e-02],
                        [  8.02917480e-02,   8.23059082e-02],
                        [  1.06597900e-01,   1.09100342e-01],
                        [  1.20117188e-01,   1.23229980e-01],
                        [  1.13067627e-01,   1.16882324e-01],
                        [  9.00878906e-02,   9.44213867e-02],
                        [  6.55517578e-02,   6.98242188e-02],
                        [  4.75158691e-02,   5.08117676e-02],
                        [  3.23791504e-02,   3.36303711e-02],
                        [  1.64794922e-02,   1.48315430e-02],
                        [  4.51660156e-03,  -4.57763672e-04],
                        [  3.17382812e-03,  -4.73022461e-03],
                        [  1.07116699e-02,   1.15966797e-03],
                        [  1.57470703e-02,   6.43920898e-03],
                        [  8.17871094e-03,   1.37329102e-03],
                        [ -7.93457031e-03,  -1.02844238e-02],
                        [ -1.89819336e-02,  -1.57165527e-02],
                        [ -1.84936523e-02,  -9.70458984e-03],
                        [ -1.11083984e-02,   1.73950195e-03],
                        [ -2.74658203e-03,   1.15661621e-02],
                        [  3.47900391e-03,   1.60522461e-02],
                        [  5.79833984e-03,   1.36718750e-02],
                        [  6.19506836e-03,   7.26318359e-03],
                        [  1.15661621e-02,   5.21850586e-03],
                        [  2.75573730e-02,   1.49230957e-02],
                        [  5.27954102e-02,   3.65295410e-02],
                        [  8.32824707e-02,   6.70166016e-02],
                        [  1.18011475e-01,   1.05407715e-01],
                        [  1.51672363e-01,   1.45629883e-01],
                        [  1.68334961e-01,   1.70196533e-01],
                        [  1.53259277e-01,   1.62567139e-01],
                        [  1.06689453e-01,   1.21185303e-01],
                        [  3.86352539e-02,   5.49316406e-02],
                        [ -4.35180664e-02,  -2.91748047e-02],
                        [ -1.34490967e-01,  -1.25305176e-01],
                        [ -2.21282959e-01,  -2.19085693e-01],
                        [ -2.81188965e-01,  -2.86132812e-01],
                        [ -2.94647217e-01,  -3.05114746e-01],
                        [ -2.61260986e-01,  -2.74383545e-01],
                        [ -2.04345703e-01,  -2.16827393e-01],
                        [ -1.56341553e-01,  -1.65252686e-01],
                        [ -1.34582520e-01,  -1.38031006e-01],
                        [ -1.31103516e-01,  -1.28723145e-01],
                        [ -1.26403809e-01,  -1.19354248e-01],
                        [ -1.09191895e-01,  -9.97009277e-02],
                        [ -8.31909180e-02,  -7.39440918e-02],
                        [ -6.01806641e-02,  -5.36193848e-02],
                        [ -4.73022461e-02,  -4.49523926e-02],
                        [ -4.00085449e-02,  -4.21447754e-02],
                        [ -2.98156738e-02,  -3.54919434e-02],
                        [ -1.64184570e-02,  -2.37731934e-02],
                        [ -5.82885742e-03,  -1.27258301e-02],
                        [ -6.10351562e-05,  -4.57763672e-03],
                        [  3.14331055e-03,   2.10571289e-03],
                        [  1.83105469e-03,   4.45556641e-03],
                        [ -8.94165039e-03,  -3.50952148e-03],
                        [ -2.67944336e-02,  -2.01110840e-02],
                        [ -4.11071777e-02,  -3.48815918e-02],
                        [ -4.48608398e-02,  -4.05578613e-02],
                        [ -4.29992676e-02,  -4.15039062e-02],
                        [ -4.41284180e-02,  -4.55627441e-02],
                        [ -4.65698242e-02,  -5.02624512e-02],
                        [ -4.04357910e-02,  -4.54101562e-02],
                        [ -2.20642090e-02,  -2.71606445e-02],
                        [  2.65502930e-03,  -1.61743164e-03],
                        [  2.89001465e-02,   2.60314941e-02],
                        [  5.94177246e-02,   5.80749512e-02],
                        [  9.87548828e-02,   9.87243652e-02],
                        [  1.44775391e-01,   1.45721436e-01],
                        [  1.88079834e-01,   1.89666748e-01],
                        [  2.17712402e-01,   2.19818115e-01],
                        [  2.27386475e-01,   2.30041504e-01],
                        [  2.21160889e-01,   2.24487305e-01],
                        [  2.12860107e-01,   2.16827393e-01],
                        [  2.12677002e-01,   2.16979980e-01],
                        [  2.15972900e-01,   2.20031738e-01],
                        [  2.11029053e-01,   2.13958740e-01],
                        [  1.90826416e-01,   1.91680908e-01],
                        [  1.52069092e-01,   1.50115967e-01],
                        [  8.98132324e-02,   8.48999023e-02],
                        [  3.17382812e-03,  -4.24194336e-03],
                        [ -9.33532715e-02,  -1.02050781e-01],
                        [ -1.70898438e-01,  -1.79138184e-01],
                        [ -2.04467773e-01,  -2.10449219e-01],
                        [ -1.91619873e-01,  -1.93847656e-01],
                        [ -1.53900146e-01,  -1.51580811e-01],
                        [ -1.19628906e-01,  -1.13006592e-01],
                        [ -1.00311279e-01,  -9.06372070e-02],
                        [ -8.41979980e-02,  -7.34558105e-02],
                        [ -5.63659668e-02,  -4.68444824e-02],
                        [ -1.91040039e-02,  -1.28784180e-02],
                        [  1.25427246e-02,   1.42517090e-02],
                        [  2.92663574e-02,   2.61840820e-02],
                        [  3.31726074e-02,   2.61535645e-02],
                        [  2.93579102e-02,   2.01721191e-02],
                        [  2.02331543e-02,   1.10168457e-02],
                        [  8.81958008e-03,   1.58691406e-03],
                        [ -3.35693359e-04,  -4.15039062e-03],
                        [ -5.18798828e-03,  -5.12695312e-03],
                        [ -6.10351562e-03,  -2.59399414e-03],
                        [ -2.62451172e-03,   3.05175781e-03],
                        [  3.08227539e-03,   9.30786133e-03],
                        [  3.47900391e-03,   8.63647461e-03],
                        [ -6.56127930e-03,  -3.47900391e-03],
                        [ -2.15148926e-02,  -2.09350586e-02],
                        [ -3.15551758e-02,  -3.30810547e-02],
                        [ -3.33251953e-02,  -3.61022949e-02],
                        [ -3.03955078e-02,  -3.33557129e-02],
                        [ -2.74047852e-02,  -2.96020508e-02],
                        [ -2.80761719e-02,  -2.89611816e-02],
                        [ -3.43933105e-02,  -3.39660645e-02],
                        [ -4.42504883e-02,  -4.29687500e-02],
                        [ -5.13305664e-02,  -4.98352051e-02],
                        [ -4.69665527e-02,  -4.59899902e-02],
                        [ -2.25830078e-02,  -2.24609375e-02],
                        [  2.43835449e-02,   2.36816406e-02],
                        [  8.16345215e-02,   8.04443359e-02],
                        [  1.24816895e-01,   1.23779297e-01],
                        [  1.36230469e-01,   1.35833740e-01],
                        [  1.18835449e-01,   1.19415283e-01],
                        [  9.02404785e-02,   9.16442871e-02],
                        [  6.66809082e-02,   6.83898926e-02],
                        [  5.23681641e-02,   5.36193848e-02],
                        [  4.00390625e-02,   4.00695801e-02],
                        [  2.22167969e-02,   2.06298828e-02],
                        [  1.15966797e-03,  -1.92260742e-03],
                        [ -1.51672363e-02,  -1.90734863e-02],
                        [ -2.22473145e-02,  -2.58483887e-02],
                        [ -2.04162598e-02,  -2.24609375e-02],
                        [ -1.19934082e-02,  -1.14746094e-02],
                        [ -1.28173828e-03,   2.13623047e-03],
                        [  4.60815430e-03,   1.05895996e-02],
                        [  1.40380859e-03,   8.78906250e-03],
                        [ -5.34057617e-03,   1.70898438e-03],
                        [ -5.98144531e-03,  -1.12915039e-03],
                        [  3.05175781e-04,   1.49536133e-03],
                        [  8.45336914e-03,   5.31005859e-03],
                        [  1.92260742e-02,   1.20239258e-02],
                        [  3.67126465e-02,   2.68249512e-02],
                        [  5.90209961e-02,   4.84924316e-02],
                        [  8.05664062e-02,   7.17163086e-02],
                        [  9.98840332e-02,   9.47265625e-02],
                        [  1.18835449e-01,   1.18591309e-01],
                        [  1.35711670e-01,   1.40563965e-01],
                        [  1.41693115e-01,   1.50665283e-01],
                        [  1.24603271e-01,   1.35894775e-01],
                        [  7.83996582e-02,   8.96301270e-02],
                        [  8.30078125e-03,   1.72119141e-02],
                        [ -7.48291016e-02,  -6.99768066e-02],
                        [ -1.62475586e-01,  -1.62536621e-01],
                        [ -2.43499756e-01,  -2.48229980e-01],
                        [ -2.95623779e-01,  -3.03955078e-01],
                        [ -2.97485352e-01,  -3.07678223e-01],
                        [ -2.53570557e-01,  -2.63580322e-01],
                        [ -1.96197510e-01,  -2.04254150e-01],
                        [ -1.55273438e-01,  -1.60064697e-01],
                        [ -1.33300781e-01,  -1.34185791e-01],
                        [ -1.16882324e-01,  -1.13983154e-01],
                        [ -1.00463867e-01,  -9.45434570e-02],
                        [ -8.69445801e-02,  -7.91625977e-02],
                        [ -7.54699707e-02,  -6.72302246e-02],
                        [ -6.28356934e-02,  -5.55419922e-02],
                        [ -5.08422852e-02,  -4.56848145e-02],
                        [ -4.17480469e-02,  -3.95202637e-02],
                        [ -3.06091309e-02,  -3.16162109e-02],
                        [ -1.20849609e-02,  -1.62048340e-02],
                        [  7.14111328e-03,   6.40869141e-04],
                        [  1.35192871e-02,   5.70678711e-03],
                        [  2.59399414e-03,  -5.09643555e-03],
                        [ -1.74560547e-02,  -2.35595703e-02],
                        [ -3.59191895e-02,  -3.92150879e-02],
                        [ -4.60205078e-02,  -4.56542969e-02],
                        [ -4.55627441e-02,  -4.14123535e-02],
                        [ -3.86047363e-02,  -3.14025879e-02],
                        [ -3.54919434e-02,  -2.66113281e-02],
                        [ -4.30908203e-02,  -3.44238281e-02],
                        [ -5.43823242e-02,  -4.78820801e-02],
                        [ -5.30700684e-02,  -5.03845215e-02],
                        [ -2.95410156e-02,  -3.15246582e-02],
                        [  1.29394531e-02,   6.46972656e-03],
                        [  6.44531250e-02,   5.47790527e-02],
                        [  1.16058350e-01,   1.05255127e-01],
                        [  1.62872314e-01,   1.53472900e-01],
                        [  2.00225830e-01,   1.94458008e-01],
                        [  2.18841553e-01,   2.18200684e-01],
                        [  2.13775635e-01,   2.18505859e-01],
                        [  1.96411133e-01,   2.05505371e-01],
                        [  1.86187744e-01,   1.97540283e-01],
                        [  1.89575195e-01,   2.00469971e-01],
                        [  1.96533203e-01,   2.04376221e-01],
                        [  1.95617676e-01,   1.98577881e-01],
                        [  1.82952881e-01,   1.80450439e-01],
                        [  1.58477783e-01,   1.51275635e-01],
                        [  1.21063232e-01,   1.11114502e-01],
                        [  6.68640137e-02,   5.67321777e-02],
                        [ -8.11767578e-03,  -1.58996582e-02],
                        [ -9.61914062e-02,  -9.98229980e-02],
                        [ -1.71386719e-01,  -1.70288086e-01],
                        [ -2.05993652e-01,  -2.00927734e-01],
                        [ -1.94793701e-01,  -1.87561035e-01],
                        [ -1.57196045e-01,  -1.50177002e-01],
                        [ -1.17218018e-01,  -1.12609863e-01],
                        [ -8.58154297e-02,  -8.48999023e-02],
                        [ -6.05163574e-02,  -6.34765625e-02],
                        [ -3.63769531e-02,  -4.20227051e-02],
                        [ -1.39465332e-02,  -2.02331543e-02],
                        [  3.96728516e-04,  -4.18090820e-03],
                        [  1.28173828e-03,   3.35693359e-04],
                        [ -7.90405273e-03,  -4.42504883e-03],
                        [ -1.61437988e-02,  -8.78906250e-03],
                        [ -1.51062012e-02,  -5.73730469e-03],
                        [ -4.85229492e-03,   3.84521484e-03],
                        [  1.02539062e-02,   1.55334473e-02],
                        [  2.42919922e-02,   2.40783691e-02],
                        [  2.78015137e-02,   2.14843750e-02],
                        [  1.51062012e-02,   3.63159180e-03],
                        [ -4.21142578e-03,  -1.84020996e-02],
                        [ -1.35498047e-02,  -2.71301270e-02],
                        [ -1.13525391e-02,  -2.09350586e-02],
                        [ -1.00708008e-02,  -1.31530762e-02],
                        [ -1.44042969e-02,  -9.94873047e-03],
                        [ -1.66015625e-02,  -5.40161133e-03],
                        [ -1.36413574e-02,   1.86157227e-03],
                        [ -1.24511719e-02,   3.87573242e-03],
                        [ -1.73645020e-02,  -3.81469727e-03],
                        [ -2.55432129e-02,  -1.77001953e-02],
                        [ -3.57971191e-02,  -3.51867676e-02],
                        [ -4.85229492e-02,  -5.49926758e-02],
                        [ -5.40466309e-02,  -6.57348633e-02],
                        [ -3.53698730e-02,  -4.94384766e-02],
                        [  1.18103027e-02,  -1.52587891e-03],
                        [  7.12585449e-02,   6.14013672e-02],
                        [  1.18865967e-01,   1.14074707e-01],
                        [  1.36657715e-01,   1.37207031e-01],
                        [  1.20422363e-01,   1.25335693e-01],
                        [  8.36791992e-02,   9.11254883e-02],
                        [  5.05676270e-02,   5.84411621e-02],
                        [  3.50036621e-02,   4.15649414e-02],
                        [  2.94494629e-02,   3.36608887e-02],
                        [  1.95617676e-02,   2.12707520e-02],
                        [  4.39453125e-03,   4.18090820e-03],
                        [ -5.40161133e-03,  -6.50024414e-03],
                        [ -2.68554688e-03,  -3.72314453e-03],
                        [  7.23266602e-03,   6.83593750e-03],
                        [  1.14746094e-02,   1.17187500e-02],
                        [  4.63867188e-03,   5.09643555e-03],
                        [ -3.02124023e-03,  -3.14331055e-03],
                        [  8.23974609e-04,  -5.18798828e-04],
                        [  1.26647949e-02,   9.73510742e-03],
                        [  1.87988281e-02,   1.46179199e-02],
                        [  1.70898438e-02,   1.24206543e-02],
                        [  1.97753906e-02,   1.57165527e-02],
                        [  3.37219238e-02,   3.14025879e-02],
                        [  5.09338379e-02,   5.10864258e-02],
                        [  6.38122559e-02,   6.64672852e-02],
                        [  7.69653320e-02,   8.15124512e-02],
                        [  9.71374512e-02,   1.02508545e-01],
                        [  1.21551514e-01,   1.26403809e-01],
                        [  1.40197754e-01,   1.43432617e-01],
                        [  1.40930176e-01,   1.42028809e-01],
                        [  1.11053467e-01,   1.10076904e-01],
                        [  4.40368652e-02,   4.17480469e-02],
                        [ -5.20935059e-02,  -5.46569824e-02],
                        [ -1.57989502e-01,  -1.59820557e-01],
                        [ -2.50823975e-01,  -2.51281738e-01],
                        [ -3.05541992e-01,  -3.04626465e-01],
                        [ -3.04077148e-01,  -3.02459717e-01],
                        [ -2.57263184e-01,  -2.55981445e-01],
                        [ -2.03582764e-01,  -2.03796387e-01],
                        [ -1.71844482e-01,  -1.74163818e-01],
                        [ -1.53594971e-01,  -1.57989502e-01],
                        [ -1.25518799e-01,  -1.31103516e-01],
                        [ -8.74633789e-02,  -9.27429199e-02],
                        [ -6.14929199e-02,  -6.46972656e-02],
                        [ -5.80444336e-02,  -5.77392578e-02],
                        [ -6.26831055e-02,  -5.82275391e-02],
                        [ -5.71899414e-02,  -4.90417480e-02],
                        [ -3.87878418e-02,  -2.85949707e-02],
                        [ -1.65710449e-02,  -6.68334961e-03],
                        [ -1.09863281e-03,   5.95092773e-03],
                        [  2.38037109e-03,   4.54711914e-03],
                        [ -2.22778320e-03,  -5.79833984e-03],
                        [ -6.31713867e-03,  -1.50451660e-02],
                        [ -7.93457031e-03,  -1.98669434e-02],
                        [ -1.31530762e-02,  -2.54821777e-02],
                        [ -2.60620117e-02,  -3.57055664e-02],
                        [ -4.40063477e-02,  -4.84924316e-02],
                        [ -6.13403320e-02,  -5.95397949e-02],
                        [ -7.27233887e-02,  -6.50634766e-02],
                        [ -7.48596191e-02,  -6.33239746e-02],
                        [ -6.58874512e-02,  -5.34057617e-02],
                        [ -4.20227051e-02,  -3.17993164e-02],
                        [ -1.22070312e-03,   4.21142578e-03],
                        [  4.99572754e-02,   4.93164062e-02],
                        [  1.01135254e-01,   9.47875977e-02],
                        [  1.45904541e-01,   1.35711670e-01],
                        [  1.78680420e-01,   1.67480469e-01],
                        [  1.92596436e-01,   1.83441162e-01],
                        [  1.88079834e-01,   1.83349609e-01],
                        [  1.75689697e-01,   1.76544189e-01],
                        [  1.66046143e-01,   1.72088623e-01],
                        [  1.61376953e-01,   1.70806885e-01],
                        [  1.58599854e-01,   1.68792725e-01],
                        [  1.55487061e-01,   1.63665771e-01],
                        [  1.51947021e-01,   1.56036377e-01],
                        [  1.50146484e-01,   1.49291992e-01],
                        [  1.52374268e-01,   1.47094727e-01],
                        [  1.53228760e-01,   1.45202637e-01],
                        [  1.37023926e-01,   1.28631592e-01],
                        [  8.92944336e-02,   8.28247070e-02],
                        [  8.94165039e-03,   6.07299805e-03],
                        [ -8.83789062e-02,  -8.71582031e-02],
                        [ -1.73919678e-01,  -1.69311523e-01],
                        [ -2.15911865e-01,  -2.09564209e-01],
                        [ -1.99340820e-01,  -1.93298340e-01],
                        [ -1.42883301e-01,  -1.38946533e-01],
                        [ -8.75549316e-02,  -8.67919922e-02],
                        [ -5.90820312e-02,  -6.14318848e-02],
                        [ -4.90417480e-02,  -5.34362793e-02],
                        [ -4.00390625e-02,  -4.47692871e-02],
                        [ -3.31420898e-02,  -3.64074707e-02],
                        [ -3.76892090e-02,  -3.81164551e-02],
                        [ -4.87060547e-02,  -4.58374023e-02],
                        [ -5.02014160e-02,  -4.46777344e-02],
                        [ -3.44543457e-02,  -2.78015137e-02],
                        [ -8.75854492e-03,  -2.99072266e-03],
                        [  1.39465332e-02,   1.69067383e-02],
                        [  2.50549316e-02,   2.39868164e-02],
                        [  2.29187012e-02,   1.77001953e-02],
                        [  1.04675293e-02,   2.10571289e-03],
                        [ -6.80541992e-03,  -1.63879395e-02],
                        [ -2.19116211e-02,  -3.03344727e-02],
                        [ -2.96020508e-02,  -3.47290039e-02],
                        [ -2.94494629e-02,  -2.98461914e-02],
                        [ -2.44140625e-02,  -1.97448730e-02],
                        [ -1.66320801e-02,  -7.81250000e-03],
                        [ -6.34765625e-03,   4.79125977e-03],
                        [  3.90625000e-03,   1.49230957e-02],
                        [  5.31005859e-03,   1.39465332e-02],
                        [ -9.79614258e-03,  -5.27954102e-03],
                        [ -3.55224609e-02,  -3.58886719e-02],
                        [ -5.55419922e-02,  -6.04858398e-02],
                        [ -5.84716797e-02,  -6.67419434e-02],
                        [ -4.10156250e-02,  -5.07812500e-02],
                        [ -8.23974609e-04,  -1.01318359e-02],
                        [  5.72814941e-02,   5.01403809e-02],
                        [  1.09771729e-01,   1.05834961e-01],
                        [  1.27868652e-01,   1.27502441e-01],
                        [  1.08245850e-01,   1.11083984e-01],
                        [  7.58972168e-02,   8.10852051e-02],
                        [  5.24291992e-02,   5.88684082e-02],
                        [  3.76586914e-02,   4.42199707e-02],
                        [  2.55432129e-02,   3.12500000e-02],
                        [  1.91345215e-02,   2.33764648e-02],
                        [  2.18505859e-02,   2.42309570e-02],
                        [  2.87170410e-02,   2.92053223e-02],
                        [  3.39660645e-02,   3.26843262e-02],
                        [  3.69873047e-02,   3.42712402e-02],
                        [  3.58276367e-02,   3.21044922e-02],
                        [  2.47497559e-02,   2.05383301e-02],
                        [  4.45556641e-03,   3.96728516e-04],
                        [ -1.38854980e-02,  -1.71813965e-02],
                        [ -2.07519531e-02,  -2.27966309e-02],
                        [ -1.59606934e-02,  -1.63879395e-02],
                        [ -1.40380859e-03,  -1.22070312e-04],
                        [  2.30102539e-02,   2.56347656e-02],
                        [  5.29479980e-02,   5.63659668e-02],
                        [  7.99560547e-02,   8.33435059e-02],
                        [  1.00555420e-01,   1.03118896e-01],
                        [  1.17156982e-01,   1.18316650e-01],
                        [  1.28997803e-01,   1.28479004e-01],
                        [  1.31988525e-01,   1.30065918e-01],
                        [  1.24633789e-01,   1.21948242e-01],
                        [  1.02996826e-01,   1.00463867e-01],
                        [  5.54199219e-02,   5.39550781e-02],
                        [ -2.56347656e-02,  -2.53601074e-02],
                        [ -1.29028320e-01,  -1.26861572e-01],
                        [ -2.27752686e-01,  -2.24121094e-01],
                        [ -2.92602539e-01,  -2.88421631e-01],
                        [ -3.03802490e-01,  -3.00292969e-01],
                        [ -2.62756348e-01,  -2.61016846e-01],
                        [ -1.97174072e-01,  -1.97998047e-01],
                        [ -1.43371582e-01,  -1.46881104e-01],
                        [ -1.15264893e-01,  -1.20849609e-01],
                        [ -1.01074219e-01,  -1.07543945e-01],
                        [ -8.86230469e-02,  -9.44213867e-02],
                        [ -7.88574219e-02,  -8.25500488e-02],
                        [ -7.50427246e-02,  -7.56225586e-02],
                        [ -7.32727051e-02,  -7.04650879e-02],
                        [ -6.52770996e-02,  -5.96008301e-02],
                        [ -4.65698242e-02,  -3.92761230e-02],
                        [ -2.26135254e-02,  -1.53198242e-02],
                        [ -4.11987305e-03,   1.49536133e-03],
                        [  4.36401367e-03,   7.11059570e-03],
                        [  6.22558594e-03,   5.64575195e-03],
                        [  4.02832031e-03,   3.66210938e-04],
                        [ -4.11987305e-03,  -9.79614258e-03],
                        [ -1.92260742e-02,  -2.55126953e-02],
                        [ -3.78112793e-02,  -4.32434082e-02],
                        [ -5.35888672e-02,  -5.69763184e-02],
                        [ -6.17675781e-02,  -6.25915527e-02],
                        [ -6.32019043e-02,  -6.16149902e-02],
                        [ -6.23168945e-02,  -5.90209961e-02],
                        [ -5.85937500e-02,  -5.47180176e-02],
                        [ -4.45556641e-02,  -4.12292480e-02],
                        [ -1.41296387e-02,  -1.22070312e-02],
                        [  3.17687988e-02,   3.19519043e-02],
                        [  8.95385742e-02,   8.81042480e-02],
                        [  1.53747559e-01,   1.51306152e-01],
                        [  2.10388184e-01,   2.07824707e-01],
                        [  2.38769531e-01,   2.36907959e-01],
                        [  2.28302002e-01,   2.27722168e-01],
                        [  1.90032959e-01,   1.90948486e-01],
                        [  1.46881104e-01,   1.49078369e-01],
                        [  1.15234375e-01,   1.18133545e-01],
                        [  9.92126465e-02,   1.02111816e-01],
                        [  9.73815918e-02,   9.95788574e-02],
                        [  1.07269287e-01,   1.08215332e-01],
                        [  1.22894287e-01,   1.22406006e-01],
                        [  1.36474609e-01,   1.34552002e-01],
                        [  1.45996094e-01,   1.42944336e-01],
                        [  1.54144287e-01,   1.50482178e-01],
                        [  1.54907227e-01,   1.51123047e-01],
                        [  1.29333496e-01,   1.25976562e-01],
                        [  6.20117188e-02,   5.95092773e-02],
                        [ -3.96423340e-02,  -4.08935547e-02],
                        [ -1.42456055e-01,  -1.42211914e-01],
                        [ -2.05169678e-01,  -2.03338623e-01],
                        [ -2.06604004e-01,  -2.03277588e-01],
                        [ -1.61224365e-01,  -1.56646729e-01],
                        [ -1.05224609e-01,  -9.99755859e-02],
                        [ -6.80236816e-02,  -6.28967285e-02],
                        [ -5.60302734e-02,  -5.19409180e-02],
                        [ -5.67932129e-02,  -5.46569824e-02],
                        [ -5.36499023e-02,  -5.41381836e-02],
                        [ -4.17480469e-02,  -4.51354980e-02],
                        [ -3.23791504e-02,  -3.82995605e-02],
                        [ -3.63464355e-02,  -4.39758301e-02],
                        [ -4.77905273e-02,  -5.57556152e-02],
                        [ -5.25817871e-02,  -5.93261719e-02],
                        [ -4.47082520e-02,  -4.87976074e-02],
                        [ -2.58178711e-02,  -2.63061523e-02],
                        [ -1.25122070e-03,   2.04467773e-03],
                        [  1.77307129e-02,   2.42004395e-02],
                        [  2.11791992e-02,   2.94799805e-02],
                        [  1.34277344e-02,   2.17285156e-02],
                        [  7.17163086e-03,   1.37023926e-02],
                        [  5.76782227e-03,   9.09423828e-03],
                        [  2.19726562e-03,   1.67846680e-03],
                        [ -6.56127930e-03,  -1.06201172e-02],
                        [ -1.56250000e-02,  -2.21557617e-02],
                        [ -2.05688477e-02,  -2.79235840e-02],
                        [ -2.14538574e-02,  -2.78625488e-02],
                        [ -2.16369629e-02,  -2.57263184e-02],
                        [ -2.68859863e-02,  -2.78625488e-02],
                        [ -3.93981934e-02,  -3.74755859e-02],
                        [ -5.00183105e-02,  -4.60510254e-02],
                        [ -4.20532227e-02,  -3.74755859e-02],
                        [ -7.50732422e-03,  -3.72314453e-03],
                        [  4.32739258e-02,   4.51049805e-02],
                        [  8.86535645e-02,   8.81347656e-02],
                        [  1.09985352e-01,   1.07452393e-01],
                        [  1.01379395e-01,   9.78088379e-02],
                        [  7.35778809e-02,   7.02819824e-02],
                        [  4.82177734e-02,   4.63867188e-02],
                        [  3.96118164e-02,   3.99475098e-02],
                        [  4.31213379e-02,   4.56237793e-02],
                        [  4.61120605e-02,   5.00488281e-02],
                        [  4.28161621e-02,   4.69665527e-02],
                        [  3.32336426e-02,   3.61633301e-02],
                        [  1.89208984e-02,   1.95617676e-02],
                        [  5.70678711e-03,   3.57055664e-03],
                        [  3.96728516e-04,  -4.15039062e-03],
                        [  1.43432617e-03,  -4.36401367e-03],
                        [  8.23974609e-04,  -4.69970703e-03],
                        [ -3.14331055e-03,  -6.83593750e-03],
                        [ -2.41088867e-03,  -3.17382812e-03],
                        [  9.70458984e-03,   1.22070312e-02],
                        [  2.95104980e-02,   3.46374512e-02],
                        [  4.91638184e-02,   5.55419922e-02],
                        [  6.80847168e-02,   7.39746094e-02],
                        [  9.14611816e-02,   9.51538086e-02],
                        [  1.17614746e-01,   1.17980957e-01],
                        [  1.37603760e-01,   1.34399414e-01],
                        [  1.47796631e-01,   1.41845703e-01],
                        [  1.50665283e-01,   1.43463135e-01],
                        [  1.40502930e-01,   1.33941650e-01],
                        [  1.02325439e-01,   9.82055664e-02],
                        [  2.81372070e-02,   2.75573730e-02],
                        [ -7.36389160e-02,  -7.04650879e-02],
                        [ -1.82312012e-01,  -1.76177979e-01],
                        [ -2.71179199e-01,  -2.63732910e-01],
                        [ -3.14117432e-01,  -3.07250977e-01],
                        [ -2.98278809e-01,  -2.93823242e-01],
                        [ -2.37670898e-01,  -2.36755371e-01],
                        [ -1.69036865e-01,  -1.71875000e-01],
                        [ -1.25000000e-01,  -1.30859375e-01],
                        [ -1.08520508e-01,  -1.15936279e-01],
                        [ -1.00067139e-01,  -1.07208252e-01],
                        [ -8.71887207e-02,  -9.24072266e-02],
                        [ -7.42492676e-02,  -7.64465332e-02],
                        [ -6.59179688e-02,  -6.47888184e-02],
                        [ -5.93872070e-02,  -5.54504395e-02],
                        [ -5.27038574e-02,  -4.71496582e-02],
                        [ -4.62951660e-02,  -4.05883789e-02],
                        [ -3.77807617e-02,  -3.32641602e-02],
                        [ -2.56042480e-02,  -2.31628418e-02],
                        [ -1.33972168e-02,  -1.33056641e-02],
                        [ -4.63867188e-03,  -6.53076172e-03],
                        [  1.19018555e-03,  -1.80053711e-03],
                        [  2.31933594e-03,  -8.54492188e-04],
                        [ -7.26318359e-03,  -9.73510742e-03],
                        [ -2.74963379e-02,  -2.88085938e-02],
                        [ -4.90417480e-02,  -4.91943359e-02],
                        [ -6.49108887e-02,  -6.43005371e-02],
                        [ -7.47375488e-02,  -7.39440918e-02],
                        [ -7.44628906e-02,  -7.40356445e-02],
                        [ -5.49926758e-02,  -5.52673340e-02],
                        [ -1.57165527e-02,  -1.67236328e-02],
                        [  3.32031250e-02,   3.18298340e-02],
                        [  8.52966309e-02,   8.40454102e-02],
                        [  1.41784668e-01,   1.41235352e-01],
                        [  1.96472168e-01,   1.96990967e-01],
                        [  2.29766846e-01,   2.31414795e-01],
                        [  2.27569580e-01,   2.30010986e-01],
                        [  1.97845459e-01,   2.00561523e-01],
                        [  1.61376953e-01,   1.63665771e-01],
                        [  1.32476807e-01,   1.33819580e-01],
                        [  1.14318848e-01,   1.14379883e-01],
                        [  1.06475830e-01,   1.05346680e-01],
                        [  1.09344482e-01,   1.07360840e-01],
                        [  1.19842529e-01,   1.17553711e-01],
                        [  1.29760742e-01,   1.27746582e-01],
                        [  1.32965088e-01,   1.31561279e-01],
                        [  1.31683350e-01,   1.31042480e-01],
                        [  1.30462646e-01,   1.30432129e-01],
                        [  1.24816895e-01,   1.25091553e-01],
                        [  1.00769043e-01,   1.00952148e-01],
                        [  4.69055176e-02,   4.67529297e-02],
                        [ -3.34777832e-02,  -3.39050293e-02],
                        [ -1.20330811e-01,  -1.20788574e-01],
                        [ -1.84906006e-01,  -1.84936523e-01],
                        [ -2.04956055e-01,  -2.04101562e-01],
                        [ -1.79656982e-01,  -1.77642822e-01],
                        [ -1.30523682e-01,  -1.27441406e-01],
                        [ -8.48693848e-02,  -8.12072754e-02],
                        [ -5.73425293e-02,  -5.38940430e-02],
                        [ -4.53491211e-02,  -4.30297852e-02],
                        [ -3.90014648e-02,  -3.86657715e-02],
                        [ -3.35083008e-02,  -3.55224609e-02],
                        [ -3.08532715e-02,  -3.51257324e-02],
                        [ -3.32946777e-02,  -3.90625000e-02],
                        [ -3.77197266e-02,  -4.37622070e-02],
                        [ -3.72009277e-02,  -4.21752930e-02],
                        [ -2.81066895e-02,  -3.07617188e-02],
                        [ -1.42517090e-02,  -1.38854980e-02],
                        [ -2.07519531e-03,   1.37329102e-03],
                        [  6.62231445e-03,   1.25122070e-02],
                        [  1.11083984e-02,   1.81274414e-02],
                        [  7.11059570e-03,   1.37634277e-02],
                        [ -5.18798828e-03,  -3.96728516e-04],
                        [ -1.56860352e-02,  -1.37023926e-02],
                        [ -1.66320801e-02,  -1.77612305e-02],
                        [ -1.49536133e-02,  -1.87377930e-02],
                        [ -2.13623047e-02,  -2.67639160e-02],
                        [ -3.39355469e-02,  -3.95507812e-02],
                        [ -4.24194336e-02,  -4.69055176e-02],
                        [ -4.54406738e-02,  -4.78210449e-02],
                        [ -5.05371094e-02,  -5.04760742e-02],
                        [ -5.75561523e-02,  -5.53283691e-02],
                        [ -5.38024902e-02,  -5.02319336e-02],
                        [ -2.83203125e-02,  -2.45056152e-02],
                        [  1.67846680e-02,   1.98059082e-02],
                        [  6.81457520e-02,   6.96411133e-02],
                        [  1.06384277e-01,   1.06201172e-01],
                        [  1.15203857e-01,   1.13647461e-01],
                        [  9.63134766e-02,   9.41162109e-02],
                        [  7.17163086e-02,   6.97631836e-02],
                        [  6.24084473e-02,   6.14624023e-02],
                        [  6.71691895e-02,   6.76879883e-02],
                        [  6.92749023e-02,   7.11669922e-02],
                        [  5.88073730e-02,   6.15539551e-02],
                        [  4.01916504e-02,   4.29992676e-02],
                        [  2.18200684e-02,   2.38342285e-02],
                        [  8.08715820e-03,   8.66699219e-03],
                        [ -3.05175781e-05,  -1.15966797e-03],
                        [ -3.57055664e-03,  -6.16455078e-03],
                        [ -4.66918945e-03,  -8.08715820e-03],
                        [ -5.00488281e-03,  -8.33129883e-03],
                        [ -4.33349609e-03,  -6.65283203e-03],
                        [  5.79833984e-04,  -1.22070312e-04],
                        [  1.37329102e-02,   1.49536133e-02],
                        [  3.64074707e-02,   3.92761230e-02],
                        [  6.64367676e-02,   7.03430176e-02],
                        [  9.93957520e-02,   1.03424072e-01],
                        [  1.28265381e-01,   1.31500244e-01],
                        [  1.46789551e-01,   1.48559570e-01],
                        [  1.54235840e-01,   1.54205322e-01],
                        [  1.52252197e-01,   1.50543213e-01],
                        [  1.35925293e-01,   1.33026123e-01],
                        [  9.53063965e-02,   9.19799805e-02],
                        [  2.64282227e-02,   2.34680176e-02],
                        [ -6.48803711e-02,  -6.67724609e-02],
                        [ -1.66870117e-01,  -1.67327881e-01],
                        [ -2.59460449e-01,  -2.58422852e-01],
                        [ -3.12255859e-01,  -3.09997559e-01],
                        [ -3.02856445e-01,  -2.99957275e-01],
                        [ -2.42858887e-01,  -2.39898682e-01],
                        [ -1.73522949e-01,  -1.71112061e-01],
                        [ -1.29364014e-01,  -1.27899170e-01],
                        [ -1.11541748e-01,  -1.11267090e-01],
                        [ -1.01684570e-01,  -1.02508545e-01],
                        [ -9.08508301e-02,  -9.24987793e-02],
                        [ -8.34350586e-02,  -8.55712891e-02],
                        [ -8.11157227e-02,  -8.32519531e-02],
                        [ -7.79418945e-02,  -7.96813965e-02],
                        [ -6.92138672e-02,  -7.02514648e-02],
                        [ -5.49316406e-02,  -5.50537109e-02],
                        [ -3.71398926e-02,  -3.63464355e-02],
                        [ -1.84936523e-02,  -1.68457031e-02],
                        [ -1.34277344e-03,   8.85009766e-04],
                        [  1.08642578e-02,   1.33361816e-02],
                        [  1.30920410e-02,   1.54113770e-02],
                        [  3.78417969e-03,   5.58471680e-03],
                        [ -1.22070312e-02,  -1.12304688e-02],
                        [ -3.05175781e-02,  -3.06091309e-02],
                        [ -5.10253906e-02,  -5.21850586e-02],
                        [ -7.10144043e-02,  -7.30590820e-02],
                        [ -8.17871094e-02,  -8.43505859e-02],
                        [ -7.52563477e-02,  -7.78503418e-02],
                        [ -4.90722656e-02,  -5.11474609e-02],
                        [ -5.31005859e-03,  -6.40869141e-03],
                        [  5.13916016e-02,   5.15136719e-02],
                        [  1.13342285e-01,   1.14715576e-01],
                        [  1.69036865e-01,   1.71447754e-01],
                        [  2.04132080e-01,   2.07092285e-01],
                        [  2.09045410e-01,   2.12036133e-01],
                        [  1.88079834e-01,   1.90460205e-01],
                        [  1.56799316e-01,   1.58111572e-01],
                        [  1.28906250e-01,   1.28936768e-01],
                        [  1.08886719e-01,   1.07727051e-01],
                        [  9.59167480e-02,   9.38415527e-02],
                        [  8.93249512e-02,   8.68835449e-02],
                        [  9.06982422e-02,   8.84094238e-02],
                        [  1.02416992e-01,   1.00799561e-01],
                        [  1.20910645e-01,   1.20239258e-01],
                        [  1.33300781e-01,   1.33636475e-01],
                        [  1.28753662e-01,   1.29974365e-01],
                        [  1.12274170e-01,   1.13952637e-01],
                        [  9.81445312e-02,   9.99145508e-02],
                        [  9.08203125e-02,   9.22241211e-02],
                        [  7.82775879e-02,   7.91015625e-02],
                        [  4.52575684e-02,   4.54101562e-02],
                        [ -1.22375488e-02,  -1.26342773e-02],
                        [ -8.41674805e-02,  -8.49304199e-02],
                        [ -1.50421143e-01,  -1.51214600e-01],
                        [ -1.86065674e-01,  -1.86706543e-01],
                        [ -1.76086426e-01,  -1.76391602e-01],
                        [ -1.32049561e-01,  -1.32019043e-01],
                        [ -8.71887207e-02,  -8.69140625e-02],
                        [ -6.61621094e-02,  -6.57958984e-02],
                        [ -6.48193359e-02,  -6.45141602e-02],
                        [ -6.35986328e-02,  -6.34765625e-02],
                        [ -5.37109375e-02,  -5.37719727e-02],
                        [ -4.18090820e-02,  -4.20227051e-02],
                        [ -3.45153809e-02,  -3.47595215e-02],
                        [ -3.08227539e-02,  -3.09753418e-02],
                        [ -2.94189453e-02,  -2.93884277e-02],
                        [ -2.98461914e-02,  -2.96936035e-02],
                        [ -2.60925293e-02,  -2.58178711e-02],
                        [ -1.12915039e-02,  -1.10473633e-02],
                        [  8.42285156e-03,   8.45336914e-03],
                        [  1.75781250e-02,   1.73645020e-02],
                        [  1.13525391e-02,   1.08947754e-02],
                        [ -3.05175781e-04,  -8.85009766e-04],
                        [ -9.24682617e-03,  -9.82666016e-03],
                        [ -1.79138184e-02,  -1.82495117e-02],
                        [ -3.00903320e-02,  -3.00292969e-02],
                        [ -4.32128906e-02,  -4.27246094e-02],
                        [ -5.14221191e-02,  -5.05371094e-02],
                        [ -5.33752441e-02,  -5.23376465e-02],
                        [ -5.52673340e-02,  -5.43518066e-02],
                        [ -6.21032715e-02,  -6.15539551e-02],
                        [ -6.65893555e-02,  -6.66809082e-02],
                        [ -5.40771484e-02,  -5.48095703e-02],
                        [ -1.71508789e-02,  -1.84631348e-02],
                        [  3.76281738e-02,   3.59802246e-02],
                        [  9.31396484e-02,   9.15222168e-02],
                        [  1.29547119e-01,   1.28295898e-01],
                        [  1.36291504e-01,   1.35681152e-01],
                        [  1.18713379e-01,   1.18896484e-01],
                        [  9.12780762e-02,   9.21630859e-02],
                        [  6.56738281e-02,   6.70776367e-02],
                        [  4.59594727e-02,   4.75463867e-02],
                        [  3.13415527e-02,   3.27453613e-02],
                        [  2.23388672e-02,   2.32543945e-02],
                        [  2.18811035e-02,   2.21252441e-02],
                        [  2.86254883e-02,   2.81677246e-02],
                        [  3.32946777e-02,   3.22570801e-02],
                        [  2.74047852e-02,   2.60314941e-02],
                        [  1.39160156e-02,   1.24816895e-02],
                        [  4.39453125e-03,   3.17382812e-03],
                        [  6.13403320e-03,   5.27954102e-03],
                        [  1.51977539e-02,   1.47705078e-02],
                        [  2.40173340e-02,   2.39868164e-02],
                        [  3.23181152e-02,   3.25622559e-02],
                        [  4.65087891e-02,   4.69055176e-02],
                        [  6.91528320e-02,   6.96105957e-02],
                        [  9.61914062e-02,   9.65881348e-02],
                        [  1.23992920e-01,   1.24298096e-01],
                        [  1.49200439e-01,   1.49414062e-01],
                        [  1.61132812e-01,   1.61224365e-01],
                        [  1.46484375e-01,   1.46514893e-01],
                        [  1.03149414e-01,   1.03088379e-01],
                        [  3.75061035e-02,   3.73535156e-02],
                        [ -4.80651855e-02,  -4.84008789e-02],
                        [ -1.50299072e-01,  -1.50848389e-01],
                        [ -2.47711182e-01,  -2.48413086e-01],
                        [ -3.02276611e-01,  -3.03100586e-01],
                        [ -2.88665771e-01,  -2.89428711e-01],
                        [ -2.22167969e-01,  -2.22778320e-01],
                        [ -1.51550293e-01,  -1.51885986e-01],
                        [ -1.16302490e-01,  -1.16302490e-01],
                        [ -1.13830566e-01,  -1.13525391e-01],
                        [ -1.14135742e-01,  -1.13586426e-01],
                        [ -9.93652344e-02,  -9.87854004e-02],
                        [ -7.79113770e-02,  -7.74841309e-02],
                        [ -6.43920898e-02,  -6.43005371e-02],
                        [ -6.05468750e-02,  -6.08215332e-02],
                        [ -5.76477051e-02,  -5.83190918e-02],
                        [ -4.91333008e-02,  -5.00488281e-02],
                        [ -3.55529785e-02,  -3.65295410e-02],
                        [ -2.13928223e-02,  -2.21557617e-02],
                        [ -1.07421875e-02,  -1.11389160e-02],
                        [ -5.43212891e-03,  -5.37109375e-03],
                        [ -6.77490234e-03,  -6.28662109e-03],
                        [ -1.60217285e-02,  -1.52893066e-02],
                        [ -3.12500000e-02,  -3.04870605e-02],
                        [ -4.61120605e-02,  -4.55932617e-02],
                        [ -5.61828613e-02,  -5.61523438e-02],
                        [ -6.24694824e-02,  -6.29882812e-02],
                        [ -6.46362305e-02,  -6.56433105e-02],
                        [ -5.58166504e-02,  -5.71594238e-02],
                        [ -2.81372070e-02,  -2.95410156e-02],
                        [  1.91955566e-02,   1.80664062e-02],
                        [  7.91320801e-02,   7.85217285e-02],
                        [  1.39892578e-01,   1.39923096e-01],
                        [  1.88446045e-01,   1.89086914e-01],
                        [  2.13806152e-01,   2.14904785e-01],
                        [  2.09869385e-01,   2.11090088e-01],
                        [  1.79016113e-01,   1.80053711e-01],
                        [  1.36505127e-01,   1.37115479e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.43603516e-02,   9.36889648e-02],
                        [  9.85107422e-02,   9.73510742e-02],
                        [  1.01928711e-01,   1.00494385e-01],
                        [  9.86328125e-02,   9.72290039e-02],
                        [  9.27734375e-02,   9.16442871e-02],
                        [  8.82263184e-02,   8.75854492e-02],
                        [  8.27941895e-02,   8.27331543e-02],
                        [  7.36389160e-02,   7.40661621e-02],
                        [  6.46057129e-02,   6.53686523e-02],
                        [  6.44531250e-02,   6.53381348e-02],
                        [  7.73010254e-02,   7.80944824e-02],
                        [  9.66796875e-02,   9.71374512e-02],
                        [  1.08459473e-01,   1.08581543e-01],
                        [  9.84497070e-02,   9.81750488e-02],
                        [  5.72204590e-02,   5.66406250e-02],
                        [ -1.52282715e-02,  -1.59606934e-02],
                        [ -1.03515625e-01,  -1.04278564e-01],
                        [ -1.77398682e-01,  -1.78009033e-01],
                        [ -2.07183838e-01,  -2.07611084e-01],
                        [ -1.86889648e-01,  -1.87103271e-01],
                        [ -1.41265869e-01,  -1.41296387e-01],
                        [ -1.02905273e-01,  -1.02813721e-01],
                        [ -8.18481445e-02,  -8.16955566e-02],
                        [ -6.59484863e-02,  -6.57958984e-02],
                        [ -4.78515625e-02,  -4.76989746e-02],
                        [ -3.51257324e-02,  -3.50341797e-02],
                        [ -3.35388184e-02,  -3.34777832e-02],
                        [ -3.68957520e-02,  -3.68652344e-02],
                        [ -3.81164551e-02,  -3.81164551e-02],
                        [ -3.66516113e-02,  -3.66821289e-02],
                        [ -3.22875977e-02,  -3.23486328e-02],
                        [ -2.30407715e-02,  -2.31933594e-02],
                        [ -1.29089355e-02,  -1.31835938e-02],
                        [ -8.91113281e-03,  -9.24682617e-03],
                        [ -9.03320312e-03,  -9.39941406e-03],
                        [ -6.80541992e-03,  -7.17163086e-03],
                        [ -6.10351562e-03,  -6.34765625e-03],
                        [ -1.49230957e-02,  -1.50146484e-02],
                        [ -2.98767090e-02,  -2.98156738e-02],
                        [ -4.26025391e-02,  -4.23889160e-02],
                        [ -5.23681641e-02,  -5.20324707e-02],
                        [ -6.14929199e-02,  -6.10961914e-02],
                        [ -6.91223145e-02,  -6.87866211e-02],
                        [ -7.35778809e-02,  -7.33642578e-02],
                        [ -6.89697266e-02,  -6.89392090e-02],
                        [ -4.44641113e-02,  -4.46166992e-02],
                        [  1.64794922e-03,   1.34277344e-03],
                        [  5.44433594e-02,   5.40161133e-02],
                        [  9.60998535e-02,   9.56726074e-02],
                        [  1.19079590e-01,   1.18713379e-01],
                        [  1.22985840e-01,   1.22772217e-01],
                        [  1.10778809e-01,   1.10778809e-01],
                        [  9.01794434e-02,   9.03320312e-02],
                        [  6.90002441e-02,   6.92749023e-02],
                        [  4.80041504e-02,   4.83398438e-02],
                        [  2.58789062e-02,   2.61840820e-02],
                        [  9.15527344e-03,   9.42993164e-03],
                        [  7.35473633e-03,   7.53784180e-03],
                        [  1.91650391e-02,   1.92260742e-02],
                        [  3.28674316e-02,   3.28369141e-02],
                        [  4.00390625e-02,   3.99780273e-02],
                        [  4.14428711e-02,   4.13513184e-02],
                        [  3.96423340e-02,   3.95812988e-02],
                        [  3.46374512e-02,   3.46069336e-02],
                        [  3.05175781e-02,   3.05175781e-02],
                        [  3.79333496e-02,   3.79638672e-02],
                        [  6.21643066e-02,   6.21948242e-02],
                        [  9.40551758e-02,   9.40856934e-02],
                        [  1.19842529e-01,   1.19903564e-01],
                        [  1.35742188e-01,   1.35803223e-01],
                        [  1.45690918e-01,   1.45751953e-01],
                        [  1.48864746e-01,   1.48986816e-01],
                        [  1.34887695e-01,   1.35070801e-01],
                        [  9.13085938e-02,   9.15222168e-02],
                        [  1.50146484e-02,   1.52893066e-02],
                        [ -8.24890137e-02,  -8.22143555e-02],
                        [ -1.80267334e-01,  -1.80023193e-01],
                        [ -2.56256104e-01,  -2.56072998e-01],
                        [ -2.91320801e-01,  -2.91198730e-01],
                        [ -2.75756836e-01,  -2.75726318e-01],
                        [ -2.21679688e-01,  -2.21679688e-01],
                        [ -1.61773682e-01,  -1.61865234e-01],
                        [ -1.23687744e-01,  -1.23748779e-01],
                        [ -1.07299805e-01,  -1.07330322e-01],
                        [ -9.49401855e-02,  -9.49096680e-02],
                        [ -7.82775879e-02,  -7.81555176e-02],
                        [ -6.53076172e-02,  -6.50939941e-02],
                        [ -6.35681152e-02,  -6.32934570e-02],
                        [ -6.67419434e-02,  -6.64367676e-02],
                        [ -6.16149902e-02,  -6.13098145e-02],
                        [ -4.32128906e-02,  -4.29382324e-02],
                        [ -1.87683105e-02,  -1.85241699e-02],
                        [  6.40869141e-04,   7.93457031e-04],
                        [  8.75854492e-03,   8.88061523e-03],
                        [  4.88281250e-03,   4.94384766e-03],
                        [ -9.97924805e-03,  -9.91821289e-03],
                        [ -3.23486328e-02,  -3.22875977e-02],
                        [ -5.42602539e-02,  -5.41687012e-02],
                        [ -6.83898926e-02,  -6.82678223e-02],
                        [ -7.46154785e-02,  -7.44628906e-02],
                        [ -7.51647949e-02,  -7.49816895e-02],
                        [ -6.68640137e-02,  -6.66503906e-02],
                        [ -4.30297852e-02,  -4.28161621e-02],
                        [  1.52587891e-04,   3.66210938e-04],
                        [  6.09436035e-02,   6.11267090e-02],
                        [  1.30126953e-01,   1.30310059e-01],
                        [  1.90124512e-01,   1.90307617e-01],
                        [  2.22045898e-01,   2.22198486e-01],
                        [  2.19390869e-01,   2.19543457e-01],
                        [  1.92749023e-01,   1.92932129e-01],
                        [  1.58599854e-01,   1.58752441e-01],
                        [  1.27319336e-01,   1.27502441e-01],
                        [  1.03363037e-01,   1.03546143e-01],
                        [  8.79516602e-02,   8.81347656e-02],
                        [  7.85522461e-02,   7.87353516e-02],
                        [  7.22961426e-02,   7.24487305e-02],
                        [  6.98852539e-02,   7.00378418e-02],
                        [  7.06787109e-02,   7.08312988e-02],
                        [  6.88476562e-02,   6.90307617e-02],
                        [  6.11877441e-02,   6.13403320e-02],
                        [  5.23986816e-02,   5.25817871e-02],
                        [  4.81567383e-02,   4.83398438e-02],
                        [  4.96215820e-02,   4.98352051e-02],
                        [  5.81359863e-02,   5.83496094e-02],
                        [  7.59887695e-02,   7.61718750e-02],
                        [  9.87854004e-02,   9.89685059e-02],
                        [  1.12762451e-01,   1.12945557e-01],
                        [  1.03332520e-01,   1.03515625e-01],
                        [  6.36596680e-02,   6.38122559e-02],
                        [ -2.62451172e-03,  -2.44140625e-03],
                        [ -8.01391602e-02,  -7.99560547e-02],
                        [ -1.44592285e-01,  -1.44439697e-01],
                        [ -1.74377441e-01,  -1.74224854e-01],
                        [ -1.63757324e-01,  -1.63574219e-01],
                        [ -1.26464844e-01,  -1.26312256e-01],
                        [ -8.64868164e-02,  -8.63037109e-02],
                        [ -6.09741211e-02,  -6.08215332e-02],
                        [ -5.05676270e-02,  -5.03845215e-02],
                        [ -4.60815430e-02,  -4.59289551e-02],
                        [ -4.27551270e-02,  -4.26025391e-02],
                        [ -4.32128906e-02,  -4.30603027e-02],
                        [ -4.87060547e-02,  -4.85534668e-02],
                        [ -5.22155762e-02,  -5.20629883e-02],
                        [ -4.47082520e-02,  -4.45556641e-02],
                        [ -2.66723633e-02,  -2.65197754e-02],
                        [ -8.30078125e-03,  -8.17871094e-03],
                        [  1.77001953e-03,   1.89208984e-03],
                        [  3.60107422e-03,   3.75366211e-03],
                        [  1.43432617e-03,   1.58691406e-03],
                        [ -2.44140625e-03,  -2.28881836e-03],
                        [ -7.84301758e-03,  -7.72094727e-03],
                        [ -1.53808594e-02,  -1.52587891e-02],
                        [ -2.64282227e-02,  -2.63061523e-02],
                        [ -4.19921875e-02,  -4.18701172e-02],
                        [ -5.87158203e-02,  -5.85937500e-02],
                        [ -6.90002441e-02,  -6.88781738e-02],
                        [ -6.72302246e-02,  -6.71386719e-02],
                        [ -5.49621582e-02,  -5.48706055e-02],
                        [ -3.76892090e-02,  -3.75976562e-02],
                        [ -1.67846680e-02,  -1.66931152e-02],
                        [  1.14746094e-02,   1.15661621e-02],
                        [  4.58374023e-02,   4.59289551e-02],
                        [  7.45544434e-02,   7.46459961e-02],
                        [  8.70666504e-02,   8.71582031e-02],
                        [  8.60290527e-02,   8.61206055e-02],
                        [  7.94067383e-02,   7.94677734e-02],
                        [  6.80236816e-02,   6.80847168e-02],
                        [  5.02014160e-02,   5.02929688e-02],
                        [  3.12194824e-02,   3.12805176e-02],
                        [  1.97143555e-02,   1.97448730e-02],
                        [  1.93176270e-02,   1.93786621e-02],
                        [  2.75268555e-02,   2.75878906e-02],
                        [  3.84521484e-02,   3.84826660e-02],
                        [  4.57153320e-02,   4.57458496e-02],
                        [  4.66613770e-02,   4.66918945e-02],
                        [  4.33959961e-02,   4.34570312e-02],
                        [  3.96423340e-02,   3.96728516e-02],
                        [  3.85131836e-02,   3.85437012e-02],
                        [  4.31823730e-02,   4.32128906e-02],
                        [  5.59082031e-02,   5.59387207e-02],
                        [  7.62023926e-02,   7.62023926e-02],
                        [  1.00128174e-01,   1.00128174e-01],
                        [  1.21429443e-01,   1.21459961e-01],
                        [  1.34338379e-01,   1.34338379e-01],
                        [  1.33850098e-01,   1.33850098e-01],
                        [  1.12365723e-01,   1.12365723e-01],
                        [  6.14929199e-02,   6.14929199e-02],
                        [ -1.83105469e-02,  -1.83410645e-02],
                        [ -1.14074707e-01,  -1.14074707e-01],
                        [ -2.05017090e-01,  -2.05047607e-01],
                        [ -2.66845703e-01,  -2.66876221e-01],
                        [ -2.79785156e-01,  -2.79815674e-01],
                        [ -2.45513916e-01,  -2.45544434e-01],
                        [ -1.90979004e-01,  -1.91009521e-01],
                        [ -1.46026611e-01,  -1.46057129e-01],
                        [ -1.19476318e-01,  -1.19537354e-01],
                        [ -1.01715088e-01,  -1.01776123e-01],
                        [ -8.36791992e-02,  -8.37402344e-02],
                        [ -6.57653809e-02,  -6.58264160e-02],
                        [ -5.17578125e-02,  -5.18188477e-02],
                        [ -4.26635742e-02,  -4.27246094e-02],
                        [ -3.71704102e-02,  -3.72314453e-02],
                        [ -3.33862305e-02,  -3.34777832e-02],
                        [ -2.87475586e-02,  -2.88391113e-02],
                        [ -2.09960938e-02,  -2.10876465e-02],
                        [ -1.17187500e-02,  -1.18103027e-02],
                        [ -6.68334961e-03,  -6.77490234e-03],
                        [ -1.05285645e-02,  -1.06201172e-02],
                        [ -2.27355957e-02,  -2.28271484e-02],
                        [ -4.04357910e-02,  -4.05273438e-02],
                        [ -6.02722168e-02,  -6.03942871e-02],
                        [ -7.48901367e-02,  -7.50122070e-02],
                        [ -7.52868652e-02,  -7.54089355e-02],
                        [ -5.91430664e-02,  -5.92651367e-02],
                        [ -3.03039551e-02,  -3.03955078e-02],
                        [  1.01928711e-02,   1.00708008e-02],
                        [  6.39038086e-02,   6.37817383e-02],
                        [  1.25610352e-01,   1.25488281e-01],
                        [  1.79504395e-01,   1.79382324e-01],
                        [  2.08435059e-01,   2.08312988e-01],
                        [  2.04498291e-01,   2.04376221e-01],
                        [  1.72485352e-01,   1.72363281e-01],
                        [  1.28845215e-01,   1.28692627e-01],
                        [  9.57946777e-02,   9.56420898e-02],
                        [  8.45947266e-02,   8.44421387e-02],
                        [  8.40148926e-02,   8.38928223e-02],
                        [  7.76367188e-02,   7.74841309e-02],
                        [  6.72607422e-02,   6.71081543e-02],
                        [  6.55517578e-02,   6.53991699e-02],
                        [  7.13195801e-02,   7.11364746e-02],
                        [  7.02209473e-02,   7.00683594e-02],
                        [  5.63049316e-02,   5.61218262e-02],
                        [  3.90014648e-02,   3.88488770e-02],
                        [  3.03955078e-02,   3.02429199e-02],
                        [  3.39965820e-02,   3.38439941e-02],
                        [  4.65698242e-02,   4.64172363e-02],
                        [  6.45751953e-02,   6.43920898e-02],
                        [  8.61816406e-02,   8.60290527e-02],
                        [  1.08459473e-01,   1.08306885e-01],
                        [  1.24420166e-01,   1.24237061e-01],
                        [  1.24389648e-01,   1.24206543e-01],
                        [  9.88159180e-02,   9.86328125e-02],
                        [  4.08325195e-02,   4.06494141e-02],
                        [ -4.54406738e-02,  -4.55932617e-02],
                        [ -1.36199951e-01,  -1.36352539e-01],
                        [ -1.96044922e-01,  -1.96228027e-01],
                        [ -2.04223633e-01,  -2.04406738e-01],
                        [ -1.72790527e-01,  -1.72973633e-01],
                        [ -1.33941650e-01,  -1.34124756e-01],
                        [ -1.09069824e-01,  -1.09252930e-01],
                        [ -9.44213867e-02,  -9.46044922e-02],
                        [ -7.67517090e-02,  -7.69348145e-02],
                        [ -5.31005859e-02,  -5.32836914e-02],
                        [ -3.11889648e-02,  -3.13720703e-02],
                        [ -1.95922852e-02,  -1.97753906e-02],
                        [ -2.15454102e-02,  -2.17285156e-02],
                        [ -3.17077637e-02,  -3.18908691e-02],
                        [ -3.82385254e-02,  -3.84216309e-02],
                        [ -3.41186523e-02,  -3.43017578e-02],
                        [ -2.51770020e-02,  -2.53601074e-02],
                        [ -2.20642090e-02,  -2.22473145e-02],
                        [ -2.60925293e-02,  -2.62756348e-02],
                        [ -2.85034180e-02,  -2.86560059e-02],
                        [ -2.28576660e-02,  -2.30102539e-02],
                        [ -1.33972168e-02,  -1.35803223e-02],
                        [ -1.07116699e-02,  -1.08947754e-02],
                        [ -2.23388672e-02,  -2.24914551e-02],
                        [ -4.66918945e-02,  -4.68444824e-02],
                        [ -7.28759766e-02,  -7.30285645e-02],
                        [ -8.75549316e-02,  -8.77380371e-02],
                        [ -8.39233398e-02,  -8.40759277e-02],
                        [ -6.26220703e-02,  -6.27746582e-02],
                        [ -2.64892578e-02,  -2.66418457e-02],
                        [  2.07824707e-02,   2.05993652e-02],
                        [  6.96105957e-02,   6.94274902e-02],
                        [  1.05102539e-01,   1.04949951e-01],
                        [  1.17248535e-01,   1.17095947e-01],
                        [  1.08581543e-01,   1.08428955e-01],
                        [  9.03015137e-02,   9.01489258e-02],
                        [  7.33032227e-02,   7.31811523e-02],
                        [  6.32629395e-02,   6.31408691e-02],
                        [  5.78002930e-02,   5.76782227e-02],
                        [  4.90722656e-02,   4.89196777e-02],
                        [  3.48815918e-02,   3.47290039e-02],
                        [  2.48107910e-02,   2.46887207e-02],
                        [  2.84118652e-02,   2.82897949e-02],
                        [  4.15344238e-02,   4.14123535e-02],
                        [  5.19104004e-02,   5.17883301e-02],
                        [  5.44128418e-02,   5.42907715e-02],
                        [  5.32531738e-02,   5.31311035e-02],
                        [  5.32226562e-02,   5.31005859e-02],
                        [  5.76171875e-02,   5.74951172e-02],
                        [  7.10449219e-02,   7.09228516e-02],
                        [  9.47875977e-02,   9.46960449e-02],
                        [  1.21002197e-01,   1.20910645e-01],
                        [  1.38488770e-01,   1.38397217e-01],
                        [  1.41326904e-01,   1.41235352e-01],
                        [  1.26129150e-01,   1.26037598e-01],
                        [  8.63647461e-02,   8.62731934e-02],
                        [  1.67541504e-02,   1.66625977e-02],
                        [ -7.76977539e-02,  -7.77893066e-02],
                        [ -1.78009033e-01,  -1.78070068e-01],
                        [ -2.54302979e-01,  -2.54364014e-01],
                        [ -2.78472900e-01,  -2.78533936e-01],
                        [ -2.45666504e-01,  -2.45758057e-01],
                        [ -1.84295654e-01,  -1.84356689e-01],
                        [ -1.34765625e-01,  -1.34826660e-01],
                        [ -1.15112305e-01,  -1.15173340e-01],
                        [ -1.12152100e-01,  -1.12182617e-01],
                        [ -1.05010986e-01,  -1.05041504e-01],
                        [ -8.92944336e-02,  -8.93249512e-02],
                        [ -7.42797852e-02,  -7.43103027e-02],
                        [ -6.40563965e-02,  -6.40869141e-02],
                        [ -5.28564453e-02,  -5.28869629e-02],
                        [ -3.72619629e-02,  -3.72924805e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [ -5.09643555e-03,  -5.12695312e-03],
                        [  7.65991211e-03,   7.62939453e-03],
                        [  1.27258301e-02,   1.26953125e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -5.02014160e-02,  -5.02014160e-02],
                        [ -7.66601562e-02,  -7.66296387e-02],
                        [ -9.08508301e-02,  -9.08203125e-02],
                        [ -8.29467773e-02,  -8.29162598e-02],
                        [ -5.49926758e-02,  -5.49621582e-02],
                        [ -1.22070312e-02,  -1.21765137e-02],
                        [  4.42504883e-02,   4.42810059e-02],
                        [  1.10992432e-01,   1.11022949e-01],
                        [  1.75720215e-01,   1.75781250e-01],
                        [  2.18811035e-01,   2.18872070e-01],
                        [  2.23724365e-01,   2.23785400e-01],
                        [  1.92413330e-01,   1.92474365e-01],
                        [  1.47766113e-01,   1.47827148e-01],
                        [  1.12792969e-01,   1.12854004e-01],
                        [  9.22851562e-02,   9.23461914e-02],
                        [  8.06274414e-02,   8.06884766e-02],
                        [  7.44323730e-02,   7.45239258e-02],
                        [  7.05261230e-02,   7.06176758e-02],
                        [  6.37207031e-02,   6.37817383e-02],
                        [  5.33447266e-02,   5.34362793e-02],
                        [  4.37316895e-02,   4.38232422e-02],
                        [  3.55834961e-02,   3.56750488e-02],
                        [  2.49938965e-02,   2.50854492e-02],
                        [  1.25732422e-02,   1.26953125e-02],
                        [  7.72094727e-03,   7.84301758e-03],
                        [  1.94091797e-02,   1.95007324e-02],
                        [  4.59594727e-02,   4.60815430e-02],
                        [  7.65380859e-02,   7.66296387e-02],
                        [  1.00769043e-01,   1.00891113e-01],
                        [  1.15661621e-01,   1.15753174e-01],
                        [  1.23229980e-01,   1.23321533e-01],
                        [  1.23596191e-01,   1.23718262e-01],
                        [  1.10321045e-01,   1.10443115e-01],
                        [  7.22961426e-02,   7.24487305e-02],
                        [  2.59399414e-03,   2.74658203e-03],
                        [ -8.91418457e-02,  -8.90197754e-02],
                        [ -1.72760010e-01,  -1.72637939e-01],
                        [ -2.14752197e-01,  -2.14630127e-01],
                        [ -2.05474854e-01,  -2.05322266e-01],
                        [ -1.64916992e-01,  -1.64764404e-01],
                        [ -1.21856689e-01,  -1.21704102e-01],
                        [ -9.21325684e-02,  -9.19799805e-02],
                        [ -7.53784180e-02,  -7.52258301e-02],
                        [ -6.33544922e-02,  -6.32019043e-02],
                        [ -5.10559082e-02,  -5.09033203e-02],
                        [ -4.29382324e-02,  -4.27856445e-02],
                        [ -4.50134277e-02,  -4.48608398e-02],
                        [ -5.00183105e-02,  -4.98657227e-02],
                        [ -4.25109863e-02,  -4.23583984e-02],
                        [ -2.08435059e-02,  -2.06909180e-02],
                        [ -5.49316406e-04,  -3.66210938e-04],
                        [  6.07299805e-03,   6.25610352e-03],
                        [  1.03759766e-03,   1.22070312e-03],
                        [ -7.56835938e-03,  -7.38525391e-03],
                        [ -1.45874023e-02,  -1.44042969e-02],
                        [ -2.01721191e-02,  -2.00195312e-02],
                        [ -2.83813477e-02,  -2.82287598e-02],
                        [ -4.16564941e-02,  -4.14733887e-02],
                        [ -5.77697754e-02,  -5.75866699e-02],
                        [ -7.40661621e-02,  -7.38830566e-02],
                        [ -8.81347656e-02,  -8.79821777e-02],
                        [ -9.17053223e-02,  -9.15222168e-02],
                        [ -7.32421875e-02,  -7.30590820e-02],
                        [ -3.10668945e-02,  -3.08837891e-02],
                        [  2.28576660e-02,   2.30407715e-02],
                        [  7.22961426e-02,   7.24792480e-02],
                        [  1.04736328e-01,   1.04919434e-01],
                        [  1.13952637e-01,   1.14105225e-01],
                        [  1.02935791e-01,   1.03118896e-01],
                        [  8.31298828e-02,   8.33129883e-02],
                        [  6.59484863e-02,   6.61315918e-02],
                        [  5.59387207e-02,   5.61218262e-02],
                        [  5.11474609e-02,   5.13305664e-02],
                        [  4.80346680e-02,   4.82177734e-02],
                        [  4.59899902e-02,   4.61425781e-02],
                        [  4.70581055e-02,   4.72412109e-02],
                        [  5.09033203e-02,   5.10559082e-02],
                        [  5.32226562e-02,   5.34057617e-02],
                        [  5.19104004e-02,   5.20935059e-02],
                        [  5.13305664e-02,   5.14831543e-02],
                        [  5.69763184e-02,   5.71594238e-02],
                        [  6.73217773e-02,   6.75048828e-02],
                        [  7.68127441e-02,   7.69653320e-02],
                        [  8.70056152e-02,   8.71582031e-02],
                        [  1.05773926e-01,   1.05926514e-01],
                        [  1.32781982e-01,   1.32965088e-01],
                        [  1.53808594e-01,   1.53961182e-01],
                        [  1.50787354e-01,   1.50939941e-01],
                        [  1.11755371e-01,   1.11907959e-01],
                        [  3.40576172e-02,   3.42102051e-02],
                        [ -7.29064941e-02,  -7.27539062e-02],
                        [ -1.86737061e-01,  -1.86584473e-01],
                        [ -2.76214600e-01,  -2.76092529e-01],
                        [ -3.12377930e-01,  -3.12225342e-01],
                        [ -2.85247803e-01,  -2.85095215e-01],
                        [ -2.15087891e-01,  -2.14935303e-01],
                        [ -1.40350342e-01,  -1.40197754e-01],
                        [ -8.99658203e-02,  -8.98437500e-02],
                        [ -6.89392090e-02,  -6.88171387e-02],
                        [ -6.63757324e-02,  -6.62231445e-02],
                        [ -7.00988770e-02,  -6.99462891e-02],
                        [ -7.49206543e-02,  -7.48291016e-02],
                        [ -8.18786621e-02,  -8.17565918e-02],
                        [ -8.79211426e-02,  -8.77990723e-02],
                        [ -8.12072754e-02,  -8.10852051e-02],
                        [ -5.57250977e-02,  -5.56030273e-02],
                        [ -2.41088867e-02,  -2.40173340e-02],
                        [ -2.25830078e-03,  -2.16674805e-03],
                        [  9.12475586e-03,   9.21630859e-03],
                        [  1.43432617e-02,   1.44348145e-02],
                        [  7.56835938e-03,   7.65991211e-03],
                        [ -1.71813965e-02,  -1.70898438e-02],
                        [ -5.14221191e-02,  -5.13305664e-02],
                        [ -7.80334473e-02,  -7.79418945e-02],
                        [ -8.57238770e-02,  -8.56628418e-02],
                        [ -7.29675293e-02,  -7.29064941e-02],
                        [ -4.14123535e-02,  -4.13208008e-02],
                        [  8.48388672e-03,   8.57543945e-03],
                        [  7.26318359e-02,   7.26928711e-02],
                        [  1.37420654e-01,   1.37481689e-01],
                        [  1.83929443e-01,   1.83990479e-01],
                        [  1.99127197e-01,   1.99188232e-01],
                        [  1.83959961e-01,   1.83990479e-01],
                        [  1.53045654e-01,   1.53106689e-01],
                        [  1.25122070e-01,   1.25152588e-01],
                        [  1.09558105e-01,   1.09588623e-01],
                        [  1.02447510e-01,   1.02478027e-01],
                        [  9.54895020e-02,   9.55200195e-02],
                        [  8.60595703e-02,   8.60900879e-02],
                        [  7.47985840e-02,   7.48291016e-02],
                        [  5.95092773e-02,   5.95092773e-02],
                        [  3.96728516e-02,   3.96728516e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  1.54724121e-02,   1.54724121e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [ -2.99072266e-03,  -2.99072266e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -1.92260742e-03,  -1.92260742e-03],
                        [  1.99890137e-02,   1.99584961e-02],
                        [  3.86962891e-02,   3.86657715e-02],
                        [  5.15136719e-02,   5.14831543e-02],
                        [  6.75354004e-02,   6.75048828e-02],
                        [  9.07592773e-02,   9.07287598e-02],
                        [  1.16851807e-01,   1.16821289e-01],
                        [  1.37908936e-01,   1.37847900e-01],
                        [  1.39282227e-01,   1.39251709e-01],
                        [  1.01806641e-01,   1.01776123e-01],
                        [  1.96838379e-02,   1.96228027e-02],
                        [ -8.61511230e-02,  -8.62121582e-02],
                        [ -1.78802490e-01,  -1.78863525e-01],
                        [ -2.27905273e-01,  -2.27966309e-01],
                        [ -2.23693848e-01,  -2.23754883e-01],
                        [ -1.79748535e-01,  -1.79809570e-01],
                        [ -1.25732422e-01,  -1.25823975e-01],
                        [ -8.84094238e-02,  -8.85009766e-02],
                        [ -7.39440918e-02,  -7.40051270e-02],
                        [ -7.12890625e-02,  -7.13806152e-02],
                        [ -7.05261230e-02,  -7.05871582e-02],
                        [ -7.01599121e-02,  -7.02514648e-02],
                        [ -6.99157715e-02,  -7.00073242e-02],
                        [ -6.59790039e-02,  -6.60705566e-02],
                        [ -5.65185547e-02,  -5.66101074e-02],
                        [ -4.36096191e-02,  -4.37011719e-02],
                        [ -2.84729004e-02,  -2.85644531e-02],
                        [ -1.20849609e-02,  -1.22070312e-02],
                        [ -1.77001953e-03,  -1.86157227e-03],
                        [ -5.49316406e-03,  -5.58471680e-03],
                        [ -1.89819336e-02,  -1.90734863e-02],
                        [ -3.03649902e-02,  -3.04565430e-02],
                        [ -3.64685059e-02,  -3.65905762e-02],
                        [ -4.27856445e-02,  -4.29077148e-02],
                        [ -5.18493652e-02,  -5.19714355e-02],
                        [ -6.34155273e-02,  -6.35375977e-02],
                        [ -7.81555176e-02,  -7.82775879e-02],
                        [ -8.99047852e-02,  -9.00268555e-02],
                        [ -8.23974609e-02,  -8.25500488e-02],
                        [ -4.61425781e-02,  -4.62646484e-02],
                        [  7.56835938e-03,   7.44628906e-03],
                        [  5.86547852e-02,   5.85021973e-02],
                        [  9.66796875e-02,   9.65270996e-02],
                        [  1.17797852e-01,   1.17645264e-01],
                        [  1.17584229e-01,   1.17431641e-01],
                        [  1.00891113e-01,   1.00738525e-01],
                        [  8.47473145e-02,   8.46252441e-02],
                        [  7.80639648e-02,   7.79113770e-02],
                        [  7.27844238e-02,   7.26318359e-02],
                        [  6.32019043e-02,   6.30493164e-02],
                        [  5.70373535e-02,   5.68847656e-02],
                        [  5.99670410e-02,   5.98144531e-02],
                        [  6.42700195e-02,   6.41174316e-02],
                        [  6.05163574e-02,   6.03637695e-02],
                        [  5.15747070e-02,   5.14221191e-02],
                        [  4.75769043e-02,   4.73937988e-02],
                        [  5.34973145e-02,   5.33447266e-02],
                        [  6.85424805e-02,   6.83898926e-02],
                        [  9.25598145e-02,   9.24072266e-02],
                        [  1.23779297e-01,   1.23626709e-01],
                        [  1.51306152e-01,   1.51153564e-01],
                        [  1.58813477e-01,   1.58630371e-01],
                        [  1.37298584e-01,   1.37145996e-01],
                        [  8.86230469e-02,   8.84704590e-02],
                        [  1.63574219e-02,   1.62048340e-02],
                        [ -7.75146484e-02,  -7.76672363e-02],
                        [ -1.81823730e-01,  -1.81976318e-01],
                        [ -2.69409180e-01,  -2.69592285e-01],
                        [ -3.09478760e-01,  -3.09631348e-01],
                        [ -2.90008545e-01,  -2.90161133e-01],
                        [ -2.29431152e-01,  -2.29583740e-01],
                        [ -1.63757324e-01,  -1.63909912e-01],
                        [ -1.18927002e-01,  -1.19079590e-01],
                        [ -9.60083008e-02,  -9.61914062e-02],
                        [ -8.27026367e-02,  -8.28857422e-02],
                        [ -7.10754395e-02,  -7.12280273e-02],
                        [ -6.15844727e-02,  -6.17370605e-02],
                        [ -5.63964844e-02,  -5.65490723e-02],
                        [ -5.41687012e-02,  -5.43212891e-02],
                        [ -5.06591797e-02,  -5.08117676e-02],
                        [ -4.16259766e-02,  -4.17785645e-02],
                        [ -2.52380371e-02,  -2.53906250e-02],
                        [ -5.03540039e-03,  -5.15747070e-03],
                        [  9.82666016e-03,   9.70458984e-03],
                        [  1.13525391e-02,   1.11999512e-02],
                        [ -9.76562500e-04,  -1.12915039e-03],
                        [ -2.39562988e-02,  -2.40783691e-02],
                        [ -5.26123047e-02,  -5.27648926e-02],
                        [ -7.47375488e-02,  -7.48901367e-02],
                        [ -7.45544434e-02,  -7.47070312e-02],
                        [ -4.79736328e-02,  -4.81262207e-02],
                        [ -2.10571289e-03,  -2.25830078e-03],
                        [  5.87768555e-02,   5.86547852e-02],
                        [  1.30004883e-01,   1.29882812e-01],
                        [  1.91833496e-01,   1.91711426e-01],
                        [  2.19940186e-01,   2.19818115e-01],
                        [  2.10662842e-01,   2.10540771e-01],
                        [  1.81304932e-01,   1.81182861e-01],
                        [  1.48162842e-01,   1.48040771e-01],
                        [  1.17126465e-01,   1.17004395e-01],
                        [  9.05456543e-02,   9.04235840e-02],
                        [  7.01904297e-02,   7.00683594e-02],
                        [  5.51452637e-02,   5.50537109e-02],
                        [  4.42504883e-02,   4.41589355e-02],
                        [  3.91235352e-02,   3.90014648e-02],
                        [  4.07409668e-02,   4.06494141e-02],
                        [  4.41284180e-02,   4.40368652e-02],
                        [  4.14733887e-02,   4.13818359e-02],
                        [  3.09143066e-02,   3.08227539e-02],
                        [  1.78222656e-02,   1.77307129e-02],
                        [  8.75854492e-03,   8.69750977e-03],
                        [  7.62939453e-03,   7.56835938e-03],
                        [  1.60827637e-02,   1.59912109e-02],
                        [  3.17687988e-02,   3.17077637e-02],
                        [  4.74853516e-02,   4.74243164e-02],
                        [  5.69458008e-02,   5.68847656e-02],
                        [  6.16455078e-02,   6.15844727e-02],
                        [  6.77795410e-02,   6.77185059e-02],
                        [  7.86743164e-02,   7.86132812e-02],
                        [  9.26818848e-02,   9.26513672e-02],
                        [  1.03881836e-01,   1.03851318e-01],
                        [  1.00769043e-01,   1.00738525e-01],
                        [  7.03735352e-02,   7.03430176e-02],
                        [  9.46044922e-03,   9.42993164e-03],
                        [ -6.99157715e-02,  -6.99462891e-02],
                        [ -1.46026611e-01,  -1.46087646e-01],
                        [ -1.95739746e-01,  -1.95770264e-01],
                        [ -2.03125000e-01,  -2.03155518e-01],
                        [ -1.70074463e-01,  -1.70104980e-01],
                        [ -1.18377686e-01,  -1.18408203e-01],
                        [ -7.49206543e-02,  -7.49206543e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -5.11779785e-02,  -5.11779785e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -7.20214844e-02,  -7.20214844e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -8.14208984e-02,  -8.14208984e-02],
                        [ -7.93762207e-02,  -7.93762207e-02],
                        [ -7.23876953e-02,  -7.23876953e-02],
                        [ -5.51757812e-02,  -5.51757812e-02],
                        [ -2.91442871e-02,  -2.91137695e-02],
                        [ -6.53076172e-03,  -6.50024414e-03],
                        [  1.00708008e-03,   1.03759766e-03],
                        [ -5.31005859e-03,  -5.31005859e-03],
                        [ -1.48315430e-02,  -1.48010254e-02],
                        [ -2.16064453e-02,  -2.15759277e-02],
                        [ -2.99682617e-02,  -2.99377441e-02],
                        [ -4.57153320e-02,  -4.56848145e-02],
                        [ -6.68640137e-02,  -6.68029785e-02],
                        [ -8.32824707e-02,  -8.32214355e-02],
                        [ -8.24279785e-02,  -8.23974609e-02],
                        [ -5.75561523e-02,  -5.74951172e-02],
                        [ -1.40075684e-02,  -1.39465332e-02],
                        [  3.39660645e-02,   3.40270996e-02],
                        [  7.31811523e-02,   7.32421875e-02],
                        [  9.71069336e-02,   9.71679688e-02],
                        [  1.05560303e-01,   1.05621338e-01],
                        [  1.02233887e-01,   1.02294922e-01],
                        [  9.22851562e-02,   9.23461914e-02],
                        [  8.02307129e-02,   8.02917480e-02],
                        [  6.90917969e-02,   6.91528320e-02],
                        [  6.06994629e-02,   6.07910156e-02],
                        [  5.64880371e-02,   5.65795898e-02],
                        [  5.72204590e-02,   5.72814941e-02],
                        [  6.14318848e-02,   6.15234375e-02],
                        [  6.49108887e-02,   6.50024414e-02],
                        [  6.40258789e-02,   6.41174316e-02],
                        [  6.13098145e-02,   6.14013672e-02],
                        [  6.43920898e-02,   6.44836426e-02],
                        [  7.75451660e-02,   7.76367188e-02],
                        [  9.67102051e-02,   9.68322754e-02],
                        [  1.14318848e-01,   1.14410400e-01],
                        [  1.25244141e-01,   1.25366211e-01],
                        [  1.27380371e-01,   1.27502441e-01],
                        [  1.17980957e-01,   1.18072510e-01],
                        [  8.82263184e-02,   8.83483887e-02],
                        [  2.48718262e-02,   2.49938965e-02],
                        [ -7.38830566e-02,  -7.37609863e-02],
                        [ -1.84539795e-01,  -1.84417725e-01],
                        [ -2.69500732e-01,  -2.69378662e-01],
                        [ -3.02490234e-01,  -3.02368164e-01],
                        [ -2.81890869e-01,  -2.81768799e-01],
                        [ -2.27722168e-01,  -2.27600098e-01],
                        [ -1.70166016e-01,  -1.70043945e-01],
                        [ -1.30920410e-01,  -1.30798340e-01],
                        [ -1.10198975e-01,  -1.10076904e-01],
                        [ -9.58251953e-02,  -9.57031250e-02],
                        [ -8.14208984e-02,  -8.12988281e-02],
                        [ -6.84814453e-02,  -6.83593750e-02],
                        [ -5.66101074e-02,  -5.64880371e-02],
                        [ -4.19006348e-02,  -4.17785645e-02],
                        [ -2.30102539e-02,  -2.28881836e-02],
                        [ -4.05883789e-03,  -3.93676758e-03],
                        [  7.90405273e-03,   8.02612305e-03],
                        [  8.78906250e-03,   8.94165039e-03],
                        [  5.18798828e-04,   6.71386719e-04],
                        [ -1.40686035e-02,  -1.39465332e-02],
                        [ -3.58886719e-02,  -3.57666016e-02],
                        [ -6.28356934e-02,  -6.26831055e-02],
                        [ -8.27941895e-02,  -8.26721191e-02],
                        [ -8.17871094e-02,  -8.16650391e-02],
                        [ -5.67321777e-02,  -5.65795898e-02],
                        [ -1.46789551e-02,  -1.45568848e-02],
                        [  3.74450684e-02,   3.75671387e-02],
                        [  9.53979492e-02,   9.55200195e-02],
                        [  1.50878906e-01,   1.51031494e-01],
                        [  1.91284180e-01,   1.91406250e-01],
                        [  2.07733154e-01,   2.07855225e-01],
                        [  1.99951172e-01,   2.00073242e-01],
                        [  1.75079346e-01,   1.75201416e-01],
                        [  1.45233154e-01,   1.45355225e-01],
                        [  1.21307373e-01,   1.21429443e-01],
                        [  1.04675293e-01,   1.04827881e-01],
                        [  8.88671875e-02,   8.89892578e-02],
                        [  7.05261230e-02,   7.06481934e-02],
                        [  5.30395508e-02,   5.31616211e-02],
                        [  3.93676758e-02,   3.94897461e-02],
                        [  2.76489258e-02,   2.77709961e-02],
                        [  1.45263672e-02,   1.46484375e-02],
                        [ -9.15527344e-05,   3.05175781e-05],
                        [ -1.12304688e-02,  -1.11083984e-02],
                        [ -1.22680664e-02,  -1.21459961e-02],
                        [ -2.71606445e-03,  -2.62451172e-03],
                        [  9.30786133e-03,   9.39941406e-03],
                        [  1.63574219e-02,   1.64794922e-02],
                        [  1.96533203e-02,   1.97448730e-02],
                        [  2.45666504e-02,   2.46582031e-02],
                        [  3.35083008e-02,   3.35998535e-02],
                        [  4.57458496e-02,   4.58679199e-02],
                        [  5.98754883e-02,   5.99670410e-02],
                        [  7.39746094e-02,   7.40661621e-02],
                        [  8.64868164e-02,   8.65783691e-02],
                        [  9.66796875e-02,   9.67712402e-02],
                        [  1.02539062e-01,   1.02600098e-01],
                        [  9.67102051e-02,   9.68017578e-02],
                        [  6.60400391e-02,   6.61315918e-02],
                        [  5.18798828e-04,   5.79833984e-04],
                        [ -9.03930664e-02,  -9.03320312e-02],
                        [ -1.73767090e-01,  -1.73675537e-01],
                        [ -2.14599609e-01,  -2.14538574e-01],
                        [ -2.04132080e-01,  -2.04071045e-01],
                        [ -1.64398193e-01,  -1.64306641e-01],
                        [ -1.26403809e-01,  -1.26342773e-01],
                        [ -1.06201172e-01,  -1.06170654e-01],
                        [ -9.89379883e-02,  -9.88769531e-02],
                        [ -9.18273926e-02,  -9.17663574e-02],
                        [ -7.96203613e-02,  -7.95593262e-02],
                        [ -6.68334961e-02,  -6.68029785e-02],
                        [ -5.86547852e-02,  -5.85937500e-02],
                        [ -5.47790527e-02,  -5.47180176e-02],
                        [ -5.14221191e-02,  -5.13916016e-02],
                        [ -4.42810059e-02,  -4.42504883e-02],
                        [ -3.03649902e-02,  -3.03039551e-02],
                        [ -1.22680664e-02,  -1.22375488e-02],
                        [  7.01904297e-04,   7.32421875e-04],
                        [ -1.22070312e-04,  -9.15527344e-05],
                        [ -1.54418945e-02,  -1.53808594e-02],
                        [ -4.01000977e-02,  -4.00695801e-02],
                        [ -6.84204102e-02,  -6.83898926e-02],
                        [ -9.38415527e-02,  -9.37805176e-02],
                        [ -1.07604980e-01,  -1.07574463e-01],
                        [ -1.04644775e-01,  -1.04644775e-01],
                        [ -8.77685547e-02,  -8.77380371e-02],
                        [ -6.14013672e-02,  -6.13708496e-02],
                        [ -2.48107910e-02,  -2.48107910e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  7.31201172e-02,   7.31506348e-02],
                        [  1.12976074e-01,   1.12976074e-01],
                        [  1.31561279e-01,   1.31561279e-01],
                        [  1.27746582e-01,   1.27746582e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  8.70971680e-02,   8.70666504e-02],
                        [  7.12890625e-02,   7.12890625e-02],
                        [  6.46057129e-02,   6.46057129e-02],
                        [  6.24389648e-02,   6.24084473e-02],
                        [  5.96313477e-02,   5.96008301e-02],
                        [  5.83190918e-02,   5.83190918e-02],
                        [  6.47277832e-02,   6.46972656e-02],
                        [  7.91320801e-02,   7.91015625e-02],
                        [  9.46350098e-02,   9.46044922e-02],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.07757568e-01,   1.07727051e-01],
                        [  1.09527588e-01,   1.09497070e-01],
                        [  1.15478516e-01,   1.15447998e-01],
                        [  1.26098633e-01,   1.26068115e-01],
                        [  1.32263184e-01,   1.32232666e-01],
                        [  1.17675781e-01,   1.17645264e-01],
                        [  6.79626465e-02,   6.79626465e-02],
                        [ -1.83715820e-02,  -1.84020996e-02],
                        [ -1.25885010e-01,  -1.25915527e-01],
                        [ -2.25769043e-01,  -2.25799561e-01],
                        [ -2.86102295e-01,  -2.86132812e-01],
                        [ -2.89093018e-01,  -2.89154053e-01],
                        [ -2.47070312e-01,  -2.47131348e-01],
                        [ -1.94824219e-01,  -1.94854736e-01],
                        [ -1.58294678e-01,  -1.58355713e-01],
                        [ -1.35528564e-01,  -1.35559082e-01],
                        [ -1.12976074e-01,  -1.13006592e-01],
                        [ -8.84399414e-02,  -8.84704590e-02],
                        [ -6.85119629e-02,  -6.86035156e-02],
                        [ -5.47790527e-02,  -5.48400879e-02],
                        [ -4.33044434e-02,  -4.33654785e-02],
                        [ -3.24096680e-02,  -3.24707031e-02],
                        [ -2.31323242e-02,  -2.32238770e-02],
                        [ -1.68151855e-02,  -1.68762207e-02],
                        [ -1.52587891e-02,  -1.52893066e-02],
                        [ -1.94091797e-02,  -1.95007324e-02],
                        [ -2.74353027e-02,  -2.74963379e-02],
                        [ -3.69567871e-02,  -3.70178223e-02],
                        [ -4.74548340e-02,  -4.75463867e-02],
                        [ -5.56945801e-02,  -5.57556152e-02],
                        [ -5.38024902e-02,  -5.38635254e-02],
                        [ -3.76281738e-02,  -3.76892090e-02],
                        [ -9.97924805e-03,  -1.00708008e-02],
                        [  2.99072266e-02,   2.98461914e-02],
                        [  8.78906250e-02,   8.78295898e-02],
                        [  1.56402588e-01,   1.56311035e-01],
                        [  2.07000732e-01,   2.06909180e-01],
                        [  2.14111328e-01,   2.14050293e-01],
                        [  1.81884766e-01,   1.81793213e-01],
                        [  1.40960693e-01,   1.40869141e-01],
                        [  1.19445801e-01,   1.19384766e-01],
                        [  1.18194580e-01,   1.18133545e-01],
                        [  1.16546631e-01,   1.16455078e-01],
                        [  1.00646973e-01,   1.00585938e-01],
                        [  7.77893066e-02,   7.77282715e-02],
                        [  6.10961914e-02,   6.10046387e-02],
                        [  5.18798828e-02,   5.17883301e-02],
                        [  4.33959961e-02,   4.33349609e-02],
                        [  3.25317383e-02,   3.24401855e-02],
                        [  2.10266113e-02,   2.09350586e-02],
                        [  1.10168457e-02,   1.09558105e-02],
                        [  3.35693359e-03,   3.26538086e-03],
                        [ -1.77001953e-03,  -1.86157227e-03],
                        [ -4.54711914e-03,  -4.63867188e-03],
                        [ -5.09643555e-03,  -5.15747070e-03],
                        [ -2.89916992e-03,  -2.99072266e-03],
                        [  2.22778320e-03,   2.13623047e-03],
                        [  9.42993164e-03,   9.33837891e-03],
                        [  1.78527832e-02,   1.77612305e-02],
                        [  2.85034180e-02,   2.84118652e-02],
                        [  4.36096191e-02,   4.35485840e-02],
                        [  6.27441406e-02,   6.26525879e-02],
                        [  8.13293457e-02,   8.12377930e-02],
                        [  9.52758789e-02,   9.51843262e-02],
                        [  1.04095459e-01,   1.04034424e-01],
                        [  1.06048584e-01,   1.05987549e-01],
                        [  9.20104980e-02,   9.19494629e-02],
                        [  4.94079590e-02,   4.93469238e-02],
                        [ -2.49938965e-02,  -2.50549316e-02],
                        [ -1.14685059e-01,  -1.14776611e-01],
                        [ -1.87530518e-01,  -1.87591553e-01],
                        [ -2.15637207e-01,  -2.15698242e-01],
                        [ -1.96685791e-01,  -1.96777344e-01],
                        [ -1.54571533e-01,  -1.54632568e-01],
                        [ -1.16912842e-01,  -1.16973877e-01],
                        [ -9.41467285e-02,  -9.42077637e-02],
                        [ -8.01391602e-02,  -8.02001953e-02],
                        [ -6.73217773e-02,  -6.74133301e-02],
                        [ -5.51452637e-02,  -5.52062988e-02],
                        [ -4.78515625e-02,  -4.79125977e-02],
                        [ -4.90722656e-02,  -4.91333008e-02],
                        [ -5.53894043e-02,  -5.54504395e-02],
                        [ -5.58776855e-02,  -5.59387207e-02],
                        [ -4.37316895e-02,  -4.37927246e-02],
                        [ -2.62756348e-02,  -2.63366699e-02],
                        [ -1.71813965e-02,  -1.72424316e-02],
                        [ -2.06909180e-02,  -2.07519531e-02],
                        [ -3.08837891e-02,  -3.09448242e-02],
                        [ -4.33044434e-02,  -4.33654785e-02],
                        [ -5.88989258e-02,  -5.89599609e-02],
                        [ -7.69653320e-02,  -7.70263672e-02],
                        [ -9.18579102e-02,  -9.18884277e-02],
                        [ -9.86328125e-02,  -9.86633301e-02],
                        [ -9.59167480e-02,  -9.59777832e-02],
                        [ -8.07189941e-02,  -8.07800293e-02],
                        [ -4.69970703e-02,  -4.70275879e-02],
                        [  5.06591797e-03,   5.03540039e-03],
                        [  6.17065430e-02,   6.16760254e-02],
                        [  1.03668213e-01,   1.03637695e-01],
                        [  1.20635986e-01,   1.20574951e-01],
                        [  1.15844727e-01,   1.15814209e-01],
                        [  9.95178223e-02,   9.94873047e-02],
                        [  8.22753906e-02,   8.22448730e-02],
                        [  7.29675293e-02,   7.29370117e-02],
                        [  7.45544434e-02,   7.45239258e-02],
                        [  7.94982910e-02,   7.94677734e-02],
                        [  7.82470703e-02,   7.82165527e-02],
                        [  7.38220215e-02,   7.38220215e-02],
                        [  7.81555176e-02,   7.81555176e-02],
                        [  9.22851562e-02,   9.22241211e-02],
                        [  1.04309082e-01,   1.04278564e-01],
                        [  1.08703613e-01,   1.08703613e-01],
                        [  1.12731934e-01,   1.12701416e-01],
                        [  1.22528076e-01,   1.22497559e-01],
                        [  1.33758545e-01,   1.33758545e-01],
                        [  1.36108398e-01,   1.36108398e-01],
                        [  1.19384766e-01,   1.19384766e-01],
                        [  7.60192871e-02,   7.60192871e-02],
                        [  3.47900391e-03,   3.44848633e-03],
                        [ -9.20715332e-02,  -9.21020508e-02],
                        [ -1.90887451e-01,  -1.90887451e-01],
                        [ -2.62298584e-01,  -2.62298584e-01],
                        [ -2.82043457e-01,  -2.82073975e-01],
                        [ -2.51281738e-01,  -2.51281738e-01],
                        [ -1.96105957e-01,  -1.96105957e-01],
                        [ -1.47491455e-01,  -1.47491455e-01],
                        [ -1.21368408e-01,  -1.21368408e-01],
                        [ -1.13616943e-01,  -1.13616943e-01],
                        [ -1.09252930e-01,  -1.09222412e-01],
                        [ -9.72900391e-02,  -9.72900391e-02],
                        [ -7.86743164e-02,  -7.86743164e-02],
                        [ -6.03332520e-02,  -6.03332520e-02],
                        [ -4.56237793e-02,  -4.56237793e-02],
                        [ -3.47290039e-02,  -3.47290039e-02],
                        [ -2.96325684e-02,  -2.96325684e-02],
                        [ -3.16467285e-02,  -3.16467285e-02],
                        [ -3.57666016e-02,  -3.57360840e-02],
                        [ -3.53088379e-02,  -3.52783203e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -3.89099121e-02,  -3.89099121e-02],
                        [ -4.19006348e-02,  -4.19006348e-02],
                        [ -2.85034180e-02,  -2.84729004e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [  5.49011230e-02,   5.49011230e-02],
                        [  1.09802246e-01,   1.09802246e-01],
                        [  1.60247803e-01,   1.60278320e-01],
                        [  1.92779541e-01,   1.92779541e-01],
                        [  1.94335938e-01,   1.94335938e-01],
                        [  1.67327881e-01,   1.67358398e-01],
                        [  1.34735107e-01,   1.34765625e-01],
                        [  1.19171143e-01,   1.19201660e-01],
                        [  1.20178223e-01,   1.20208740e-01],
                        [  1.20330811e-01,   1.20391846e-01],
                        [  1.07757568e-01,   1.07757568e-01],
                        [  8.48693848e-02,   8.48693848e-02],
                        [  6.10656738e-02,   6.11267090e-02],
                        [  4.27246094e-02,   4.27856445e-02],
                        [  2.99682617e-02,   2.99682617e-02],
                        [  2.06604004e-02,   2.06909180e-02],
                        [  1.36108398e-02,   1.36718750e-02],
                        [  6.40869141e-03,   6.43920898e-03],
                        [ -2.92968750e-03,  -2.89916992e-03],
                        [ -1.02539062e-02,  -1.02233887e-02],
                        [ -9.27734375e-03,  -9.21630859e-03],
                        [ -1.58691406e-03,  -1.58691406e-03],
                        [  5.37109375e-03,   5.40161133e-03],
                        [  9.73510742e-03,   9.76562500e-03],
                        [  1.49536133e-02,   1.49841309e-02],
                        [  2.00500488e-02,   2.00805664e-02],
                        [  1.91650391e-02,   1.91955566e-02],
                        [  1.24511719e-02,   1.24816895e-02],
                        [  9.42993164e-03,   9.46044922e-03],
                        [  1.89514160e-02,   1.89819336e-02],
                        [  4.00085449e-02,   4.00390625e-02],
                        [  6.39038086e-02,   6.39343262e-02],
                        [  8.30688477e-02,   8.30993652e-02],
                        [  9.53063965e-02,   9.53369141e-02],
                        [  9.74121094e-02,   9.74731445e-02],
                        [  7.62634277e-02,   7.62939453e-02],
                        [  1.62048340e-02,   1.62048340e-02],
                        [ -7.56225586e-02,  -7.55615234e-02],
                        [ -1.61621094e-01,  -1.61560059e-01],
                        [ -2.03338623e-01,  -2.03338623e-01],
                        [ -1.93908691e-01,  -1.93878174e-01],
                        [ -1.56097412e-01,  -1.56036377e-01],
                        [ -1.17156982e-01,  -1.17126465e-01],
                        [ -9.14001465e-02,  -9.14001465e-02],
                        [ -7.86743164e-02,  -7.86437988e-02],
                        [ -7.17468262e-02,  -7.16857910e-02],
                        [ -6.60095215e-02,  -6.60095215e-02],
                        [ -6.43920898e-02,  -6.43615723e-02],
                        [ -7.01293945e-02,  -7.00683594e-02],
                        [ -7.69348145e-02,  -7.69042969e-02],
                        [ -7.34863281e-02,  -7.34863281e-02],
                        [ -5.86547852e-02,  -5.85937500e-02],
                        [ -4.44335938e-02,  -4.43725586e-02],
                        [ -4.04968262e-02,  -4.04663086e-02],
                        [ -4.33654785e-02,  -4.33349609e-02],
                        [ -4.50439453e-02,  -4.49829102e-02],
                        [ -4.58679199e-02,  -4.58374023e-02],
                        [ -5.29785156e-02,  -5.29785156e-02],
                        [ -6.92138672e-02,  -6.91833496e-02],
                        [ -8.77685547e-02,  -8.77075195e-02],
                        [ -9.73510742e-02,  -9.73510742e-02],
                        [ -9.02709961e-02,  -9.02404785e-02],
                        [ -6.58264160e-02,  -6.57653809e-02],
                        [ -2.89001465e-02,  -2.88696289e-02],
                        [  1.39465332e-02,   1.39465332e-02],
                        [  5.59082031e-02,   5.59692383e-02],
                        [  8.88061523e-02,   8.88671875e-02],
                        [  1.05834961e-01,   1.05834961e-01],
                        [  1.08459473e-01,   1.08489990e-01],
                        [  1.06109619e-01,   1.06140137e-01],
                        [  1.06262207e-01,   1.06292725e-01],
                        [  1.08764648e-01,   1.08764648e-01],
                        [  1.08856201e-01,   1.08886719e-01],
                        [  1.02966309e-01,   1.02996826e-01],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  8.96301270e-02,   8.96606445e-02],
                        [  9.64965820e-02,   9.65270996e-02],
                        [  1.08825684e-01,   1.08856201e-01],
                        [  1.16027832e-01,   1.16058350e-01],
                        [  1.16333008e-01,   1.16363525e-01],
                        [  1.19384766e-01,   1.19415283e-01],
                        [  1.32232666e-01,   1.32263184e-01],
                        [  1.44287109e-01,   1.44317627e-01],
                        [  1.31835938e-01,   1.31866455e-01],
                        [  8.06274414e-02,   8.06274414e-02],
                        [ -6.40869141e-04,  -6.10351562e-04],
                        [ -9.20410156e-02,  -9.20104980e-02],
                        [ -1.80053711e-01,  -1.80023193e-01],
                        [ -2.53387451e-01,  -2.53387451e-01],
                        [ -2.90557861e-01,  -2.90527344e-01],
                        [ -2.73071289e-01,  -2.73071289e-01],
                        [ -2.14813232e-01,  -2.14782715e-01],
                        [ -1.57714844e-01,  -1.57714844e-01],
                        [ -1.30035400e-01,  -1.30035400e-01],
                        [ -1.22924805e-01,  -1.22894287e-01],
                        [ -1.14868164e-01,  -1.14837646e-01],
                        [ -1.01470947e-01,  -1.01440430e-01],
                        [ -9.02099609e-02,  -9.01794434e-02],
                        [ -8.04443359e-02,  -8.04138184e-02],
                        [ -6.39343262e-02,  -6.39038086e-02],
                        [ -4.00390625e-02,  -4.00085449e-02],
                        [ -1.85852051e-02,  -1.85546875e-02],
                        [ -8.54492188e-03,  -8.51440430e-03],
                        [ -1.02844238e-02,  -1.02844238e-02],
                        [ -1.78527832e-02,  -1.78527832e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -2.73742676e-02,  -2.73742676e-02],
                        [ -2.62756348e-02,  -2.62756348e-02],
                        [ -1.98364258e-02,  -1.98059082e-02],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [  3.17993164e-02,   3.17993164e-02],
                        [  8.02612305e-02,   8.02612305e-02],
                        [  1.33666992e-01,   1.33697510e-01],
                        [  1.77917480e-01,   1.77917480e-01],
                        [  1.99584961e-01,   1.99554443e-01],
                        [  1.94183350e-01,   1.94183350e-01],
                        [  1.70318604e-01,   1.70318604e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.21246338e-01,   1.21246338e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  8.28857422e-02,   8.28552246e-02],
                        [  6.86035156e-02,   6.86035156e-02],
                        [  5.76782227e-02,   5.77087402e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  5.10864258e-02,   5.10864258e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [ -2.88085938e-02,  -2.88085938e-02],
                        [ -3.64379883e-02,  -3.64379883e-02],
                        [ -3.29895020e-02,  -3.30200195e-02],
                        [ -1.98669434e-02,  -1.98669434e-02],
                        [  1.31225586e-03,   1.31225586e-03],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.11584473e-02,   3.11584473e-02],
                        [  2.81677246e-02,   2.81372070e-02],
                        [  2.66113281e-02,   2.66113281e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  3.18603516e-02,   3.18603516e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  9.11560059e-02,   9.11560059e-02],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  7.64160156e-02,   7.64160156e-02],
                        [  7.78198242e-03,   7.78198242e-03],
                        [ -8.18786621e-02,  -8.19091797e-02],
                        [ -1.61804199e-01,  -1.61804199e-01],
                        [ -1.99127197e-01,  -1.99127197e-01],
                        [ -1.84082031e-01,  -1.84082031e-01],
                        [ -1.39892578e-01,  -1.39923096e-01],
                        [ -1.02081299e-01,  -1.02081299e-01],
                        [ -8.80737305e-02,  -8.80737305e-02],
                        [ -8.93859863e-02,  -8.94165039e-02],
                        [ -8.92333984e-02,  -8.92333984e-02],
                        [ -8.24279785e-02,  -8.24279785e-02],
                        [ -7.57751465e-02,  -7.58056641e-02],
                        [ -7.30895996e-02,  -7.30895996e-02],
                        [ -6.98242188e-02,  -6.98242188e-02],
                        [ -6.38122559e-02,  -6.38427734e-02],
                        [ -5.82275391e-02,  -5.82580566e-02],
                        [ -5.27954102e-02,  -5.27648926e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -3.91540527e-02,  -3.91540527e-02],
                        [ -4.00390625e-02,  -4.00390625e-02],
                        [ -4.81872559e-02,  -4.81872559e-02],
                        [ -6.29272461e-02,  -6.29577637e-02],
                        [ -8.19702148e-02,  -8.19702148e-02],
                        [ -9.45129395e-02,  -9.45129395e-02],
                        [ -8.80737305e-02,  -8.80737305e-02],
                        [ -6.28051758e-02,  -6.28356934e-02],
                        [ -2.73437500e-02,  -2.73437500e-02],
                        [  1.55029297e-02,   1.54724121e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  1.08581543e-01,   1.08581543e-01],
                        [  1.28570557e-01,   1.28570557e-01],
                        [  1.23809814e-01,   1.23809814e-01],
                        [  1.12609863e-01,   1.12609863e-01],
                        [  1.08734131e-01,   1.08764648e-01],
                        [  1.08184814e-01,   1.08154297e-01],
                        [  1.03576660e-01,   1.03576660e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  9.68933105e-02,   9.68933105e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  9.63439941e-02,   9.63439941e-02],
                        [  9.86633301e-02,   9.86633301e-02],
                        [  1.08032227e-01,   1.08001709e-01],
                        [  1.22222900e-01,   1.22222900e-01],
                        [  1.37695312e-01,   1.37695312e-01],
                        [  1.51489258e-01,   1.51489258e-01],
                        [  1.55670166e-01,   1.55670166e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  8.19702148e-02,   8.19702148e-02],
                        [ -5.61523438e-03,  -5.64575195e-03],
                        [ -1.12121582e-01,  -1.12121582e-01],
                        [ -2.15667725e-01,  -2.15667725e-01],
                        [ -2.90985107e-01,  -2.90985107e-01],
                        [ -3.14056396e-01,  -3.14056396e-01],
                        [ -2.78533936e-01,  -2.78533936e-01],
                        [ -2.11181641e-01,  -2.11181641e-01],
                        [ -1.54724121e-01,  -1.54724121e-01],
                        [ -1.28204346e-01,  -1.28234863e-01],
                        [ -1.16699219e-01,  -1.16729736e-01],
                        [ -1.01959229e-01,  -1.01959229e-01],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -7.57751465e-02,  -7.57751465e-02],
                        [ -7.17468262e-02,  -7.17468262e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -6.39038086e-02,  -6.39038086e-02],
                        [ -5.46569824e-02,  -5.46569824e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -1.47399902e-02,  -1.47399902e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [ -1.12915039e-02,  -1.12915039e-02],
                        [ -2.20031738e-02,  -2.20031738e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -1.28479004e-02,  -1.28479004e-02],
                        [  2.05383301e-02,   2.05383301e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  1.23931885e-01,   1.23931885e-01],
                        [  1.66595459e-01,   1.66595459e-01],
                        [  1.91619873e-01,   1.91619873e-01],
                        [  1.95343018e-01,   1.95343018e-01],
                        [  1.80389404e-01,   1.80389404e-01],
                        [  1.59637451e-01,   1.59637451e-01],
                        [  1.44195557e-01,   1.44226074e-01],
                        [  1.29608154e-01,   1.29577637e-01],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  8.16650391e-02,   8.16955566e-02],
                        [  6.59484863e-02,   6.59484863e-02],
                        [  5.96923828e-02,   5.96618652e-02],
                        [  5.58471680e-02,   5.58776855e-02],
                        [  5.28564453e-02,   5.28564453e-02],
                        [  4.92858887e-02,   4.92553711e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  1.84631348e-02,   1.84631348e-02],
                        [ -5.06591797e-03,  -5.09643555e-03],
                        [ -2.39868164e-02,  -2.40173340e-02],
                        [ -3.41186523e-02,  -3.40881348e-02],
                        [ -3.38134766e-02,  -3.38134766e-02],
                        [ -2.31628418e-02,  -2.31933594e-02],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  1.15356445e-02,   1.15356445e-02],
                        [  1.89514160e-02,   1.89208984e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  1.89514160e-02,   1.89819336e-02],
                        [  2.47497559e-02,   2.47497559e-02],
                        [  2.84729004e-02,   2.84423828e-02],
                        [  2.79541016e-02,   2.79846191e-02],
                        [  3.16467285e-02,   3.16467285e-02],
                        [  4.36706543e-02,   4.36401367e-02],
                        [  5.73425293e-02,   5.73425293e-02],
                        [  6.79321289e-02,   6.79626465e-02],
                        [  7.81860352e-02,   7.82165527e-02],
                        [  8.65783691e-02,   8.65478516e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  4.73022461e-02,   4.73022461e-02],
                        [ -1.71203613e-02,  -1.71508789e-02],
                        [ -9.94262695e-02,  -9.94262695e-02],
                        [ -1.70593262e-01,  -1.70562744e-01],
                        [ -1.99890137e-01,  -1.99890137e-01],
                        [ -1.77917480e-01,  -1.77947998e-01],
                        [ -1.26464844e-01,  -1.26434326e-01],
                        [ -8.24890137e-02,  -8.24584961e-02],
                        [ -6.89086914e-02,  -6.89086914e-02],
                        [ -7.79724121e-02,  -7.80029297e-02],
                        [ -8.61816406e-02,  -8.61816406e-02],
                        [ -8.36486816e-02,  -8.36486816e-02],
                        [ -7.91931152e-02,  -7.91931152e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -8.06579590e-02,  -8.06274414e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -7.87658691e-02,  -7.87963867e-02],
                        [ -7.50427246e-02,  -7.50427246e-02],
                        [ -6.41784668e-02,  -6.41784668e-02],
                        [ -5.31616211e-02,  -5.31616211e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -6.58874512e-02,  -6.58874512e-02],
                        [ -7.62329102e-02,  -7.62634277e-02],
                        [ -7.94067383e-02,  -7.94067383e-02],
                        [ -7.64465332e-02,  -7.64465332e-02],
                        [ -6.39038086e-02,  -6.38732910e-02],
                        [ -3.61633301e-02,  -3.61938477e-02],
                        [  3.93676758e-03,   3.93676758e-03],
                        [  4.71496582e-02,   4.71801758e-02],
                        [  8.54187012e-02,   8.53881836e-02],
                        [  1.13037109e-01,   1.13037109e-01],
                        [  1.24938965e-01,   1.24969482e-01],
                        [  1.19293213e-01,   1.19293213e-01],
                        [  1.02325439e-01,   1.02294922e-01],
                        [  8.71887207e-02,   8.71887207e-02],
                        [  8.37402344e-02,   8.37707520e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  9.59472656e-02,   9.59472656e-02],
                        [  9.77783203e-02,   9.78088379e-02],
                        [  9.87548828e-02,   9.87548828e-02],
                        [  1.06140137e-01,   1.06109619e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.53289795e-01,   1.53289795e-01],
                        [  1.77886963e-01,   1.77856445e-01],
                        [  1.85089111e-01,   1.85089111e-01],
                        [  1.69403076e-01,   1.69403076e-01],
                        [  1.31164551e-01,   1.31164551e-01],
                        [  6.77490234e-02,   6.77490234e-02],
                        [ -2.45971680e-02,  -2.45971680e-02],
                        [ -1.37237549e-01,  -1.37237549e-01],
                        [ -2.42675781e-01,  -2.42675781e-01],
                        [ -3.06884766e-01,  -3.06884766e-01],
                        [ -3.12286377e-01,  -3.12286377e-01],
                        [ -2.70629883e-01,  -2.70629883e-01],
                        [ -2.13653564e-01,  -2.13653564e-01],
                        [ -1.68365479e-01,  -1.68365479e-01],
                        [ -1.39984131e-01,  -1.39984131e-01],
                        [ -1.16699219e-01,  -1.16699219e-01],
                        [ -8.89282227e-02,  -8.89282227e-02],
                        [ -6.16149902e-02,  -6.16149902e-02],
                        [ -4.61425781e-02,  -4.61425781e-02],
                        [ -4.41894531e-02,  -4.41589355e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.19311523e-02,  -4.19616699e-02],
                        [ -3.60412598e-02,  -3.60412598e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -4.66613770e-02,  -4.66613770e-02],
                        [ -4.77600098e-02,  -4.77294922e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [  1.91650391e-02,   1.91955566e-02],
                        [  7.63244629e-02,   7.63244629e-02],
                        [  1.36871338e-01,   1.36871338e-01],
                        [  1.86157227e-01,   1.86157227e-01],
                        [  2.15454102e-01,   2.15454102e-01],
                        [  2.20336914e-01,   2.20336914e-01],
                        [  2.03674316e-01,   2.03674316e-01],
                        [  1.77795410e-01,   1.77825928e-01],
                        [  1.54876709e-01,   1.54876709e-01],
                        [  1.36718750e-01,   1.36688232e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  9.51232910e-02,   9.51538086e-02],
                        [  7.11975098e-02,   7.11975098e-02],
                        [  5.41076660e-02,   5.41076660e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.98352051e-02,   4.98352051e-02],
                        [  4.56237793e-02,   4.55932617e-02],
                        [  3.61633301e-02,   3.61938477e-02],
                        [  2.91442871e-02,   2.91748047e-02],
                        [  2.25524902e-02,   2.25219727e-02],
                        [  7.17163086e-03,   7.17163086e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.44140625e-02,  -2.44140625e-02],
                        [ -1.71813965e-02,  -1.71813965e-02],
                        [ -9.39941406e-03,  -9.39941406e-03],
                        [ -3.66210938e-03,  -3.66210938e-03],
                        [ -3.05175781e-03,  -3.02124023e-03],
                        [ -5.70678711e-03,  -5.70678711e-03],
                        [ -3.41796875e-03,  -3.41796875e-03],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  2.11791992e-02,   2.12097168e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  3.58886719e-02,   3.58581543e-02],
                        [  4.70581055e-02,   4.70581055e-02],
                        [  6.40869141e-02,   6.40869141e-02],
                        [  7.85522461e-02,   7.85522461e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  8.94470215e-02,   8.94470215e-02],
                        [  7.82470703e-02,   7.82470703e-02],
                        [  3.93676758e-02,   3.93676758e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -1.11724854e-01,  -1.11724854e-01],
                        [ -1.76361084e-01,  -1.76361084e-01],
                        [ -1.99615479e-01,  -1.99615479e-01],
                        [ -1.76605225e-01,  -1.76605225e-01],
                        [ -1.27136230e-01,  -1.27105713e-01],
                        [ -8.45336914e-02,  -8.45336914e-02],
                        [ -6.99768066e-02,  -6.99768066e-02],
                        [ -7.65686035e-02,  -7.65380859e-02],
                        [ -8.33740234e-02,  -8.33740234e-02],
                        [ -8.05358887e-02,  -8.05664062e-02],
                        [ -7.40661621e-02,  -7.40661621e-02],
                        [ -7.16857910e-02,  -7.16857910e-02],
                        [ -7.29370117e-02,  -7.29370117e-02],
                        [ -7.27233887e-02,  -7.27233887e-02],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [ -6.50634766e-02,  -6.50634766e-02],
                        [ -6.51855469e-02,  -6.51855469e-02],
                        [ -6.84509277e-02,  -6.84509277e-02],
                        [ -6.99462891e-02,  -6.99462891e-02],
                        [ -6.72912598e-02,  -6.73217773e-02],
                        [ -6.29272461e-02,  -6.29272461e-02],
                        [ -5.93566895e-02,  -5.93566895e-02],
                        [ -5.54809570e-02,  -5.54809570e-02],
                        [ -4.53186035e-02,  -4.53186035e-02],
                        [ -2.04467773e-02,  -2.04467773e-02],
                        [  2.09960938e-02,   2.09960938e-02],
                        [  6.82373047e-02,   6.82373047e-02],
                        [  1.06628418e-01,   1.06628418e-01],
                        [  1.28540039e-01,   1.28540039e-01],
                        [  1.31378174e-01,   1.31378174e-01],
                        [  1.15966797e-01,   1.15966797e-01],
                        [  9.29870605e-02,   9.29870605e-02],
                        [  7.91931152e-02,   7.91931152e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.04614258e-01,   1.04614258e-01],
                        [  1.15936279e-01,   1.15936279e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.47888184e-01,   1.47888184e-01],
                        [  1.73126221e-01,   1.73126221e-01],
                        [  1.95098877e-01,   1.95129395e-01],
                        [  1.97174072e-01,   1.97143555e-01],
                        [  1.67083740e-01,   1.67083740e-01],
                        [  1.02996826e-01,   1.02996826e-01],
                        [  1.01318359e-02,   1.01318359e-02],
                        [ -1.00402832e-01,  -1.00402832e-01],
                        [ -2.09777832e-01,  -2.09777832e-01],
                        [ -2.92236328e-01,  -2.92236328e-01],
                        [ -3.21075439e-01,  -3.21075439e-01],
                        [ -2.84332275e-01,  -2.84332275e-01],
                        [ -2.04864502e-01,  -2.04864502e-01],
                        [ -1.34063721e-01,  -1.34063721e-01],
                        [ -1.07086182e-01,  -1.07086182e-01],
                        [ -1.10748291e-01,  -1.10748291e-01],
                        [ -1.09436035e-01,  -1.09436035e-01],
                        [ -9.12170410e-02,  -9.12170410e-02],
                        [ -7.20520020e-02,  -7.20520020e-02],
                        [ -6.63757324e-02,  -6.63757324e-02],
                        [ -7.09533691e-02,  -7.09533691e-02],
                        [ -7.20520020e-02,  -7.20520020e-02],
                        [ -5.87768555e-02,  -5.87768555e-02],
                        [ -3.37219238e-02,  -3.37219238e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [ -1.71508789e-02,  -1.71508789e-02],
                        [ -3.47595215e-02,  -3.47595215e-02],
                        [ -4.33349609e-02,  -4.33349609e-02],
                        [ -2.51159668e-02,  -2.51464844e-02],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  7.84301758e-02,   7.84301758e-02],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.85302734e-01,   1.85302734e-01],
                        [  2.06268311e-01,   2.06298828e-01],
                        [  1.97296143e-01,   1.97296143e-01],
                        [  1.69342041e-01,   1.69342041e-01],
                        [  1.41937256e-01,   1.41937256e-01],
                        [  1.25793457e-01,   1.25793457e-01],
                        [  1.16760254e-01,   1.16760254e-01],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  8.90502930e-02,   8.90502930e-02],
                        [  7.78198242e-02,   7.78198242e-02],
                        [  6.64672852e-02,   6.64672852e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  4.62036133e-02,   4.62036133e-02],
                        [  2.68859863e-02,   2.68554688e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [ -8.78906250e-03,  -8.75854492e-03],
                        [ -1.12304688e-02,  -1.12609863e-02],
                        [ -1.21459961e-02,  -1.21459961e-02],
                        [ -1.79443359e-02,  -1.79138184e-02],
                        [ -2.61535645e-02,  -2.61535645e-02],
                        [ -3.06396484e-02,  -3.06396484e-02],
                        [ -2.68554688e-02,  -2.68249512e-02],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [  1.83105469e-03,   1.86157227e-03],
                        [  8.78906250e-03,   8.78906250e-03],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.06201172e-02,   1.06201172e-02],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.52893066e-02,   1.52893066e-02],
                        [  3.14941406e-02,   3.14941406e-02],
                        [  5.21240234e-02,   5.21240234e-02],
                        [  6.95495605e-02,   6.95495605e-02],
                        [  8.34350586e-02,   8.34350586e-02],
                        [  9.37500000e-02,   9.37500000e-02],
                        [  8.95996094e-02,   8.96301270e-02],
                        [  5.76782227e-02,   5.76782227e-02],
                        [ -7.93457031e-04,  -7.93457031e-04],
                        [ -7.06481934e-02,  -7.06481934e-02],
                        [ -1.34277344e-01,  -1.34277344e-01],
                        [ -1.74835205e-01,  -1.74865723e-01],
                        [ -1.80114746e-01,  -1.80114746e-01],
                        [ -1.56219482e-01,  -1.56219482e-01],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -1.11480713e-01,  -1.11480713e-01],
                        [ -1.05743408e-01,  -1.05743408e-01],
                        [ -1.00921631e-01,  -1.00921631e-01],
                        [ -9.45739746e-02,  -9.45739746e-02],
                        [ -8.78601074e-02,  -8.78601074e-02],
                        [ -8.13293457e-02,  -8.13293457e-02],
                        [ -7.59887695e-02,  -7.59582520e-02],
                        [ -7.19909668e-02,  -7.19909668e-02],
                        [ -6.66503906e-02,  -6.66809082e-02],
                        [ -5.85327148e-02,  -5.85021973e-02],
                        [ -5.13916016e-02,  -5.13916016e-02],
                        [ -5.01098633e-02,  -5.01403809e-02],
                        [ -5.41381836e-02,  -5.41381836e-02],
                        [ -5.88378906e-02,  -5.88378906e-02],
                        [ -6.22558594e-02,  -6.22558594e-02],
                        [ -6.55517578e-02,  -6.55517578e-02],
                        [ -6.65588379e-02,  -6.65283203e-02],
                        [ -5.79223633e-02,  -5.79223633e-02],
                        [ -3.29284668e-02,  -3.29589844e-02],
                        [  7.56835938e-03,   7.59887695e-03],
                        [  5.42297363e-02,   5.42602539e-02],
                        [  9.44519043e-02,   9.44213867e-02],
                        [  1.20391846e-01,   1.20391846e-01],
                        [  1.31256104e-01,   1.31286621e-01],
                        [  1.28814697e-01,   1.28784180e-01],
                        [  1.15997314e-01,   1.15997314e-01],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  9.10339355e-02,   9.10339355e-02],
                        [  9.14001465e-02,   9.13696289e-02],
                        [  9.87548828e-02,   9.87854004e-02],
                        [  1.11328125e-01,   1.11358643e-01],
                        [  1.29364014e-01,   1.29364014e-01],
                        [  1.51611328e-01,   1.51580811e-01],
                        [  1.74194336e-01,   1.74224854e-01],
                        [  1.90155029e-01,   1.90155029e-01],
                        [  1.87652588e-01,   1.87622070e-01],
                        [  1.53411865e-01,   1.53411865e-01],
                        [  8.12072754e-02,   8.12377930e-02],
                        [ -2.30407715e-02,  -2.30712891e-02],
                        [ -1.42456055e-01,  -1.42456055e-01],
                        [ -2.51281738e-01,  -2.51251221e-01],
                        [ -3.18359375e-01,  -3.18359375e-01],
                        [ -3.19946289e-01,  -3.19946289e-01],
                        [ -2.61322021e-01,  -2.61322021e-01],
                        [ -1.82525635e-01,  -1.82525635e-01],
                        [ -1.28845215e-01,  -1.28845215e-01],
                        [ -1.12884521e-01,  -1.12884521e-01],
                        [ -1.13983154e-01,  -1.13983154e-01],
                        [ -1.09649658e-01,  -1.09649658e-01],
                        [ -9.50317383e-02,  -9.50317383e-02],
                        [ -7.61108398e-02,  -7.61108398e-02],
                        [ -5.86242676e-02,  -5.86242676e-02],
                        [ -4.50134277e-02,  -4.50439453e-02],
                        [ -3.45458984e-02,  -3.45764160e-02],
                        [ -2.53906250e-02,  -2.53906250e-02],
                        [ -1.83410645e-02,  -1.83105469e-02],
                        [ -1.54724121e-02,  -1.55029297e-02],
                        [ -1.47094727e-02,  -1.46789551e-02],
                        [ -1.06201172e-02,  -1.05895996e-02],
                        [ -5.18798828e-04,  -5.18798828e-04],
                        [  1.80053711e-02,   1.80053711e-02],
                        [  5.16967773e-02,   5.16967773e-02],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  1.59179688e-01,   1.59179688e-01],
                        [  1.98242188e-01,   1.98242188e-01],
                        [  2.08343506e-01,   2.08343506e-01],
                        [  1.95678711e-01,   1.95648193e-01],
                        [  1.75323486e-01,   1.75323486e-01],
                        [  1.56158447e-01,   1.56158447e-01],
                        [  1.36810303e-01,   1.36810303e-01],
                        [  1.16668701e-01,   1.16668701e-01],
                        [  1.01165771e-01,   1.01165771e-01],
                        [  9.24072266e-02,   9.24072266e-02],
                        [  8.46252441e-02,   8.45947266e-02],
                        [  7.26013184e-02,   7.26013184e-02],
                        [  5.53283691e-02,   5.53283691e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  7.32421875e-03,   7.32421875e-03],
                        [ -1.11999512e-02,  -1.11999512e-02],
                        [ -1.76391602e-02,  -1.76391602e-02],
                        [ -1.51977539e-02,  -1.51977539e-02],
                        [ -8.42285156e-03,  -8.42285156e-03],
                        [  2.74658203e-04,   2.74658203e-04],
                        [  4.85229492e-03,   4.88281250e-03],
                        [ -9.46044922e-04,  -9.46044922e-04],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [  2.77709961e-03,   2.77709961e-03],
                        [ -2.28881836e-03,  -2.31933594e-03],
                        [ -6.50024414e-03,  -6.46972656e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [  6.46972656e-03,   6.46972656e-03],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  3.41491699e-02,   3.41491699e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  8.90197754e-02,   8.90197754e-02],
                        [  1.07360840e-01,   1.07360840e-01],
                        [  1.16088867e-01,   1.16088867e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  8.78295898e-02,   8.77990723e-02],
                        [  3.14636230e-02,   3.14636230e-02],
                        [ -4.83703613e-02,  -4.83703613e-02],
                        [ -1.29882812e-01,  -1.29882812e-01],
                        [ -1.88507080e-01,  -1.88507080e-01],
                        [ -2.08587646e-01,  -2.08587646e-01],
                        [ -1.92749023e-01,  -1.92749023e-01],
                        [ -1.60736084e-01,  -1.60736084e-01],
                        [ -1.32568359e-01,  -1.32568359e-01],
                        [ -1.13586426e-01,  -1.13555908e-01],
                        [ -9.77783203e-02,  -9.77783203e-02],
                        [ -8.16955566e-02,  -8.16955566e-02],
                        [ -7.02514648e-02,  -7.02514648e-02],
                        [ -6.97631836e-02,  -6.97631836e-02],
                        [ -7.76062012e-02,  -7.76062012e-02],
                        [ -8.27941895e-02,  -8.27636719e-02],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -7.15637207e-02,  -7.15637207e-02],
                        [ -6.62841797e-02,  -6.62841797e-02],
                        [ -6.29577637e-02,  -6.29272461e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -6.44226074e-02,  -6.44226074e-02],
                        [ -7.18994141e-02,  -7.18994141e-02],
                        [ -7.64465332e-02,  -7.64465332e-02],
                        [ -6.90307617e-02,  -6.90612793e-02],
                        [ -4.27246094e-02,  -4.26940918e-02],
                        [  2.86865234e-03,   2.86865234e-03],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  9.35668945e-02,   9.35363770e-02],
                        [  1.09375000e-01,   1.09405518e-01],
                        [  1.10412598e-01,   1.10412598e-01],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  1.04858398e-01,   1.04858398e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [  1.00524902e-01,   1.00524902e-01],
                        [  1.12152100e-01,   1.12152100e-01],
                        [  1.31866455e-01,   1.31866455e-01],
                        [  1.54724121e-01,   1.54724121e-01],
                        [  1.77856445e-01,   1.77856445e-01],
                        [  1.97235107e-01,   1.97235107e-01],
                        [  2.04681396e-01,   2.04681396e-01],
                        [  1.90032959e-01,   1.90032959e-01],
                        [  1.43829346e-01,   1.43829346e-01],
                        [  6.16760254e-02,   6.16760254e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -1.66137695e-01,  -1.66137695e-01],
                        [ -2.63000488e-01,  -2.63000488e-01],
                        [ -3.17504883e-01,  -3.17504883e-01],
                        [ -3.17962646e-01,  -3.17962646e-01],
                        [ -2.67974854e-01,  -2.67974854e-01],
                        [ -1.91986084e-01,  -1.91986084e-01],
                        [ -1.26617432e-01,  -1.26617432e-01],
                        [ -9.52453613e-02,  -9.52453613e-02],
                        [ -9.10034180e-02,  -9.10034180e-02],
                        [ -9.06372070e-02,  -9.06372070e-02],
                        [ -8.23059082e-02,  -8.23059082e-02],
                        [ -7.30285645e-02,  -7.30285645e-02],
                        [ -7.04040527e-02,  -7.04040527e-02],
                        [ -7.06787109e-02,  -7.06787109e-02],
                        [ -6.92138672e-02,  -6.92138672e-02],
                        [ -6.98547363e-02,  -6.98547363e-02],
                        [ -7.52563477e-02,  -7.52563477e-02],
                        [ -7.77282715e-02,  -7.77282715e-02],
                        [ -6.64367676e-02,  -6.64672852e-02],
                        [ -3.55529785e-02,  -3.55529785e-02],
                        [  1.42517090e-02,   1.42517090e-02],
                        [  7.46154785e-02,   7.45849609e-02],
                        [  1.32171631e-01,   1.32171631e-01],
                        [  1.76635742e-01,   1.76635742e-01],
                        [  2.01293945e-01,   2.01293945e-01],
                        [  2.01599121e-01,   2.01568604e-01],
                        [  1.82922363e-01,   1.82952881e-01],
                        [  1.61285400e-01,   1.61315918e-01],
                        [  1.46392822e-01,   1.46392822e-01],
                        [  1.34735107e-01,   1.34735107e-01],
                        [  1.22619629e-01,   1.22650146e-01],
                        [  1.11145020e-01,   1.11145020e-01],
                        [  9.75646973e-02,   9.75341797e-02],
                        [  7.83996582e-02,   7.84301758e-02],
                        [  5.97839355e-02,   5.98144531e-02],
                        [  4.88281250e-02,   4.88281250e-02],
                        [  3.98559570e-02,   3.98559570e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  4.45556641e-03,   4.45556641e-03],
                        [  7.23266602e-03,   7.23266602e-03],
                        [  7.72094727e-03,   7.72094727e-03],
                        [  7.01904297e-03,   7.01904297e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [ -4.08935547e-03,  -4.08935547e-03],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -3.37829590e-02,  -3.37524414e-02],
                        [ -3.65600586e-02,  -3.65600586e-02],
                        [ -3.22570801e-02,  -3.22875977e-02],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -1.17187500e-02,  -1.17187500e-02],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  4.91333008e-03,   4.91333008e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  3.13415527e-02,   3.13415527e-02],
                        [  4.96215820e-02,   4.96215820e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  7.17163086e-02,   7.17163086e-02],
                        [  7.56225586e-02,   7.56225586e-02],
                        [  8.08105469e-02,   8.07800293e-02],
                        [  8.69140625e-02,   8.69140625e-02],
                        [  8.11462402e-02,   8.11462402e-02],
                        [  4.48608398e-02,   4.48303223e-02],
                        [ -2.53295898e-02,  -2.52990723e-02],
                        [ -1.07482910e-01,  -1.07452393e-01],
                        [ -1.69891357e-01,  -1.69891357e-01],
                        [ -1.91497803e-01,  -1.91497803e-01],
                        [ -1.72454834e-01,  -1.72424316e-01],
                        [ -1.34918213e-01,  -1.34918213e-01],
                        [ -1.08581543e-01,  -1.08612061e-01],
                        [ -1.04736328e-01,  -1.04736328e-01],
                        [ -1.09893799e-01,  -1.09893799e-01],
                        [ -1.08032227e-01,  -1.08032227e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -9.11254883e-02,  -9.10949707e-02],
                        [ -9.15832520e-02,  -9.15832520e-02],
                        [ -9.71679688e-02,  -9.71679688e-02],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -7.81555176e-02,  -7.81555176e-02],
                        [ -5.02319336e-02,  -5.02319336e-02],
                        [ -3.12500000e-02,  -3.12500000e-02],
                        [ -3.10058594e-02,  -3.10058594e-02],
                        [ -4.24194336e-02,  -4.24194336e-02],
                        [ -5.49621582e-02,  -5.49926758e-02],
                        [ -6.16760254e-02,  -6.16760254e-02],
                        [ -5.40771484e-02,  -5.40771484e-02],
                        [ -2.61230469e-02,  -2.61230469e-02],
                        [  1.63574219e-02,   1.63269043e-02],
                        [  5.93872070e-02,   5.93872070e-02],
                        [  9.25598145e-02,   9.25598145e-02],
                        [  1.11267090e-01,   1.11267090e-01],
                        [  1.14990234e-01,   1.14990234e-01],
                        [  1.09100342e-01,   1.09100342e-01],
                        [  1.03454590e-01,   1.03424072e-01],
                        [  1.04125977e-01,   1.04125977e-01],
                        [  1.09588623e-01,   1.09588623e-01],
                        [  1.16363525e-01,   1.16363525e-01],
                        [  1.26434326e-01,   1.26403809e-01],
                        [  1.45355225e-01,   1.45355225e-01],
                        [  1.72302246e-01,   1.72332764e-01],
                        [  1.95648193e-01,   1.95648193e-01],
                        [  2.03002930e-01,   2.03002930e-01],
                        [  1.90734863e-01,   1.90765381e-01],
                        [  1.58508301e-01,   1.58477783e-01],
                        [  1.01135254e-01,   1.01135254e-01],
                        [  1.42517090e-02,   1.42822266e-02],
                        [ -9.54284668e-02,  -9.54284668e-02],
                        [ -2.06237793e-01,  -2.06268311e-01],
                        [ -2.86773682e-01,  -2.86773682e-01],
                        [ -3.11218262e-01,  -3.11218262e-01],
                        [ -2.78656006e-01,  -2.78656006e-01],
                        [ -2.15820312e-01,  -2.15820312e-01],
                        [ -1.57012939e-01,  -1.56982422e-01],
                        [ -1.20971680e-01,  -1.20971680e-01],
                        [ -1.04675293e-01,  -1.04675293e-01],
                        [ -9.38720703e-02,  -9.38415527e-02],
                        [ -7.96813965e-02,  -7.96813965e-02],
                        [ -6.64062500e-02,  -6.64062500e-02],
                        [ -6.18896484e-02,  -6.18896484e-02],
                        [ -6.43615723e-02,  -6.43615723e-02],
                        [ -6.54602051e-02,  -6.54602051e-02],
                        [ -6.29577637e-02,  -6.29577637e-02],
                        [ -5.97229004e-02,  -5.97229004e-02],
                        [ -5.33447266e-02,  -5.33447266e-02],
                        [ -3.72009277e-02,  -3.72009277e-02],
                        [ -1.08337402e-02,  -1.08337402e-02],
                        [  2.04162598e-02,   2.04162598e-02],
                        [  5.50842285e-02,   5.51147461e-02],
                        [  9.63745117e-02,   9.63745117e-02],
                        [  1.41784668e-01,   1.41784668e-01],
                        [  1.78039551e-01,   1.78070068e-01],
                        [  1.90429688e-01,   1.90429688e-01],
                        [  1.77185059e-01,   1.77185059e-01],
                        [  1.52282715e-01,   1.52252197e-01],
                        [  1.32720947e-01,   1.32720947e-01],
                        [  1.25274658e-01,   1.25274658e-01],
                        [  1.25305176e-01,   1.25274658e-01],
                        [  1.23992920e-01,   1.23992920e-01],
                        [  1.15417480e-01,   1.15417480e-01],
                        [  1.00769043e-01,   1.00769043e-01],
                        [  8.72802734e-02,   8.72802734e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  6.82983398e-02,   6.82983398e-02],
                        [  4.93774414e-02,   4.93774414e-02],
                        [  2.59399414e-02,   2.59399414e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -1.05895996e-02,  -1.05895996e-02],
                        [ -2.49023438e-02,  -2.49023438e-02],
                        [ -2.85034180e-02,  -2.84729004e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -5.49316406e-03,  -5.52368164e-03],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -1.12609863e-02,  -1.12609863e-02],
                        [ -1.46484375e-02,  -1.46484375e-02],
                        [ -1.45874023e-02,  -1.46179199e-02],
                        [ -1.13830566e-02,  -1.13525391e-02],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [  2.62451172e-03,   2.59399414e-03],
                        [ -4.27246094e-04,  -4.27246094e-04],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [ -7.11059570e-03,  -7.11059570e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [  3.02124023e-03,   3.02124023e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  3.59191895e-02,   3.58886719e-02],
                        [  6.31408691e-02,   6.31408691e-02],
                        [  8.56933594e-02,   8.56933594e-02],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  9.49096680e-02,   9.49096680e-02],
                        [  7.83386230e-02,   7.83691406e-02],
                        [  4.40979004e-02,   4.40979004e-02],
                        [ -1.02539062e-02,  -1.02539062e-02],
                        [ -7.99255371e-02,  -7.99255371e-02],
                        [ -1.44744873e-01,  -1.44744873e-01],
                        [ -1.77124023e-01,  -1.77124023e-01],
                        [ -1.68212891e-01,  -1.68212891e-01],
                        [ -1.39099121e-01,  -1.39068604e-01],
                        [ -1.18316650e-01,  -1.18316650e-01],
                        [ -1.15844727e-01,  -1.15844727e-01],
                        [ -1.22955322e-01,  -1.22955322e-01],
                        [ -1.27288818e-01,  -1.27258301e-01],
                        [ -1.21520996e-01,  -1.21520996e-01],
                        [ -1.07116699e-01,  -1.07116699e-01],
                        [ -9.42993164e-02,  -9.42993164e-02],
                        [ -9.21936035e-02,  -9.21936035e-02],
                        [ -9.60083008e-02,  -9.60083008e-02],
                        [ -9.17663574e-02,  -9.17663574e-02],
                        [ -7.47985840e-02,  -7.47985840e-02],
                        [ -5.51452637e-02,  -5.51452637e-02],
                        [ -4.33959961e-02,  -4.33959961e-02],
                        [ -3.97033691e-02,  -3.97033691e-02],
                        [ -3.92761230e-02,  -3.92761230e-02],
                        [ -3.90930176e-02,  -3.90930176e-02],
                        [ -3.52478027e-02,  -3.52478027e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [  1.47705078e-02,   1.47705078e-02],
                        [  5.85021973e-02,   5.85021973e-02],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  1.00402832e-01,   1.00402832e-01],
                        [  9.50622559e-02,   9.50927734e-02],
                        [  9.25903320e-02,   9.25903320e-02],
                        [  9.90905762e-02,   9.90600586e-02],
                        [  1.10046387e-01,   1.10046387e-01],
                        [  1.20697021e-01,   1.20697021e-01],
                        [  1.29241943e-01,   1.29211426e-01],
                        [  1.38458252e-01,   1.38458252e-01],
                        [  1.56280518e-01,   1.56311035e-01],
                        [  1.85150146e-01,   1.85119629e-01],
                        [  2.12188721e-01,   2.12219238e-01],
                        [  2.17956543e-01,   2.17987061e-01],
                        [  1.90307617e-01,   1.90307617e-01],
                        [  1.26708984e-01,   1.26708984e-01],
                        [  3.19213867e-02,   3.19519043e-02],
                        [ -8.08410645e-02,  -8.08410645e-02],
                        [ -1.91589355e-01,  -1.91619873e-01],
                        [ -2.77648926e-01,  -2.77648926e-01],
                        [ -3.16864014e-01,  -3.16833496e-01],
                        [ -2.98034668e-01,  -2.98034668e-01],
                        [ -2.36450195e-01,  -2.36450195e-01],
                        [ -1.70288086e-01,  -1.70288086e-01],
                        [ -1.31072998e-01,  -1.31072998e-01],
                        [ -1.20178223e-01,  -1.20208740e-01],
                        [ -1.16363525e-01,  -1.16363525e-01],
                        [ -1.01715088e-01,  -1.01684570e-01],
                        [ -7.83691406e-02,  -7.83996582e-02],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -6.39953613e-02,  -6.39953613e-02],
                        [ -7.34252930e-02,  -7.34252930e-02],
                        [ -7.72705078e-02,  -7.72705078e-02],
                        [ -7.37304688e-02,  -7.37304688e-02],
                        [ -6.67724609e-02,  -6.67419434e-02],
                        [ -5.19104004e-02,  -5.19104004e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  8.42285156e-02,   8.42285156e-02],
                        [  1.41448975e-01,   1.41448975e-01],
                        [  1.85943604e-01,   1.85943604e-01],
                        [  2.05017090e-01,   2.05017090e-01],
                        [  1.97326660e-01,   1.97326660e-01],
                        [  1.74865723e-01,   1.74865723e-01],
                        [  1.51580811e-01,   1.51580811e-01],
                        [  1.35284424e-01,   1.35284424e-01],
                        [  1.26983643e-01,   1.26983643e-01],
                        [  1.20666504e-01,   1.20666504e-01],
                        [  1.08123779e-01,   1.08123779e-01],
                        [  8.98437500e-02,   8.98437500e-02],
                        [  7.50122070e-02,   7.50122070e-02],
                        [  6.69250488e-02,   6.69250488e-02],
                        [  5.90515137e-02,   5.90515137e-02],
                        [  4.73327637e-02,   4.73327637e-02],
                        [  3.44238281e-02,   3.44238281e-02],
                        [  2.16674805e-02,   2.16674805e-02],
                        [  8.78906250e-03,   8.78906250e-03],
                        [ -9.15527344e-04,  -9.15527344e-04],
                        [ -5.52368164e-03,  -5.52368164e-03],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -2.17285156e-02,  -2.17285156e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -7.01904297e-03,  -7.01904297e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.44348145e-02,  -1.44042969e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.81982422e-02,  -2.81982422e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.41088867e-03,  -2.41088867e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  1.98669434e-02,   1.98364258e-02],
                        [  3.61022949e-02,   3.61022949e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.62841797e-02,   6.62841797e-02],
                        [  8.23974609e-02,   8.23974609e-02],
                        [  9.65270996e-02,   9.65270996e-02],
                        [  1.06048584e-01,   1.06079102e-01],
                        [  1.07208252e-01,   1.07208252e-01],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  3.80554199e-02,   3.80554199e-02],
                        [ -3.63769531e-02,  -3.63769531e-02],
                        [ -1.16058350e-01,  -1.16088867e-01],
                        [ -1.80877686e-01,  -1.80877686e-01],
                        [ -2.14233398e-01,  -2.14202881e-01],
                        [ -2.09747314e-01,  -2.09747314e-01],
                        [ -1.79626465e-01,  -1.79626465e-01],
                        [ -1.45324707e-01,  -1.45324707e-01],
                        [ -1.18896484e-01,  -1.18896484e-01],
                        [ -1.01470947e-01,  -1.01470947e-01],
                        [ -9.39941406e-02,  -9.39941406e-02],
                        [ -9.73205566e-02,  -9.73205566e-02],
                        [ -1.06262207e-01,  -1.06262207e-01],
                        [ -1.13006592e-01,  -1.13006592e-01],
                        [ -1.13769531e-01,  -1.13769531e-01],
                        [ -1.06353760e-01,  -1.06353760e-01],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -3.22570801e-02,  -3.22570801e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -1.16577148e-02,  -1.16577148e-02],
                        [ -2.53295898e-02,  -2.53295898e-02],
                        [ -4.38232422e-02,  -4.38232422e-02],
                        [ -4.58679199e-02,  -4.58679199e-02],
                        [ -1.68457031e-02,  -1.68457031e-02],
                        [  3.47290039e-02,   3.47290039e-02],
                        [  8.42590332e-02,   8.42590332e-02],
                        [  1.14440918e-01,   1.14440918e-01],
                        [  1.25732422e-01,   1.25732422e-01],
                        [  1.26739502e-01,   1.26739502e-01],
                        [  1.23077393e-01,   1.23077393e-01],
                        [  1.18347168e-01,   1.18347168e-01],
                        [  1.19445801e-01,   1.19445801e-01],
                        [  1.33483887e-01,   1.33483887e-01],
                        [  1.60339355e-01,   1.60339355e-01],
                        [  1.91497803e-01,   1.91497803e-01],
                        [  2.16003418e-01,   2.16003418e-01],
                        [  2.25555420e-01,   2.25555420e-01],
                        [  2.14416504e-01,   2.14416504e-01],
                        [  1.77764893e-01,   1.77764893e-01],
                        [  1.10839844e-01,   1.10839844e-01],
                        [  1.27258301e-02,   1.27258301e-02],
                        [ -1.06628418e-01,  -1.06628418e-01],
                        [ -2.23602295e-01,  -2.23602295e-01],
                        [ -3.07006836e-01,  -3.07006836e-01],
                        [ -3.31695557e-01,  -3.31695557e-01],
                        [ -2.94189453e-01,  -2.94189453e-01],
                        [ -2.20245361e-01,  -2.20245361e-01],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -1.18774414e-01,  -1.18774414e-01],
                        [ -1.18377686e-01,  -1.18377686e-01],
                        [ -1.27990723e-01,  -1.27990723e-01],
                        [ -1.29180908e-01,  -1.29180908e-01],
                        [ -1.18743896e-01,  -1.18743896e-01],
                        [ -1.01013184e-01,  -1.00982666e-01],
                        [ -7.98645020e-02,  -7.98645020e-02],
                        [ -6.02111816e-02,  -6.02111816e-02],
                        [ -4.88891602e-02,  -4.88891602e-02],
                        [ -4.71496582e-02,  -4.71496582e-02],
                        [ -4.59289551e-02,  -4.59289551e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.26538086e-03,  -3.26538086e-03],
                        [  4.51660156e-02,   4.51660156e-02],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.79565430e-01,   1.79565430e-01],
                        [  2.29980469e-01,   2.29980469e-01],
                        [  2.43041992e-01,   2.43041992e-01],
                        [  2.21313477e-01,   2.21313477e-01],
                        [  1.83807373e-01,   1.83837891e-01],
                        [  1.49291992e-01,   1.49291992e-01],
                        [  1.26037598e-01,   1.26037598e-01],
                        [  1.13098145e-01,   1.13098145e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.49401855e-02,   9.49401855e-02],
                        [  8.55407715e-02,   8.55407715e-02],
                        [  8.00170898e-02,   8.00170898e-02],
                        [  7.65991211e-02,   7.65991211e-02],
                        [  6.95190430e-02,   6.95190430e-02],
                        [  5.77392578e-02,   5.77697754e-02],
                        [  4.36706543e-02,   4.36706543e-02],
                        [  2.70690918e-02,   2.70690918e-02],
                        [  9.73510742e-03,   9.76562500e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.00402832e-02,  -1.00402832e-02],
                        [ -1.42211914e-02,  -1.42211914e-02],
                        [ -2.56652832e-02,  -2.56652832e-02],
                        [ -3.95812988e-02,  -3.95812988e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -4.04968262e-02,  -4.04968262e-02],
                        [ -3.20129395e-02,  -3.20129395e-02],
                        [ -2.63366699e-02,  -2.63366699e-02],
                        [ -2.25830078e-02,  -2.25830078e-02],
                        [ -1.57165527e-02,  -1.57165527e-02],
                        [ -4.11987305e-03,  -4.11987305e-03],
                        [  7.59887695e-03,   7.59887695e-03],
                        [  1.40075684e-02,   1.40075684e-02],
                        [  1.41296387e-02,   1.41296387e-02],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [  3.93371582e-02,   3.93371582e-02],
                        [  6.02111816e-02,   6.02111816e-02],
                        [  8.02917480e-02,   8.02917480e-02],
                        [  9.73815918e-02,   9.73815918e-02],
                        [  1.07177734e-01,   1.07177734e-01],
                        [  9.95483398e-02,   9.95483398e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -7.91015625e-02,  -7.91015625e-02],
                        [ -1.52008057e-01,  -1.52008057e-01],
                        [ -2.00103760e-01,  -2.00103760e-01],
                        [ -2.09411621e-01,  -2.09411621e-01],
                        [ -1.83410645e-01,  -1.83410645e-01],
                        [ -1.47033691e-01,  -1.47033691e-01],
                        [ -1.26007080e-01,  -1.26007080e-01],
                        [ -1.23016357e-01,  -1.23016357e-01],
                        [ -1.22955322e-01,  -1.22955322e-01],
                        [ -1.16912842e-01,  -1.16912842e-01],
                        [ -1.10656738e-01,  -1.10656738e-01],
                        [ -1.11053467e-01,  -1.11053467e-01],
                        [ -1.13159180e-01,  -1.13159180e-01],
                        [ -1.05194092e-01,  -1.05194092e-01],
                        [ -8.46862793e-02,  -8.46862793e-02],
                        [ -6.25305176e-02,  -6.25305176e-02],
                        [ -4.94079590e-02,  -4.94079590e-02],
                        [ -4.50439453e-02,  -4.50439453e-02],
                        [ -4.40673828e-02,  -4.40673828e-02],
                        [ -4.31823730e-02,  -4.31823730e-02],
                        [ -3.74755859e-02,  -3.74755859e-02],
                        [ -1.76086426e-02,  -1.76086426e-02],
                        [  2.16979980e-02,   2.16979980e-02],
                        [  7.18688965e-02,   7.18688965e-02],
                        [  1.12701416e-01,   1.12701416e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.16729736e-01,   1.16729736e-01],
                        [  9.92736816e-02,   9.92736816e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  1.04553223e-01,   1.04553223e-01],
                        [  1.25518799e-01,   1.25518799e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.64031982e-01,   1.64031982e-01],
                        [  1.83624268e-01,   1.83624268e-01],
                        [  2.08953857e-01,   2.08953857e-01],
                        [  2.27844238e-01,   2.27844238e-01],
                        [  2.19604492e-01,   2.19604492e-01],
                        [  1.76788330e-01,   1.76788330e-01],
                        [  1.08428955e-01,   1.08428955e-01],
                        [  2.13317871e-02,   2.13317871e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -1.98486328e-01,  -1.98486328e-01],
                        [ -2.89367676e-01,  -2.89367676e-01],
                        [ -3.22967529e-01,  -3.22967529e-01],
                        [ -2.90130615e-01,  -2.90130615e-01],
                        [ -2.19757080e-01,  -2.19757080e-01],
                        [ -1.58966064e-01,  -1.58966064e-01],
                        [ -1.32843018e-01,  -1.32843018e-01],
                        [ -1.29608154e-01,  -1.29577637e-01],
                        [ -1.27410889e-01,  -1.27410889e-01],
                        [ -1.21124268e-01,  -1.21124268e-01],
                        [ -1.15051270e-01,  -1.15051270e-01],
                        [ -1.08337402e-01,  -1.08337402e-01],
                        [ -9.86633301e-02,  -9.86633301e-02],
                        [ -8.86230469e-02,  -8.86230469e-02],
                        [ -8.02307129e-02,  -8.02307129e-02],
                        [ -6.91528320e-02,  -6.91528320e-02],
                        [ -4.73022461e-02,  -4.73022461e-02],
                        [ -1.10473633e-02,  -1.10168457e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  8.31298828e-02,   8.31298828e-02],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.95404053e-01,   1.95404053e-01],
                        [  2.36602783e-01,   2.36602783e-01],
                        [  2.36328125e-01,   2.36328125e-01],
                        [  1.98730469e-01,   1.98730469e-01],
                        [  1.55761719e-01,   1.55761719e-01],
                        [  1.33117676e-01,   1.33117676e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.26342773e-01,   1.26342773e-01],
                        [  1.15264893e-01,   1.15264893e-01],
                        [  9.89990234e-02,   9.89990234e-02],
                        [  8.44726562e-02,   8.44726562e-02],
                        [  7.54089355e-02,   7.54089355e-02],
                        [  7.22045898e-02,   7.22045898e-02],
                        [  7.04650879e-02,   7.04650879e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  4.72717285e-02,   4.72717285e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  1.46484375e-03,   1.46484375e-03],
                        [ -1.15051270e-02,  -1.15051270e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -7.08007812e-03,  -7.08007812e-03],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.22680664e-02,  -1.22680664e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -3.66210938e-02,  -3.66516113e-02],
                        [ -4.31213379e-02,  -4.31213379e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -4.76684570e-02,  -4.76684570e-02],
                        [ -4.08935547e-02,  -4.08935547e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [  1.22070312e-04,   1.22070312e-04],
                        [  1.14440918e-02,   1.14746094e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  1.81884766e-02,   1.81884766e-02],
                        [  2.31933594e-02,   2.31933594e-02],
                        [  3.16772461e-02,   3.16772461e-02],
                        [  4.29077148e-02,   4.29077148e-02],
                        [  5.63354492e-02,   5.63354492e-02],
                        [  6.85729980e-02,   6.85729980e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  4.23583984e-02,   4.23583984e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -1.06170654e-01,  -1.06170654e-01],
                        [ -1.73461914e-01,  -1.73461914e-01],
                        [ -2.09564209e-01,  -2.09564209e-01],
                        [ -2.05902100e-01,  -2.05902100e-01],
                        [ -1.77551270e-01,  -1.77551270e-01],
                        [ -1.50024414e-01,  -1.50024414e-01],
                        [ -1.33880615e-01,  -1.33880615e-01],
                        [ -1.22619629e-01,  -1.22619629e-01],
                        [ -1.11175537e-01,  -1.11175537e-01],
                        [ -1.03820801e-01,  -1.03820801e-01],
                        [ -1.04309082e-01,  -1.04309082e-01],
                        [ -1.07360840e-01,  -1.07360840e-01],
                        [ -1.03607178e-01,  -1.03607178e-01],
                        [ -9.09118652e-02,  -9.09118652e-02],
                        [ -7.75146484e-02,  -7.75146484e-02],
                        [ -7.21740723e-02,  -7.21740723e-02],
                        [ -7.42492676e-02,  -7.42492676e-02],
                        [ -7.54699707e-02,  -7.54699707e-02],
                        [ -6.79321289e-02,  -6.79321289e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -9.79614258e-03,  -9.79614258e-03],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  8.58764648e-02,   8.58764648e-02],
                        [  1.18682861e-01,   1.18682861e-01],
                        [  1.29608154e-01,   1.29608154e-01],
                        [  1.23046875e-01,   1.23046875e-01],
                        [  1.09649658e-01,   1.09649658e-01],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.02966309e-01,   1.02966309e-01],
                        [  1.20880127e-01,   1.20880127e-01],
                        [  1.42730713e-01,   1.42730713e-01],
                        [  1.57836914e-01,   1.57836914e-01],
                        [  1.72332764e-01,   1.72332764e-01],
                        [  1.95526123e-01,   1.95526123e-01],
                        [  2.15515137e-01,   2.15515137e-01],
                        [  2.09564209e-01,   2.09564209e-01],
                        [  1.70806885e-01,   1.70806885e-01],
                        [  1.04980469e-01,   1.04980469e-01],
                        [  1.29699707e-02,   1.29699707e-02],
                        [ -1.02325439e-01,  -1.02325439e-01],
                        [ -2.18505859e-01,  -2.18505859e-01],
                        [ -2.98553467e-01,  -2.98553467e-01],
                        [ -3.15490723e-01,  -3.15490723e-01],
                        [ -2.72125244e-01,  -2.72125244e-01],
                        [ -2.02392578e-01,  -2.02392578e-01],
                        [ -1.49200439e-01,  -1.49200439e-01],
                        [ -1.31591797e-01,  -1.31591797e-01],
                        [ -1.34857178e-01,  -1.34857178e-01],
                        [ -1.35192871e-01,  -1.35192871e-01],
                        [ -1.26464844e-01,  -1.26464844e-01],
                        [ -1.16882324e-01,  -1.16882324e-01],
                        [ -1.10687256e-01,  -1.10687256e-01],
                        [ -1.04888916e-01,  -1.04888916e-01],
                        [ -9.65270996e-02,  -9.65270996e-02],
                        [ -8.26721191e-02,  -8.26721191e-02],
                        [ -5.89294434e-02,  -5.89294434e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [  5.97839355e-02,   5.97839355e-02],
                        [  1.12762451e-01,   1.12762451e-01],
                        [  1.68914795e-01,   1.68914795e-01],
                        [  2.11730957e-01,   2.11730957e-01],
                        [  2.26531982e-01,   2.26531982e-01],
                        [  2.13806152e-01,   2.13806152e-01],
                        [  1.85974121e-01,   1.85974121e-01],
                        [  1.55548096e-01,   1.55548096e-01],
                        [  1.29943848e-01,   1.29943848e-01],
                        [  1.13189697e-01,   1.13189697e-01],
                        [  1.04339600e-01,   1.04339600e-01],
                        [  9.66491699e-02,   9.66491699e-02],
                        [  8.53271484e-02,   8.53271484e-02],
                        [  7.32421875e-02,   7.32421875e-02],
                        [  6.43005371e-02,   6.43005371e-02],
                        [  5.72509766e-02,   5.72509766e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  3.98254395e-02,   3.98254395e-02],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  1.12304688e-02,   1.12304688e-02],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  3.66210938e-03,   3.66210938e-03],
                        [  5.52368164e-03,   5.52368164e-03],
                        [  1.95312500e-03,   1.95312500e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [  2.34985352e-03,   2.34985352e-03],
                        [  3.66210938e-04,   3.66210938e-04],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -3.33557129e-02,  -3.33557129e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -4.07714844e-02,  -4.07714844e-02],
                        [ -3.53088379e-02,  -3.53088379e-02],
                        [ -2.93579102e-02,  -2.93579102e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -1.89208984e-02,  -1.89208984e-02],
                        [ -1.24816895e-02,  -1.24816895e-02],
                        [ -1.28173828e-03,  -1.28173828e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.94091797e-02,   1.94091797e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.60217285e-02,   1.60217285e-02],
                        [  1.46484375e-02,   1.46484375e-02],
                        [  1.81274414e-02,   1.81274414e-02],
                        [  2.81677246e-02,   2.81677246e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  6.65893555e-02,   6.65893555e-02],
                        [  8.69445801e-02,   8.69445801e-02],
                        [  1.00006104e-01,   1.00006104e-01],
                        [  9.99755859e-02,   9.99755859e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  3.49731445e-02,   3.49731445e-02],
                        [ -3.98254395e-02,  -3.98254395e-02],
                        [ -1.28753662e-01,  -1.28753662e-01],
                        [ -1.99645996e-01,  -1.99645996e-01],
                        [ -2.24365234e-01,  -2.24365234e-01],
                        [ -2.01660156e-01,  -2.01660156e-01],
                        [ -1.56097412e-01,  -1.56097412e-01],
                        [ -1.17767334e-01,  -1.17767334e-01],
                        [ -1.02569580e-01,  -1.02569580e-01],
                        [ -1.05590820e-01,  -1.05590820e-01],
                        [ -1.09527588e-01,  -1.09527588e-01],
                        [ -1.03393555e-01,  -1.03393555e-01],
                        [ -9.19494629e-02,  -9.19494629e-02],
                        [ -8.47473145e-02,  -8.47473145e-02],
                        [ -8.22753906e-02,  -8.22753906e-02],
                        [ -8.05053711e-02,  -8.05053711e-02],
                        [ -8.09326172e-02,  -8.09326172e-02],
                        [ -8.41979980e-02,  -8.41979980e-02],
                        [ -8.21533203e-02,  -8.21533203e-02],
                        [ -6.82983398e-02,  -6.82983398e-02],
                        [ -4.68139648e-02,  -4.68139648e-02],
                        [ -2.05383301e-02,  -2.05383301e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  5.99060059e-02,   5.99060059e-02],
                        [  9.64965820e-02,   9.64965820e-02],
                        [  1.13372803e-01,   1.13372803e-01],
                        [  1.11572266e-01,   1.11572266e-01],
                        [  9.93041992e-02,   9.93041992e-02],
                        [  8.94775391e-02,   8.94775391e-02],
                        [  9.58557129e-02,   9.58557129e-02],
                        [  1.19140625e-01,   1.19140625e-01],
                        [  1.45141602e-01,   1.45141602e-01],
                        [  1.63604736e-01,   1.63604736e-01],
                        [  1.77612305e-01,   1.77612305e-01],
                        [  1.92016602e-01,   1.92016602e-01],
                        [  2.03308105e-01,   2.03308105e-01],
                        [  2.02026367e-01,   2.02026367e-01],
                        [  1.76940918e-01,   1.76940918e-01],
                        [  1.19049072e-01,   1.19049072e-01],
                        [  2.86865234e-02,   2.86865234e-02],
                        [ -8.07800293e-02,  -8.07800293e-02],
                        [ -1.88232422e-01,  -1.88232422e-01],
                        [ -2.71057129e-01,  -2.71057129e-01],
                        [ -3.07525635e-01,  -3.07525635e-01],
                        [ -2.86041260e-01,  -2.86041260e-01],
                        [ -2.22015381e-01,  -2.22015381e-01],
                        [ -1.55487061e-01,  -1.55487061e-01],
                        [ -1.18621826e-01,  -1.18621826e-01],
                        [ -1.09771729e-01,  -1.09771729e-01],
                        [ -1.08978271e-01,  -1.08978271e-01],
                        [ -1.06750488e-01,  -1.06750488e-01],
                        [ -1.06781006e-01,  -1.06781006e-01],
                        [ -1.11541748e-01,  -1.11541748e-01],
                        [ -1.17004395e-01,  -1.17004395e-01],
                        [ -1.16088867e-01,  -1.16088867e-01],
                        [ -1.01074219e-01,  -1.01074219e-01],
                        [ -6.93054199e-02,  -6.93054199e-02],
                        [ -2.76184082e-02,  -2.76184082e-02],
                        [  1.77307129e-02,   1.77307129e-02],
                        [  7.13500977e-02,   7.13500977e-02],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  2.00469971e-01,   2.00469971e-01],
                        [  2.32818604e-01,   2.32818604e-01],
                        [  2.22625732e-01,   2.22625732e-01],
                        [  1.84234619e-01,   1.84234619e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.08795166e-01,   1.08795166e-01],
                        [  9.46350098e-02,   9.46350098e-02],
                        [  9.71069336e-02,   9.71069336e-02],
                        [  1.05621338e-01,   1.05621338e-01],
                        [  1.09130859e-01,   1.09130859e-01],
                        [  1.06964111e-01,   1.06964111e-01],
                        [  1.04095459e-01,   1.04095459e-01],
                        [  9.82666016e-02,   9.82666016e-02],
                        [  8.24584961e-02,   8.24584961e-02],
                        [  5.79528809e-02,   5.79528809e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  1.99279785e-02,   1.99279785e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  9.12475586e-03,   9.12475586e-03],
                        [  7.17163086e-03,   7.17163086e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [ -6.37817383e-03,  -6.37817383e-03],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [ -1.50756836e-02,  -1.50756836e-02],
                        [ -1.10168457e-02,  -1.10168457e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -1.13525391e-02,  -1.13525391e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.71911621e-02,  -2.71911621e-02],
                        [ -3.60107422e-02,  -3.60107422e-02],
                        [ -4.16259766e-02,  -4.16259766e-02],
                        [ -3.97338867e-02,  -3.97338867e-02],
                        [ -2.89306641e-02,  -2.89306641e-02],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  2.96020508e-03,   2.96020508e-03],
                        [  5.37109375e-03,   5.37109375e-03],
                        [  1.17797852e-02,   1.17797852e-02],
                        [  2.03247070e-02,   2.03247070e-02],
                        [  2.49633789e-02,   2.49633789e-02],
                        [  2.61840820e-02,   2.61840820e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  6.86340332e-02,   6.86340332e-02],
                        [  9.10034180e-02,   9.10034180e-02],
                        [  1.03851318e-01,   1.03851318e-01],
                        [  9.74731445e-02,   9.74731445e-02],
                        [  6.46972656e-02,   6.46972656e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [ -7.93457031e-02,  -7.93457031e-02],
                        [ -1.61926270e-01,  -1.61926270e-01],
                        [ -2.12127686e-01,  -2.12127686e-01],
                        [ -2.10754395e-01,  -2.10754395e-01],
                        [ -1.69891357e-01,  -1.69891357e-01],
                        [ -1.21643066e-01,  -1.21643066e-01],
                        [ -9.17053223e-02,  -9.17053223e-02],
                        [ -8.70971680e-02,  -8.70971680e-02],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -1.07818604e-01,  -1.07818604e-01],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -9.28649902e-02,  -9.28649902e-02],
                        [ -8.95690918e-02,  -8.95690918e-02],
                        [ -9.28344727e-02,  -9.28344727e-02],
                        [ -8.90808105e-02,  -8.90808105e-02],
                        [ -7.55920410e-02,  -7.55920410e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -6.08520508e-02,  -6.08520508e-02],
                        [ -5.62438965e-02,  -5.62438965e-02],
                        [ -4.08630371e-02,  -4.08630371e-02],
                        [ -1.46179199e-02,  -1.46179199e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  5.74035645e-02,   5.74035645e-02],
                        [  9.03625488e-02,   9.03625488e-02],
                        [  1.06933594e-01,   1.06933594e-01],
                        [  1.05377197e-01,   1.05377197e-01],
                        [  9.78698730e-02,   9.78698730e-02],
                        [  1.00921631e-01,   1.00921631e-01],
                        [  1.19628906e-01,   1.19628906e-01],
                        [  1.43341064e-01,   1.43371582e-01],
                        [  1.60247803e-01,   1.60247803e-01],
                        [  1.70410156e-01,   1.70410156e-01],
                        [  1.80236816e-01,   1.80236816e-01],
                        [  1.90826416e-01,   1.90826416e-01],
                        [  1.97265625e-01,   1.97265625e-01],
                        [  1.90063477e-01,   1.90063477e-01],
                        [  1.53228760e-01,   1.53228760e-01],
                        [  7.37609863e-02,   7.37609863e-02],
                        [ -4.24804688e-02,  -4.25109863e-02],
                        [ -1.69525146e-01,  -1.69525146e-01],
                        [ -2.73468018e-01,  -2.73468018e-01],
                        [ -3.23974609e-01,  -3.23974609e-01],
                        [ -3.07098389e-01,  -3.07098389e-01],
                        [ -2.40173340e-01,  -2.40173340e-01],
                        [ -1.67114258e-01,  -1.67114258e-01],
                        [ -1.25610352e-01,  -1.25610352e-01],
                        [ -1.18347168e-01,  -1.18347168e-01],
                        [ -1.21643066e-01,  -1.21643066e-01],
                        [ -1.18835449e-01,  -1.18835449e-01],
                        [ -1.14074707e-01,  -1.14074707e-01],
                        [ -1.15356445e-01,  -1.15356445e-01],
                        [ -1.18652344e-01,  -1.18652344e-01],
                        [ -1.15173340e-01,  -1.15173340e-01],
                        [ -1.01684570e-01,  -1.01684570e-01],
                        [ -7.59582520e-02,  -7.59582520e-02],
                        [ -3.37524414e-02,  -3.37524414e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  1.37664795e-01,   1.37664795e-01],
                        [  1.84600830e-01,   1.84600830e-01],
                        [  2.14538574e-01,   2.14538574e-01],
                        [  2.15850830e-01,   2.15850830e-01],
                        [  1.89208984e-01,   1.89208984e-01],
                        [  1.52069092e-01,   1.52069092e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.16973877e-01,   1.16973877e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.22528076e-01,   1.22528076e-01],
                        [  1.19659424e-01,   1.19659424e-01],
                        [  1.13616943e-01,   1.13616943e-01],
                        [  1.06658936e-01,   1.06658936e-01],
                        [  9.91210938e-02,   9.91210938e-02],
                        [  8.85009766e-02,   8.85009766e-02],
                        [  6.86950684e-02,   6.86950684e-02],
                        [  3.86657715e-02,   3.86657715e-02],
                        [  1.10473633e-02,   1.10473633e-02],
                        [  6.10351562e-05,   6.10351562e-05],
                        [  2.92968750e-03,   2.92968750e-03],
                        [  7.04956055e-03,   7.04956055e-03],
                        [  9.27734375e-03,   9.27734375e-03],
                        [  1.36108398e-02,   1.36108398e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  5.85937500e-03,   5.85937500e-03],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -3.28979492e-02,  -3.28979492e-02],
                        [ -4.30908203e-02,  -4.30908203e-02],
                        [ -4.95300293e-02,  -4.95300293e-02],
                        [ -5.64575195e-02,  -5.64575195e-02],
                        [ -5.84106445e-02,  -5.84106445e-02],
                        [ -4.87060547e-02,  -4.87060547e-02],
                        [ -3.00598145e-02,  -3.00598145e-02],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  1.30920410e-02,   1.30920410e-02],
                        [  1.06506348e-02,   1.06506348e-02],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  1.23291016e-02,   1.23291016e-02],
                        [  9.91821289e-03,   9.91821289e-03],
                        [  4.24194336e-03,   4.24194336e-03],
                        [  7.44628906e-03,   7.44628906e-03],
                        [  2.63671875e-02,   2.63671875e-02],
                        [  5.29479980e-02,   5.29479980e-02],
                        [  7.53479004e-02,   7.53479004e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.00280762e-01,   1.00280762e-01],
                        [  1.07543945e-01,   1.07543945e-01],
                        [  1.02569580e-01,   1.02569580e-01],
                        [  6.85424805e-02,   6.85424805e-02],
                        [ -2.59399414e-03,  -2.59399414e-03],
                        [ -9.65576172e-02,  -9.65576172e-02],
                        [ -1.82952881e-01,  -1.82952881e-01],
                        [ -2.32177734e-01,  -2.32177734e-01],
                        [ -2.30285645e-01,  -2.30285645e-01],
                        [ -1.89117432e-01,  -1.89117432e-01],
                        [ -1.41540527e-01,  -1.41540527e-01],
                        [ -1.14166260e-01,  -1.14166260e-01],
                        [ -1.05804443e-01,  -1.05804443e-01],
                        [ -9.93347168e-02,  -9.93347168e-02],
                        [ -8.85009766e-02,  -8.85009766e-02],
                        [ -8.29772949e-02,  -8.29772949e-02],
                        [ -9.08813477e-02,  -9.08813477e-02],
                        [ -1.06079102e-01,  -1.06079102e-01],
                        [ -1.14440918e-01,  -1.14440918e-01],
                        [ -1.09558105e-01,  -1.09588623e-01],
                        [ -9.77172852e-02,  -9.77172852e-02],
                        [ -8.55407715e-02,  -8.55407715e-02],
                        [ -6.90002441e-02,  -6.90002441e-02],
                        [ -4.01916504e-02,  -4.01916504e-02],
                        [  7.01904297e-04,   7.01904297e-04],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  8.99353027e-02,   8.99353027e-02],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.26464844e-01,   1.26464844e-01],
                        [  1.11236572e-01,   1.11236572e-01],
                        [  9.13085938e-02,   9.13085938e-02],
                        [  8.44421387e-02,   8.44421387e-02],
                        [  9.55505371e-02,   9.55505371e-02],
                        [  1.16485596e-01,   1.16485596e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.49414062e-01,   1.49414062e-01],
                        [  1.67144775e-01,   1.67144775e-01],
                        [  1.95312500e-01,   1.95312500e-01],
                        [  2.23663330e-01,   2.23663330e-01],
                        [  2.30987549e-01,   2.30987549e-01],
                        [  2.01110840e-01,   2.01080322e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  1.81274414e-02,   1.81274414e-02],
                        [ -1.16027832e-01,  -1.16027832e-01],
                        [ -2.46826172e-01,  -2.46856689e-01],
                        [ -3.38043213e-01,  -3.38043213e-01],
                        [ -3.58673096e-01,  -3.58673096e-01],
                        [ -3.07617188e-01,  -3.07617188e-01],
                        [ -2.22656250e-01,  -2.22656250e-01],
                        [ -1.52770996e-01,  -1.52740479e-01],
                        [ -1.19537354e-01,  -1.19537354e-01],
                        [ -1.10931396e-01,  -1.10931396e-01],
                        [ -1.07299805e-01,  -1.07299805e-01],
                        [ -1.03057861e-01,  -1.03057861e-01],
                        [ -1.03363037e-01,  -1.03363037e-01],
                        [ -1.10870361e-01,  -1.10870361e-01],
                        [ -1.20666504e-01,  -1.20666504e-01],
                        [ -1.22802734e-01,  -1.22802734e-01],
                        [ -1.06018066e-01,  -1.06018066e-01],
                        [ -6.29882812e-02,  -6.29882812e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  7.63854980e-02,   7.63854980e-02],
                        [  1.45751953e-01,   1.45751953e-01],
                        [  2.02239990e-01,   2.02239990e-01],
                        [  2.37182617e-01,   2.37182617e-01],
                        [  2.42279053e-01,   2.42279053e-01],
                        [  2.20153809e-01,   2.20153809e-01],
                        [  1.85302734e-01,   1.85302734e-01],
                        [  1.51794434e-01,   1.51794434e-01],
                        [  1.25213623e-01,   1.25213623e-01],
                        [  1.06719971e-01,   1.06719971e-01],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  8.97521973e-02,   8.97521973e-02],
                        [  8.60595703e-02,   8.60290527e-02],
                        [  8.43505859e-02,   8.43505859e-02],
                        [  8.01391602e-02,   8.01391602e-02],
                        [  6.61315918e-02,   6.61315918e-02],
                        [  4.44946289e-02,   4.44946289e-02],
                        [  2.74047852e-02,   2.74047852e-02],
                        [  2.14538574e-02,   2.14538574e-02],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  1.30615234e-02,   1.30615234e-02],
                        [ -1.61743164e-03,  -1.61743164e-03],
                        [ -1.63879395e-02,  -1.63879395e-02],
                        [ -2.37426758e-02,  -2.37426758e-02],
                        [ -2.42309570e-02,  -2.42309570e-02],
                        [ -2.55126953e-02,  -2.55126953e-02],
                        [ -3.18298340e-02,  -3.18603516e-02],
                        [ -3.91235352e-02,  -3.91235352e-02],
                        [ -4.13208008e-02,  -4.13208008e-02],
                        [ -3.68652344e-02,  -3.68957520e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -1.20849609e-02,  -1.20849609e-02],
                        [  2.41088867e-03,   2.41088867e-03],
                        [  1.11999512e-02,   1.11999512e-02],
                        [  1.24206543e-02,   1.24206543e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -8.27026367e-03,  -8.27026367e-03],
                        [ -6.77490234e-03,  -6.80541992e-03],
                        [  4.21142578e-03,   4.21142578e-03],
                        [  1.65405273e-02,   1.65405273e-02],
                        [  2.54211426e-02,   2.54211426e-02],
                        [  3.59497070e-02,   3.59497070e-02],
                        [  5.36193848e-02,   5.36193848e-02],
                        [  7.57446289e-02,   7.57446289e-02],
                        [  9.57641602e-02,   9.57641602e-02],
                        [  1.09375000e-01,   1.09375000e-01],
                        [  1.10809326e-01,   1.10809326e-01],
                        [  8.93859863e-02,   8.93859863e-02],
                        [  3.77197266e-02,   3.77197266e-02],
                        [ -3.81774902e-02,  -3.81774902e-02],
                        [ -1.20452881e-01,  -1.20452881e-01],
                        [ -1.87774658e-01,  -1.87774658e-01],
                        [ -2.20764160e-01,  -2.20733643e-01],
                        [ -2.11456299e-01,  -2.11456299e-01],
                        [ -1.75079346e-01,  -1.75079346e-01],
                        [ -1.40625000e-01,  -1.40655518e-01],
                        [ -1.22680664e-01,  -1.22680664e-01],
                        [ -1.13525391e-01,  -1.13525391e-01],
                        [ -1.05072021e-01,  -1.05072021e-01],
                        [ -1.00616455e-01,  -1.00616455e-01],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -1.05834961e-01,  -1.05865479e-01],
                        [ -1.04431152e-01,  -1.04431152e-01],
                        [ -9.93041992e-02,  -9.92736816e-02],
                        [ -9.38720703e-02,  -9.38720703e-02],
                        [ -8.90197754e-02,  -8.90197754e-02],
                        [ -7.97729492e-02,  -7.97424316e-02],
                        [ -5.66406250e-02,  -5.66406250e-02],
                        [ -1.37023926e-02,  -1.37329102e-02],
                        [  4.27246094e-02,   4.27246094e-02],
                        [  9.47265625e-02,   9.47265625e-02],
                        [  1.24664307e-01,   1.24664307e-01],
                        [  1.28265381e-01,   1.28265381e-01],
                        [  1.15844727e-01,   1.15844727e-01],
                        [  1.01776123e-01,   1.01776123e-01],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  9.42993164e-02,   9.42993164e-02],
                        [  9.99145508e-02,   9.99145508e-02],
                        [  1.12365723e-01,   1.12365723e-01],
                        [  1.37237549e-01,   1.37237549e-01],
                        [  1.75598145e-01,   1.75598145e-01],
                        [  2.14538574e-01,   2.14538574e-01],
                        [  2.33032227e-01,   2.33032227e-01],
                        [  2.17590332e-01,   2.17590332e-01],
                        [  1.66259766e-01,   1.66259766e-01],
                        [  8.26721191e-02,   8.26721191e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -1.40411377e-01,  -1.40411377e-01],
                        [ -2.40875244e-01,  -2.40875244e-01],
                        [ -2.98431396e-01,  -2.98431396e-01],
                        [ -2.92999268e-01,  -2.92999268e-01],
                        [ -2.35870361e-01,  -2.35870361e-01],
                        [ -1.72485352e-01,  -1.72485352e-01],
                        [ -1.42547607e-01,  -1.42547607e-01],
                        [ -1.43066406e-01,  -1.43066406e-01],
                        [ -1.46179199e-01,  -1.46179199e-01],
                        [ -1.38519287e-01,  -1.38519287e-01],
                        [ -1.27838135e-01,  -1.27838135e-01],
                        [ -1.24481201e-01,  -1.24481201e-01],
                        [ -1.29364014e-01,  -1.29364014e-01],
                        [ -1.31958008e-01,  -1.31927490e-01],
                        [ -1.15783691e-01,  -1.15783691e-01],
                        [ -7.26928711e-02,  -7.26928711e-02],
                        [ -9.00268555e-03,  -9.00268555e-03],
                        [  6.39648438e-02,   6.39648438e-02],
                        [  1.36322021e-01,   1.36322021e-01],
                        [  1.95343018e-01,   1.95343018e-01],
                        [  2.27691650e-01,   2.27691650e-01],
                        [  2.29614258e-01,   2.29614258e-01],
                        [  2.09594727e-01,   2.09594727e-01],
                        [  1.81945801e-01,   1.81945801e-01],
                        [  1.57684326e-01,   1.57684326e-01],
                        [  1.37847900e-01,   1.37847900e-01],
                        [  1.17950439e-01,   1.17950439e-01],
                        [  9.98840332e-02,   9.99145508e-02],
                        [  9.06677246e-02,   9.06982422e-02],
                        [  9.02099609e-02,   9.01794434e-02],
                        [  9.17358398e-02,   9.17358398e-02],
                        [  9.08508301e-02,   9.08508301e-02],
                        [  8.43200684e-02,   8.43200684e-02],
                        [  6.83288574e-02,   6.83288574e-02],
                        [  4.63867188e-02,   4.64172363e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  1.93481445e-02,   1.93481445e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  9.33837891e-03,   9.33837891e-03],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  1.27868652e-02,   1.27868652e-02],
                        [  1.22680664e-02,   1.22680664e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  7.53784180e-03,   7.53784180e-03],
                        [  6.25610352e-03,   6.25610352e-03],
                        [  2.80761719e-03,   2.80761719e-03],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [ -2.44445801e-02,  -2.44445801e-02],
                        [ -4.39147949e-02,  -4.39147949e-02],
                        [ -5.34667969e-02,  -5.34667969e-02],
                        [ -4.76074219e-02,  -4.76379395e-02],
                        [ -3.50952148e-02,  -3.50952148e-02],
                        [ -2.88391113e-02,  -2.88391113e-02],
                        [ -2.86560059e-02,  -2.86560059e-02],
                        [ -2.30102539e-02,  -2.30102539e-02],
                        [ -1.01318359e-02,  -1.01318359e-02],
                        [ -2.65502930e-03,  -2.65502930e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -7.65991211e-03,  -7.65991211e-03],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  7.96508789e-03,   7.96508789e-03],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  3.60717773e-02,   3.60717773e-02],
                        [  5.12084961e-02,   5.12084961e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  6.93664551e-02,   6.93664551e-02],
                        [  8.64257812e-02,   8.64257812e-02],
                        [  1.00341797e-01,   1.00341797e-01],
                        [  9.86022949e-02,   9.86022949e-02],
                        [  8.06579590e-02,   8.06884766e-02],
                        [  4.69360352e-02,   4.69360352e-02],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -8.56933594e-02,  -8.56628418e-02],
                        [ -1.61926270e-01,  -1.61926270e-01],
                        [ -2.09381104e-01,  -2.09381104e-01],
                        [ -2.14263916e-01,  -2.14263916e-01],
                        [ -1.87042236e-01,  -1.87042236e-01],
                        [ -1.51947021e-01,  -1.51947021e-01],
                        [ -1.26800537e-01,  -1.26800537e-01],
                        [ -1.13861084e-01,  -1.13861084e-01],
                        [ -1.06475830e-01,  -1.06475830e-01],
                        [ -9.84191895e-02,  -9.84191895e-02],
                        [ -8.91418457e-02,  -8.91418457e-02],
                        [ -8.54492188e-02,  -8.54492188e-02],
                        [ -9.37500000e-02,  -9.37500000e-02],
                        [ -1.07910156e-01,  -1.07910156e-01],
                        [ -1.12518311e-01,  -1.12518311e-01],
                        [ -1.00769043e-01,  -1.00769043e-01],
                        [ -7.85217285e-02,  -7.85217285e-02],
                        [ -4.89807129e-02,  -4.89807129e-02],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [  4.16259766e-02,   4.16259766e-02],
                        [  8.92639160e-02,   8.92639160e-02],
                        [  1.21765137e-01,   1.21765137e-01],
                        [  1.32537842e-01,   1.32537842e-01],
                        [  1.24053955e-01,   1.24053955e-01],
                        [  1.07208252e-01,   1.07238770e-01],
                        [  9.51843262e-02,   9.51843262e-02],
                        [  9.56420898e-02,   9.56420898e-02],
                        [  1.10626221e-01,   1.10626221e-01],
                        [  1.38671875e-01,   1.38671875e-01],
                        [  1.73278809e-01,   1.73278809e-01],
                        [  2.02789307e-01,   2.02789307e-01],
                        [  2.16705322e-01,   2.16705322e-01],
                        [  2.08557129e-01,   2.08557129e-01],
                        [  1.71630859e-01,   1.71630859e-01],
                        [  9.97619629e-02,   9.97619629e-02],
                        [ -3.60107422e-03,  -3.60107422e-03],
                        [ -1.20544434e-01,  -1.20544434e-01],
                        [ -2.23937988e-01,  -2.23937988e-01],
                        [ -2.86346436e-01,  -2.86346436e-01],
                        [ -2.91992188e-01,  -2.91992188e-01],
                        [ -2.49877930e-01,  -2.49877930e-01],
                        [ -1.93237305e-01,  -1.93237305e-01],
                        [ -1.55151367e-01,  -1.55151367e-01],
                        [ -1.43035889e-01,  -1.43035889e-01],
                        [ -1.42700195e-01,  -1.42700195e-01],
                        [ -1.42639160e-01,  -1.42639160e-01],
                        [ -1.44348145e-01,  -1.44348145e-01],
                        [ -1.50024414e-01,  -1.50024414e-01],
                        [ -1.51153564e-01,  -1.51153564e-01],
                        [ -1.35131836e-01,  -1.35131836e-01],
                        [ -9.85717773e-02,  -9.86022949e-02],
                        [ -4.67529297e-02,  -4.67529297e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  8.82263184e-02,   8.82263184e-02],
                        [  1.58569336e-01,   1.58569336e-01],
                        [  2.10662842e-01,   2.10662842e-01],
                        [  2.31079102e-01,   2.31079102e-01],
                        [  2.18811035e-01,   2.18811035e-01],
                        [  1.86065674e-01,   1.86065674e-01],
                        [  1.52435303e-01,   1.52435303e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.27288818e-01,   1.27288818e-01],
                        [  1.21673584e-01,   1.21704102e-01],
                        [  1.07086182e-01,   1.07086182e-01],
                        [  8.83483887e-02,   8.83483887e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  5.62744141e-02,   5.62744141e-02],
                        [  5.21240234e-02,   5.21545410e-02],
                        [  5.06286621e-02,   5.06286621e-02],
                        [  4.90417480e-02,   4.90417480e-02],
                        [  4.48913574e-02,   4.48913574e-02],
                        [  3.87268066e-02,   3.87268066e-02],
                        [  3.24707031e-02,   3.24707031e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.34277344e-03,   1.34277344e-03],
                        [ -1.45874023e-02,  -1.45874023e-02],
                        [ -2.74047852e-02,  -2.74047852e-02],
                        [ -3.23486328e-02,  -3.23181152e-02],
                        [ -3.05786133e-02,  -3.05786133e-02],
                        [ -2.93273926e-02,  -2.93273926e-02],
                        [ -3.22875977e-02,  -3.22875977e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -3.59497070e-02,  -3.59497070e-02],
                        [ -3.23181152e-02,  -3.23181152e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.52380371e-02,  -2.52380371e-02],
                        [ -2.43530273e-02,  -2.43530273e-02],
                        [ -1.94702148e-02,  -1.94396973e-02],
                        [ -9.18579102e-03,  -9.18579102e-03],
                        [ -1.43432617e-03,  -1.46484375e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  1.21459961e-02,   1.21459961e-02],
                        [  2.02941895e-02,   2.02941895e-02],
                        [  2.69775391e-02,   2.69775391e-02],
                        [  3.68957520e-02,   3.68957520e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  6.66809082e-02,   6.66809082e-02],
                        [  7.89489746e-02,   7.89489746e-02],
                        [  8.61206055e-02,   8.61511230e-02],
                        [  8.49914551e-02,   8.49609375e-02],
                        [  7.32727051e-02,   7.32421875e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [ -3.37524414e-02,  -3.37829590e-02],
                        [ -1.11450195e-01,  -1.11450195e-01],
                        [ -1.83532715e-01,  -1.83532715e-01],
                        [ -2.16430664e-01,  -2.16430664e-01],
                        [ -2.06420898e-01,  -2.06420898e-01],
                        [ -1.77246094e-01,  -1.77215576e-01],
                        [ -1.49993896e-01,  -1.50024414e-01],
                        [ -1.30187988e-01,  -1.30187988e-01],
                        [ -1.16149902e-01,  -1.16119385e-01],
                        [ -1.06079102e-01,  -1.06079102e-01],
                        [ -9.81445312e-02,  -9.81750488e-02],
                        [ -9.29565430e-02,  -9.29260254e-02],
                        [ -9.45739746e-02,  -9.45434570e-02],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -1.09771729e-01,  -1.09802246e-01],
                        [ -9.99755859e-02,  -9.99450684e-02],
                        [ -7.45239258e-02,  -7.45239258e-02],
                        [ -4.37622070e-02,  -4.37927246e-02],
                        [ -1.07116699e-02,  -1.06811523e-02],
                        [  2.93884277e-02,   2.94189453e-02],
                        [  7.30590820e-02,   7.30285645e-02],
                        [  1.06109619e-01,   1.06109619e-01],
                        [  1.17065430e-01,   1.17126465e-01],
                        [  1.07055664e-01,   1.07055664e-01],
                        [  8.90808105e-02,   8.90502930e-02],
                        [  8.08410645e-02,   8.08715820e-02],
                        [  9.17663574e-02,   9.17968750e-02],
                        [  1.16943359e-01,   1.16912842e-01],
                        [  1.47186279e-01,   1.47155762e-01],
                        [  1.78314209e-01,   1.78344727e-01],
                        [  2.05383301e-01,   2.05383301e-01],
                        [  2.19573975e-01,   2.19543457e-01],
                        [  2.14111328e-01,   2.14141846e-01],
                        [  1.82037354e-01,   1.82037354e-01],
                        [  1.11785889e-01,   1.11755371e-01],
                        [  7.93457031e-04,   8.23974609e-04],
                        [ -1.30798340e-01,  -1.30767822e-01],
                        [ -2.48199463e-01,  -2.48199463e-01],
                        [ -3.19366455e-01,  -3.19366455e-01],
                        [ -3.26873779e-01,  -3.26873779e-01],
                        [ -2.78411865e-01,  -2.78411865e-01],
                        [ -2.08923340e-01,  -2.08953857e-01],
                        [ -1.57562256e-01,  -1.57531738e-01],
                        [ -1.36413574e-01,  -1.36413574e-01],
                        [ -1.30340576e-01,  -1.30340576e-01],
                        [ -1.24877930e-01,  -1.24877930e-01],
                        [ -1.21490479e-01,  -1.21490479e-01],
                        [ -1.24481201e-01,  -1.24481201e-01],
                        [ -1.26586914e-01,  -1.26586914e-01],
                        [ -1.15631104e-01,  -1.15631104e-01],
                        [ -8.72802734e-02,  -8.73107910e-02],
                        [ -4.21142578e-02,  -4.21142578e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  9.82360840e-02,   9.82360840e-02],
                        [  1.72393799e-01,   1.72363281e-01],
                        [  2.21923828e-01,   2.21954346e-01],
                        [  2.34802246e-01,   2.34802246e-01],
                        [  2.14569092e-01,   2.14538574e-01],
                        [  1.76910400e-01,   1.76910400e-01],
                        [  1.39709473e-01,   1.39709473e-01],
                        [  1.12854004e-01,   1.12823486e-01],
                        [  9.63134766e-02,   9.63134766e-02],
                        [  8.70971680e-02,   8.70971680e-02],
                        [  8.48083496e-02,   8.48083496e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  9.84802246e-02,   9.84802246e-02],
                        [  1.03759766e-01,   1.03759766e-01],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  1.65100098e-02,   1.65100098e-02],
                        [  1.74865723e-02,   1.74865723e-02],
                        [  2.77099609e-02,   2.77404785e-02],
                        [  3.25927734e-02,   3.25927734e-02],
                        [  2.92053223e-02,   2.92053223e-02],
                        [  2.34375000e-02,   2.34375000e-02],
                        [  2.02026367e-02,   2.02026367e-02],
                        [  1.79138184e-02,   1.79138184e-02],
                        [  9.94873047e-03,   9.94873047e-03],
                        [ -6.04248047e-03,  -6.04248047e-03],
                        [ -2.12707520e-02,  -2.12707520e-02],
                        [ -2.66418457e-02,  -2.66418457e-02],
                        [ -2.58789062e-02,  -2.59094238e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -3.23486328e-02,  -3.23486328e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -3.57666016e-02,  -3.57666016e-02],
                        [ -3.42407227e-02,  -3.42407227e-02],
                        [ -3.14025879e-02,  -3.14025879e-02],
                        [ -2.79541016e-02,  -2.79846191e-02],
                        [ -2.46582031e-02,  -2.46582031e-02],
                        [ -2.02941895e-02,  -2.02636719e-02],
                        [ -1.21154785e-02,  -1.21459961e-02],
                        [  7.62939453e-04,   7.62939453e-04],
                        [  1.41906738e-02,   1.41906738e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  1.67541504e-02,   1.67541504e-02],
                        [  1.91040039e-02,   1.90734863e-02],
                        [  2.44140625e-02,   2.44140625e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  3.79943848e-02,   3.79943848e-02],
                        [  4.66918945e-02,   4.66918945e-02],
                        [  5.48095703e-02,   5.48095703e-02],
                        [  6.37817383e-02,   6.37817383e-02],
                        [  7.29064941e-02,   7.29064941e-02],
                        [  7.39746094e-02,   7.39746094e-02],
                        [  5.68847656e-02,   5.68847656e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [ -4.89196777e-02,  -4.89196777e-02],
                        [ -1.28448486e-01,  -1.28448486e-01],
                        [ -1.96441650e-01,  -1.96441650e-01],
                        [ -2.25372314e-01,  -2.25372314e-01],
                        [ -2.12585449e-01,  -2.12585449e-01],
                        [ -1.81274414e-01,  -1.81274414e-01],
                        [ -1.54815674e-01,  -1.54815674e-01],
                        [ -1.38366699e-01,  -1.38366699e-01],
                        [ -1.23840332e-01,  -1.23840332e-01],
                        [ -1.05743408e-01,  -1.05712891e-01],
                        [ -8.92944336e-02,  -8.92944336e-02],
                        [ -8.22448730e-02,  -8.22448730e-02],
                        [ -8.27331543e-02,  -8.27026367e-02],
                        [ -8.20922852e-02,  -8.20922852e-02],
                        [ -7.65075684e-02,  -7.65075684e-02],
                        [ -6.76879883e-02,  -6.76879883e-02],
                        [ -5.42602539e-02,  -5.42297363e-02],
                        [ -3.15551758e-02,  -3.15551758e-02],
                        [  1.55639648e-03,   1.52587891e-03],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  8.45642090e-02,   8.45642090e-02],
                        [  1.15020752e-01,   1.15020752e-01],
                        [  1.23657227e-01,   1.23657227e-01],
                        [  1.16943359e-01,   1.16943359e-01],
                        [  1.11968994e-01,   1.11968994e-01],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.33697510e-01,   1.33728027e-01],
                        [  1.51184082e-01,   1.51184082e-01],
                        [  1.68090820e-01,   1.68090820e-01],
                        [  1.85516357e-01,   1.85516357e-01],
                        [  2.02087402e-01,   2.02117920e-01],
                        [  2.06481934e-01,   2.06451416e-01],
                        [  1.78100586e-01,   1.78100586e-01],
                        [  1.01745605e-01,   1.01776123e-01],
                        [ -1.68151855e-02,  -1.68151855e-02],
                        [ -1.49597168e-01,  -1.49627686e-01],
                        [ -2.59887695e-01,  -2.59857178e-01],
                        [ -3.18420410e-01,  -3.18420410e-01],
                        [ -3.14117432e-01,  -3.14147949e-01],
                        [ -2.58728027e-01,  -2.58728027e-01],
                        [ -1.86767578e-01,  -1.86767578e-01],
                        [ -1.38854980e-01,  -1.38854980e-01],
                        [ -1.29760742e-01,  -1.29760742e-01],
                        [ -1.39617920e-01,  -1.39617920e-01],
                        [ -1.44134521e-01,  -1.44134521e-01],
                        [ -1.40075684e-01,  -1.40075684e-01],
                        [ -1.34704590e-01,  -1.34674072e-01],
                        [ -1.25946045e-01,  -1.25946045e-01],
                        [ -1.03790283e-01,  -1.03790283e-01],
                        [ -6.27136230e-02,  -6.27136230e-02],
                        [ -5.85937500e-03,  -5.82885742e-03],
                        [  6.07299805e-02,   6.07299805e-02],
                        [  1.31347656e-01,   1.31347656e-01],
                        [  1.95251465e-01,   1.95251465e-01],
                        [  2.32421875e-01,   2.32421875e-01],
                        [  2.27508545e-01,   2.27508545e-01],
                        [  1.90155029e-01,   1.90185547e-01],
                        [  1.48498535e-01,   1.48498535e-01],
                        [  1.21154785e-01,   1.21154785e-01],
                        [  1.07574463e-01,   1.07574463e-01],
                        [  1.01074219e-01,   1.01104736e-01],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  9.64050293e-02,   9.64050293e-02],
                        [  9.50927734e-02,   9.51232910e-02],
                        [  9.30480957e-02,   9.30480957e-02],
                        [  8.72192383e-02,   8.71887207e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  5.61828613e-02,   5.62133789e-02],
                        [  4.01916504e-02,   4.01916504e-02],
                        [  3.10058594e-02,   3.10058594e-02],
                        [  2.64282227e-02,   2.64282227e-02],
                        [  2.41699219e-02,   2.41699219e-02],
                        [  2.69470215e-02,   2.69165039e-02],
                        [  3.54614258e-02,   3.54614258e-02],
                        [  4.30908203e-02,   4.31213379e-02],
                        [  4.39147949e-02,   4.39147949e-02],
                        [  4.04968262e-02,   4.04968262e-02],
                        [  3.41491699e-02,   3.41796875e-02],
                        [  1.71508789e-02,   1.71508789e-02],
                        [ -1.23596191e-02,  -1.23901367e-02],
                        [ -3.93981934e-02,  -3.93981934e-02],
                        [ -5.13610840e-02,  -5.13305664e-02],
                        [ -5.52062988e-02,  -5.52368164e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -6.01196289e-02,  -6.01196289e-02],
                        [ -4.26025391e-02,  -4.25720215e-02],
                        [ -1.89514160e-02,  -1.89819336e-02],
                        [ -8.57543945e-03,  -8.57543945e-03],
                        [ -1.04675293e-02,  -1.04675293e-02],
                        [ -8.66699219e-03,  -8.66699219e-03],
                        [  1.25122070e-03,   1.25122070e-03],
                        [  1.01013184e-02,   1.01318359e-02],
                        [  1.31835938e-02,   1.32141113e-02],
                        [  1.44653320e-02,   1.44348145e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.73950195e-02,   1.73950195e-02],
                        [  1.84020996e-02,   1.83715820e-02],
                        [  2.07214355e-02,   2.07214355e-02],
                        [  2.28576660e-02,   2.28881836e-02],
                        [  2.45971680e-02,   2.45971680e-02],
                        [  3.04870605e-02,   3.04565430e-02],
                        [  4.41284180e-02,   4.41284180e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  7.55920410e-02,   7.55920410e-02],
                        [  7.83081055e-02,   7.83081055e-02],
                        [  6.99157715e-02,   6.99462891e-02],
                        [  5.09338379e-02,   5.09338379e-02],
                        [  1.70288086e-02,   1.70288086e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -1.00738525e-01,  -1.00708008e-01],
                        [ -1.61437988e-01,  -1.61437988e-01],
                        [ -2.01232910e-01,  -2.01232910e-01],
                        [ -2.12371826e-01,  -2.12341309e-01],
                        [ -1.97143555e-01,  -1.97143555e-01],
                        [ -1.66717529e-01,  -1.66717529e-01],
                        [ -1.37969971e-01,  -1.37969971e-01],
                        [ -1.22161865e-01,  -1.22161865e-01],
                        [ -1.14624023e-01,  -1.14624023e-01],
                        [ -1.02508545e-01,  -1.02508545e-01],
                        [ -8.38012695e-02,  -8.38012695e-02],
                        [ -7.20520020e-02,  -7.20825195e-02],
                        [ -7.84301758e-02,  -7.84301758e-02],
                        [ -9.47265625e-02,  -9.46960449e-02],
                        [ -1.02020264e-01,  -1.02020264e-01],
                        [ -8.95080566e-02,  -8.95080566e-02],
                        [ -5.80139160e-02,  -5.80139160e-02],
                        [ -1.25732422e-02,  -1.25732422e-02],
                        [  4.07104492e-02,   4.07104492e-02],
                        [  9.24682617e-02,   9.24682617e-02],
                        [  1.30798340e-01,   1.30828857e-01],
                        [  1.48834229e-01,   1.48834229e-01],
                        [  1.51123047e-01,   1.51123047e-01],
                        [  1.48406982e-01,   1.48437500e-01],
                        [  1.46484375e-01,   1.46484375e-01],
                        [  1.45751953e-01,   1.45721436e-01],
                        [  1.50848389e-01,   1.50848389e-01],
                        [  1.69769287e-01,   1.69769287e-01],
                        [  1.97723389e-01,   1.97692871e-01],
                        [  2.13806152e-01,   2.13775635e-01],
                        [  1.99157715e-01,   1.99188232e-01],
                        [  1.49566650e-01,   1.49597168e-01],
                        [  6.88476562e-02,   6.88171387e-02],
                        [ -3.74450684e-02,  -3.74450684e-02],
                        [ -1.57073975e-01,  -1.57043457e-01],
                        [ -2.65228271e-01,  -2.65258789e-01],
                        [ -3.28674316e-01,  -3.28704834e-01],
                        [ -3.24493408e-01,  -3.24462891e-01],
                        [ -2.63275146e-01,  -2.63275146e-01],
                        [ -1.88781738e-01,  -1.88812256e-01],
                        [ -1.43768311e-01,  -1.43768311e-01],
                        [ -1.35528564e-01,  -1.35498047e-01],
                        [ -1.40899658e-01,  -1.40899658e-01],
                        [ -1.39190674e-01,  -1.39221191e-01],
                        [ -1.29577637e-01,  -1.29547119e-01],
                        [ -1.19415283e-01,  -1.19415283e-01],
                        [ -1.06536865e-01,  -1.06567383e-01],
                        [ -7.65686035e-02,  -7.65686035e-02],
                        [ -1.99584961e-02,  -1.99584961e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  1.77154541e-01,   1.77154541e-01],
                        [  2.10693359e-01,   2.10693359e-01],
                        [  2.20092773e-01,   2.20092773e-01],
                        [  2.01385498e-01,   2.01385498e-01],
                        [  1.61804199e-01,   1.61804199e-01],
                        [  1.20117188e-01,   1.20117188e-01],
                        [  9.09423828e-02,   9.09423828e-02],
                        [  7.57141113e-02,   7.56835938e-02],
                        [  7.07702637e-02,   7.07702637e-02],
                        [  7.49816895e-02,   7.50122070e-02],
                        [  8.54187012e-02,   8.53881836e-02],
                        [  9.38720703e-02,   9.38720703e-02],
                        [  9.42382812e-02,   9.42687988e-02],
                        [  8.74633789e-02,   8.74633789e-02],
                        [  7.68432617e-02,   7.68432617e-02],
                        [  6.57653809e-02,   6.57958984e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  5.99060059e-02,   5.98754883e-02],
                        [  5.93566895e-02,   5.93566895e-02],
                        [  5.09643555e-02,   5.09948730e-02],
                        [  3.71093750e-02,   3.71093750e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.53198242e-02,   1.53503418e-02],
                        [  5.49316406e-03,   5.52368164e-03],
                        [ -6.56127930e-03,  -6.56127930e-03],
                        [ -1.69982910e-02,  -1.69677734e-02],
                        [ -2.29187012e-02,  -2.29187012e-02],
                        [ -2.68249512e-02,  -2.68554688e-02],
                        [ -3.03039551e-02,  -3.03039551e-02],
                        [ -3.05480957e-02,  -3.05175781e-02],
                        [ -2.69165039e-02,  -2.69165039e-02],
                        [ -2.41394043e-02,  -2.41699219e-02],
                        [ -2.55432129e-02,  -2.55432129e-02],
                        [ -2.92053223e-02,  -2.91748047e-02],
                        [ -3.10363770e-02,  -3.10363770e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -1.22375488e-02,  -1.22375488e-02],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  5.76782227e-03,   5.76782227e-03],
                        [ -2.74658203e-04,  -2.74658203e-04],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  3.54003906e-03,   3.54003906e-03],
                        [  1.04064941e-02,   1.04064941e-02],
                        [  2.18200684e-02,   2.18200684e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  4.67224121e-02,   4.67224121e-02],
                        [  5.70373535e-02,   5.70068359e-02],
                        [  6.15234375e-02,   6.15234375e-02],
                        [  5.96008301e-02,   5.96008301e-02],
                        [  5.75561523e-02,   5.75561523e-02],
                        [  5.67016602e-02,   5.67016602e-02],
                        [  4.67834473e-02,   4.68139648e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [ -4.58679199e-02,  -4.58984375e-02],
                        [ -1.21002197e-01,  -1.21002197e-01],
                        [ -1.87866211e-01,  -1.87866211e-01],
                        [ -2.24639893e-01,  -2.24639893e-01],
                        [ -2.23571777e-01,  -2.23571777e-01],
                        [ -1.94244385e-01,  -1.94244385e-01],
                        [ -1.56677246e-01,  -1.56707764e-01],
                        [ -1.27380371e-01,  -1.27380371e-01],
                        [ -1.10137939e-01,  -1.10137939e-01],
                        [ -1.00769043e-01,  -1.00769043e-01],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -9.43908691e-02,  -9.43908691e-02],
                        [ -9.37500000e-02,  -9.37194824e-02],
                        [ -8.98132324e-02,  -8.98132324e-02],
                        [ -7.97119141e-02,  -7.97119141e-02],
                        [ -6.12792969e-02,  -6.12792969e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [  1.04675293e-02,   1.04675293e-02],
                        [  5.63964844e-02,   5.63964844e-02],
                        [  9.52758789e-02,   9.52758789e-02],
                        [  1.19964600e-01,   1.19964600e-01],
                        [  1.30523682e-01,   1.30523682e-01],
                        [  1.31683350e-01,   1.31713867e-01],
                        [  1.28997803e-01,   1.28997803e-01],
                        [  1.29089355e-01,   1.29058838e-01],
                        [  1.40960693e-01,   1.40960693e-01],
                        [  1.68426514e-01,   1.68426514e-01],
                        [  2.00653076e-01,   2.00653076e-01],
                        [  2.17926025e-01,   2.17926025e-01],
                        [  2.08679199e-01,   2.08709717e-01],
                        [  1.73461914e-01,   1.73431396e-01],
                        [  1.11724854e-01,   1.11724854e-01],
                        [  1.77917480e-02,   1.78222656e-02],
                        [ -1.03149414e-01,  -1.03149414e-01],
                        [ -2.23144531e-01,  -2.23144531e-01],
                        [ -3.02856445e-01,  -3.02856445e-01],
                        [ -3.16284180e-01,  -3.16284180e-01],
                        [ -2.70263672e-01,  -2.70263672e-01],
                        [ -2.01995850e-01,  -2.01995850e-01],
                        [ -1.52862549e-01,  -1.52862549e-01],
                        [ -1.38702393e-01,  -1.38702393e-01],
                        [ -1.45263672e-01,  -1.45263672e-01],
                        [ -1.49871826e-01,  -1.49871826e-01],
                        [ -1.42425537e-01,  -1.42425537e-01],
                        [ -1.25335693e-01,  -1.25335693e-01],
                        [ -1.02783203e-01,  -1.02783203e-01],
                        [ -7.49816895e-02,  -7.49816895e-02],
                        [ -3.66821289e-02,  -3.66821289e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  9.17358398e-02,   9.17358398e-02],
                        [  1.65435791e-01,   1.65435791e-01],
                        [  2.17071533e-01,   2.17071533e-01],
                        [  2.30560303e-01,   2.30590820e-01],
                        [  2.08801270e-01,   2.08801270e-01],
                        [  1.70806885e-01,   1.70806885e-01],
                        [  1.35467529e-01,   1.35467529e-01],
                        [  1.09527588e-01,   1.09527588e-01],
                        [  9.13391113e-02,   9.13391113e-02],
                        [  8.02917480e-02,   8.03222656e-02],
                        [  7.66906738e-02,   7.66906738e-02],
                        [  7.81860352e-02,   7.81860352e-02],
                        [  8.20617676e-02,   8.20617676e-02],
                        [  8.60900879e-02,   8.60900879e-02],
                        [  8.53576660e-02,   8.53576660e-02],
                        [  7.71179199e-02,   7.71179199e-02],
                        [  6.72607422e-02,   6.72912598e-02],
                        [  6.29272461e-02,   6.29272461e-02],
                        [  6.17370605e-02,   6.17370605e-02],
                        [  5.64880371e-02,   5.64880371e-02],
                        [  4.61120605e-02,   4.61120605e-02],
                        [  3.56140137e-02,   3.55834961e-02],
                        [  2.80456543e-02,   2.80151367e-02],
                        [  2.31628418e-02,   2.31628418e-02],
                        [  2.00500488e-02,   2.00500488e-02],
                        [  1.59301758e-02,   1.59301758e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [ -5.61523438e-03,  -5.58471680e-03],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [ -2.85034180e-02,  -2.85339355e-02],
                        [ -3.28979492e-02,  -3.28674316e-02],
                        [ -3.18603516e-02,  -3.18603516e-02],
                        [ -2.88696289e-02,  -2.89001465e-02],
                        [ -2.93884277e-02,  -2.93579102e-02],
                        [ -3.65905762e-02,  -3.65905762e-02],
                        [ -4.62646484e-02,  -4.62951660e-02],
                        [ -4.75158691e-02,  -4.75158691e-02],
                        [ -3.39965820e-02,  -3.39660645e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [  1.49536133e-03,   1.46484375e-03],
                        [  4.94384766e-03,   4.94384766e-03],
                        [  3.11279297e-03,   3.11279297e-03],
                        [  2.19726562e-03,   2.16674805e-03],
                        [  3.87573242e-03,   3.87573242e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.33361816e-02,   1.33056641e-02],
                        [  1.83715820e-02,   1.83715820e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.45056152e-02,   2.45056152e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  2.92663574e-02,   2.92663574e-02],
                        [  2.90832520e-02,   2.90527344e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.60620117e-02,   2.60925293e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  5.38940430e-02,   5.38635254e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  4.83398438e-02,   4.83398438e-02],
                        [  2.04162598e-02,   2.03857422e-02],
                        [ -2.40783691e-02,  -2.40783691e-02],
                        [ -8.45642090e-02,  -8.45642090e-02],
                        [ -1.50726318e-01,  -1.50756836e-01],
                        [ -2.00439453e-01,  -2.00439453e-01],
                        [ -2.12829590e-01,  -2.12829590e-01],
                        [ -1.87561035e-01,  -1.87561035e-01],
                        [ -1.47491455e-01,  -1.47521973e-01],
                        [ -1.17645264e-01,  -1.17614746e-01],
                        [ -1.05255127e-01,  -1.05255127e-01],
                        [ -1.03332520e-01,  -1.03363037e-01],
                        [ -1.03271484e-01,  -1.03271484e-01],
                        [ -1.00799561e-01,  -1.00799561e-01],
                        [ -9.65270996e-02,  -9.65576172e-02],
                        [ -9.24377441e-02,  -9.24377441e-02],
                        [ -8.67614746e-02,  -8.67309570e-02],
                        [ -7.42187500e-02,  -7.42187500e-02],
                        [ -4.97741699e-02,  -4.98046875e-02],
                        [ -1.15356445e-02,  -1.15356445e-02],
                        [  3.74450684e-02,   3.74450684e-02],
                        [  8.77990723e-02,   8.77990723e-02],
                        [  1.26464844e-01,   1.26434326e-01],
                        [  1.44012451e-01,   1.44012451e-01],
                        [  1.42456055e-01,   1.42456055e-01],
                        [  1.37115479e-01,   1.37115479e-01],
                        [  1.47979736e-01,   1.47979736e-01],
                        [  1.80297852e-01,   1.80328369e-01],
                        [  2.15362549e-01,   2.15332031e-01],
                        [  2.30926514e-01,   2.30895996e-01],
                        [  2.22595215e-01,   2.22595215e-01],
                        [  1.91589355e-01,   1.91619873e-01],
                        [  1.26922607e-01,   1.26922607e-01],
                        [  2.06909180e-02,   2.06909180e-02],
                        [ -1.09771729e-01,  -1.09771729e-01],
                        [ -2.30987549e-01,  -2.30987549e-01],
                        [ -3.12744141e-01,  -3.12774658e-01],
                        [ -3.32397461e-01,  -3.32397461e-01],
                        [ -2.83721924e-01,  -2.83721924e-01],
                        [ -1.97174072e-01,  -1.97204590e-01],
                        [ -1.27685547e-01,  -1.27685547e-01],
                        [ -1.05773926e-01,  -1.05773926e-01],
                        [ -1.16851807e-01,  -1.16851807e-01],
                        [ -1.32324219e-01,  -1.32354736e-01],
                        [ -1.40289307e-01,  -1.40258789e-01],
                        [ -1.40136719e-01,  -1.40106201e-01],
                        [ -1.27593994e-01,  -1.27624512e-01],
                        [ -9.55505371e-02,  -9.55505371e-02],
                        [ -4.06799316e-02,  -4.06799316e-02],
                        [  3.46374512e-02,   3.46374512e-02],
                        [  1.18469238e-01,   1.18469238e-01],
                        [  1.86950684e-01,   1.86950684e-01],
                        [  2.18597412e-01,   2.18597412e-01],
                        [  2.12005615e-01,   2.12005615e-01],
                        [  1.82525635e-01,   1.82495117e-01],
                        [  1.45904541e-01,   1.45904541e-01],
                        [  1.12915039e-01,   1.12945557e-01],
                        [  9.17053223e-02,   9.17053223e-02],
                        [  8.44116211e-02,   8.44116211e-02],
                        [  8.39538574e-02,   8.39843750e-02],
                        [  8.32214355e-02,   8.32214355e-02],
                        [  8.36791992e-02,   8.36791992e-02],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  8.80737305e-02,   8.80737305e-02],
                        [  8.18176270e-02,   8.17871094e-02],
                        [  7.25402832e-02,   7.25402832e-02],
                        [  6.44836426e-02,   6.44836426e-02],
                        [  5.69152832e-02,   5.69152832e-02],
                        [  5.18798828e-02,   5.19104004e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  6.16149902e-02,   6.16149902e-02],
                        [  6.10351562e-02,   6.10351562e-02],
                        [  4.88891602e-02,   4.88891602e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  2.09350586e-02,   2.09350586e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -7.41577148e-03,  -7.41577148e-03],
                        [ -2.31018066e-02,  -2.31323242e-02],
                        [ -3.28063965e-02,  -3.28063965e-02],
                        [ -3.68347168e-02,  -3.68347168e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -4.04663086e-02,  -4.04663086e-02],
                        [ -3.45153809e-02,  -3.45153809e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -2.35900879e-02,  -2.36206055e-02],
                        [ -2.60925293e-02,  -2.60925293e-02],
                        [ -2.49633789e-02,  -2.49328613e-02],
                        [ -2.03552246e-02,  -2.03857422e-02],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -1.43432617e-02,  -1.43127441e-02],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  8.23974609e-03,   8.20922852e-03],
                        [  9.39941406e-03,   9.39941406e-03],
                        [  4.39453125e-03,   4.42504883e-03],
                        [  2.47192383e-03,   2.44140625e-03],
                        [  2.62451172e-03,   2.62451172e-03],
                        [  1.83105469e-04,   2.13623047e-04],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -1.34277344e-03,  -1.34277344e-03],
                        [ -6.10351562e-05,  -6.10351562e-05],
                        [ -1.67846680e-03,  -1.64794922e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [  2.25830078e-03,   2.25830078e-03],
                        [  1.10168457e-02,   1.10473633e-02],
                        [  2.30407715e-02,   2.30407715e-02],
                        [  3.89404297e-02,   3.89404297e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  6.18286133e-02,   6.18286133e-02],
                        [  5.13610840e-02,   5.13610840e-02],
                        [  2.16369629e-02,   2.16369629e-02],
                        [ -2.55737305e-02,  -2.55737305e-02],
                        [ -8.52966309e-02,  -8.52661133e-02],
                        [ -1.45080566e-01,  -1.45080566e-01],
                        [ -1.86981201e-01,  -1.86981201e-01],
                        [ -1.99157715e-01,  -1.99157715e-01],
                        [ -1.85150146e-01,  -1.85150146e-01],
                        [ -1.61529541e-01,  -1.61529541e-01],
                        [ -1.43920898e-01,  -1.43920898e-01],
                        [ -1.34002686e-01,  -1.33972168e-01],
                        [ -1.22619629e-01,  -1.22619629e-01],
                        [ -1.05438232e-01,  -1.05468750e-01],
                        [ -8.95690918e-02,  -8.95690918e-02],
                        [ -8.17565918e-02,  -8.17565918e-02],
                        [ -7.59887695e-02,  -7.59887695e-02],
                        [ -6.07910156e-02,  -6.07910156e-02],
                        [ -3.58886719e-02,  -3.58886719e-02],
                        [ -9.94873047e-03,  -9.97924805e-03],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  4.82482910e-02,   4.82482910e-02],
                        [  8.80432129e-02,   8.80432129e-02],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  1.43432617e-01,   1.43432617e-01],
                        [  1.55853271e-01,   1.55853271e-01],
                        [  1.71234131e-01,   1.71234131e-01],
                        [  1.90704346e-01,   1.90704346e-01],
                        [  2.05963135e-01,   2.05963135e-01],
                        [  2.09777832e-01,   2.09777832e-01],
                        [  1.99584961e-01,   1.99584961e-01],
                        [  1.70989990e-01,   1.70989990e-01],
                        [  1.13586426e-01,   1.13586426e-01],
                        [  2.05383301e-02,   2.05383301e-02],
                        [ -9.80224609e-02,  -9.80224609e-02],
                        [ -2.13745117e-01,  -2.13745117e-01],
                        [ -2.92633057e-01,  -2.92633057e-01],
                        [ -3.12744141e-01,  -3.12713623e-01],
                        [ -2.77801514e-01,  -2.77832031e-01],
                        [ -2.16949463e-01,  -2.16949463e-01],
                        [ -1.67236328e-01,  -1.67205811e-01],
                        [ -1.49749756e-01,  -1.49749756e-01],
                        [ -1.56280518e-01,  -1.56280518e-01],
                        [ -1.61010742e-01,  -1.61010742e-01],
                        [ -1.48651123e-01,  -1.48651123e-01],
                        [ -1.26342773e-01,  -1.26373291e-01],
                        [ -1.05438232e-01,  -1.05438232e-01],
                        [ -7.95593262e-02,  -7.95593262e-02],
                        [ -3.14941406e-02,  -3.14941406e-02],
                        [  4.19006348e-02,   4.18701172e-02],
                        [  1.22589111e-01,   1.22558594e-01],
                        [  1.87194824e-01,   1.87194824e-01],
                        [  2.20367432e-01,   2.20336914e-01],
                        [  2.17102051e-01,   2.17102051e-01],
                        [  1.84295654e-01,   1.84295654e-01],
                        [  1.39617920e-01,   1.39587402e-01],
                        [  1.01684570e-01,   1.01684570e-01],
                        [  7.86132812e-02,   7.86132812e-02],
                        [  6.91223145e-02,   6.91223145e-02],
                        [  7.11669922e-02,   7.11669922e-02],
                        [  8.10852051e-02,   8.10852051e-02],
                        [  8.96606445e-02,   8.96606445e-02],
                        [  8.95690918e-02,   8.95690918e-02],
                        [  8.27636719e-02,   8.27636719e-02],
                        [  7.46765137e-02,   7.47070312e-02],
                        [  6.70166016e-02,   6.70471191e-02],
                        [  6.06384277e-02,   6.06689453e-02],
                        [  5.90209961e-02,   5.90209961e-02],
                        [  6.26525879e-02,   6.26220703e-02],
                        [  6.56738281e-02,   6.56738281e-02],
                        [  6.35681152e-02,   6.35681152e-02],
                        [  5.85021973e-02,   5.85327148e-02],
                        [  5.25817871e-02,   5.25817871e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  2.52075195e-02,   2.51770020e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [ -1.13220215e-02,  -1.13220215e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -2.47497559e-02,  -2.47192383e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -3.56140137e-02,  -3.56445312e-02],
                        [ -3.22265625e-02,  -3.22265625e-02],
                        [ -2.54821777e-02,  -2.54516602e-02],
                        [ -1.90124512e-02,  -1.89819336e-02],
                        [ -1.70288086e-02,  -1.70288086e-02],
                        [ -2.14233398e-02,  -2.14538574e-02],
                        [ -2.87780762e-02,  -2.88085938e-02],
                        [ -3.26843262e-02,  -3.26843262e-02],
                        [ -2.94494629e-02,  -2.94494629e-02],
                        [ -1.95922852e-02,  -1.95922852e-02],
                        [ -6.62231445e-03,  -6.59179688e-03],
                        [  4.51660156e-03,   4.51660156e-03],
                        [  1.19323730e-02,   1.19018555e-02],
                        [  1.82189941e-02,   1.82189941e-02],
                        [  2.38037109e-02,   2.38037109e-02],
                        [  2.51770020e-02,   2.52075195e-02],
                        [  2.23083496e-02,   2.23083496e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.55029297e-02,   1.54724121e-02],
                        [  7.75146484e-03,   7.75146484e-03],
                        [ -2.59399414e-03,  -2.56347656e-03],
                        [ -8.27026367e-03,  -8.23974609e-03],
                        [ -6.04248047e-03,  -6.01196289e-03],
                        [  1.80053711e-03,   1.77001953e-03],
                        [  1.40686035e-02,   1.40380859e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  4.84008789e-02,   4.84008789e-02],
                        [  5.83496094e-02,   5.84106445e-02],
                        [  5.13305664e-02,   5.13610840e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [ -3.72924805e-02,  -3.73229980e-02],
                        [ -1.08276367e-01,  -1.08276367e-01],
                        [ -1.70806885e-01,  -1.70806885e-01],
                        [ -2.01843262e-01,  -2.01812744e-01],
                        [ -1.93939209e-01,  -1.93908691e-01],
                        [ -1.62933350e-01,  -1.62933350e-01],
                        [ -1.34246826e-01,  -1.34307861e-01],
                        [ -1.19781494e-01,  -1.19781494e-01],
                        [ -1.12182617e-01,  -1.12182617e-01],
                        [ -1.02264404e-01,  -1.02264404e-01],
                        [ -9.07287598e-02,  -9.06982422e-02],
                        [ -8.29162598e-02,  -8.28857422e-02],
                        [ -8.09020996e-02,  -8.09631348e-02],
                        [ -8.00170898e-02,  -8.00476074e-02],
                        [ -6.96411133e-02,  -6.96105957e-02],
                        [ -4.27551270e-02,  -4.27246094e-02],
                        [ -2.80761719e-03,  -2.80761719e-03],
                        [  4.22363281e-02,   4.22668457e-02],
                        [  8.66394043e-02,   8.66088867e-02],
                        [  1.23992920e-01,   1.23901367e-01],
                        [  1.47491455e-01,   1.47491455e-01],
                        [  1.57714844e-01,   1.57806396e-01],
                        [  1.65344238e-01,   1.65374756e-01],
                        [  1.81793213e-01,   1.81793213e-01],
                        [  2.07611084e-01,   2.07580566e-01],
                        [  2.28363037e-01,   2.28302002e-01],
                        [  2.22625732e-01,   2.22595215e-01],
                        [  1.77001953e-01,   1.77062988e-01],
                        [  9.32006836e-02,   9.32922363e-02],
                        [ -1.83410645e-02,  -1.83410645e-02],
                        [ -1.41876221e-01,  -1.41937256e-01],
                        [ -2.51861572e-01,  -2.51922607e-01],
                        [ -3.17718506e-01,  -3.17718506e-01],
                        [ -3.21380615e-01,  -3.21380615e-01],
                        [ -2.72644043e-01,  -2.72583008e-01],
                        [ -2.06939697e-01,  -2.06909180e-01],
                        [ -1.61407471e-01,  -1.61468506e-01],
                        [ -1.46240234e-01,  -1.46301270e-01],
                        [ -1.44195557e-01,  -1.44195557e-01],
                        [ -1.38610840e-01,  -1.38549805e-01],
                        [ -1.29943848e-01,  -1.29882812e-01],
                        [ -1.20727539e-01,  -1.20697021e-01],
                        [ -9.97924805e-02,  -9.98229980e-02],
                        [ -5.38940430e-02,  -5.39550781e-02],
                        [  1.59912109e-02,   1.59301758e-02],
                        [  9.64965820e-02,   9.65270996e-02],
                        [  1.68395996e-01,   1.68487549e-01],
                        [  2.10906982e-01,   2.10937500e-01],
                        [  2.15087891e-01,   2.15057373e-01],
                        [  1.93145752e-01,   1.93084717e-01],
                        [  1.63024902e-01,   1.62963867e-01],
                        [  1.30279541e-01,   1.30310059e-01],
                        [  9.50927734e-02,   9.51843262e-02],
                        [  6.68945312e-02,   6.69860840e-02],
                        [  5.78002930e-02,   5.77697754e-02],
                        [  6.71081543e-02,   6.70166016e-02],
                        [  8.20617676e-02,   8.20007324e-02],
                        [  8.92333984e-02,   8.92639160e-02],
                        [  8.28857422e-02,   8.29467773e-02],
                        [  6.80847168e-02,   6.81152344e-02],
                        [  5.57861328e-02,   5.57556152e-02],
                        [  5.21545410e-02,   5.20629883e-02],
                        [  5.52062988e-02,   5.51147461e-02],
                        [  5.96618652e-02,   5.96618652e-02],
                        [  6.10046387e-02,   6.10961914e-02],
                        [  5.76477051e-02,   5.77392578e-02],
                        [  5.29785156e-02,   5.29479980e-02],
                        [  5.27343750e-02,   5.26733398e-02],
                        [  5.72204590e-02,   5.71289062e-02],
                        [  5.85327148e-02,   5.85327148e-02],
                        [  5.00793457e-02,   5.01403809e-02],
                        [  3.37524414e-02,   3.38439941e-02],
                        [  1.48620605e-02,   1.48620605e-02],
                        [ -4.33349609e-03,  -4.42504883e-03],
                        [ -2.31323242e-02,  -2.32238770e-02],
                        [ -3.99475098e-02,  -3.99475098e-02],
                        [ -5.23681641e-02,  -5.23071289e-02],
                        [ -5.73425293e-02,  -5.72509766e-02],
                        [ -5.32531738e-02,  -5.32226562e-02],
                        [ -4.26940918e-02,  -4.27856445e-02],
                        [ -3.13720703e-02,  -3.14941406e-02],
                        [ -2.33459473e-02,  -2.33459473e-02],
                        [ -1.96838379e-02,  -1.95922852e-02],
                        [ -2.03857422e-02,  -2.02941895e-02],
                        [ -2.28881836e-02,  -2.28576660e-02],
                        [ -2.11791992e-02,  -2.12402344e-02],
                        [ -1.11083984e-02,  -1.12304688e-02],
                        [  5.76782227e-03,   5.70678711e-03],
                        [  2.37731934e-02,   2.38647461e-02],
                        [  3.60107422e-02,   3.61328125e-02],
                        [  3.83605957e-02,   3.84216309e-02],
                        [  3.22265625e-02,   3.21655273e-02],
                        [  2.08435059e-02,   2.07214355e-02],
                        [  5.85937500e-03,   5.82885742e-03],
                        [ -9.42993164e-03,  -9.36889648e-03],
                        [ -1.77612305e-02,  -1.76391602e-02],
                        [ -1.35498047e-02,  -1.34887695e-02],
                        [ -7.62939453e-04,  -7.93457031e-04],
                        [  1.03149414e-02,   1.01623535e-02],
                        [  1.52282715e-02,   1.51672363e-02],
                        [  1.82800293e-02,   1.83410645e-02],
                        [  2.14538574e-02,   2.15759277e-02],
                        [  2.11791992e-02,   2.12402344e-02],
                        [  1.72424316e-02,   1.71813965e-02],
                        [  1.53198242e-02,   1.51977539e-02],
                        [  1.62963867e-02,   1.61743164e-02],
                        [  1.14440918e-02,   1.14746094e-02],
                        [ -8.54492188e-03,  -8.42285156e-03],
                        [ -4.67224121e-02,  -4.66308594e-02],
                        [ -9.91516113e-02,  -9.92126465e-02],
                        [ -1.51763916e-01,  -1.51885986e-01],
                        [ -1.83074951e-01,  -1.83197021e-01],
                        [ -1.82006836e-01,  -1.82006836e-01],
                        [ -1.58569336e-01,  -1.58416748e-01],
                        [ -1.31256104e-01,  -1.31134033e-01],
                        [ -1.10504150e-01,  -1.10534668e-01],
                        [ -9.77783203e-02,  -9.79309082e-02],
                        [ -9.17968750e-02,  -9.19189453e-02],
                        [ -8.79211426e-02,  -8.79211426e-02],
                        [ -7.91015625e-02,  -7.89794922e-02],
                        [ -6.55212402e-02,  -6.53991699e-02],
                        [ -5.59387207e-02,  -5.59082031e-02],
                        [ -5.12390137e-02,  -5.13916016e-02],
                        [ -3.62243652e-02,  -3.63464355e-02],
                        [  3.63159180e-03,   3.60107422e-03],
                        [  6.22253418e-02,   6.23779297e-02],
                        [  1.18347168e-01,   1.18469238e-01],
                        [  1.57318115e-01,   1.57348633e-01],
                        [  1.81182861e-01,   1.81060791e-01],
                        [  1.99066162e-01,   1.98883057e-01],
                        [  2.16217041e-01,   2.16156006e-01],
                        [  2.29461670e-01,   2.29583740e-01],
                        [  2.26837158e-01,   2.26989746e-01],
                        [  1.93725586e-01,   1.93756104e-01],
                        [  1.23718262e-01,   1.23626709e-01],
                        [  2.25219727e-02,   2.23693848e-02],
                        [ -9.71984863e-02,  -9.72595215e-02],
                        [ -2.17132568e-01,  -2.17041016e-01],
                        [ -3.08380127e-01,  -3.08197021e-01],
                        [ -3.39355469e-01,  -3.39294434e-01],
                        [ -3.03253174e-01,  -3.03344727e-01],
                        [ -2.32055664e-01,  -2.32238770e-01],
                        [ -1.72302246e-01,  -1.72393799e-01],
                        [ -1.46636963e-01,  -1.46545410e-01],
                        [ -1.43676758e-01,  -1.43463135e-01],
                        [ -1.41387939e-01,  -1.41265869e-01],
                        [ -1.31378174e-01,  -1.31469727e-01],
                        [ -1.17218018e-01,  -1.17401123e-01],
                        [ -9.78393555e-02,  -9.79309082e-02],
                        [ -6.11267090e-02,  -6.10351562e-02],
                        [  4.54711914e-03,   4.73022461e-03],
                        [  9.32922363e-02,   9.34448242e-02],
                        [  1.77703857e-01,   1.77642822e-01],
                        [  2.25402832e-01,   2.25189209e-01],
                        [  2.23541260e-01,   2.23419189e-01],
                        [  1.87927246e-01,   1.88018799e-01],
                        [  1.48071289e-01,   1.48254395e-01],
                        [  1.21063232e-01,   1.21215820e-01],
                        [  1.01837158e-01,   1.01776123e-01],
                        [  7.88879395e-02,   7.87048340e-02],
                        [  5.35278320e-02,   5.33752441e-02],
                        [  3.85437012e-02,   3.85742188e-02],
                        [  4.19311523e-02,   4.21447754e-02],
                        [  5.73120117e-02,   5.74645996e-02],
                        [  7.06787109e-02,   7.06481934e-02],
                        [  7.38525391e-02,   7.36694336e-02],
                        [  6.98242188e-02,   6.96411133e-02],
                        [  6.73217773e-02,   6.73217773e-02],
                        [  7.08007812e-02,   7.09838867e-02],
                        [  7.62939453e-02,   7.65075684e-02],
                        [  7.78808594e-02,   7.78808594e-02],
                        [  7.36999512e-02,   7.35168457e-02],
                        [  6.48498535e-02,   6.46667480e-02],
                        [  5.27648926e-02,   5.27343750e-02],
                        [  4.03137207e-02,   4.04968262e-02],
                        [  3.11889648e-02,   3.14025879e-02],
                        [  2.52380371e-02,   2.52685547e-02],
                        [  1.82495117e-02,   1.80358887e-02],
                        [  8.72802734e-03,   8.51440430e-03],
                        [ -2.44140625e-04,  -2.74658203e-04],
                        [ -8.11767578e-03,  -7.96508789e-03],
                        [ -1.73950195e-02,  -1.71813965e-02],
                        [ -2.77404785e-02,  -2.76794434e-02],
                        [ -3.65905762e-02,  -3.67431641e-02],
                        [ -4.25109863e-02,  -4.27551270e-02],
                        [ -4.44030762e-02,  -4.44946289e-02],
                        [ -4.18701172e-02,  -4.17175293e-02],
                        [ -3.62854004e-02,  -3.60717773e-02],
                        [ -2.86254883e-02,  -2.85339355e-02],
                        [ -1.89208984e-02,  -1.90429688e-02],
                        [ -9.33837891e-03,  -9.61303711e-03],
                        [ -1.31225586e-03,  -1.43432617e-03],
                        [  8.94165039e-03,   9.09423828e-03],
                        [  2.23999023e-02,   2.26440430e-02],
                        [  2.88391113e-02,   2.89611816e-02],
                        [  1.98669434e-02,   1.97448730e-02],
                        [  4.63867188e-03,   4.39453125e-03],
                        [ -2.16674805e-03,  -2.31933594e-03],
                        [ -8.54492188e-04,  -7.32421875e-04],
                        [ -1.19018555e-03,  -9.15527344e-04],
                        [ -4.42504883e-03,  -4.27246094e-03],
                        [ -3.50952148e-03,  -3.60107422e-03],
                        [  1.92260742e-03,   1.67846680e-03],
                        [  3.44848633e-03,   3.26538086e-03],
                        [ -1.73950195e-03,  -1.64794922e-03],
                        [ -5.27954102e-03,  -5.03540039e-03],
                        [ -1.34277344e-03,  -1.12915039e-03],
                        [  5.27954102e-03,   5.18798828e-03],
                        [  7.87353516e-03,   7.59887695e-03],
                        [  8.17871094e-03,   7.96508789e-03],
                        [  1.36413574e-02,   1.36718750e-02],
                        [  2.69470215e-02,   2.71911621e-02],
                        [  4.06188965e-02,   4.08325195e-02],
                        [  4.18395996e-02,   4.18090820e-02],
                        [  2.21557617e-02,   2.19116211e-02],
                        [ -1.77612305e-02,  -1.80053711e-02],
                        [ -7.14721680e-02,  -7.14416504e-02],
                        [ -1.29211426e-01,  -1.28936768e-01],
                        [ -1.76361084e-01,  -1.76116943e-01],
                        [ -1.96868896e-01,  -1.96899414e-01],
                        [ -1.84722900e-01,  -1.84967041e-01],
                        [ -1.49444580e-01,  -1.49688721e-01],
                        [ -1.10046387e-01,  -1.10076904e-01],
                        [ -8.33740234e-02,  -8.31604004e-02],
                        [ -7.43103027e-02,  -7.40356445e-02],
                        [ -7.42797852e-02,  -7.42187500e-02],
                        [ -7.14721680e-02,  -7.17163086e-02],
                        [ -6.16149902e-02,  -6.18896484e-02],
                        [ -4.78515625e-02,  -4.78820801e-02],
                        [ -3.09753418e-02,  -3.07617188e-02],
                        [ -4.60815430e-03,  -4.33349609e-03],
                        [  3.61328125e-02,   3.62243652e-02],
                        [  8.41064453e-02,   8.38928223e-02],
                        [  1.26037598e-01,   1.25701904e-01],
                        [  1.56738281e-01,   1.56646729e-01],
                        [  1.80450439e-01,   1.80664062e-01],
                        [  1.99890137e-01,   2.00195312e-01],
                        [  2.12158203e-01,   2.12249756e-01],
                        [  2.12951660e-01,   2.12768555e-01],
                        [  1.95770264e-01,   1.95465088e-01],
                        [  1.48773193e-01,   1.48620605e-01],
                        [  6.40869141e-02,   6.42395020e-02],
                        [ -4.95300293e-02,  -4.91943359e-02],
                        [ -1.68762207e-01,  -1.68609619e-01],
                        [ -2.66815186e-01,  -2.66967773e-01],
                        [ -3.20007324e-01,  -3.20343018e-01],
                        [ -3.14178467e-01,  -3.14361572e-01],
                        [ -2.57110596e-01,  -2.56988525e-01],
                        [ -1.84570312e-01,  -1.84234619e-01],
                        [ -1.38183594e-01,  -1.37969971e-01],
                        [ -1.29394531e-01,  -1.29516602e-01],
                        [ -1.35253906e-01,  -1.35589600e-01],
                        [ -1.31713867e-01,  -1.31927490e-01],
                        [ -1.16363525e-01,  -1.16271973e-01],
                        [ -9.48181152e-02,  -9.44824219e-02],
                        [ -6.19812012e-02,  -6.17370605e-02],
                        [ -7.96508789e-03,  -8.05664062e-03],
                        [  6.54907227e-02,   6.51550293e-02],
                        [  1.41357422e-01,   1.41113281e-01],
                        [  1.96441650e-01,   1.96533203e-01],
                        [  2.14355469e-01,   2.14691162e-01],
                        [  1.97052002e-01,   1.97326660e-01],
                        [  1.63513184e-01,   1.63482666e-01],
                        [  1.33544922e-01,   1.33209229e-01],
                        [  1.13311768e-01,   1.13037109e-01],
                        [  9.79614258e-02,   9.79919434e-02],
                        [  8.34655762e-02,   8.37707520e-02],
                        [  7.22045898e-02,   7.25097656e-02],
                        [  6.76574707e-02,   6.76574707e-02],
                        [  6.90307617e-02,   6.87255859e-02],
                        [  7.18688965e-02,   7.15332031e-02],
                        [  7.15637207e-02,   7.15332031e-02],
                        [  6.72607422e-02,   6.75659180e-02],
                        [  6.23779297e-02,   6.27441406e-02],
                        [  5.97839355e-02,   5.98144531e-02],
                        [  5.94787598e-02,   5.91735840e-02],
                        [  6.13708496e-02,   6.10351562e-02],
                        [  6.39953613e-02,   6.39343262e-02],
                        [  6.26831055e-02,   6.29272461e-02],
                        [  5.48706055e-02,   5.52368164e-02],
                        [  4.49523926e-02,   4.50439453e-02],
                        [  3.83911133e-02,   3.81164551e-02],
                        [  3.47900391e-02,   3.44238281e-02],
                        [  3.03039551e-02,   3.02124023e-02],
                        [  2.30407715e-02,   2.32849121e-02],
                        [  1.28479004e-02,   1.32141113e-02],
                        [ -6.40869141e-04,  -4.88281250e-04],
                        [ -1.68762207e-02,  -1.71203613e-02],
                        [ -3.20739746e-02,  -3.24707031e-02],
                        [ -3.97033691e-02,  -3.98559570e-02],
                        [ -3.65600586e-02,  -3.63159180e-02],
                        [ -2.81982422e-02,  -2.78320312e-02],
                        [ -2.23388672e-02,  -2.21557617e-02],
                        [ -1.91955566e-02,  -1.93786621e-02],
                        [ -1.58691406e-02,  -1.62658691e-02],
                        [ -1.38854980e-02,  -1.40991211e-02],
                        [ -1.49536133e-02,  -1.47705078e-02],
                        [ -1.51977539e-02,  -1.48010254e-02],
                        [ -9.85717773e-03,  -9.64355469e-03],
                        [ -1.22070312e-04,  -3.05175781e-04],
                        [  8.17871094e-03,   7.78198242e-03],
                        [  1.10778809e-02,   1.08032227e-02],
                        [  9.36889648e-03,   9.52148438e-03],
                        [  6.98852539e-03,   7.38525391e-03],
                        [  6.80541992e-03,   7.08007812e-03],
                        [  7.41577148e-03,   7.32421875e-03],
                        [  5.79833984e-03,   5.37109375e-03],
                        [  2.96020508e-03,   2.65502930e-03],
                        [  2.13623047e-03,   2.22778320e-03],
                        [  1.49536133e-03,   1.89208984e-03],
                        [ -4.08935547e-03,  -3.78417969e-03],
                        [ -1.37939453e-02,  -1.38549805e-02],
                        [ -1.95312500e-02,  -1.98974609e-02],
                        [ -1.51672363e-02,  -1.55334473e-02],
                        [ -2.96020508e-03,  -2.92968750e-03],
                        [  9.30786133e-03,   9.70458984e-03],
                        [  1.37939453e-02,   1.41601562e-02],
                        [  8.85009766e-03,   8.81958008e-03],
                        [  3.44848633e-03,   3.08227539e-03],
                        [  8.30078125e-03,   7.93457031e-03],
                        [  1.95922852e-02,   1.95617676e-02],
                        [  1.99584961e-02,   2.03247070e-02],
                        [ -3.72314453e-03,  -3.29589844e-03],
                        [ -5.05981445e-02,  -5.05371094e-02],
                        [ -1.09344482e-01,  -1.09710693e-01],
                        [ -1.62048340e-01,  -1.62445068e-01],
                        [ -1.88262939e-01,  -1.88323975e-01],
                        [ -1.78497314e-01,  -1.78161621e-01],
                        [ -1.44989014e-01,  -1.44592285e-01],
                        [ -1.10626221e-01,  -1.10504150e-01],
                        [ -8.82873535e-02,  -8.85925293e-02],
                        [ -7.68737793e-02,  -7.73315430e-02],
                        [ -7.23571777e-02,  -7.24792480e-02],
                        [ -7.40356445e-02,  -7.37304688e-02],
                        [ -7.99255371e-02,  -7.94982910e-02],
                        [ -8.06579590e-02,  -8.05053711e-02],
                        [ -6.30798340e-02,  -6.33544922e-02],
                        [ -2.18811035e-02,  -2.23388672e-02],
                        [  3.46679688e-02,   3.44848633e-02],
                        [  9.12475586e-02,   9.15222168e-02],
                        [  1.36749268e-01,   1.37237549e-01],
                        [  1.69281006e-01,   1.69494629e-01],
                        [  1.92718506e-01,   1.92474365e-01],
                        [  2.11517334e-01,   2.11059570e-01],
                        [  2.26257324e-01,   2.26013184e-01],
                        [  2.28881836e-01,   2.29095459e-01],
                        [  2.03063965e-01,   2.03552246e-01],
                        [  1.35375977e-01,   1.35650635e-01],
                        [  2.81677246e-02,   2.79846191e-02],
                        [ -9.91821289e-02,  -9.96704102e-02],
                        [ -2.19451904e-01,  -2.19757080e-01],
                        [ -3.05175781e-01,  -3.04992676e-01],
                        [ -3.34869385e-01,  -3.34381104e-01],
                        [ -3.06304932e-01,  -3.05999756e-01],
                        [ -2.44995117e-01,  -2.45147705e-01],
                        [ -1.88751221e-01,  -1.89239502e-01],
                        [ -1.59210205e-01,  -1.59545898e-01],
                        [ -1.49719238e-01,  -1.49597168e-01],
                        [ -1.40075684e-01,  -1.39617920e-01],
                        [ -1.19903564e-01,  -1.19537354e-01],
                        [ -9.28955078e-02,  -9.29870605e-02],
                        [ -6.02416992e-02,  -6.07299805e-02],
                        [ -1.29394531e-02,  -1.33361816e-02],
                        [  5.29479980e-02,   5.29785156e-02],
                        [  1.23565674e-01,   1.24023438e-01],
                        [  1.77978516e-01,   1.78405762e-01],
                        [  2.04559326e-01,   2.04528809e-01],
                        [  2.02667236e-01,   2.02209473e-01],
                        [  1.77124023e-01,   1.76696777e-01],
                        [  1.39251709e-01,   1.39251709e-01],
                        [  1.05529785e-01,   1.05957031e-01],
                        [  8.63647461e-02,   8.67919922e-02],
                        [  7.88574219e-02,   7.88879395e-02],
                        [  7.46765137e-02,   7.42492676e-02],
                        [  7.08312988e-02,   7.03735352e-02],
                        [  6.89392090e-02,   6.88781738e-02],
                        [  6.76879883e-02,   6.80847168e-02],
                        [  6.32019043e-02,   6.36901855e-02],
                        [  5.59387207e-02,   5.60302734e-02],
                        [  5.06286621e-02,   5.02624512e-02],
                        [  5.04455566e-02,   4.99572754e-02],
                        [  5.47485352e-02,   5.46264648e-02],
                        [  6.09130859e-02,   6.12487793e-02],
                        [  6.65588379e-02,   6.70776367e-02],
                        [  7.04650879e-02,   7.06481934e-02],
                        [  7.14721680e-02,   7.11364746e-02],
                        [  6.87255859e-02,   6.82067871e-02],
                        [  6.22863770e-02,   6.21032715e-02],
                        [  5.20019531e-02,   5.23071289e-02],
                        [  3.81164551e-02,   3.86352539e-02],
                        [  2.44750977e-02,   2.47192383e-02],
                        [  1.56555176e-02,   1.53503418e-02],
                        [  9.64355469e-03,   9.09423828e-03],
                        [ -1.37329102e-03,  -1.61743164e-03],
                        [ -1.95922852e-02,  -1.93481445e-02],
                        [ -3.61022949e-02,  -3.55529785e-02],
                        [ -4.09240723e-02,  -4.06188965e-02],
                        [ -3.43322754e-02,  -3.45458984e-02],
                        [ -2.42309570e-02,  -2.47802734e-02],
                        [ -1.69067383e-02,  -1.72424316e-02],
                        [ -1.38244629e-02,  -1.36108398e-02],
                        [ -1.39160156e-02,  -1.33972168e-02],
                        [ -1.47399902e-02,  -1.44042969e-02],
                        [ -1.23291016e-02,  -1.25122070e-02],
                        [ -4.45556641e-03,  -4.97436523e-03],
                        [  5.95092773e-03,   5.55419922e-03],
                        [  1.37329102e-02,   1.38854980e-02],
                        [  1.70593262e-02,   1.76086426e-02],
                        [  1.80664062e-02,   1.84631348e-02],
                        [  1.95312500e-02,   1.94091797e-02],
                        [  2.08740234e-02,   2.03552246e-02],
                        [  1.80969238e-02,   1.76391602e-02],
                        [  1.03759766e-02,   1.04675293e-02],
                        [  2.34985352e-03,   2.86865234e-03],
                        [ -3.81469727e-03,  -3.35693359e-03],
                        [ -1.17492676e-02,  -1.17797852e-02],
                        [ -2.25524902e-02,  -2.30407715e-02],
                        [ -2.96020508e-02,  -3.00903320e-02],
                        [ -2.69165039e-02,  -2.68859863e-02],
                        [ -1.68151855e-02,  -1.63269043e-02],
                        [ -5.49316406e-03,  -4.97436523e-03],
                        [  4.42504883e-03,   4.45556641e-03],
                        [  1.22680664e-02,   1.17797852e-02],
                        [  1.68457031e-02,   1.63269043e-02],
                        [  1.95007324e-02,   1.94396973e-02],
                        [  2.48718262e-02,   2.53295898e-02],
                        [  3.46069336e-02,   3.51562500e-02],
                        [  4.17785645e-02,   4.18701172e-02],
                        [  3.44238281e-02,   3.39965820e-02],
                        [  4.82177734e-03,   4.27246094e-03],
                        [ -4.55932617e-02,  -4.57153320e-02],
                        [ -1.05865479e-01,  -1.05438232e-01],
                        [ -1.56677246e-01,  -1.56127930e-01],
                        [ -1.78741455e-01,  -1.78558350e-01],
                        [ -1.67419434e-01,  -1.67816162e-01],
                        [ -1.39251709e-01,  -1.39831543e-01],
                        [ -1.18591309e-01,  -1.18804932e-01],
                        [ -1.15051270e-01,  -1.14685059e-01],
                        [ -1.16271973e-01,  -1.15692139e-01],
                        [ -1.05499268e-01,  -1.05255127e-01],
                        [ -8.21533203e-02,  -8.24890137e-02],
                        [ -5.92956543e-02,  -5.98754883e-02],
                        [ -4.46472168e-02,  -4.49523926e-02],
                        [ -3.06701660e-02,  -3.03649902e-02],
                        [ -3.35693359e-03,  -2.74658203e-03],
                        [  4.28466797e-02,   4.31518555e-02],
                        [  1.00646973e-01,   1.00372314e-01],
                        [  1.56463623e-01,   1.55853271e-01],
                        [  1.99493408e-01,   1.99127197e-01],
                        [  2.27722168e-01,   2.27966309e-01],
                        [  2.44598389e-01,   2.45208740e-01],
                        [  2.47222900e-01,   2.47619629e-01],
                        [  2.22076416e-01,   2.21862793e-01],
                        [  1.57135010e-01,   1.56524658e-01],
                        [  5.53894043e-02,   5.49926758e-02],
                        [ -6.79016113e-02,  -6.77185059e-02],
                        [ -1.92840576e-01,  -1.92260742e-01],
                        [ -2.91992188e-01,  -2.91534424e-01],
                        [ -3.34564209e-01,  -3.34686279e-01],
                        [ -3.11950684e-01,  -3.12530518e-01],
                        [ -2.52471924e-01,  -2.52929688e-01],
                        [ -1.98730469e-01,  -1.98638916e-01],
                        [ -1.72760010e-01,  -1.72180176e-01],
                        [ -1.66381836e-01,  -1.65893555e-01],
                        [ -1.58813477e-01,  -1.58874512e-01],
                        [ -1.37451172e-01,  -1.38000488e-01],
                        [ -1.02874756e-01,  -1.03424072e-01],
                        [ -5.95703125e-02,  -5.95397949e-02],
                        [ -6.40869141e-03,  -5.85937500e-03],
                        [  5.85021973e-02,   5.90515137e-02],
                        [  1.26922607e-01,   1.26953125e-01],
                        [  1.80725098e-01,   1.80206299e-01],
                        [  2.05657959e-01,   2.05108643e-01],
                        [  2.01751709e-01,   2.01690674e-01],
                        [  1.79595947e-01,   1.80084229e-01],
                        [  1.50604248e-01,   1.51214600e-01],
                        [  1.22680664e-01,   1.22772217e-01],
                        [  1.01196289e-01,   1.00708008e-01],
                        [  8.77685547e-02,   8.71582031e-02],
                        [  7.75756836e-02,   7.74230957e-02],
                        [  6.48498535e-02,   6.53076172e-02],
                        [  5.10864258e-02,   5.17272949e-02],
                        [  4.11987305e-02,   4.13818359e-02],
                        [  3.51867676e-02,   3.47595215e-02],
                        [  3.15246582e-02,   3.08837891e-02],
                        [  3.35998535e-02,   3.33862305e-02],
                        [  4.51354980e-02,   4.55627441e-02],
                        [  6.19812012e-02,   6.26220703e-02],
                        [  7.71179199e-02,   7.73620605e-02],
                        [  8.88977051e-02,   8.85314941e-02],
                        [  9.64660645e-02,   9.58251953e-02],
                        [  9.47570801e-02,   9.44519043e-02],
                        [  8.18786621e-02,   8.22143555e-02],
                        [  6.42089844e-02,   6.48803711e-02],
                        [  4.83093262e-02,   4.86450195e-02],
                        [  3.44543457e-02,   3.41186523e-02],
                        [  2.18200684e-02,   2.11486816e-02],
                        [  1.19323730e-02,   1.15661621e-02],
                        [  3.60107422e-03,   3.87573242e-03],
                        [ -7.87353516e-03,  -7.23266602e-03],
                        [ -2.24609375e-02,  -2.20642090e-02],
                        [ -3.40270996e-02,  -3.42407227e-02],
                        [ -3.95202637e-02,  -4.01611328e-02],
                        [ -4.18701172e-02,  -4.22973633e-02],
                        [ -4.23278809e-02,  -4.21142578e-02],
                        [ -3.73229980e-02,  -3.66821289e-02],
                        [ -2.52075195e-02,  -2.47497559e-02],
                        [ -1.11999512e-02,  -1.13525391e-02],
                        [ -2.10571289e-03,  -2.71606445e-03],
                        [  2.22778320e-03,   1.70898438e-03],
                        [  8.02612305e-03,   8.11767578e-03],
                        [  1.72424316e-02,   1.78833008e-02],
                        [  2.16979980e-02,   2.22167969e-02],
                        [  1.30615234e-02,   1.29699707e-02],
                        [ -3.29589844e-03,  -3.90625000e-03],
                        [ -1.33972168e-02,  -1.39465332e-02],
                        [ -1.22680664e-02,  -1.22375488e-02],
                        [ -6.46972656e-03,  -5.85937500e-03],
                        [ -1.83105469e-03,  -1.25122070e-03],
                        [  2.74658203e-04,   3.05175781e-04],
                        [ -1.95312500e-03,  -2.53295898e-03],
                        [ -9.85717773e-03,  -1.04675293e-02],
                        [ -1.95617676e-02,  -1.95922852e-02],
                        [ -2.49328613e-02,  -2.43835449e-02],
                        [ -2.42614746e-02,  -2.36206055e-02],
                        [ -2.05688477e-02,  -2.04772949e-02],
                        [ -1.69677734e-02,  -1.74865723e-02],
                        [ -1.31530762e-02,  -1.37939453e-02],
                        [ -7.32421875e-03,  -7.47680664e-03],
                        [  5.79833984e-04,   1.06811523e-03],
                        [  9.70458984e-03,   1.03759766e-02],
                        [  2.20947266e-02,   2.22473145e-02],
                        [  3.96118164e-02,   3.91235352e-02],
                        [  5.58776855e-02,   5.52062988e-02],
                        [  5.81359863e-02,   5.79223633e-02],
                        [  3.89404297e-02,   3.93676758e-02],
                        [  3.66210938e-04,   1.06811523e-03],
                        [ -5.14526367e-02,  -5.12084961e-02],
                        [ -1.08642578e-01,  -1.09039307e-01],
                        [ -1.57928467e-01,  -1.58630371e-01],
                        [ -1.83532715e-01,  -1.83837891e-01],
                        [ -1.78771973e-01,  -1.78405762e-01],
                        [ -1.54083252e-01,  -1.53381348e-01],
                        [ -1.28509521e-01,  -1.28173828e-01],
                        [ -1.12396240e-01,  -1.12762451e-01],
                        [ -1.00952148e-01,  -1.01654053e-01],
                        [ -8.55712891e-02,  -8.59680176e-02],
                        [ -6.69860840e-02,  -6.66809082e-02],
                        [ -5.13000488e-02,  -5.05981445e-02],
                        [ -3.72009277e-02,  -3.67736816e-02],
                        [ -1.47399902e-02,  -1.50146484e-02],
                        [  2.35290527e-02,   2.28271484e-02],
                        [  7.54089355e-02,   7.49511719e-02],
                        [  1.32141113e-01,   1.32354736e-01],
                        [  1.84875488e-01,   1.85546875e-01],
                        [  2.26074219e-01,   2.26562500e-01],
                        [  2.47802734e-01,   2.47650146e-01],
                        [  2.42584229e-01,   2.41912842e-01],
                        [  2.05902100e-01,   2.05383301e-01],
                        [  1.36230469e-01,   1.36383057e-01],
                        [  3.53698730e-02,   3.60412598e-02],
                        [ -8.64868164e-02,  -8.59375000e-02],
                        [ -2.07092285e-01,  -2.07183838e-01],
                        [ -2.97210693e-01,  -2.97851562e-01],
                        [ -3.33099365e-01,  -3.33679199e-01],
                        [ -3.10302734e-01,  -3.10241699e-01],
                        [ -2.52014160e-01,  -2.51403809e-01],
                        [ -1.98486328e-01,  -1.97875977e-01],
                        [ -1.75384521e-01,  -1.75415039e-01],
                        [ -1.72851562e-01,  -1.73461914e-01],
                        [ -1.62200928e-01,  -1.62841797e-01],
                        [ -1.29119873e-01,  -1.29150391e-01],
                        [ -8.01086426e-02,  -7.95288086e-02],
                        [ -2.29492188e-02,  -2.23083496e-02],
                        [  4.27551270e-02,   4.28466797e-02],
                        [  1.13250732e-01,   1.12670898e-01],
                        [  1.72912598e-01,   1.72241211e-01],
                        [  2.06451416e-01,   2.06329346e-01],
                        [  2.11212158e-01,   2.11761475e-01],
                        [  1.94183350e-01,   1.94854736e-01],
                        [  1.65008545e-01,   1.65191650e-01],
                        [  1.32934570e-01,   1.32415771e-01],
                        [  1.03179932e-01,   1.02478027e-01],
                        [  7.66906738e-02,   7.64770508e-02],
                        [  5.73120117e-02,   5.78002930e-02],
                        [  5.23986816e-02,   5.31311035e-02],
                        [  6.01196289e-02,   6.03637695e-02],
                        [  6.53076172e-02,   6.48803711e-02],
                        [  5.70678711e-02,   5.63354492e-02],
                        [  4.19006348e-02,   4.15954590e-02],
                        [  3.33251953e-02,   3.37219238e-02],
                        [  3.56445312e-02,   3.63769531e-02],
                        [  4.47998047e-02,   4.51354980e-02],
                        [  5.78002930e-02,   5.74340820e-02],
                        [  7.36999512e-02,   7.29675293e-02],
                        [  8.70361328e-02,   8.66699219e-02],
                        [  8.90502930e-02,   8.93554688e-02],
                        [  7.73315430e-02,   7.80334473e-02],
                        [  5.90820312e-02,   5.95092773e-02],
                        [  4.24194336e-02,   4.21447754e-02],
                        [  2.98156738e-02,   2.90832520e-02],
                        [  1.94091797e-02,   1.89514160e-02],
                        [  8.42285156e-03,   8.66699219e-03],
                        [ -3.60107422e-03,  -2.89916992e-03],
                        [ -1.26037598e-02,  -1.21154785e-02],
                        [ -1.47399902e-02,  -1.49230957e-02],
                        [ -1.32141113e-02,  -1.39160156e-02],
                        [ -1.49230957e-02,  -1.54724121e-02],
                        [ -2.19726562e-02,  -2.18200684e-02],
                        [ -3.09448242e-02,  -3.02734375e-02],
                        [ -3.72009277e-02,  -3.66516113e-02],
                        [ -3.56750488e-02,  -3.57971191e-02],
                        [ -2.38952637e-02,  -2.45666504e-02],
                        [ -6.56127930e-03,  -7.17163086e-03],
                        [  7.50732422e-03,   7.56835938e-03],
                        [  1.38854980e-02,   1.45263672e-02],
                        [  1.43737793e-02,   1.49841309e-02],
                        [  1.30920410e-02,   1.30615234e-02],
                        [  1.18713379e-02,   1.12609863e-02],
                        [  8.23974609e-03,   7.59887695e-03],
                        [ -7.93457031e-04,  -8.23974609e-04],
                        [ -1.23596191e-02,  -1.17492676e-02],
                        [ -1.89819336e-02,  -1.83410645e-02],
                        [ -1.70288086e-02,  -1.69677734e-02],
                        [ -1.01928711e-02,  -1.07727051e-02],
                        [ -4.05883789e-03,  -4.73022461e-03],
                        [ -1.15966797e-03,  -1.28173828e-03],
                        [ -2.56347656e-03,  -2.01416016e-03],
                        [ -1.00097656e-02,  -9.30786133e-03],
                        [ -2.23999023e-02,  -2.22473145e-02],
                        [ -3.30505371e-02,  -3.35998535e-02],
                        [ -3.56750488e-02,  -3.64074707e-02],
                        [ -3.15551758e-02,  -3.17687988e-02],
                        [ -2.48718262e-02,  -2.43835449e-02],
                        [ -1.44042969e-02,  -1.36718750e-02],
                        [  1.25122070e-03,   1.49536133e-03],
                        [  1.57775879e-02,   1.53198242e-02],
                        [  2.30712891e-02,   2.23083496e-02],
                        [  2.61535645e-02,   2.58483887e-02],
                        [  2.92968750e-02,   2.97241211e-02],
                        [  2.81677246e-02,   2.89001465e-02],
                        [  1.72119141e-02,   1.75476074e-02],
                        [ -2.74658203e-03,  -3.11279297e-03],
                        [ -3.16162109e-02,  -3.23486328e-02],
                        [ -7.32421875e-02,  -7.36389160e-02],
                        [ -1.21917725e-01,  -1.21551514e-01],
                        [ -1.56433105e-01,  -1.55700684e-01],
                        [ -1.59332275e-01,  -1.58905029e-01],
                        [ -1.36199951e-01,  -1.36535645e-01],
                        [ -1.08825684e-01,  -1.09558105e-01],
                        [ -9.19799805e-02,  -9.24377441e-02],
                        [ -8.36486816e-02,  -8.34045410e-02],
                        [ -7.46154785e-02,  -7.38830566e-02],
                        [ -6.15844727e-02,  -6.10961914e-02],
                        [ -4.78210449e-02,  -4.80346680e-02],
                        [ -3.43322754e-02,  -3.50646973e-02],
                        [ -1.51367188e-02,  -1.56555176e-02],
                        [  1.73339844e-02,   1.75170898e-02],
                        [  6.35681152e-02,   6.42700195e-02],
                        [  1.16058350e-01,   1.16638184e-01],
                        [  1.66137695e-01,   1.66015625e-01],
                        [  2.07824707e-01,   2.07153320e-01],
                        [  2.33215332e-01,   2.32635498e-01],
                        [  2.30072021e-01,   2.30133057e-01],
                        [  1.89514160e-01,   1.90185547e-01],
                        [  1.12243652e-01,   1.12854004e-01],
                        [  3.99780273e-03,   3.96728516e-03],
                        [ -1.24877930e-01,  -1.25518799e-01],
                        [ -2.49114990e-01,  -2.49755859e-01],
                        [ -3.30383301e-01,  -3.30413818e-01],
                        [ -3.42468262e-01,  -3.41827393e-01],
                        [ -2.93487549e-01,  -2.92816162e-01],
                        [ -2.20916748e-01,  -2.20855713e-01],
                        [ -1.66076660e-01,  -1.66687012e-01],
                        [ -1.47735596e-01,  -1.48406982e-01],
                        [ -1.52008057e-01,  -1.52130127e-01],
                        [ -1.48071289e-01,  -1.47491455e-01],
                        [ -1.16973877e-01,  -1.16241455e-01],
                        [ -6.39648438e-02,  -6.38122559e-02],
                        [ -2.71606445e-03,  -3.26538086e-03],
                        [  6.17980957e-02,   6.10961914e-02],
                        [  1.27227783e-01,   1.27044678e-01],
                        [  1.80877686e-01,   1.81396484e-01],
                        [  2.06420898e-01,   2.07153320e-01],
                        [  2.01873779e-01,   2.02117920e-01],
                        [  1.80541992e-01,   1.80053711e-01],
                        [  1.54937744e-01,   1.54174805e-01],
                        [  1.28143311e-01,   1.27868652e-01],
                        [  1.00433350e-01,   1.00891113e-01],
                        [  7.61413574e-02,   7.69042969e-02],
                        [  6.16455078e-02,   6.19812012e-02],
                        [  5.91125488e-02,   5.87158203e-02],
                        [  6.29882812e-02,   6.22253418e-02],
                        [  6.38427734e-02,   6.34460449e-02],
                        [  5.72814941e-02,   5.76477051e-02],
                        [  4.74243164e-02,   4.81567383e-02],
                        [  4.03442383e-02,   4.07714844e-02],
                        [  3.81164551e-02,   3.77807617e-02],
                        [  3.99780273e-02,   3.92456055e-02],
                        [  4.58374023e-02,   4.53796387e-02],
                        [  5.48400879e-02,   5.51147461e-02],
                        [  6.35375977e-02,   6.42700195e-02],
                        [  6.87561035e-02,   6.92749023e-02],
                        [  7.02514648e-02,   7.00378418e-02],
                        [  6.85119629e-02,   6.77795410e-02],
                        [  6.23474121e-02,   6.18286133e-02],
                        [  5.02014160e-02,   5.04150391e-02],
                        [  3.22875977e-02,   3.29895020e-02],
                        [  1.11999512e-02,   1.17797852e-02],
                        [ -7.41577148e-03,  -7.56835938e-03],
                        [ -1.72119141e-02,  -1.79138184e-02],
                        [ -1.65710449e-02,  -1.71508789e-02],
                        [ -1.27563477e-02,  -1.26342773e-02],
                        [ -1.62658691e-02,  -1.55639648e-02],
                        [ -2.86254883e-02,  -2.80151367e-02],
                        [ -3.86047363e-02,  -3.86657715e-02],
                        [ -3.50646973e-02,  -3.57360840e-02],
                        [ -2.05688477e-02,  -2.12097168e-02],
                        [ -6.86645508e-03,  -6.86645508e-03],
                        [  2.74658203e-04,   9.46044922e-04],
                        [  4.30297852e-03,   4.97436523e-03],
                        [  8.11767578e-03,   8.14819336e-03],
                        [  1.08032227e-02,   1.01623535e-02],
                        [  1.18103027e-02,   1.11083984e-02],
                        [  1.08947754e-02,   1.08032227e-02],
                        [  5.46264648e-03,   6.04248047e-03],
                        [ -4.21142578e-03,  -3.47900391e-03],
                        [ -9.85717773e-03,  -9.73510742e-03],
                        [ -3.93676758e-03,  -4.51660156e-03],
                        [  9.33837891e-03,   8.63647461e-03],
                        [  1.91955566e-02,   1.90124512e-02],
                        [  2.01110840e-02,   2.06298828e-02],
                        [  1.14440918e-02,   1.21765137e-02],
                        [ -6.59179688e-03,  -6.37817383e-03],
                        [ -2.82287598e-02,  -2.87170410e-02],
                        [ -4.29382324e-02,  -4.37011719e-02],
                        [ -4.65087891e-02,  -4.67834473e-02],
                        [ -4.22058105e-02,  -4.17480469e-02],
                        [ -3.21350098e-02,  -3.13720703e-02],
                        [ -1.80969238e-02,  -1.77917480e-02],
                        [ -6.86645508e-03,  -7.26318359e-03],
                        [ -3.78417969e-03,  -4.51660156e-03],
                        [ -6.50024414e-03,  -6.86645508e-03],
                        [ -9.55200195e-03,  -9.15527344e-03],
                        [ -8.69750977e-03,  -7.93457031e-03],
                        [ -7.62939453e-04,  -3.66210938e-04],
                        [  1.33972168e-02,   1.30615234e-02],
                        [  2.63977051e-02,   2.56347656e-02],
                        [  2.85949707e-02,   2.81677246e-02],
                        [  1.17797852e-02,   1.20849609e-02],
                        [ -2.83813477e-02,  -2.76489258e-02],
                        [ -8.43200684e-02,  -8.38317871e-02],
                        [ -1.34582520e-01,  -1.34826660e-01],
                        [ -1.59027100e-01,  -1.59790039e-01],
                        [ -1.54846191e-01,  -1.55395508e-01],
                        [ -1.34185791e-01,  -1.33972168e-01],
                        [ -1.10473633e-01,  -1.09741211e-01],
                        [ -9.09118652e-02,  -9.03625488e-02],
                        [ -7.60498047e-02,  -7.62023926e-02],
                        [ -6.19812012e-02,  -6.26831055e-02],
                        [ -4.41894531e-02,  -4.47692871e-02],
                        [ -2.21252441e-02,  -2.20336914e-02],
                        [  9.76562500e-04,   1.67846680e-03],
                        [  2.53295898e-02,   2.59399414e-02],
                        [  5.89294434e-02,   5.88378906e-02],
                        [  1.09771729e-01,   1.09069824e-01],
                        [  1.70776367e-01,   1.70135498e-01],
                        [  2.18750000e-01,   2.18780518e-01],
                        [  2.32849121e-01,   2.33489990e-01],
                        [  2.08557129e-01,   2.09228516e-01],
                        [  1.50085449e-01,   1.50115967e-01],
                        [  5.89294434e-02,   5.82885742e-02],
                        [ -6.05163574e-02,  -6.11877441e-02],
                        [ -1.88568115e-01,  -1.88659668e-01],
                        [ -2.92266846e-01,  -2.91656494e-01],
                        [ -3.40515137e-01,  -3.39813232e-01],
                        [ -3.23181152e-01,  -3.23059082e-01],
                        [ -2.61749268e-01,  -2.62329102e-01],
                        [ -1.98059082e-01,  -1.98791504e-01],
                        [ -1.61834717e-01,  -1.61987305e-01],
                        [ -1.48956299e-01,  -1.48406982e-01],
                        [ -1.34887695e-01,  -1.34155273e-01],
                        [ -1.04248047e-01,  -1.04034424e-01],
                        [ -6.21337891e-02,  -6.26220703e-02],
                        [ -1.91040039e-02,  -1.98669434e-02],
                        [  2.48107910e-02,   2.45666504e-02],
                        [  7.59887695e-02,   7.64465332e-02],
                        [  1.31225586e-01,   1.31988525e-01],
                        [  1.75720215e-01,   1.76025391e-01],
                        [  1.96624756e-01,   1.96166992e-01],
                        [  1.93054199e-01,   1.92291260e-01],
                        [  1.73583984e-01,   1.73217773e-01],
                        [  1.47827148e-01,   1.48223877e-01],
                        [  1.20574951e-01,   1.21337891e-01],
                        [  9.21630859e-02,   9.25598145e-02],
                        [  6.49719238e-02,   6.46057129e-02],
                        [  4.67224121e-02,   4.59594727e-02],
                        [  4.28161621e-02,   4.23889160e-02],
                        [  4.85534668e-02,   4.88586426e-02],
                        [  5.42297363e-02,   5.49926758e-02],
                        [  5.63964844e-02,   5.68542480e-02],
                        [  5.79833984e-02,   5.77392578e-02],
                        [  6.06079102e-02,   5.98754883e-02],
                        [  6.28967285e-02,   6.23779297e-02],
                        [  6.44531250e-02,   6.46667480e-02],
                        [  6.61621094e-02,   6.68945312e-02],
                        [  6.77490234e-02,   6.82983398e-02],
                        [  6.85729980e-02,   6.83898926e-02],
                        [  6.85119629e-02,   6.77795410e-02],
                        [  6.63757324e-02,   6.57958984e-02],
                        [  5.98144531e-02,   5.99365234e-02],
                        [  4.84008789e-02,   4.91027832e-02],
                        [  3.48205566e-02,   3.54309082e-02],
                        [  2.28576660e-02,   2.27661133e-02],
                        [  1.45874023e-02,   1.38854980e-02],
                        [  8.91113281e-03,   8.27026367e-03],
                        [  2.50244141e-03,   2.53295898e-03],
                        [ -6.25610352e-03,  -5.58471680e-03],
                        [ -1.49230957e-02,  -1.42822266e-02],
                        [ -2.01416016e-02,  -2.01110840e-02],
                        [ -2.13317871e-02,  -2.19726562e-02],
                        [ -1.91955566e-02,  -1.98669434e-02],
                        [ -1.24511719e-02,  -1.25122070e-02],
                        [ -1.77001953e-03,  -1.12915039e-03],
                        [  6.22558594e-03,   6.92749023e-03],
                        [  6.10351562e-03,   6.22558594e-03],
                        [  2.44140625e-03,   1.86157227e-03],
                        [  2.34985352e-03,   1.64794922e-03],
                        [  4.11987305e-03,   3.96728516e-03],
                        [  2.16674805e-03,   2.71606445e-03],
                        [ -1.49536133e-03,  -7.62939453e-04],
                        [ -1.06811523e-03,  -8.85009766e-04],
                        [  3.23486328e-03,   2.71606445e-03],
                        [  7.69042969e-03,   6.95800781e-03],
                        [  1.15661621e-02,   1.13220215e-02],
                        [  1.47705078e-02,   1.52587891e-02],
                        [  1.38244629e-02,   1.45874023e-02],
                        [  5.31005859e-03,   5.58471680e-03],
                        [ -8.48388672e-03,  -8.94165039e-03],
                        [ -2.02331543e-02,  -2.09960938e-02],
                        [ -2.35900879e-02,  -2.39562988e-02],
                        [ -1.83105469e-02,  -1.78833008e-02],
                        [ -9.82666016e-03,  -9.06372070e-03],
                        [ -4.66918945e-03,  -4.27246094e-03],
                        [ -5.43212891e-03,  -5.79833984e-03],
                        [ -1.08947754e-02,  -1.16577148e-02],
                        [ -1.86157227e-02,  -1.90429688e-02],
                        [ -2.54516602e-02,  -2.51159668e-02],
                        [ -2.70690918e-02,  -2.63061523e-02],
                        [ -2.13317871e-02,  -2.08740234e-02],
                        [ -1.13220215e-02,  -1.15966797e-02],
                        [ -1.52587891e-03,  -2.25830078e-03],
                        [  7.65991211e-03,   7.17163086e-03],
                        [  1.71813965e-02,   1.74255371e-02],
                        [  2.30712891e-02,   2.38037109e-02],
                        [  1.69372559e-02,   1.74865723e-02],
                        [ -7.32421875e-03,  -7.50732422e-03],
                        [ -4.85534668e-02,  -4.92858887e-02],
                        [ -9.73510742e-02,  -9.79003906e-02],
                        [ -1.38122559e-01,  -1.38000488e-01],
                        [ -1.55700684e-01,  -1.54968262e-01],
                        [ -1.43981934e-01,  -1.43402100e-01],
                        [ -1.11450195e-01,  -1.11541748e-01],
                        [ -7.59887695e-02,  -7.66906738e-02],
                        [ -5.15441895e-02,  -5.21545410e-02],
                        [ -3.86657715e-02,  -3.86047363e-02],
                        [ -2.91442871e-02,  -2.84729004e-02],
                        [ -1.66931152e-02,  -1.60522461e-02],
                        [  1.52587891e-04,   1.52587891e-04],
                        [  2.22473145e-02,   2.16064453e-02],
                        [  5.30395508e-02,   5.23681641e-02],
                        [  9.71984863e-02,   9.71374512e-02],
                        [  1.52618408e-01,   1.53228760e-01],
                        [  2.01812744e-01,   2.02514648e-01],
                        [  2.18200684e-01,   2.18292236e-01],
                        [  1.86767578e-01,   1.86157227e-01],
                        [  1.13372803e-01,   1.12670898e-01],
                        [  1.21459961e-02,   1.19934082e-02],
                        [ -1.05163574e-01,  -1.04583740e-01],
                        [ -2.21618652e-01,  -2.20886230e-01],
                        [ -3.08502197e-01,  -3.08288574e-01],
                        [ -3.38165283e-01,  -3.38714600e-01],
                        [ -3.07769775e-01,  -3.08502197e-01],
                        [ -2.46185303e-01,  -2.46429443e-01],
                        [ -1.91009521e-01,  -1.90521240e-01],
                        [ -1.56921387e-01,  -1.56158447e-01],
                        [ -1.31896973e-01,  -1.31622314e-01],
                        [ -1.02447510e-01,  -1.02905273e-01],
                        [ -6.94274902e-02,  -7.01904297e-02],
                        [ -3.76281738e-02,  -3.79333496e-02],
                        [ -2.80761719e-03,  -2.41088867e-03],
                        [  4.33044434e-02,   4.40673828e-02],
                        [  9.89990234e-02,   9.93652344e-02],
                        [  1.47918701e-01,   1.47521973e-01],
                        [  1.72698975e-01,   1.71936035e-01],
                        [  1.73065186e-01,   1.72637939e-01],
                        [  1.63757324e-01,   1.64093018e-01],
                        [  1.54449463e-01,   1.55212402e-01],
                        [  1.41662598e-01,   1.42120361e-01],
                        [  1.21063232e-01,   1.20758057e-01],
                        [  9.62524414e-02,   9.54895020e-02],
                        [  7.38220215e-02,   7.33337402e-02],
                        [  5.82580566e-02,   5.85021973e-02],
                        [  5.12695312e-02,   5.20019531e-02],
                        [  4.97131348e-02,   5.02319336e-02],
                        [  4.65698242e-02,   4.63562012e-02],
                        [  3.92150879e-02,   3.84826660e-02],
                        [  3.32031250e-02,   3.26538086e-02],
                        [  3.39660645e-02,   3.41186523e-02],
                        [  3.93676758e-02,   4.01000977e-02],
                        [  4.43420410e-02,   4.49523926e-02],
                        [  4.82482910e-02,   4.81262207e-02],
                        [  5.26428223e-02,   5.19409180e-02],
                        [  5.59387207e-02,   5.53283691e-02],
                        [  5.52978516e-02,   5.53588867e-02],
                        [  5.16967773e-02,   5.23681641e-02],
                        [  4.75769043e-02,   4.82177734e-02],
                        [  4.22363281e-02,   4.22058105e-02],
                        [  3.45153809e-02,   3.38745117e-02],
                        [  2.63977051e-02,   2.57263184e-02],
                        [  1.95922852e-02,   1.95617676e-02],
                        [  1.31530762e-02,   1.37939453e-02],
                        [  6.34765625e-03,   7.04956055e-03],
                        [ -5.49316406e-04,  -4.88281250e-04],
                        [ -8.39233398e-03,  -9.00268555e-03],
                        [ -1.61743164e-02,  -1.68762207e-02],
                        [ -1.90734863e-02,  -1.91955566e-02],
                        [ -1.47094727e-02,  -1.41296387e-02],
                        [ -7.59887695e-03,  -6.86645508e-03],
                        [ -2.68554688e-03,  -2.50244141e-03],
                        [ -7.93457031e-04,  -1.34277344e-03],
                        [ -2.19726562e-03,  -2.92968750e-03],
                        [ -7.04956055e-03,  -7.29370117e-03],
                        [ -1.19628906e-02,  -1.14440918e-02],
                        [ -1.22070312e-02,  -1.14746094e-02],
                        [ -7.44628906e-03,  -7.20214844e-03],
                        [ -9.76562500e-04,  -1.46484375e-03],
                        [  4.42504883e-03,   3.66210938e-03],
                        [  8.51440430e-03,   8.20922852e-03],
                        [  1.28784180e-02,   1.33056641e-02],
                        [  1.80358887e-02,   1.87988281e-02],
                        [  2.03247070e-02,   2.06909180e-02],
                        [  1.53198242e-02,   1.49230957e-02],
                        [  4.97436523e-03,   4.21142578e-03],
                        [ -2.80761719e-03,  -3.17382812e-03],
                        [ -3.96728516e-03,  -3.60107422e-03],
                        [ -4.18090820e-03,  -3.41796875e-03],
                        [ -1.16577148e-02,  -1.12304688e-02],
                        [ -2.65808105e-02,  -2.69165039e-02],
                        [ -4.08935547e-02,  -4.16564941e-02],
                        [ -4.78210449e-02,  -4.83093262e-02],
                        [ -4.79125977e-02,  -4.76379395e-02],
                        [ -4.50439453e-02,  -4.43115234e-02],
                        [ -4.08630371e-02,  -4.03747559e-02],
                        [ -3.43933105e-02,  -3.46069336e-02],
                        [ -2.52075195e-02,  -2.59704590e-02],
                        [ -1.41296387e-02,  -1.46789551e-02],
                        [ -9.15527344e-04,  -7.32421875e-04],
                        [  1.49536133e-02,   1.56555176e-02],
                        [  3.05480957e-02,   3.11279297e-02],
                        [  3.93676758e-02,   3.92456055e-02],
                        [  3.51257324e-02,   3.44238281e-02],
                        [  1.29394531e-02,   1.23291016e-02],
                        [ -3.00292969e-02,  -2.99377441e-02],
                        [ -8.73718262e-02,  -8.66699219e-02],
                        [ -1.38763428e-01,  -1.38122559e-01],
                        [ -1.61804199e-01,  -1.61834717e-01],
                        [ -1.49719238e-01,  -1.50390625e-01],
                        [ -1.14471436e-01,  -1.15142822e-01],
                        [ -7.48596191e-02,  -7.48901367e-02],
                        [ -4.58068848e-02,  -4.51660156e-02],
                        [ -3.32946777e-02,  -3.26232910e-02],
                        [ -3.20739746e-02,  -3.20129395e-02],
                        [ -2.88391113e-02,  -2.94494629e-02],
                        [ -1.21154785e-02,  -1.28173828e-02],
                        [  2.13012695e-02,   2.12097168e-02],
                        [  6.98547363e-02,   7.04345703e-02],
                        [  1.29638672e-01,   1.30371094e-01],
                        [  1.89270020e-01,   1.89422607e-01],
                        [  2.27600098e-01,   2.27050781e-01],
                        [  2.24975586e-01,   2.24243164e-01],
                        [  1.76086426e-01,   1.75872803e-01],
                        [  8.93859863e-02,   8.99047852e-02],
                        [ -2.36511230e-02,  -2.29187012e-02],
                        [ -1.51702881e-01,  -1.51458740e-01],
                        [ -2.72338867e-01,  -2.72827148e-01],
                        [ -3.48388672e-01,  -3.49151611e-01],
                        [ -3.53057861e-01,  -3.53332520e-01],
                        [ -3.00354004e-01,  -2.99896240e-01],
                        [ -2.36907959e-01,  -2.36145020e-01],
                        [ -1.98577881e-01,  -1.98242188e-01],
                        [ -1.82495117e-01,  -1.82891846e-01],
                        [ -1.62597656e-01,  -1.63360596e-01],
                        [ -1.22894287e-01,  -1.23291016e-01],
                        [ -6.86950684e-02,  -6.83288574e-02],
                        [ -1.07421875e-02,  -9.97924805e-03],
                        [  4.85229492e-02,   4.89501953e-02],
                        [  1.08276367e-01,   1.07940674e-01],
                        [  1.58203125e-01,   1.57470703e-01],
                        [  1.85211182e-01,   1.84753418e-01],
                        [  1.87774658e-01,   1.88079834e-01],
                        [  1.77215576e-01,   1.77947998e-01],
                        [  1.64398193e-01,   1.64886475e-01],
                        [  1.49566650e-01,   1.49322510e-01],
                        [  1.26739502e-01,   1.25976562e-01],
                        [  9.70458984e-02,   9.64965820e-02],
                        [  7.19604492e-02,   7.21740723e-02],
                        [  6.01501465e-02,   6.08825684e-02],
                        [  5.66711426e-02,   5.72509766e-02],
                        [  5.05981445e-02,   5.04760742e-02],
                        [  3.89709473e-02,   3.82690430e-02],
                        [  2.78320312e-02,   2.72216797e-02],
                        [  2.26745605e-02,   2.27661133e-02],
                        [  2.38037109e-02,   2.45056152e-02],
                        [  2.99072266e-02,   3.05175781e-02],
                        [  4.04968262e-02,   4.04663086e-02],
                        [  5.36193848e-02,   5.29479980e-02],
                        [  6.54907227e-02,   6.48498535e-02],
                        [  7.33642578e-02,   7.33642578e-02],
                        [  7.59582520e-02,   7.65991211e-02],
                        [  7.20825195e-02,   7.27844238e-02],
                        [  6.20422363e-02,   6.21032715e-02],
                        [  4.88586426e-02,   4.82177734e-02],
                        [  3.62854004e-02,   3.55834961e-02],
                        [  2.67333984e-02,   2.66113281e-02],
                        [  2.08740234e-02,   2.14538574e-02],
                        [  1.76696777e-02,   1.83715820e-02],
                        [  1.44348145e-02,   1.45874023e-02],
                        [  8.30078125e-03,   7.72094727e-03],
                        [ -1.43432617e-03,  -2.16674805e-03],
                        [ -1.22070312e-02,  -1.24206543e-02],
                        [ -2.08129883e-02,  -2.02941895e-02],
                        [ -2.57263184e-02,  -2.49633789e-02],
                        [ -2.52685547e-02,  -2.50244141e-02],
                        [ -1.69677734e-02,  -1.74560547e-02],
                        [ -2.99072266e-03,  -3.75366211e-03],
                        [  6.71386719e-03,   6.43920898e-03],
                        [  5.09643555e-03,   5.55419922e-03],
                        [ -1.25122070e-03,  -4.88281250e-04],
                        [ -7.62939453e-04,  -4.57763672e-04],
                        [  6.25610352e-03,   5.82885742e-03],
                        [  1.05590820e-02,   9.79614258e-03],
                        [  1.09558105e-02,   1.05895996e-02],
                        [  1.48010254e-02,   1.51672363e-02],
                        [  2.15454102e-02,   2.23083496e-02],
                        [  2.10876465e-02,   2.15148926e-02],
                        [  1.05590820e-02,   1.02233887e-02],
                        [ -9.15527344e-04,  -1.67846680e-03],
                        [ -6.37817383e-03,  -6.83593750e-03],
                        [ -9.06372070e-03,  -8.78906250e-03],
                        [ -1.46484375e-02,  -1.38854980e-02],
                        [ -2.28271484e-02,  -2.23388672e-02],
                        [ -2.90527344e-02,  -2.92968750e-02],
                        [ -3.04870605e-02,  -3.12500000e-02],
                        [ -2.85949707e-02,  -2.91442871e-02],
                        [ -2.61230469e-02,  -2.59399414e-02],
                        [ -2.41699219e-02,  -2.34375000e-02],
                        [ -2.34069824e-02,  -2.28576660e-02],
                        [ -2.44750977e-02,  -2.46276855e-02],
                        [ -2.55126953e-02,  -2.62145996e-02],
                        [ -2.31323242e-02,  -2.37121582e-02],
                        [ -1.69067383e-02,  -1.67846680e-02],
                        [ -8.23974609e-03,  -7.53784180e-03],
                        [  2.92968750e-03,   3.57055664e-03],
                        [  1.55944824e-02,   1.55334473e-02],
                        [  2.42309570e-02,   2.35595703e-02],
                        [  2.39562988e-02,   2.33154297e-02],
                        [  1.48010254e-02,   1.48010254e-02],
                        [ -2.83813477e-03,  -2.16674805e-03],
                        [ -3.20739746e-02,  -3.14025879e-02],
                        [ -7.11669922e-02,  -7.11364746e-02],
                        [ -1.06292725e-01,  -1.06933594e-01],
                        [ -1.22802734e-01,  -1.23474121e-01],
                        [ -1.19903564e-01,  -1.19995117e-01],
                        [ -1.06353760e-01,  -1.05743408e-01],
                        [ -8.91113281e-02,  -8.84094238e-02],
                        [ -7.40051270e-02,  -7.38830566e-02],
                        [ -6.57348633e-02,  -6.63146973e-02],
                        [ -5.85632324e-02,  -5.92651367e-02],
                        [ -3.72619629e-02,  -3.74145508e-02],
                        [  5.46264648e-03,   5.98144531e-03],
                        [  6.16455078e-02,   6.23779297e-02],
                        [  1.21032715e-01,   1.21246338e-01],
                        [  1.78924561e-01,   1.78405762e-01],
                        [  2.25769043e-01,   2.25036621e-01],
                        [  2.40936279e-01,   2.40661621e-01],
                        [  2.07214355e-01,   2.07672119e-01],
                        [  1.26739502e-01,   1.27502441e-01],
                        [  1.37939453e-02,   1.40991211e-02],
                        [ -1.18377686e-01,  -1.18804932e-01],
                        [ -2.49969482e-01,  -2.50732422e-01],
                        [ -3.44024658e-01,  -3.44390869e-01],
                        [ -3.67340088e-01,  -3.66943359e-01],
                        [ -3.26019287e-01,  -3.25256348e-01],
                        [ -2.62969971e-01,  -2.62573242e-01],
                        [ -2.14843750e-01,  -2.15209961e-01],
                        [ -1.85211182e-01,  -1.85974121e-01],
                        [ -1.58874512e-01,  -1.59301758e-01],
                        [ -1.24572754e-01,  -1.24267578e-01],
                        [ -7.77893066e-02,  -7.70263672e-02],
                        [ -1.73339844e-02,  -1.68457031e-02],
                        [  5.01403809e-02,   4.98962402e-02],
                        [  1.09466553e-01,   1.08703613e-01],
                        [  1.48559570e-01,   1.48040771e-01],
                        [  1.67999268e-01,   1.68212891e-01],
                        [  1.75933838e-01,   1.76666260e-01],
                        [  1.77886963e-01,   1.78405762e-01],
                        [  1.73309326e-01,   1.73126221e-01],
                        [  1.58325195e-01,   1.57623291e-01],
                        [  1.31378174e-01,   1.30798340e-01],
                        [  9.96093750e-02,   9.97314453e-02],
                        [  7.72094727e-02,   7.79113770e-02],
                        [  7.12585449e-02,   7.18688965e-02],
                        [  7.28149414e-02,   7.27233887e-02],
                        [  6.71691895e-02,   6.64978027e-02],
                        [  5.14831543e-02,   5.08422852e-02],
                        [  3.43322754e-02,   3.43627930e-02],
                        [  2.26440430e-02,   2.33154297e-02],
                        [  1.76086426e-02,   1.82495117e-02],
                        [  2.02636719e-02,   2.02636719e-02],
                        [  3.11889648e-02,   3.05480957e-02],
                        [  4.58984375e-02,   4.52270508e-02],
                        [  5.87158203e-02,   5.86547852e-02],
                        [  6.85424805e-02,   6.91223145e-02],
                        [  7.47985840e-02,   7.55004883e-02],
                        [  7.23876953e-02,   7.24792480e-02],
                        [  5.94177246e-02,   5.88378906e-02],
                        [  4.55322266e-02,   4.48303223e-02],
                        [  4.06188965e-02,   4.04663086e-02],
                        [  4.00085449e-02,   4.05578613e-02],
                        [  3.21655273e-02,   3.28979492e-02],
                        [  1.67541504e-02,   1.69677734e-02],
                        [  2.44140625e-03,   1.92260742e-03],
                        [ -6.59179688e-03,  -7.32421875e-03],
                        [ -1.18713379e-02,  -1.21154785e-02],
                        [ -1.43127441e-02,  -1.38244629e-02],
                        [ -1.43127441e-02,  -1.35803223e-02],
                        [ -1.36108398e-02,  -1.33361816e-02],
                        [ -1.27563477e-02,  -1.31835938e-02],
                        [ -9.61303711e-03,  -1.03454590e-02],
                        [ -2.25830078e-03,  -2.59399414e-03],
                        [  7.32421875e-03,   7.72094727e-03],
                        [  1.33972168e-02,   1.41601562e-02],
                        [  1.16882324e-02,   1.20544434e-02],
                        [  4.30297852e-03,   3.96728516e-03],
                        [ -1.73950195e-03,  -2.50244141e-03],
                        [ -2.22778320e-03,  -2.65502930e-03],
                        [  1.15966797e-03,   1.46484375e-03],
                        [  5.00488281e-03,   5.73730469e-03],
                        [  7.50732422e-03,   7.96508789e-03],
                        [  7.08007812e-03,   6.80541992e-03],
                        [  2.83813477e-03,   2.10571289e-03],
                        [ -2.16674805e-03,  -2.65502930e-03],
                        [ -3.60107422e-03,  -3.38745117e-03],
                        [ -3.17382812e-03,  -2.44140625e-03],
                        [ -6.46972656e-03,  -5.95092773e-03],
                        [ -1.30920410e-02,  -1.32446289e-02],
                        [ -1.72119141e-02,  -1.79138184e-02],
                        [ -1.88903809e-02,  -1.94702148e-02],
                        [ -2.39562988e-02,  -2.38342285e-02],
                        [ -3.20434570e-02,  -3.13415527e-02],
                        [ -3.60717773e-02,  -3.54614258e-02],
                        [ -3.44848633e-02,  -3.45764160e-02],
                        [ -3.31115723e-02,  -3.37829590e-02],
                        [ -3.41796875e-02,  -3.47900391e-02],
                        [ -3.35388184e-02,  -3.35083008e-02],
                        [ -2.88391113e-02,  -2.81982422e-02],
                        [ -2.22778320e-02,  -2.16674805e-02],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -8.30078125e-03,  -8.91113281e-03],
                        [  2.13623047e-03,   1.49536133e-03],
                        [  1.45568848e-02,   1.45263672e-02],
                        [  2.43225098e-02,   2.49328613e-02],
                        [  2.45971680e-02,   2.52990723e-02],
                        [  9.18579102e-03,   9.27734375e-03],
                        [ -2.46582031e-02,  -2.52380371e-02],
                        [ -7.22045898e-02,  -7.28759766e-02],
                        [ -1.17340088e-01,  -1.17492676e-01],
                        [ -1.39160156e-01,  -1.38610840e-01],
                        [ -1.29516602e-01,  -1.28814697e-01],
                        [ -1.02996826e-01,  -1.02813721e-01],
                        [ -8.31909180e-02,  -8.37097168e-02],
                        [ -7.82165527e-02,  -7.89489746e-02],
                        [ -7.31811523e-02,  -7.33947754e-02],
                        [ -4.94079590e-02,  -4.89196777e-02],
                        [ -6.34765625e-03,  -5.61523438e-03],
                        [  4.37927246e-02,   4.40673828e-02],
                        [  9.57031250e-02,   9.52758789e-02],
                        [  1.51428223e-01,   1.50726318e-01],
                        [  2.03674316e-01,   2.03369141e-01],
                        [  2.32971191e-01,   2.33367920e-01],
                        [  2.21466064e-01,   2.22198486e-01],
                        [  1.62475586e-01,   1.62841797e-01],
                        [  5.97839355e-02,   5.94177246e-02],
                        [ -7.25708008e-02,  -7.33032227e-02],
                        [ -2.08984375e-01,  -2.09381104e-01],
                        [ -3.15399170e-01,  -3.15093994e-01],
                        [ -3.62182617e-01,  -3.61480713e-01],
                        [ -3.42285156e-01,  -3.41857910e-01],
                        [ -2.79876709e-01,  -2.80181885e-01],
                        [ -2.15637207e-01,  -2.16339111e-01],
                        [ -1.77124023e-01,  -1.77612305e-01],
                        [ -1.60949707e-01,  -1.60705566e-01],
                        [ -1.42303467e-01,  -1.41601562e-01],
                        [ -1.02783203e-01,  -1.02294922e-01],
                        [ -4.53796387e-02,  -4.55932617e-02],
                        [  1.69067383e-02,   1.62048340e-02],
                        [  7.58056641e-02,   7.52868652e-02],
                        [  1.25457764e-01,   1.25610352e-01],
                        [  1.58081055e-01,   1.58752441e-01],
                        [  1.73034668e-01,   1.73583984e-01],
                        [  1.80297852e-01,   1.80206299e-01],
                        [  1.85211182e-01,   1.84539795e-01],
                        [  1.79290771e-01,   1.78680420e-01],
                        [  1.54785156e-01,   1.54846191e-01],
                        [  1.19781494e-01,   1.20452881e-01],
                        [  8.98742676e-02,   9.04846191e-02],
                        [  7.07397461e-02,   7.07092285e-02],
                        [  5.64575195e-02,   5.58471680e-02],
                        [  4.11682129e-02,   4.05273438e-02],
                        [  2.57873535e-02,   2.57568359e-02],
                        [  1.63574219e-02,   1.69677734e-02],
                        [  1.76086426e-02,   1.82800293e-02],
                        [  2.77404785e-02,   2.78015137e-02],
                        [  4.03747559e-02,   3.97949219e-02],
                        [  5.10559082e-02,   5.03845215e-02],
                        [  5.87463379e-02,   5.86242676e-02],
                        [  6.39648438e-02,   6.45141602e-02],
                        [  6.79626465e-02,   6.86340332e-02],
                        [  7.04956055e-02,   7.06481934e-02],
                        [  6.91223145e-02,   6.86035156e-02],
                        [  6.29577637e-02,   6.22558594e-02],
                        [  5.47790527e-02,   5.45654297e-02],
                        [  4.75463867e-02,   4.80041504e-02],
                        [  4.10461426e-02,   4.17480469e-02],
                        [  3.25317383e-02,   3.28063965e-02],
                        [  1.97753906e-02,   1.93176270e-02],
                        [  4.08935547e-03,   3.38745117e-03],
                        [ -8.69750977e-03,  -9.00268555e-03],
                        [ -1.36413574e-02,  -1.32446289e-02],
                        [ -1.25732422e-02,  -1.18408203e-02],
                        [ -1.11999512e-02,  -1.08642578e-02],
                        [ -1.19018555e-02,  -1.22375488e-02],
                        [ -1.25122070e-02,  -1.32141113e-02],
                        [ -1.07727051e-02,  -1.11694336e-02],
                        [ -6.83593750e-03,  -6.53076172e-03],
                        [ -2.19726562e-03,  -1.49536133e-03],
                        [  2.25830078e-03,   2.65502930e-03],
                        [  6.65283203e-03,   6.34765625e-03],
                        [  1.00708008e-02,   9.36889648e-03],
                        [  1.02233887e-02,   9.79614258e-03],
                        [  7.29370117e-03,   7.53784180e-03],
                        [  5.92041016e-03,   6.62231445e-03],
                        [  9.15527344e-03,   9.61303711e-03],
                        [  1.36108398e-02,   1.33972168e-02],
                        [  1.46789551e-02,   1.40075684e-02],
                        [  1.24206543e-02,   1.19018555e-02],
                        [  9.27734375e-03,   9.42993164e-03],
                        [  5.79833984e-03,   6.46972656e-03],
                        [  1.31225586e-03,   1.83105469e-03],
                        [ -4.60815430e-03,  -4.73022461e-03],
                        [ -1.22375488e-02,  -1.28784180e-02],
                        [ -2.05383301e-02,  -2.10876465e-02],
                        [ -2.66723633e-02,  -2.66113281e-02],
                        [ -3.02429199e-02,  -2.96325684e-02],
                        [ -3.37219238e-02,  -3.31420898e-02],
                        [ -3.57971191e-02,  -3.57971191e-02],
                        [ -3.10974121e-02,  -3.16772461e-02],
                        [ -2.00195312e-02,  -2.05993652e-02],
                        [ -1.19934082e-02,  -1.20239258e-02],
                        [ -1.55334473e-02,  -1.49536133e-02],
                        [ -2.70080566e-02,  -2.63977051e-02],
                        [ -3.41491699e-02,  -3.40881348e-02],
                        [ -3.02429199e-02,  -3.07922363e-02],
                        [ -1.83105469e-02,  -1.89514160e-02],
                        [ -1.92260742e-03,  -2.01416016e-03],
                        [  1.79138184e-02,   1.84326172e-02],
                        [  3.43627930e-02,   3.50036621e-02],
                        [  3.46984863e-02,   3.48510742e-02],
                        [  1.28784180e-02,   1.23901367e-02],
                        [ -2.56652832e-02,  -2.63366699e-02],
                        [ -7.20214844e-02,  -7.22045898e-02],
                        [ -1.15692139e-01,  -1.15234375e-01],
                        [ -1.40258789e-01,  -1.39587402e-01],
                        [ -1.31866455e-01,  -1.31652832e-01],
                        [ -9.69543457e-02,  -9.73815918e-02],
                        [ -6.12487793e-02,  -6.19201660e-02],
                        [ -4.49218750e-02,  -4.51965332e-02],
                        [ -4.41894531e-02,  -4.37927246e-02],
                        [ -3.97033691e-02,  -3.90319824e-02],
                        [ -1.74560547e-02,  -1.71508789e-02],
                        [  2.29492188e-02,   2.25830078e-02],
                        [  7.47985840e-02,   7.41271973e-02],
                        [  1.30462646e-01,   1.30126953e-01],
                        [  1.80236816e-01,   1.80572510e-01],
                        [  2.11059570e-01,   2.11730957e-01],
                        [  2.10144043e-01,   2.10510254e-01],
                        [  1.69372559e-01,   1.69097900e-01],
                        [  8.64257812e-02,   8.57543945e-02],
                        [ -3.28369141e-02,  -3.32336426e-02],
                        [ -1.68640137e-01,  -1.68395996e-01],
                        [ -2.86529541e-01,  -2.85858154e-01],
                        [ -3.50738525e-01,  -3.50311279e-01],
                        [ -3.47412109e-01,  -3.47595215e-01],
                        [ -2.95806885e-01,  -2.96478271e-01],
                        [ -2.34375000e-01,  -2.34863281e-01],
                        [ -1.91711426e-01,  -1.91558838e-01],
                        [ -1.68945312e-01,  -1.68334961e-01],
                        [ -1.47308350e-01,  -1.46820068e-01],
                        [ -1.08551025e-01,  -1.08673096e-01],
                        [ -4.87976074e-02,  -4.94384766e-02],
                        [  2.09045410e-02,   2.03857422e-02],
                        [  8.44726562e-02,   8.45642090e-02],
                        [  1.30493164e-01,   1.31072998e-01],
                        [  1.54418945e-01,   1.54968262e-01],
                        [  1.59210205e-01,   1.59179688e-01],
                        [  1.56372070e-01,   1.55792236e-01],
                        [  1.56921387e-01,   1.56372070e-01],
                        [  1.57470703e-01,   1.57470703e-01],
                        [  1.44287109e-01,   1.44836426e-01],
                        [  1.15386963e-01,   1.15966797e-01],
                        [  8.70361328e-02,   8.70666504e-02],
                        [  7.15942383e-02,   7.10754395e-02],
                        [  6.22863770e-02,   6.17065430e-02],
                        [  4.80346680e-02,   4.79431152e-02],
                        [  3.15246582e-02,   3.20129395e-02],
                        [  2.29187012e-02,   2.35290527e-02],
                        [  2.33459473e-02,   2.34680176e-02],
                        [  2.53601074e-02,   2.49023438e-02],
                        [  2.68249512e-02,   2.62145996e-02],
                        [  3.33862305e-02,   3.32336426e-02],
                        [  4.69055176e-02,   4.73327637e-02],
                        [  6.11572266e-02,   6.17980957e-02],
                        [  7.14111328e-02,   7.16247559e-02],
                        [  7.83386230e-02,   7.79418945e-02],
                        [  8.21228027e-02,   8.15124512e-02],
                        [  8.13598633e-02,   8.11157227e-02],
                        [  7.69042969e-02,   7.72705078e-02],
                        [  6.97631836e-02,   7.03735352e-02],
                        [  5.78918457e-02,   5.81665039e-02],
                        [  4.08020020e-02,   4.04357910e-02],
                        [  2.25219727e-02,   2.19116211e-02],
                        [  7.99560547e-03,   7.69042969e-03],
                        [ -1.19018555e-03,  -8.85009766e-04],
                        [ -7.50732422e-03,  -6.86645508e-03],
                        [ -1.59606934e-02,  -1.56250000e-02],
                        [ -2.93273926e-02,  -2.96020508e-02],
                        [ -4.29687500e-02,  -4.35791016e-02],
                        [ -4.61120605e-02,  -4.65087891e-02],
                        [ -3.32336426e-02,  -3.30200195e-02],
                        [ -1.21765137e-02,  -1.15661621e-02],
                        [  3.35693359e-03,   3.75366211e-03],
                        [  7.29370117e-03,   7.11059570e-03],
                        [  4.51660156e-03,   3.90625000e-03],
                        [  2.80761719e-03,   2.38037109e-03],
                        [  5.79833984e-03,   5.98144531e-03],
                        [  1.25732422e-02,   1.31835938e-02],
                        [  1.95007324e-02,   1.99279785e-02],
                        [  2.12707520e-02,   2.11486816e-02],
                        [  1.61132812e-02,   1.55334473e-02],
                        [  9.15527344e-03,   8.66699219e-03],
                        [  5.82885742e-03,   5.92041016e-03],
                        [  4.91333008e-03,   5.46264648e-03],
                        [  2.44140625e-03,   2.92968750e-03],
                        [ -2.53295898e-03,  -2.59399414e-03],
                        [ -8.85009766e-03,  -9.39941406e-03],
                        [ -1.58996582e-02,  -1.64184570e-02],
                        [ -2.29797363e-02,  -2.29797363e-02],
                        [ -2.85034180e-02,  -2.79846191e-02],
                        [ -3.08532715e-02,  -3.03039551e-02],
                        [ -2.92663574e-02,  -2.92358398e-02],
                        [ -2.49328613e-02,  -2.54211426e-02],
                        [ -2.09350586e-02,  -2.14538574e-02],
                        [ -1.90734863e-02,  -1.91345215e-02],
                        [ -1.82800293e-02,  -1.77917480e-02],
                        [ -1.79138184e-02,  -1.73645020e-02],
                        [ -1.98364258e-02,  -1.97143555e-02],
                        [ -2.32543945e-02,  -2.36816406e-02],
                        [ -2.14233398e-02,  -2.19726562e-02],
                        [ -9.18579102e-03,  -9.30786133e-03],
                        [  8.78906250e-03,   9.21630859e-03],
                        [  2.28881836e-02,   2.34375000e-02],
                        [  2.79235840e-02,   2.81066895e-02],
                        [  2.31933594e-02,   2.28271484e-02],
                        [  6.77490234e-03,   6.22558594e-03],
                        [ -2.47497559e-02,  -2.49633789e-02],
                        [ -6.89392090e-02,  -6.85729980e-02],
                        [ -1.13128662e-01,  -1.12548828e-01],
                        [ -1.40991211e-01,  -1.40747070e-01],
                        [ -1.41143799e-01,  -1.41479492e-01],
                        [ -1.13494873e-01,  -1.14074707e-01],
                        [ -7.31811523e-02,  -7.34558105e-02],
                        [ -4.10766602e-02,  -4.08020020e-02],
                        [ -2.46276855e-02,  -2.40783691e-02],
                        [ -1.32446289e-02,  -1.29394531e-02],
                        [  6.86645508e-03,   6.59179688e-03],
                        [  3.90930176e-02,   3.85131836e-02],
                        [  7.86132812e-02,   7.83081055e-02],
                        [  1.21459961e-01,   1.21704102e-01],
                        [  1.64062500e-01,   1.64611816e-01],
                        [  1.94641113e-01,   1.95007324e-01],
                        [  1.93542480e-01,   1.93359375e-01],
                        [  1.47186279e-01,   1.46636963e-01],
                        [  5.83190918e-02,   5.79528809e-02],
                        [ -5.91125488e-02,  -5.89599609e-02],
                        [ -1.85974121e-01,  -1.85424805e-01],
                        [ -2.94158936e-01,  -2.93762207e-01],
                        [ -3.49700928e-01,  -3.49822998e-01],
                        [ -3.35784912e-01,  -3.36303711e-01],
                        [ -2.74475098e-01,  -2.74902344e-01],
                        [ -2.13897705e-01,  -2.13806152e-01],
                        [ -1.85272217e-01,  -1.84753418e-01],
                        [ -1.77368164e-01,  -1.76910400e-01],
                        [ -1.56799316e-01,  -1.56860352e-01],
                        [ -1.04888916e-01,  -1.05407715e-01],
                        [ -2.96630859e-02,  -3.00903320e-02],
                        [  4.87976074e-02,   4.87976074e-02],
                        [  1.12945557e-01,   1.13433838e-01],
                        [  1.52130127e-01,   1.52618408e-01],
                        [  1.65588379e-01,   1.65618896e-01],
                        [  1.64733887e-01,   1.64276123e-01],
                        [  1.63269043e-01,   1.62780762e-01],
                        [  1.63391113e-01,   1.63330078e-01],
                        [  1.55914307e-01,   1.56341553e-01],
                        [  1.33575439e-01,   1.34094238e-01],
                        [  1.01959229e-01,   1.02050781e-01],
                        [  7.40051270e-02,   7.35778809e-02],
                        [  5.58166504e-02,   5.53283691e-02],
                        [  4.36401367e-02,   4.35485840e-02],
                        [  3.30810547e-02,   3.34472656e-02],
                        [  2.45361328e-02,   2.50549316e-02],
                        [  2.02331543e-02,   2.03857422e-02],
                        [  2.13623047e-02,   2.09960938e-02],
                        [  2.81677246e-02,   2.76489258e-02],
                        [  3.93676758e-02,   3.91845703e-02],
                        [  5.17578125e-02,   5.20629883e-02],
                        [  6.23779297e-02,   6.28967285e-02],
                        [  6.99768066e-02,   7.01904297e-02],
                        [  7.37915039e-02,   7.34863281e-02],
                        [  7.34252930e-02,   7.29064941e-02],
                        [  6.93359375e-02,   6.91223145e-02],
                        [  6.28051758e-02,   6.30493164e-02],
                        [  5.46264648e-02,   5.51147461e-02],
                        [  4.44335938e-02,   4.46777344e-02],
                        [  3.20434570e-02,   3.17993164e-02],
                        [  2.02331543e-02,   1.97448730e-02],
                        [  1.27258301e-02,   1.24511719e-02],
                        [  8.23974609e-03,   8.45336914e-03],
                        [  1.37329102e-03,   1.86157227e-03],
                        [ -7.96508789e-03,  -7.65991211e-03],
                        [ -1.38854980e-02,  -1.40686035e-02],
                        [ -1.50146484e-02,  -1.55029297e-02],
                        [ -1.43127441e-02,  -1.46179199e-02],
                        [ -1.12609863e-02,  -1.11083984e-02],
                        [ -5.49316406e-03,  -5.03540039e-03],
                        [ -1.09863281e-03,  -7.32421875e-04],
                        [  3.05175781e-05,  -9.15527344e-05],
                        [  4.57763672e-04,   0.00000000e+00],
                        [  8.54492188e-04,   5.18798828e-04],
                        [  6.10351562e-05,   1.52587891e-04],
                        [  4.88281250e-04,   9.46044922e-04],
                        [  7.26318359e-03,   7.62939453e-03],
                        [  1.99584961e-02,   1.98974609e-02],
                        [  3.07922363e-02,   3.03649902e-02],
                        [  3.28063965e-02,   3.24096680e-02],
                        [  2.66418457e-02,   2.66723633e-02],
                        [  1.66320801e-02,   1.70593262e-02],
                        [  4.54711914e-03,   4.94384766e-03],
                        [ -9.15527344e-03,  -9.15527344e-03],
                        [ -1.98974609e-02,  -2.02941895e-02],
                        [ -2.30102539e-02,  -2.34069824e-02],
                        [ -2.24304199e-02,  -2.24609375e-02],
                        [ -2.60925293e-02,  -2.56958008e-02],
                        [ -3.27148438e-02,  -3.22875977e-02],
                        [ -3.43017578e-02,  -3.42407227e-02],
                        [ -3.05480957e-02,  -3.09143066e-02],
                        [ -2.76184082e-02,  -2.80456543e-02],
                        [ -2.53906250e-02,  -2.54821777e-02],
                        [ -2.07519531e-02,  -2.04162598e-02],
                        [ -1.73950195e-02,  -1.69677734e-02],
                        [ -1.98974609e-02,  -1.97753906e-02],
                        [ -2.47192383e-02,  -2.50244141e-02],
                        [ -2.41699219e-02,  -2.45971680e-02],
                        [ -1.53503418e-02,  -1.55029297e-02],
                        [ -2.74658203e-03,  -2.44140625e-03],
                        [  8.63647461e-03,   9.06372070e-03],
                        [  1.98669434e-02,   2.00500488e-02],
                        [  3.24401855e-02,   3.21960449e-02],
                        [  3.87573242e-02,   3.83300781e-02],
                        [  2.74963379e-02,   2.73132324e-02],
                        [ -3.90625000e-03,  -3.66210938e-03],
                        [ -4.84008789e-02,  -4.79736328e-02],
                        [ -9.60693359e-02,  -9.58557129e-02],
                        [ -1.33880615e-01,  -1.34094238e-01],
                        [ -1.46942139e-01,  -1.47369385e-01],
                        [ -1.30981445e-01,  -1.31225586e-01],
                        [ -9.79003906e-02,  -9.77172852e-02],
                        [ -6.31408691e-02,  -6.27136230e-02],
                        [ -3.49426270e-02,  -3.46984863e-02],
                        [ -1.36108398e-02,  -1.37634277e-02],
                        [  8.33129883e-03,   7.90405273e-03],
                        [  4.15344238e-02,   4.12597656e-02],
                        [  8.90808105e-02,   8.92333984e-02],
                        [  1.41784668e-01,   1.42211914e-01],
                        [  1.85272217e-01,   1.85546875e-01],
                        [  2.06268311e-01,   2.06176758e-01],
                        [  1.91772461e-01,   1.91375732e-01],
                        [  1.30615234e-01,   1.30310059e-01],
                        [  2.23999023e-02,   2.24914551e-02],
                        [ -1.15875244e-01,  -1.15509033e-01],
                        [ -2.52716064e-01,  -2.52410889e-01],
                        [ -3.50189209e-01,  -3.50250244e-01],
                        [ -3.78753662e-01,  -3.79150391e-01],
                        [ -3.38073730e-01,  -3.38409424e-01],
                        [ -2.64434814e-01,  -2.64404297e-01],
                        [ -2.05352783e-01,  -2.04986572e-01],
                        [ -1.79809570e-01,  -1.79443359e-01],
                        [ -1.66625977e-01,  -1.66625977e-01],
                        [ -1.32263184e-01,  -1.32598877e-01],
                        [ -6.47888184e-02,  -6.51550293e-02],
                        [  2.00805664e-02,   2.00805664e-02],
                        [  9.72900391e-02,   9.76257324e-02],
                        [  1.48254395e-01,   1.48620605e-01],
                        [  1.68090820e-01,   1.68151855e-01],
                        [  1.67938232e-01,   1.67633057e-01],
                        [  1.64154053e-01,   1.63787842e-01],
                        [  1.61590576e-01,   1.61529541e-01],
                        [  1.54571533e-01,   1.54846191e-01],
                        [  1.39251709e-01,   1.39617920e-01],
                        [  1.17309570e-01,   1.17401123e-01],
                        [  9.10644531e-02,   9.08203125e-02],
                        [  6.16760254e-02,   6.13098145e-02],
                        [  3.21960449e-02,   3.20739746e-02],
                        [  9.27734375e-03,   9.52148438e-03],
                        [ -1.49536133e-03,  -1.12915039e-03],
                        [ -1.22070312e-04,   0.00000000e+00],
                        [  1.01318359e-02,   9.91821289e-03],
                        [  2.74963379e-02,   2.71301270e-02],
                        [  5.04150391e-02,   5.02624512e-02],
                        [  7.31201172e-02,   7.33337402e-02],
                        [  8.80126953e-02,   8.83789062e-02],
                        [  9.26818848e-02,   9.28344727e-02],
                        [  8.99658203e-02,   8.97827148e-02],
                        [  8.30383301e-02,   8.26721191e-02],
                        [  7.25097656e-02,   7.22961426e-02],
                        [  5.79223633e-02,   5.80749512e-02],
                        [  4.11987305e-02,   4.15649414e-02],
                        [  2.72827148e-02,   2.74658203e-02],
                        [  1.94091797e-02,   1.92565918e-02],
                        [  1.54418945e-02,   1.51062012e-02],
                        [  1.07727051e-02,   1.05590820e-02],
                        [  4.45556641e-03,   4.54711914e-03],
                        [ -5.49316406e-04,  -2.13623047e-04],
                        [ -3.44848633e-03,  -3.20434570e-03],
                        [ -7.44628906e-03,  -7.53784180e-03],
                        [ -1.35498047e-02,  -1.38549805e-02],
                        [ -1.82800293e-02,  -1.85241699e-02],
                        [ -1.87988281e-02,  -1.87377930e-02],
                        [ -1.55029297e-02,  -1.51672363e-02],
                        [ -9.61303711e-03,  -9.36889648e-03],
                        [ -1.86157227e-03,  -1.92260742e-03],
                        [  7.01904297e-03,   6.68334961e-03],
                        [  1.58691406e-02,   1.56250000e-02],
                        [  2.24304199e-02,   2.24609375e-02],
                        [  2.51770020e-02,   2.54516602e-02],
                        [  2.71301270e-02,   2.74047852e-02],
                        [  3.06701660e-02,   3.06701660e-02],
                        [  3.07312012e-02,   3.04565430e-02],
                        [  2.26440430e-02,   2.23693848e-02],
                        [  9.36889648e-03,   9.36889648e-03],
                        [ -4.57763672e-03,  -4.30297852e-03],
                        [ -1.73645020e-02,  -1.70898438e-02],
                        [ -2.67639160e-02,  -2.67333984e-02],
                        [ -2.99682617e-02,  -3.02124023e-02],
                        [ -2.78625488e-02,  -2.81677246e-02],
                        [ -2.40173340e-02,  -2.40783691e-02],
                        [ -2.04467773e-02,  -2.02331543e-02],
                        [ -1.80053711e-02,  -1.77001953e-02],
                        [ -1.74255371e-02,  -1.73645020e-02],
                        [ -1.59301758e-02,  -1.61743164e-02],
                        [ -9.64355469e-03,  -9.94873047e-03],
                        [ -1.98364258e-03,  -2.07519531e-03],
                        [ -9.15527344e-04,  -7.32421875e-04],
                        [ -7.41577148e-03,  -7.11059570e-03],
                        [ -1.57470703e-02,  -1.56555176e-02],
                        [ -2.42309570e-02,  -2.44140625e-02],
                        [ -3.51562500e-02,  -3.54309082e-02],
                        [ -4.51354980e-02,  -4.52575684e-02],
                        [ -4.59594727e-02,  -4.58068848e-02],
                        [ -3.55224609e-02,  -3.52172852e-02],
                        [ -1.81579590e-02,  -1.80358887e-02],
                        [  2.71606445e-03,   2.56347656e-03],
                        [  2.43835449e-02,   2.41088867e-02],
                        [  3.92150879e-02,   3.90930176e-02],
                        [  3.62854004e-02,   3.64074707e-02],
                        [  9.58251953e-03,   9.85717773e-03],
                        [ -3.53698730e-02,  -3.51867676e-02],
                        [ -8.31298828e-02,  -8.32519531e-02],
                        [ -1.16394043e-01,  -1.16668701e-01],
                        [ -1.24389648e-01,  -1.24572754e-01],
                        [ -1.07391357e-01,  -1.07299805e-01],
                        [ -7.56225586e-02,  -7.53479004e-02],
                        [ -4.28771973e-02,  -4.26940918e-02],
                        [ -1.68457031e-02,  -1.69372559e-02],
                        [  5.43212891e-03,   5.15747070e-03],
                        [  3.20739746e-02,   3.18908691e-02],
                        [  6.74743652e-02,   6.75354004e-02],
                        [  1.08093262e-01,   1.08337402e-01],
                        [  1.46453857e-01,   1.46667480e-01],
                        [  1.74987793e-01,   1.74957275e-01],
                        [  1.80877686e-01,   1.80633545e-01],
                        [  1.46484375e-01,   1.46270752e-01],
                        [  6.50939941e-02,   6.51245117e-02],
                        [ -5.13916016e-02,  -5.11779785e-02],
                        [ -1.80664062e-01,  -1.80450439e-01],
                        [ -2.94464111e-01,  -2.94494629e-01],
                        [ -3.61389160e-01,  -3.61602783e-01],
                        [ -3.63006592e-01,  -3.63220215e-01],
                        [ -3.11340332e-01,  -3.11340332e-01],
                        [ -2.42828369e-01,  -2.42645264e-01],
                        [ -1.89117432e-01,  -1.88873291e-01],
                        [ -1.53991699e-01,  -1.53961182e-01],
                        [ -1.19659424e-01,  -1.19842529e-01],
                        [ -6.99462891e-02,  -7.01599121e-02],
                        [ -6.10351562e-03,  -6.16455078e-03],
                        [  5.67626953e-02,   5.69458008e-02],
                        [  1.04309082e-01,   1.04522705e-01],
                        [  1.31225586e-01,   1.31286621e-01],
                        [  1.40411377e-01,   1.40228271e-01],
                        [  1.40380859e-01,   1.40167236e-01],
                        [  1.41052246e-01,   1.40991211e-01],
                        [  1.44104004e-01,   1.44256592e-01],
                        [  1.40991211e-01,   1.41204834e-01],
                        [  1.26861572e-01,   1.26953125e-01],
                        [  1.10198975e-01,   1.10076904e-01],
                        [  9.99145508e-02,   9.96704102e-02],
                        [  9.08813477e-02,   9.07897949e-02],
                        [  7.22351074e-02,   7.23571777e-02],
                        [  4.27551270e-02,   4.29687500e-02],
                        [  1.24816895e-02,   1.25732422e-02],
                        [ -6.92749023e-03,  -7.04956055e-03],
                        [ -9.76562500e-03,  -9.97924805e-03],
                        [  2.34985352e-03,   2.25830078e-03],
                        [  2.31933594e-02,   2.32849121e-02],
                        [  4.60815430e-02,   4.62951660e-02],
                        [  6.64062500e-02,   6.65283203e-02],
                        [  8.17260742e-02,   8.16345215e-02],
                        [  9.10644531e-02,   9.08508301e-02],
                        [  9.32617188e-02,   9.31396484e-02],
                        [  8.69140625e-02,   8.69750977e-02],
                        [  7.34252930e-02,   7.36389160e-02],
                        [  5.74340820e-02,   5.75561523e-02],
                        [  4.14733887e-02,   4.14123535e-02],
                        [  2.48718262e-02,   2.46887207e-02],
                        [  8.39233398e-03,   8.23974609e-03],
                        [ -3.08227539e-03,  -3.02124023e-03],
                        [ -5.40161133e-03,  -5.21850586e-03],
                        [ -2.74658203e-03,  -2.62451172e-03],
                        [ -3.05175781e-03,  -3.08227539e-03],
                        [ -6.62231445e-03,  -6.80541992e-03],
                        [ -8.81958008e-03,  -8.97216797e-03],
                        [ -8.94165039e-03,  -8.91113281e-03],
                        [ -8.08715820e-03,  -7.90405273e-03],
                        [ -3.96728516e-03,  -3.81469727e-03],
                        [  4.97436523e-03,   4.97436523e-03],
                        [  1.51672363e-02,   1.50146484e-02],
                        [  2.14233398e-02,   2.12707520e-02],
                        [  2.27355957e-02,   2.27355957e-02],
                        [  2.17895508e-02,   2.19421387e-02],
                        [  2.05993652e-02,   2.07519531e-02],
                        [  1.90734863e-02,   1.90734863e-02],
                        [  1.62048340e-02,   1.60522461e-02],
                        [  1.11694336e-02,   1.10168457e-02],
                        [  4.54711914e-03,   4.54711914e-03],
                        [ -1.31225586e-03,  -1.15966797e-03],
                        [ -4.05883789e-03,  -3.90625000e-03],
                        [ -3.90625000e-03,  -3.87573242e-03],
                        [ -2.71606445e-03,  -2.83813477e-03],
                        [ -1.09863281e-03,  -1.25122070e-03],
                        [ -6.10351562e-05,  -9.15527344e-05],
                        [ -3.23486328e-03,  -3.11279297e-03],
                        [ -1.25122070e-02,  -1.23596191e-02],
                        [ -2.40173340e-02,  -2.39562988e-02],
                        [ -3.14941406e-02,  -3.16162109e-02],
                        [ -3.24401855e-02,  -3.25927734e-02],
                        [ -2.88696289e-02,  -2.89306641e-02],
                        [ -2.48718262e-02,  -2.47802734e-02],
                        [ -2.39868164e-02,  -2.38037109e-02],
                        [ -2.65808105e-02,  -2.65197754e-02],
                        [ -3.03955078e-02,  -3.04870605e-02],
                        [ -3.39660645e-02,  -3.41186523e-02],
                        [ -3.57360840e-02,  -3.57971191e-02],
                        [ -3.18298340e-02,  -3.17687988e-02],
                        [ -1.94091797e-02,  -1.92565918e-02],
                        [ -9.15527344e-04,  -8.54492188e-04],
                        [  1.66015625e-02,   1.65405273e-02],
                        [  2.75268555e-02,   2.74047852e-02],
                        [  3.17382812e-02,   3.16467285e-02],
                        [  2.92663574e-02,   2.93273926e-02],
                        [  1.48925781e-02,   1.50451660e-02],
                        [ -1.66320801e-02,  -1.65405273e-02],
                        [ -6.10961914e-02,  -6.11267090e-02],
                        [ -1.03057861e-01,  -1.03179932e-01],
                        [ -1.25061035e-01,  -1.25152588e-01],
                        [ -1.20117188e-01,  -1.20056152e-01],
                        [ -9.30786133e-02,  -9.29565430e-02],
                        [ -5.55725098e-02,  -5.54809570e-02],
                        [ -2.28881836e-02,  -2.29187012e-02],
                        [ -4.39453125e-03,  -4.51660156e-03],
                        [  6.92749023e-03,   6.83593750e-03],
                        [  2.60314941e-02,   2.60314941e-02],
                        [  6.07604980e-02,   6.08825684e-02],
                        [  1.08947754e-01,   1.09039307e-01],
                        [  1.59118652e-01,   1.59118652e-01],
                        [  1.92016602e-01,   1.91925049e-01],
                        [  1.89910889e-01,   1.89819336e-01],
                        [  1.43951416e-01,   1.43951416e-01],
                        [  5.31005859e-02,   5.31921387e-02],
                        [ -7.33337402e-02,  -7.32116699e-02],
                        [ -2.10205078e-01,  -2.10205078e-01],
                        [ -3.21838379e-01,  -3.21929932e-01],
                        [ -3.77655029e-01,  -3.77746582e-01],
                        [ -3.68164062e-01,  -3.68164062e-01],
                        [ -3.12927246e-01,  -3.12835693e-01],
                        [ -2.49237061e-01,  -2.49114990e-01],
                        [ -2.02911377e-01,  -2.02911377e-01],
                        [ -1.69647217e-01,  -1.69738770e-01],
                        [ -1.26922607e-01,  -1.27044678e-01],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [  1.98059082e-02,   1.98669434e-02],
                        [  9.21020508e-02,   9.22241211e-02],
                        [  1.35375977e-01,   1.35406494e-01],
                        [  1.49169922e-01,   1.49108887e-01],
                        [  1.51306152e-01,   1.51184082e-01],
                        [  1.55792236e-01,   1.55731201e-01],
                        [  1.60766602e-01,   1.60827637e-01],
                        [  1.56890869e-01,   1.56982422e-01],
                        [  1.38610840e-01,   1.38671875e-01],
                        [  1.09893799e-01,   1.09832764e-01],
                        [  8.13903809e-02,   8.12683105e-02],
                        [  6.01196289e-02,   6.00891113e-02],
                        [  4.50439453e-02,   4.51049805e-02],
                        [  3.12500000e-02,   3.13720703e-02],
                        [  1.49841309e-02,   1.50146484e-02],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [ -7.41577148e-03,  -7.50732422e-03],
                        [  3.44848633e-03,   3.38745117e-03],
                        [  2.62145996e-02,   2.62451172e-02],
                        [  4.93469238e-02,   4.94384766e-02],
                        [  6.83288574e-02,   6.83898926e-02],
                        [  8.55407715e-02,   8.55102539e-02],
                        [  9.92126465e-02,   9.91210938e-02],
                        [  1.04431152e-01,   1.04370117e-01],
                        [  1.02447510e-01,   1.02478027e-01],
                        [  9.61608887e-02,   9.62524414e-02],
                        [  8.26110840e-02,   8.26721191e-02],
                        [  6.10351562e-02,   6.10046387e-02],
                        [  3.93676758e-02,   3.93066406e-02],
                        [  2.45971680e-02,   2.45361328e-02],
                        [  1.43127441e-02,   1.43127441e-02],
                        [  2.65502930e-03,   2.74658203e-03],
                        [ -1.08337402e-02,  -1.07727051e-02],
                        [ -2.13012695e-02,  -2.13012695e-02],
                        [ -2.63977051e-02,  -2.64587402e-02],
                        [ -2.89611816e-02,  -2.90527344e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.33459473e-02,  -2.32849121e-02],
                        [ -1.44958496e-02,  -1.44348145e-02],
                        [ -8.08715820e-03,  -8.08715820e-03],
                        [ -5.18798828e-04,  -5.79833984e-04],
                        [  1.40075684e-02,   1.39465332e-02],
                        [  3.10668945e-02,   3.10668945e-02],
                        [  4.11987305e-02,   4.12597656e-02],
                        [  4.22973633e-02,   4.23583984e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.40576172e-02,   3.40270996e-02],
                        [  2.41394043e-02,   2.40783691e-02],
                        [  1.06811523e-02,   1.06811523e-02],
                        [ -5.18798828e-04,  -4.88281250e-04],
                        [ -5.92041016e-03,  -5.85937500e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -5.49316406e-03,  -5.55419922e-03],
                        [ -7.44628906e-03,  -7.50732422e-03],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -2.38037109e-02,  -2.37426758e-02],
                        [ -3.24401855e-02,  -3.23791504e-02],
                        [ -3.52478027e-02,  -3.52172852e-02],
                        [ -3.17077637e-02,  -3.17687988e-02],
                        [ -2.58178711e-02,  -2.58789062e-02],
                        [ -2.06604004e-02,  -2.06909180e-02],
                        [ -1.63574219e-02,  -1.63574219e-02],
                        [ -1.36718750e-02,  -1.36413574e-02],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -2.40783691e-02,  -2.41088867e-02],
                        [ -3.10363770e-02,  -3.10974121e-02],
                        [ -2.95715332e-02,  -2.95715332e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.20849609e-02,  -1.20239258e-02],
                        [ -3.96728516e-03,  -3.93676758e-03],
                        [  7.01904297e-03,   6.98852539e-03],
                        [  1.98669434e-02,   1.98364258e-02],
                        [  2.87170410e-02,   2.86865234e-02],
                        [  2.95104980e-02,   2.95104980e-02],
                        [  1.99279785e-02,   1.99890137e-02],
                        [ -3.81469727e-03,  -3.78417969e-03],
                        [ -4.39758301e-02,  -4.39758301e-02],
                        [ -9.31396484e-02,  -9.32006836e-02],
                        [ -1.33361816e-01,  -1.33392334e-01],
                        [ -1.46942139e-01,  -1.46942139e-01],
                        [ -1.28448486e-01,  -1.28387451e-01],
                        [ -8.76159668e-02,  -8.75854492e-02],
                        [ -4.35180664e-02,  -4.35485840e-02],
                        [ -1.07727051e-02,  -1.08337402e-02],
                        [  1.14746094e-02,   1.14440918e-02],
                        [  3.51257324e-02,   3.51257324e-02],
                        [  7.00988770e-02,   7.01293945e-02],
                        [  1.16149902e-01,   1.16180420e-01],
                        [  1.62170410e-01,   1.62170410e-01],
                        [  1.92443848e-01,   1.92413330e-01],
                        [  1.92749023e-01,   1.92718506e-01],
                        [  1.51306152e-01,   1.51306152e-01],
                        [  6.13098145e-02,   6.13403320e-02],
                        [ -7.08007812e-02,  -7.07702637e-02],
                        [ -2.17895508e-01,  -2.17895508e-01],
                        [ -3.37860107e-01,  -3.37890625e-01],
                        [ -3.94714355e-01,  -3.94744873e-01],
                        [ -3.79547119e-01,  -3.79547119e-01],
                        [ -3.15551758e-01,  -3.15521240e-01],
                        [ -2.42858887e-01,  -2.42828369e-01],
                        [ -1.91131592e-01,  -1.91101074e-01],
                        [ -1.59179688e-01,  -1.59210205e-01],
                        [ -1.22192383e-01,  -1.22222900e-01],
                        [ -6.11572266e-02,  -6.11877441e-02],
                        [  1.55334473e-02,   1.55639648e-02],
                        [  8.24890137e-02,   8.25195312e-02],
                        [  1.21948242e-01,   1.21978760e-01],
                        [  1.35131836e-01,   1.35101318e-01],
                        [  1.36199951e-01,   1.36199951e-01],
                        [  1.38946533e-01,   1.38946533e-01],
                        [  1.44714355e-01,   1.44744873e-01],
                        [  1.44592285e-01,   1.44622803e-01],
                        [  1.33026123e-01,   1.33026123e-01],
                        [  1.14593506e-01,   1.14562988e-01],
                        [  9.57641602e-02,   9.57336426e-02],
                        [  7.62329102e-02,   7.62329102e-02],
                        [  5.42907715e-02,   5.42907715e-02],
                        [  3.44238281e-02,   3.44543457e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  1.55639648e-02,   1.55334473e-02],
                        [  1.31530762e-02,   1.31530762e-02],
                        [  1.66015625e-02,   1.65710449e-02],
                        [  2.80761719e-02,   2.80761719e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  6.11877441e-02,   6.12182617e-02],
                        [  7.47985840e-02,   7.47985840e-02],
                        [  8.48388672e-02,   8.48083496e-02],
                        [  8.98742676e-02,   8.98742676e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  8.15734863e-02,   8.15734863e-02],
                        [  7.25708008e-02,   7.25708008e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  3.95812988e-02,   3.95812988e-02],
                        [  1.15051270e-02,   1.15051270e-02],
                        [ -1.16882324e-02,  -1.16882324e-02],
                        [ -2.13623047e-02,  -2.13317871e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -1.92565918e-02,  -1.92565918e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -4.91333008e-03,  -4.91333008e-03],
                        [  1.52587891e-04,   1.83105469e-04],
                        [  4.30297852e-03,   4.30297852e-03],
                        [  9.67407227e-03,   9.67407227e-03],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  2.12707520e-02,   2.12707520e-02],
                        [  2.81982422e-02,   2.81982422e-02],
                        [  3.48510742e-02,   3.48815918e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.21655273e-02,   3.21655273e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  6.80541992e-03,   6.80541992e-03],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -2.09960938e-02,  -2.09960938e-02],
                        [ -1.72119141e-02,  -1.72119141e-02],
                        [ -7.75146484e-03,  -7.78198242e-03],
                        [ -5.27954102e-03,  -5.27954102e-03],
                        [ -1.27563477e-02,  -1.27563477e-02],
                        [ -2.33764648e-02,  -2.33764648e-02],
                        [ -3.05175781e-02,  -3.05175781e-02],
                        [ -3.27758789e-02,  -3.27758789e-02],
                        [ -3.08532715e-02,  -3.08532715e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -5.15747070e-03,  -5.15747070e-03],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [ -2.96020508e-03,  -2.96020508e-03],
                        [ -5.12695312e-03,  -5.12695312e-03],
                        [ -8.75854492e-03,  -8.75854492e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -1.74560547e-02,  -1.74560547e-02],
                        [ -1.85241699e-02,  -1.85241699e-02],
                        [ -1.91650391e-02,  -1.91345215e-02],
                        [ -1.94091797e-02,  -1.94091797e-02],
                        [ -1.65405273e-02,  -1.65405273e-02],
                        [ -8.69750977e-03,  -8.69750977e-03],
                        [  3.50952148e-03,   3.50952148e-03],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  1.40075684e-02,   1.40075684e-02],
                        [ -4.76074219e-03,  -4.76074219e-03],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -7.33947754e-02,  -7.33947754e-02],
                        [ -9.88769531e-02,  -9.88769531e-02],
                        [ -1.02752686e-01,  -1.02752686e-01],
                        [ -8.44421387e-02,  -8.44421387e-02],
                        [ -5.60607910e-02,  -5.60607910e-02],
                        [ -2.91137695e-02,  -2.91137695e-02],
                        [ -2.53295898e-03,  -2.53295898e-03],
                        [  2.94799805e-02,   2.94799805e-02],
                        [  6.63757324e-02,   6.63757324e-02],
                        [  1.04278564e-01,   1.04278564e-01],
                        [  1.40594482e-01,   1.40594482e-01],
                        [  1.67938232e-01,   1.67938232e-01],
                        [  1.69982910e-01,   1.69982910e-01],
                        [  1.28723145e-01,   1.28723145e-01],
                        [  3.84826660e-02,   3.84826660e-02],
                        [ -8.66394043e-02,  -8.66394043e-02],
                        [ -2.16400146e-01,  -2.16400146e-01],
                        [ -3.15307617e-01,  -3.15307617e-01],
                        [ -3.56506348e-01,  -3.56506348e-01],
                        [ -3.34960938e-01,  -3.34960938e-01],
                        [ -2.74139404e-01,  -2.74139404e-01],
                        [ -2.12463379e-01,  -2.12463379e-01],
                        [ -1.72119141e-01,  -1.72119141e-01],
                        [ -1.42883301e-01,  -1.42883301e-01],
                        [ -1.01501465e-01,  -1.01501465e-01],
                        [ -4.04052734e-02,  -4.04052734e-02],
                        [  2.52685547e-02,   2.52685547e-02],
                        [  7.27539062e-02,   7.27539062e-02],
                        [  9.18579102e-02,   9.18579102e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.80224609e-02,   9.80224609e-02],
                        [  1.15142822e-01,   1.15142822e-01],
                        [  1.36627197e-01,   1.36627197e-01],
                        [  1.48193359e-01,   1.48193359e-01],
                        [  1.43615723e-01,   1.43615723e-01],
                        [  1.26708984e-01,   1.26708984e-01],
                        [  1.05194092e-01,   1.05194092e-01],
                        [  8.39233398e-02,   8.39233398e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  4.40368652e-02,   4.40368652e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  1.70898438e-02,   1.70898438e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  3.86352539e-02,   3.86352539e-02],
                        [  5.09948730e-02,   5.09948730e-02],
                        [  6.60705566e-02,   6.60705566e-02],
                        [  8.05969238e-02,   8.05969238e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  7.84606934e-02,   7.84606934e-02],
                        [  6.49414062e-02,   6.49414062e-02],
                        [  5.19409180e-02,   5.19409180e-02],
                        [  4.15954590e-02,   4.15954590e-02],
                        [  3.46984863e-02,   3.46984863e-02],
                        [  2.96020508e-02,   2.96020508e-02],
                        [  2.20642090e-02,   2.20642090e-02],
                        [  1.22070312e-02,   1.22070312e-02],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  2.28881836e-03,   2.28881836e-03],
                        [  3.05175781e-05,   3.05175781e-05],
                        [ -2.44140625e-03,  -2.44140625e-03],
                        [ -2.89916992e-03,  -2.89916992e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [  8.14819336e-03,   8.14819336e-03],
                        [  1.42211914e-02,   1.42211914e-02],
                        [  1.41601562e-02,   1.41601562e-02],
                        [  1.00097656e-02,   1.00097656e-02],
                        [  7.26318359e-03,   7.26318359e-03],
                        [  8.97216797e-03,   8.97216797e-03],
                        [  1.54113770e-02,   1.54113770e-02],
                        [  2.33154297e-02,   2.33154297e-02],
                        [  2.57263184e-02,   2.57263184e-02],
                        [  1.92565918e-02,   1.92565918e-02],
                        [  1.02233887e-02,   1.02233887e-02],
                        [  7.69042969e-03,   7.69042969e-03],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  1.34582520e-02,   1.34582520e-02],
                        [  6.74438477e-03,   6.74438477e-03],
                        [ -3.50952148e-03,  -3.50952148e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.37829590e-02,  -3.37829590e-02],
                        [ -3.26538086e-02,  -3.26538086e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -2.18811035e-02,  -2.18811035e-02],
                        [ -2.02331543e-02,  -2.02331543e-02],
                        [ -1.69372559e-02,  -1.69372559e-02],
                        [ -1.48010254e-02,  -1.48010254e-02],
                        [ -1.75781250e-02,  -1.75781250e-02],
                        [ -2.59399414e-02,  -2.59399414e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -5.10864258e-02,  -5.10864258e-02],
                        [ -4.32434082e-02,  -4.32434082e-02],
                        [ -2.58178711e-02,  -2.58178711e-02],
                        [ -1.55639648e-03,  -1.55639648e-03],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  3.98864746e-02,   3.98864746e-02],
                        [  4.19006348e-02,   4.19006348e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  9.03320312e-03,   9.03320312e-03],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -6.10351562e-02,  -6.10351562e-02],
                        [ -8.15734863e-02,  -8.15734863e-02],
                        [ -7.82165527e-02,  -7.82165527e-02],
                        [ -5.79833984e-02,  -5.79833984e-02],
                        [ -3.28674316e-02,  -3.28674316e-02],
                        [ -8.20922852e-03,  -8.20922852e-03],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  5.35278320e-02,   5.35278320e-02],
                        [  9.62219238e-02,   9.62219238e-02],
                        [  1.39282227e-01,   1.39282227e-01],
                        [  1.66992188e-01,   1.66992188e-01],
                        [  1.60888672e-01,   1.60888672e-01],
                        [  1.07788086e-01,   1.07788086e-01],
                        [  8.81958008e-03,   8.81958008e-03],
                        [ -1.18072510e-01,  -1.18072510e-01],
                        [ -2.44293213e-01,  -2.44293213e-01],
                        [ -3.39111328e-01,  -3.39111328e-01],
                        [ -3.79119873e-01,  -3.79119873e-01],
                        [ -3.61663818e-01,  -3.61663818e-01],
                        [ -3.08044434e-01,  -3.08044434e-01],
                        [ -2.46673584e-01,  -2.46673584e-01],
                        [ -1.91619873e-01,  -1.91650391e-01],
                        [ -1.37481689e-01,  -1.37481689e-01],
                        [ -7.15026855e-02,  -7.15026855e-02],
                        [  8.48388672e-03,   8.48388672e-03],
                        [  8.51745605e-02,   8.51745605e-02],
                        [  1.34002686e-01,   1.34002686e-01],
                        [  1.46118164e-01,   1.46118164e-01],
                        [  1.34429932e-01,   1.34429932e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.17462158e-01,   1.17462158e-01],
                        [  1.25244141e-01,   1.25244141e-01],
                        [  1.29058838e-01,   1.29058838e-01],
                        [  1.20056152e-01,   1.20056152e-01],
                        [  1.03637695e-01,   1.03637695e-01],
                        [  8.65173340e-02,   8.65173340e-02],
                        [  6.74743652e-02,   6.74743652e-02],
                        [  4.53796387e-02,   4.53796387e-02],
                        [  2.54516602e-02,   2.54516602e-02],
                        [  1.32751465e-02,   1.32751465e-02],
                        [  1.01013184e-02,   1.01013184e-02],
                        [  1.58081055e-02,   1.58081055e-02],
                        [  2.89306641e-02,   2.89306641e-02],
                        [  4.54101562e-02,   4.54101562e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  7.73010254e-02,   7.73010254e-02],
                        [  8.88977051e-02,   8.88977051e-02],
                        [  9.44213867e-02,   9.44213867e-02],
                        [  9.15832520e-02,   9.15832520e-02],
                        [  7.95288086e-02,   7.95288086e-02],
                        [  6.20727539e-02,   6.20727539e-02],
                        [  4.47387695e-02,   4.47387695e-02],
                        [  2.86254883e-02,   2.86254883e-02],
                        [  1.33972168e-02,   1.33972168e-02],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  3.20434570e-03,   3.20434570e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  1.32141113e-02,   1.32141113e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [ -5.49316406e-04,  -5.49316406e-04],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -8.94165039e-03,  -8.94165039e-03],
                        [ -1.67846680e-03,  -1.67846680e-03],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  1.83410645e-02,   1.83715820e-02],
                        [  2.25830078e-02,   2.25830078e-02],
                        [  2.06298828e-02,   2.06298828e-02],
                        [  1.24816895e-02,   1.24816895e-02],
                        [  3.38745117e-03,   3.38745117e-03],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [ -6.71386719e-04,  -6.71386719e-04],
                        [ -4.05883789e-03,  -4.05883789e-03],
                        [ -9.03320312e-03,  -9.03320312e-03],
                        [ -1.01623535e-02,  -1.01623535e-02],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -1.00708008e-03,  -1.00708008e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.49230957e-02,   1.49230957e-02],
                        [  1.52587891e-02,   1.52587891e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  8.11767578e-03,   8.11767578e-03],
                        [  2.96020508e-03,   2.92968750e-03],
                        [ -5.92041016e-03,  -5.92041016e-03],
                        [ -1.82189941e-02,  -1.82189941e-02],
                        [ -3.01208496e-02,  -3.01208496e-02],
                        [ -3.88488770e-02,  -3.88488770e-02],
                        [ -4.51660156e-02,  -4.51660156e-02],
                        [ -4.88586426e-02,  -4.88586426e-02],
                        [ -4.87365723e-02,  -4.87365723e-02],
                        [ -4.62951660e-02,  -4.62951660e-02],
                        [ -4.20227051e-02,  -4.20227051e-02],
                        [ -3.39965820e-02,  -3.39965820e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -2.09045410e-02,  -2.09045410e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [ -9.24682617e-03,  -9.24682617e-03],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  3.73535156e-02,   3.73535156e-02],
                        [  3.09143066e-02,   3.09143066e-02],
                        [  6.40869141e-03,   6.40869141e-03],
                        [ -3.11279297e-02,  -3.11279297e-02],
                        [ -6.81457520e-02,  -6.81457520e-02],
                        [ -8.95690918e-02,  -8.95690918e-02],
                        [ -8.76159668e-02,  -8.76159668e-02],
                        [ -6.60705566e-02,  -6.60705566e-02],
                        [ -3.76281738e-02,  -3.76281738e-02],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  6.04248047e-02,   6.04248047e-02],
                        [  1.10473633e-01,   1.10473633e-01],
                        [  1.58477783e-01,   1.58477783e-01],
                        [  1.85180664e-01,   1.85180664e-01],
                        [  1.71264648e-01,   1.71264648e-01],
                        [  1.06842041e-01,   1.06842041e-01],
                        [ -6.07299805e-03,  -6.07299805e-03],
                        [ -1.49841309e-01,  -1.49841309e-01],
                        [ -2.87963867e-01,  -2.87963867e-01],
                        [ -3.79943848e-01,  -3.79943848e-01],
                        [ -4.05029297e-01,  -4.05029297e-01],
                        [ -3.70208740e-01,  -3.70208740e-01],
                        [ -3.01513672e-01,  -3.01513672e-01],
                        [ -2.29125977e-01,  -2.29125977e-01],
                        [ -1.70288086e-01,  -1.70288086e-01],
                        [ -1.19201660e-01,  -1.19201660e-01],
                        [ -5.80444336e-02,  -5.80444336e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  8.85620117e-02,   8.85620117e-02],
                        [  1.29699707e-01,   1.29699707e-01],
                        [  1.35437012e-01,   1.35437012e-01],
                        [  1.24267578e-01,   1.24267578e-01],
                        [  1.19018555e-01,   1.19018555e-01],
                        [  1.25152588e-01,   1.25152588e-01],
                        [  1.30035400e-01,   1.30035400e-01],
                        [  1.23535156e-01,   1.23535156e-01],
                        [  1.09924316e-01,   1.09924316e-01],
                        [  9.54895020e-02,   9.54895020e-02],
                        [  7.94067383e-02,   7.94067383e-02],
                        [  6.13708496e-02,   6.13708496e-02],
                        [  4.34265137e-02,   4.34265137e-02],
                        [  2.61230469e-02,   2.61230469e-02],
                        [  1.18103027e-02,   1.18103027e-02],
                        [  6.59179688e-03,   6.59179688e-03],
                        [  1.31225586e-02,   1.31225586e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  5.53588867e-02,   5.53588867e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  8.09020996e-02,   8.09020996e-02],
                        [  8.26110840e-02,   8.26110840e-02],
                        [  7.85827637e-02,   7.85827637e-02],
                        [  7.22351074e-02,   7.22656250e-02],
                        [  6.38427734e-02,   6.38122559e-02],
                        [  5.24597168e-02,   5.24597168e-02],
                        [  3.92150879e-02,   3.92150879e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  1.60827637e-02,   1.60827637e-02],
                        [  6.92749023e-03,   6.92749023e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -8.85009766e-04,  -8.85009766e-04],
                        [ -9.76562500e-04,  -9.76562500e-04],
                        [ -5.09643555e-03,  -5.09643555e-03],
                        [ -1.26037598e-02,  -1.26037598e-02],
                        [ -1.52282715e-02,  -1.52587891e-02],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  4.48608398e-03,   4.48608398e-03],
                        [  6.80541992e-03,   6.80541992e-03],
                        [  1.04980469e-02,   1.04980469e-02],
                        [  1.21765137e-02,   1.21765137e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  1.44958496e-02,   1.44958496e-02],
                        [  2.30712891e-02,   2.30712891e-02],
                        [  3.44543457e-02,   3.44543457e-02],
                        [  4.19616699e-02,   4.19616699e-02],
                        [  4.21447754e-02,   4.21447754e-02],
                        [  3.48815918e-02,   3.48815918e-02],
                        [  2.18505859e-02,   2.18505859e-02],
                        [  8.51440430e-03,   8.51440430e-03],
                        [ -1.83105469e-04,  -1.83105469e-04],
                        [ -6.77490234e-03,  -6.77490234e-03],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -2.32849121e-02,  -2.32849121e-02],
                        [ -2.78015137e-02,  -2.78015137e-02],
                        [ -3.18298340e-02,  -3.18298340e-02],
                        [ -3.93066406e-02,  -3.93066406e-02],
                        [ -4.81262207e-02,  -4.81262207e-02],
                        [ -5.31921387e-02,  -5.31921387e-02],
                        [ -5.19409180e-02,  -5.19409180e-02],
                        [ -4.49829102e-02,  -4.49829102e-02],
                        [ -3.56445312e-02,  -3.56445312e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -2.49328613e-02,  -2.49328613e-02],
                        [ -1.91955566e-02,  -1.91955566e-02],
                        [ -6.40869141e-03,  -6.40869141e-03],
                        [  1.11694336e-02,   1.11694336e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  2.69470215e-02,   2.69470215e-02],
                        [  1.96533203e-02,   1.96533203e-02],
                        [  1.07116699e-02,   1.07116699e-02],
                        [  5.82885742e-03,   5.82885742e-03],
                        [  3.57055664e-03,   3.57055664e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -2.06909180e-02,  -2.06909180e-02],
                        [ -4.93164062e-02,  -4.93164062e-02],
                        [ -7.95288086e-02,  -7.95288086e-02],
                        [ -9.57946777e-02,  -9.57946777e-02],
                        [ -8.78295898e-02,  -8.78295898e-02],
                        [ -6.02722168e-02,  -6.02722168e-02],
                        [ -2.60620117e-02,  -2.60620117e-02],
                        [  9.21630859e-03,   9.21630859e-03],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  9.58862305e-02,   9.58862305e-02],
                        [  1.40045166e-01,   1.40045166e-01],
                        [  1.69097900e-01,   1.69097900e-01],
                        [  1.69433594e-01,   1.69433594e-01],
                        [  1.28448486e-01,   1.28448486e-01],
                        [  4.05273438e-02,   4.05273438e-02],
                        [ -8.50830078e-02,  -8.50830078e-02],
                        [ -2.21252441e-01,  -2.21252441e-01],
                        [ -3.30322266e-01,  -3.30322266e-01],
                        [ -3.80645752e-01,  -3.80645752e-01],
                        [ -3.64318848e-01,  -3.64318848e-01],
                        [ -3.02581787e-01,  -3.02581787e-01],
                        [ -2.30743408e-01,  -2.30743408e-01],
                        [ -1.72210693e-01,  -1.72210693e-01],
                        [ -1.24816895e-01,  -1.24816895e-01],
                        [ -7.15332031e-02,  -7.15332031e-02],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [  5.49316406e-02,   5.49316406e-02],
                        [  9.15222168e-02,   9.15222168e-02],
                        [  1.01715088e-01,   1.01715088e-01],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  9.94567871e-02,   9.94567871e-02],
                        [  1.06811523e-01,   1.06811523e-01],
                        [  1.14746094e-01,   1.14746094e-01],
                        [  1.13830566e-01,   1.13830566e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  9.07897949e-02,   9.07897949e-02],
                        [  8.14208984e-02,   8.13903809e-02],
                        [  7.47680664e-02,   7.47680664e-02],
                        [  6.68029785e-02,   6.68029785e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  4.02221680e-02,   4.02221680e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  2.42004395e-02,   2.42004395e-02],
                        [  2.24914551e-02,   2.24914551e-02],
                        [  2.58483887e-02,   2.58483887e-02],
                        [  3.82080078e-02,   3.82080078e-02],
                        [  5.68847656e-02,   5.68542480e-02],
                        [  7.49206543e-02,   7.49206543e-02],
                        [  8.84094238e-02,   8.84094238e-02],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  9.09423828e-02,   9.09118652e-02],
                        [  8.08410645e-02,   8.08410645e-02],
                        [  6.85729980e-02,   6.85729980e-02],
                        [  5.18493652e-02,   5.18493652e-02],
                        [  2.80456543e-02,   2.80456543e-02],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -1.66320801e-02,  -1.66320801e-02],
                        [ -2.46887207e-02,  -2.46887207e-02],
                        [ -2.07519531e-02,  -2.07519531e-02],
                        [ -9.82666016e-03,  -9.82666016e-03],
                        [  1.49536133e-03,   1.49536133e-03],
                        [  1.11083984e-02,   1.11083984e-02],
                        [  1.91040039e-02,   1.91040039e-02],
                        [  2.36206055e-02,   2.36206055e-02],
                        [  2.25524902e-02,   2.25524902e-02],
                        [  1.66015625e-02,   1.66320801e-02],
                        [  8.60595703e-03,   8.60595703e-03],
                        [  2.53295898e-03,   2.53295898e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.35290527e-02,   2.35290527e-02],
                        [  2.36511230e-02,   2.36511230e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  9.52148438e-03,   9.52148438e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  1.93786621e-02,   1.93786621e-02],
                        [  2.50244141e-02,   2.50244141e-02],
                        [  2.56652832e-02,   2.56652832e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.51367188e-02,   1.51367188e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -3.66210938e-04,  -3.66210938e-04],
                        [ -2.31933594e-03,  -2.31933594e-03],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -1.38854980e-02,  -1.38854980e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [ -4.74243164e-02,  -4.74243164e-02],
                        [ -6.15539551e-02,  -6.15539551e-02],
                        [ -6.69555664e-02,  -6.69555664e-02],
                        [ -6.04248047e-02,  -6.04248047e-02],
                        [ -4.52270508e-02,  -4.52270508e-02],
                        [ -3.09448242e-02,  -3.09448242e-02],
                        [ -2.47802734e-02,  -2.47802734e-02],
                        [ -2.43835449e-02,  -2.43835449e-02],
                        [ -2.32543945e-02,  -2.32543945e-02],
                        [ -2.06298828e-02,  -2.06298828e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [ -1.22985840e-02,  -1.22985840e-02],
                        [ -3.05175781e-04,  -3.05175781e-04],
                        [  1.28784180e-02,   1.28784180e-02],
                        [  2.23693848e-02,   2.23693848e-02],
                        [  2.56042480e-02,   2.56042480e-02],
                        [  2.01416016e-02,   2.01416016e-02],
                        [  4.45556641e-03,   4.45556641e-03],
                        [ -1.86462402e-02,  -1.86157227e-02],
                        [ -4.13513184e-02,  -4.13513184e-02],
                        [ -5.32836914e-02,  -5.32836914e-02],
                        [ -4.70275879e-02,  -4.70275879e-02],
                        [ -2.33154297e-02,  -2.33154297e-02],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  4.56848145e-02,   4.56848145e-02],
                        [  7.90100098e-02,   7.90100098e-02],
                        [  1.10107422e-01,   1.10107422e-01],
                        [  1.33697510e-01,   1.33697510e-01],
                        [  1.37420654e-01,   1.37420654e-01],
                        [  1.08337402e-01,   1.08337402e-01],
                        [  3.69873047e-02,   3.69873047e-02],
                        [ -7.59887695e-02,  -7.59887695e-02],
                        [ -2.07977295e-01,  -2.07977295e-01],
                        [ -3.15948486e-01,  -3.15948486e-01],
                        [ -3.62060547e-01,  -3.62091064e-01],
                        [ -3.41491699e-01,  -3.41491699e-01],
                        [ -2.81982422e-01,  -2.81982422e-01],
                        [ -2.18811035e-01,  -2.18811035e-01],
                        [ -1.71936035e-01,  -1.71936035e-01],
                        [ -1.38122559e-01,  -1.38122559e-01],
                        [ -9.94873047e-02,  -9.94873047e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [  1.56555176e-02,   1.56555176e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  8.05664062e-02,   8.05358887e-02],
                        [  8.16650391e-02,   8.16650391e-02],
                        [  8.63342285e-02,   8.63647461e-02],
                        [  1.05743408e-01,   1.05712891e-01],
                        [  1.29821777e-01,   1.29821777e-01],
                        [  1.42181396e-01,   1.42181396e-01],
                        [  1.38122559e-01,   1.38122559e-01],
                        [  1.24511719e-01,   1.24511719e-01],
                        [  1.08398438e-01,   1.08398438e-01],
                        [  9.05761719e-02,   9.05761719e-02],
                        [  6.79931641e-02,   6.79931641e-02],
                        [  4.13208008e-02,   4.13208008e-02],
                        [  1.74255371e-02,   1.74255371e-02],
                        [  3.35693359e-03,   3.35693359e-03],
                        [  1.46484375e-03,   1.46484375e-03],
                        [  1.06201172e-02,   1.06506348e-02],
                        [  2.71911621e-02,   2.71911621e-02],
                        [  4.55627441e-02,   4.55627441e-02],
                        [  6.15539551e-02,   6.15539551e-02],
                        [  7.55310059e-02,   7.55615234e-02],
                        [  8.88366699e-02,   8.88366699e-02],
                        [  9.71679688e-02,   9.71679688e-02],
                        [  9.53674316e-02,   9.53674316e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  7.46459961e-02,   7.46459961e-02],
                        [  6.10046387e-02,   6.10046387e-02],
                        [  4.23889160e-02,   4.23889160e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  1.00708008e-03,   1.00708008e-03],
                        [ -1.05285645e-02,  -1.05285645e-02],
                        [ -1.31835938e-02,  -1.31835938e-02],
                        [ -9.27734375e-03,  -9.30786133e-03],
                        [ -3.11279297e-03,  -3.11279297e-03],
                        [  1.83105469e-03,   1.86157227e-03],
                        [  7.08007812e-03,   7.08007812e-03],
                        [  1.68457031e-02,   1.68457031e-02],
                        [  2.93579102e-02,   2.93579102e-02],
                        [  3.50341797e-02,   3.50341797e-02],
                        [  2.64892578e-02,   2.64892578e-02],
                        [  8.42285156e-03,   8.42285156e-03],
                        [ -6.83593750e-03,  -6.83593750e-03],
                        [ -1.23291016e-02,  -1.23291016e-02],
                        [ -1.05895996e-02,  -1.06201172e-02],
                        [ -5.76782227e-03,  -5.76782227e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  8.54492188e-03,   8.54492188e-03],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.92260742e-02,   1.92260742e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  6.40869141e-03,   6.43920898e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -1.28173828e-02,  -1.28173828e-02],
                        [ -2.03857422e-02,  -2.03857422e-02],
                        [ -2.93884277e-02,  -2.93884277e-02],
                        [ -3.80554199e-02,  -3.80554199e-02],
                        [ -4.34570312e-02,  -4.34570312e-02],
                        [ -4.35485840e-02,  -4.35485840e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -2.85339355e-02,  -2.85339355e-02],
                        [ -1.57775879e-02,  -1.57775879e-02],
                        [ -5.24902344e-03,  -5.24902344e-03],
                        [ -1.46484375e-03,  -1.46484375e-03],
                        [ -2.16674805e-03,  -2.16674805e-03],
                        [ -1.12915039e-03,  -1.12915039e-03],
                        [  4.54711914e-03,   4.54711914e-03],
                        [  1.24511719e-02,   1.24511719e-02],
                        [  1.73645020e-02,   1.73645020e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  6.01196289e-03,   6.01196289e-03],
                        [ -8.36181641e-03,  -8.36181641e-03],
                        [ -2.37121582e-02,  -2.37121582e-02],
                        [ -3.64990234e-02,  -3.64990234e-02],
                        [ -4.70581055e-02,  -4.70581055e-02],
                        [ -5.85632324e-02,  -5.85632324e-02],
                        [ -7.20214844e-02,  -7.20214844e-02],
                        [ -8.30688477e-02,  -8.30688477e-02],
                        [ -8.34045410e-02,  -8.34045410e-02],
                        [ -6.56127930e-02,  -6.56127930e-02],
                        [ -2.83508301e-02,  -2.83203125e-02],
                        [  2.10876465e-02,   2.10876465e-02],
                        [  7.11364746e-02,   7.11364746e-02],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.45874023e-01,   1.45874023e-01],
                        [  1.63085938e-01,   1.63085938e-01],
                        [  1.57714844e-01,   1.57714844e-01],
                        [  1.17858887e-01,   1.17858887e-01],
                        [  3.31420898e-02,   3.31420898e-02],
                        [ -9.48181152e-02,  -9.48181152e-02],
                        [ -2.41638184e-01,  -2.41638184e-01],
                        [ -3.63647461e-01,  -3.63647461e-01],
                        [ -4.21966553e-01,  -4.21966553e-01],
                        [ -4.06585693e-01,  -4.06585693e-01],
                        [ -3.39050293e-01,  -3.39050293e-01],
                        [ -2.56011963e-01,  -2.56011963e-01],
                        [ -1.83227539e-01,  -1.83227539e-01],
                        [ -1.19354248e-01,  -1.19354248e-01],
                        [ -4.80346680e-02,  -4.80346680e-02],
                        [  3.43017578e-02,   3.43017578e-02],
                        [  1.07727051e-01,   1.07727051e-01],
                        [  1.47583008e-01,   1.47583008e-01],
                        [  1.49536133e-01,   1.49536133e-01],
                        [  1.30462646e-01,   1.30462646e-01],
                        [  1.10992432e-01,   1.10992432e-01],
                        [  1.01348877e-01,   1.01348877e-01],
                        [  9.79614258e-02,   9.79614258e-02],
                        [  9.14916992e-02,   9.14916992e-02],
                        [  7.94677734e-02,   7.94677734e-02],
                        [  6.89086914e-02,   6.88781738e-02],
                        [  6.51855469e-02,   6.52160645e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  4.73022461e-02,   4.72717285e-02],
                        [  2.21557617e-02,   2.21557617e-02],
                        [  0.00000000e+00,   0.00000000e+00],
                        [ -6.74438477e-03,  -6.74438477e-03],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.93176270e-02,   1.93176270e-02],
                        [  3.58581543e-02,   3.58581543e-02],
                        [  4.67529297e-02,   4.67224121e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  6.27441406e-02,   6.27441406e-02],
                        [  7.80029297e-02,   7.80029297e-02],
                        [  9.02404785e-02,   9.02404785e-02],
                        [  9.12475586e-02,   9.12475586e-02],
                        [  8.12683105e-02,   8.12683105e-02],
                        [  6.50939941e-02,   6.50939941e-02],
                        [  4.74853516e-02,   4.75158691e-02],
                        [  3.26843262e-02,   3.26843262e-02],
                        [  2.34375000e-02,   2.34069824e-02],
                        [  1.84020996e-02,   1.84020996e-02],
                        [  1.47399902e-02,   1.47399902e-02],
                        [  1.39770508e-02,   1.39770508e-02],
                        [  1.81579590e-02,   1.81579590e-02],
                        [  2.23693848e-02,   2.23999023e-02],
                        [  1.88903809e-02,   1.88903809e-02],
                        [  7.59887695e-03,   7.59887695e-03],
                        [ -3.05175781e-03,  -3.05175781e-03],
                        [ -5.43212891e-03,  -5.43212891e-03],
                        [ -8.23974609e-04,  -8.23974609e-04],
                        [  3.14331055e-03,   3.14331055e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [ -5.61523438e-03,  -5.61523438e-03],
                        [ -1.14135742e-02,  -1.14135742e-02],
                        [ -1.24206543e-02,  -1.24206543e-02],
                        [ -8.54492188e-03,  -8.54492188e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  4.02832031e-03,   4.02832031e-03],
                        [  9.42993164e-03,   9.42993164e-03],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  9.06372070e-03,   9.06372070e-03],
                        [  3.78417969e-03,   3.78417969e-03],
                        [  9.15527344e-04,   9.15527344e-04],
                        [  3.02124023e-03,   2.99072266e-03],
                        [  6.53076172e-03,   6.53076172e-03],
                        [  5.92041016e-03,   5.92041016e-03],
                        [  7.32421875e-04,   7.32421875e-04],
                        [ -5.03540039e-03,  -5.06591797e-03],
                        [ -9.03320312e-03,  -9.00268555e-03],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -1.53808594e-02,  -1.53808594e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -2.17590332e-02,  -2.17590332e-02],
                        [ -2.42614746e-02,  -2.42614746e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -4.10766602e-02,  -4.10766602e-02],
                        [ -4.82177734e-02,  -4.82177734e-02],
                        [ -4.66308594e-02,  -4.66308594e-02],
                        [ -4.02221680e-02,  -4.02221680e-02],
                        [ -3.63464355e-02,  -3.63464355e-02],
                        [ -3.56750488e-02,  -3.56750488e-02],
                        [ -3.31726074e-02,  -3.31726074e-02],
                        [ -2.59704590e-02,  -2.59704590e-02],
                        [ -1.53198242e-02,  -1.52893066e-02],
                        [ -4.79125977e-03,  -4.79125977e-03],
                        [  2.44140625e-03,   2.44140625e-03],
                        [  6.77490234e-03,   6.80541992e-03],
                        [  9.15527344e-03,   9.12475586e-03],
                        [  4.66918945e-03,   4.63867188e-03],
                        [ -1.23596191e-02,  -1.23291016e-02],
                        [ -3.73535156e-02,  -3.73535156e-02],
                        [ -5.56945801e-02,  -5.56945801e-02],
                        [ -5.39855957e-02,  -5.39855957e-02],
                        [ -2.97241211e-02,  -2.97241211e-02],
                        [  9.00268555e-03,   9.00268555e-03],
                        [  5.17272949e-02,   5.17272949e-02],
                        [  9.33227539e-02,   9.33227539e-02],
                        [  1.33239746e-01,   1.33239746e-01],
                        [  1.67175293e-01,   1.67175293e-01],
                        [  1.82098389e-01,   1.82098389e-01],
                        [  1.58233643e-01,   1.58233643e-01],
                        [  7.68737793e-02,   7.68432617e-02],
                        [ -6.15844727e-02,  -6.15844727e-02],
                        [ -2.22625732e-01,  -2.22625732e-01],
                        [ -3.52783203e-01,  -3.52783203e-01],
                        [ -4.13543701e-01,  -4.13543701e-01],
                        [ -3.99780273e-01,  -3.99780273e-01],
                        [ -3.36914062e-01,  -3.36914062e-01],
                        [ -2.63397217e-01,  -2.63397217e-01],
                        [ -2.04650879e-01,  -2.04650879e-01],
                        [ -1.56433105e-01,  -1.56433105e-01],
                        [ -9.84802246e-02,  -9.84802246e-02],
                        [ -2.64892578e-02,  -2.64892578e-02],
                        [  3.81774902e-02,   3.81774902e-02],
                        [  7.32116699e-02,   7.32116699e-02],
                        [  7.96508789e-02,   7.96508789e-02],
                        [  7.92541504e-02,   7.92541504e-02],
                        [  9.18273926e-02,   9.18273926e-02],
                        [  1.17004395e-01,   1.16973877e-01],
                        [  1.39373779e-01,   1.39373779e-01],
                        [  1.46789551e-01,   1.46789551e-01],
                        [  1.39862061e-01,   1.39862061e-01],
                        [  1.27563477e-01,   1.27563477e-01],
                        [  1.16149902e-01,   1.16149902e-01],
                        [  1.02325439e-01,   1.02325439e-01],
                        [  8.10546875e-02,   8.10546875e-02],
                        [  5.73120117e-02,   5.72814941e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  3.70483398e-02,   3.70483398e-02],
                        [  3.64379883e-02,   3.64379883e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.97644043e-02,   3.97644043e-02],
                        [  4.42504883e-02,   4.42504883e-02],
                        [  4.65393066e-02,   4.65393066e-02],
                        [  4.79431152e-02,   4.79431152e-02],
                        [  5.20019531e-02,   5.20019531e-02],
                        [  5.70678711e-02,   5.70678711e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  4.58679199e-02,   4.58679199e-02],
                        [  2.78930664e-02,   2.78930664e-02],
                        [  1.34887695e-02,   1.34887695e-02],
                        [  1.19628906e-02,   1.19628906e-02],
                        [  2.06604004e-02,   2.06604004e-02],
                        [  2.71301270e-02,   2.71301270e-02],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  8.88061523e-03,   8.88061523e-03],
                        [ -2.28881836e-03,  -2.28881836e-03],
                        [ -2.86865234e-03,  -2.86865234e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  2.79541016e-02,   2.79541016e-02],
                        [  4.51965332e-02,   4.51965332e-02],
                        [  5.14831543e-02,   5.14831543e-02],
                        [  4.30603027e-02,   4.30603027e-02],
                        [  2.46887207e-02,   2.46887207e-02],
                        [  6.98852539e-03,   6.98852539e-03],
                        [ -1.25122070e-03,  -1.25122070e-03],
                        [  1.83105469e-03,   1.83105469e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  1.55029297e-02,   1.55029297e-02],
                        [  1.44042969e-02,   1.44042969e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  2.02331543e-02,   2.02331543e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  2.55432129e-02,   2.55432129e-02],
                        [  2.63977051e-02,   2.63977051e-02],
                        [  2.72216797e-02,   2.71911621e-02],
                        [  2.46276855e-02,   2.46276855e-02],
                        [  1.56860352e-02,   1.57165527e-02],
                        [  2.34985352e-03,   2.34985352e-03],
                        [ -8.88061523e-03,  -8.88061523e-03],
                        [ -1.37634277e-02,  -1.37634277e-02],
                        [ -1.56250000e-02,  -1.56250000e-02],
                        [ -2.09655762e-02,  -2.09655762e-02],
                        [ -3.24707031e-02,  -3.24707031e-02],
                        [ -4.79125977e-02,  -4.78820801e-02],
                        [ -6.42700195e-02,  -6.42700195e-02],
                        [ -7.95898438e-02,  -7.95898438e-02],
                        [ -9.04235840e-02,  -9.04235840e-02],
                        [ -9.17358398e-02,  -9.17358398e-02],
                        [ -8.12683105e-02,  -8.12683105e-02],
                        [ -6.22863770e-02,  -6.22863770e-02],
                        [ -4.12902832e-02,  -4.12902832e-02],
                        [ -2.35900879e-02,  -2.35900879e-02],
                        [ -1.01013184e-02,  -1.01013184e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  3.57360840e-02,   3.57360840e-02],
                        [  5.23071289e-02,   5.23376465e-02],
                        [  6.28051758e-02,   6.28051758e-02],
                        [  6.43615723e-02,   6.43615723e-02],
                        [  5.40161133e-02,   5.40161133e-02],
                        [  2.87170410e-02,   2.87170410e-02],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -4.42504883e-02,  -4.42504883e-02],
                        [ -6.36291504e-02,  -6.35986328e-02],
                        [ -5.90820312e-02,  -5.90820312e-02],
                        [ -3.32641602e-02,  -3.32641602e-02],
                        [  5.73730469e-03,   5.73730469e-03],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  8.14819336e-02,   8.14819336e-02],
                        [  9.87854004e-02,   9.87854004e-02],
                        [  9.48486328e-02,   9.48486328e-02],
                        [  6.33239746e-02,   6.33239746e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [ -1.09619141e-01,  -1.09619141e-01],
                        [ -2.27233887e-01,  -2.27203369e-01],
                        [ -3.17901611e-01,  -3.17901611e-01],
                        [ -3.49792480e-01,  -3.49792480e-01],
                        [ -3.20007324e-01,  -3.20007324e-01],
                        [ -2.54394531e-01,  -2.54394531e-01],
                        [ -1.87683105e-01,  -1.87683105e-01],
                        [ -1.38305664e-01,  -1.38305664e-01],
                        [ -9.90600586e-02,  -9.90600586e-02],
                        [ -5.24597168e-02,  -5.24597168e-02],
                        [  5.79833984e-03,   5.79833984e-03],
                        [  5.89904785e-02,   5.89904785e-02],
                        [  8.60595703e-02,   8.60595703e-02],
                        [  8.43811035e-02,   8.43811035e-02],
                        [  7.19909668e-02,   7.19909668e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  7.06481934e-02,   7.06481934e-02],
                        [  7.20520020e-02,   7.20520020e-02],
                        [  6.85424805e-02,   6.85424805e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  6.48803711e-02,   6.48803711e-02],
                        [  6.44531250e-02,   6.44836426e-02],
                        [  6.21643066e-02,   6.21643066e-02],
                        [  5.66101074e-02,   5.66101074e-02],
                        [  4.79125977e-02,   4.79125977e-02],
                        [  3.96423340e-02,   3.96423340e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  4.72106934e-02,   4.72106934e-02],
                        [  6.25610352e-02,   6.25610352e-02],
                        [  7.79724121e-02,   7.79724121e-02],
                        [  8.93554688e-02,   8.93554688e-02],
                        [  9.45129395e-02,   9.45129395e-02],
                        [  9.36889648e-02,   9.36889648e-02],
                        [  8.84399414e-02,   8.84399414e-02],
                        [  7.80334473e-02,   7.80334473e-02],
                        [  5.95703125e-02,   5.95703125e-02],
                        [  3.34777832e-02,   3.34777832e-02],
                        [  8.17871094e-03,   8.17871094e-03],
                        [ -6.62231445e-03,  -6.62231445e-03],
                        [ -1.10778809e-02,  -1.10778809e-02],
                        [ -1.20239258e-02,  -1.20239258e-02],
                        [ -1.18713379e-02,  -1.18713379e-02],
                        [ -7.38525391e-03,  -7.38525391e-03],
                        [  3.32641602e-03,   3.35693359e-03],
                        [  1.77001953e-02,   1.77001953e-02],
                        [  3.02734375e-02,   3.02734375e-02],
                        [  3.51867676e-02,   3.51867676e-02],
                        [  2.94189453e-02,   2.94189453e-02],
                        [  1.63269043e-02,   1.63269043e-02],
                        [  2.99072266e-03,   2.99072266e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -1.28784180e-02,  -1.29089355e-02],
                        [ -1.37329102e-02,  -1.37329102e-02],
                        [ -5.21850586e-03,  -5.21850586e-03],
                        [  1.10778809e-02,   1.10778809e-02],
                        [  2.76794434e-02,   2.76794434e-02],
                        [  3.99169922e-02,   3.99169922e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  5.02929688e-02,   5.02624512e-02],
                        [  4.33044434e-02,   4.33044434e-02],
                        [  2.77099609e-02,   2.77099609e-02],
                        [  1.12915039e-02,   1.12915039e-02],
                        [  9.46044922e-04,   9.15527344e-04],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -2.19726562e-03,  -2.19726562e-03],
                        [ -2.10571289e-03,  -2.13623047e-03],
                        [ -6.16455078e-03,  -6.13403320e-03],
                        [ -1.31530762e-02,  -1.31225586e-02],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.05993652e-02,  -2.05993652e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.33666992e-02,  -1.33666992e-02],
                        [ -1.31225586e-02,  -1.31225586e-02],
                        [ -1.90734863e-02,  -1.90734863e-02],
                        [ -3.15856934e-02,  -3.15856934e-02],
                        [ -4.75158691e-02,  -4.75463867e-02],
                        [ -6.18591309e-02,  -6.18591309e-02],
                        [ -7.08312988e-02,  -7.08312988e-02],
                        [ -7.44323730e-02,  -7.44323730e-02],
                        [ -7.26013184e-02,  -7.26013184e-02],
                        [ -6.28662109e-02,  -6.28662109e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -2.53601074e-02,  -2.53601074e-02],
                        [ -8.78906250e-03,  -8.78906250e-03],
                        [  4.39453125e-03,   4.39453125e-03],
                        [  1.87988281e-02,   1.87988281e-02],
                        [  3.56140137e-02,   3.56140137e-02],
                        [  5.05981445e-02,   5.06286621e-02],
                        [  5.69763184e-02,   5.69458008e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  2.46276855e-02,   2.46582031e-02],
                        [ -4.82177734e-03,  -4.82177734e-03],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [ -2.52685547e-02,  -2.52380371e-02],
                        [ -2.01416016e-03,  -2.01416016e-03],
                        [  3.72314453e-02,   3.72314453e-02],
                        [  8.12988281e-02,   8.12988281e-02],
                        [  1.15112305e-01,   1.15112305e-01],
                        [  1.23382568e-01,   1.23382568e-01],
                        [  9.81445312e-02,   9.81445312e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [ -5.00183105e-02,  -5.00183105e-02],
                        [ -1.62902832e-01,  -1.62902832e-01],
                        [ -2.77404785e-01,  -2.77404785e-01],
                        [ -3.57208252e-01,  -3.57208252e-01],
                        [ -3.75213623e-01,  -3.75213623e-01],
                        [ -3.35510254e-01,  -3.35510254e-01],
                        [ -2.66845703e-01,  -2.66845703e-01],
                        [ -1.98455811e-01,  -1.98455811e-01],
                        [ -1.42883301e-01,  -1.42883301e-01],
                        [ -9.45434570e-02,  -9.45434570e-02],
                        [ -4.26025391e-02,  -4.26025391e-02],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  5.26123047e-02,   5.26123047e-02],
                        [  6.68945312e-02,   6.68945312e-02],
                        [  6.03637695e-02,   6.03637695e-02],
                        [  5.35583496e-02,   5.35583496e-02],
                        [  6.17675781e-02,   6.17675781e-02],
                        [  8.23059082e-02,   8.23059082e-02],
                        [  1.02020264e-01,   1.02020264e-01],
                        [  1.12426758e-01,   1.12426758e-01],
                        [  1.13922119e-01,   1.13922119e-01],
                        [  1.10137939e-01,   1.10137939e-01],
                        [  1.03332520e-01,   1.03332520e-01],
                        [  9.47570801e-02,   9.47570801e-02],
                        [  8.57543945e-02,   8.57543945e-02],
                        [  7.69653320e-02,   7.69653320e-02],
                        [  6.89392090e-02,   6.89392090e-02],
                        [  6.25305176e-02,   6.25305176e-02],
                        [  5.65490723e-02,   5.65490723e-02],
                        [  5.01403809e-02,   5.01403809e-02],
                        [  4.55017090e-02,   4.55017090e-02],
                        [  4.49218750e-02,   4.49218750e-02],
                        [  4.81262207e-02,   4.81262207e-02],
                        [  5.25207520e-02,   5.25207520e-02],
                        [  5.44128418e-02,   5.44128418e-02],
                        [  5.22460938e-02,   5.22155762e-02],
                        [  4.82177734e-02,   4.82177734e-02],
                        [  4.45556641e-02,   4.45556641e-02],
                        [  3.96118164e-02,   3.96118164e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  2.44140625e-02,   2.44445801e-02],
                        [  2.29492188e-02,   2.29492188e-02],
                        [  2.86865234e-02,   2.86865234e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.10156250e-02,   4.10156250e-02],
                        [  3.17993164e-02,   3.17687988e-02],
                        [  1.21459961e-02,   1.21459961e-02],
                        [ -6.50024414e-03,  -6.50024414e-03],
                        [ -1.43432617e-02,  -1.43432617e-02],
                        [ -9.76562500e-03,  -9.76562500e-03],
                        [  2.99072266e-03,   2.99072266e-03],
                        [  1.67846680e-02,   1.67541504e-02],
                        [  2.38952637e-02,   2.38647461e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  1.70593262e-02,   1.70593262e-02],
                        [  1.39465332e-02,   1.39160156e-02],
                        [  1.57470703e-02,   1.57470703e-02],
                        [  2.28271484e-02,   2.28271484e-02],
                        [  3.22265625e-02,   3.22265625e-02],
                        [  3.96728516e-02,   3.96423340e-02],
                        [  4.24499512e-02,   4.24499512e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  3.00292969e-02,   3.00292969e-02],
                        [  1.76696777e-02,   1.76696777e-02],
                        [  5.67626953e-03,   5.67626953e-03],
                        [ -4.48608398e-03,  -4.51660156e-03],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -1.84631348e-02,  -1.84631348e-02],
                        [ -2.07214355e-02,  -2.07214355e-02],
                        [ -2.23388672e-02,  -2.23388672e-02],
                        [ -2.59094238e-02,  -2.58789062e-02],
                        [ -3.03344727e-02,  -3.03344727e-02],
                        [ -3.20434570e-02,  -3.20434570e-02],
                        [ -2.76489258e-02,  -2.76489258e-02],
                        [ -1.91650391e-02,  -1.91650391e-02],
                        [ -1.45568848e-02,  -1.45568848e-02],
                        [ -1.92871094e-02,  -1.92871094e-02],
                        [ -3.07006836e-02,  -3.07006836e-02],
                        [ -4.18701172e-02,  -4.18701172e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -4.43115234e-02,  -4.43115234e-02],
                        [ -3.87573242e-02,  -3.87573242e-02],
                        [ -3.75976562e-02,  -3.75976562e-02],
                        [ -4.35485840e-02,  -4.35791016e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.76379395e-02,  -4.76379395e-02],
                        [ -3.51257324e-02,  -3.51562500e-02],
                        [ -1.72424316e-02,  -1.72424316e-02],
                        [  5.18798828e-04,   5.18798828e-04],
                        [  1.35192871e-02,   1.35192871e-02],
                        [  1.97143555e-02,   1.97143555e-02],
                        [  1.97448730e-02,   1.97448730e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  1.86157227e-03,   1.86157227e-03],
                        [ -1.60217285e-02,  -1.60217285e-02],
                        [ -3.36914062e-02,  -3.36914062e-02],
                        [ -4.37927246e-02,  -4.37927246e-02],
                        [ -4.37622070e-02,  -4.37622070e-02],
                        [ -3.46679688e-02,  -3.46679688e-02],
                        [ -1.84020996e-02,  -1.84020996e-02],
                        [  2.92968750e-03,   2.89916992e-03],
                        [  2.78015137e-02,   2.78015137e-02],
                        [  5.49926758e-02,   5.49926758e-02],
                        [  8.29772949e-02,   8.29772949e-02],
                        [  1.09344482e-01,   1.09344482e-01],
                        [  1.29486084e-01,   1.29486084e-01],
                        [  1.38854980e-01,   1.38854980e-01],
                        [  1.34765625e-01,   1.34765625e-01],
                        [  1.12213135e-01,   1.12213135e-01],
                        [  6.06384277e-02,   6.06689453e-02],
                        [ -2.89916992e-02,  -2.90222168e-02],
                        [ -1.47552490e-01,  -1.47521973e-01],
                        [ -2.60711670e-01,  -2.60711670e-01],
                        [ -3.28308105e-01,  -3.28308105e-01],
                        [ -3.31359863e-01,  -3.31359863e-01],
                        [ -2.84240723e-01,  -2.84210205e-01],
                        [ -2.23449707e-01,  -2.23449707e-01],
                        [ -1.77886963e-01,  -1.77886963e-01],
                        [ -1.46759033e-01,  -1.46759033e-01],
                        [ -1.09100342e-01,  -1.09100342e-01],
                        [ -5.24902344e-02,  -5.24902344e-02],
                        [  1.02844238e-02,   1.02844238e-02],
                        [  5.41381836e-02,   5.41381836e-02],
                        [  6.83593750e-02,   6.83288574e-02],
                        [  6.46667480e-02,   6.46667480e-02],
                        [  6.26220703e-02,   6.26220703e-02],
                        [  7.15942383e-02,   7.15942383e-02],
                        [  8.80126953e-02,   8.80126953e-02],
                        [  1.04980469e-01,   1.05010986e-01],
                        [  1.17126465e-01,   1.17126465e-01],
                        [  1.19689941e-01,   1.19689941e-01],
                        [  1.12091064e-01,   1.12091064e-01],
                        [  9.94873047e-02,   9.94873047e-02],
                        [  8.67614746e-02,   8.67309570e-02],
                        [  7.43103027e-02,   7.43103027e-02],
                        [  6.16455078e-02,   6.16455078e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  4.71801758e-02,   4.71801758e-02],
                        [  4.68139648e-02,   4.68139648e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  3.91235352e-02,   3.90930176e-02],
                        [  3.24096680e-02,   3.24096680e-02],
                        [  3.08227539e-02,   3.08227539e-02],
                        [  3.61328125e-02,   3.61328125e-02],
                        [  4.50439453e-02,   4.50439453e-02],
                        [  5.15441895e-02,   5.15441895e-02],
                        [  4.94995117e-02,   4.94995117e-02],
                        [  3.79638672e-02,   3.79638672e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  1.76086426e-02,   1.76086426e-02],
                        [  1.82189941e-02,   1.81884766e-02],
                        [  1.75781250e-02,   1.75781250e-02],
                        [  9.42993164e-03,   9.42993164e-03],
                        [ -3.44848633e-03,  -3.44848633e-03],
                        [ -1.36718750e-02,  -1.36718750e-02],
                        [ -1.64184570e-02,  -1.64184570e-02],
                        [ -1.26647949e-02,  -1.26647949e-02],
                        [ -7.04956055e-03,  -7.04956055e-03],
                        [ -1.52587891e-03,  -1.52587891e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.76391602e-02,   1.76391602e-02],
                        [  2.70996094e-02,   2.70996094e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  2.12097168e-02,   2.12097168e-02],
                        [  1.72729492e-02,   1.72729492e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  1.98364258e-02,   1.98364258e-02],
                        [  2.67944336e-02,   2.67944336e-02],
                        [  3.15856934e-02,   3.15856934e-02],
                        [  2.88085938e-02,   2.88085938e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [ -2.41088867e-03,  -2.38037109e-03],
                        [ -8.69750977e-03,  -8.72802734e-03],
                        [ -1.41906738e-02,  -1.41906738e-02],
                        [ -1.65405273e-02,  -1.65100098e-02],
                        [ -1.23596191e-02,  -1.23596191e-02],
                        [ -1.95312500e-03,  -1.95312500e-03],
                        [  1.05590820e-02,   1.05590820e-02],
                        [  1.72729492e-02,   1.73034668e-02],
                        [  1.14746094e-02,   1.14746094e-02],
                        [ -5.06591797e-03,  -5.06591797e-03],
                        [ -2.28576660e-02,  -2.28576660e-02],
                        [ -3.38745117e-02,  -3.38745117e-02],
                        [ -3.86962891e-02,  -3.86962891e-02],
                        [ -4.19921875e-02,  -4.19921875e-02],
                        [ -4.48913574e-02,  -4.48913574e-02],
                        [ -4.69665527e-02,  -4.69970703e-02],
                        [ -4.79431152e-02,  -4.79431152e-02],
                        [ -4.53491211e-02,  -4.53491211e-02],
                        [ -3.78417969e-02,  -3.78723145e-02],
                        [ -2.72521973e-02,  -2.72521973e-02],
                        [ -1.81579590e-02,  -1.81579590e-02],
                        [ -1.77307129e-02,  -1.77307129e-02],
                        [ -2.86865234e-02,  -2.86865234e-02],
                        [ -4.45556641e-02,  -4.45861816e-02],
                        [ -5.56030273e-02,  -5.56030273e-02],
                        [ -5.65490723e-02,  -5.65490723e-02],
                        [ -4.91943359e-02,  -4.92248535e-02],
                        [ -3.77502441e-02,  -3.77502441e-02],
                        [ -2.48413086e-02,  -2.48413086e-02],
                        [ -1.26647949e-02,  -1.26953125e-02],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [  6.01196289e-03,   6.01196289e-03],
                        [  1.13220215e-02,   1.13220215e-02],
                        [  1.46179199e-02,   1.46179199e-02],
                        [  1.87072754e-02,   1.87072754e-02],
                        [  2.25219727e-02,   2.25219727e-02],
                        [  2.20947266e-02,   2.20947266e-02],
                        [  1.56250000e-02,   1.56250000e-02],
                        [  5.88989258e-03,   5.92041016e-03],
                        [ -2.77709961e-03,  -2.77709961e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -1.24816895e-02,  -1.24511719e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  2.21862793e-02,   2.21862793e-02],
                        [  5.62133789e-02,   5.62133789e-02],
                        [  9.67712402e-02,   9.67712402e-02],
                        [  1.38549805e-01,   1.38549805e-01],
                        [  1.75170898e-01,   1.75170898e-01],
                        [  1.97998047e-01,   1.97998047e-01],
                        [  1.95861816e-01,   1.95831299e-01],
                        [  1.55273438e-01,   1.55273438e-01],
                        [  6.85729980e-02,   6.85729980e-02],
                        [ -5.57250977e-02,  -5.57250977e-02],
                        [ -1.92443848e-01,  -1.92443848e-01],
                        [ -3.07830811e-01,  -3.07830811e-01],
                        [ -3.72833252e-01,  -3.72833252e-01],
                        [ -3.77471924e-01,  -3.77471924e-01],
                        [ -3.36914062e-01,  -3.36914062e-01],
                        [ -2.79632568e-01,  -2.79632568e-01],
                        [ -2.24243164e-01,  -2.24243164e-01],
                        [ -1.68792725e-01,  -1.68792725e-01],
                        [ -1.03637695e-01,  -1.03637695e-01],
                        [ -2.89916992e-02,  -2.89916992e-02],
                        [  4.20227051e-02,   4.20227051e-02],
                        [  9.31701660e-02,   9.31701660e-02],
                        [  1.17034912e-01,   1.17065430e-01],
                        [  1.19079590e-01,   1.19079590e-01],
                        [  1.11694336e-01,   1.11694336e-01],
                        [  1.05957031e-01,   1.05957031e-01],
                        [  1.05285645e-01,   1.05285645e-01],
                        [  1.04431152e-01,   1.04431152e-01],
                        [  9.68322754e-02,   9.68322754e-02],
                        [  8.17871094e-02,   8.17871094e-02],
                        [  6.35375977e-02,   6.35375977e-02],
                        [  4.62341309e-02,   4.62341309e-02],
                        [  3.13110352e-02,   3.13110352e-02],
                        [  1.91650391e-02,   1.91650391e-02],
                        [  1.09558105e-02,   1.09558105e-02],
                        [  7.17163086e-03,   7.14111328e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.08337402e-02,   1.08337402e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  3.74755859e-02,   3.74755859e-02],
                        [  5.57556152e-02,   5.57556152e-02],
                        [  6.63146973e-02,   6.63146973e-02],
                        [  6.53686523e-02,   6.53686523e-02],
                        [  5.81359863e-02,   5.81359863e-02],
                        [  5.16052246e-02,   5.16052246e-02],
                        [  4.76074219e-02,   4.76074219e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  4.04663086e-02,   4.04968262e-02],
                        [  3.91845703e-02,   3.91845703e-02],
                        [  4.10461426e-02,   4.10461426e-02],
                        [  4.21142578e-02,   4.21142578e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  1.80664062e-02,   1.80664062e-02],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -1.94091797e-02,  -1.93786621e-02],
                        [ -2.84118652e-02,  -2.84118652e-02],
                        [ -3.31420898e-02,  -3.31420898e-02],
                        [ -3.42102051e-02,  -3.42102051e-02],
                        [ -2.99682617e-02,  -2.99682617e-02],
                        [ -2.15454102e-02,  -2.15454102e-02],
                        [ -1.19323730e-02,  -1.19323730e-02],
                        [ -8.54492188e-04,  -8.54492188e-04],
                        [  1.33056641e-02,   1.32751465e-02],
                        [  2.79235840e-02,   2.79235840e-02],
                        [  3.78112793e-02,   3.78112793e-02],
                        [  3.94592285e-02,   3.94592285e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  3.01818848e-02,   3.02124023e-02],
                        [  3.06396484e-02,   3.06396484e-02],
                        [  3.50036621e-02,   3.50036621e-02],
                        [  3.80859375e-02,   3.80859375e-02],
                        [  3.59802246e-02,   3.60107422e-02],
                        [  2.98461914e-02,   2.98461914e-02],
                        [  2.39868164e-02,   2.39868164e-02],
                        [  2.19421387e-02,   2.19421387e-02],
                        [  2.49023438e-02,   2.49023438e-02],
                        [  3.12500000e-02,   3.12500000e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  3.57666016e-02,   3.57666016e-02],
                        [  2.41394043e-02,   2.41394043e-02],
                        [  1.64794922e-03,   1.64794922e-03],
                        [ -2.67028809e-02,  -2.67028809e-02],
                        [ -5.25207520e-02,  -5.25207520e-02],
                        [ -6.73828125e-02,  -6.73828125e-02],
                        [ -6.82678223e-02,  -6.82678223e-02],
                        [ -6.06994629e-02,  -6.06994629e-02],
                        [ -5.28564453e-02,  -5.28564453e-02],
                        [ -4.68750000e-02,  -4.68750000e-02],
                        [ -3.94897461e-02,  -3.94897461e-02],
                        [ -2.94189453e-02,  -2.94189453e-02],
                        [ -1.95007324e-02,  -1.95007324e-02],
                        [ -1.26953125e-02,  -1.26953125e-02],
                        [ -9.49096680e-03,  -9.49096680e-03],
                        [ -8.91113281e-03,  -8.91113281e-03],
                        [ -9.30786133e-03,  -9.30786133e-03],
                        [ -8.23974609e-03,  -8.23974609e-03],
                        [ -4.42504883e-03,  -4.42504883e-03],
                        [ -2.34985352e-03,  -2.34985352e-03],
                        [ -9.12475586e-03,  -9.12475586e-03],
                        [ -2.50244141e-02,  -2.50244141e-02],
                        [ -4.18395996e-02,  -4.18395996e-02],
                        [ -5.05981445e-02,  -5.05676270e-02],
                        [ -4.80651855e-02,  -4.80651855e-02],
                        [ -3.67736816e-02,  -3.67736816e-02],
                        [ -2.13623047e-02,  -2.13623047e-02],
                        [ -8.48388672e-03,  -8.48388672e-03],
                        [ -3.78417969e-03,  -3.78417969e-03],
                        [ -4.94384766e-03,  -4.94384766e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  3.84521484e-03,   3.84521484e-03],
                        [  1.56860352e-02,   1.56860352e-02],
                        [  2.67639160e-02,   2.67639160e-02],
                        [  3.49731445e-02,   3.50036621e-02],
                        [  4.06494141e-02,   4.06494141e-02],
                        [  4.35791016e-02,   4.35791016e-02],
                        [  4.55932617e-02,   4.55932617e-02],
                        [  5.07202148e-02,   5.07202148e-02],
                        [  6.00585938e-02,   6.00585938e-02],
                        [  7.20825195e-02,   7.20825195e-02],
                        [  8.74328613e-02,   8.74328613e-02],
                        [  1.07971191e-01,   1.07971191e-01],
                        [  1.31256104e-01,   1.31256104e-01],
                        [  1.49139404e-01,   1.49139404e-01],
                        [  1.53045654e-01,   1.53045654e-01],
                        [  1.36138916e-01,   1.36138916e-01],
                        [  9.09118652e-02,   9.09118652e-02],
                        [  1.19934082e-02,   1.19934082e-02],
                        [ -9.58862305e-02,  -9.58862305e-02],
                        [ -2.14874268e-01,  -2.14874268e-01],
                        [ -3.17535400e-01,  -3.17535400e-01],
                        [ -3.76251221e-01,  -3.76251221e-01],
                        [ -3.77044678e-01,  -3.77044678e-01],
                        [ -3.29284668e-01,  -3.29254150e-01],
                        [ -2.60589600e-01,  -2.60620117e-01],
                        [ -1.96990967e-01,  -1.96990967e-01],
                        [ -1.44165039e-01,  -1.44165039e-01],
                        [ -9.03320312e-02,  -9.03320312e-02],
                        [ -2.57873535e-02,  -2.57873535e-02],
                        [  4.20837402e-02,   4.20837402e-02],
                        [  9.29565430e-02,   9.29565430e-02],
                        [  1.11907959e-01,   1.11907959e-01],
                        [  1.03454590e-01,   1.03454590e-01],
                        [  8.61206055e-02,   8.61206055e-02],
                        [  7.44934082e-02,   7.44628906e-02],
                        [  6.93969727e-02,   6.93969727e-02],
                        [  6.47277832e-02,   6.47277832e-02],
                        [  5.57861328e-02,   5.57861328e-02],
                        [  4.09545898e-02,   4.09545898e-02],
                        [  2.29797363e-02,   2.29797363e-02],
                        [  9.52148438e-03,   9.55200195e-03],
                        [  6.16455078e-03,   6.16455078e-03],
                        [  1.03454590e-02,   1.03454590e-02],
                        [  1.66625977e-02,   1.66625977e-02],
                        [  2.42919922e-02,   2.42919922e-02],
                        [  3.59191895e-02,   3.59191895e-02],
                        [  5.11779785e-02,   5.11779785e-02],
                        [  6.54907227e-02,   6.54907227e-02],
                        [  7.47070312e-02,   7.47070312e-02],
                        [  7.83691406e-02,   7.83691406e-02],
                        [  7.79418945e-02,   7.79418945e-02],
                        [  7.41882324e-02,   7.41882324e-02],
                        [  6.75659180e-02,   6.75354004e-02],
                        [  5.89904785e-02,   5.90209961e-02],
                        [  4.76379395e-02,   4.76379395e-02],
                        [  3.12805176e-02,   3.12805176e-02],
                        [  1.32446289e-02,   1.32446289e-02],
                        [  2.19726562e-03,   2.22778320e-03],
                        [  1.61743164e-03,   1.58691406e-03],
                        [  4.79125977e-03,   4.79125977e-03],
                        [  3.93676758e-03,   3.93676758e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -1.76391602e-02,  -1.76086426e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -2.56958008e-02,  -2.56958008e-02],
                        [ -2.00500488e-02,  -2.00500488e-02],
                        [ -9.64355469e-03,  -9.61303711e-03],
                        [  2.31933594e-03,   2.31933594e-03],
                        [  1.63879395e-02,   1.63879395e-02],
                        [  3.32031250e-02,   3.32031250e-02],
                        [  4.84924316e-02,   4.84924316e-02],
                        [  5.75256348e-02,   5.75256348e-02],
                        [  6.06689453e-02,   6.06689453e-02],
                        [  5.96923828e-02,   5.96923828e-02],
                        [  5.31311035e-02,   5.31311035e-02],
                        [  4.05273438e-02,   4.05273438e-02],
                        [  2.74963379e-02,   2.75268555e-02],
                        [  1.86767578e-02,   1.86767578e-02],
                        [  9.67407227e-03,   9.67407227e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -2.24304199e-02,  -2.24304199e-02],
                        [ -3.57360840e-02,  -3.57360840e-02],
                        [ -4.17785645e-02,  -4.17785645e-02],
                        [ -4.18090820e-02,  -4.18090820e-02],
                        [ -3.66516113e-02,  -3.66516113e-02],
                        [ -2.67944336e-02,  -2.68249512e-02],
                        [ -1.58691406e-02,  -1.58691406e-02],
                        [ -7.44628906e-03,  -7.41577148e-03],
                        [ -1.80053711e-03,  -1.80053711e-03],
                        [  7.62939453e-04,   7.62939453e-04],
                        [ -5.79833984e-04,  -5.79833984e-04],
                        [ -4.27246094e-03,  -4.27246094e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -6.68334961e-03,  -6.68334961e-03],
                        [ -7.81250000e-03,  -7.81250000e-03],
                        [ -1.34582520e-02,  -1.34582520e-02],
                        [ -2.22778320e-02,  -2.22778320e-02],
                        [ -3.13415527e-02,  -3.13415527e-02],
                        [ -3.97644043e-02,  -3.97644043e-02],
                        [ -4.67529297e-02,  -4.67834473e-02],
                        [ -4.99572754e-02,  -4.99572754e-02],
                        [ -4.64782715e-02,  -4.64782715e-02],
                        [ -3.54614258e-02,  -3.54614258e-02],
                        [ -1.90429688e-02,  -1.90429688e-02],
                        [ -1.89208984e-03,  -1.89208984e-03],
                        [  9.58251953e-03,   9.55200195e-03],
                        [  1.19018555e-02,   1.19018555e-02],
                        [  8.66699219e-03,   8.66699219e-03],
                        [  6.65283203e-03,   6.65283203e-03],
                        [  8.30078125e-03,   8.30078125e-03],
                        [  1.09252930e-02,   1.09252930e-02],
                        [  1.26342773e-02,   1.26342773e-02],
                        [  1.44653320e-02,   1.44653320e-02],
                        [  1.53503418e-02,   1.53503418e-02],
                        [  1.11694336e-02,   1.11999512e-02],
                        [ -3.05175781e-05,  -3.05175781e-05],
                        [ -1.58081055e-02,  -1.58081055e-02],
                        [ -3.14636230e-02,  -3.14636230e-02],
                        [ -4.23889160e-02,  -4.23889160e-02],
                        [ -4.40063477e-02,  -4.40063477e-02],
                        [ -3.35998535e-02,  -3.35998535e-02],
                        [ -1.49536133e-02,  -1.49536133e-02],
                        [  4.82177734e-03,   4.82177734e-03],
                        [  2.22167969e-02,   2.22167969e-02],
                        [  3.58276367e-02,   3.58276367e-02],
                        [  4.31823730e-02,   4.31823730e-02],
                        [  4.31518555e-02,   4.31518555e-02],
                        [  3.92761230e-02,   3.92761230e-02],
                        [  3.89099121e-02,   3.89099121e-02],
                        [  4.78820801e-02,   4.78820801e-02],
                        [  6.71386719e-02,   6.71691895e-02],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  1.19049072e-01,   1.19018555e-01],
                        [  1.33117676e-01,   1.33148193e-01],
                        [  1.22833252e-01,   1.22833252e-01],
                        [  7.57751465e-02,   7.57446289e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.27105713e-01,  -1.27105713e-01],
                        [ -2.39898682e-01,  -2.39898682e-01],
                        [ -3.15826416e-01,  -3.15826416e-01],
                        [ -3.35723877e-01,  -3.35723877e-01],
                        [ -3.07464600e-01,  -3.07464600e-01],
                        [ -2.58056641e-01,  -2.58056641e-01],
                        [ -2.12005615e-01,  -2.12005615e-01],
                        [ -1.75994873e-01,  -1.75994873e-01],
                        [ -1.40502930e-01,  -1.40502930e-01],
                        [ -9.30175781e-02,  -9.30175781e-02],
                        [ -3.19213867e-02,  -3.19213867e-02],
                        [  2.93884277e-02,   2.93884277e-02],
                        [  7.44018555e-02,   7.44018555e-02],
                        [  9.85107422e-02,   9.85107422e-02],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.21093750e-01,   1.21093750e-01],
                        [  1.31408691e-01,   1.31408691e-01],
                        [  1.34643555e-01,   1.34643555e-01],
                        [  1.26647949e-01,   1.26647949e-01],
                        [  1.08917236e-01,   1.08886719e-01],
                        [  8.48388672e-02,   8.48388672e-02],
                        [  5.72814941e-02,   5.72814941e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.26538086e-03,   3.26538086e-03],
                        [ -1.59301758e-02,  -1.59301758e-02],
                        [ -2.49023438e-02,  -2.48718262e-02],
                        [ -1.87377930e-02,  -1.87377930e-02],
                        [  1.70898438e-03,   1.67846680e-03],
                        [  2.72216797e-02,   2.72216797e-02],
                        [  4.84313965e-02,   4.84313965e-02],
                        [  6.10656738e-02,   6.10351562e-02],
                        [  6.51855469e-02,   6.51855469e-02],
                        [  6.27746582e-02,   6.27746582e-02],
                        [  5.66406250e-02,   5.66406250e-02],
                        [  5.05065918e-02,   5.05065918e-02],
                        [  4.56237793e-02,   4.56237793e-02],
                        [  3.97033691e-02,   3.97033691e-02],
                        [  3.23791504e-02,   3.23791504e-02],
                        [  2.63366699e-02,   2.63366699e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  2.21252441e-02,   2.21252441e-02],
                        [  2.13012695e-02,   2.13012695e-02],
                        [  2.07824707e-02,   2.07824707e-02],
                        [  1.99584961e-02,   1.99584961e-02],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  1.12609863e-02,   1.12609863e-02],
                        [  6.28662109e-03,   6.28662109e-03],
                        [  2.56347656e-03,   2.53295898e-03],
                        [  1.86157227e-03,   1.89208984e-03],
                        [  6.98852539e-03,   6.98852539e-03],
                        [  1.66320801e-02,   1.66320801e-02],
                        [  2.40783691e-02,   2.40783691e-02],
                        [  2.35595703e-02,   2.35595703e-02],
                        [  1.62963867e-02,   1.62963867e-02],
                        [  7.65991211e-03,   7.65991211e-03],
                        [  1.37329102e-03,   1.40380859e-03],
                        [ -1.19018555e-03,  -1.19018555e-03],
                        [ -1.28173828e-03,  -1.31225586e-03],
                        [ -6.40869141e-04,  -6.40869141e-04],
                        [  1.73950195e-03,   1.73950195e-03],
                        [  7.93457031e-03,   7.93457031e-03],
                        [  1.78527832e-02,   1.78527832e-02],
                        [  2.88696289e-02,   2.88696289e-02],
                        [  3.75061035e-02,   3.75061035e-02],
                        [  4.16870117e-02,   4.16870117e-02],
                        [  4.11376953e-02,   4.11376953e-02],
                        [  3.57971191e-02,   3.57971191e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  1.55639648e-02,   1.55639648e-02],
                        [  6.62231445e-03,   6.62231445e-03],
                        [  1.67846680e-03,   1.67846680e-03],
                        [ -1.49536133e-03,  -1.49536133e-03],
                        [ -7.47680664e-03,  -7.47680664e-03],
                        [ -1.80664062e-02,  -1.80664062e-02],
                        [ -3.06091309e-02,  -3.06091309e-02],
                        [ -4.07409668e-02,  -4.07409668e-02],
                        [ -4.55322266e-02,  -4.55322266e-02],
                        [ -4.28161621e-02,  -4.28161621e-02],
                        [ -3.12194824e-02,  -3.12194824e-02],
                        [ -1.37023926e-02,  -1.37023926e-02],
                        [  1.52587891e-03,   1.52587891e-03],
                        [  6.71386719e-03,   6.71386719e-03],
                        [ -9.15527344e-05,  -9.15527344e-05],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -3.51257324e-02,  -3.51257324e-02],
                        [ -5.14526367e-02,  -5.14526367e-02],
                        [ -5.99060059e-02,  -5.99060059e-02],
                        [ -6.04858398e-02,  -6.04858398e-02],
                        [ -5.67626953e-02,  -5.67626953e-02],
                        [ -5.15441895e-02,  -5.15441895e-02],
                        [ -4.50134277e-02,  -4.50134277e-02],
                        [ -3.61328125e-02,  -3.61328125e-02],
                        [ -2.54821777e-02,  -2.55126953e-02],
                        [ -1.48925781e-02,  -1.48925781e-02],
                        [ -5.00488281e-03,  -5.00488281e-03],
                        [  4.33349609e-03,   4.33349609e-03],
                        [  1.29394531e-02,   1.29394531e-02],
                        [  2.03857422e-02,   2.03857422e-02],
                        [  2.64587402e-02,   2.64587402e-02],
                        [  3.17687988e-02,   3.17687988e-02],
                        [  3.71398926e-02,   3.71093750e-02],
                        [  4.18395996e-02,   4.18395996e-02],
                        [  4.47082520e-02,   4.47082520e-02],
                        [  4.50134277e-02,   4.50134277e-02],
                        [  4.25109863e-02,   4.25109863e-02],
                        [  3.82995605e-02,   3.82995605e-02],
                        [  3.38439941e-02,   3.38439941e-02],
                        [  2.91748047e-02,   2.91748047e-02],
                        [  2.32238770e-02,   2.32238770e-02],
                        [  1.64794922e-02,   1.64794922e-02],
                        [  1.40686035e-02,   1.40686035e-02],
                        [  2.33764648e-02,   2.33764648e-02],
                        [  4.52270508e-02,   4.52270508e-02],
                        [  7.24487305e-02,   7.24487305e-02],
                        [  9.78393555e-02,   9.78393555e-02],
                        [  1.16790771e-01,   1.16790771e-01],
                        [  1.20239258e-01,   1.20269775e-01],
                        [  9.24987793e-02,   9.24987793e-02],
                        [  2.27355957e-02,   2.27050781e-02],
                        [ -8.13903809e-02,  -8.13903809e-02],
                        [ -1.94610596e-01,  -1.94610596e-01],
                        [ -2.85095215e-01,  -2.85095215e-01],
                        [ -3.26293945e-01,  -3.26293945e-01],
                        [ -3.11645508e-01,  -3.11645508e-01],
                        [ -2.62786865e-01,  -2.62786865e-01],
                        [ -2.14080811e-01,  -2.14080811e-01],
                        [ -1.83807373e-01,  -1.83807373e-01],
                        [ -1.63574219e-01,  -1.63574219e-01],
                        [ -1.34185791e-01,  -1.34185791e-01],
                        [ -8.61206055e-02,  -8.60900879e-02],
                        [ -2.54821777e-02,  -2.54821777e-02],
                        [  3.21960449e-02,   3.21655273e-02],
                        [  7.31506348e-02,   7.31506348e-02],
                        [  9.39025879e-02,   9.39025879e-02],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  1.04400635e-01,   1.04400635e-01],
                        [  1.08520508e-01,   1.08551025e-01],
                        [  1.12548828e-01,   1.12548828e-01],
                        [  1.12030029e-01,   1.12030029e-01],
                        [  1.03271484e-01,   1.03271484e-01],
                        [  8.72192383e-02,   8.72192383e-02],
                        [  6.82678223e-02,   6.82678223e-02],
                        [  4.98657227e-02,   4.98657227e-02],
                        [  3.25012207e-02,   3.25012207e-02],
                        [  1.41906738e-02,   1.41906738e-02],
                        [ -4.82177734e-03,  -4.85229492e-03],
                        [ -1.87683105e-02,  -1.87683105e-02],
                        [ -2.20947266e-02,  -2.20947266e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [ -1.64794922e-03,  -1.64794922e-03],
                        [  1.37634277e-02,   1.37634277e-02],
                        [  2.94494629e-02,   2.94494629e-02],
                        [  4.50744629e-02,   4.50439453e-02],
                        [  5.93872070e-02,   5.93872070e-02],
                        [  6.99157715e-02,   6.99462891e-02],
                        [  7.30895996e-02,   7.30895996e-02],
                        [  6.71997070e-02,   6.71997070e-02],
                        [  5.46875000e-02,   5.46875000e-02],
                        [  3.88488770e-02,   3.88488770e-02],
                        [  2.26745605e-02,   2.26745605e-02],
                        [  1.00708008e-02,   1.00708008e-02],
                        [  3.47900391e-03,   3.47900391e-03],
                        [  1.19018555e-03,   1.19018555e-03],
                        [ -1.37329102e-03,  -1.37329102e-03],
                        [ -6.50024414e-03,  -6.46972656e-03],
                        [ -1.09252930e-02,  -1.09252930e-02],
                        [ -1.19018555e-02,  -1.19018555e-02],
                        [ -1.11389160e-02,  -1.11389160e-02],
                        [ -9.70458984e-03,  -9.70458984e-03],
                        [ -5.34057617e-03,  -5.34057617e-03],
                        [  2.74658203e-03,   2.74658203e-03],
                        [  9.94873047e-03,   9.94873047e-03],
                        [  1.18408203e-02,   1.18408203e-02],
                        [  1.16882324e-02,   1.16882324e-02],
                        [  1.55944824e-02,   1.55944824e-02],
                        [  2.45971680e-02,   2.46276855e-02],
                        [  3.53088379e-02,   3.53088379e-02],
                        [  4.24194336e-02,   4.24194336e-02],
                        [  4.10461426e-02,   4.10766602e-02],
                        [  3.03344727e-02,   3.03344727e-02],
                        [  1.55334473e-02,   1.55334473e-02],
                        [  5.46264648e-03,   5.46264648e-03],
                        [  3.32641602e-03,   3.32641602e-03],
                        [  2.56347656e-03,   2.56347656e-03],
                        [ -3.32641602e-03,  -3.32641602e-03],
                        [ -1.35803223e-02,  -1.35803223e-02],
                        [ -2.32238770e-02,  -2.31933594e-02],
                        [ -2.82287598e-02,  -2.82287598e-02],
                        [ -2.79846191e-02,  -2.79846191e-02],
                        [ -2.38037109e-02,  -2.37731934e-02],
                        [ -1.75476074e-02,  -1.75476074e-02],
                        [ -1.08032227e-02,  -1.08032227e-02],
                        [ -2.68554688e-03,  -2.68554688e-03],
                        [  6.50024414e-03,   6.50024414e-03],
                        [  1.17187500e-02,   1.17187500e-02],
                        [  9.73510742e-03,   9.73510742e-03],
                        [  3.47900391e-03,   3.44848633e-03],
                        [ -2.62451172e-03,  -2.62451172e-03],
                        [ -7.44628906e-03,  -7.44628906e-03],
                        [ -1.38244629e-02,  -1.38244629e-02],
                        [ -2.35290527e-02,  -2.35290527e-02],
                        [ -3.40881348e-02,  -3.40881348e-02],
                        [ -4.09240723e-02,  -4.09240723e-02],
                        [ -4.06188965e-02,  -4.06188965e-02],
                        [ -3.30505371e-02,  -3.30505371e-02],
                        [ -2.28271484e-02,  -2.28271484e-02],
                        [ -1.60522461e-02,  -1.60522461e-02],
                        [ -1.52587891e-02,  -1.52587891e-02],
                        [ -1.73645020e-02,  -1.73645020e-02],
                        [ -1.73950195e-02,  -1.73950195e-02],
                        [ -1.44042969e-02,  -1.44042969e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -7.53784180e-03,  -7.53784180e-03],
                        [ -6.16455078e-03,  -6.16455078e-03],
                        [ -7.26318359e-03,  -7.26318359e-03],
                        [ -1.04370117e-02,  -1.04370117e-02],
                        [ -1.40380859e-02,  -1.40380859e-02],
                        [ -1.61743164e-02,  -1.61743164e-02],
                        [ -1.61132812e-02,  -1.61132812e-02],
                        [ -1.39770508e-02,  -1.39770508e-02],
                        [ -9.55200195e-03,  -9.55200195e-03],
                        [ -3.23486328e-03,  -3.26538086e-03],
                        [  9.76562500e-04,   9.76562500e-04],
                        [ -1.22070312e-03,  -1.25122070e-03],
                        [ -7.99560547e-03,  -7.99560547e-03],
                        [ -1.12915039e-02,  -1.12609863e-02],
                        [ -5.37109375e-03,  -5.37109375e-03],
                        [  8.85009766e-03,   8.85009766e-03],
                        [  2.85034180e-02,   2.85339355e-02],
                        [  5.08728027e-02,   5.08728027e-02],
                        [  7.08312988e-02,   7.08007812e-02],
                        [  8.45031738e-02,   8.45336914e-02],
                        [  9.46960449e-02,   9.46960449e-02],
                        [  1.06903076e-01,   1.06903076e-01],
                        [  1.21704102e-01,   1.21734619e-01],
                        [  1.31713867e-01,   1.31713867e-01],
                        [  1.24969482e-01,   1.24969482e-01],
                        [  9.13696289e-02,   9.13696289e-02],
                        [  2.68554688e-02,   2.68554688e-02],
                        [ -6.33850098e-02,  -6.33850098e-02],
                        [ -1.62841797e-01,  -1.62841797e-01],
                        [ -2.47253418e-01,  -2.47283936e-01],
                        [ -2.94799805e-01,  -2.94769287e-01],
                        [ -2.98797607e-01,  -2.98828125e-01],
                        [ -2.72491455e-01,  -2.72491455e-01],
                        [ -2.36419678e-01,  -2.36389160e-01],
                        [ -2.02789307e-01,  -2.02789307e-01],
                        [ -1.69952393e-01,  -1.69952393e-01],
                        [ -1.26983643e-01,  -1.26953125e-01],
                        [ -6.73522949e-02,  -6.73522949e-02],
                        [ -2.44140625e-04,  -2.44140625e-04],
                        [  5.41687012e-02,   5.41687012e-02],
                        [  8.07800293e-02,   8.07800293e-02],
                        [  8.24279785e-02,   8.24279785e-02],
                        [  7.62634277e-02,   7.62634277e-02],
                        [  7.65380859e-02,   7.65380859e-02],
                        [  8.48388672e-02,   8.48693848e-02],
                        [  9.34753418e-02,   9.34753418e-02],
                        [  9.34143066e-02,   9.34143066e-02],
                        [  8.29162598e-02,   8.29162598e-02],
                        [  6.82067871e-02,   6.82067871e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  4.83093262e-02,   4.83093262e-02],
                        [  4.10461426e-02,   4.10766602e-02],
                        [  3.02124023e-02,   3.02124023e-02],
                        [  1.86462402e-02,   1.86462402e-02],
                        [  1.22985840e-02,   1.22985840e-02],
                        [  1.37023926e-02,   1.37023926e-02],
                        [  2.22778320e-02,   2.22778320e-02],
                        [  3.47900391e-02,   3.47900391e-02],
                        [  4.62951660e-02,   4.62951660e-02],
                        [  5.26733398e-02,   5.26733398e-02],
                        [  5.40466309e-02,   5.40466309e-02],
                        [  5.45959473e-02,   5.45959473e-02],
                        [  5.54199219e-02,   5.54504395e-02],
                        [  5.28869629e-02,   5.28869629e-02],
                        [  4.67529297e-02,   4.67529297e-02],
                        [  4.05883789e-02,   4.05883789e-02],
                        [  3.47595215e-02,   3.47595215e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.58996582e-02,   1.59301758e-02],
                        [  6.07299805e-03,   6.07299805e-03],
                        [  1.03759766e-03,   1.03759766e-03],
                        [  1.28173828e-03,   1.28173828e-03],
                        [  5.00488281e-03,   5.00488281e-03],
                        [  9.15527344e-03,   9.15527344e-03],
                        [  9.82666016e-03,   9.82666016e-03],
                        [  4.79125977e-03,   4.82177734e-03],
                        [ -3.20434570e-03,  -3.20434570e-03],
                        [ -7.78198242e-03,  -7.78198242e-03],
                        [ -4.66918945e-03,  -4.63867188e-03],
                        [  4.36401367e-03,   4.36401367e-03],
                        [  1.52282715e-02,   1.51977539e-02],
                        [  2.52990723e-02,   2.52990723e-02],
                        [  3.31420898e-02,   3.31420898e-02],
                        [  3.79333496e-02,   3.79333496e-02],
                        [  3.94287109e-02,   3.94287109e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  3.62548828e-02,   3.62548828e-02],
                        [  3.53698730e-02,   3.53698730e-02],
                        [  3.54309082e-02,   3.54003906e-02],
                        [  3.18298340e-02,   3.18298340e-02],
                        [  2.09045410e-02,   2.09045410e-02],
                        [  7.17163086e-03,   7.14111328e-03],
                        [ -1.83105469e-03,  -1.83105469e-03],
                        [ -5.09643555e-03,  -5.12695312e-03],
                        [ -7.14111328e-03,  -7.14111328e-03],
                        [ -1.15966797e-02,  -1.15966797e-02],
                        [ -1.87072754e-02,  -1.87377930e-02],
                        [ -2.75878906e-02,  -2.75878906e-02],
                        [ -3.76586914e-02,  -3.76586914e-02],
                        [ -4.55627441e-02,  -4.55627441e-02],
                        [ -4.58984375e-02,  -4.58984375e-02],
                        [ -3.69262695e-02,  -3.69262695e-02],
                        [ -2.19726562e-02,  -2.19726562e-02],
                        [ -6.19506836e-03,  -6.19506836e-03],
                        [  6.46972656e-03,   6.43920898e-03],
                        [  1.30920410e-02,   1.30615234e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [  4.30297852e-03,   4.30297852e-03],
                        [ -4.11987305e-03,  -4.15039062e-03],
                        [ -1.21154785e-02,  -1.21154785e-02],
                        [ -2.03552246e-02,  -2.03552246e-02],
                        [ -2.76794434e-02,  -2.76794434e-02],
                        [ -3.32336426e-02,  -3.32336426e-02],
                        [ -3.83605957e-02,  -3.83605957e-02],
                        [ -4.22668457e-02,  -4.22668457e-02],
                        [ -4.00695801e-02,  -4.00695801e-02],
                        [ -3.07922363e-02,  -3.07617188e-02],
                        [ -2.22473145e-02,  -2.22473145e-02],
                        [ -2.18811035e-02,  -2.19116211e-02],
                        [ -2.78930664e-02,  -2.78930664e-02],
                        [ -3.21960449e-02,  -3.21960449e-02],
                        [ -3.00903320e-02,  -3.00903320e-02],
                        [ -2.42004395e-02,  -2.42004395e-02],
                        [ -1.86462402e-02,  -1.86462402e-02],
                        [ -1.44653320e-02,  -1.44653320e-02],
                        [ -1.20544434e-02,  -1.20849609e-02],
                        [ -1.14440918e-02,  -1.14440918e-02],
                        [ -9.94873047e-03,  -9.94873047e-03],
                        [ -3.84521484e-03,  -3.84521484e-03],
                        [  7.35473633e-03,   7.35473633e-03],
                        [  1.97448730e-02,   1.97753906e-02],
                        [  3.07617188e-02,   3.07617188e-02],
                        [  4.06188965e-02,   4.06188965e-02],
                        [  4.73327637e-02,   4.73632812e-02],
                        [  4.81262207e-02,   4.80957031e-02],
                        [  4.43420410e-02,   4.43420410e-02],
                        [  4.04052734e-02,   4.04357910e-02],
                        [  4.08020020e-02,   4.08020020e-02],
                        [  4.79736328e-02,   4.79736328e-02],
                        [  6.09741211e-02,   6.10046387e-02],
                        [  7.65075684e-02,   7.65075684e-02],
                        [  9.16442871e-02,   9.16442871e-02],
                        [  1.05224609e-01,   1.05224609e-01],
                        [  1.14105225e-01,   1.14105225e-01],
                        [  1.08642578e-01,   1.08642578e-01],
                        [  7.37304688e-02,   7.37304688e-02],
                        [ -1.67846680e-03,  -1.64794922e-03],
                        [ -1.10534668e-01,  -1.10504150e-01],
                        [ -2.23236084e-01,  -2.23236084e-01],
                        [ -3.03497314e-01,  -3.03497314e-01],
                        [ -3.30871582e-01,  -3.30871582e-01],
                        [ -3.10791016e-01,  -3.10791016e-01],
                        [ -2.68249512e-01,  -2.68280029e-01],
                        [ -2.29339600e-01,  -2.29339600e-01],
                        [ -2.02423096e-01,  -2.02423096e-01],
                        [ -1.75476074e-01,  -1.75506592e-01],
                        [ -1.31896973e-01,  -1.31896973e-01],
                        [ -6.89392090e-02,  -6.89392090e-02],
                        [  0.00000000e+00,  -3.05175781e-05],
                        [  5.68237305e-02,   5.68237305e-02],
                        [  9.08813477e-02,   9.09118652e-02],
                        [  1.04583740e-01,   1.04583740e-01],
                        [  1.08276367e-01,   1.08276367e-01],
                        [  1.10504150e-01,   1.10504150e-01],
                        [  1.14410400e-01,   1.14379883e-01],
                        [  1.18255615e-01,   1.18255615e-01],
                        [  1.17767334e-01,   1.17767334e-01],
                        [  1.08978271e-01,   1.08978271e-01],
                        [  9.02099609e-02,   9.02099609e-02],
                        [  6.33239746e-02,   6.32934570e-02],
                        [  3.45153809e-02,   3.45153809e-02],
                        [  1.16577148e-02,   1.16577148e-02],
                        [ -6.10351562e-04,  -6.40869141e-04],
                        [ -3.69262695e-03,  -3.69262695e-03],
                        [ -1.34277344e-03,  -1.31225586e-03],
                        [  5.24902344e-03,   5.24902344e-03],
                        [  1.50146484e-02,   1.50146484e-02],
                        [  2.51464844e-02,   2.51464844e-02],
                        [  3.48510742e-02,   3.48510742e-02],
                        [  4.51049805e-02,   4.51049805e-02],
                        [  5.41992188e-02,   5.41992188e-02],
                        [  5.85937500e-02,   5.85937500e-02],
                        [  5.77087402e-02,   5.77087402e-02],
                        [  5.45654297e-02,   5.45654297e-02],
                        [  5.07812500e-02,   5.07812500e-02],
                        [  4.40673828e-02,   4.40673828e-02],
                        [  3.25317383e-02,   3.25317383e-02],
                        [  1.87683105e-02,   1.87988281e-02],
                        [  7.08007812e-03,   7.08007812e-03],
                        [ -1.43432617e-03,  -1.43432617e-03],
                        [ -6.98852539e-03,  -6.98852539e-03],
                        [ -8.39233398e-03,  -8.39233398e-03],
                        [ -6.43920898e-03,  -6.43920898e-03],
                        [ -5.21850586e-03,  -5.18798828e-03],
                        [ -6.71386719e-03,  -6.71386719e-03],
                        [ -8.60595703e-03,  -8.60595703e-03],
                        [ -7.93457031e-03,  -7.93457031e-03],
                        [ -4.39453125e-03,  -4.39453125e-03],
                        [  1.06811523e-03,   1.06811523e-03],
                        [  9.46044922e-03,   9.46044922e-03],
                        [  2.03552246e-02,   2.03552246e-02],
                        [  2.81372070e-02,   2.81372070e-02],
                        [  2.86560059e-02,   2.86560059e-02],
                        [  2.53601074e-02,   2.53601074e-02],
                        [  2.41088867e-02,   2.41088867e-02],
                        [  2.67333984e-02,   2.67333984e-02],
                        [  3.03955078e-02,   3.03955078e-02],
                        [  3.08837891e-02,   3.08837891e-02],
                        [  2.66723633e-02,   2.66723633e-02],
                        [  1.96838379e-02,   1.96838379e-02],
                        [  1.29699707e-02,   1.29699707e-02],
                        [  8.69750977e-03,   8.66699219e-03],
                        [  7.14111328e-03,   7.14111328e-03],
                        [  7.11059570e-03,   7.11059570e-03],
                        [  6.89697266e-03,   6.89697266e-03],
                        [  5.58471680e-03,   5.58471680e-03],
                        [  3.41796875e-03,   3.41796875e-03],
                        [  5.79833984e-04,   5.79833984e-04],
                        [ -3.14331055e-03,  -3.14331055e-03],
                        [ -8.30078125e-03,  -8.30078125e-03],
                        [ -1.58386230e-02,  -1.58386230e-02],
                        [ -2.47192383e-02,  -2.47192383e-02],
                        [ -3.12805176e-02,  -3.12805176e-02],
                        [ -3.41491699e-02,  -3.41491699e-02],
                        [ -3.59802246e-02,  -3.59497070e-02],
                        [ -3.78417969e-02,  -3.78417969e-02],
                        [ -3.77807617e-02,  -3.77807617e-02],
                        [ -3.49121094e-02,  -3.49121094e-02],
                        [ -3.21960449e-02,  -3.22265625e-02],
                        [ -3.26232910e-02,  -3.26232910e-02],
                        [ -3.43017578e-02,  -3.43017578e-02],
                        [ -3.35083008e-02,  -3.35083008e-02],
                        [ -2.99377441e-02,  -2.99682617e-02],
                        [ -2.49938965e-02,  -2.49938965e-02],
                        [ -1.95312500e-02,  -1.95312500e-02],
                        [ -1.55944824e-02,  -1.56250000e-02],
                        [ -1.43737793e-02,  -1.43737793e-02],
                        [ -1.28784180e-02,  -1.28784180e-02],
                        [ -6.50024414e-03,  -6.53076172e-03],
                        [  4.88281250e-03,   4.88281250e-03],
                        [  1.43737793e-02,   1.43737793e-02],
                        [  1.45874023e-02,   1.45874023e-02],
                        [  6.71386719e-03,   6.71386719e-03],
                        [ -3.23486328e-03,  -3.23486328e-03],
                        [ -1.30004883e-02,  -1.30310059e-02],
                        [ -2.09350586e-02,  -2.09350586e-02],
                        [ -2.05078125e-02,  -2.05078125e-02],
                        [ -7.41577148e-03,  -7.44628906e-03],
                        [  1.17492676e-02,   1.17492676e-02],
                        [  2.51159668e-02,   2.51159668e-02],
                        [  2.70385742e-02,   2.70385742e-02],
                        [  2.08740234e-02,   2.08740234e-02],
                        [  1.42822266e-02,   1.43127441e-02],
                        [  1.33056641e-02,   1.33056641e-02],
                        [  1.86157227e-02,   1.86157227e-02],
                        [  2.73742676e-02,   2.73742676e-02],
                        [  3.67126465e-02,   3.67126465e-02],
                        [  4.62036133e-02,   4.61730957e-02],
                        [  5.86547852e-02,   5.86547852e-02],
                        [  7.69042969e-02,   7.69042969e-02],
                        [  9.77783203e-02,   9.77783203e-02],
                        [  1.14440918e-01,   1.14471436e-01],
                        [  1.23077393e-01,   1.23107910e-01],
                        [  1.21368408e-01,   1.21368408e-01],
                        [  1.02142334e-01,   1.02142334e-01],
                        [  5.38940430e-02,   5.38940430e-02],
                        [ -2.98461914e-02,  -2.98461914e-02],
                        [ -1.39190674e-01,  -1.39190674e-01],
                        [ -2.45849609e-01,  -2.45849609e-01],
                        [ -3.17016602e-01,  -3.17016602e-01],
                        [ -3.36425781e-01,  -3.36425781e-01],
                        [ -3.13629150e-01,  -3.13629150e-01],
                        [ -2.73254395e-01,  -2.73254395e-01],
                        [ -2.35839844e-01,  -2.35839844e-01],
                        [ -2.05352783e-01,  -2.05352783e-01],
                        [ -1.70898438e-01,  -1.70898438e-01],
                        [ -1.19812012e-01,  -1.19812012e-01],
                        [ -5.34973145e-02,  -5.34973145e-02],
                        [  1.15356445e-02,   1.15661621e-02],
                        [  5.92956543e-02,   5.92956543e-02],
                        [  8.67004395e-02,   8.67004395e-02],
                        [  1.01196289e-01,   1.01196289e-01],
                        [  1.10595703e-01,   1.10595703e-01],
                        [  1.18438721e-01,   1.18438721e-01],
                        [  1.24847412e-01,   1.24847412e-01],
                        [  1.27258301e-01,   1.27258301e-01],
                        [  1.20574951e-01,   1.20574951e-01],
                        [  1.03088379e-01,   1.03088379e-01],
                        [  8.09631348e-02,   8.09631348e-02],
                        [  6.19201660e-02,   6.19201660e-02],
                        [  4.60815430e-02,   4.60815430e-02],
                        [  2.88391113e-02,   2.88391113e-02],
                        [  1.18713379e-02,   1.18713379e-02],
                        [  2.38037109e-03,   2.38037109e-03],
                        [  2.89916992e-03,   2.89916992e-03],
                        [  9.88769531e-03,   9.88769531e-03],
                        [  1.98059082e-02,   1.98059082e-02],
                        [  2.99072266e-02,   2.99072266e-02],
                        [  3.82690430e-02,   3.82690430e-02],
                        [  4.64172363e-02,   4.64172363e-02],
                        [  5.60302734e-02,   5.60302734e-02],
                        [  6.40563965e-02,   6.40563965e-02],
                        [  6.51550293e-02,   6.51550293e-02],
                        [  5.88378906e-02,   5.88378906e-02],
                        [  4.95605469e-02,   4.95605469e-02],
                        [  4.12597656e-02,   4.12597656e-02],
                        [  3.40881348e-02,   3.40881348e-02],
                        [  2.59094238e-02,   2.59094238e-02],
                        [  1.57165527e-02,   1.57165527e-02],
                        [  6.04248047e-03,   6.04248047e-03],
                        [ -4.88281250e-04,  -4.88281250e-04],
                        [ -4.30297852e-03,  -4.30297852e-03],
                        [ -6.34765625e-03,  -6.34765625e-03],
                        [ -7.32421875e-03,  -7.32421875e-03],
                        [ -9.06372070e-03,  -9.06372070e-03],
                        [ -1.35192871e-02,  -1.35192871e-02],
                        [ -1.98364258e-02,  -1.98364258e-02],
                        [ -2.24914551e-02,  -2.24914551e-02],
                        [ -1.49841309e-02,  -1.49841309e-02],
                        [  2.50244141e-03,   2.50244141e-03],
                        [  2.17285156e-02,   2.17285156e-02],
                        [  3.42712402e-02,   3.42712402e-02],
                        [  3.93981934e-02,   3.93981934e-02],
                        [  4.15649414e-02,   4.15649414e-02],
                        [  4.29687500e-02,   4.29687500e-02],
                        [  4.35180664e-02,   4.35180664e-02],
                        [  4.34570312e-02,   4.34570312e-02],
                        [  4.12292480e-02,   4.12292480e-02],
                        [  3.32946777e-02,   3.32946777e-02],
                        [  1.89208984e-02,   1.89208984e-02],
                        [  3.87573242e-03,   3.87573242e-03],
                        [ -4.97436523e-03,  -4.97436523e-03],
                        [ -8.51440430e-03,  -8.51440430e-03],
                        [ -1.09252930e-02,  -1.08947754e-02],
                        [ -1.06201172e-02,  -1.06201172e-02],
                        [ -6.59179688e-03,  -6.59179688e-03],
                        [ -2.04467773e-03,  -2.04467773e-03]],
                        dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri1",
    rate = 41000,
    data = numpy.array([  2.40989635e-03,  -8.31340905e-03,   1.79964025e-03,
                          5.37692336e-03,   5.92153193e-03,   1.22074515e-03,
                         -4.08060988e-03,   1.02435856e-03,   1.63954461e-03,
                         -2.17389851e-03,   5.20089408e-03,   4.45305603e-03,
                         -5.44066820e-03,  -1.61284010e-03,   1.01350471e-02,
                          1.27663440e-03,  -1.40033262e-02,  -7.43818283e-03,
                          1.11947246e-02,   4.74276673e-03,  -1.75486610e-03,
                         -2.00476311e-03,   5.24314772e-03,  -4.10799263e-03,
                         -7.22509343e-03,   7.53957499e-03,  -1.55217424e-01,
                          6.81524798e-02,   1.60771906e-01,  -1.71175301e-01,
                         -9.38377157e-02,   2.65554518e-01,  -1.34096416e-02,
                         -3.26490223e-01,   5.01467101e-02,   2.20261380e-01,
                         -8.10710192e-02,  -1.37213647e-01,   3.45162190e-02,
                          3.10216416e-02,   8.26436952e-02,  -9.20528825e-03,
                         -2.88345695e-01,   4.24881205e-02,   4.23902631e-01,
                         -1.98359460e-01,  -4.48117614e-01,   3.82600367e-01,
                          4.43323225e-01,  -5.09799719e-01,  -2.12905869e-01,
                          6.02322400e-01,  -9.10047516e-02,  -5.47155261e-01,
                          2.75794923e-01,   3.59878898e-01,  -3.00812095e-01,
                         -1.16232961e-01,   1.47043347e-01,   6.08971380e-02,
                          9.09556150e-02,  -2.89856523e-01,  -1.03479706e-01,
                          5.94483256e-01,  -1.65681317e-01,  -7.17501223e-01,
                          6.31392062e-01,   4.81149465e-01,  -8.91723633e-01,
                         -1.11857615e-01,   9.14758563e-01,  -2.12573290e-01,
                         -8.02893519e-01,   4.40895051e-01,   5.18449545e-01,
                         -4.38324153e-01,  -2.57497191e-01,   2.67236114e-01,
                          1.21876404e-01,   5.83641743e-03,  -1.25803754e-01,
                         -2.89462477e-01,   2.59424359e-01,   4.39144492e-01,
                         -4.80127901e-01,  -5.09769082e-01,   6.67881608e-01,
                          3.05163920e-01,  -7.81469822e-01,   1.06838867e-02,
                          7.41747975e-01,  -3.61483216e-01,  -6.07600272e-01,
                          4.69153970e-01,   2.94910461e-01,  -4.41773891e-01,
                         -2.09715590e-02,   2.56781310e-01,  -2.32785139e-02,
                         -5.39737605e-02,  -1.95502654e-01,   2.94074765e-03,
                          4.26371545e-01,  -3.15273196e-01,  -4.65995610e-01,
                          7.07860470e-01,   1.75072625e-01,  -9.28603947e-01,
                          1.89360723e-01,   8.62314522e-01,  -5.63856840e-01,
                         -6.32183492e-01,   6.84293032e-01,   2.86917090e-01,
                         -6.77650690e-01,  -9.28562433e-02,   4.68875438e-01,
                          1.93194812e-03,  -1.99648961e-01,  -1.05085731e-01,
                         -8.11126679e-02,   2.93576330e-01,   1.79725930e-01,
                         -5.74482203e-01,  -1.82285637e-01,   7.25276947e-01,
                         -8.71314667e-03,  -7.72451282e-01,   2.89104462e-01,
                          6.59726262e-01,  -5.59659421e-01,  -4.52765942e-01,
                          6.24109805e-01,   9.28454697e-02,  -5.75973809e-01,
                          1.46051437e-01,   3.30175549e-01,  -1.72583446e-01,
                         -1.29155606e-01,  -4.01948206e-02,   6.70216233e-02,
                          2.18781278e-01,  -3.74861598e-01,  -2.64822811e-01,
                          6.83464170e-01,  -1.45197622e-02,  -8.75675917e-01,
                          4.74264503e-01,   6.78328395e-01,  -8.24077547e-01,
                         -3.33513230e-01,   8.85503948e-01,   7.87854474e-03,
                         -8.03279281e-01,   1.66995242e-01,   5.46175599e-01,
                         -2.16628537e-01,  -2.80223161e-01,   6.54060096e-02,
                          8.56871977e-02,   1.70908943e-01,  -2.99230609e-02,
                         -4.76131976e-01,   9.18023512e-02,   6.44133091e-01,
                         -3.14207911e-01,  -6.91860735e-01,   5.02933502e-01,
                          5.35575390e-01,  -7.16786861e-01,  -2.11500168e-01,
                          7.37896383e-01,  -1.35255739e-01,  -5.99207282e-01,
                          3.27220559e-01,   3.13858837e-01,  -3.37163001e-01,
                         -9.33132246e-02,   1.52244642e-01,   5.49134985e-02,
                          7.33896941e-02,  -2.94642538e-01,  -7.94276521e-02,
                          5.82169473e-01,  -2.23306969e-01,  -6.77296221e-01,
                          6.72198296e-01,   4.24740106e-01,  -9.55909371e-01,
                         -1.73386082e-03,   9.20005083e-01,  -3.12564909e-01,
                         -7.73921907e-01,   4.79086757e-01,   4.46157306e-01,
                         -4.96543467e-01,  -2.27278054e-01,   2.95548707e-01,
                          1.07398652e-01,  -1.74045898e-02,  -1.38498679e-01,
                         -2.83957541e-01,   2.71061003e-01,   4.22477335e-01,
                         -5.11662185e-01,  -4.43527430e-01,   6.82191432e-01,
                          2.55304813e-01,  -7.86622465e-01,   7.08980560e-02,
                          7.61309862e-01,  -3.68110925e-01,  -5.88951051e-01,
                          5.11676490e-01,   2.29457691e-01,  -4.63894695e-01,
                          2.29221825e-02,   2.54157394e-01,  -5.84096983e-02,
                         -5.75443916e-02,  -1.70657083e-01,   4.51476686e-02,
                          4.21997637e-01,  -3.71836036e-01,  -4.42302257e-01,
                          7.36488700e-01,   1.37971133e-01,  -9.22930717e-01,
                          2.39287272e-01,   8.20064902e-01,  -6.00548029e-01,
                         -5.87618589e-01,   7.53925145e-01,   2.67349929e-01,
                         -6.86392486e-01,  -6.78844675e-02,   4.57369924e-01,
                         -3.27617787e-02,  -1.94700837e-01,  -9.41894129e-02,
                         -5.43361418e-02,   3.04378599e-01,   1.78356886e-01,
                         -5.62250912e-01,  -1.50648355e-01,   7.10944772e-01,
                         -8.67846757e-02,  -7.67299473e-01,   3.86152744e-01,
                          6.37493670e-01,  -6.28636360e-01,  -4.50699419e-01,
                          6.25820756e-01,   2.67724749e-02,  -5.99087894e-01,
                          1.59675226e-01,   2.94110149e-01,  -2.05243111e-01,
                         -1.22871816e-01,  -3.63113172e-02,   8.20170194e-02,
                          2.02296048e-01,  -3.97893906e-01,  -2.16390789e-01,
                          6.72694147e-01,  -1.30787373e-01,  -8.48707020e-01,
                          5.11755407e-01,   6.21697187e-01,  -8.97050917e-01,
                         -2.92660266e-01,   8.70437086e-01,  -4.58576977e-02,
                         -8.17577600e-01,   1.97928280e-01,   5.01682341e-01,
                         -2.68381119e-01,  -2.87215531e-01,   6.19255528e-02,
                          6.92047849e-02,   1.59901366e-01,  -7.99333528e-02,
                         -4.94906753e-01,   1.19235799e-01,   5.84983110e-01,
                         -3.91798586e-01,  -6.40625536e-01,   5.74064970e-01,
                          4.42494005e-01,  -7.79374421e-01,  -1.77203521e-01,
                          7.37674952e-01,  -2.25956544e-01,  -6.33347273e-01,
                          3.25427175e-01,   3.03512543e-01,  -3.71541053e-01,
                         -1.05690092e-01,   1.01620547e-01,   2.65325382e-02,
                          4.10382897e-02,  -3.38199943e-01,  -8.12940001e-02,
                          5.64499080e-01,  -3.30043703e-01,  -6.59964800e-01,
                          6.91597462e-01,   2.95331568e-01,  -9.72564697e-01,
                          1.21005224e-02,   8.99473965e-01,  -3.93395722e-01,
                         -7.56550074e-01,   5.36702037e-01,   3.91452640e-01,
                         -5.23574293e-01,  -2.30477944e-01,   2.72921532e-01,
                          7.11530000e-02,  -3.48603129e-02,  -1.73370376e-01,
                         -2.88944036e-01,   2.96143740e-01,   3.45910937e-01,
                         -5.81405818e-01,  -3.85493457e-01,   7.38953054e-01,
                          1.45693719e-01,  -8.46079171e-01,   1.21570311e-01,
                          6.95442855e-01,  -4.61001545e-01,  -5.38326025e-01,
                          5.22044361e-01,   1.82921275e-01,  -4.82692033e-01,
                          2.49465350e-02,   2.27286234e-01,  -6.89620674e-02,
                         -8.84847790e-02,  -2.03057408e-01,   5.15112430e-02,
                          3.88306469e-01,  -4.17425543e-01,  -4.14880335e-01,
                          7.59672105e-01,   1.87325887e-02,  -9.28669691e-01,
                          3.16070259e-01,   7.95397043e-01,  -6.68263972e-01,
                         -5.11850476e-01,   7.68597543e-01,   1.59735516e-01,
                         -7.08848894e-01,  -1.54505540e-02,   4.65437949e-01,
                         -5.56092449e-02,  -2.14047581e-01,  -9.83458981e-02,
                         -4.88057137e-02,   3.06581825e-01,   1.11801177e-01,
                         -5.83481610e-01,  -8.60016942e-02,   7.07297981e-01,
                         -1.61302328e-01,  -7.78245568e-01,   4.09661114e-01,
                          6.34222448e-01,  -6.34672523e-01,  -3.38061988e-01,
                          6.60110533e-01,  -3.76574360e-02,  -5.59643865e-01,
                          2.26022288e-01,   3.06097239e-01,  -2.11131021e-01,
                         -1.20410681e-01,  -2.08324175e-02,   1.10004909e-01,
                          2.02800691e-01,  -4.02305275e-01,  -1.81070477e-01,
                          6.99188530e-01,  -1.50983512e-01,  -7.77624846e-01,
                          5.74091494e-01,   5.40465891e-01,  -8.60130548e-01,
                         -1.69962868e-01,   8.99525464e-01,  -7.53355101e-02,
                         -7.62514353e-01,   2.99425632e-01,   5.00692189e-01,
                         -2.83781052e-01,  -2.34550908e-01,   1.07068889e-01,
                          1.12453356e-01,   1.85672998e-01,  -6.73114881e-02,
                         -4.41560060e-01,   2.08298802e-01,   6.03963315e-01,
                         -4.31088716e-01,  -5.42048216e-01,   6.82771802e-01,
                          4.46764499e-01,  -7.26670742e-01,  -3.95011418e-02,
                          7.94475555e-01,  -2.18172878e-01,  -4.98305976e-01,
                          4.54066515e-01,   2.88071841e-01,  -3.28483582e-01,
                         -4.93077142e-03,   1.84255853e-01,   8.98337215e-02,
                          8.13514888e-02,  -2.70218521e-01,   3.29348445e-02,
                          6.00280881e-01,  -2.97151297e-01,  -5.51216066e-01,
                          8.08807254e-01,   3.24609727e-01,  -8.91725242e-01,
                          1.21189989e-01,   9.63587642e-01,  -4.26322013e-01,
                         -6.17918670e-01,   6.55055940e-01,   4.32265222e-01,
                         -4.99769688e-01,  -1.08569749e-01,   3.62396121e-01,
                          1.34892017e-01,   2.15426888e-02,  -1.23508207e-01,
                         -1.82101235e-01,   3.95563722e-01,   3.92731816e-01,
                         -5.27722836e-01,  -2.76631147e-01,   8.01139891e-01,
                          1.41229302e-01,  -7.74903953e-01,   2.81995714e-01,
                          7.71701157e-01,  -4.05976444e-01,  -4.18873757e-01,
                          6.20997548e-01,   1.61655247e-01,  -4.39548999e-01,
                          1.36900693e-01,   2.97915936e-01,  -1.11962836e-02,
                         -1.11862924e-02,  -1.09737799e-01,   1.50078565e-01,
                          4.34243739e-01,  -3.87486041e-01,  -2.68932521e-01,
                          8.23310018e-01,   5.46832122e-02,  -8.63310039e-01,
                          4.49982345e-01,   8.10903013e-01,  -7.08587289e-01,
                         -3.76746804e-01,   8.94654036e-01,   1.30369440e-01,
                         -6.44723713e-01,   7.02734515e-02,   5.21999896e-01,
                         -1.16785439e-02,  -1.58931598e-01,  -2.25892272e-02,
                          3.81893367e-02,   3.71584088e-01,   1.27904743e-01,
                         -5.56683660e-01,   3.08905691e-02,   7.89561450e-01,
                         -1.65296450e-01,  -6.75941765e-01,   5.24085760e-01,
                          6.24157310e-01,  -5.95505178e-01,  -2.30998442e-01,
                          7.20119715e-01,  -3.36978771e-02,  -5.21407843e-01,
                          3.07427257e-01,   3.52618486e-01,  -1.73018411e-01,
                         -3.34422700e-02,   4.57310081e-02,   1.57960773e-01,
                          2.25905120e-01,  -3.76817048e-01,  -6.77957833e-02,
                          7.46406853e-01,  -1.86905727e-01,  -7.27368772e-01,
                          7.21322417e-01,   5.35879493e-01,  -8.70167494e-01,
                         -8.67130160e-02,   9.44886625e-01,  -1.27955392e-01,
                         -7.32454717e-01,   3.85681003e-01,   5.32492340e-01,
                         -2.85047382e-01,  -1.92662641e-01,   1.62303224e-01,
                          1.34893104e-01,   2.06724748e-01,  -7.95477107e-02,
                         -3.96239847e-01,   2.72108167e-01,   6.02744937e-01,
                         -4.71218556e-01,  -5.35675526e-01,   6.91710055e-01,
                          3.76263499e-01,  -7.39453435e-01,   3.24328132e-02,
                          7.52699375e-01,  -3.14846039e-01,  -5.25885403e-01,
                          4.45902795e-01,   2.79396296e-01,  -3.32889497e-01,
                          1.85458902e-02,   1.78977996e-01,   5.09067997e-02,
                          5.32377362e-02,  -2.87738293e-01,   3.89792174e-02,
                          5.71673036e-01,  -3.63830805e-01,  -4.68512297e-01,
                          7.78649628e-01,   2.06641063e-01,  -9.26486135e-01,
                          2.02005401e-01,   8.99279654e-01,  -5.02517819e-01,
                         -6.14222765e-01,   6.40147090e-01,   3.27343166e-01,
                         -5.37609339e-01,  -1.10298954e-01,   3.51348251e-01,
                          8.43528658e-02,  -2.31963955e-02,  -1.54362679e-01,
                         -2.02412590e-01,   3.90028119e-01,   3.08187962e-01,
                         -6.07740700e-01,  -2.36822918e-01,   7.89891839e-01,
                          4.67931665e-02,  -7.66321421e-01,   2.98594087e-01,
                          6.64048731e-01,  -5.24959326e-01,  -4.05611038e-01,
                          6.03987634e-01,   8.94973427e-02,  -4.77937847e-01,
                          1.44545421e-01,   2.59827763e-01,  -6.12070002e-02,
                         -6.59285933e-02,  -1.59871727e-01,   1.30520165e-01,
                          3.41209948e-01,  -4.56714809e-01,  -2.67152190e-01,
                          7.79216170e-01,  -2.57644746e-02,  -9.16288137e-01,
                          5.13678491e-01,   7.04100132e-01,  -8.00745249e-01,
                         -3.28725666e-01,   8.46047461e-01,   5.23009486e-02,
                         -7.10202932e-01,   1.08352356e-01,   4.56902504e-01,
                         -9.79348496e-02,  -1.73904017e-01,  -6.52945861e-02,
                          2.82680290e-03,   3.21323305e-01,   5.27650416e-02,
                         -5.69152117e-01,   4.40601856e-02,   7.33478010e-01,
                         -2.78213322e-01,  -7.32753813e-01,   5.02813697e-01,
                          5.25605500e-01,  -6.88547134e-01,  -1.78118914e-01,
                          7.11130619e-01,  -1.32945254e-01,  -5.27677059e-01,
                          2.90679455e-01,   2.68448949e-01,  -2.48049349e-01,
                         -5.54944389e-02,   1.10573247e-02,   1.29380718e-01,
                          1.64690211e-01,  -4.27189618e-01,  -8.43442157e-02,
                          7.08007693e-01,  -2.83403188e-01,  -7.25242913e-01,
                          7.24767804e-01,   4.30512398e-01,  -9.56296802e-01,
                         -1.61862131e-02,   8.90819192e-01,  -2.61556268e-01,
                         -7.42042661e-01,   3.94605219e-01,   4.22091335e-01,
                         -3.60874593e-01,  -1.97937325e-01,   1.24991372e-01,
                          1.00451797e-01,   1.53552905e-01,  -1.34520724e-01,
                         -4.40201610e-01,   2.77299672e-01,   5.26859224e-01,
                         -5.20278275e-01,  -5.04052043e-01,   6.90373898e-01,
                          2.58227110e-01,  -7.71569014e-01,   6.45604208e-02,
                          7.37868607e-01,  -3.74236822e-01,  -5.31411290e-01,
                          4.59513664e-01,   1.72902450e-01,  -3.80662173e-01,
                          1.92380305e-02,   1.34184077e-01,   3.56750414e-02,
                          6.70275558e-03,  -3.24650347e-01,   7.25368187e-02,
                          5.30831218e-01,  -4.69746619e-01,  -4.58052516e-01,
                          7.94434965e-01,   1.21454537e-01,  -9.36196804e-01,
                          2.21773818e-01,   8.08461666e-01,  -5.78090847e-01,
                         -5.81645727e-01,   6.59426868e-01,   2.65552580e-01,
                         -5.69535971e-01,  -1.28373429e-01,   3.18417132e-01,
                          3.12141012e-02,  -6.56480640e-02,  -1.86890438e-01,
                         -1.89353243e-01,   3.87339979e-01,   2.79796511e-01,
                         -6.32848382e-01,  -2.32188329e-01,   7.47604966e-01,
                         -6.12333417e-02,  -7.98218668e-01,   3.71143013e-01,
                          5.97478330e-01,  -6.13121390e-01,  -4.27942693e-01,
                          5.72669089e-01,   1.47647290e-02,  -5.26610255e-01,
                          1.23327941e-01,   1.96863592e-01,  -1.10799313e-01,
                         -8.81352723e-02,  -1.86806515e-01,   1.30081534e-01,
                          2.76797116e-01,  -5.01833618e-01,  -2.46110797e-01,
                          7.57571697e-01,  -1.67506173e-01,  -8.89475822e-01,
                          5.29651761e-01,   6.08253121e-01,  -8.78998458e-01,
                         -3.08405787e-01,   8.02665949e-01,  -1.05700130e-02,
                         -7.53504276e-01,   1.14470795e-01,   3.98388594e-01,
                         -1.51511416e-01,  -2.18546897e-01,  -9.26619992e-02,
                         -3.11377039e-03,   2.88016796e-01,  -3.20761390e-02,
                         -6.10782921e-01,   6.69142380e-02,   6.40448391e-01,
                         -3.80503088e-01,  -6.86234117e-01,   5.55730581e-01,
                          4.52344179e-01,  -7.80716181e-01,  -1.75249889e-01,
                          6.87593400e-01,  -2.19132781e-01,  -5.89722455e-01,
                          2.75897950e-01,   2.18320146e-01,  -2.74825722e-01,
                         -1.02402672e-01,  -2.36145277e-02,   1.05626352e-01,
                          9.76385176e-02,  -4.65657413e-01,  -8.01230520e-02,
                          6.57907367e-01,  -4.00997370e-01,  -7.07760692e-01,
                          7.40224361e-01,   2.85547584e-01,  -9.89774346e-01,
                         -5.48107922e-03,   8.59069586e-01,  -3.45910132e-01,
                         -7.27635503e-01,   4.29594606e-01,   3.65047872e-01,
                         -4.16461378e-01,  -2.25433737e-01,   9.26063508e-02,
                          8.37912261e-02,   1.01729244e-01,  -1.97154328e-01,
                         -4.36161280e-01,   2.99237609e-01,   4.47257876e-01,
                         -5.97041965e-01,  -4.64338422e-01,   7.39662290e-01,
                          1.63506985e-01,  -8.46819639e-01,   9.21132118e-02,
                          6.60835981e-01,  -4.35400754e-01,  -5.10069370e-01,
                          4.53971386e-01,   1.35444582e-01,  -4.18836266e-01,
                          7.78413704e-03,   1.17239147e-01,   4.62675700e-03,
                         -3.46625783e-02,  -3.57883036e-01,   7.96784386e-02,
                          4.82778996e-01,  -5.30260801e-01,  -4.50022250e-01,
                          8.33460987e-01,  -1.64887104e-02,  -9.69259679e-01,
                          3.23874295e-01,   7.85719573e-01,  -6.60600960e-01,
                         -4.98416066e-01,   6.69699311e-01,   1.65469781e-01,
                         -5.98406732e-01,  -9.17139798e-02,   3.19886118e-01,
                          9.74747725e-03,  -7.06504434e-02,  -2.06581771e-01,
                         -1.74174935e-01,   3.72507483e-01,   2.13273868e-01,
                         -6.60336554e-01,  -1.60731986e-01,   7.17428923e-01,
                         -1.41978770e-01,  -8.15238893e-01,   3.83646399e-01,
                          6.20363712e-01,  -6.24117196e-01,  -3.31291258e-01,
                          6.01159453e-01,  -4.96884622e-02,  -4.98880744e-01,
                          1.71642154e-01,   2.05982238e-01,  -1.12105496e-01,
                         -9.37553346e-02,  -1.63897052e-01,   1.63009793e-01,
                          2.76086122e-01,  -5.40007830e-01,  -1.88471690e-01,
                          7.80014992e-01,  -2.08858088e-01,  -8.31789553e-01,
                          5.93418717e-01,   5.30389130e-01,  -8.82033348e-01,
                         -1.86222687e-01,   8.41711164e-01,  -5.12743630e-02,
                         -7.03594327e-01,   1.97659552e-01,   4.09588337e-01,
                         -1.71927363e-01,  -1.79365128e-01,  -5.61601594e-02,
                          2.73203515e-02,   3.27750593e-01,  -2.95869373e-02,
                         -5.73346734e-01,   1.57127991e-01,   6.67380810e-01,
                         -4.36691284e-01,  -6.00791872e-01,   6.66662872e-01,
                          4.47567642e-01,  -7.07549930e-01,  -5.70296273e-02,
                          7.33348548e-01,  -2.01900125e-01,  -4.58132923e-01,
                          3.66500169e-01,   2.25177482e-01,  -2.34144077e-01,
                         -2.28197481e-02,   6.31664619e-02,   1.64079502e-01,
                          1.36846840e-01,  -4.22083110e-01,   5.48808537e-02,
                          6.97070062e-01,  -3.96599293e-01,  -5.99070668e-01,
                          8.63458276e-01,   2.84765989e-01,  -9.13473010e-01,
                          1.13221340e-01,   9.26226199e-01,  -3.97761911e-01,
                         -6.06732488e-01,   5.48852742e-01,   4.02572155e-01,
                         -3.69878858e-01,  -1.41598731e-01,   1.92914113e-01,
                          1.35677472e-01,   1.76139995e-01,  -1.58642173e-01,
                         -3.29000801e-01,   4.11547273e-01,   4.82314676e-01,
                         -5.60441017e-01,  -3.54070216e-01,   7.95885026e-01,
                          1.50527909e-01,  -7.76530981e-01,   2.50157058e-01,
                          7.38634408e-01,  -3.88510585e-01,  -3.89261156e-01,
                          5.38924277e-01,   1.36203289e-01,  -3.58352512e-01,
                          9.06461030e-02,   1.90770954e-01,   7.65316933e-02,
                          2.83212867e-02,  -2.67068565e-01,   1.94270849e-01,
                          5.26931763e-01,  -5.12395978e-01,  -3.01747888e-01,
                          9.02611494e-01,   1.43213412e-02,  -8.86008322e-01,
                          4.50173736e-01,   7.89114058e-01,  -6.77912772e-01,
                         -3.87596160e-01,   8.00651729e-01,   1.76716685e-01,
                         -5.55012763e-01,  -5.08914643e-04,   3.85304391e-01,
                          5.95154352e-02,  -1.61407311e-02,  -1.47380516e-01,
                         -9.01616886e-02,   4.62291718e-01,   2.08893225e-01,
                         -6.42193556e-01,  -3.79595570e-02,   8.25889647e-01,
                         -1.44996211e-01,  -7.03649223e-01,   5.01111865e-01,
                          6.07713580e-01,  -5.81364691e-01,  -2.23911107e-01,
                          6.56974316e-01,  -4.49573882e-02,  -4.37679440e-01,
                          2.47338757e-01,   2.60089844e-01,  -6.58373386e-02,
                         -2.16122232e-02,  -1.08168088e-01,   2.31817335e-01,
                          3.18280309e-01,  -5.26574194e-01,  -5.93166687e-02,
                          8.32604408e-01,  -2.55711943e-01,  -7.53504217e-01,
                          7.41384625e-01,   5.16187131e-01,  -8.46455336e-01,
                         -9.81984809e-02,   8.70290875e-01,  -8.11444148e-02,
                         -6.56028032e-01,   2.76090622e-01,   4.54985321e-01,
                         -1.51383132e-01,  -1.39407218e-01,   2.07056262e-04,
                          7.59112686e-02,   3.52879912e-01,  -5.17172776e-02,
                         -5.30358434e-01,   2.39853814e-01,   6.66864157e-01,
                         -4.50256407e-01,  -6.15358353e-01,   6.83413565e-01,
                          3.76452535e-01,  -7.20895290e-01,   2.93433871e-02,
                          6.92038834e-01,  -3.03912431e-01,  -4.65863258e-01,
                          3.76419216e-01,   2.18278199e-01,  -2.21855149e-01,
                         -5.08696958e-03,   3.20436433e-02,   1.62992939e-01,
                          9.81002897e-02,  -4.45329040e-01,   6.56957999e-02,
                          6.52756751e-01,  -4.43310887e-01,  -5.14306426e-01,
                          8.41369271e-01,   1.72578871e-01,  -9.36557412e-01,
                          1.98954776e-01,   8.50079119e-01,  -4.49429929e-01,
                         -5.98343134e-01,   5.38013458e-01,   3.08857679e-01,
                         -4.11776453e-01,  -1.40688926e-01,   1.80797875e-01,
                          1.03685565e-01,   1.32395148e-01,  -2.00749174e-01,
                         -3.50202709e-01,   4.28774983e-01,   4.05482113e-01,
                         -6.50094092e-01,  -3.06769997e-01,   7.79093683e-01,
                          7.23483339e-02,  -7.58944392e-01,   2.80312717e-01,
                          6.33263528e-01,  -5.13371110e-01,  -3.82676750e-01,
                          5.37116408e-01,   6.43205270e-02,  -3.78688276e-01,
                          8.62038806e-02,   1.54003561e-01,   3.85437645e-02,
                         -3.09397578e-02,  -3.05625498e-01,   1.72884434e-01,
                          4.36435461e-01,  -5.87984622e-01,  -2.85521746e-01,
                          8.61791790e-01,  -6.34642765e-02,  -9.44682896e-01,
                          5.19819617e-01,   6.77888334e-01,  -7.69689679e-01,
                         -3.32353503e-01,   7.50806391e-01,   7.78505206e-02,
                         -5.97069621e-01,   1.76174175e-02,   3.30394447e-01,
                          2.22552591e-03,  -6.89985156e-02,  -1.86352804e-01,
                         -1.11475177e-01,   4.34453487e-01,   1.35630727e-01,
                         -6.67952597e-01,  -1.38024045e-02,   7.81415939e-01,
                         -2.75678247e-01,  -7.47801244e-01,   4.78655487e-01,
                          5.23327470e-01,  -6.60952032e-01,  -1.75005585e-01,
                          6.32674992e-01,  -1.23630181e-01,  -4.52408731e-01,
                          2.29341075e-01,   1.70819491e-01,  -1.17653966e-01,
                         -5.63685521e-02,  -1.39507353e-01,   2.01546580e-01,
                          2.38500357e-01,  -5.64392328e-01,  -6.21438362e-02,
                          7.88103819e-01,  -3.46841037e-01,  -7.50222325e-01,
                          7.53133595e-01,   4.13729757e-01,  -9.54580426e-01,
                         -2.52395459e-02,   8.28373849e-01,  -2.03006089e-01,
                         -6.70618355e-01,   2.82667905e-01,   3.49277258e-01,
                         -2.27220267e-01,  -1.49826661e-01,  -4.18201536e-02,
                          5.37030585e-02,   3.13067198e-01,  -1.18025459e-01,
                         -5.62169194e-01,   2.59973735e-01,   6.04996443e-01,
                         -5.09369373e-01,  -5.64404786e-01,   6.79763973e-01,
                          2.73785502e-01,  -7.58880973e-01,   5.77796102e-02,
                          6.82921886e-01,  -3.35733473e-01,  -4.80936646e-01,
                          3.81579965e-01,   1.30799368e-01,  -2.58256346e-01,
                         -1.45667838e-02,   1.82491429e-02,   1.38899922e-01,
                          5.79913929e-02,  -4.61862415e-01,   1.10307112e-01,
                          6.24445021e-01,  -5.62664211e-01,  -4.86528397e-01,
                          8.72745931e-01,   9.09641162e-02,  -9.47124898e-01,
                          2.23367035e-01,   7.77949750e-01,  -5.13983548e-01,
                         -5.64530313e-01,   5.57575464e-01,   2.63717413e-01,
                         -4.46434677e-01,  -1.38472512e-01,   1.59133106e-01,
                          8.13611746e-02,   1.01363868e-01,  -2.48913571e-01,
                         -3.20282817e-01,   4.42432523e-01,   3.96155417e-01,
                         -6.64505899e-01,  -2.82045633e-01,   7.52387404e-01,
                         -3.19299996e-02,  -7.78786659e-01,   3.41394335e-01,
                          5.91675997e-01,  -5.73632896e-01,  -3.92180145e-01,
                          5.07920623e-01,   9.37549584e-03,  -4.02673930e-01,
                          7.70491883e-02,   1.17583662e-01,   4.73560998e-03,
                         -6.84948340e-02,  -2.93465912e-01,   1.98576823e-01,
                          3.77192289e-01,  -6.16096437e-01,  -2.37196520e-01,
                          8.52692723e-01,  -1.98226526e-01,  -9.00029242e-01,
                          5.46029091e-01,   6.20525062e-01,  -8.32726061e-01,
                         -3.17692369e-01,   7.40358293e-01,   4.71891388e-02,
                         -6.49691880e-01,   3.71144339e-02,   3.16115946e-01,
                         -4.05130684e-02,  -9.22106057e-02,  -2.12496415e-01,
                         -1.08862884e-01,   4.37161505e-01,   6.05903566e-02,
                         -7.00263619e-01,   3.01446151e-02,   7.01664567e-01,
                         -3.47168654e-01,  -6.97271168e-01,   5.50818980e-01,
                          4.46213126e-01,  -7.20549345e-01,  -1.51338920e-01,
                          6.28821075e-01,  -2.00572759e-01,  -4.80145961e-01,
                          2.23073110e-01,   1.61946520e-01,  -1.45402089e-01,
                         -8.27934220e-02,  -1.43756911e-01,   2.20145538e-01,
                          1.76916271e-01,  -5.86880922e-01,  -5.77088520e-02,
                          7.74724901e-01,  -4.45699155e-01,  -7.22703516e-01,
                          7.83786356e-01,   2.99470603e-01,  -9.57607925e-01,
                         -1.18510304e-02,   8.17946315e-01,  -2.63604552e-01,
                         -6.56643808e-01,   3.27660263e-01,   3.35446328e-01,
                         -2.64057040e-01,  -1.78080052e-01,  -5.81727475e-02,
                          6.96842596e-02,   2.88629830e-01,  -1.69175893e-01,
                         -5.63834488e-01,   3.10933620e-01,   5.52500427e-01,
                         -5.87122858e-01,  -4.97679263e-01,   7.47556627e-01,
                          1.90704852e-01,  -8.06178153e-01,   1.01698749e-01,
                          6.27164245e-01,  -3.98566693e-01,  -4.33338732e-01,
                          3.85714293e-01,   1.16725892e-01,  -2.86179304e-01,
                         -4.48915455e-03,   5.74344769e-03,   1.31888747e-01,
                          2.50571780e-02,  -4.72163558e-01,   1.22198880e-01,
                          5.84042072e-01,  -6.02479994e-01,  -4.44146186e-01,
                          9.03847992e-01,  -1.60099119e-02,  -9.50894713e-01,
                          3.10231090e-01,   7.72145212e-01,  -5.79401135e-01,
                         -4.79766876e-01,   5.85998237e-01,   1.93940639e-01,
                         -4.68011916e-01,  -1.04854003e-01,   1.79612309e-01,
                          9.58233774e-02,   7.44717941e-02,  -2.57531464e-01,
                         -2.91084081e-01,   4.41747576e-01,   3.36332381e-01,
                         -6.89295888e-01,  -2.14964747e-01,   7.60836184e-01,
                         -1.11497812e-01,  -7.98198819e-01,   3.72833103e-01,
                          6.14149213e-01,  -5.71685135e-01,  -2.96601534e-01,
                          5.34850657e-01,  -3.96333374e-02,  -3.91472191e-01,
                          1.31759018e-01,   1.33202821e-01,  -2.82341178e-04,
                         -4.89567295e-02,  -2.67873555e-01,   2.37295836e-01,
                          3.60864550e-01,  -6.37362480e-01,  -1.58306643e-01,
                          8.35666120e-01,  -2.24656567e-01,  -8.14562678e-01,
                          5.98267198e-01,   5.21386325e-01,  -8.04990947e-01,
                         -2.00213000e-01,   7.72408664e-01,   1.93061382e-02,
                         -6.00019872e-01,   1.05650440e-01,   3.32367063e-01,
                         -4.55653258e-02,  -7.77299181e-02,  -1.74804151e-01,
                         -6.11691400e-02,   4.69561011e-01,   5.90251982e-02,
                         -6.50622368e-01,   1.17643468e-01,   7.32186556e-01,
                         -3.98400694e-01,  -6.19113326e-01,   6.42662346e-01,
                          4.79467243e-01,  -6.66714609e-01,  -4.91066016e-02,
                          6.84930146e-01,  -1.82937577e-01,  -3.74627233e-01,
                          2.92013407e-01,   2.00328022e-01,  -1.25499234e-01,
                         -2.67208666e-02,  -6.14421703e-02,   2.88099021e-01,
                          1.97953030e-01,  -5.37803292e-01,   8.63353759e-02,
                          7.71834552e-01,  -4.48199332e-01,  -5.91538489e-01,
                          8.82903039e-01,   3.00692677e-01,  -8.84219289e-01,
                          8.42484310e-02,   8.89423728e-01,  -3.10283661e-01,
                         -5.60758650e-01,   4.43500310e-01,   3.70871753e-01,
                         -2.22764522e-01,  -1.12690732e-01,   2.51429714e-02,
                          1.42669111e-01,   3.31414670e-01,  -1.45058185e-01,
                         -4.41036373e-01,   4.06152159e-01,   5.84053934e-01,
                         -5.61963558e-01,  -3.95475239e-01,   7.99447656e-01,
                          1.75172210e-01,  -7.70622134e-01,   2.52646834e-01,
                          7.02627420e-01,  -3.42630684e-01,  -3.56696695e-01,
                          4.79706287e-01,   1.18028566e-01,  -2.26628676e-01,
                          4.62634489e-02,   8.24445561e-02,   2.02162102e-01,
                          8.37420598e-02,  -4.12071645e-01,   2.59543061e-01,
                          6.02957487e-01,  -5.89170396e-01,  -2.95396745e-01,
                          9.48330402e-01,   1.22236181e-02,  -8.92403066e-01,
                          4.28523809e-01,   7.80082226e-01,  -6.05106413e-01,
                         -3.79719883e-01,   7.14929640e-01,   1.88078925e-01,
                         -4.26402211e-01,  -3.47910114e-02,   2.42205173e-01,
                          1.39546931e-01,   1.29658818e-01,  -2.24749193e-01,
                         -2.14817509e-01,   5.42575300e-01,   3.11476469e-01,
                         -6.88760459e-01,  -9.42061543e-02,   8.54509115e-01,
                         -1.26642659e-01,  -6.99469864e-01,   4.97156173e-01,
                          5.82925439e-01,  -5.48000336e-01,  -1.96882382e-01,
                          6.00115597e-01,  -4.29371148e-02,  -3.32801074e-01,
                          1.80521160e-01,   1.93536490e-01,   5.39632104e-02,
                         -2.02395320e-02,  -2.39557371e-01,   3.23703945e-01,
                          3.80451649e-01,  -6.25406802e-01,  -5.25105782e-02,
                          9.01271403e-01,  -2.83651888e-01,  -7.70899415e-01,
                          7.56117880e-01,   5.08780837e-01,  -8.16044211e-01,
                         -1.16041347e-01,   8.16649556e-01,  -2.76838187e-02,
                         -5.60621619e-01,   1.75355896e-01,   3.60340893e-01,
                         -2.51752734e-02,  -4.39683162e-02,  -1.42424181e-01,
                         -9.42537282e-03,   4.91707265e-01,   5.06403111e-03,
                         -6.41452372e-01,   2.11453199e-01,   7.07326889e-01,
                         -4.42277849e-01,  -6.31386101e-01,   6.65782213e-01,
                          3.70735049e-01,  -6.97582722e-01,   2.77195834e-02,
                          6.38270736e-01,  -2.75115430e-01,  -3.92174691e-01,
                          2.98681170e-01,   1.63623467e-01,  -1.06485277e-01,
                         -4.69149761e-02,  -8.67906362e-02,   2.71166444e-01,
                          1.28204226e-01,  -5.72260737e-01,   9.84190926e-02,
                          7.17591643e-01,  -5.08658111e-01,  -5.27666450e-01,
                          8.60511363e-01,   1.52826801e-01,  -9.22575176e-01,
                          1.67585790e-01,   8.10516238e-01,  -3.88596773e-01,
                         -5.67657471e-01,   4.29543853e-01,   2.79387742e-01,
                         -2.79323578e-01,  -1.22866370e-01,   4.16107755e-03,
                          9.80316624e-02,   2.83124566e-01,  -2.15844303e-01,
                         -4.77036864e-01,   4.33274567e-01,   4.71344799e-01,
                         -6.61192298e-01,  -3.68361205e-01,   7.82672524e-01,
                          8.81908461e-02,  -7.68842578e-01,   2.70381510e-01,
                          5.90810418e-01,  -4.75333869e-01,  -3.52184623e-01,
                          4.59566742e-01,   3.92792746e-02,  -2.81489521e-01,
                          2.67828088e-02,   5.06163575e-02,   1.50670767e-01,
                         -1.16699096e-02,  -4.45872724e-01,   2.37241656e-01,
                          4.86644775e-01,  -6.87620997e-01,  -2.87624508e-01,
                          8.96580875e-01,  -7.99561292e-02,  -9.53244627e-01,
                          4.91268784e-01,   6.59549832e-01,  -7.17728376e-01,
                         -3.54518801e-01,   6.61294878e-01,   9.91807058e-02,
                         -4.91514832e-01,  -4.49395217e-02,   1.95541427e-01,
                          6.98913783e-02,   3.59591953e-02,  -2.70306170e-01,
                         -2.43118107e-01,   4.95587468e-01,   2.34248966e-01,
                         -7.29042292e-01,  -7.70813525e-02,   8.08830142e-01,
                         -2.67399967e-01,  -7.64612973e-01,   4.51046884e-01,
                          5.01633346e-01,  -6.31423771e-01,  -1.67237550e-01,
                          5.63075960e-01,  -1.27775639e-01,  -3.69500816e-01,
                          1.42360508e-01,   9.93463397e-02,  -9.61869198e-04,
                         -9.91418809e-02,  -2.58802027e-01,   2.95402318e-01,
                          2.72400916e-01,  -6.86380148e-01,  -5.28728403e-02,
                          8.40551317e-01,  -3.93760651e-01,  -7.56859362e-01,
                          7.44276762e-01,   3.91541988e-01,  -9.18651164e-01,
                         -5.71529046e-02,   7.54670203e-01,  -1.52630821e-01,
                         -6.09897077e-01,   1.72318414e-01,   2.79624224e-01,
                         -9.84861925e-02,  -1.02022879e-01,  -1.95672825e-01,
                         -7.40659935e-03,   4.41362858e-01,  -8.14902261e-02,
                         -6.71566904e-01,   2.21995935e-01,   6.59392595e-01,
                         -5.14997602e-01,  -5.91418326e-01,   6.60490274e-01,
                          2.68014461e-01,  -7.53583968e-01,   6.51607513e-02,
                          6.07833147e-01,  -3.13710898e-01,  -4.16812390e-01,
                          2.90674806e-01,   9.28855911e-02,  -1.50849208e-01,
                         -7.85890445e-02,  -8.40283707e-02,   2.52906144e-01,
                          7.71584138e-02,  -5.92930675e-01,   1.47499204e-01,
                          6.83140397e-01,  -6.39472306e-01,  -4.87359822e-01,
                          8.77260864e-01,   8.13402310e-02,  -9.37965572e-01,
                          1.95472404e-01,   7.37484217e-01,  -4.47551697e-01,
                         -5.53770959e-01,   4.35289294e-01,   2.50487834e-01,
                         -3.10382128e-01,  -1.41032219e-01,  -1.34527450e-02,
                          8.55644494e-02,   2.53097773e-01,  -2.71364659e-01,
                         -4.41954464e-01,   4.52602208e-01,   4.88251597e-01,
                         -6.90513611e-01,  -3.23059767e-01,   7.57495582e-01,
                         -2.88736075e-02,  -7.76930749e-01,   3.32712561e-01,
                          5.45458376e-01,  -5.36751390e-01,  -3.45156044e-01,
                          4.39271301e-01,  -3.99200292e-03,  -2.96980679e-01,
                          2.10818183e-02,   2.65530683e-02,   1.39257073e-01,
                         -6.54369146e-02,  -4.28239703e-01,   2.75887609e-01,
                          4.40026879e-01,  -7.02450156e-01,  -2.20601976e-01,
                          8.88612986e-01,  -2.26293281e-01,  -8.94099653e-01,
                          5.33890128e-01,   6.06796920e-01,  -7.72936463e-01,
                         -3.25987786e-01,   6.53287709e-01,   8.08539391e-02,
                         -5.23603499e-01,  -2.74116509e-02,   1.68972030e-01,
                          6.60598874e-02,   3.12794670e-02,  -3.11747402e-01,
                         -2.03294992e-01,   5.23688614e-01,   1.40947014e-01,
                         -7.58679569e-01,  -2.02061161e-02,   7.51515388e-01,
                         -3.42576087e-01,  -6.97842836e-01,   5.35377324e-01,
                          4.37397391e-01,  -6.87223375e-01,  -1.29015982e-01,
                          5.60981095e-01,  -1.89104825e-01,  -3.82332385e-01,
                          1.51581094e-01,   9.98169407e-02,  -1.26958778e-02,
                         -9.87862647e-02,  -2.60865897e-01,   3.31332147e-01,
                          2.33284444e-01,  -7.06466436e-01,  -2.73933094e-02,
                          8.39469314e-01,  -4.90520835e-01,  -7.07059622e-01,
                          7.85457969e-01,   2.97918588e-01,  -9.12426233e-01,
                         -5.24106026e-02,   7.79113531e-01,  -1.95522785e-01,
                         -5.89804113e-01,   2.24349171e-01,   2.68007994e-01,
                         -1.12144805e-01,  -1.11530118e-01,  -2.00761184e-01,
                          4.98143723e-04,   4.35482562e-01,  -1.19981684e-01,
                         -6.72711074e-01,   2.98938155e-01,   6.18275404e-01,
                         -5.75006902e-01,  -5.24631977e-01,   7.37201989e-01,
                          2.09012017e-01,  -7.76828051e-01,   1.01061195e-01,
                          5.67785859e-01,  -3.54783922e-01,  -3.65022510e-01,
                          3.19052964e-01,   8.15396830e-02,  -1.63819611e-01,
                         -6.56357706e-02,  -8.49158615e-02,   2.62309283e-01,
                          6.43444508e-02,  -6.07233226e-01,   1.90098420e-01,
                          6.47382855e-01,  -6.68051720e-01,  -4.35490489e-01,
                          9.24425364e-01,  -2.69593559e-02,  -9.27130699e-01,
                          2.85676569e-01,   7.57516742e-01,  -4.99347687e-01,
                         -4.75971162e-01,   4.87128675e-01,   2.07032621e-01,
                         -3.25020999e-01,  -1.18721873e-01,   8.39438289e-03,
                          1.21613555e-01,   2.50345647e-01,  -2.89949715e-01,
                         -4.22143489e-01,   4.84286606e-01,   4.29919779e-01,
                         -7.06364214e-01,  -2.66048074e-01,   7.85854161e-01,
                         -9.81410518e-02,  -7.75508642e-01,   3.52026790e-01,
                          5.67602277e-01,  -5.08757353e-01,  -2.49672920e-01,
                          4.50321466e-01,  -2.70043220e-02,  -2.86649197e-01,
                          5.07050455e-02,   5.78649156e-02,   1.52261898e-01,
                         -6.61447048e-02,  -3.97478580e-01,   3.41362357e-01,
                          4.17237073e-01,  -7.31357932e-01,  -1.49496734e-01,
                          9.03357387e-01,  -2.50732690e-01,  -8.12488854e-01,
                          5.89153409e-01,   5.20709038e-01,  -7.51410544e-01,
                         -2.13430285e-01,   6.90408468e-01,   5.90821207e-02,
                         -4.86551166e-01,   4.41870354e-02,   1.95023194e-01,
                          7.67270699e-02,   3.79505865e-02,  -2.93670624e-01,
                         -1.58892885e-01,   5.76055408e-01,   1.43807501e-01,
                         -7.16380000e-01,   7.93113485e-02,   7.69779086e-01,
                         -3.84753048e-01,  -6.22334778e-01,   6.35316908e-01,
                          4.56870615e-01,  -6.19627118e-01,  -2.82624606e-02,
                          5.98595560e-01,  -1.55353412e-01,  -2.94365853e-01,
                          2.16803879e-01,   1.44343019e-01,   1.66666731e-02,
                         -6.43469468e-02,  -1.83530077e-01,   4.18374717e-01,
                          2.29777202e-01,  -6.61436498e-01,   1.17626727e-01,
                          8.51431549e-01,  -4.97232497e-01,  -6.09107435e-01,
                          9.02589738e-01,   2.89767325e-01,  -8.57317507e-01,
                          6.53011650e-02,   8.46059799e-01,  -2.56422728e-01,
                         -4.92820174e-01,   3.35586756e-01,   3.12505335e-01,
                         -7.25901946e-02,  -6.04932159e-02,  -1.41146481e-01,
                          9.20930132e-02,   4.89508957e-01,  -1.11779548e-01,
                         -5.59654295e-01,   4.05228943e-01,   6.44647419e-01,
                         -5.56595922e-01,  -4.24792707e-01,   7.93676972e-01,
                          1.65063903e-01,  -7.16041803e-01,   2.46328712e-01,
                          6.44086778e-01,  -3.14424425e-01,  -2.90321946e-01,
                          3.84125441e-01,   1.04771160e-01,  -1.10795937e-01,
                         -1.58724412e-02,  -5.94313443e-03,   3.46014559e-01,
                          8.66377428e-02,  -5.48509061e-01,   3.33906263e-01,
                          6.66670978e-01,  -6.87961459e-01,  -2.74644524e-01,
                          9.83426750e-01,   1.99777816e-04,  -8.80625367e-01,
                          4.04948413e-01,   7.64410675e-01,  -5.39466560e-01,
                         -3.66813391e-01,   5.93023479e-01,   2.11153746e-01,
                         -2.78236032e-01,  -5.86936288e-02,   7.48825520e-02,
                          1.85605362e-01,   2.74923056e-01,  -2.73383945e-01,
                         -3.25797528e-01,   5.86168766e-01,   3.93412858e-01,
                         -7.16546297e-01,  -1.33612946e-01,   8.48038614e-01,
                         -1.09797463e-01,  -6.67363763e-01,   4.67524648e-01,
                          5.51740348e-01,  -5.02326071e-01,  -1.63932472e-01,
                          5.11587918e-01,  -1.87882148e-02,  -2.32447803e-01,
                          1.03439674e-01,   1.11802682e-01,   2.01872975e-01,
                         -4.91609015e-02,  -3.64965737e-01,   4.27673608e-01,
                          4.32275176e-01,  -7.44811952e-01,  -1.77414040e-03,
                          9.32486713e-01,  -3.09883833e-01,  -7.76613176e-01,
                          7.43827403e-01,   5.12536287e-01,  -7.53098130e-01,
                         -1.45066857e-01,   7.31994629e-01,   2.00446341e-02,
                         -4.57535923e-01,   9.59855989e-02,   2.43630946e-01,
                          9.83137563e-02,   5.36361784e-02,  -2.83125043e-01,
                         -8.56723860e-02,   5.89662850e-01,   7.34755322e-02,
                         -7.27998257e-01,   1.72419399e-01,   7.56913006e-01,
                         -4.38350916e-01,  -6.50024474e-01,   6.44700825e-01,
                          3.56437147e-01,  -6.57741785e-01,   3.51121835e-02,
                          5.67464173e-01,  -2.44666561e-01,  -3.23120773e-01,
                          2.11569071e-01,   1.15918495e-01,   2.02969797e-02,
                         -1.05586722e-01,  -2.01313823e-01,   3.94645840e-01,
                          1.36678547e-01,  -6.85601830e-01,   1.44759595e-01,
                          7.71941364e-01,  -5.76563835e-01,  -5.27911127e-01,
                          8.62189829e-01,   1.56114474e-01,  -9.02378559e-01,
                          1.32818058e-01,   7.57499397e-01,  -3.26144785e-01,
                         -5.04901528e-01,   2.94808507e-01,   2.39699557e-01,
                         -1.26586348e-01,  -1.00320011e-01,  -1.70489326e-01,
                          6.03838190e-02,   4.23367769e-01,  -1.98765472e-01,
                         -5.99082470e-01,   4.30379450e-01,   5.49991727e-01,
                         -6.90782785e-01,  -3.99581164e-01,   7.80664265e-01,
                          6.54645115e-02,  -7.28743374e-01,   2.48753175e-01,
                          5.34382045e-01,  -4.33019280e-01,  -3.02835137e-01,
                          3.60047251e-01,   2.73226295e-02,  -1.64063618e-01,
                         -6.27001002e-02,  -4.40864637e-02,   2.88829654e-01,
                         -2.06294805e-02,  -5.88282168e-01,   3.20687830e-01,
                          5.21419048e-01,  -7.78114080e-01,  -2.79031813e-01,
                          9.26975012e-01,  -1.23851493e-01,  -9.28193867e-01,
                          4.63662893e-01,   6.23155415e-01,  -6.46400213e-01,
                         -3.64542693e-01,   5.43694258e-01,   1.23221375e-01,
                         -3.56430173e-01,  -8.68140236e-02,   2.27481779e-02,
                          1.19668283e-01,   1.93184525e-01,  -3.54164779e-01,
                         -3.69502246e-01,   5.48415422e-01,   3.06944191e-01,
                         -7.72384226e-01,  -1.13835424e-01,   7.93732762e-01,
                         -2.48465896e-01,  -7.51319349e-01,   4.21679378e-01,
                          4.65485066e-01,  -5.96633255e-01,  -1.50690764e-01,
                          4.73353058e-01,  -1.08335868e-01,  -2.81377405e-01,
                          4.77868430e-02,   3.96783352e-02,   1.27493322e-01,
                         -1.29720837e-01,  -4.08349782e-01,   4.12809640e-01,
                          2.96478212e-01,  -8.01275313e-01,  -2.40451898e-02,
                          8.77482712e-01,  -4.24690396e-01,  -7.72201359e-01,
                          7.21286416e-01,   3.80110115e-01,  -8.64990413e-01,
                         -9.94249508e-02,   6.77859426e-01,  -1.00017153e-01,
                         -5.11161506e-01,   6.42685741e-02,   1.69534251e-01,
                          2.67825965e-02,  -9.76948440e-03,  -3.35611999e-01,
                         -1.12684056e-01,   5.67179441e-01,  -2.04161890e-02,
                         -7.67276108e-01,   1.96370691e-01,   6.99368536e-01,
                         -5.19015729e-01,  -6.11318350e-01,   6.38180792e-01,
                          2.51711309e-01,  -7.10180283e-01,   5.05765453e-02,
                          5.39951146e-01,  -2.85839111e-01,  -3.47992331e-01,
                          1.98318228e-01,   6.17342405e-02,  -2.82757115e-02,
                         -1.39331296e-01,  -2.02088758e-01,   3.93973291e-01,
                          8.61464888e-02,  -7.31245458e-01,   1.96872145e-01,
                          7.41081715e-01,  -6.98694348e-01,  -5.02515554e-01,
                          8.84989500e-01,   9.38019156e-02,  -9.26898122e-01,
                          1.62492231e-01,   6.89819574e-01,  -3.94831419e-01,
                         -4.94110703e-01,   3.19493026e-01,   2.02876270e-01,
                         -1.61670640e-01,  -1.27018675e-01,  -1.76974133e-01,
                          8.02868903e-02,   4.05704051e-01,  -2.77457714e-01,
                         -5.65863550e-01,   4.72844273e-01,   5.63850343e-01,
                         -6.86729610e-01,  -3.56770098e-01,   7.35022485e-01,
                         -2.31875982e-02,  -7.35135794e-01,   3.23147386e-01,
                          4.93471920e-01,  -4.88204658e-01,  -2.93970615e-01,
                          3.46298575e-01,   1.74273066e-02,  -1.72681928e-01,
                         -6.59518540e-02,  -5.08528911e-02,   2.73819983e-01,
                         -5.69752865e-02,  -5.71139395e-01,   3.91368359e-01,
                          4.90113467e-01,  -7.91491866e-01,  -2.00347096e-01,
                          9.22741830e-01,  -2.21146822e-01,  -8.85425627e-01,
                          4.98297185e-01,   6.04035676e-01,  -6.94831073e-01,
                         -3.19493294e-01,   5.54725707e-01,   1.02102727e-01,
                         -3.63047421e-01,  -8.14230964e-02,   2.72552613e-02,
                          1.40829816e-01,   1.80832520e-01,  -3.98486078e-01,
                         -3.13478798e-01,   6.06724441e-01,   2.35178426e-01,
                         -7.91012883e-01,  -5.64064719e-02,   7.46928513e-01,
                         -3.09321433e-01,  -6.79878354e-01,   5.19921720e-01,
                          4.09266025e-01,  -6.22116446e-01,  -1.07600078e-01,
                          4.75715399e-01,  -1.43520668e-01,  -2.77426034e-01,
                          5.89455888e-02,   4.97762598e-02,   1.44782424e-01,
                         -1.38517812e-01,  -3.56568336e-01,   4.54126060e-01,
                          2.70126581e-01,  -8.10681105e-01,   2.81314384e-02,
                          8.86798084e-01,  -5.25808692e-01,  -6.94707751e-01,
                          7.87228584e-01,   3.12568873e-01,  -8.66343498e-01,
                         -6.02572784e-02,   7.00663269e-01,  -1.34353146e-01,
                         -4.69671398e-01,   1.16735771e-01,   1.76692843e-01,
                          3.93862538e-02,  -9.63347126e-03,  -3.35539550e-01,
                         -7.92659223e-02,   5.69894910e-01,  -5.97749986e-02,
                         -7.38018751e-01,   2.71240920e-01,   6.63996458e-01,
                         -5.59168041e-01,  -5.13353229e-01,   7.23480225e-01,
                          1.88904822e-01,  -7.11701810e-01,   1.10571414e-01,
                          5.04719317e-01,  -3.15196127e-01,  -2.75840133e-01,
                          2.20192477e-01,   6.55218959e-02,  -1.44046126e-02,
                         -1.26258984e-01,  -1.71188578e-01,   3.94849539e-01,
                          7.07082674e-02,  -7.12334096e-01,   2.57465541e-01,
                          7.12897956e-01,  -7.35053837e-01,  -4.25311595e-01,
                          9.44689989e-01,  -9.17049497e-03,  -9.02019918e-01,
                          2.62597948e-01,   7.03506470e-01,  -4.07503814e-01,
                         -4.26712841e-01,   3.66934836e-01,   1.82970077e-01,
                         -1.61077306e-01,  -1.02100015e-01,  -1.45085156e-01,
                          1.26221225e-01,   4.08782721e-01,  -2.98904687e-01,
                         -5.42860210e-01,   5.20865858e-01,   4.92139310e-01,
                         -6.95989013e-01,  -2.76832491e-01,   7.67066538e-01,
                         -8.57331604e-02,  -7.45088160e-01,   3.54821026e-01,
                          5.27079463e-01,  -4.67161298e-01,  -1.94758534e-01,
                          3.62674743e-01,  -2.41614338e-02,  -1.53289661e-01,
                         -4.10160311e-02,  -1.10807493e-02,   3.01383764e-01,
                         -7.66385347e-02,  -5.11143565e-01,   4.55233127e-01,
                          4.62407559e-01,  -8.20635200e-01,  -1.32297203e-01,
                          9.39901114e-01,  -2.56785631e-01,  -8.08714509e-01,
                          5.73644042e-01,   5.18286645e-01,  -6.69896662e-01,
                         -2.21527085e-01,   5.82311630e-01,   9.49517861e-02,
                         -3.41389269e-01,  -2.85547432e-02,   6.07164800e-02,
                          1.69865862e-01,   1.72675535e-01,  -3.96430999e-01,
                         -2.54138708e-01,   6.57571495e-01,   2.23851770e-01,
                         -7.59642899e-01,   5.02344891e-02,   7.90979862e-01,
                         -3.65204930e-01,  -6.10856056e-01,   6.09411359e-01,
                          4.32958484e-01,  -5.60300767e-01,  -1.53986020e-02,
                          5.08284807e-01,  -1.17648683e-01,  -2.17038736e-01,
                          1.29656225e-01,   9.04394239e-02,   1.70574605e-01,
                         -1.26277521e-01,  -2.83473730e-01,   5.43638229e-01,
                          2.41170868e-01,  -7.66215742e-01,   1.66870862e-01,
                          8.85320365e-01,  -5.26802182e-01,  -6.08450055e-01,
                          8.92524719e-01,   3.07452530e-01,  -8.05825591e-01,
                          2.85104457e-02,   7.49729037e-01,  -1.49211630e-01,
                         -4.12395537e-01,   1.89775869e-01,   2.34547958e-01,
                          8.46985728e-02,  -1.93038920e-03,  -2.86630243e-01,
                          3.65789682e-02,   6.10188782e-01,  -7.44386539e-02,
                         -6.44813418e-01,   3.92922699e-01,   6.86558425e-01,
                         -5.53174317e-01,  -4.37122017e-01,   7.70069599e-01,
                          1.81793615e-01,  -6.82629645e-01,   2.31829062e-01,
                          5.74182630e-01,  -2.67358243e-01,  -2.17009157e-01,
                          2.79826880e-01,   8.62316489e-02,   1.82886850e-02,
                         -9.38491076e-02,  -8.37515444e-02,   4.71369594e-01,
                          8.63815099e-02,  -6.57594979e-01,   4.00461018e-01,
                          7.05676556e-01,  -7.32666671e-01,  -2.75312364e-01,
                          9.88617241e-01,   1.57915067e-03,  -8.54296386e-01,
                          3.67877543e-01,   7.21820951e-01,  -4.41608161e-01,
                         -3.43485534e-01,   4.45732296e-01,   2.20671505e-01,
                         -1.20121785e-01,  -6.86695278e-02,  -1.02064192e-01,
                          2.04087883e-01,   4.36268568e-01,  -3.07243139e-01,
                         -4.33045417e-01,   6.12388432e-01,   4.57455158e-01,
                         -7.37961411e-01,  -1.60768613e-01,   8.47004175e-01,
                         -9.26603526e-02,  -6.49461508e-01,   4.47427034e-01,
                          5.03472149e-01,  -4.52340484e-01,  -1.16616040e-01,
                          4.09438014e-01,  -7.61959748e-03,  -1.17446184e-01,
                          7.22642941e-03,   4.33987044e-02,   3.39737475e-01,
                         -8.78532007e-02,  -4.72452670e-01,   5.29186428e-01,
                          4.51133698e-01,  -8.25155258e-01,   2.35079825e-02,
                          9.59754109e-01,  -3.22451979e-01,  -7.76253402e-01,
                          7.15937853e-01,   5.00724494e-01,  -6.84694409e-01,
                         -1.66475073e-01,   6.23983622e-01,   8.01042020e-02,
                         -3.25880229e-01,   3.50062153e-03,   9.49961990e-02,
                          2.06211150e-01,   1.78441405e-01,  -3.75539690e-01,
                         -1.96578488e-01,   6.55387759e-01,   1.27031535e-01,
                         -7.62621880e-01,   1.41341850e-01,   7.55137265e-01,
                         -4.12954539e-01,  -6.44062042e-01,   6.16148829e-01,
                          3.26058239e-01,  -6.05215013e-01,   4.06645276e-02,
                          4.76430744e-01,  -2.09282279e-01,  -2.40385234e-01,
                          1.14866763e-01,   7.61702731e-02,   1.32117808e-01,
                         -1.66768163e-01,  -2.88941890e-01,   5.07774889e-01,
                          1.31790549e-01,  -7.84936249e-01,   1.83751687e-01,
                          7.99593687e-01,  -6.07360005e-01,  -5.32523036e-01,
                          8.43969047e-01,   1.67343214e-01,  -8.69991422e-01,
                          7.88201988e-02,   6.92637742e-01,  -2.32297748e-01,
                         -4.41133380e-01,   1.61732852e-01,   1.74672946e-01,
                          2.45245453e-02,  -5.37539087e-02,  -3.30269188e-01,
                          1.54885864e-02,   5.36077321e-01,  -1.80787146e-01,
                         -6.79512858e-01,   4.12307888e-01,   5.82918942e-01,
                         -6.79056406e-01,  -4.20073718e-01,   7.39622712e-01,
                          6.30783513e-02,  -6.87326431e-01,   2.32214198e-01,
                          4.57548261e-01,  -3.90265167e-01,  -2.40838885e-01,
                          2.48088464e-01,   2.84441188e-02,  -5.09474427e-02,
                         -1.56521916e-01,  -1.21919163e-01,   4.08396184e-01,
                         -4.38616127e-02,  -6.88658476e-01,   3.84229690e-01,
                          5.41424155e-01,  -8.38058710e-01,  -2.84921557e-01,
                          9.33011830e-01,  -1.01264507e-01,  -9.31123614e-01,
                          3.98478448e-01,   6.03649974e-01,  -5.56513190e-01,
                         -3.60902458e-01,   3.95051122e-01,   1.36321560e-01,
                         -2.06808046e-01,  -1.26419738e-01,  -1.45927280e-01,
                          1.55262858e-01,   3.18253249e-01,  -4.02220786e-01,
                         -4.66973484e-01,   5.66808999e-01,   3.56240958e-01,
                         -7.87795424e-01,  -1.48326918e-01,   7.87795961e-01,
                         -2.40842000e-01,  -7.32289374e-01,   3.93942863e-01,
                          4.14811909e-01,  -5.43591022e-01,  -1.27559677e-01,
                          3.71363372e-01,  -9.17323530e-02,  -1.89106837e-01,
                         -6.08065538e-02,  -9.41059273e-03,   2.59784847e-01,
                         -1.84491202e-01,  -5.16192555e-01,   5.05527616e-01,
                          3.01984578e-01,  -8.81180346e-01,  -7.55122676e-03,
                          8.93436432e-01,  -4.31796104e-01,  -7.90286064e-01,
                          6.84408605e-01,   3.93992811e-01,  -7.98088729e-01,
                         -1.56106085e-01,   5.69006801e-01,  -3.17100696e-02,
                         -3.84601414e-01,  -4.48680706e-02,   4.82017957e-02,
                          1.41763687e-01,   8.05728287e-02,  -4.46917146e-01,
                         -2.01800346e-01,   6.34573877e-01,   4.10300083e-02,
                         -8.10361028e-01,   1.52374372e-01,   7.07241118e-01,
                         -4.92203683e-01,  -6.01383686e-01,   5.91436982e-01,
                          2.37561911e-01,  -6.57054186e-01,   4.49618809e-02,
                          4.51633394e-01,  -2.47988880e-01,  -2.64304876e-01,
                          8.10477808e-02,   3.64402309e-02,   9.48017240e-02,
                         -2.22081661e-01,  -2.70324886e-01,   5.16092837e-01,
                          6.83536530e-02,  -8.10322881e-01,   2.45865047e-01,
                          7.67239273e-01,  -7.42358506e-01,  -4.97631609e-01,
                          8.63452613e-01,   1.09080568e-01,  -8.79146695e-01,
                          9.65219587e-02,   6.31302893e-01,  -2.88348377e-01,
                         -4.40354079e-01,   1.68688238e-01,   1.49856672e-01,
                         -3.73874535e-03,  -7.96735287e-02,  -3.34097952e-01,
                          5.35552725e-02,   5.27090549e-01,  -2.52849400e-01,
                         -6.49216354e-01,   4.61525798e-01,   6.07255816e-01,
                         -6.73218429e-01,  -3.66855234e-01,   7.19162881e-01,
                         -1.67852733e-02,  -6.93922877e-01,   2.97802836e-01,
                          4.39111441e-01,  -4.08881932e-01,  -2.32859150e-01,
                          2.41834223e-01,   1.88726615e-02,  -4.96290699e-02,
                         -1.58134297e-01,  -8.96066204e-02,   4.14852142e-01,
                         -1.02078229e-01,  -6.53405905e-01,   4.78444189e-01,
                          5.05887210e-01,  -8.29859734e-01,  -1.88406706e-01,
                          9.31065321e-01,  -2.05219626e-01,  -8.66407037e-01,
                          4.56448227e-01,   5.91009140e-01,  -5.90358078e-01,
                         -3.22815388e-01,   4.21228111e-01,   1.32957011e-01,
                         -1.91633999e-01,  -1.26279891e-01,  -1.22102872e-01,
                          1.90328464e-01,   3.22174966e-01,  -4.28736478e-01,
                         -4.09218043e-01,   6.40000999e-01,   2.99052209e-01,
                         -7.95912683e-01,  -7.36360401e-02,   7.49084592e-01,
                         -2.91180104e-01,  -6.45030677e-01,   4.91125643e-01,
                          3.83954257e-01,  -5.44986725e-01,  -8.64919871e-02,
                          3.81583124e-01,  -1.00317374e-01,  -1.72250316e-01,
                         -3.78198363e-02,   2.11849306e-02,   2.81489164e-01,
                         -1.83067918e-01,  -4.29249972e-01,   5.60299456e-01,
                          2.75591940e-01,  -8.66819203e-01,   5.38066402e-02,
                          9.25074518e-01,  -5.23361325e-01,  -6.96382046e-01,
                          7.63200045e-01,   3.32993686e-01,  -7.80203521e-01,
                         -9.81533006e-02,   6.10648036e-01,  -3.87407802e-02,
                         -3.61826569e-01,   1.53122831e-03,   8.07420313e-02,
                          1.71763018e-01,   8.75596032e-02,  -4.35954362e-01,
                         -1.50359988e-01,   6.59528553e-01,   2.55867443e-03,
                         -7.82761991e-01,   2.57998884e-01,   6.84473157e-01,
                         -5.38241208e-01,  -5.10131478e-01,   7.07334757e-01,
                          1.96078613e-01,  -6.61516368e-01,   1.07291423e-01,
                          4.32984471e-01,  -2.40961313e-01,  -2.01820940e-01,
                          1.22030795e-01,   6.25075996e-02,   1.12457767e-01,
                         -2.08471239e-01,  -2.31445327e-01,   5.40521622e-01,
                          5.49694300e-02,  -7.94421434e-01,   3.14349413e-01,
                          7.51689970e-01,  -7.60220289e-01,  -4.31760192e-01,
                          9.47466314e-01,   1.87035352e-02,  -8.57711613e-01,
                          2.09977537e-01,   6.68269038e-01,  -3.05941939e-01,
                         -3.75872284e-01,   2.23918870e-01,   1.59512714e-01,
                          1.02937147e-02,  -7.32647106e-02,  -3.11240733e-01,
                          1.14662856e-01,   5.45787990e-01,  -2.76092440e-01,
                         -6.14046454e-01,   5.07695138e-01,   5.44208288e-01,
                         -6.90010428e-01,  -2.87271678e-01,   7.63096154e-01,
                         -7.62897283e-02,  -6.99396551e-01,   3.39281142e-01,
                          4.72328961e-01,  -3.95100355e-01,  -1.48827985e-01,
                          2.60743529e-01,   1.37804374e-02,  -4.45095338e-02,
                         -1.45195633e-01,  -5.95355891e-02,   4.39262390e-01,
                         -1.08182825e-01,  -5.97495437e-01,   5.41698873e-01,
                          4.79668796e-01,  -8.66800070e-01,  -1.20152451e-01,
                          9.47691858e-01,  -2.31329948e-01,  -7.86918521e-01,
                          5.24402678e-01,   5.20360649e-01,  -5.73670268e-01,
                         -2.34777465e-01,   4.65947866e-01,   1.31196231e-01,
                         -1.85990259e-01,  -9.20366496e-02,  -8.83482695e-02,
                          2.27951974e-01,   3.08548719e-01,  -4.35367078e-01,
                         -3.57573479e-01,   6.97423637e-01,   2.90696621e-01,
                         -7.66189635e-01,   2.77920756e-02,   7.83049166e-01,
                         -3.50351632e-01,  -5.87208450e-01,   5.90974450e-01,
                          3.94147456e-01,  -5.08892536e-01,   1.73539959e-03,
                          4.20296729e-01,  -7.99070969e-02,  -1.24440014e-01,
                          2.29033336e-04,   6.94547966e-02,   3.10887367e-01,
                         -1.96522981e-01,  -3.66633654e-01,   6.55837357e-01,
                          2.35033154e-01,  -8.28203678e-01,   1.88428894e-01,
                          9.07198250e-01,  -5.32980144e-01,  -6.20535135e-01,
                          8.54181349e-01,   3.24475944e-01,  -7.42319822e-01,
                         -1.83315966e-02,   6.57833576e-01,  -6.60252571e-02,
                         -3.11428457e-01,   6.66023493e-02,   1.28601685e-01,
                          2.12573066e-01,   9.54155698e-02,  -4.16187882e-01,
                         -4.68989611e-02,   7.05429912e-01,  -2.14549117e-02,
                         -6.95853591e-01,   3.61917913e-01,   7.09132195e-01,
                         -5.43546736e-01,  -4.42297697e-01,   7.37809420e-01,
                          1.60196140e-01,  -6.27096653e-01,   2.16209903e-01,
                          4.94464964e-01,  -2.13036209e-01,  -1.54877797e-01,
                          1.60561055e-01,   9.10299346e-02,   1.36464521e-01,
                         -1.91555575e-01,  -1.42812625e-01,   5.90128720e-01,
                          6.56511933e-02,  -7.58404255e-01,   4.62083548e-01,
                          7.23116696e-01,  -7.65915990e-01,  -2.78187066e-01,
                          9.76882577e-01,   2.02016104e-02,  -8.21403623e-01,
                          3.05731505e-01,   6.73697948e-01,  -3.35405648e-01,
                         -3.17805111e-01,   3.04803967e-01,   1.90786242e-01,
                          3.89251113e-02,  -4.90658879e-02,  -2.61473536e-01,
                          1.83558345e-01,   5.69503307e-01,  -2.97618896e-01,
                         -5.23383379e-01,   6.03910804e-01,   5.11353612e-01,
                         -7.38001227e-01,  -1.81866542e-01,   8.27299953e-01,
                         -9.00722891e-02,  -6.10781610e-01,   4.22910035e-01,
                          4.48582858e-01,  -3.87775838e-01,  -9.55202058e-02,
                          3.06009561e-01,   3.27556245e-02,  -1.59059893e-02,
                         -1.07798398e-01,   1.30847131e-03,   4.78803098e-01,
                         -1.43846259e-01,  -5.65525413e-01,   6.21024966e-01,
                          4.57421482e-01,  -8.86162579e-01,   3.17749381e-02,
                          9.63820159e-01,  -3.08865339e-01,  -7.65707076e-01,
                          6.54841423e-01,   4.97035950e-01,  -5.90435266e-01,
                         -1.83813646e-01,   4.93985981e-01,   1.20739371e-01,
                         -1.79386243e-01,  -6.90767318e-02,  -5.40258326e-02,
                          2.70758420e-01,   3.09342027e-01,  -4.40969706e-01,
                         -3.05134416e-01,   7.08311498e-01,   1.76033661e-01,
                         -7.95966208e-01,   1.12020671e-01,   7.51409531e-01,
                         -4.09868628e-01,  -6.19831800e-01,   5.75012445e-01,
                          2.88978010e-01,  -5.38642704e-01,   3.27776521e-02,
                          3.76945376e-01,  -1.40785679e-01,  -1.57759711e-01,
                         -1.52408956e-02,   5.44908009e-02,   2.68780857e-01,
                         -2.58440465e-01,  -3.65650296e-01,   6.24369621e-01,
                          1.13795362e-01,  -8.60822380e-01,   2.13135093e-01,
                          8.12146068e-01,  -6.19652390e-01,  -5.36763310e-01,
                          8.03636670e-01,   1.81190208e-01,  -7.97285080e-01,
                          1.99493859e-02,   5.94111145e-01,  -1.43243253e-01,
                         -3.51523995e-01,   2.37972774e-02,   7.78086931e-02,
                          1.58452049e-01,   2.74550803e-02,  -4.80573148e-01,
                         -5.54669648e-02,   6.37012541e-01,  -1.46303579e-01,
                         -7.43591845e-01,   3.94284070e-01,   6.04889870e-01,
                         -6.72038674e-01,  -4.20139939e-01,   6.98528767e-01,
                          5.15273996e-02,  -6.28723085e-01,   1.97812647e-01,
                          3.76188040e-01,  -3.13702077e-01,  -1.84289739e-01,
                          1.08910620e-01,   4.56475951e-02,   7.67231733e-02,
                         -2.67520577e-01,  -1.85025170e-01,   5.43510854e-01,
                         -7.95160607e-02,  -7.77322710e-01,   4.44677234e-01,
                          5.51399648e-01,  -8.77414703e-01,  -2.85329074e-01,
                          9.10983443e-01,  -9.13657919e-02,  -8.97194147e-01,
                          3.25970054e-01,   5.59144497e-01,  -4.54498917e-01,
                         -3.42835784e-01,   2.38477916e-01,   1.17180005e-01,
                         -4.14847657e-02,  -1.28682002e-01,  -3.09956133e-01,
                          1.55041829e-01,   4.42999661e-01,  -4.10142154e-01,
                         -5.62470913e-01,   5.75196624e-01,   4.02572125e-01,
                         -7.95480549e-01,  -1.70953527e-01,   7.59733081e-01,
                         -2.39118621e-01,  -6.87154174e-01,   3.63828331e-01,
                          3.46189857e-01,  -4.69952971e-01,  -1.01247139e-01,
                          2.47371539e-01,  -5.36106266e-02,  -8.29655826e-02,
                         -1.86943769e-01,  -5.58233671e-02,   3.89430821e-01,
                         -2.46715099e-01,  -6.02000296e-01,   5.93048632e-01,
                          2.98827380e-01,  -9.39381063e-01,   1.32672302e-03,
                          8.90085042e-01,  -4.28309321e-01,  -7.74991751e-01,
                          6.23491108e-01,   3.85364801e-01,  -7.12377071e-01,
                         -1.85957536e-01,   4.49988931e-01,   1.62202269e-02,
                         -2.50592977e-01,  -1.24642357e-01,  -1.02061987e-01,
                          2.29485914e-01,   1.98202327e-01,  -5.25264442e-01,
                         -3.05560172e-01,   6.90232754e-01,   9.24520791e-02,
                         -8.33278120e-01,   1.32442132e-01,   6.96947694e-01,
                         -4.85441566e-01,  -5.82295001e-01,   5.54481208e-01,
                          1.90918818e-01,  -5.79769433e-01,   4.74901050e-02,
                          3.41123551e-01,  -1.90498605e-01,  -1.83486477e-01,
                         -4.86622714e-02,   2.33238637e-02,   2.19770700e-01,
                         -3.07565778e-01,  -3.38013440e-01,   6.28166616e-01,
                          4.50033173e-02,  -8.90921772e-01,   2.76171952e-01,
                          7.78016388e-01,  -7.51837313e-01,  -5.07300377e-01,
                          8.22670043e-01,   1.30848244e-01,  -8.21029365e-01,
                          3.75389755e-02,   5.43676078e-01,  -1.93320945e-01,
                         -3.55290532e-01,   3.21813859e-02,   7.71248341e-02,
                          1.39286578e-01,  -9.14718211e-03,  -4.72053915e-01,
                          9.62294362e-05,   6.24122918e-01,  -2.20078707e-01,
                         -7.03208983e-01,   4.44204539e-01,   6.29207253e-01,
                         -6.65728331e-01,  -3.70401561e-01,   7.01163352e-01,
                         -2.80354824e-02,  -6.26902938e-01,   2.79162616e-01,
                          3.65189314e-01,  -3.34342867e-01,  -1.64537042e-01,
                          1.22247927e-01,   5.44120967e-02,   7.43368119e-02,
                         -2.65826821e-01,  -1.39054984e-01,   5.60579300e-01,
                         -1.39043137e-01,  -7.22217441e-01,   5.49578130e-01,
                          5.17339706e-01,  -8.53621125e-01,  -1.80323601e-01,
                          9.22607183e-01,  -1.77942634e-01,  -8.28334332e-01,
                          3.88910294e-01,   5.60624599e-01,  -4.64334488e-01,
                         -2.98396409e-01,   2.83581048e-01,   1.35600194e-01,
                         -2.31037904e-02,  -1.16226226e-01,  -2.80190378e-01,
                          2.06926465e-01,   4.57343698e-01,  -4.47173893e-01,
                         -4.87693250e-01,   6.64337635e-01,   3.47456932e-01,
                         -7.98419654e-01,  -7.73168877e-02,   7.38466561e-01,
                         -2.74377078e-01,  -6.01635277e-01,   4.72278744e-01,
                          3.32129568e-01,  -4.65985447e-01,  -5.59022650e-02,
                          2.72703439e-01,  -3.78483944e-02,  -6.46715686e-02,
                         -1.54900029e-01,  -3.65625275e-03,   4.24712181e-01,
                         -2.41302341e-01,  -4.93983120e-01,   6.66407466e-01,
                          2.85572857e-01,  -9.11709011e-01,   7.99388513e-02,
                          9.40513253e-01,  -5.02684236e-01,  -6.78886473e-01,
                          7.10764945e-01,   3.47947091e-01,  -6.79135859e-01,
                         -1.20872602e-01,   4.99401987e-01,   2.82358676e-02,
                         -2.16055751e-01,  -7.60351717e-02,  -4.78984676e-02,
                          2.72000223e-01,   2.12320685e-01,  -5.07337391e-01,
                         -2.31729642e-01,   7.16848910e-01,   5.41108251e-02,
                         -8.16218972e-01,   2.56020248e-01,   6.98260128e-01,
                         -5.27577698e-01,  -4.83664125e-01,   6.73773527e-01,
                          1.79538429e-01,  -5.83566964e-01,   9.92236435e-02,
                          3.56050193e-01,  -1.64159521e-01,  -1.21103592e-01,
                          4.14652098e-03,   7.74409994e-02,   2.43463337e-01,
                         -2.96579510e-01,  -2.85764337e-01,   6.66709483e-01,
                          4.41110842e-02,  -8.56354833e-01,   3.68790090e-01,
                          7.61106193e-01,  -7.63289094e-01,  -4.08749282e-01,
                          9.12494719e-01,   5.30837849e-02,  -7.88991034e-01,
                          1.49854988e-01,   5.96628010e-01,  -1.94893360e-01,
                         -3.06022465e-01,   9.28446278e-02,   1.07052349e-01,
                          1.65266648e-01,  -1.71789993e-02,  -4.45136756e-01,
                          6.55253902e-02,   6.55749619e-01,  -2.50845104e-01,
                         -6.71041369e-01,   5.09600997e-01,   5.67195058e-01,
                         -6.76106930e-01,  -2.80747235e-01,   7.32520640e-01,
                         -7.30668604e-02,  -6.28579140e-01,   3.05915117e-01,
                          4.08102691e-01,  -3.18534821e-01,  -1.16144776e-01,
                          1.48581237e-01,   5.50438240e-02,   7.62561709e-02,
                         -2.68065184e-01,  -8.62661377e-02,   5.77908516e-01,
                         -1.54108316e-01,  -6.51549697e-01,   6.17922544e-01,
                          4.75427955e-01,  -8.93724561e-01,  -1.04593806e-01,
                          9.34426904e-01,  -2.00058624e-01,  -7.54156947e-01,
                          4.58016276e-01,   5.02337039e-01,  -4.62729335e-01,
                         -2.31290251e-01,   3.20459247e-01,   1.43668339e-01,
                         -2.09764782e-02,  -1.12452082e-01,  -2.43024364e-01,
                          2.62805074e-01,   4.28922504e-01,  -4.76028174e-01,
                         -4.40476805e-01,   7.27891803e-01,   3.27062070e-01,
                         -7.63441682e-01,   2.92286538e-02,   7.73788154e-01,
                         -3.45208526e-01,  -5.48745632e-01,   5.51040590e-01,
                          3.48920852e-01,  -4.35178846e-01,   4.49565379e-03,
                          3.10010374e-01,  -1.98057815e-02,  -3.59796844e-02,
                         -1.29180074e-01,   6.11081496e-02,   4.43002284e-01,
                         -2.81728387e-01,  -4.23680127e-01,   7.51123905e-01,
                          2.08964661e-01,  -8.79650891e-01,   2.09663913e-01,
                          9.07379031e-01,  -5.26010156e-01,  -6.10001028e-01,
                          7.89188564e-01,   3.29761684e-01,  -6.52385950e-01,
                         -6.13315739e-02,   5.35728455e-01,   2.20183283e-02,
                         -1.86805308e-01,  -4.57125157e-02,   2.81523238e-03,
                          3.23497266e-01,   2.07853153e-01,  -5.13078928e-01,
                         -1.33835852e-01,   7.57581770e-01,   1.56732798e-02,
                         -7.30008185e-01,   3.46983343e-01,   7.03307390e-01,
                         -5.23097754e-01,  -4.20708895e-01,   6.92376196e-01,
                          1.32122964e-01,  -5.53586245e-01,   1.93571389e-01,
                          4.00513381e-01,  -1.30074382e-01,  -9.63433385e-02,
                          1.99912339e-02,   1.15092732e-01,   2.57441789e-01,
                         -3.08973342e-01,  -1.95527554e-01,   7.15412259e-01,
                          3.02277748e-02,  -8.29750121e-01,   5.10120630e-01,
                          7.25407660e-01,  -7.88893580e-01,  -2.83210725e-01,
                          9.42792952e-01,   5.16638979e-02,  -7.66825438e-01,
                          2.23113313e-01,   6.01988673e-01,  -2.21308812e-01,
                         -2.64227062e-01,   1.49588287e-01,   1.44078597e-01,
                          1.97628334e-01,   1.55238551e-03,  -4.05277789e-01,
                          1.43178388e-01,   6.66078746e-01,  -2.88091809e-01,
                         -5.84382117e-01,   6.05557740e-01,   5.30211210e-01,
                         -7.30917871e-01,  -1.75232098e-01,   7.89061248e-01,
                         -9.03785676e-02,  -5.54892063e-01,   3.75431418e-01,
                          3.77772063e-01,  -3.09103042e-01,  -6.73802719e-02,
                          1.79101810e-01,   8.21546987e-02,   9.26222652e-02,
                         -2.37343132e-01,  -3.33112776e-02,   6.13408506e-01,
                         -2.13921741e-01,  -6.45103157e-01,   7.04915822e-01,
                          4.57498938e-01,  -9.28350329e-01,   3.56671773e-02,
                          9.52736616e-01,  -2.83489406e-01,  -7.43384182e-01,
                          5.72331309e-01,   4.89596665e-01,  -4.85550612e-01,
                         -1.93322301e-01,   3.46159071e-01,   1.36135951e-01,
                         -1.11760581e-02,  -1.01377346e-01,  -2.12669760e-01,
                          3.07479292e-01,   4.23642695e-01,  -4.75797385e-01,
                         -3.82969588e-01,   7.19108522e-01,   2.07693785e-01,
                         -7.90659010e-01,   9.44483578e-02,   7.29936421e-01,
                         -3.94409120e-01,  -5.82323015e-01,   5.33995926e-01,
                          2.56214231e-01,  -4.60781038e-01,   2.79700272e-02,
                          2.68619567e-01,  -6.78397641e-02,  -7.64582306e-02,
                         -1.49367228e-01,   4.70298938e-02,   3.91692311e-01,
                         -3.54477644e-01,  -4.25032347e-01,   7.15559006e-01,
                          9.96007845e-02,  -9.07440662e-01,   2.29129836e-01,
                          8.11916053e-01,  -6.03818357e-01,  -5.43116629e-01,
                          7.46903539e-01,   1.95834368e-01,  -7.18446553e-01,
                         -3.71463820e-02,   4.80860353e-01,  -6.17463067e-02,
                         -2.34336302e-01,  -8.36776271e-02,  -3.35378721e-02,
                          2.70611703e-01,   1.23914607e-01,  -5.74697673e-01,
                         -1.46843597e-01,   6.86981559e-01,  -9.54906866e-02,
                         -7.82325923e-01,   3.68317932e-01,   6.00861371e-01,
                         -6.54275298e-01,  -4.18653071e-01,   6.64596617e-01,
                          3.96025628e-02,  -5.77078640e-01,   1.72262505e-01,
                          2.95087963e-01,  -2.39809215e-01,  -1.35006666e-01,
                         -1.69636216e-02,   7.27320984e-02,   1.81315333e-01,
                         -3.90240788e-01,  -2.27523714e-01,   6.53385520e-01,
                         -1.14779882e-01,  -8.33809555e-01,   4.90812391e-01,
                          5.59353650e-01,  -8.93062830e-01,  -3.00438821e-01,
                          8.81992280e-01,  -5.95615953e-02,  -8.39731872e-01,
                          2.37363204e-01,   4.91801679e-01,  -3.28256518e-01,
                         -3.11252832e-01,   8.61207098e-02,   6.52445480e-02,
                          1.20620921e-01,  -9.65125933e-02,  -4.66220617e-01,
                          1.16496280e-01,   5.54258227e-01,  -4.14418399e-01,
                         -6.37024820e-01,   5.61486244e-01,   4.25304592e-01,
                         -7.87319303e-01,  -1.80463836e-01,   7.30324507e-01,
                         -2.38368511e-01,  -6.46475792e-01,   3.19426596e-01,
                          2.90828198e-01,  -3.96686167e-01,  -9.38585624e-02,
                          1.22100361e-01,  -4.36494534e-04,  -1.91539701e-03,
                         -3.16641778e-01,  -6.42864257e-02,   5.05087018e-01,
                         -3.12640458e-01,  -6.65009081e-01,   6.67496741e-01,
                          2.84680873e-01,  -9.76416588e-01,  -6.72803260e-03,
                          8.85186732e-01,  -4.08088088e-01,  -7.69735515e-01,
                          5.34000039e-01,   3.75685781e-01,  -6.01061702e-01,
                         -2.12881863e-01,   2.97230482e-01,   4.92149591e-02,
                         -1.03086077e-01,  -1.77702785e-01,  -2.42824093e-01,
                          2.71673560e-01,   3.21878284e-01,  -5.85509062e-01,
                         -3.92495513e-01,   7.23121047e-01,   1.31531805e-01,
                         -8.60445440e-01,   1.03194773e-01,   6.86601758e-01,
                         -4.67584878e-01,  -5.54222167e-01,   5.13571799e-01,
                          1.67060599e-01,  -5.24050057e-01,   2.45373920e-02,
                          2.40864545e-01,  -1.18773960e-01,  -1.18240952e-01,
                         -1.82870060e-01,   5.03068976e-02,   3.32211941e-01,
                         -4.10293072e-01,  -3.84241283e-01,   7.32194364e-01,
                          1.19845429e-02,  -9.39383030e-01,   2.99892306e-01,
                          7.90396869e-01,  -7.46676445e-01,  -5.11383593e-01,
                          7.64675140e-01,   1.48656622e-01,  -7.34875977e-01,
                         -2.66871676e-02,   4.34911340e-01,  -1.05200529e-01,
                         -2.51306891e-01,  -7.06240535e-02,  -4.09859829e-02,
                          2.74740487e-01,   9.29940864e-02,  -5.80163658e-01,
                         -6.62376657e-02,   7.14768410e-01,  -1.80059135e-01,
                         -7.39238620e-01,   4.34650600e-01,   6.53623998e-01,
                         -6.33915842e-01,  -3.51194590e-01,   6.61151588e-01,
                         -2.61903498e-02,  -5.78676462e-01,   2.48352200e-01,
                          3.06891978e-01,  -2.48357818e-01,  -1.14671908e-01,
                          1.89080313e-02,   1.09874569e-01,   1.73167139e-01,
                         -3.89578491e-01,  -1.41599298e-01,   6.66265190e-01,
                         -1.88523442e-01,  -7.64262795e-01,   6.11479104e-01,
                          5.36600292e-01,  -8.64121854e-01,  -1.73441961e-01,
                          9.04327571e-01,  -1.41719684e-01,  -7.59267211e-01,
                          3.15400332e-01,   5.19013643e-01,  -3.25608701e-01,
                         -2.58918196e-01,   1.23504303e-01,   1.15123436e-01,
                          1.51386753e-01,  -9.07512382e-02,  -4.21558380e-01,
                          2.06632376e-01,   5.84180593e-01,  -4.42077488e-01,
                         -5.49600482e-01,   6.83131635e-01,   3.87266517e-01,
                         -7.80849636e-01,  -8.55153874e-02,   7.23186016e-01,
                         -2.54075110e-01,  -5.45910597e-01,   4.39392865e-01,
                          2.80960143e-01,  -3.68378997e-01,  -4.47840802e-02,
                          1.71682984e-01,   3.99874598e-02,   3.80974412e-02,
                         -2.82546639e-01,   1.32119283e-02,   5.57347775e-01,
                         -3.20438564e-01,  -5.16403556e-01,   7.67817736e-01,
                          2.75231093e-01,  -9.41955030e-01,   1.02889948e-01,
                          9.29656684e-01,  -4.72581804e-01,  -6.43362045e-01,
                          6.40021443e-01,   3.59627724e-01,  -5.39319515e-01,
                         -1.32823437e-01,   3.57819289e-01,   9.35489014e-02,
                         -4.32700738e-02,  -1.44363597e-01,  -1.84332505e-01,
                          3.46217960e-01,   3.39844823e-01,  -5.56698859e-01,
                         -2.96386421e-01,   7.63964057e-01,   9.48454440e-02,
                         -8.23713481e-01,   2.31330782e-01,   6.95844233e-01,
                         -4.83220756e-01,  -4.52750683e-01,   6.23034656e-01,
                          1.47109851e-01,  -4.93904352e-01,   9.30980220e-02,
                          2.70476937e-01,  -6.96835965e-02,  -5.66523224e-02,
                         -1.35947898e-01,   1.17472515e-01,   3.65640998e-01,
                         -4.08144325e-01,  -3.01414371e-01,   7.76867807e-01,
                          1.02200899e-02,  -8.96613657e-01,   4.20053273e-01,
                          7.58847594e-01,  -7.48704374e-01,  -4.07529980e-01,
                          8.68472636e-01,   8.16077143e-02,  -6.96453631e-01,
                          9.15787667e-02,   4.90319103e-01,  -8.48197639e-02,
                         -2.03490078e-01,  -3.08675803e-02,   1.78178921e-02,
                          3.04077953e-01,   6.96324557e-02,  -5.76271474e-01,
                          1.68141238e-02,   7.43193448e-01,  -2.01473445e-01,
                         -7.10071564e-01,   4.91412103e-01,   5.94158411e-01,
                         -6.50125980e-01,  -2.76171446e-01,   6.95308805e-01,
                         -6.57879040e-02,  -5.64344168e-01,   2.68021792e-01,
                          3.39082599e-01,  -2.12219849e-01,  -8.68248940e-02,
                          2.51072571e-02,   1.28905833e-01,   1.77157491e-01,
                         -3.96708310e-01,  -9.13309008e-02,   6.97699547e-01,
                         -2.14963540e-01,  -6.96363091e-01,   6.95712388e-01,
                          4.88681644e-01,  -9.07264888e-01,  -1.00361794e-01,
                          9.13459837e-01,  -1.71054840e-01,  -7.07775056e-01,
                          3.79693598e-01,   4.59098905e-01,  -3.36767465e-01,
                         -1.99778333e-01,   1.65389821e-01,   1.24940895e-01,
                          1.51171491e-01,  -1.12208679e-01,  -3.75989079e-01,
                          2.66687185e-01,   5.39048314e-01,  -4.71243709e-01,
                         -5.08942544e-01,   7.20981777e-01,   3.79119188e-01,
                         -7.61917412e-01,  -4.52437252e-03,   7.51673460e-01,
                         -3.21340233e-01,  -5.10734439e-01,   5.01385212e-01,
                          2.94519007e-01,  -3.52461278e-01,  -2.77546910e-03,
                          1.97690114e-01,   7.03635812e-02,   3.59405912e-02,
                         -2.65188307e-01,   7.24061280e-02,   5.58433354e-01,
                         -3.74763280e-01,  -4.57934231e-01,   8.31571698e-01,
                          1.89160824e-01,  -9.05698895e-01,   2.31426269e-01,
                          9.02767658e-01,  -5.02333343e-01,  -5.88537753e-01,
                          7.18675017e-01,   3.38052452e-01,  -5.48686504e-01,
                         -9.80302766e-02,   3.90486330e-01,   9.01463181e-02,
                         -4.05648276e-02,  -1.37104779e-01,  -1.48201585e-01,
                          4.02778804e-01,   3.08221251e-01,  -5.71140528e-01,
                         -2.09308028e-01,   7.90638208e-01,   4.83798906e-02,
                         -7.41796315e-01,   3.22687894e-01,   6.94234729e-01,
                         -4.99227285e-01,  -4.07740742e-01,   6.37555659e-01,
                          1.14722475e-01,  -4.73562747e-01,   1.66078463e-01,
                          3.05009097e-01,  -5.48639968e-02,  -3.82010899e-02,
                         -1.13619581e-01,   1.62114978e-01,   3.57108593e-01,
                         -4.20844376e-01,  -2.08874032e-01,   8.00486863e-01,
                         -1.10053429e-02,  -8.60683322e-01,   5.45664966e-01,
                          7.13858247e-01,  -7.80322671e-01,  -2.84881115e-01,
                          8.99821639e-01,   6.91268519e-02,  -6.90201163e-01,
                          1.52929783e-01,   4.99386013e-01,  -9.99655798e-02,
                         -1.72040373e-01,  -1.79677233e-02,   7.38422945e-02,
                          3.48777741e-01,   6.79239184e-02,  -5.39914966e-01,
                          9.16367397e-02,   7.51060247e-01,  -2.68319309e-01,
                         -6.26505971e-01,   5.82593739e-01,   5.43263912e-01,
                         -7.22337604e-01,  -1.86773777e-01,   7.59759188e-01,
                         -9.65015441e-02,  -4.94938195e-01,   3.42793941e-01,
                          3.10874492e-01,  -2.24651083e-01,  -3.61372791e-02,
                          5.86417168e-02,   1.47161573e-01,   1.77410215e-01,
                         -3.64956081e-01,  -4.23377007e-02,   7.13059008e-01,
                         -2.87949026e-01,  -6.79308891e-01,   7.46476591e-01,
                          4.52605218e-01,  -9.31254327e-01,   2.98911240e-02,
                          9.26747620e-01,  -2.41725639e-01,  -7.05523014e-01,
                          4.76405740e-01,   4.52230036e-01,  -3.46664548e-01,
                         -1.81506634e-01,   1.78385541e-01,   1.41688228e-01,
                          1.56785041e-01,  -1.21792138e-01,  -3.66209060e-01,
                          3.19592237e-01,   5.41553020e-01,  -4.86032426e-01,
                         -4.71862406e-01,   7.16698289e-01,   2.41905436e-01,
                         -8.10521662e-01,   6.28436282e-02,   7.07728863e-01,
                         -3.88110846e-01,  -5.47751844e-01,   4.89375412e-01,
                          2.12325618e-01,  -3.87049496e-01,   1.17216781e-02,
                          1.56336889e-01,   1.36129931e-02,  -6.50272472e-03,
                         -2.87441880e-01,   6.88253269e-02,   4.86876637e-01,
                         -4.47287798e-01,  -4.54462647e-01,   8.06952596e-01,
                          6.45570606e-02,  -9.37939703e-01,   2.35120520e-01,
                          7.98101962e-01,  -5.84807932e-01,  -5.18453479e-01,
                          6.58928752e-01,   2.07000300e-01,  -6.07498348e-01,
                         -8.98639783e-02,   3.48415256e-01,   1.68833565e-02,
                         -1.00945286e-01,  -1.81428373e-01,  -1.58093959e-01,
                          3.49382818e-01,   2.33643442e-01,  -6.59319937e-01,
                         -2.30670646e-01,   7.26371527e-01,  -6.34974837e-02,
                         -7.97428966e-01,   3.48662466e-01,   5.95455825e-01,
                         -6.41958952e-01,  -4.01975423e-01,   6.12530947e-01,
                          1.38874175e-02,  -4.95989859e-01,   1.33564129e-01,
                          2.02170566e-01,  -1.40142918e-01,  -9.53925028e-02,
                         -1.63962558e-01,   1.14094153e-01,   2.81438440e-01,
                         -5.22736728e-01,  -2.39725515e-01,   7.57135034e-01,
                         -1.63807407e-01,  -8.84012938e-01,   5.16130686e-01,
                          5.48976660e-01,  -8.88326168e-01,  -3.04112881e-01,
                          8.25822711e-01,  -2.99270004e-02,  -7.63060391e-01,
                          1.57822371e-01,   4.14191127e-01,  -2.25698516e-01,
                         -2.31075257e-01,  -5.15773781e-02,   9.48304310e-04,
                          2.58127213e-01,  -3.83463763e-02,  -5.88732004e-01,
                          6.97047636e-02,   6.31465912e-01,  -3.73611897e-01,
                         -6.88741148e-01,   5.42975724e-01,   4.32340324e-01,
                         -7.62411892e-01,  -1.69524506e-01,   6.81640804e-01,
                         -2.49740869e-01,  -5.89624345e-01,   2.73991764e-01,
                          2.20760569e-01,  -2.90992707e-01,  -8.30415040e-02,
                          1.51607418e-03,   7.95568824e-02,   6.96609765e-02,
                         -4.61884886e-01,  -6.13108948e-02,   6.21006548e-01,
                         -3.93787622e-01,  -7.10295439e-01,   7.46334732e-01,
                          2.75517493e-01,  -9.99975801e-01,  -1.76169109e-02,
                          8.59420478e-01,  -3.66131723e-01,  -7.22526312e-01,
                          4.49080676e-01,   3.41529548e-01,  -4.70820069e-01,
                         -2.14300737e-01,   1.37496367e-01,   6.12388290e-02,
                          5.61314113e-02,  -1.93579048e-01,  -3.93264204e-01,
                          3.02518576e-01,   4.34369087e-01,  -5.93113601e-01,
                         -4.66548234e-01,   7.32901573e-01,   1.65565550e-01,
                         -8.45698774e-01,   9.80553254e-02,   6.53837502e-01,
                         -4.52674627e-01,  -5.01829088e-01,   4.65840876e-01,
                          1.26907170e-01,  -4.19367433e-01,   1.02508441e-02,
                          1.40240252e-01,  -1.87064614e-02,  -4.64936681e-02,
                         -3.20499659e-01,   8.90868157e-02,   4.44396198e-01,
                         -5.32438219e-01,  -4.10932362e-01,   8.21125269e-01,
                         -9.98012442e-03,  -9.78729129e-01,   3.15516263e-01,
                          7.83537090e-01,  -7.04681754e-01,  -5.07576525e-01,
                          7.06035495e-01,   1.65079787e-01,  -6.19616747e-01,
                         -6.65621385e-02,   3.11546087e-01,  -1.65012628e-02,
                         -1.18763775e-01,  -1.94074422e-01,  -1.50603250e-01,
                          3.65766287e-01,   1.96045980e-01,  -6.49188280e-01,
                         -1.29610583e-01,   7.62982190e-01,  -1.47976488e-01,
                         -7.68732488e-01,   4.24694031e-01,   6.44099116e-01,
                         -6.24298096e-01,  -3.15637350e-01,   6.15943134e-01,
                         -4.04086784e-02,  -4.79286671e-01,   1.95939854e-01,
                          2.19377279e-01,  -1.39003888e-01,  -7.31607601e-02,
                         -1.29039094e-01,   1.77263916e-01,   2.84817427e-01,
                         -5.16665041e-01,  -1.44605115e-01,   7.93783724e-01,
                         -2.43713021e-01,  -8.01628709e-01,   6.62210763e-01,
                          5.40289402e-01,  -8.55072618e-01,  -1.85050443e-01,
                          8.56896579e-01,  -8.79926458e-02,  -6.84955657e-01,
                          2.36929908e-01,   4.44145620e-01,  -1.83611855e-01,
                         -1.95836097e-01,  -1.23294946e-02,   6.71287850e-02,
                          3.12837094e-01,  -3.06072664e-02,  -5.40569484e-01,
                          1.79339677e-01,   6.77383959e-01,  -4.29658741e-01,
                         -5.88962674e-01,   6.80414081e-01,   4.16533560e-01,
                         -7.67517865e-01,  -6.45909831e-02,   6.94330275e-01,
                         -2.37379819e-01,  -4.77132350e-01,   3.83066684e-01,
                          2.48880491e-01,  -2.61364251e-01,  -4.46774140e-02,
                          6.00060150e-02,   1.48315102e-01,   1.12809122e-01,
                         -4.04350489e-01,   2.75469162e-02,   6.78205967e-01,
                         -3.84393722e-01,  -5.46201646e-01,   8.42487574e-01,
                          2.81223297e-01,  -9.41939473e-01,   8.38142782e-02,
                          9.21124041e-01,  -4.05646712e-01,  -6.11909509e-01,
                          5.59699893e-01,   3.49914908e-01,  -4.15166020e-01,
                         -1.53603554e-01,   2.13916317e-01,   1.32553682e-01,
                          1.27292290e-01,  -1.74626291e-01,  -3.26544851e-01,
                          3.92063171e-01,   4.64110494e-01,  -5.66456139e-01,
                         -3.72559637e-01,   7.93537021e-01,   1.43742442e-01,
                         -8.06810796e-01,   2.47040987e-01,   6.87553942e-01,
                         -4.58222896e-01,  -3.98667395e-01,   5.82018435e-01,
                          1.43135712e-01,  -3.99396926e-01,   7.60918632e-02,
                          1.82468131e-01,   2.74514351e-02,  -9.44888778e-03,
                         -2.50697017e-01,   1.74998119e-01,   4.56862479e-01,
                         -5.02430379e-01,  -2.98457474e-01,   8.79704773e-01,
                         -5.92126837e-03,  -9.08940852e-01,   4.22011316e-01,
                          7.79139519e-01,  -6.99558437e-01,  -4.04394388e-01,
                          7.94573367e-01,   1.30043164e-01,  -5.86491883e-01,
                          2.16105934e-02,   3.84678155e-01,   2.44457591e-02,
                         -8.06350410e-02,  -1.46597445e-01,  -8.67569819e-02,
                          4.32785600e-01,   1.86007410e-01,  -6.45058572e-01,
                         -5.87433316e-02,   7.96501100e-01,  -1.64306924e-01,
                         -7.23266959e-01,   4.83368635e-01,   5.91659844e-01,
                         -6.16731167e-01,  -2.53532320e-01,   6.52136683e-01,
                         -5.30545786e-02,  -4.67959881e-01,   2.46847749e-01,
                          2.66591042e-01,  -1.14154324e-01,  -4.60364409e-02,
                         -8.07694942e-02,   1.96931094e-01,   2.55286723e-01,
                         -5.08621156e-01,  -6.93607628e-02,   8.03774774e-01,
                         -2.59001255e-01,  -7.24713266e-01,   7.20148206e-01,
                          4.97796029e-01,  -8.91669333e-01,  -1.21709995e-01,
                          8.78848195e-01,  -1.05203167e-01,  -6.32500112e-01,
                          2.94303447e-01,   4.10528928e-01,  -1.91478029e-01,
                         -1.60874531e-01,   1.64893381e-02,   9.38848108e-02,
                          3.09758961e-01,  -7.64198154e-02,  -5.22458315e-01,
                          2.53848433e-01,   6.25463724e-01,  -4.73519683e-01,
                         -5.52441418e-01,   7.18728960e-01,   3.84001940e-01,
                         -7.31841087e-01,   1.92666091e-02,   6.96451902e-01,
                         -3.01951975e-01,  -4.31284338e-01,   4.32235658e-01,
                          2.41704509e-01,  -2.46394396e-01,  -8.90067592e-03,
                          6.27411157e-02,   1.52670652e-01,   9.49820057e-02,
                         -3.93366277e-01,   1.00209869e-01,   6.61722243e-01,
                         -4.57798511e-01,  -4.95885313e-01,   8.88213694e-01,
                          1.88743114e-01,  -9.30916965e-01,   2.00652406e-01,
                          8.80053461e-01,  -4.47301656e-01,  -5.85684419e-01,
                          6.22048318e-01,   3.44286352e-01,  -4.17980522e-01,
                         -1.24295138e-01,   2.16822386e-01,   1.25075117e-01,
                          1.25884995e-01,  -2.00439170e-01,  -3.04996490e-01,
                          4.41490591e-01,   4.06222314e-01,  -6.29228234e-01,
                         -2.88108379e-01,   8.13127816e-01,   7.70675167e-02,
                         -7.50558972e-01,   3.02675545e-01,   6.58104837e-01,
                         -4.88973469e-01,  -3.74470413e-01,   5.65379679e-01,
                          9.60665718e-02,  -3.83619547e-01,   1.17182426e-01,
                          1.86120361e-01,   3.76707055e-02,  -4.87821270e-03,
                         -2.65016764e-01,   2.02017799e-01,   4.40765709e-01,
                         -5.52325428e-01,  -2.26176441e-01,   8.76484811e-01,
                         -3.54559422e-02,  -9.11862075e-01,   5.26605785e-01,
                          7.19939411e-01,  -7.46300519e-01,  -3.16258579e-01,
                          8.06883454e-01,   1.25682086e-01,  -6.10950708e-01,
                          6.63275272e-02,   3.90148818e-01,   1.14718114e-03,
                         -7.01255649e-02,  -1.53631881e-01,  -4.98604737e-02,
                          4.65923846e-01,   1.59478471e-01,  -6.35531902e-01,
                          2.20939983e-02,   8.07852030e-01,  -2.42920876e-01,
                         -6.57206833e-01,   5.65383017e-01,   5.35232306e-01,
                         -6.87910676e-01,  -1.89198866e-01,   6.83141708e-01,
                         -8.10789689e-02,  -4.18146282e-01,   2.59996414e-01,
                          2.23188028e-01,  -9.86037254e-02,  -3.49660069e-02,
                         -7.95875862e-02,   2.21454889e-01,   2.51452476e-01,
                         -5.09311378e-01,  -3.56473476e-02,   8.10952246e-01,
                         -3.38410199e-01,  -7.17040360e-01,   7.81864285e-01,
                          4.51004982e-01,  -9.20651257e-01,  -2.86859064e-03,
                          8.68964791e-01,  -1.97840557e-01,  -6.52381003e-01,
                          3.58282983e-01,   3.98603886e-01,  -2.16730192e-01,
                         -1.52863890e-01,   1.94686539e-02,   9.49193537e-02,
                          3.22977573e-01,  -9.68874916e-02,  -5.23591876e-01,
                          3.07760894e-01,   6.27148151e-01,  -4.84670967e-01,
                         -5.24238825e-01,   7.00712383e-01,   2.45739967e-01,
                         -7.86198258e-01,   6.22521229e-02,   6.55592740e-01,
                         -3.41003865e-01,  -4.78993118e-01,   4.13374275e-01,
                          1.77676633e-01,  -2.63687044e-01,  -2.73798555e-02,
                          3.29219662e-02,   1.35516182e-01,   4.02282476e-02,
                         -4.30825382e-01,   1.09434202e-01,   5.81264436e-01,
                         -5.49644887e-01,  -4.75773543e-01,   8.67332458e-01,
                          4.50502448e-02,  -9.44409966e-01,   2.19758794e-01,
                          7.79999316e-01,  -5.30399203e-01,  -5.24028838e-01,
                          5.68819642e-01,   2.30098277e-01,  -4.79470968e-01,
                         -1.33013308e-01,   1.94038004e-01,   7.31917545e-02,
                          5.81122339e-02,  -2.42552593e-01,  -2.99375981e-01,
                          4.26683009e-01,   3.32187831e-01,  -7.01800525e-01,
                         -2.97981322e-01,   7.35469818e-01,  -4.42275070e-02,
                         -7.89237559e-01,   3.44764441e-01,   5.81045270e-01,
                         -5.97357988e-01,  -3.61987889e-01,   5.42598248e-01,
                         -2.38876976e-03,  -4.04158771e-01,   7.81437978e-02,
                          1.07421242e-01,  -2.58771740e-02,  -7.17205405e-02,
                         -3.04157615e-01,   1.90556735e-01,   3.65011543e-01,
                         -6.48560226e-01,  -2.42410138e-01,   8.23201418e-01,
                         -1.94175392e-01,  -8.98138583e-01,   5.27048349e-01,
                          5.48692405e-01,  -8.55015695e-01,  -3.26485813e-01,
                          7.47722805e-01,   2.65218690e-02,  -6.67078495e-01,
                          5.30822873e-02,   3.16923916e-01,  -8.43911991e-02,
                         -1.38691857e-01,  -2.12450534e-01,  -9.11685303e-02,
                          3.98407519e-01,   3.08489334e-02,  -7.03410745e-01,
                          1.81529038e-02,   6.78964913e-01,  -3.78547370e-01,
                         -7.21707642e-01,   5.35899401e-01,   4.33671445e-01,
                         -7.49631643e-01,  -1.63272545e-01,   6.26979232e-01,
                         -2.29331926e-01,  -5.16809523e-01,   2.14869007e-01,
                          1.53980136e-01,  -1.84611991e-01,  -1.06786184e-01,
                         -1.24744870e-01,   1.85537919e-01,   1.24301888e-01,
                         -5.90339243e-01,  -3.16187777e-02,   6.86549067e-01,
                         -4.66124535e-01,  -7.27872491e-01,   7.70730495e-01,
                          2.72789896e-01,  -9.85438049e-01,  -2.39637010e-02,
                          8.16268563e-01,  -3.02755684e-01,  -6.95172131e-01,
                          3.35060269e-01,   3.21079612e-01,  -3.24362814e-01,
                         -2.07148269e-01,  -3.56720276e-02,   4.75747138e-02,
                          2.34300315e-01,  -2.01859817e-01,  -5.29810250e-01,
                          3.17665786e-01,   5.19120097e-01,  -6.25553250e-01,
                         -5.23572206e-01,   7.41265655e-01,   1.84357047e-01,
                         -8.47301066e-01,   1.00923613e-01,   6.31368518e-01,
                         -4.21467483e-01,  -4.61364895e-01,   3.92988831e-01,
                          1.03822492e-01,  -3.19299430e-01,  -3.83052565e-02,
                          2.07513012e-02,   1.05957992e-01,  -5.78056881e-03,
                         -4.66305047e-01,   1.37609586e-01,   5.14400065e-01,
                         -6.27889276e-01,  -4.11925465e-01,   8.89546514e-01,
                         -2.85768211e-02,  -9.86364126e-01,   3.01503479e-01,
                          7.74867415e-01,  -6.62981927e-01,  -4.99058276e-01,
                          6.01869106e-01,   1.94439054e-01,  -5.00916183e-01,
                         -1.09017774e-01,   1.83871955e-01,   5.20101562e-02,
                          3.39484811e-02,  -2.68234253e-01,  -2.91738421e-01,
                          4.33019102e-01,   3.06213021e-01,  -6.97776556e-01,
                         -1.70314863e-01,   8.08105350e-01,  -1.20724417e-01,
                         -7.63439357e-01,   4.23852652e-01,   6.42507553e-01,
                         -5.72706878e-01,  -3.03910702e-01,   5.54655254e-01,
                         -2.51277871e-02,  -3.86142105e-01,   1.43327042e-01,
                          1.46277085e-01,   7.72132399e-03,  -5.52737564e-02,
                         -2.58531898e-01,   2.53943831e-01,   3.63075286e-01,
                         -6.18791699e-01,  -1.11638233e-01,   8.46998334e-01,
                         -2.73032576e-01,  -8.09075356e-01,   6.76773310e-01,
                          5.46313345e-01,  -8.11254025e-01,  -1.89172849e-01,
                          8.03168058e-01,  -2.85948105e-02,  -6.06749654e-01,
                          1.52612463e-01,   3.61523032e-01,  -5.12835570e-02,
                         -8.65259096e-02,  -1.50909573e-01,  -2.89174821e-02,
                          4.59675431e-01,   5.16342483e-02,  -6.35510802e-01,
                          1.50626957e-01,   7.39304662e-01,  -3.99907231e-01,
                         -6.10841036e-01,   6.73654079e-01,   4.23668265e-01,
                         -7.22260356e-01,  -5.19937575e-02,   6.48951769e-01,
                         -2.05803394e-01,  -3.96317869e-01,   3.25617880e-01,
                          1.90236986e-01,  -1.28798410e-01,  -3.12142428e-02,
                         -7.13154376e-02,   2.55538762e-01,   1.86053604e-01,
                         -5.34564435e-01,   6.72498494e-02,   7.72459686e-01,
                         -4.50918943e-01,  -5.54951608e-01,   8.92813385e-01,
                          2.85690069e-01,  -9.25447702e-01,   9.37572718e-02,
                          8.95115554e-01,  -3.45467478e-01,  -5.71439683e-01,
                          4.67553377e-01,   3.48072052e-01,  -2.59110421e-01,
                         -1.16690874e-01,   5.43356463e-02,   1.31841883e-01,
                          3.06210577e-01,  -1.76236823e-01,  -4.68425363e-01,
                          4.08220112e-01,   5.66438496e-01,  -5.77273667e-01,
                         -4.09794897e-01,   7.99364746e-01,   1.57205492e-01,
                         -7.80138910e-01,   2.33059585e-01,   6.49910450e-01,
                         -4.28397208e-01,  -3.44334215e-01,   5.15137792e-01,
                          1.23696864e-01,  -2.73279548e-01,   3.37078348e-02,
                          6.64347932e-02,   1.58360943e-01,   4.32724729e-02,
                         -3.86531740e-01,   2.34502524e-01,   5.51190794e-01,
                         -6.01463974e-01,  -3.09131503e-01,   9.34722304e-01,
                         -1.28453337e-02,  -9.15332019e-01,   4.16619390e-01,
                          7.71310449e-01,  -6.55988157e-01,  -4.10135597e-01,
                          7.07817078e-01,   1.80134907e-01,  -4.72276241e-01,
                         -2.77727898e-02,   2.51191705e-01,   9.88410637e-02,
                          7.04662576e-02,  -2.38057807e-01,  -2.05802083e-01,
                          5.01863062e-01,   2.84609288e-01,  -7.07998157e-01,
                         -1.03443168e-01,   8.22078347e-01,  -1.41718358e-01,
                         -7.27011681e-01,   4.73963559e-01,   5.81014752e-01,
                         -5.89254916e-01,  -2.28565007e-01,   5.95470548e-01,
                         -4.80927490e-02,  -3.74560267e-01,   1.74418271e-01,
                          1.78246021e-01,   2.90572103e-02,  -3.30400392e-02,
                         -2.26147547e-01,   2.98521489e-01,   3.25528800e-01,
                         -6.34503305e-01,  -6.25049248e-02,   8.70667398e-01,
                         -2.95729727e-01,  -7.35822499e-01,   7.32689679e-01,
                          5.02969623e-01,  -8.51178169e-01,  -1.49057493e-01,
                          8.16655517e-01,  -4.03436571e-02,  -5.73435247e-01,
                          1.89408943e-01,   3.45640451e-01,  -5.05566634e-02,
                         -9.09931883e-02,  -1.34302542e-01,   1.14031676e-02,
                          4.56405818e-01,  -1.22856116e-02,  -6.40217245e-01,
                          2.09627628e-01,   6.93497181e-01,  -4.54101294e-01,
                         -5.94922483e-01,   7.10908651e-01,   3.99995863e-01,
                         -7.14527667e-01,   9.87566449e-03,   6.49481773e-01,
                         -2.78287292e-01,  -3.89802903e-01,   3.54537934e-01,
                          1.93039075e-01,  -1.31897062e-01,  -4.58459742e-02,
                         -6.00234382e-02,   2.67387003e-01,   1.33504331e-01,
                         -5.42621911e-01,   1.44138336e-01,   7.14538932e-01,
                         -5.30752778e-01,  -5.11055052e-01,   9.16150212e-01,
                          1.74095884e-01,  -9.15947258e-01,   1.82827294e-01,
                          8.35185170e-01,  -3.83804440e-01,  -5.66227734e-01,
                          4.82181996e-01,   3.13109159e-01,  -2.80005902e-01,
                         -1.26495004e-01,   5.10944799e-02,   1.37268350e-01,
                          2.74879724e-01,  -2.19926879e-01,  -4.60293800e-01,
                          4.51098084e-01,   5.01473784e-01,  -6.41171813e-01,
                         -3.42627287e-01,   8.15697372e-01,   9.02405009e-02,
                         -7.43636608e-01,   2.75600940e-01,   6.23744071e-01,
                         -4.69090849e-01,  -3.36194307e-01,   5.00520766e-01,
                          7.00640678e-02,  -2.86340237e-01,   5.32134287e-02,
                          8.93401504e-02,   1.53194681e-01,   7.01544574e-03,
                         -3.96160215e-01,   2.77729511e-01,   4.93644774e-01,
                         -6.43457711e-01,  -2.16505691e-01,   9.10209239e-01,
                         -6.67137131e-02,  -9.26984251e-01,   5.23072064e-01,
                          6.95120275e-01,  -6.96381032e-01,  -3.27290565e-01,
                          6.99093401e-01,   1.33365422e-01,  -4.93584186e-01,
                          8.94956000e-04,   2.49112561e-01,   8.88586566e-02,
                          5.44407032e-02,  -2.63234884e-01,  -1.81070477e-01,
                          5.31396329e-01,   2.48485699e-01,  -6.95933044e-01,
                         -4.12494987e-02,   8.34470630e-01,  -2.29968816e-01,
                         -6.63934648e-01,   5.41446745e-01,   5.14595509e-01,
                         -6.71085477e-01,  -1.67179123e-01,   6.27776623e-01,
                         -8.36129710e-02,  -3.52335185e-01,   1.93732873e-01,
                          1.65370315e-01,   7.20581925e-03,  -7.26806447e-02,
                         -2.04140991e-01,   3.14774722e-01,   3.01010638e-01,
                         -6.33557856e-01,  -2.25890540e-02,   8.64624858e-01,
                         -3.92746478e-01,  -7.35095799e-01,   7.82490194e-01,
                          4.51203108e-01,  -9.00640786e-01,  -3.67703550e-02,
                          8.07430565e-01,  -1.33261383e-01,  -5.84142268e-01,
                          2.45812654e-01,   3.30757201e-01,  -9.19448659e-02,
                         -9.69956741e-02,  -1.27993971e-01,   2.31817774e-02,
                          4.56663847e-01,  -4.56474535e-02,  -6.28200233e-01,
                          2.63827860e-01,   6.88402832e-01,  -4.75133032e-01,
                         -5.59807718e-01,   6.81954682e-01,   2.49112919e-01,
                         -7.75230467e-01,   5.44923507e-02,   6.10018969e-01,
                         -3.26137006e-01,  -4.26854461e-01,   3.33819777e-01,
                          1.38198316e-01,  -1.68617964e-01,  -5.75754307e-02,
                         -6.25201985e-02,   2.34835297e-01,   7.37359673e-02,
                         -5.57824433e-01,   1.36742979e-01,   6.48773372e-01,
                         -6.16836607e-01,  -4.96590108e-01,   8.80697072e-01,
                          4.32646275e-02,  -9.38715875e-01,   1.93701595e-01,
                          7.62011349e-01,  -4.69341993e-01,  -5.21385312e-01,
                          4.48562980e-01,   2.29157686e-01,  -3.43909085e-01,
                         -1.42507315e-01,   2.04739720e-02,   9.76421759e-02,
                          2.21079677e-01,  -2.69786805e-01,  -4.31062102e-01,
                          4.60800856e-01,   4.25047040e-01,  -7.31840312e-01,
                         -3.50343645e-01,   7.47083545e-01,  -2.45890301e-02,
                         -7.89466619e-01,   3.24712604e-01,   5.44958949e-01,
                         -5.60789108e-01,  -3.30714256e-01,   4.67053980e-01,
                         -1.99885108e-03,  -3.27685446e-01,   1.81153789e-02,
                          5.15739247e-02,   9.87498313e-02,  -7.12402835e-02,
                         -4.16201442e-01,   2.69016832e-01,   4.10372734e-01,
                         -7.45227039e-01,  -2.20668077e-01,   8.67336214e-01,
                         -2.19834447e-01,  -9.03538942e-01,   5.30389428e-01,
                          5.42350233e-01,  -7.87043095e-01,  -3.43801349e-01,
                          6.70557320e-01,   5.59719838e-02,  -5.47435284e-01,
                         -1.64751150e-02,   1.71539724e-01,   2.74475981e-02,
                         -6.40759850e-03,  -3.25548559e-01,  -2.05323905e-01,
                          5.07310510e-01,   1.27516508e-01,  -7.68660367e-01,
                         -4.57749330e-02,   7.18928039e-01,  -3.50384414e-01,
                         -7.18838871e-01,   5.18005490e-01,   4.24079329e-01,
                         -7.09170938e-01,  -1.48499474e-01,   5.49229562e-01,
                         -2.04858556e-01,  -4.25672770e-01,   1.42274201e-01,
                          9.63173807e-02,  -5.66216484e-02,  -1.14605732e-01,
                         -2.46478856e-01,   2.83766448e-01,   1.74019337e-01,
                         -7.03094482e-01,   3.51400406e-04,   7.58783638e-01,
                         -5.10268688e-01,  -7.33762264e-01,   7.87515044e-01,
                          2.67333776e-01,  -9.52074409e-01,  -4.46421579e-02,
                          7.63664007e-01,  -2.49053329e-01,  -6.27280116e-01,
                          2.31050372e-01,   2.50414342e-01,  -1.75670236e-01,
                         -1.49064988e-01,  -2.00004905e-01,   2.10599319e-04,
                          4.03528184e-01,  -1.34017542e-01,  -6.37700200e-01,
                          3.06885660e-01,   5.93126595e-01,  -5.96612096e-01,
                         -5.48718572e-01,   7.14953303e-01,   1.95607364e-01,
                         -7.79441714e-01,   9.57413912e-02,   5.64968407e-01,
                         -3.87353510e-01,  -3.83067727e-01,   3.10582787e-01,
                          5.92941642e-02,  -1.99139699e-01,  -7.92544261e-02,
                         -7.59940296e-02,   2.25241199e-01,   2.79114358e-02,
                         -5.91201961e-01,   2.06899881e-01,   5.71752071e-01,
                         -6.88555717e-01,  -3.94172758e-01,   9.17843103e-01,
                         -3.16472650e-02,  -9.59526777e-01,   2.88291097e-01,
                          7.41395950e-01,  -5.68377316e-01,  -4.77068573e-01,
                          4.88604516e-01,   1.99146926e-01,  -3.59973162e-01,
                         -1.31623641e-01,   3.06382440e-02,   9.47494954e-02,
                          1.91524833e-01,  -3.17733556e-01,  -4.20894355e-01,
                          4.78041798e-01,   3.87609839e-01,  -7.06675351e-01,
                         -2.10041076e-01,   7.94198275e-01,  -7.36545920e-02,
                         -7.29358435e-01,   3.84043902e-01,   5.86941183e-01,
                         -5.27488410e-01,  -2.58148730e-01,   4.72698510e-01,
                         -3.01282555e-02,  -2.78802037e-01,   7.98989460e-02,
                          7.75327832e-02,   1.32033885e-01,  -5.35508990e-02,
                         -3.66287887e-01,   3.55390102e-01,   4.26811546e-01,
                         -7.11860061e-01,  -7.73251578e-02,   9.02430415e-01,
                         -2.81954437e-01,  -8.18813264e-01,   6.67810678e-01,
                          5.49352407e-01,  -7.35314667e-01,  -1.96386069e-01,
                          7.20998704e-01,   3.24516818e-02,  -4.91184294e-01,
                          7.22233504e-02,   2.50212491e-01,   7.17602223e-02,
                          3.15388478e-02,  -2.62491852e-01,  -1.14975743e-01,
                          5.76403081e-01,   1.42883703e-01,  -6.90382421e-01,
                          8.49181190e-02,   7.76291430e-01,  -3.54881316e-01,
                         -5.96596003e-01,   6.48443520e-01,   4.16399002e-01,
                         -6.61785126e-01,  -2.34650094e-02,   5.78936517e-01,
                         -1.83147028e-01,  -3.04611772e-01,   2.55139261e-01,
                          1.43733829e-01,  -1.32850476e-03,  -6.03355430e-02,
                         -1.75689846e-01,   3.83868337e-01,   2.24787012e-01,
                         -6.42205954e-01,   1.25410393e-01,   8.43028724e-01,
                         -4.93662208e-01,  -5.47864377e-01,   8.93989682e-01,
                          3.01273078e-01,  -8.75110924e-01,   6.84961155e-02,
                          8.43102396e-01,  -2.38074571e-01,  -5.01166046e-01,
                          3.50856066e-01,   3.09834391e-01,  -1.04215048e-01,
                         -7.39503130e-02,  -1.00947924e-01,   9.35409889e-02,
                          4.65634257e-01,  -1.43008783e-01,  -5.59604764e-01,
                          4.02796924e-01,   6.39716029e-01,  -5.42750120e-01,
                         -4.32424545e-01,   7.76371717e-01,   1.82142377e-01,
                         -7.29955614e-01,   2.36421242e-01,   5.94501615e-01,
                         -3.64407212e-01,  -2.68171281e-01,   4.26327378e-01,
                          9.32051241e-02,  -1.51712492e-01,   4.81997500e-04,
                         -1.03772804e-02,   2.94487566e-01,   3.73170786e-02,
                         -5.24361730e-01,   3.22407156e-01,   6.14120066e-01,
                         -6.84777319e-01,  -2.90161401e-01,   9.90807891e-01,
                         -2.87836846e-02,  -9.11449015e-01,   4.04137790e-01,
                          7.47045815e-01,  -5.61983883e-01,  -3.87761742e-01,
                          5.93031228e-01,   2.00090721e-01,  -3.14266205e-01,
                         -6.64895475e-02,   9.52152759e-02,   1.61099210e-01,
                          2.19730765e-01,  -2.89174050e-01,  -3.18422437e-01,
                          5.71091235e-01,   3.64465803e-01,  -7.40292609e-01,
                         -1.45981729e-01,   8.37125719e-01,  -1.10118277e-01,
                         -6.94301367e-01,   4.55505848e-01,   5.47671437e-01,
                         -5.24606049e-01,  -1.80730969e-01,   5.04694462e-01,
                         -4.25797738e-02,  -2.73593575e-01,   1.05504654e-01,
                          1.06832191e-01,   1.66763350e-01,  -5.74611090e-02,
                         -3.33821833e-01,   3.95813376e-01,   3.68285298e-01,
                         -7.54071355e-01,  -1.39512336e-02,   9.37302947e-01,
                         -3.29013467e-01,  -7.43424773e-01,   7.37728655e-01,
                          4.86444920e-01,  -7.99422801e-01,  -1.52673051e-01,
                          7.31035173e-01,   7.49197649e-03,  -4.49659646e-01,
                          1.00692064e-01,   2.31603175e-01,   6.86633587e-02,
                          2.77719907e-02,  -2.73006648e-01,  -9.25440490e-02,
                          5.68368256e-01,   4.47482541e-02,  -7.13852763e-01,
                          1.83230728e-01,   7.31792688e-01,  -4.54886109e-01,
                         -6.05690718e-01,   6.83470488e-01,   3.81391317e-01,
                         -6.62351429e-01,   1.04175601e-02,   5.74797928e-01,
                         -2.51962662e-01,  -3.08981240e-01,   2.55131781e-01,
                          1.40505359e-01,  -1.38061093e-02,  -9.06903222e-02,
                         -1.69118226e-01,   3.84678334e-01,   1.39213219e-01,
                         -6.57029688e-01,   2.00182483e-01,   7.71428525e-01,
                         -6.13796949e-01,  -5.17223656e-01,   9.30920660e-01,
                          1.55862674e-01,  -9.06273365e-01,   1.40897945e-01,
                          7.81718791e-01,  -3.18732113e-01,  -5.05208611e-01,
                          3.54097337e-01,   2.67127275e-01,  -1.28743052e-01,
                         -9.54578370e-02,  -1.30977258e-01,   1.03484683e-01,
                          4.30859149e-01,  -2.19861686e-01,  -5.80042779e-01,
                          4.41631347e-01,   5.64783037e-01,  -6.69348240e-01,
                         -3.90410125e-01,   7.91211247e-01,   9.89509076e-02,
                         -7.37233996e-01,   2.69585967e-01,   5.68657219e-01,
                         -4.43385720e-01,  -2.92888969e-01,   3.90782595e-01,
                          5.53627685e-02,  -1.70974538e-01,  -1.99986659e-02,
                         -6.76781638e-03,   2.76719481e-01,  -2.21603041e-04,
                         -5.49090564e-01,   3.65629643e-01,   5.31691909e-01,
                         -7.54642844e-01,  -2.16810316e-01,   9.45833325e-01,
                         -9.08720717e-02,  -9.45307255e-01,   4.95536327e-01,
                          6.70080364e-01,  -6.49844825e-01,  -3.42107147e-01,
                          5.88277161e-01,   1.53698981e-01,  -3.58317107e-01,
                         -7.49209300e-02,   7.12207407e-02,   1.63192809e-01,
                          1.88934848e-01,  -3.41303706e-01,  -3.02543342e-01,
                          5.89373767e-01,   3.19025606e-01,  -7.31117487e-01,
                         -7.78642222e-02,   8.34817827e-01,  -2.32149720e-01,
                         -6.62907004e-01,   5.26826203e-01,   4.65721220e-01,
                         -6.21443331e-01,  -1.29952237e-01,   5.24919033e-01,
                         -8.00986215e-02,  -2.50200570e-01,   1.08889706e-01,
                          7.66287223e-02,   1.46447033e-01,  -8.13007653e-02,
                         -3.25164586e-01,   4.20682162e-01,   3.28695059e-01,
                         -7.53064215e-01,   1.80736405e-03,   9.21104252e-01,
                         -4.36403662e-01,  -7.44733930e-01,   7.80194700e-01,
                          4.41005021e-01,  -8.58861208e-01,  -6.89353198e-02,
                          7.38184094e-01,  -8.78564939e-02,  -5.00645101e-01,
                          1.26824230e-01,   2.34267354e-01,   4.92286943e-02,
                         -2.01252736e-02,  -2.81175107e-01,  -4.50080037e-02,
                          5.78142822e-01,   1.62077660e-03,  -7.25469768e-01,
                          2.42311746e-01,   7.20067143e-01,  -4.80044574e-01,
                         -5.74350953e-01,   6.72221720e-01,   2.24674255e-01,
                         -7.41198123e-01,   6.09489046e-02,   5.44504583e-01,
                         -2.92786717e-01,  -3.28981578e-01,   2.34814718e-01,
                          8.07023942e-02,  -4.29343730e-02,  -1.14560090e-01,
                         -1.66572794e-01,   3.64500076e-01,   8.86702538e-02,
                         -6.79742932e-01,   1.89539909e-01,   6.86541319e-01,
                         -6.63575530e-01,  -4.97972071e-01,   8.96256685e-01,
                          4.95836884e-02,  -9.11991835e-01,   1.49396524e-01,
                          7.12815583e-01,  -3.90467405e-01,  -4.87545162e-01,
                          3.23217362e-01,   1.85443163e-01,  -1.89191967e-01,
                         -1.39806688e-01,  -1.45235449e-01,   9.49606225e-02,
                          3.67969900e-01,  -2.74237901e-01,  -5.60020983e-01,
                          4.64175493e-01,   5.09845614e-01,  -7.46880531e-01,
                         -3.89732599e-01,   7.52082050e-01,  -1.85541715e-02,
                         -7.66384482e-01,   3.17987233e-01,   4.94375616e-01,
                         -5.11850834e-01,  -2.68666148e-01,   3.68766576e-01,
                         -2.12243814e-02,  -1.97067842e-01,  -6.93186000e-02,
                         -4.02870402e-02,   2.28960544e-01,  -8.30010995e-02,
                         -5.59996784e-01,   3.22823256e-01,   4.25135046e-01,
                         -7.29192674e-01,  -1.61454096e-01,   7.91350782e-01,
                         -1.66616887e-01,  -7.64084220e-01,   3.69486988e-01,
                          4.48222488e-01,  -5.32308757e-01,  -2.36172900e-01,
                          4.22579914e-01,   5.62756136e-02,  -3.08251739e-01,
                         -7.23626539e-02,   2.12443024e-02,   7.52103105e-02,
                          7.81625435e-02,  -2.44818836e-01,  -1.84375197e-01,
                          3.43330264e-01,   1.32376999e-01,  -4.29605961e-01,
                         -4.85551693e-02,   3.99019659e-01,  -1.71895772e-01,
                         -3.66243035e-01,   1.74398705e-01,   1.66372478e-01,
                         -2.71166116e-01,  -4.72339541e-02,   1.73342884e-01,
                         -6.78873062e-02,  -1.15242444e-01,   7.21284468e-03,
                         -1.00490013e-02,   6.40357984e-03,  -5.59188053e-02,
                         -1.03268690e-01,   9.69104469e-02,   2.68180277e-02,
                         -1.84381709e-01,  -2.96586175e-02,   1.22160621e-01,
                         -6.84340596e-02,  -1.18358426e-01,   7.56306127e-02,
                         -3.69493812e-02,  -5.78372926e-02,  -3.72501463e-02,
                          2.02914234e-02,  -2.35701278e-02,  -2.03870442e-02,
                         -2.69200671e-02,  -2.55803671e-02,  -2.92499512e-02,
                         -2.16945652e-02,  -1.60218161e-02,  -2.06623599e-02,
                         -2.77295653e-02,  -1.85808446e-02,  -2.26815287e-02,
                         -1.92347616e-02,  -9.79337469e-03,  -2.37158481e-02,
                         -2.30227951e-02,  -1.47885382e-02,  -2.65755914e-02,
                         -2.47708801e-02,  -1.57960113e-02,  -2.04677563e-02,
                         -2.19781008e-02,  -2.31556911e-02,  -1.80422086e-02,
                         -1.85184777e-02,  -2.17501298e-02,  -2.57606786e-02,
                         -9.50257014e-03,  -1.67878456e-02,  -1.97529383e-02,
                         -1.20028146e-02,  -1.93497296e-02,  -2.57135145e-02,
                         -1.75377689e-02,  -2.50004996e-02,  -1.84719507e-02,
                         -1.47221517e-02,  -1.80970151e-02,  -2.40750238e-02,
                         -1.76676176e-02,  -1.24619855e-02,  -1.91105120e-02,
                         -2.11735740e-02,  -1.33574372e-02,  -1.33566372e-02,
                         -2.35665739e-02,  -1.39659625e-02,  -1.58700421e-02,
                         -1.66226476e-02,  -1.50946183e-02,  -1.57235004e-02,
                         -1.60560515e-02,  -1.21119004e-02,  -1.83339845e-02,
                         -1.64643750e-02,  -1.40722943e-02,  -1.94942150e-02,
                         -1.71066802e-02,  -2.06591319e-02,  -1.01000415e-02,
                         -1.73137672e-02,  -1.77725833e-02,  -1.09337633e-02,
                         -6.87932130e-03,  -2.10578870e-02,  -1.92034412e-02,
                         -1.57539807e-02,  -1.30737498e-02,  -1.50288390e-02,
                         -1.07052261e-02,  -1.56719349e-02,  -1.60900448e-02,
                         -1.20978802e-02,  -1.32225174e-02,  -1.14561925e-02,
                         -1.28784459e-02,  -1.46174701e-02,  -1.34536866e-02,
                         -1.19013824e-02,  -1.01386402e-02,  -1.65710095e-02,
                         -1.44038033e-02,  -1.07465889e-02,  -1.06880469e-02,
                         -9.13406257e-03,  -8.00686423e-03,  -1.17683560e-02,
                         -1.49317291e-02,  -1.22825447e-02,  -1.05163101e-02,
                         -1.02886232e-02,  -9.85199679e-03,  -8.60977080e-03,
                         -1.01596862e-02,  -1.33278072e-02,  -1.13678286e-02,
                         -8.90456326e-03,  -8.78325943e-03,  -9.27873049e-03,
                         -8.80195666e-03,  -1.03935283e-02,  -7.75699737e-03,
                         -6.55662967e-03,  -9.94505826e-03,  -7.27285398e-03,
                         -7.96691887e-03,  -8.28010403e-03,  -6.89707696e-03,
                         -6.39032898e-03,  -9.42626316e-03,  -9.74073447e-03,
                         -6.47160644e-03,  -7.05002574e-03,  -9.61574633e-03,
                         -6.03996078e-03,  -5.34459064e-03,  -6.57262420e-03,
                         -7.33561674e-03,  -5.96086960e-03,  -6.30107429e-03,
                         -7.55096367e-03,  -6.39716210e-03,  -5.34720207e-03,
                         -4.21163207e-03,  -5.05094184e-03,  -6.10020291e-03,
                         -4.32217540e-03,  -3.30125866e-03,  -5.96707547e-03,
                         -5.40439738e-03,  -3.86215514e-03,  -4.00755182e-03,
                         -5.28636295e-03,  -4.08463879e-03,  -4.64341929e-03,
                         -4.76435898e-03,  -4.10937937e-03,  -3.69633990e-03,
                         -3.59263970e-03,  -3.79961496e-03,  -2.32571340e-03,
                         -2.98743509e-03,  -2.40870193e-03,  -3.24299070e-03,
                         -3.16536729e-03,  -3.54252080e-03,  -2.10463675e-03,
                         -2.23875651e-03,  -2.16264161e-03,  -1.84571010e-03,
                         -1.48761843e-03,  -3.20796506e-03,  -1.77739991e-03,
                         -1.97948585e-03,  -1.81448064e-03,  -9.34304204e-04,
                         -1.17067667e-03,  -1.30654790e-03,  -1.69118214e-03,
                         -1.11053581e-03,  -8.32810765e-04,  -1.75897600e-04,
                         -2.62813875e-04,  -8.28953926e-04,  -8.34643026e-04,
                          5.29292272e-04,   6.36464683e-04,  -7.51188840e-04,
                         -1.41448967e-04,   1.18439342e-03,   9.07721114e-04,
                          1.20079269e-04,   2.86076567e-04,   9.34668642e-04,
                          9.80070326e-04,   1.17972668e-03,   1.15288049e-03,
                          1.44959625e-03,   1.07912417e-03,   1.47707015e-03,
                          1.47440785e-03,   1.19114551e-03,   2.17574090e-03,
                          2.42500007e-03,   1.92955905e-03,   1.95483631e-03,
                          2.46785069e-03,   2.26578512e-03,   2.21344898e-03,
                          2.74222507e-03,   2.99712270e-03,   2.88612372e-03,
                          2.82621570e-03,   3.32060386e-03,   2.98942928e-03,
                          2.95849331e-03,   2.81042396e-03,   3.21681262e-03,
                          3.58017837e-03,   3.17203836e-03,   4.05951357e-03,
                          4.12329845e-03,   4.03820444e-03,   4.21168283e-03,
                          3.94812971e-03,   4.30586748e-03,   4.46775462e-03,
                          4.33502160e-03,   4.40548779e-03,   4.46987059e-03,
                          5.34950010e-03,   4.61762585e-03,   4.39020200e-03,
                          5.53285843e-03,   5.21832611e-03,   4.69800271e-03,
                          5.01280837e-03,   5.86323347e-03,   5.14903385e-03,
                          5.32743195e-03,   5.57464641e-03,   5.52728074e-03,
                          5.78844454e-03,   5.75918891e-03,   5.97920269e-03,
                          6.06576446e-03,   5.84062841e-03,   6.16556732e-03,
                          5.82988793e-03,   6.13151351e-03,   6.25396147e-03,
                          6.22387603e-03,   6.69599324e-03,   6.61553582e-03,
                          7.00426986e-03,   6.70469925e-03,   6.64394069e-03,
                          7.04125920e-03,   6.89678360e-03,   6.78433711e-03,
                          6.97750458e-03,   7.23091420e-03,   7.13723572e-03,
                          7.30397180e-03,   7.43657351e-03,   7.43479189e-03,
                          7.25099817e-03,   7.31139211e-03,   7.76286889e-03,
                          7.60527374e-03,   7.85901677e-03,   7.95748364e-03,
                          7.86777399e-03,   7.79138505e-03,   7.96486344e-03,
                          7.89694767e-03,   7.68581219e-03,   8.22727196e-03,
                          8.45810771e-03,   7.95214903e-03,   7.65688065e-03,
                          8.63798335e-03,   8.47086310e-03,   8.11628345e-03,
                          8.40726960e-03,   8.69762804e-03,   8.48511606e-03,
                          8.51709489e-03,   8.44142493e-03,   8.41306988e-03,
                          8.64523184e-03,   8.84039328e-03,   8.53790715e-03,
                          8.96453205e-03,   8.86045769e-03,   8.83819629e-03,
                          8.66918266e-03,   9.15774982e-03,   8.85642786e-03,
                          8.83961376e-03,   9.36268084e-03,   8.99990182e-03,
                          8.86666309e-03,   9.12140869e-03,   9.21120960e-03,
                          9.12365597e-03,   9.25285555e-03,   9.35589802e-03,
                          9.29149520e-03,   9.23505984e-03,   9.32346378e-03,
                          9.13062040e-03,   9.30369366e-03,   9.50865448e-03,
                          9.38043650e-03,   9.36129410e-03,   9.56983771e-03,
                          9.61065385e-03,   9.49403644e-03,   9.36484709e-03,
                          9.50924121e-03,   9.64956731e-03,   9.43847187e-03,
                          9.52030625e-03,   9.59375873e-03,   9.50767286e-03,
                          9.64582153e-03,   9.42262914e-03,   9.44258180e-03,
                          9.71970893e-03,   9.64769442e-03,   9.53033846e-03,
                          9.67341661e-03,   9.74065345e-03,   9.58417263e-03,
                          9.64049716e-03,   9.55700222e-03,   9.62248817e-03,
                          9.67277866e-03,   9.54423659e-03,   9.64623690e-03,
                          9.54516791e-03,   9.49472561e-03,   9.62512009e-03,
                          9.50152799e-03,   9.39104520e-03,   9.60861892e-03,
                          9.63556673e-03,   9.38408077e-03,   9.41304211e-03,
                          9.61678848e-03,   9.50134546e-03,   9.27030761e-03,
                          9.34764743e-03,   9.46542900e-03,   9.39874910e-03,
                          9.25413147e-03,   9.25755315e-03,   9.40887164e-03,
                          9.35889408e-03,   9.09084734e-03,   9.15973447e-03,
                          9.36788414e-03,   9.20046959e-03,   9.01406351e-03,
                          9.13668424e-03,   9.27171484e-03,   9.00880992e-03,
                          8.95296130e-03,   9.12032556e-03,   9.09944158e-03,
                          8.92493036e-03,   8.95036012e-03,   9.01433732e-03,
                          8.93682521e-03,   8.83547403e-03,   8.86697602e-03,
                          8.90080724e-03,   8.84158816e-03,   8.76597874e-03,
                          8.79061874e-03,   8.81748460e-03,   8.75048060e-03,
                          8.65737908e-03,   8.68989434e-03,   8.72599334e-03,
                          8.61129910e-03,   8.56692996e-03,   8.61842558e-03,
                          8.58205371e-03,   8.49679764e-03,   8.46250076e-03,
                          8.50180909e-03,   8.44556559e-03,   8.36917665e-03,
                          8.39774404e-03,   8.37319531e-03,   8.28274619e-03,
                          8.28411337e-03,   8.27489141e-03,   8.15092493e-03,
                          8.16363934e-03,   8.16994533e-03,   8.03769846e-03,
                          8.02675541e-03,   8.03813431e-03,   7.92550482e-03,
                          7.87645951e-03,   7.88628869e-03,   7.79897766e-03,
                          7.73819908e-03,   7.74344243e-03,   7.65870279e-03,
                          7.58603960e-03,   7.59763084e-03,   7.51692988e-03,
                          7.40294484e-03,   7.42763467e-03,   7.37680728e-03,
                          7.23705860e-03,   7.24278856e-03,   7.23612728e-03,
                          7.08620576e-03,   7.05454079e-03,   7.06427917e-03,
                          6.93897624e-03,   6.86838850e-03,   6.89520454e-03,
                          6.79487502e-03,   6.69110427e-03,   6.71390118e-03,
                          6.63780654e-03,   6.53302297e-03,   6.53883349e-03,
                          6.47664769e-03,   6.36981940e-03,   6.38167374e-03,
                          6.32797088e-03,   6.19259570e-03,   6.19678665e-03,
                          6.19860878e-03,   6.05722051e-03,   5.99992462e-03,
                          6.03199424e-03,   5.95173892e-03,   5.84559888e-03,
                          5.83624514e-03,   5.81200048e-03,   5.71863586e-03,
                          5.66522684e-03,   5.64532494e-03,   5.57949534e-03,
                          5.51540637e-03,   5.49117196e-03,   5.42344898e-03,
                          5.35751740e-03,   5.34618972e-03,   5.26030641e-03,
                          5.19532664e-03,   5.20880008e-03,   5.10429032e-03,
                          5.01308171e-03,   5.06239105e-03,   4.96922899e-03,
                          4.81698895e-03,   4.87724086e-03,   4.85127559e-03,
                          4.65996051e-03,   4.64480650e-03,   4.69034957e-03,
                          4.56465222e-03,   4.43977444e-03,   4.43729432e-03,
                          4.43761842e-03,   4.33956692e-03,   4.20540664e-03,
                          4.18456318e-03,   4.21298854e-03,   4.10216162e-03,
                          3.95765575e-03,   3.94763378e-03,   3.95597517e-03,
                          3.86235747e-03,   3.73782404e-03,   3.68108461e-03,
                          3.69630964e-03,   3.64304218e-03,   3.49064032e-03,
                          3.43363755e-03,   3.45293200e-03,   3.37115815e-03,
                          3.27871484e-03,   3.22165131e-03,   3.14621464e-03,
                          3.13844020e-03,   3.09326104e-03,   2.94182054e-03,
                          2.91232206e-03,   2.91991443e-03,   2.81438185e-03,
                          2.76219775e-03,   2.69433297e-03,   2.59669661e-03,
                          2.64794938e-03,   2.58300011e-03,   2.36610416e-03,
                          2.40619131e-03,   2.48637586e-03,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,   0.00000000e+00,
                          0.00000000e+00,   0.00000000e+00,  -1.76632532e-03,
                         -5.30083897e-03,   1.07332366e-03,  -4.99803922e-04,
                          5.59605658e-03,   2.25540898e-05,  -5.78071037e-03,
                          4.05285275e-03,   4.12600162e-03,  -4.73227911e-03,
                         -2.43485975e-03,   4.27230960e-03,  -2.48246826e-04,
                          1.31271279e-03,   3.87048628e-03,   4.49239416e-03,
                         -4.02500387e-03,   1.13737199e-03,   6.91533904e-04,
                          1.66606694e-03,   1.33977167e-03,   5.41227288e-04,
                         -5.25475887e-04,   3.26973568e-05,   3.55621705e-05,
                          1.89551536e-03,  -1.56724607e-04,   4.62209014e-03,
                         -3.76381003e-03,  -4.22501471e-03,   3.60825961e-03,
                          3.77693959e-03,   5.83592155e-05,   3.25311371e-03,
                          6.84341509e-03,  -4.60849516e-03,  -1.19137832e-04,
                          6.54547429e-03,   2.36986997e-03,  -7.79991876e-03,
                          4.60476987e-03,   6.37871795e-04,   4.93026525e-03,
                          4.23428742e-03,  -7.21905008e-03,   2.42039398e-03,
                          5.48631279e-03,  -7.12625217e-03,  -5.66747412e-03,
                          7.19794352e-03,  -3.07680108e-03,   2.29478756e-04,
                          1.60326378e-03,   5.03630377e-04,  -3.73908947e-03,
                         -2.20347792e-04,   6.83928467e-03,  -8.33225844e-04,
                         -4.41464921e-03,   2.87962472e-03,  -1.14485284e-03,
                         -3.11079412e-03,  -2.09997012e-03,   3.14332941e-03,
                         -4.40621702e-03,   5.20022586e-03,  -2.12090439e-03,
                         -1.06672142e-02,   1.25068903e-03,   2.59681791e-03,
                         -1.71653018e-03,  -7.15201546e-04,   1.57594979e-02,
                         -6.02056505e-04,  -1.27839576e-03,   1.75347924e-03,
                         -1.02151404e-04,   2.27315468e-03,   5.73914556e-04,
                         -1.18163996e-03,   1.70846222e-04,   1.07421037e-02,
                          1.51166052e-03,   9.26286739e-04,   9.15884320e-03,
                          1.61522918e-03,  -1.59988261e-03,   4.87579359e-03,
                          4.90567647e-03,   7.75524604e-05,   5.40865911e-03,
                          7.31362915e-03,   8.41213949e-03,  -1.61054218e-03,
                         -1.88566570e-03,  -2.83949706e-03,   4.24218317e-03,
                         -2.62549659e-03,   1.34254538e-03,   2.69280444e-03,
                          8.90353043e-03,  -3.59304459e-03,   7.98925012e-03,
                          2.59576528e-03,   2.41120229e-04,  -1.23864273e-03,
                         -8.31950339e-04,  -1.06474943e-03,   7.16056908e-03,
                          3.18480365e-04,  -1.65498222e-03,   1.09307161e-02,
                          3.12343775e-03,  -1.07857138e-02,  -7.34728819e-05,
                          1.29700184e-03,  -3.86846182e-03,  -2.39952025e-03,
                          8.97314691e-04,  -7.85126258e-03,   1.00288866e-02,
                          7.01752072e-03,  -1.91236008e-03,  -2.83573149e-03,
                         -3.71335680e-03,   1.09084966e-02,   7.04846671e-03,
                          1.97139755e-03,  -9.30913011e-05,   1.36923976e-02,
                          2.24857591e-03,  -1.69882504e-03,   2.30339210e-04,
                          5.13898162e-03,   6.82291575e-04,  -7.08818948e-03,
                          6.91913534e-03,   8.26767366e-03,   1.74199976e-03,
                         -6.29095128e-04,   1.98430428e-03,   3.94118531e-03,
                          8.65128543e-03,  -1.99048955e-04,   1.26522570e-03,
                          8.49878183e-04,  -3.34629603e-03,   3.83041939e-03,
                          7.26529164e-04,   1.86542980e-03,   2.40989635e-03,
                         -8.31340905e-03,   1.79964025e-03,   5.37692336e-03,
                          5.92153193e-03,   1.22074515e-03,  -4.08060988e-03,
                          1.02435856e-03,   1.63954461e-03,  -2.17389851e-03,
                          5.20089408e-03,   4.45305603e-03,  -5.44066820e-03,
                         -1.61284010e-03,   1.01350471e-02,   1.27663440e-03,
                         -1.40033262e-02,  -7.43818283e-03,   1.11947246e-02,
                          4.74276673e-03,  -1.75486610e-03,  -2.00476311e-03,
                          5.24314772e-03,  -4.10799263e-03,  -7.22509343e-03,
                          7.53957499e-03,  -1.55217424e-01,   6.81524798e-02,
                          1.60771906e-01,  -1.71175301e-01,  -9.38377157e-02,
                          2.65554518e-01,  -1.34096416e-02,  -3.26490223e-01,
                          5.01467101e-02,   2.20261380e-01,  -8.10710192e-02,
                         -1.37213647e-01,   3.45162190e-02,   3.10216416e-02,
                          8.26436952e-02,  -9.20528825e-03,  -2.88345695e-01,
                          4.24881205e-02,   4.23902631e-01,  -1.98359460e-01,
                         -4.48117614e-01,   3.82600367e-01,   4.43323225e-01,
                         -5.09799719e-01,  -2.12905869e-01,   6.02322400e-01,
                         -9.10047516e-02,  -5.47155261e-01,   2.75794923e-01,
                          3.59878898e-01,  -3.00812095e-01,  -1.16232961e-01,
                          1.47043347e-01,   6.08971380e-02,   9.09556150e-02,
                         -2.89856523e-01,  -1.03479706e-01,   5.94483256e-01,
                         -1.65681317e-01,  -7.17501223e-01,   6.31392062e-01,
                          4.81149465e-01,  -8.91723633e-01,  -1.11857615e-01,
                          9.14758563e-01,  -2.12573290e-01,  -8.02893519e-01,
                          4.40895051e-01,   5.18449545e-01,  -4.38324153e-01,
                         -2.57497191e-01,   2.67236114e-01,   1.21876404e-01,
                          5.83641743e-03,  -1.25803754e-01,  -2.89462477e-01,
                          2.59424359e-01,   4.39144492e-01,  -4.80127901e-01,
                         -5.09769082e-01,   6.67881608e-01,   3.05163920e-01,
                         -7.81469822e-01,   1.06838867e-02,   7.41747975e-01,
                         -3.61483216e-01,  -6.07600272e-01,   4.69153970e-01,
                          2.94910461e-01,  -4.41773891e-01,  -2.09715590e-02,
                          2.56781310e-01,  -2.32785139e-02,  -5.39737605e-02,
                         -1.95502654e-01,   2.94074765e-03,   4.26371545e-01,
                         -3.15273196e-01,  -4.65995610e-01,   7.07860470e-01,
                          1.75072625e-01,  -9.28603947e-01,   1.89360723e-01,
                          8.62314522e-01,  -5.63856840e-01,  -6.32183492e-01,
                          6.84293032e-01,   2.86917090e-01,  -6.77650690e-01,
                         -9.28562433e-02,   4.68875438e-01,   1.93194812e-03,
                         -1.99648961e-01,  -1.05085731e-01,  -8.11126679e-02,
                          2.93576330e-01,   1.79725930e-01,  -5.74482203e-01,
                         -1.82285637e-01,   7.25276947e-01,  -8.71314667e-03,
                         -7.72451282e-01,   2.89104462e-01,   6.59726262e-01,
                         -5.59659421e-01,  -4.52765942e-01,   6.24109805e-01,
                          9.28454697e-02,  -5.75973809e-01,   1.46051437e-01,
                          3.30175549e-01,  -1.72583446e-01,  -1.29155606e-01,
                         -4.01948206e-02,   6.70216233e-02,   2.18781278e-01,
                         -3.74861598e-01,  -2.64822811e-01,   6.83464170e-01,
                         -1.45197622e-02,  -8.75675917e-01,   4.74264503e-01,
                          6.78328395e-01,  -8.24077547e-01,  -3.33513230e-01,
                          8.85503948e-01,   7.87854474e-03,  -8.03279281e-01,
                          1.66995242e-01,   5.46175599e-01,  -2.16628537e-01,
                         -2.80223161e-01,   6.54060096e-02,   8.56871977e-02,
                          1.70908943e-01,  -2.99230609e-02,  -4.76131976e-01,
                          9.18023512e-02,   6.44133091e-01,  -3.14207911e-01,
                         -6.91860735e-01,   5.02933502e-01,   5.35575390e-01,
                         -7.16786861e-01,  -2.11500168e-01,   7.37896383e-01,
                         -1.35255739e-01,  -5.99207282e-01,   3.27220559e-01,
                          3.13858837e-01,  -3.37163001e-01,  -9.33132246e-02,
                          1.52244642e-01,   5.49134985e-02,   7.33896941e-02,
                         -2.94642538e-01,  -7.94276521e-02,   5.82169473e-01,
                         -2.23306969e-01,  -6.77296221e-01,   6.72198296e-01,
                          4.24740106e-01,  -9.55909371e-01,  -1.73386082e-03,
                          9.20005083e-01,  -3.12564909e-01,  -7.73921907e-01,
                          4.79086757e-01,   4.46157306e-01,  -4.96543467e-01,
                         -2.27278054e-01,   2.95548707e-01,   1.07398652e-01,
                         -1.74045898e-02,  -1.38498679e-01,  -2.83957541e-01,
                          2.71061003e-01,   4.22477335e-01,  -5.11662185e-01,
                         -4.43527430e-01,   6.82191432e-01,   2.55304813e-01,
                         -7.86622465e-01,   7.08980560e-02,   7.61309862e-01,
                         -3.68110925e-01,  -5.88951051e-01,   5.11676490e-01,
                          2.29457691e-01,  -4.63894695e-01,   2.29221825e-02,
                          2.54157394e-01,  -5.84096983e-02,  -5.75443916e-02,
                         -1.70657083e-01,   4.51476686e-02,   4.21997637e-01,
                         -3.71836036e-01,  -4.42302257e-01,   7.36488700e-01,
                          1.37971133e-01,  -9.22930717e-01,   2.39287272e-01,
                          8.20064902e-01,  -6.00548029e-01,  -5.87618589e-01,
                          7.53925145e-01,   2.67349929e-01,  -6.86392486e-01,
                         -6.78844675e-02,   4.57369924e-01,  -3.27617787e-02,
                         -1.94700837e-01,  -9.41894129e-02,  -5.43361418e-02,
                          3.04378599e-01,   1.78356886e-01,  -5.62250912e-01,
                         -1.50648355e-01,   7.10944772e-01,  -8.67846757e-02,
                         -7.67299473e-01,   3.86152744e-01,   6.37493670e-01,
                         -6.28636360e-01,  -4.50699419e-01,   6.25820756e-01,
                          2.67724749e-02,  -5.99087894e-01,   1.59675226e-01,
                          2.94110149e-01,  -2.05243111e-01,  -1.22871816e-01,
                         -3.63113172e-02,   8.20170194e-02,   2.02296048e-01,
                         -3.97893906e-01,  -2.16390789e-01,   6.72694147e-01,
                         -1.30787373e-01,  -8.48707020e-01,   5.11755407e-01,
                          6.21697187e-01,  -8.97050917e-01,  -2.92660266e-01,
                          8.70437086e-01,  -4.58576977e-02,  -8.17577600e-01,
                          1.97928280e-01,   5.01682341e-01,  -2.68381119e-01,
                         -2.87215531e-01,   6.19255528e-02,   6.92047849e-02,
                          1.59901366e-01,  -7.99333528e-02,  -4.94906753e-01,
                          1.19235799e-01,   5.84983110e-01,  -3.91798586e-01,
                         -6.40625536e-01,   5.74064970e-01,   4.42494005e-01,
                         -7.79374421e-01,  -1.77203521e-01,   7.37674952e-01,
                         -2.25956544e-01,  -6.33347273e-01,   3.25427175e-01,
                          3.03512543e-01,  -3.71541053e-01,  -1.05690092e-01,
                          1.01620547e-01,   2.65325382e-02,   4.10382897e-02,
                         -3.38199943e-01,  -8.12940001e-02,   5.64499080e-01,
                         -3.30043703e-01,  -6.59964800e-01,   6.91597462e-01,
                          2.95331568e-01,  -9.72564697e-01,   1.21005224e-02,
                          8.99473965e-01,  -3.93395722e-01,  -7.56550074e-01,
                          5.36702037e-01,   3.91452640e-01,  -5.23574293e-01,
                         -2.30477944e-01,   2.72921532e-01,   7.11530000e-02,
                         -3.48603129e-02,  -1.73370376e-01,  -2.88944036e-01,
                          2.96143740e-01,   3.45910937e-01,  -5.81405818e-01,
                         -3.85493457e-01,   7.38953054e-01,   1.45693719e-01,
                         -8.46079171e-01,   1.21570311e-01,   6.95442855e-01,
                         -4.61001545e-01,  -5.38326025e-01,   5.22044361e-01,
                          1.82921275e-01,  -4.82692033e-01,   2.49465350e-02,
                          2.27286234e-01,  -6.89620674e-02,  -8.84847790e-02,
                         -2.03057408e-01,   5.15112430e-02,   3.88306469e-01,
                         -4.17425543e-01,  -4.14880335e-01,   7.59672105e-01,
                          1.87325887e-02,  -9.28669691e-01,   3.16070259e-01,
                          7.95397043e-01,  -6.68263972e-01,  -5.11850476e-01,
                          7.68597543e-01,   1.59735516e-01,  -7.08848894e-01,
                         -1.54505540e-02,   4.65437949e-01,  -5.56092449e-02,
                         -2.14047581e-01,  -9.83458981e-02,  -4.88057137e-02,
                          3.06581825e-01,   1.11801177e-01,  -5.83481610e-01,
                         -8.60016942e-02,   7.07297981e-01,  -1.61302328e-01,
                         -7.78245568e-01,   4.09661114e-01,   6.34222448e-01,
                         -6.34672523e-01,  -3.38061988e-01,   6.60110533e-01,
                         -3.76574360e-02,  -5.59643865e-01,   2.26022288e-01,
                          3.06097239e-01,  -2.11131021e-01,  -1.20410681e-01,
                         -2.08324175e-02,   1.10004909e-01,   2.02800691e-01,
                         -4.02305275e-01,  -1.81070477e-01,   6.99188530e-01,
                         -1.50983512e-01,  -7.77624846e-01,   5.74091494e-01,
                          5.40465891e-01,  -8.60130548e-01,  -1.69962868e-01,
                          8.99525464e-01,  -7.53355101e-02,  -7.62514353e-01,
                          2.99425632e-01,   5.00692189e-01,  -2.83781052e-01,
                         -2.34550908e-01,   1.07068889e-01,   1.12453356e-01,
                          1.85672998e-01,  -6.73114881e-02,  -4.41560060e-01,
                          2.08298802e-01,   6.03963315e-01,  -4.31088716e-01,
                         -5.42048216e-01,   6.82771802e-01,   4.46764499e-01,
                         -7.26670742e-01,  -3.95011418e-02,   7.94475555e-01,
                         -2.18172878e-01,  -4.98305976e-01,   4.54066515e-01,
                          2.88071841e-01,  -3.28483582e-01,  -4.93077142e-03,
                          1.84255853e-01,   8.98337215e-02,   8.13514888e-02,
                         -2.70218521e-01,   3.29348445e-02,   6.00280881e-01,
                         -2.97151297e-01,  -5.51216066e-01,   8.08807254e-01,
                          3.24609727e-01,  -8.91725242e-01,   1.21189989e-01,
                          9.63587642e-01,  -4.26322013e-01,  -6.17918670e-01,
                          6.55055940e-01,   4.32265222e-01,  -4.99769688e-01,
                         -1.08569749e-01,   3.62396121e-01,   1.34892017e-01,
                          2.15426888e-02,  -1.23508207e-01,  -1.82101235e-01,
                          3.95563722e-01,   3.92731816e-01,  -5.27722836e-01,
                         -2.76631147e-01,   8.01139891e-01,   1.41229302e-01,
                         -7.74903953e-01,   2.81995714e-01,   7.71701157e-01,
                         -4.05976444e-01,  -4.18873757e-01,   6.20997548e-01,
                          1.61655247e-01,  -4.39548999e-01,   1.36900693e-01,
                          2.97915936e-01,  -1.11962836e-02,  -1.11862924e-02,
                         -1.09737799e-01,   1.50078565e-01,   4.34243739e-01,
                         -3.87486041e-01,  -2.68932521e-01,   8.23310018e-01,
                          5.46832122e-02,  -8.63310039e-01,   4.49982345e-01,
                          8.10903013e-01,  -7.08587289e-01,  -3.76746804e-01,
                          8.94654036e-01,   1.30369440e-01,  -6.44723713e-01,
                          7.02734515e-02,   5.21999896e-01,  -1.16785439e-02,
                         -1.58931598e-01,  -2.25892272e-02,   3.81893367e-02,
                          3.71584088e-01,   1.27904743e-01,  -5.56683660e-01,
                          3.08905691e-02,   7.89561450e-01,  -1.65296450e-01,
                         -6.75941765e-01,   5.24085760e-01,   6.24157310e-01,
                         -5.95505178e-01,  -2.30998442e-01,   7.20119715e-01,
                         -3.36978771e-02,  -5.21407843e-01,   3.07427257e-01,
                          3.52618486e-01,  -1.73018411e-01,  -3.34422700e-02,
                          4.57310081e-02,   1.57960773e-01,   2.25905120e-01,
                         -3.76817048e-01,  -6.77957833e-02,   7.46406853e-01,
                         -1.86905727e-01,  -7.27368772e-01,   7.21322417e-01,
                          5.35879493e-01,  -8.70167494e-01,  -8.67130160e-02,
                          9.44886625e-01,  -1.27955392e-01,  -7.32454717e-01,
                          3.85681003e-01,   5.32492340e-01,  -2.85047382e-01,
                         -1.92662641e-01,   1.62303224e-01,   1.34893104e-01,
                          2.06724748e-01,  -7.95477107e-02,  -3.96239847e-01,
                          2.72108167e-01,   6.02744937e-01,  -4.71218556e-01,
                         -5.35675526e-01,   6.91710055e-01,   3.76263499e-01,
                         -7.39453435e-01,   3.24328132e-02,   7.52699375e-01,
                         -3.14846039e-01,  -5.25885403e-01,   4.45902795e-01,
                          2.79396296e-01,  -3.32889497e-01,   1.85458902e-02,
                          1.78977996e-01,   5.09067997e-02,   5.32377362e-02,
                         -2.87738293e-01,   3.89792174e-02,   5.71673036e-01,
                         -3.63830805e-01,  -4.68512297e-01,   7.78649628e-01,
                          2.06641063e-01,  -9.26486135e-01,   2.02005401e-01,
                          8.99279654e-01,  -5.02517819e-01,  -6.14222765e-01,
                          6.40147090e-01,   3.27343166e-01,  -5.37609339e-01,
                         -1.10298954e-01,   3.51348251e-01,   8.43528658e-02,
                         -2.31963955e-02,  -1.54362679e-01,  -2.02412590e-01,
                          3.90028119e-01,   3.08187962e-01,  -6.07740700e-01,
                         -2.36822918e-01,   7.89891839e-01,   4.67931665e-02,
                         -7.66321421e-01,   2.98594087e-01,   6.64048731e-01,
                         -5.24959326e-01,  -4.05611038e-01,   6.03987634e-01,
                          8.94973427e-02,  -4.77937847e-01,   1.44545421e-01,
                          2.59827763e-01,  -6.12070002e-02,  -6.59285933e-02,
                         -1.59871727e-01,   1.30520165e-01,   3.41209948e-01,
                         -4.56714809e-01,  -2.67152190e-01,   7.79216170e-01,
                         -2.57644746e-02,  -9.16288137e-01,   5.13678491e-01,
                          7.04100132e-01,  -8.00745249e-01,  -3.28725666e-01,
                          8.46047461e-01,   5.23009486e-02,  -7.10202932e-01,
                          1.08352356e-01,   4.56902504e-01,  -9.79348496e-02,
                         -1.73904017e-01,  -6.52945861e-02,   2.82680290e-03,
                          3.21323305e-01,   5.27650416e-02,  -5.69152117e-01,
                          4.40601856e-02,   7.33478010e-01,  -2.78213322e-01,
                         -7.32753813e-01,   5.02813697e-01,   5.25605500e-01,
                         -6.88547134e-01,  -1.78118914e-01,   7.11130619e-01,
                         -1.32945254e-01,  -5.27677059e-01,   2.90679455e-01,
                          2.68448949e-01,  -2.48049349e-01,  -5.54944389e-02,
                          1.10573247e-02,   1.29380718e-01,   1.64690211e-01,
                         -4.27189618e-01,  -8.43442157e-02,   7.08007693e-01,
                         -2.83403188e-01,  -7.25242913e-01,   7.24767804e-01,
                          4.30512398e-01,  -9.56296802e-01,  -1.61862131e-02,
                          8.90819192e-01,  -2.61556268e-01,  -7.42042661e-01,
                          3.94605219e-01,   4.22091335e-01,  -3.60874593e-01,
                         -1.97937325e-01,   1.24991372e-01,   1.00451797e-01,
                          1.53552905e-01,  -1.34520724e-01,  -4.40201610e-01,
                          2.77299672e-01,   5.26859224e-01,  -5.20278275e-01,
                         -5.04052043e-01,   6.90373898e-01,   2.58227110e-01,
                         -7.71569014e-01,   6.45604208e-02,   7.37868607e-01,
                         -3.74236822e-01,  -5.31411290e-01,   4.59513664e-01,
                          1.72902450e-01,  -3.80662173e-01,   1.92380305e-02,
                          1.34184077e-01,   3.56750414e-02,   6.70275558e-03,
                         -3.24650347e-01,   7.25368187e-02,   5.30831218e-01,
                         -4.69746619e-01,  -4.58052516e-01,   7.94434965e-01,
                          1.21454537e-01,  -9.36196804e-01,   2.21773818e-01,
                          8.08461666e-01,  -5.78090847e-01,  -5.81645727e-01,
                          6.59426868e-01,   2.65552580e-01,  -5.69535971e-01,
                         -1.28373429e-01,   3.18417132e-01,   3.12141012e-02,
                         -6.56480640e-02,  -1.86890438e-01,  -1.89353243e-01,
                          3.87339979e-01,   2.79796511e-01,  -6.32848382e-01,
                         -2.32188329e-01,   7.47604966e-01,  -6.12333417e-02,
                         -7.98218668e-01,   3.71143013e-01,   5.97478330e-01,
                         -6.13121390e-01,  -4.27942693e-01,   5.72669089e-01,
                          1.47647290e-02,  -5.26610255e-01,   1.23327941e-01,
                          1.96863592e-01,  -1.10799313e-01,  -8.81352723e-02,
                         -1.86806515e-01,   1.30081534e-01,   2.76797116e-01,
                         -5.01833618e-01,  -2.46110797e-01,   7.57571697e-01,
                         -1.67506173e-01,  -8.89475822e-01,   5.29651761e-01,
                          6.08253121e-01,  -8.78998458e-01,  -3.08405787e-01,
                          8.02665949e-01,  -1.05700130e-02,  -7.53504276e-01,
                          1.14470795e-01,   3.98388594e-01,  -1.51511416e-01,
                         -2.18546897e-01,  -9.26619992e-02,  -3.11377039e-03,
                          2.88016796e-01,  -3.20761390e-02,  -6.10782921e-01,
                          6.69142380e-02,   6.40448391e-01,  -3.80503088e-01,
                         -6.86234117e-01,   5.55730581e-01,   4.52344179e-01,
                         -7.80716181e-01,  -1.75249889e-01,   6.87593400e-01,
                         -2.19132781e-01,  -5.89722455e-01,   2.75897950e-01,
                          2.18320146e-01,  -2.74825722e-01,  -1.02402672e-01,
                         -2.36145277e-02,   1.05626352e-01,   9.76385176e-02,
                         -4.65657413e-01,  -8.01230520e-02,   6.57907367e-01,
                         -4.00997370e-01,  -7.07760692e-01,   7.40224361e-01,
                          2.85547584e-01,  -9.89774346e-01,  -5.48107922e-03,
                          8.59069586e-01,  -3.45910132e-01,  -7.27635503e-01,
                          4.29594606e-01,   3.65047872e-01,  -4.16461378e-01,
                         -2.25433737e-01,   9.26063508e-02,   8.37912261e-02,
                          1.01729244e-01,  -1.97154328e-01,  -4.36161280e-01,
                          2.99237609e-01,   4.47257876e-01,  -5.97041965e-01,
                         -4.64338422e-01,   7.39662290e-01,   1.63506985e-01,
                         -8.46819639e-01,   9.21132118e-02,   6.60835981e-01,
                         -4.35400754e-01,  -5.10069370e-01,   4.53971386e-01,
                          1.35444582e-01,  -4.18836266e-01,   7.78413704e-03,
                          1.17239147e-01,   4.62675700e-03,  -3.46625783e-02,
                         -3.57883036e-01,   7.96784386e-02,   4.82778996e-01,
                         -5.30260801e-01,  -4.50022250e-01,   8.33460987e-01,
                         -1.64887104e-02,  -9.69259679e-01,   3.23874295e-01,
                          7.85719573e-01,  -6.60600960e-01,  -4.98416066e-01,
                          6.69699311e-01,   1.65469781e-01,  -5.98406732e-01,
                         -9.17139798e-02,   3.19886118e-01,   9.74747725e-03,
                         -7.06504434e-02,  -2.06581771e-01,  -1.74174935e-01,
                          3.72507483e-01,   2.13273868e-01,  -6.60336554e-01,
                         -1.60731986e-01,   7.17428923e-01,  -1.41978770e-01,
                         -8.15238893e-01,   3.83646399e-01,   6.20363712e-01,
                         -6.24117196e-01,  -3.31291258e-01,   6.01159453e-01,
                         -4.96884622e-02,  -4.98880744e-01,   1.71642154e-01,
                          2.05982238e-01,  -1.12105496e-01,  -9.37553346e-02,
                         -1.63897052e-01,   1.63009793e-01,   2.76086122e-01,
                         -5.40007830e-01,  -1.88471690e-01,   7.80014992e-01,
                         -2.08858088e-01,  -8.31789553e-01,   5.93418717e-01,
                          5.30389130e-01,  -8.82033348e-01,  -1.86222687e-01,
                          8.41711164e-01,  -5.12743630e-02,  -7.03594327e-01,
                          1.97659552e-01,   4.09588337e-01,  -1.71927363e-01,
                         -1.79365128e-01,  -5.61601594e-02,   2.73203515e-02,
                          3.27750593e-01,  -2.95869373e-02,  -5.73346734e-01,
                          1.57127991e-01,   6.67380810e-01,  -4.36691284e-01,
                         -6.00791872e-01,   6.66662872e-01,   4.47567642e-01,
                         -7.07549930e-01,  -5.70296273e-02,   7.33348548e-01,
                         -2.01900125e-01,  -4.58132923e-01,   3.66500169e-01,
                          2.25177482e-01,  -2.34144077e-01,  -2.28197481e-02,
                          6.31664619e-02,   1.64079502e-01,   1.36846840e-01,
                         -4.22083110e-01,   5.48808537e-02,   6.97070062e-01,
                         -3.96599293e-01,  -5.99070668e-01,   8.63458276e-01,
                          2.84765989e-01,  -9.13473010e-01,   1.13221340e-01,
                          9.26226199e-01,  -3.97761911e-01,  -6.06732488e-01,
                          5.48852742e-01,   4.02572155e-01,  -3.69878858e-01,
                         -1.41598731e-01,   1.92914113e-01,   1.35677472e-01,
                          1.76139995e-01,  -1.58642173e-01,  -3.29000801e-01,
                          4.11547273e-01,   4.82314676e-01,  -5.60441017e-01,
                         -3.54070216e-01,   7.95885026e-01,   1.50527909e-01,
                         -7.76530981e-01,   2.50157058e-01,   7.38634408e-01,
                         -3.88510585e-01,  -3.89261156e-01,   5.38924277e-01,
                          1.36203289e-01,  -3.58352512e-01,   9.06461030e-02,
                          1.90770954e-01,   7.65316933e-02,   2.83212867e-02,
                         -2.67068565e-01,   1.94270849e-01,   5.26931763e-01,
                         -5.12395978e-01,  -3.01747888e-01,   9.02611494e-01,
                          1.43213412e-02,  -8.86008322e-01,   4.50173736e-01,
                          7.89114058e-01,  -6.77912772e-01,  -3.87596160e-01,
                          8.00651729e-01,   1.76716685e-01,  -5.55012763e-01,
                         -5.08914643e-04,   3.85304391e-01,   5.95154352e-02,
                         -1.61407311e-02,  -1.47380516e-01,  -9.01616886e-02,
                          4.62291718e-01,   2.08893225e-01,  -6.42193556e-01,
                         -3.79595570e-02,   8.25889647e-01,  -1.44996211e-01,
                         -7.03649223e-01,   5.01111865e-01,   6.07713580e-01,
                         -5.81364691e-01,  -2.23911107e-01,   6.56974316e-01,
                         -4.49573882e-02,  -4.37679440e-01,   2.47338757e-01,
                          2.60089844e-01,  -6.58373386e-02,  -2.16122232e-02,
                         -1.08168088e-01,   2.31817335e-01,   3.18280309e-01,
                         -5.26574194e-01,  -5.93166687e-02,   8.32604408e-01,
                         -2.55711943e-01,  -7.53504217e-01,   7.41384625e-01,
                          5.16187131e-01,  -8.46455336e-01,  -9.81984809e-02,
                          8.70290875e-01,  -8.11444148e-02,  -6.56028032e-01,
                          2.76090622e-01,   4.54985321e-01,  -1.51383132e-01,
                         -1.39407218e-01,   2.07056262e-04,   7.59112686e-02,
                          3.52879912e-01,  -5.17172776e-02,  -5.30358434e-01,
                          2.39853814e-01,   6.66864157e-01,  -4.50256407e-01,
                         -6.15358353e-01,   6.83413565e-01,   3.76452535e-01,
                         -7.20895290e-01,   2.93433871e-02,   6.92038834e-01,
                         -3.03912431e-01,  -4.65863258e-01,   3.76419216e-01,
                          2.18278199e-01,  -2.21855149e-01,  -5.08696958e-03,
                          3.20436433e-02,   1.62992939e-01,   9.81002897e-02,
                         -4.45329040e-01,   6.56957999e-02,   6.52756751e-01,
                         -4.43310887e-01,  -5.14306426e-01,   8.41369271e-01,
                          1.72578871e-01,  -9.36557412e-01,   1.98954776e-01,
                          8.50079119e-01,  -4.49429929e-01,  -5.98343134e-01,
                          5.38013458e-01,   3.08857679e-01,  -4.11776453e-01,
                         -1.40688926e-01,   1.80797875e-01,   1.03685565e-01,
                          1.32395148e-01,  -2.00749174e-01,  -3.50202709e-01,
                          4.28774983e-01,   4.05482113e-01,  -6.50094092e-01,
                         -3.06769997e-01,   7.79093683e-01,   7.23483339e-02,
                         -7.58944392e-01,   2.80312717e-01,   6.33263528e-01,
                         -5.13371110e-01,  -3.82676750e-01,   5.37116408e-01,
                          6.43205270e-02,  -3.78688276e-01,   8.62038806e-02,
                          1.54003561e-01,   3.85437645e-02,  -3.09397578e-02,
                         -3.05625498e-01,   1.72884434e-01,   4.36435461e-01,
                         -5.87984622e-01,  -2.85521746e-01,   8.61791790e-01,
                         -6.34642765e-02,  -9.44682896e-01,   5.19819617e-01,
                          6.77888334e-01,  -7.69689679e-01,  -3.32353503e-01,
                          7.50806391e-01,   7.78505206e-02,  -5.97069621e-01,
                          1.76174175e-02,   3.30394447e-01,   2.22552591e-03,
                         -6.89985156e-02,  -1.86352804e-01,  -1.11475177e-01,
                          4.34453487e-01,   1.35630727e-01,  -6.67952597e-01,
                         -1.38024045e-02,   7.81415939e-01,  -2.75678247e-01,
                         -7.47801244e-01,   4.78655487e-01,   5.23327470e-01,
                         -6.60952032e-01,  -1.75005585e-01,   6.32674992e-01,
                         -1.23630181e-01,  -4.52408731e-01,   2.29341075e-01,
                          1.70819491e-01,  -1.17653966e-01,  -5.63685521e-02,
                         -1.39507353e-01,   2.01546580e-01,   2.38500357e-01,
                         -5.64392328e-01,  -6.21438362e-02,   7.88103819e-01,
                         -3.46841037e-01,  -7.50222325e-01,   7.53133595e-01,
                          4.13729757e-01,  -9.54580426e-01,  -2.52395459e-02,
                          8.28373849e-01,  -2.03006089e-01,  -6.70618355e-01,
                          2.82667905e-01,   3.49277258e-01,  -2.27220267e-01,
                         -1.49826661e-01,  -4.18201536e-02,   5.37030585e-02,
                          3.13067198e-01,  -1.18025459e-01,  -5.62169194e-01,
                          2.59973735e-01,   6.04996443e-01,  -5.09369373e-01,
                         -5.64404786e-01,   6.79763973e-01,   2.73785502e-01,
                         -7.58880973e-01,   5.77796102e-02,   6.82921886e-01,
                         -3.35733473e-01,  -4.80936646e-01,   3.81579965e-01,
                          1.30799368e-01,  -2.58256346e-01,  -1.45667838e-02,
                          1.82491429e-02,   1.38899922e-01,   5.79913929e-02,
                         -4.61862415e-01,   1.10307112e-01,   6.24445021e-01,
                         -5.62664211e-01,  -4.86528397e-01,   8.72745931e-01,
                          9.09641162e-02,  -9.47124898e-01,   2.23367035e-01,
                          7.77949750e-01,  -5.13983548e-01,  -5.64530313e-01,
                          5.57575464e-01,   2.63717413e-01,  -4.46434677e-01,
                         -1.38472512e-01,   1.59133106e-01,   8.13611746e-02,
                          1.01363868e-01,  -2.48913571e-01,  -3.20282817e-01,
                          4.42432523e-01,   3.96155417e-01,  -6.64505899e-01,
                         -2.82045633e-01,   7.52387404e-01,  -3.19299996e-02,
                         -7.78786659e-01,   3.41394335e-01,   5.91675997e-01,
                         -5.73632896e-01,  -3.92180145e-01,   5.07920623e-01,
                          9.37549584e-03,  -4.02673930e-01,   7.70491883e-02,
                          1.17583662e-01,   4.73560998e-03,  -6.84948340e-02,
                         -2.93465912e-01,   1.98576823e-01,   3.77192289e-01,
                         -6.16096437e-01,  -2.37196520e-01,   8.52692723e-01,
                         -1.98226526e-01,  -9.00029242e-01,   5.46029091e-01,
                          6.20525062e-01,  -8.32726061e-01,  -3.17692369e-01,
                          7.40358293e-01,   4.71891388e-02,  -6.49691880e-01,
                          3.71144339e-02,   3.16115946e-01,  -4.05130684e-02,
                         -9.22106057e-02,  -2.12496415e-01,  -1.08862884e-01,
                          4.37161505e-01,   6.05903566e-02,  -7.00263619e-01,
                          3.01446151e-02,   7.01664567e-01,  -3.47168654e-01,
                         -6.97271168e-01,   5.50818980e-01,   4.46213126e-01,
                         -7.20549345e-01,  -1.51338920e-01,   6.28821075e-01,
                         -2.00572759e-01,  -4.80145961e-01,   2.23073110e-01,
                          1.61946520e-01,  -1.45402089e-01,  -8.27934220e-02,
                         -1.43756911e-01,   2.20145538e-01,   1.76916271e-01,
                         -5.86880922e-01,  -5.77088520e-02,   7.74724901e-01,
                         -4.45699155e-01,  -7.22703516e-01,   7.83786356e-01,
                          2.99470603e-01,  -9.57607925e-01,  -1.18510304e-02,
                          8.17946315e-01,  -2.63604552e-01,  -6.56643808e-01,
                          3.27660263e-01,   3.35446328e-01,  -2.64057040e-01,
                         -1.78080052e-01,  -5.81727475e-02,   6.96842596e-02,
                          2.88629830e-01,  -1.69175893e-01,  -5.63834488e-01,
                          3.10933620e-01,   5.52500427e-01,  -5.87122858e-01,
                         -4.97679263e-01,   7.47556627e-01,   1.90704852e-01,
                         -8.06178153e-01,   1.01698749e-01,   6.27164245e-01,
                         -3.98566693e-01,  -4.33338732e-01,   3.85714293e-01,
                          1.16725892e-01,  -2.86179304e-01,  -4.48915455e-03,
                          5.74344769e-03,   1.31888747e-01,   2.50571780e-02,
                         -4.72163558e-01,   1.22198880e-01,   5.84042072e-01,
                         -6.02479994e-01,  -4.44146186e-01,   9.03847992e-01,
                         -1.60099119e-02,  -9.50894713e-01,   3.10231090e-01,
                          7.72145212e-01,  -5.79401135e-01,  -4.79766876e-01,
                          5.85998237e-01,   1.93940639e-01,  -4.68011916e-01,
                         -1.04854003e-01,   1.79612309e-01,   9.58233774e-02,
                          7.44717941e-02,  -2.57531464e-01,  -2.91084081e-01,
                          4.41747576e-01,   3.36332381e-01,  -6.89295888e-01,
                         -2.14964747e-01,   7.60836184e-01,  -1.11497812e-01,
                         -7.98198819e-01,   3.72833103e-01,   6.14149213e-01,
                         -5.71685135e-01,  -2.96601534e-01,   5.34850657e-01,
                         -3.96333374e-02,  -3.91472191e-01,   1.31759018e-01,
                          1.33202821e-01,  -2.82341178e-04,  -4.89567295e-02,
                         -2.67873555e-01,   2.37295836e-01,   3.60864550e-01,
                         -6.37362480e-01,  -1.58306643e-01,   8.35666120e-01,
                         -2.24656567e-01,  -8.14562678e-01,   5.98267198e-01,
                          5.21386325e-01,  -8.04990947e-01,  -2.00213000e-01,
                          7.72408664e-01,   1.93061382e-02,  -6.00019872e-01,
                          1.05650440e-01,   3.32367063e-01,  -4.55653258e-02,
                         -7.77299181e-02,  -1.74804151e-01,  -6.11691400e-02,
                          4.69561011e-01,   5.90251982e-02,  -6.50622368e-01,
                          1.17643468e-01,   7.32186556e-01,  -3.98400694e-01,
                         -6.19113326e-01,   6.42662346e-01,   4.79467243e-01,
                         -6.66714609e-01,  -4.91066016e-02,   6.84930146e-01,
                         -1.82937577e-01,  -3.74627233e-01,   2.92013407e-01,
                          2.00328022e-01,  -1.25499234e-01,  -2.67208666e-02,
                         -6.14421703e-02,   2.88099021e-01,   1.97953030e-01,
                         -5.37803292e-01,   8.63353759e-02,   7.71834552e-01,
                         -4.48199332e-01,  -5.91538489e-01,   8.82903039e-01,
                          3.00692677e-01,  -8.84219289e-01,   8.42484310e-02,
                          8.89423728e-01,  -3.10283661e-01,  -5.60758650e-01,
                          4.43500310e-01,   3.70871753e-01,  -2.22764522e-01,
                         -1.12690732e-01,   2.51429714e-02,   1.42669111e-01,
                          3.31414670e-01,  -1.45058185e-01,  -4.41036373e-01,
                          4.06152159e-01,   5.84053934e-01,  -5.61963558e-01,
                         -3.95475239e-01,   7.99447656e-01,   1.75172210e-01,
                         -7.70622134e-01,   2.52646834e-01,   7.02627420e-01,
                         -3.42630684e-01,  -3.56696695e-01,   4.79706287e-01,
                          1.18028566e-01,  -2.26628676e-01,   4.62634489e-02,
                          8.24445561e-02,   2.02162102e-01,   8.37420598e-02,
                         -4.12071645e-01,   2.59543061e-01,   6.02957487e-01,
                         -5.89170396e-01,  -2.95396745e-01,   9.48330402e-01,
                          1.22236181e-02,  -8.92403066e-01,   4.28523809e-01,
                          7.80082226e-01,  -6.05106413e-01,  -3.79719883e-01,
                          7.14929640e-01,   1.88078925e-01,  -4.26402211e-01,
                         -3.47910114e-02,   2.42205173e-01,   1.39546931e-01,
                          1.29658818e-01,  -2.24749193e-01,  -2.14817509e-01,
                          5.42575300e-01,   3.11476469e-01,  -6.88760459e-01,
                         -9.42061543e-02,   8.54509115e-01,  -1.26642659e-01,
                         -6.99469864e-01,   4.97156173e-01,   5.82925439e-01,
                         -5.48000336e-01,  -1.96882382e-01,   6.00115597e-01,
                         -4.29371148e-02,  -3.32801074e-01,   1.80521160e-01,
                          1.93536490e-01,   5.39632104e-02,  -2.02395320e-02,
                         -2.39557371e-01,   3.23703945e-01,   3.80451649e-01,
                         -6.25406802e-01,  -5.25105782e-02,   9.01271403e-01,
                         -2.83651888e-01,  -7.70899415e-01,   7.56117880e-01,
                          5.08780837e-01,  -8.16044211e-01,  -1.16041347e-01,
                          8.16649556e-01,  -2.76838187e-02,  -5.60621619e-01,
                          1.75355896e-01,   3.60340893e-01,  -2.51752734e-02,
                         -4.39683162e-02,  -1.42424181e-01,  -9.42537282e-03,
                          4.91707265e-01,   5.06403111e-03,  -6.41452372e-01,
                          2.11453199e-01,   7.07326889e-01,  -4.42277849e-01,
                         -6.31386101e-01,   6.65782213e-01,   3.70735049e-01,
                         -6.97582722e-01,   2.77195834e-02,   6.38270736e-01,
                         -2.75115430e-01,  -3.92174691e-01,   2.98681170e-01,
                          1.63623467e-01,  -1.06485277e-01,  -4.69149761e-02,
                         -8.67906362e-02,   2.71166444e-01,   1.28204226e-01,
                         -5.72260737e-01,   9.84190926e-02,   7.17591643e-01,
                         -5.08658111e-01,  -5.27666450e-01,   8.60511363e-01,
                          1.52826801e-01,  -9.22575176e-01,   1.67585790e-01,
                          8.10516238e-01,  -3.88596773e-01,  -5.67657471e-01,
                          4.29543853e-01,   2.79387742e-01,  -2.79323578e-01,
                         -1.22866370e-01,   4.16107755e-03,   9.80316624e-02,
                          2.83124566e-01,  -2.15844303e-01,  -4.77036864e-01,
                          4.33274567e-01,   4.71344799e-01,  -6.61192298e-01,
                         -3.68361205e-01,   7.82672524e-01,   8.81908461e-02,
                         -7.68842578e-01,   2.70381510e-01,   5.90810418e-01,
                         -4.75333869e-01,  -3.52184623e-01,   4.59566742e-01,
                          3.92792746e-02,  -2.81489521e-01,   2.67828088e-02,
                          5.06163575e-02,   1.50670767e-01,  -1.16699096e-02,
                         -4.45872724e-01,   2.37241656e-01,   4.86644775e-01,
                         -6.87620997e-01,  -2.87624508e-01,   8.96580875e-01,
                         -7.99561292e-02,  -9.53244627e-01,   4.91268784e-01,
                          6.59549832e-01,  -7.17728376e-01,  -3.54518801e-01,
                          6.61294878e-01,   9.91807058e-02,  -4.91514832e-01,
                         -4.49395217e-02,   1.95541427e-01,   6.98913783e-02,
                          3.59591953e-02,  -2.70306170e-01,  -2.43118107e-01,
                          4.95587468e-01,   2.34248966e-01,  -7.29042292e-01,
                         -7.70813525e-02,   8.08830142e-01,  -2.67399967e-01,
                         -7.64612973e-01,   4.51046884e-01,   5.01633346e-01,
                         -6.31423771e-01,  -1.67237550e-01,   5.63075960e-01,
                         -1.27775639e-01,  -3.69500816e-01,   1.42360508e-01,
                          9.93463397e-02,  -9.61869198e-04,  -9.91418809e-02,
                         -2.58802027e-01,   2.95402318e-01,   2.72400916e-01,
                         -6.86380148e-01,  -5.28728403e-02,   8.40551317e-01,
                         -3.93760651e-01,  -7.56859362e-01,   7.44276762e-01,
                          3.91541988e-01,  -9.18651164e-01,  -5.71529046e-02,
                          7.54670203e-01,  -1.52630821e-01,  -6.09897077e-01,
                          1.72318414e-01,   2.79624224e-01,  -9.84861925e-02,
                         -1.02022879e-01,  -1.95672825e-01,  -7.40659935e-03,
                          4.41362858e-01,  -8.14902261e-02,  -6.71566904e-01,
                          2.21995935e-01,   6.59392595e-01,  -5.14997602e-01,
                         -5.91418326e-01,   6.60490274e-01,   2.68014461e-01,
                         -7.53583968e-01,   6.51607513e-02,   6.07833147e-01,
                         -3.13710898e-01,  -4.16812390e-01,   2.90674806e-01,
                          9.28855911e-02,  -1.50849208e-01,  -7.85890445e-02,
                         -8.40283707e-02,   2.52906144e-01,   7.71584138e-02,
                         -5.92930675e-01,   1.47499204e-01,   6.83140397e-01,
                         -6.39472306e-01,  -4.87359822e-01,   8.77260864e-01,
                          8.13402310e-02,  -9.37965572e-01,   1.95472404e-01,
                          7.37484217e-01,  -4.47551697e-01,  -5.53770959e-01,
                          4.35289294e-01,   2.50487834e-01,  -3.10382128e-01,
                         -1.41032219e-01,  -1.34527450e-02,   8.55644494e-02,
                          2.53097773e-01,  -2.71364659e-01,  -4.41954464e-01,
                          4.52602208e-01,   4.88251597e-01,  -6.90513611e-01,
                         -3.23059767e-01,   7.57495582e-01,  -2.88736075e-02,
                         -7.76930749e-01,   3.32712561e-01,   5.45458376e-01,
                         -5.36751390e-01,  -3.45156044e-01,   4.39271301e-01,
                         -3.99200292e-03,  -2.96980679e-01,   2.10818183e-02,
                          2.65530683e-02,   1.39257073e-01,  -6.54369146e-02,
                         -4.28239703e-01,   2.75887609e-01,   4.40026879e-01,
                         -7.02450156e-01,  -2.20601976e-01,   8.88612986e-01,
                         -2.26293281e-01,  -8.94099653e-01,   5.33890128e-01,
                          6.06796920e-01,  -7.72936463e-01,  -3.25987786e-01,
                          6.53287709e-01,   8.08539391e-02,  -5.23603499e-01,
                         -2.74116509e-02,   1.68972030e-01,   6.60598874e-02,
                          3.12794670e-02,  -3.11747402e-01,  -2.03294992e-01,
                          5.23688614e-01,   1.40947014e-01,  -7.58679569e-01,
                         -2.02061161e-02,   7.51515388e-01,  -3.42576087e-01,
                         -6.97842836e-01,   5.35377324e-01,   4.37397391e-01,
                         -6.87223375e-01,  -1.29015982e-01,   5.60981095e-01,
                         -1.89104825e-01,  -3.82332385e-01,   1.51581094e-01,
                          9.98169407e-02,  -1.26958778e-02,  -9.87862647e-02,
                         -2.60865897e-01,   3.31332147e-01,   2.33284444e-01,
                         -7.06466436e-01,  -2.73933094e-02,   8.39469314e-01,
                         -4.90520835e-01,  -7.07059622e-01,   7.85457969e-01,
                          2.97918588e-01,  -9.12426233e-01,  -5.24106026e-02,
                          7.79113531e-01,  -1.95522785e-01,  -5.89804113e-01,
                          2.24349171e-01,   2.68007994e-01,  -1.12144805e-01,
                         -1.11530118e-01,  -2.00761184e-01,   4.98143723e-04,
                          4.35482562e-01,  -1.19981684e-01,  -6.72711074e-01,
                          2.98938155e-01,   6.18275404e-01,  -5.75006902e-01,
                         -5.24631977e-01,   7.37201989e-01,   2.09012017e-01,
                         -7.76828051e-01,   1.01061195e-01,   5.67785859e-01,
                         -3.54783922e-01,  -3.65022510e-01,   3.19052964e-01,
                          8.15396830e-02,  -1.63819611e-01,  -6.56357706e-02,
                         -8.49158615e-02,   2.62309283e-01,   6.43444508e-02,
                         -6.07233226e-01,   1.90098420e-01,   6.47382855e-01,
                         -6.68051720e-01,  -4.35490489e-01,   9.24425364e-01,
                         -2.69593559e-02,  -9.27130699e-01,   2.85676569e-01,
                          7.57516742e-01,  -4.99347687e-01,  -4.75971162e-01,
                          4.87128675e-01,   2.07032621e-01,  -3.25020999e-01,
                         -1.18721873e-01,   8.39438289e-03,   1.21613555e-01,
                          2.50345647e-01,  -2.89949715e-01,  -4.22143489e-01,
                          4.84286606e-01,   4.29919779e-01,  -7.06364214e-01,
                         -2.66048074e-01,   7.85854161e-01,  -9.81410518e-02,
                         -7.75508642e-01,   3.52026790e-01,   5.67602277e-01,
                         -5.08757353e-01,  -2.49672920e-01,   4.50321466e-01,
                         -2.70043220e-02,  -2.86649197e-01,   5.07050455e-02,
                          5.78649156e-02,   1.52261898e-01,  -6.61447048e-02,
                         -3.97478580e-01,   3.41362357e-01,   4.17237073e-01,
                         -7.31357932e-01,  -1.49496734e-01,   9.03357387e-01,
                         -2.50732690e-01,  -8.12488854e-01,   5.89153409e-01,
                          5.20709038e-01,  -7.51410544e-01,  -2.13430285e-01,
                          6.90408468e-01,   5.90821207e-02,  -4.86551166e-01,
                          4.41870354e-02,   1.95023194e-01,   7.67270699e-02,
                          3.79505865e-02,  -2.93670624e-01,  -1.58892885e-01,
                          5.76055408e-01,   1.43807501e-01,  -7.16380000e-01,
                          7.93113485e-02,   7.69779086e-01,  -3.84753048e-01,
                         -6.22334778e-01,   6.35316908e-01,   4.56870615e-01,
                         -6.19627118e-01,  -2.82624606e-02,   5.98595560e-01,
                         -1.55353412e-01,  -2.94365853e-01,   2.16803879e-01,
                          1.44343019e-01,   1.66666731e-02,  -6.43469468e-02,
                         -1.83530077e-01,   4.18374717e-01,   2.29777202e-01,
                         -6.61436498e-01,   1.17626727e-01,   8.51431549e-01,
                         -4.97232497e-01,  -6.09107435e-01,   9.02589738e-01,
                          2.89767325e-01,  -8.57317507e-01,   6.53011650e-02,
                          8.46059799e-01,  -2.56422728e-01,  -4.92820174e-01,
                          3.35586756e-01,   3.12505335e-01,  -7.25901946e-02,
                         -6.04932159e-02,  -1.41146481e-01,   9.20930132e-02,
                          4.89508957e-01,  -1.11779548e-01,  -5.59654295e-01,
                          4.05228943e-01,   6.44647419e-01,  -5.56595922e-01,
                         -4.24792707e-01,   7.93676972e-01,   1.65063903e-01,
                         -7.16041803e-01,   2.46328712e-01,   6.44086778e-01,
                         -3.14424425e-01,  -2.90321946e-01,   3.84125441e-01,
                          1.04771160e-01,  -1.10795937e-01,  -1.58724412e-02,
                         -5.94313443e-03,   3.46014559e-01,   8.66377428e-02,
                         -5.48509061e-01,   3.33906263e-01,   6.66670978e-01,
                         -6.87961459e-01,  -2.74644524e-01,   9.83426750e-01,
                          1.99777816e-04,  -8.80625367e-01,   4.04948413e-01,
                          7.64410675e-01,  -5.39466560e-01,  -3.66813391e-01,
                          5.93023479e-01,   2.11153746e-01,  -2.78236032e-01,
                         -5.86936288e-02,   7.48825520e-02,   1.85605362e-01,
                          2.74923056e-01,  -2.73383945e-01,  -3.25797528e-01,
                          5.86168766e-01,   3.93412858e-01,  -7.16546297e-01,
                         -1.33612946e-01,   8.48038614e-01,  -1.09797463e-01,
                         -6.67363763e-01,   4.67524648e-01,   5.51740348e-01,
                         -5.02326071e-01,  -1.63932472e-01,   5.11587918e-01,
                         -1.87882148e-02,  -2.32447803e-01,   1.03439674e-01,
                          1.11802682e-01,   2.01872975e-01,  -4.91609015e-02,
                         -3.64965737e-01,   4.27673608e-01,   4.32275176e-01,
                         -7.44811952e-01,  -1.77414040e-03,   9.32486713e-01,
                         -3.09883833e-01,  -7.76613176e-01,   7.43827403e-01,
                          5.12536287e-01,  -7.53098130e-01,  -1.45066857e-01,
                          7.31994629e-01,   2.00446341e-02,  -4.57535923e-01,
                          9.59855989e-02,   2.43630946e-01,   9.83137563e-02,
                          5.36361784e-02,  -2.83125043e-01,  -8.56723860e-02,
                          5.89662850e-01,   7.34755322e-02,  -7.27998257e-01,
                          1.72419399e-01,   7.56913006e-01,  -4.38350916e-01,
                         -6.50024474e-01,   6.44700825e-01,   3.56437147e-01,
                         -6.57741785e-01,   3.51121835e-02,   5.67464173e-01,
                         -2.44666561e-01,  -3.23120773e-01,   2.11569071e-01,
                          1.15918495e-01,   2.02969797e-02,  -1.05586722e-01,
                         -2.01313823e-01,   3.94645840e-01,   1.36678547e-01,
                         -6.85601830e-01,   1.44759595e-01,   7.71941364e-01,
                         -5.76563835e-01,  -5.27911127e-01,   8.62189829e-01,
                          1.56114474e-01,  -9.02378559e-01,   1.32818058e-01,
                          7.57499397e-01,  -3.26144785e-01,  -5.04901528e-01,
                          2.94808507e-01,   2.39699557e-01,  -1.26586348e-01,
                         -1.00320011e-01,  -1.70489326e-01,   6.03838190e-02,
                          4.23367769e-01,  -1.98765472e-01,  -5.99082470e-01,
                          4.30379450e-01,   5.49991727e-01,  -6.90782785e-01,
                         -3.99581164e-01,   7.80664265e-01,   6.54645115e-02,
                         -7.28743374e-01,   2.48753175e-01,   5.34382045e-01,
                         -4.33019280e-01,  -3.02835137e-01,   3.60047251e-01,
                          2.73226295e-02,  -1.64063618e-01,  -6.27001002e-02,
                         -4.40864637e-02,   2.88829654e-01,  -2.06294805e-02,
                         -5.88282168e-01,   3.20687830e-01,   5.21419048e-01,
                         -7.78114080e-01,  -2.79031813e-01,   9.26975012e-01,
                         -1.23851493e-01,  -9.28193867e-01,   4.63662893e-01,
                          6.23155415e-01,  -6.46400213e-01,  -3.64542693e-01,
                          5.43694258e-01,   1.23221375e-01,  -3.56430173e-01,
                         -8.68140236e-02,   2.27481779e-02,   1.19668283e-01,
                          1.93184525e-01,  -3.54164779e-01,  -3.69502246e-01,
                          5.48415422e-01,   3.06944191e-01,  -7.72384226e-01,
                         -1.13835424e-01,   7.93732762e-01,  -2.48465896e-01,
                         -7.51319349e-01,   4.21679378e-01,   4.65485066e-01,
                         -5.96633255e-01,  -1.50690764e-01,   4.73353058e-01,
                         -1.08335868e-01,  -2.81377405e-01,   4.77868430e-02,
                          3.96783352e-02,   1.27493322e-01,  -1.29720837e-01,
                         -4.08349782e-01,   4.12809640e-01,   2.96478212e-01,
                         -8.01275313e-01,  -2.40451898e-02,   8.77482712e-01,
                         -4.24690396e-01,  -7.72201359e-01,   7.21286416e-01,
                          3.80110115e-01,  -8.64990413e-01,  -9.94249508e-02,
                          6.77859426e-01,  -1.00017153e-01,  -5.11161506e-01,
                          6.42685741e-02,   1.69534251e-01,   2.67825965e-02,
                         -9.76948440e-03,  -3.35611999e-01,  -1.12684056e-01,
                          5.67179441e-01,  -2.04161890e-02,  -7.67276108e-01,
                          1.96370691e-01,   6.99368536e-01,  -5.19015729e-01,
                         -6.11318350e-01,   6.38180792e-01,   2.51711309e-01,
                         -7.10180283e-01,   5.05765453e-02,   5.39951146e-01,
                         -2.85839111e-01,  -3.47992331e-01,   1.98318228e-01,
                          6.17342405e-02,  -2.82757115e-02,  -1.39331296e-01,
                         -2.02088758e-01,   3.93973291e-01,   8.61464888e-02,
                         -7.31245458e-01,   1.96872145e-01,   7.41081715e-01,
                         -6.98694348e-01,  -5.02515554e-01,   8.84989500e-01,
                          9.38019156e-02,  -9.26898122e-01,   1.62492231e-01,
                          6.89819574e-01,  -3.94831419e-01,  -4.94110703e-01,
                          3.19493026e-01,   2.02876270e-01,  -1.61670640e-01,
                         -1.27018675e-01,  -1.76974133e-01,   8.02868903e-02,
                          4.05704051e-01,  -2.77457714e-01,  -5.65863550e-01,
                          4.72844273e-01,   5.63850343e-01,  -6.86729610e-01,
                         -3.56770098e-01,   7.35022485e-01,  -2.31875982e-02,
                         -7.35135794e-01,   3.23147386e-01,   4.93471920e-01,
                         -4.88204658e-01,  -2.93970615e-01,   3.46298575e-01,
                          1.74273066e-02,  -1.72681928e-01,  -6.59518540e-02,
                         -5.08528911e-02,   2.73819983e-01,  -5.69752865e-02,
                         -5.71139395e-01,   3.91368359e-01,   4.90113467e-01,
                         -7.91491866e-01,  -2.00347096e-01,   9.22741830e-01,
                         -2.21146822e-01,  -8.85425627e-01,   4.98297185e-01,
                          6.04035676e-01,  -6.94831073e-01,  -3.19493294e-01,
                          5.54725707e-01,   1.02102727e-01,  -3.63047421e-01,
                         -8.14230964e-02,   2.72552613e-02,   1.40829816e-01,
                          1.80832520e-01,  -3.98486078e-01,  -3.13478798e-01,
                          6.06724441e-01,   2.35178426e-01,  -7.91012883e-01,
                         -5.64064719e-02,   7.46928513e-01,  -3.09321433e-01,
                         -6.79878354e-01,   5.19921720e-01,   4.09266025e-01,
                         -6.22116446e-01,  -1.07600078e-01,   4.75715399e-01,
                         -1.43520668e-01,  -2.77426034e-01,   5.89455888e-02,
                          4.97762598e-02,   1.44782424e-01,  -1.38517812e-01,
                         -3.56568336e-01,   4.54126060e-01,   2.70126581e-01,
                         -8.10681105e-01,   2.81314384e-02,   8.86798084e-01,
                         -5.25808692e-01,  -6.94707751e-01,   7.87228584e-01,
                          3.12568873e-01,  -8.66343498e-01,  -6.02572784e-02,
                          7.00663269e-01,  -1.34353146e-01,  -4.69671398e-01,
                          1.16735771e-01,   1.76692843e-01,   3.93862538e-02,
                         -9.63347126e-03,  -3.35539550e-01,  -7.92659223e-02,
                          5.69894910e-01,  -5.97749986e-02,  -7.38018751e-01,
                          2.71240920e-01,   6.63996458e-01,  -5.59168041e-01,
                         -5.13353229e-01,   7.23480225e-01,   1.88904822e-01,
                         -7.11701810e-01,   1.10571414e-01,   5.04719317e-01,
                         -3.15196127e-01,  -2.75840133e-01,   2.20192477e-01,
                          6.55218959e-02,  -1.44046126e-02,  -1.26258984e-01,
                         -1.71188578e-01,   3.94849539e-01,   7.07082674e-02,
                         -7.12334096e-01,   2.57465541e-01,   7.12897956e-01,
                         -7.35053837e-01,  -4.25311595e-01,   9.44689989e-01,
                         -9.17049497e-03,  -9.02019918e-01,   2.62597948e-01,
                          7.03506470e-01,  -4.07503814e-01,  -4.26712841e-01,
                          3.66934836e-01,   1.82970077e-01,  -1.61077306e-01,
                         -1.02100015e-01,  -1.45085156e-01,   1.26221225e-01,
                          4.08782721e-01,  -2.98904687e-01,  -5.42860210e-01,
                          5.20865858e-01,   4.92139310e-01,  -6.95989013e-01,
                         -2.76832491e-01,   7.67066538e-01,  -8.57331604e-02,
                         -7.45088160e-01,   3.54821026e-01,   5.27079463e-01,
                         -4.67161298e-01,  -1.94758534e-01,   3.62674743e-01,
                         -2.41614338e-02,  -1.53289661e-01,  -4.10160311e-02,
                         -1.10807493e-02,   3.01383764e-01,  -7.66385347e-02,
                         -5.11143565e-01,   4.55233127e-01,   4.62407559e-01,
                         -8.20635200e-01,  -1.32297203e-01,   9.39901114e-01,
                         -2.56785631e-01,  -8.08714509e-01,   5.73644042e-01,
                          5.18286645e-01,  -6.69896662e-01,  -2.21527085e-01,
                          5.82311630e-01,   9.49517861e-02,  -3.41389269e-01,
                         -2.85547432e-02,   6.07164800e-02,   1.69865862e-01,
                          1.72675535e-01,  -3.96430999e-01,  -2.54138708e-01,
                          6.57571495e-01,   2.23851770e-01,  -7.59642899e-01,
                          5.02344891e-02,   7.90979862e-01,  -3.65204930e-01,
                         -6.10856056e-01,   6.09411359e-01,   4.32958484e-01,
                         -5.60300767e-01,  -1.53986020e-02,   5.08284807e-01,
                         -1.17648683e-01,  -2.17038736e-01,   1.29656225e-01,
                          9.04394239e-02,   1.70574605e-01,  -1.26277521e-01,
                         -2.83473730e-01,   5.43638229e-01,   2.41170868e-01,
                         -7.66215742e-01,   1.66870862e-01,   8.85320365e-01,
                         -5.26802182e-01,  -6.08450055e-01,   8.92524719e-01,
                          3.07452530e-01,  -8.05825591e-01,   2.85104457e-02,
                          7.49729037e-01,  -1.49211630e-01,  -4.12395537e-01,
                          1.89775869e-01,   2.34547958e-01,   8.46985728e-02,
                         -1.93038920e-03,  -2.86630243e-01,   3.65789682e-02,
                          6.10188782e-01,  -7.44386539e-02,  -6.44813418e-01,
                          3.92922699e-01,   6.86558425e-01,  -5.53174317e-01,
                         -4.37122017e-01,   7.70069599e-01,   1.81793615e-01,
                         -6.82629645e-01,   2.31829062e-01,   5.74182630e-01,
                         -2.67358243e-01,  -2.17009157e-01,   2.79826880e-01,
                          8.62316489e-02,   1.82886850e-02,  -9.38491076e-02,
                         -8.37515444e-02,   4.71369594e-01,   8.63815099e-02,
                         -6.57594979e-01,   4.00461018e-01,   7.05676556e-01,
                         -7.32666671e-01,  -2.75312364e-01,   9.88617241e-01,
                          1.57915067e-03,  -8.54296386e-01,   3.67877543e-01,
                          7.21820951e-01,  -4.41608161e-01,  -3.43485534e-01,
                          4.45732296e-01,   2.20671505e-01,  -1.20121785e-01,
                         -6.86695278e-02,  -1.02064192e-01,   2.04087883e-01,
                          4.36268568e-01,  -3.07243139e-01,  -4.33045417e-01,
                          6.12388432e-01,   4.57455158e-01,  -7.37961411e-01,
                         -1.60768613e-01,   8.47004175e-01,  -9.26603526e-02,
                         -6.49461508e-01,   4.47427034e-01,   5.03472149e-01,
                         -4.52340484e-01,  -1.16616040e-01,   4.09438014e-01,
                         -7.61959748e-03,  -1.17446184e-01,   7.22642941e-03,
                          4.33987044e-02,   3.39737475e-01,  -8.78532007e-02,
                         -4.72452670e-01,   5.29186428e-01,   4.51133698e-01,
                         -8.25155258e-01,   2.35079825e-02,   9.59754109e-01,
                         -3.22451979e-01,  -7.76253402e-01,   7.15937853e-01,
                          5.00724494e-01,  -6.84694409e-01,  -1.66475073e-01,
                          6.23983622e-01,   8.01042020e-02,  -3.25880229e-01,
                          3.50062153e-03,   9.49961990e-02,   2.06211150e-01,
                          1.78441405e-01,  -3.75539690e-01,  -1.96578488e-01,
                          6.55387759e-01,   1.27031535e-01,  -7.62621880e-01,
                          1.41341850e-01,   7.55137265e-01,  -4.12954539e-01,
                         -6.44062042e-01,   6.16148829e-01,   3.26058239e-01,
                         -6.05215013e-01,   4.06645276e-02,   4.76430744e-01,
                         -2.09282279e-01,  -2.40385234e-01,   1.14866763e-01,
                          7.61702731e-02,   1.32117808e-01,  -1.66768163e-01,
                         -2.88941890e-01,   5.07774889e-01,   1.31790549e-01,
                         -7.84936249e-01,   1.83751687e-01,   7.99593687e-01,
                         -6.07360005e-01,  -5.32523036e-01,   8.43969047e-01,
                          1.67343214e-01,  -8.69991422e-01,   7.88201988e-02,
                          6.92637742e-01,  -2.32297748e-01,  -4.41133380e-01,
                          1.61732852e-01,   1.74672946e-01,   2.45245453e-02,
                         -5.37539087e-02,  -3.30269188e-01,   1.54885864e-02,
                          5.36077321e-01,  -1.80787146e-01,  -6.79512858e-01,
                          4.12307888e-01,   5.82918942e-01,  -6.79056406e-01,
                         -4.20073718e-01,   7.39622712e-01,   6.30783513e-02,
                         -6.87326431e-01,   2.32214198e-01,   4.57548261e-01,
                         -3.90265167e-01,  -2.40838885e-01,   2.48088464e-01,
                          2.84441188e-02,  -5.09474427e-02,  -1.56521916e-01,
                         -1.21919163e-01,   4.08396184e-01,  -4.38616127e-02,
                         -6.88658476e-01,   3.84229690e-01,   5.41424155e-01,
                         -8.38058710e-01,  -2.84921557e-01,   9.33011830e-01,
                         -1.01264507e-01,  -9.31123614e-01,   3.98478448e-01,
                          6.03649974e-01,  -5.56513190e-01,  -3.60902458e-01,
                          3.95051122e-01,   1.36321560e-01,  -2.06808046e-01,
                         -1.26419738e-01,  -1.45927280e-01,   1.55262858e-01,
                          3.18253249e-01,  -4.02220786e-01,  -4.66973484e-01,
                          5.66808999e-01,   3.56240958e-01,  -7.87795424e-01,
                         -1.48326918e-01,   7.87795961e-01,  -2.40842000e-01,
                         -7.32289374e-01,   3.93942863e-01,   4.14811909e-01,
                         -5.43591022e-01,  -1.27559677e-01,   3.71363372e-01,
                         -9.17323530e-02,  -1.89106837e-01,  -6.08065538e-02,
                         -9.41059273e-03,   2.59784847e-01,  -1.84491202e-01,
                         -5.16192555e-01,   5.05527616e-01,   3.01984578e-01,
                         -8.81180346e-01,  -7.55122676e-03,   8.93436432e-01,
                         -4.31796104e-01,  -7.90286064e-01,   6.84408605e-01,
                          3.93992811e-01,  -7.98088729e-01,  -1.56106085e-01,
                          5.69006801e-01,  -3.17100696e-02,  -3.84601414e-01,
                         -4.48680706e-02,   4.82017957e-02,   1.41763687e-01,
                          8.05728287e-02,  -4.46917146e-01,  -2.01800346e-01,
                          6.34573877e-01,   4.10300083e-02,  -8.10361028e-01,
                          1.52374372e-01,   7.07241118e-01,  -4.92203683e-01,
                         -6.01383686e-01,   5.91436982e-01,   2.37561911e-01,
                         -6.57054186e-01,   4.49618809e-02,   4.51633394e-01,
                         -2.47988880e-01,  -2.64304876e-01,   8.10477808e-02,
                          3.64402309e-02,   9.48017240e-02,  -2.22081661e-01,
                         -2.70324886e-01,   5.16092837e-01,   6.83536530e-02,
                         -8.10322881e-01,   2.45865047e-01,   7.67239273e-01,
                         -7.42358506e-01,  -4.97631609e-01,   8.63452613e-01,
                          1.09080568e-01,  -8.79146695e-01,   9.65219587e-02,
                          6.31302893e-01,  -2.88348377e-01,  -4.40354079e-01,
                          1.68688238e-01,   1.49856672e-01,  -3.73874535e-03,
                         -7.96735287e-02,  -3.34097952e-01,   5.35552725e-02,
                          5.27090549e-01,  -2.52849400e-01,  -6.49216354e-01,
                          4.61525798e-01,   6.07255816e-01,  -6.73218429e-01,
                         -3.66855234e-01,   7.19162881e-01,  -1.67852733e-02,
                         -6.93922877e-01,   2.97802836e-01,   4.39111441e-01,
                         -4.08881932e-01,  -2.32859150e-01,   2.41834223e-01,
                          1.88726615e-02,  -4.96290699e-02,  -1.58134297e-01,
                         -8.96066204e-02,   4.14852142e-01,  -1.02078229e-01,
                         -6.53405905e-01,   4.78444189e-01,   5.05887210e-01,
                         -8.29859734e-01,  -1.88406706e-01,   9.31065321e-01,
                         -2.05219626e-01,  -8.66407037e-01,   4.56448227e-01,
                          5.91009140e-01,  -5.90358078e-01,  -3.22815388e-01,
                          4.21228111e-01,   1.32957011e-01,  -1.91633999e-01,
                         -1.26279891e-01,  -1.22102872e-01,   1.90328464e-01,
                          3.22174966e-01,  -4.28736478e-01,  -4.09218043e-01,
                          6.40000999e-01,   2.99052209e-01,  -7.95912683e-01,
                         -7.36360401e-02,   7.49084592e-01,  -2.91180104e-01,
                         -6.45030677e-01,   4.91125643e-01,   3.83954257e-01,
                         -5.44986725e-01,  -8.64919871e-02,   3.81583124e-01,
                         -1.00317374e-01,  -1.72250316e-01,  -3.78198363e-02,
                          2.11849306e-02,   2.81489164e-01,  -1.83067918e-01,
                         -4.29249972e-01,   5.60299456e-01,   2.75591940e-01,
                         -8.66819203e-01,   5.38066402e-02,   9.25074518e-01,
                         -5.23361325e-01,  -6.96382046e-01,   7.63200045e-01,
                          3.32993686e-01,  -7.80203521e-01,  -9.81533006e-02,
                          6.10648036e-01,  -3.87407802e-02,  -3.61826569e-01,
                          1.53122831e-03,   8.07420313e-02,   1.71763018e-01,
                          8.75596032e-02,  -4.35954362e-01,  -1.50359988e-01,
                          6.59528553e-01,   2.55867443e-03,  -7.82761991e-01,
                          2.57998884e-01,   6.84473157e-01,  -5.38241208e-01,
                         -5.10131478e-01,   7.07334757e-01,   1.96078613e-01,
                         -6.61516368e-01,   1.07291423e-01,   4.32984471e-01,
                         -2.40961313e-01,  -2.01820940e-01,   1.22030795e-01,
                          6.25075996e-02,   1.12457767e-01,  -2.08471239e-01,
                         -2.31445327e-01,   5.40521622e-01,   5.49694300e-02,
                         -7.94421434e-01,   3.14349413e-01,   7.51689970e-01,
                         -7.60220289e-01,  -4.31760192e-01,   9.47466314e-01,
                          1.87035352e-02,  -8.57711613e-01,   2.09977537e-01,
                          6.68269038e-01,  -3.05941939e-01,  -3.75872284e-01,
                          2.23918870e-01,   1.59512714e-01,   1.02937147e-02,
                         -7.32647106e-02,  -3.11240733e-01,   1.14662856e-01,
                          5.45787990e-01,  -2.76092440e-01,  -6.14046454e-01,
                          5.07695138e-01,   5.44208288e-01,  -6.90010428e-01,
                         -2.87271678e-01,   7.63096154e-01,  -7.62897283e-02,
                         -6.99396551e-01,   3.39281142e-01,   4.72328961e-01,
                         -3.95100355e-01,  -1.48827985e-01,   2.60743529e-01,
                          1.37804374e-02,  -4.45095338e-02,  -1.45195633e-01,
                         -5.95355891e-02,   4.39262390e-01,  -1.08182825e-01,
                         -5.97495437e-01,   5.41698873e-01,   4.79668796e-01,
                         -8.66800070e-01,  -1.20152451e-01,   9.47691858e-01,
                         -2.31329948e-01,  -7.86918521e-01,   5.24402678e-01,
                          5.20360649e-01,  -5.73670268e-01,  -2.34777465e-01,
                          4.65947866e-01,   1.31196231e-01,  -1.85990259e-01,
                         -9.20366496e-02,  -8.83482695e-02,   2.27951974e-01,
                          3.08548719e-01,  -4.35367078e-01,  -3.57573479e-01,
                          6.97423637e-01,   2.90696621e-01,  -7.66189635e-01,
                          2.77920756e-02,   7.83049166e-01,  -3.50351632e-01,
                         -5.87208450e-01,   5.90974450e-01,   3.94147456e-01,
                         -5.08892536e-01,   1.73539959e-03,   4.20296729e-01,
                         -7.99070969e-02,  -1.24440014e-01,   2.29033336e-04,
                          6.94547966e-02,   3.10887367e-01,  -1.96522981e-01,
                         -3.66633654e-01,   6.55837357e-01,   2.35033154e-01,
                         -8.28203678e-01,   1.88428894e-01,   9.07198250e-01,
                         -5.32980144e-01,  -6.20535135e-01,   8.54181349e-01,
                          3.24475944e-01,  -7.42319822e-01,  -1.83315966e-02,
                          6.57833576e-01,  -6.60252571e-02,  -3.11428457e-01,
                          6.66023493e-02,   1.28601685e-01,   2.12573066e-01,
                          9.54155698e-02,  -4.16187882e-01,  -4.68989611e-02,
                          7.05429912e-01,  -2.14549117e-02,  -6.95853591e-01,
                          3.61917913e-01,   7.09132195e-01,  -5.43546736e-01,
                         -4.42297697e-01,   7.37809420e-01,   1.60196140e-01,
                         -6.27096653e-01,   2.16209903e-01,   4.94464964e-01,
                         -2.13036209e-01,  -1.54877797e-01,   1.60561055e-01,
                          9.10299346e-02,   1.36464521e-01,  -1.91555575e-01,
                         -1.42812625e-01,   5.90128720e-01,   6.56511933e-02,
                         -7.58404255e-01,   4.62083548e-01,   7.23116696e-01,
                         -7.65915990e-01,  -2.78187066e-01,   9.76882577e-01,
                          2.02016104e-02,  -8.21403623e-01,   3.05731505e-01,
                          6.73697948e-01,  -3.35405648e-01,  -3.17805111e-01,
                          3.04803967e-01,   1.90786242e-01,   3.89251113e-02,
                         -4.90658879e-02,  -2.61473536e-01,   1.83558345e-01,
                          5.69503307e-01,  -2.97618896e-01,  -5.23383379e-01,
                          6.03910804e-01,   5.11353612e-01,  -7.38001227e-01,
                         -1.81866542e-01,   8.27299953e-01,  -9.00722891e-02,
                         -6.10781610e-01,   4.22910035e-01,   4.48582858e-01,
                         -3.87775838e-01,  -9.55202058e-02,   3.06009561e-01,
                          3.27556245e-02,  -1.59059893e-02,  -1.07798398e-01,
                          1.30847131e-03,   4.78803098e-01,  -1.43846259e-01,
                         -5.65525413e-01,   6.21024966e-01,   4.57421482e-01,
                         -8.86162579e-01,   3.17749381e-02,   9.63820159e-01,
                         -3.08865339e-01,  -7.65707076e-01,   6.54841423e-01,
                          4.97035950e-01,  -5.90435266e-01,  -1.83813646e-01,
                          4.93985981e-01,   1.20739371e-01,  -1.79386243e-01,
                         -6.90767318e-02,  -5.40258326e-02,   2.70758420e-01,
                          3.09342027e-01,  -4.40969706e-01,  -3.05134416e-01,
                          7.08311498e-01,   1.76033661e-01,  -7.95966208e-01,
                          1.12020671e-01,   7.51409531e-01,  -4.09868628e-01,
                         -6.19831800e-01,   5.75012445e-01,   2.88978010e-01,
                         -5.38642704e-01,   3.27776521e-02,   3.76945376e-01,
                         -1.40785679e-01,  -1.57759711e-01,  -1.52408956e-02,
                          5.44908009e-02,   2.68780857e-01,  -2.58440465e-01,
                         -3.65650296e-01,   6.24369621e-01,   1.13795362e-01,
                         -8.60822380e-01,   2.13135093e-01,   8.12146068e-01,
                         -6.19652390e-01,  -5.36763310e-01,   8.03636670e-01,
                          1.81190208e-01,  -7.97285080e-01,   1.99493859e-02,
                          5.94111145e-01,  -1.43243253e-01,  -3.51523995e-01,
                          2.37972774e-02,   7.78086931e-02,   1.58452049e-01,
                          2.74550803e-02,  -4.80573148e-01,  -5.54669648e-02,
                          6.37012541e-01,  -1.46303579e-01,  -7.43591845e-01,
                          3.94284070e-01,   6.04889870e-01,  -6.72038674e-01,
                         -4.20139939e-01,   6.98528767e-01,   5.15273996e-02,
                         -6.28723085e-01,   1.97812647e-01,   3.76188040e-01,
                         -3.13702077e-01,  -1.84289739e-01,   1.08910620e-01,
                          4.56475951e-02,   7.67231733e-02,  -2.67520577e-01,
                         -1.85025170e-01,   5.43510854e-01,  -7.95160607e-02,
                         -7.77322710e-01,   4.44677234e-01,   5.51399648e-01,
                         -8.77414703e-01,  -2.85329074e-01,   9.10983443e-01,
                         -9.13657919e-02,  -8.97194147e-01,   3.25970054e-01,
                          5.59144497e-01,  -4.54498917e-01,  -3.42835784e-01,
                          2.38477916e-01,   1.17180005e-01,  -4.14847657e-02,
                         -1.28682002e-01,  -3.09956133e-01,   1.55041829e-01,
                          4.42999661e-01,  -4.10142154e-01,  -5.62470913e-01,
                          5.75196624e-01,   4.02572125e-01,  -7.95480549e-01,
                         -1.70953527e-01,   7.59733081e-01,  -2.39118621e-01,
                         -6.87154174e-01,   3.63828331e-01,   3.46189857e-01,
                         -4.69952971e-01,  -1.01247139e-01,   2.47371539e-01,
                         -5.36106266e-02,  -8.29655826e-02,  -1.86943769e-01,
                         -5.58233671e-02,   3.89430821e-01,  -2.46715099e-01,
                         -6.02000296e-01,   5.93048632e-01,   2.98827380e-01,
                         -9.39381063e-01,   1.32672302e-03,   8.90085042e-01,
                         -4.28309321e-01,  -7.74991751e-01,   6.23491108e-01,
                          3.85364801e-01,  -7.12377071e-01,  -1.85957536e-01,
                          4.49988931e-01,   1.62202269e-02,  -2.50592977e-01,
                         -1.24642357e-01,  -1.02061987e-01,   2.29485914e-01,
                          1.98202327e-01,  -5.25264442e-01,  -3.05560172e-01,
                          6.90232754e-01,   9.24520791e-02,  -8.33278120e-01,
                          1.32442132e-01,   6.96947694e-01,  -4.85441566e-01,
                         -5.82295001e-01,   5.54481208e-01,   1.90918818e-01,
                         -5.79769433e-01,   4.74901050e-02,   3.41123551e-01,
                         -1.90498605e-01,  -1.83486477e-01,  -4.86622714e-02,
                          2.33238637e-02,   2.19770700e-01,  -3.07565778e-01,
                         -3.38013440e-01,   6.28166616e-01,   4.50033173e-02,
                         -8.90921772e-01,   2.76171952e-01,   7.78016388e-01,
                         -7.51837313e-01,  -5.07300377e-01,   8.22670043e-01,
                          1.30848244e-01,  -8.21029365e-01,   3.75389755e-02,
                          5.43676078e-01,  -1.93320945e-01,  -3.55290532e-01,
                          3.21813859e-02,   7.71248341e-02,   1.39286578e-01,
                         -9.14718211e-03,  -4.72053915e-01,   9.62294362e-05,
                          6.24122918e-01,  -2.20078707e-01,  -7.03208983e-01,
                          4.44204539e-01,   6.29207253e-01,  -6.65728331e-01,
                         -3.70401561e-01,   7.01163352e-01,  -2.80354824e-02,
                         -6.26902938e-01,   2.79162616e-01,   3.65189314e-01,
                         -3.34342867e-01,  -1.64537042e-01,   1.22247927e-01,
                          5.44120967e-02,   7.43368119e-02,  -2.65826821e-01,
                         -1.39054984e-01,   5.60579300e-01,  -1.39043137e-01,
                         -7.22217441e-01,   5.49578130e-01,   5.17339706e-01,
                         -8.53621125e-01,  -1.80323601e-01,   9.22607183e-01,
                         -1.77942634e-01,  -8.28334332e-01,   3.88910294e-01,
                          5.60624599e-01,  -4.64334488e-01,  -2.98396409e-01,
                          2.83581048e-01,   1.35600194e-01,  -2.31037904e-02,
                         -1.16226226e-01,  -2.80190378e-01,   2.06926465e-01,
                          4.57343698e-01,  -4.47173893e-01,  -4.87693250e-01,
                          6.64337635e-01,   3.47456932e-01,  -7.98419654e-01,
                         -7.73168877e-02,   7.38466561e-01,  -2.74377078e-01,
                         -6.01635277e-01,   4.72278744e-01,   3.32129568e-01,
                         -4.65985447e-01,  -5.59022650e-02,   2.72703439e-01,
                         -3.78483944e-02,  -6.46715686e-02,  -1.54900029e-01,
                         -3.65625275e-03,   4.24712181e-01,  -2.41302341e-01,
                         -4.93983120e-01,   6.66407466e-01,   2.85572857e-01,
                         -9.11709011e-01,   7.99388513e-02,   9.40513253e-01,
                         -5.02684236e-01,  -6.78886473e-01,   7.10764945e-01,
                          3.47947091e-01,  -6.79135859e-01,  -1.20872602e-01,
                          4.99401987e-01,   2.82358676e-02,  -2.16055751e-01,
                         -7.60351717e-02,  -4.78984676e-02,   2.72000223e-01,
                          2.12320685e-01,  -5.07337391e-01,  -2.31729642e-01,
                          7.16848910e-01,   5.41108251e-02,  -8.16218972e-01,
                          2.56020248e-01,   6.98260128e-01,  -5.27577698e-01,
                         -4.83664125e-01,   6.73773527e-01,   1.79538429e-01,
                         -5.83566964e-01,   9.92236435e-02,   3.56050193e-01,
                         -1.64159521e-01,  -1.21103592e-01,   4.14652098e-03,
                          7.74409994e-02,   2.43463337e-01,  -2.96579510e-01,
                         -2.85764337e-01,   6.66709483e-01,   4.41110842e-02,
                         -8.56354833e-01,   3.68790090e-01,   7.61106193e-01,
                         -7.63289094e-01,  -4.08749282e-01,   9.12494719e-01,
                          5.30837849e-02,  -7.88991034e-01,   1.49854988e-01,
                          5.96628010e-01,  -1.94893360e-01,  -3.06022465e-01,
                          9.28446278e-02,   1.07052349e-01,   1.65266648e-01,
                         -1.71789993e-02,  -4.45136756e-01,   6.55253902e-02,
                          6.55749619e-01,  -2.50845104e-01,  -6.71041369e-01,
                          5.09600997e-01,   5.67195058e-01,  -6.76106930e-01,
                         -2.80747235e-01,   7.32520640e-01,  -7.30668604e-02,
                         -6.28579140e-01,   3.05915117e-01,   4.08102691e-01,
                         -3.18534821e-01,  -1.16144776e-01,   1.48581237e-01,
                          5.50438240e-02,   7.62561709e-02,  -2.68065184e-01,
                         -8.62661377e-02,   5.77908516e-01,  -1.54108316e-01,
                         -6.51549697e-01,   6.17922544e-01,   4.75427955e-01,
                         -8.93724561e-01,  -1.04593806e-01,   9.34426904e-01,
                         -2.00058624e-01,  -7.54156947e-01,   4.58016276e-01,
                          5.02337039e-01,  -4.62729335e-01,  -2.31290251e-01,
                          3.20459247e-01,   1.43668339e-01,  -2.09764782e-02,
                         -1.12452082e-01,  -2.43024364e-01,   2.62805074e-01,
                          4.28922504e-01,  -4.76028174e-01,  -4.40476805e-01,
                          7.27891803e-01,   3.27062070e-01,  -7.63441682e-01,
                          2.92286538e-02,   7.73788154e-01,  -3.45208526e-01,
                         -5.48745632e-01,   5.51040590e-01,   3.48920852e-01,
                         -4.35178846e-01,   4.49565379e-03,   3.10010374e-01,
                         -1.98057815e-02,  -3.59796844e-02,  -1.29180074e-01,
                          6.11081496e-02,   4.43002284e-01,  -2.81728387e-01,
                         -4.23680127e-01,   7.51123905e-01,   2.08964661e-01,
                         -8.79650891e-01,   2.09663913e-01,   9.07379031e-01,
                         -5.26010156e-01,  -6.10001028e-01,   7.89188564e-01,
                          3.29761684e-01,  -6.52385950e-01,  -6.13315739e-02,
                          5.35728455e-01,   2.20183283e-02,  -1.86805308e-01,
                         -4.57125157e-02,   2.81523238e-03,   3.23497266e-01,
                          2.07853153e-01,  -5.13078928e-01,  -1.33835852e-01,
                          7.57581770e-01,   1.56732798e-02,  -7.30008185e-01,
                          3.46983343e-01,   7.03307390e-01,  -5.23097754e-01,
                         -4.20708895e-01,   6.92376196e-01,   1.32122964e-01,
                         -5.53586245e-01,   1.93571389e-01,   4.00513381e-01,
                         -1.30074382e-01,  -9.63433385e-02,   1.99912339e-02,
                          1.15092732e-01,   2.57441789e-01,  -3.08973342e-01,
                         -1.95527554e-01,   7.15412259e-01,   3.02277748e-02,
                         -8.29750121e-01,   5.10120630e-01,   7.25407660e-01,
                         -7.88893580e-01,  -2.83210725e-01,   9.42792952e-01,
                          5.16638979e-02,  -7.66825438e-01,   2.23113313e-01,
                          6.01988673e-01,  -2.21308812e-01,  -2.64227062e-01,
                          1.49588287e-01,   1.44078597e-01,   1.97628334e-01,
                          1.55238551e-03,  -4.05277789e-01,   1.43178388e-01,
                          6.66078746e-01,  -2.88091809e-01,  -5.84382117e-01,
                          6.05557740e-01,   5.30211210e-01,  -7.30917871e-01,
                         -1.75232098e-01,   7.89061248e-01,  -9.03785676e-02,
                         -5.54892063e-01,   3.75431418e-01,   3.77772063e-01,
                         -3.09103042e-01,  -6.73802719e-02,   1.79101810e-01,
                          8.21546987e-02,   9.26222652e-02,  -2.37343132e-01,
                         -3.33112776e-02,   6.13408506e-01,  -2.13921741e-01,
                         -6.45103157e-01,   7.04915822e-01,   4.57498938e-01,
                         -9.28350329e-01,   3.56671773e-02,   9.52736616e-01,
                         -2.83489406e-01,  -7.43384182e-01,   5.72331309e-01,
                          4.89596665e-01,  -4.85550612e-01,  -1.93322301e-01,
                          3.46159071e-01,   1.36135951e-01,  -1.11760581e-02,
                         -1.01377346e-01,  -2.12669760e-01,   3.07479292e-01,
                          4.23642695e-01,  -4.75797385e-01,  -3.82969588e-01,
                          7.19108522e-01,   2.07693785e-01,  -7.90659010e-01,
                          9.44483578e-02,   7.29936421e-01,  -3.94409120e-01,
                         -5.82323015e-01,   5.33995926e-01,   2.56214231e-01,
                         -4.60781038e-01,   2.79700272e-02,   2.68619567e-01,
                         -6.78397641e-02,  -7.64582306e-02,  -1.49367228e-01,
                          4.70298938e-02,   3.91692311e-01,  -3.54477644e-01,
                         -4.25032347e-01,   7.15559006e-01,   9.96007845e-02,
                         -9.07440662e-01,   2.29129836e-01,   8.11916053e-01,
                         -6.03818357e-01,  -5.43116629e-01,   7.46903539e-01,
                          1.95834368e-01,  -7.18446553e-01,  -3.71463820e-02,
                          4.80860353e-01,  -6.17463067e-02,  -2.34336302e-01,
                         -8.36776271e-02,  -3.35378721e-02,   2.70611703e-01,
                          1.23914607e-01,  -5.74697673e-01,  -1.46843597e-01,
                          6.86981559e-01,  -9.54906866e-02,  -7.82325923e-01,
                          3.68317932e-01,   6.00861371e-01,  -6.54275298e-01,
                         -4.18653071e-01,   6.64596617e-01,   3.96025628e-02,
                         -5.77078640e-01,   1.72262505e-01,   2.95087963e-01,
                         -2.39809215e-01,  -1.35006666e-01,  -1.69636216e-02,
                          7.27320984e-02,   1.81315333e-01,  -3.90240788e-01,
                         -2.27523714e-01,   6.53385520e-01,  -1.14779882e-01,
                         -8.33809555e-01,   4.90812391e-01,   5.59353650e-01,
                         -8.93062830e-01,  -3.00438821e-01,   8.81992280e-01,
                         -5.95615953e-02,  -8.39731872e-01,   2.37363204e-01,
                          4.91801679e-01,  -3.28256518e-01,  -3.11252832e-01,
                          8.61207098e-02,   6.52445480e-02,   1.20620921e-01,
                         -9.65125933e-02,  -4.66220617e-01,   1.16496280e-01,
                          5.54258227e-01,  -4.14418399e-01,  -6.37024820e-01,
                          5.61486244e-01,   4.25304592e-01,  -7.87319303e-01,
                         -1.80463836e-01,   7.30324507e-01,  -2.38368511e-01,
                         -6.46475792e-01,   3.19426596e-01,   2.90828198e-01,
                         -3.96686167e-01,  -9.38585624e-02,   1.22100361e-01,
                         -4.36494534e-04,  -1.91539701e-03,  -3.16641778e-01,
                         -6.42864257e-02,   5.05087018e-01,  -3.12640458e-01,
                         -6.65009081e-01,   6.67496741e-01,   2.84680873e-01,
                         -9.76416588e-01,  -6.72803260e-03,   8.85186732e-01,
                         -4.08088088e-01,  -7.69735515e-01,   5.34000039e-01,
                          3.75685781e-01,  -6.01061702e-01,  -2.12881863e-01,
                          2.97230482e-01,   4.92149591e-02,  -1.03086077e-01,
                         -1.77702785e-01,  -2.42824093e-01,   2.71673560e-01,
                          3.21878284e-01,  -5.85509062e-01,  -3.92495513e-01,
                          7.23121047e-01,   1.31531805e-01,  -8.60445440e-01,
                          1.03194773e-01,   6.86601758e-01,  -4.67584878e-01,
                         -5.54222167e-01,   5.13571799e-01,   1.67060599e-01,
                         -5.24050057e-01,   2.45373920e-02,   2.40864545e-01,
                         -1.18773960e-01,  -1.18240952e-01,  -1.82870060e-01,
                          5.03068976e-02,   3.32211941e-01,  -4.10293072e-01,
                         -3.84241283e-01,   7.32194364e-01,   1.19845429e-02,
                         -9.39383030e-01,   2.99892306e-01,   7.90396869e-01,
                         -7.46676445e-01,  -5.11383593e-01,   7.64675140e-01,
                          1.48656622e-01,  -7.34875977e-01,  -2.66871676e-02,
                          4.34911340e-01,  -1.05200529e-01,  -2.51306891e-01,
                         -7.06240535e-02,  -4.09859829e-02,   2.74740487e-01,
                          9.29940864e-02,  -5.80163658e-01,  -6.62376657e-02,
                          7.14768410e-01,  -1.80059135e-01,  -7.39238620e-01,
                          4.34650600e-01,   6.53623998e-01,  -6.33915842e-01,
                         -3.51194590e-01,   6.61151588e-01,  -2.61903498e-02,
                         -5.78676462e-01,   2.48352200e-01,   3.06891978e-01,
                         -2.48357818e-01,  -1.14671908e-01,   1.89080313e-02,
                          1.09874569e-01,   1.73167139e-01,  -3.89578491e-01,
                         -1.41599298e-01,   6.66265190e-01,  -1.88523442e-01,
                         -7.64262795e-01,   6.11479104e-01,   5.36600292e-01,
                         -8.64121854e-01,  -1.73441961e-01,   9.04327571e-01,
                         -1.41719684e-01,  -7.59267211e-01,   3.15400332e-01,
                          5.19013643e-01,  -3.25608701e-01,  -2.58918196e-01,
                          1.23504303e-01,   1.15123436e-01,   1.51386753e-01,
                         -9.07512382e-02,  -4.21558380e-01,   2.06632376e-01,
                          5.84180593e-01,  -4.42077488e-01,  -5.49600482e-01,
                          6.83131635e-01,   3.87266517e-01,  -7.80849636e-01,
                         -8.55153874e-02,   7.23186016e-01,  -2.54075110e-01,
                         -5.45910597e-01,   4.39392865e-01,   2.80960143e-01,
                         -3.68378997e-01,  -4.47840802e-02,   1.71682984e-01,
                          3.99874598e-02,   3.80974412e-02,  -2.82546639e-01,
                          1.32119283e-02,   5.57347775e-01,  -3.20438564e-01,
                         -5.16403556e-01,   7.67817736e-01,   2.75231093e-01,
                         -9.41955030e-01,   1.02889948e-01,   9.29656684e-01,
                         -4.72581804e-01,  -6.43362045e-01,   6.40021443e-01,
                          3.59627724e-01,  -5.39319515e-01,  -1.32823437e-01,
                          3.57819289e-01,   9.35489014e-02,  -4.32700738e-02,
                         -1.44363597e-01,  -1.84332505e-01,   3.46217960e-01,
                          3.39844823e-01,  -5.56698859e-01,  -2.96386421e-01,
                          7.63964057e-01,   9.48454440e-02,  -8.23713481e-01,
                          2.31330782e-01,   6.95844233e-01,  -4.83220756e-01,
                         -4.52750683e-01,   6.23034656e-01,   1.47109851e-01,
                         -4.93904352e-01,   9.30980220e-02,   2.70476937e-01,
                         -6.96835965e-02,  -5.66523224e-02,  -1.35947898e-01,
                          1.17472515e-01,   3.65640998e-01,  -4.08144325e-01,
                         -3.01414371e-01,   7.76867807e-01,   1.02200899e-02,
                         -8.96613657e-01,   4.20053273e-01,   7.58847594e-01,
                         -7.48704374e-01,  -4.07529980e-01,   8.68472636e-01,
                          8.16077143e-02,  -6.96453631e-01,   9.15787667e-02,
                          4.90319103e-01,  -8.48197639e-02,  -2.03490078e-01,
                         -3.08675803e-02,   1.78178921e-02,   3.04077953e-01,
                          6.96324557e-02,  -5.76271474e-01,   1.68141238e-02,
                          7.43193448e-01,  -2.01473445e-01,  -7.10071564e-01,
                          4.91412103e-01,   5.94158411e-01,  -6.50125980e-01,
                         -2.76171446e-01,   6.95308805e-01,  -6.57879040e-02,
                         -5.64344168e-01,   2.68021792e-01,   3.39082599e-01,
                         -2.12219849e-01,  -8.68248940e-02,   2.51072571e-02,
                          1.28905833e-01,   1.77157491e-01,  -3.96708310e-01,
                         -9.13309008e-02,   6.97699547e-01,  -2.14963540e-01,
                         -6.96363091e-01,   6.95712388e-01,   4.88681644e-01,
                         -9.07264888e-01,  -1.00361794e-01,   9.13459837e-01,
                         -1.71054840e-01,  -7.07775056e-01,   3.79693598e-01,
                          4.59098905e-01,  -3.36767465e-01,  -1.99778333e-01,
                          1.65389821e-01,   1.24940895e-01,   1.51171491e-01,
                         -1.12208679e-01,  -3.75989079e-01,   2.66687185e-01,
                          5.39048314e-01,  -4.71243709e-01,  -5.08942544e-01,
                          7.20981777e-01,   3.79119188e-01,  -7.61917412e-01,
                         -4.52437252e-03,   7.51673460e-01,  -3.21340233e-01,
                         -5.10734439e-01,   5.01385212e-01,   2.94519007e-01,
                         -3.52461278e-01,  -2.77546910e-03,   1.97690114e-01,
                          7.03635812e-02,   3.59405912e-02,  -2.65188307e-01,
                          7.24061280e-02,   5.58433354e-01,  -3.74763280e-01,
                         -4.57934231e-01,   8.31571698e-01,   1.89160824e-01,
                         -9.05698895e-01,   2.31426269e-01,   9.02767658e-01,
                         -5.02333343e-01,  -5.88537753e-01,   7.18675017e-01,
                          3.38052452e-01,  -5.48686504e-01,  -9.80302766e-02,
                          3.90486330e-01,   9.01463181e-02,  -4.05648276e-02,
                         -1.37104779e-01,  -1.48201585e-01,   4.02778804e-01,
                          3.08221251e-01,  -5.71140528e-01,  -2.09308028e-01,
                          7.90638208e-01,   4.83798906e-02,  -7.41796315e-01,
                          3.22687894e-01,   6.94234729e-01,  -4.99227285e-01,
                         -4.07740742e-01,   6.37555659e-01,   1.14722475e-01,
                         -4.73562747e-01,   1.66078463e-01,   3.05009097e-01,
                         -5.48639968e-02,  -3.82010899e-02,  -1.13619581e-01,
                          1.62114978e-01,   3.57108593e-01,  -4.20844376e-01,
                         -2.08874032e-01,   8.00486863e-01,  -1.10053429e-02,
                         -8.60683322e-01,   5.45664966e-01,   7.13858247e-01,
                         -7.80322671e-01,  -2.84881115e-01,   8.99821639e-01,
                          6.91268519e-02,  -6.90201163e-01,   1.52929783e-01,
                          4.99386013e-01,  -9.99655798e-02,  -1.72040373e-01,
                         -1.79677233e-02,   7.38422945e-02,   3.48777741e-01,
                          6.79239184e-02,  -5.39914966e-01,   9.16367397e-02,
                          7.51060247e-01,  -2.68319309e-01,  -6.26505971e-01,
                          5.82593739e-01,   5.43263912e-01,  -7.22337604e-01,
                         -1.86773777e-01,   7.59759188e-01,  -9.65015441e-02,
                         -4.94938195e-01,   3.42793941e-01,   3.10874492e-01,
                         -2.24651083e-01,  -3.61372791e-02,   5.86417168e-02,
                          1.47161573e-01,   1.77410215e-01,  -3.64956081e-01,
                         -4.23377007e-02,   7.13059008e-01,  -2.87949026e-01,
                         -6.79308891e-01,   7.46476591e-01,   4.52605218e-01,
                         -9.31254327e-01,   2.98911240e-02,   9.26747620e-01,
                         -2.41725639e-01,  -7.05523014e-01,   4.76405740e-01,
                          4.52230036e-01,  -3.46664548e-01,  -1.81506634e-01,
                          1.78385541e-01,   1.41688228e-01,   1.56785041e-01,
                         -1.21792138e-01,  -3.66209060e-01,   3.19592237e-01,
                          5.41553020e-01,  -4.86032426e-01,  -4.71862406e-01,
                          7.16698289e-01,   2.41905436e-01,  -8.10521662e-01,
                          6.28436282e-02,   7.07728863e-01,  -3.88110846e-01,
                         -5.47751844e-01,   4.89375412e-01,   2.12325618e-01,
                         -3.87049496e-01,   1.17216781e-02,   1.56336889e-01,
                          1.36129931e-02,  -6.50272472e-03,  -2.87441880e-01,
                          6.88253269e-02,   4.86876637e-01,  -4.47287798e-01,
                         -4.54462647e-01,   8.06952596e-01,   6.45570606e-02,
                         -9.37939703e-01,   2.35120520e-01,   7.98101962e-01,
                         -5.84807932e-01,  -5.18453479e-01,   6.58928752e-01,
                          2.07000300e-01,  -6.07498348e-01,  -8.98639783e-02,
                          3.48415256e-01,   1.68833565e-02,  -1.00945286e-01,
                         -1.81428373e-01,  -1.58093959e-01,   3.49382818e-01,
                          2.33643442e-01,  -6.59319937e-01,  -2.30670646e-01,
                          7.26371527e-01,  -6.34974837e-02,  -7.97428966e-01,
                          3.48662466e-01,   5.95455825e-01,  -6.41958952e-01,
                         -4.01975423e-01,   6.12530947e-01,   1.38874175e-02,
                         -4.95989859e-01,   1.33564129e-01,   2.02170566e-01,
                         -1.40142918e-01,  -9.53925028e-02,  -1.63962558e-01,
                          1.14094153e-01,   2.81438440e-01,  -5.22736728e-01,
                         -2.39725515e-01,   7.57135034e-01,  -1.63807407e-01,
                         -8.84012938e-01,   5.16130686e-01,   5.48976660e-01,
                         -8.88326168e-01,  -3.04112881e-01,   8.25822711e-01,
                         -2.99270004e-02,  -7.63060391e-01,   1.57822371e-01,
                          4.14191127e-01,  -2.25698516e-01,  -2.31075257e-01,
                         -5.15773781e-02,   9.48304310e-04,   2.58127213e-01,
                         -3.83463763e-02,  -5.88732004e-01,   6.97047636e-02,
                          6.31465912e-01,  -3.73611897e-01,  -6.88741148e-01,
                          5.42975724e-01,   4.32340324e-01,  -7.62411892e-01,
                         -1.69524506e-01,   6.81640804e-01,  -2.49740869e-01,
                         -5.89624345e-01,   2.73991764e-01,   2.20760569e-01,
                         -2.90992707e-01,  -8.30415040e-02,   1.51607418e-03,
                          7.95568824e-02,   6.96609765e-02,  -4.61884886e-01,
                         -6.13108948e-02,   6.21006548e-01,  -3.93787622e-01,
                         -7.10295439e-01,   7.46334732e-01,   2.75517493e-01,
                         -9.99975801e-01,  -1.76169109e-02,   8.59420478e-01,
                         -3.66131723e-01,  -7.22526312e-01,   4.49080676e-01,
                          3.41529548e-01,  -4.70820069e-01,  -2.14300737e-01,
                          1.37496367e-01,   6.12388290e-02,   5.61314113e-02,
                         -1.93579048e-01,  -3.93264204e-01,   3.02518576e-01,
                          4.34369087e-01,  -5.93113601e-01,  -4.66548234e-01,
                          7.32901573e-01,   1.65565550e-01,  -8.45698774e-01,
                          9.80553254e-02,   6.53837502e-01,  -4.52674627e-01,
                         -5.01829088e-01,   4.65840876e-01,   1.26907170e-01,
                         -4.19367433e-01,   1.02508441e-02,   1.40240252e-01,
                         -1.87064614e-02,  -4.64936681e-02,  -3.20499659e-01,
                          8.90868157e-02,   4.44396198e-01,  -5.32438219e-01,
                         -4.10932362e-01,   8.21125269e-01,  -9.98012442e-03,
                         -9.78729129e-01,   3.15516263e-01,   7.83537090e-01,
                         -7.04681754e-01,  -5.07576525e-01,   7.06035495e-01,
                          1.65079787e-01,  -6.19616747e-01,  -6.65621385e-02,
                          3.11546087e-01,  -1.65012628e-02,  -1.18763775e-01,
                         -1.94074422e-01,  -1.50603250e-01,   3.65766287e-01,
                          1.96045980e-01,  -6.49188280e-01,  -1.29610583e-01,
                          7.62982190e-01,  -1.47976488e-01,  -7.68732488e-01,
                          4.24694031e-01,   6.44099116e-01,  -6.24298096e-01,
                         -3.15637350e-01,   6.15943134e-01,  -4.04086784e-02,
                         -4.79286671e-01,   1.95939854e-01,   2.19377279e-01,
                         -1.39003888e-01,  -7.31607601e-02,  -1.29039094e-01,
                          1.77263916e-01,   2.84817427e-01,  -5.16665041e-01,
                         -1.44605115e-01,   7.93783724e-01,  -2.43713021e-01,
                         -8.01628709e-01,   6.62210763e-01,   5.40289402e-01,
                         -8.55072618e-01,  -1.85050443e-01,   8.56896579e-01,
                         -8.79926458e-02,  -6.84955657e-01,   2.36929908e-01,
                          4.44145620e-01,  -1.83611855e-01,  -1.95836097e-01,
                         -1.23294946e-02,   6.71287850e-02,   3.12837094e-01,
                         -3.06072664e-02,  -5.40569484e-01,   1.79339677e-01,
                          6.77383959e-01,  -4.29658741e-01,  -5.88962674e-01,
                          6.80414081e-01,   4.16533560e-01,  -7.67517865e-01,
                         -6.45909831e-02,   6.94330275e-01,  -2.37379819e-01,
                         -4.77132350e-01,   3.83066684e-01,   2.48880491e-01,
                         -2.61364251e-01,  -4.46774140e-02,   6.00060150e-02,
                          1.48315102e-01,   1.12809122e-01,  -4.04350489e-01,
                          2.75469162e-02,   6.78205967e-01,  -3.84393722e-01,
                         -5.46201646e-01,   8.42487574e-01,   2.81223297e-01,
                         -9.41939473e-01,   8.38142782e-02,   9.21124041e-01,
                         -4.05646712e-01,  -6.11909509e-01,   5.59699893e-01,
                          3.49914908e-01,  -4.15166020e-01,  -1.53603554e-01,
                          2.13916317e-01,   1.32553682e-01,   1.27292290e-01,
                         -1.74626291e-01,  -3.26544851e-01,   3.92063171e-01,
                          4.64110494e-01,  -5.66456139e-01,  -3.72559637e-01,
                          7.93537021e-01,   1.43742442e-01,  -8.06810796e-01,
                          2.47040987e-01,   6.87553942e-01,  -4.58222896e-01,
                         -3.98667395e-01,   5.82018435e-01,   1.43135712e-01,
                         -3.99396926e-01,   7.60918632e-02,   1.82468131e-01,
                          2.74514351e-02,  -9.44888778e-03,  -2.50697017e-01,
                          1.74998119e-01,   4.56862479e-01,  -5.02430379e-01,
                         -2.98457474e-01,   8.79704773e-01,  -5.92126837e-03,
                         -9.08940852e-01,   4.22011316e-01,   7.79139519e-01,
                         -6.99558437e-01,  -4.04394388e-01,   7.94573367e-01,
                          1.30043164e-01,  -5.86491883e-01,   2.16105934e-02,
                          3.84678155e-01,   2.44457591e-02,  -8.06350410e-02,
                         -1.46597445e-01,  -8.67569819e-02,   4.32785600e-01,
                          1.86007410e-01,  -6.45058572e-01,  -5.87433316e-02,
                          7.96501100e-01,  -1.64306924e-01,  -7.23266959e-01,
                          4.83368635e-01,   5.91659844e-01,  -6.16731167e-01,
                         -2.53532320e-01,   6.52136683e-01,  -5.30545786e-02,
                         -4.67959881e-01,   2.46847749e-01,   2.66591042e-01,
                         -1.14154324e-01,  -4.60364409e-02,  -8.07694942e-02,
                          1.96931094e-01,   2.55286723e-01,  -5.08621156e-01,
                         -6.93607628e-02,   8.03774774e-01,  -2.59001255e-01,
                         -7.24713266e-01,   7.20148206e-01,   4.97796029e-01,
                         -8.91669333e-01,  -1.21709995e-01,   8.78848195e-01,
                         -1.05203167e-01,  -6.32500112e-01,   2.94303447e-01,
                          4.10528928e-01,  -1.91478029e-01,  -1.60874531e-01,
                          1.64893381e-02,   9.38848108e-02,   3.09758961e-01,
                         -7.64198154e-02,  -5.22458315e-01,   2.53848433e-01,
                          6.25463724e-01,  -4.73519683e-01,  -5.52441418e-01,
                          7.18728960e-01,   3.84001940e-01,  -7.31841087e-01,
                          1.92666091e-02,   6.96451902e-01,  -3.01951975e-01,
                         -4.31284338e-01,   4.32235658e-01,   2.41704509e-01,
                         -2.46394396e-01,  -8.90067592e-03,   6.27411157e-02,
                          1.52670652e-01,   9.49820057e-02,  -3.93366277e-01,
                          1.00209869e-01,   6.61722243e-01,  -4.57798511e-01,
                         -4.95885313e-01,   8.88213694e-01,   1.88743114e-01,
                         -9.30916965e-01,   2.00652406e-01,   8.80053461e-01,
                         -4.47301656e-01,  -5.85684419e-01,   6.22048318e-01,
                          3.44286352e-01,  -4.17980522e-01,  -1.24295138e-01,
                          2.16822386e-01,   1.25075117e-01,   1.25884995e-01,
                         -2.00439170e-01,  -3.04996490e-01,   4.41490591e-01,
                          4.06222314e-01,  -6.29228234e-01,  -2.88108379e-01,
                          8.13127816e-01,   7.70675167e-02,  -7.50558972e-01,
                          3.02675545e-01,   6.58104837e-01,  -4.88973469e-01,
                         -3.74470413e-01,   5.65379679e-01,   9.60665718e-02,
                         -3.83619547e-01,   1.17182426e-01,   1.86120361e-01,
                          3.76707055e-02,  -4.87821270e-03,  -2.65016764e-01,
                          2.02017799e-01,   4.40765709e-01,  -5.52325428e-01,
                         -2.26176441e-01,   8.76484811e-01,  -3.54559422e-02,
                         -9.11862075e-01,   5.26605785e-01,   7.19939411e-01,
                         -7.46300519e-01,  -3.16258579e-01,   8.06883454e-01,
                          1.25682086e-01,  -6.10950708e-01,   6.63275272e-02,
                          3.90148818e-01,   1.14718114e-03,  -7.01255649e-02,
                         -1.53631881e-01,  -4.98604737e-02,   4.65923846e-01,
                          1.59478471e-01,  -6.35531902e-01,   2.20939983e-02,
                          8.07852030e-01,  -2.42920876e-01,  -6.57206833e-01,
                          5.65383017e-01,   5.35232306e-01,  -6.87910676e-01,
                         -1.89198866e-01,   6.83141708e-01,  -8.10789689e-02,
                         -4.18146282e-01,   2.59996414e-01,   2.23188028e-01,
                         -9.86037254e-02,  -3.49660069e-02,  -7.95875862e-02,
                          2.21454889e-01,   2.51452476e-01,  -5.09311378e-01,
                         -3.56473476e-02,   8.10952246e-01,  -3.38410199e-01,
                         -7.17040360e-01,   7.81864285e-01,   4.51004982e-01,
                         -9.20651257e-01,  -2.86859064e-03,   8.68964791e-01,
                         -1.97840557e-01,  -6.52381003e-01,   3.58282983e-01,
                          3.98603886e-01,  -2.16730192e-01,  -1.52863890e-01,
                          1.94686539e-02,   9.49193537e-02,   3.22977573e-01,
                         -9.68874916e-02,  -5.23591876e-01,   3.07760894e-01,
                          6.27148151e-01,  -4.84670967e-01,  -5.24238825e-01,
                          7.00712383e-01,   2.45739967e-01,  -7.86198258e-01,
                          6.22521229e-02,   6.55592740e-01,  -3.41003865e-01,
                         -4.78993118e-01,   4.13374275e-01,   1.77676633e-01,
                         -2.63687044e-01,  -2.73798555e-02,   3.29219662e-02,
                          1.35516182e-01,   4.02282476e-02,  -4.30825382e-01,
                          1.09434202e-01,   5.81264436e-01,  -5.49644887e-01,
                         -4.75773543e-01,   8.67332458e-01,   4.50502448e-02,
                         -9.44409966e-01,   2.19758794e-01,   7.79999316e-01,
                         -5.30399203e-01,  -5.24028838e-01,   5.68819642e-01,
                          2.30098277e-01,  -4.79470968e-01,  -1.33013308e-01,
                          1.94038004e-01,   7.31917545e-02,   5.81122339e-02,
                         -2.42552593e-01,  -2.99375981e-01,   4.26683009e-01,
                          3.32187831e-01,  -7.01800525e-01,  -2.97981322e-01,
                          7.35469818e-01,  -4.42275070e-02,  -7.89237559e-01,
                          3.44764441e-01,   5.81045270e-01,  -5.97357988e-01,
                         -3.61987889e-01,   5.42598248e-01,  -2.38876976e-03,
                         -4.04158771e-01,   7.81437978e-02,   1.07421242e-01,
                         -2.58771740e-02,  -7.17205405e-02,  -3.04157615e-01,
                          1.90556735e-01,   3.65011543e-01,  -6.48560226e-01,
                         -2.42410138e-01,   8.23201418e-01,  -1.94175392e-01,
                         -8.98138583e-01,   5.27048349e-01,   5.48692405e-01,
                         -8.55015695e-01,  -3.26485813e-01,   7.47722805e-01,
                          2.65218690e-02,  -6.67078495e-01,   5.30822873e-02,
                          3.16923916e-01,  -8.43911991e-02,  -1.38691857e-01,
                         -2.12450534e-01,  -9.11685303e-02,   3.98407519e-01,
                          3.08489334e-02,  -7.03410745e-01,   1.81529038e-02,
                          6.78964913e-01,  -3.78547370e-01,  -7.21707642e-01,
                          5.35899401e-01,   4.33671445e-01,  -7.49631643e-01,
                         -1.63272545e-01,   6.26979232e-01,  -2.29331926e-01,
                         -5.16809523e-01,   2.14869007e-01,   1.53980136e-01,
                         -1.84611991e-01,  -1.06786184e-01,  -1.24744870e-01,
                          1.85537919e-01,   1.24301888e-01,  -5.90339243e-01,
                         -3.16187777e-02,   6.86549067e-01,  -4.66124535e-01,
                         -7.27872491e-01,   7.70730495e-01,   2.72789896e-01,
                         -9.85438049e-01,  -2.39637010e-02,   8.16268563e-01,
                         -3.02755684e-01,  -6.95172131e-01,   3.35060269e-01,
                          3.21079612e-01,  -3.24362814e-01,  -2.07148269e-01,
                         -3.56720276e-02,   4.75747138e-02,   2.34300315e-01,
                         -2.01859817e-01,  -5.29810250e-01,   3.17665786e-01,
                          5.19120097e-01,  -6.25553250e-01,  -5.23572206e-01,
                          7.41265655e-01,   1.84357047e-01,  -8.47301066e-01,
                          1.00923613e-01,   6.31368518e-01,  -4.21467483e-01,
                         -4.61364895e-01,   3.92988831e-01,   1.03822492e-01,
                         -3.19299430e-01,  -3.83052565e-02,   2.07513012e-02,
                          1.05957992e-01,  -5.78056881e-03,  -4.66305047e-01,
                          1.37609586e-01,   5.14400065e-01,  -6.27889276e-01,
                         -4.11925465e-01,   8.89546514e-01,  -2.85768211e-02,
                         -9.86364126e-01,   3.01503479e-01,   7.74867415e-01,
                         -6.62981927e-01,  -4.99058276e-01,   6.01869106e-01,
                          1.94439054e-01,  -5.00916183e-01,  -1.09017774e-01,
                          1.83871955e-01,   5.20101562e-02,   3.39484811e-02,
                         -2.68234253e-01,  -2.91738421e-01,   4.33019102e-01,
                          3.06213021e-01,  -6.97776556e-01,  -1.70314863e-01,
                          8.08105350e-01,  -1.20724417e-01,  -7.63439357e-01,
                          4.23852652e-01,   6.42507553e-01,  -5.72706878e-01,
                         -3.03910702e-01,   5.54655254e-01,  -2.51277871e-02,
                         -3.86142105e-01,   1.43327042e-01,   1.46277085e-01,
                          7.72132399e-03,  -5.52737564e-02,  -2.58531898e-01,
                          2.53943831e-01,   3.63075286e-01,  -6.18791699e-01,
                         -1.11638233e-01,   8.46998334e-01,  -2.73032576e-01,
                         -8.09075356e-01,   6.76773310e-01,   5.46313345e-01,
                         -8.11254025e-01,  -1.89172849e-01,   8.03168058e-01,
                         -2.85948105e-02,  -6.06749654e-01,   1.52612463e-01,
                          3.61523032e-01,  -5.12835570e-02,  -8.65259096e-02,
                         -1.50909573e-01,  -2.89174821e-02,   4.59675431e-01,
                          5.16342483e-02,  -6.35510802e-01,   1.50626957e-01,
                          7.39304662e-01,  -3.99907231e-01,  -6.10841036e-01,
                          6.73654079e-01,   4.23668265e-01,  -7.22260356e-01,
                         -5.19937575e-02,   6.48951769e-01,  -2.05803394e-01,
                         -3.96317869e-01,   3.25617880e-01,   1.90236986e-01,
                         -1.28798410e-01,  -3.12142428e-02,  -7.13154376e-02,
                          2.55538762e-01,   1.86053604e-01,  -5.34564435e-01,
                          6.72498494e-02,   7.72459686e-01,  -4.50918943e-01,
                         -5.54951608e-01,   8.92813385e-01,   2.85690069e-01,
                         -9.25447702e-01,   9.37572718e-02,   8.95115554e-01,
                         -3.45467478e-01,  -5.71439683e-01,   4.67553377e-01,
                          3.48072052e-01,  -2.59110421e-01,  -1.16690874e-01,
                          5.43356463e-02,   1.31841883e-01,   3.06210577e-01,
                         -1.76236823e-01,  -4.68425363e-01,   4.08220112e-01,
                          5.66438496e-01,  -5.77273667e-01,  -4.09794897e-01,
                          7.99364746e-01,   1.57205492e-01,  -7.80138910e-01,
                          2.33059585e-01,   6.49910450e-01,  -4.28397208e-01,
                         -3.44334215e-01,   5.15137792e-01,   1.23696864e-01,
                         -2.73279548e-01,   3.37078348e-02,   6.64347932e-02,
                          1.58360943e-01,   4.32724729e-02,  -3.86531740e-01,
                          2.34502524e-01,   5.51190794e-01,  -6.01463974e-01,
                         -3.09131503e-01,   9.34722304e-01,  -1.28453337e-02,
                         -9.15332019e-01,   4.16619390e-01,   7.71310449e-01,
                         -6.55988157e-01,  -4.10135597e-01,   7.07817078e-01,
                          1.80134907e-01,  -4.72276241e-01,  -2.77727898e-02,
                          2.51191705e-01,   9.88410637e-02,   7.04662576e-02,
                         -2.38057807e-01,  -2.05802083e-01,   5.01863062e-01,
                          2.84609288e-01,  -7.07998157e-01,  -1.03443168e-01,
                          8.22078347e-01,  -1.41718358e-01,  -7.27011681e-01,
                          4.73963559e-01,   5.81014752e-01,  -5.89254916e-01,
                         -2.28565007e-01,   5.95470548e-01,  -4.80927490e-02,
                         -3.74560267e-01,   1.74418271e-01,   1.78246021e-01,
                          2.90572103e-02,  -3.30400392e-02,  -2.26147547e-01,
                          2.98521489e-01,   3.25528800e-01,  -6.34503305e-01,
                         -6.25049248e-02,   8.70667398e-01,  -2.95729727e-01,
                         -7.35822499e-01,   7.32689679e-01,   5.02969623e-01,
                         -8.51178169e-01,  -1.49057493e-01,   8.16655517e-01,
                         -4.03436571e-02,  -5.73435247e-01,   1.89408943e-01,
                          3.45640451e-01,  -5.05566634e-02,  -9.09931883e-02,
                         -1.34302542e-01,   1.14031676e-02,   4.56405818e-01,
                         -1.22856116e-02,  -6.40217245e-01,   2.09627628e-01,
                          6.93497181e-01,  -4.54101294e-01,  -5.94922483e-01,
                          7.10908651e-01,   3.99995863e-01,  -7.14527667e-01,
                          9.87566449e-03,   6.49481773e-01,  -2.78287292e-01,
                         -3.89802903e-01,   3.54537934e-01,   1.93039075e-01,
                         -1.31897062e-01,  -4.58459742e-02,  -6.00234382e-02,
                          2.67387003e-01,   1.33504331e-01,  -5.42621911e-01,
                          1.44138336e-01,   7.14538932e-01,  -5.30752778e-01,
                         -5.11055052e-01,   9.16150212e-01,   1.74095884e-01,
                         -9.15947258e-01,   1.82827294e-01,   8.35185170e-01,
                         -3.83804440e-01,  -5.66227734e-01,   4.82181996e-01,
                          3.13109159e-01,  -2.80005902e-01,  -1.26495004e-01,
                          5.10944799e-02,   1.37268350e-01,   2.74879724e-01,
                         -2.19926879e-01,  -4.60293800e-01,   4.51098084e-01,
                          5.01473784e-01,  -6.41171813e-01,  -3.42627287e-01,
                          8.15697372e-01,   9.02405009e-02,  -7.43636608e-01,
                          2.75600940e-01,   6.23744071e-01,  -4.69090849e-01,
                         -3.36194307e-01,   5.00520766e-01,   7.00640678e-02,
                         -2.86340237e-01,   5.32134287e-02,   8.93401504e-02,
                          1.53194681e-01,   7.01544574e-03,  -3.96160215e-01,
                          2.77729511e-01,   4.93644774e-01,  -6.43457711e-01,
                         -2.16505691e-01,   9.10209239e-01,  -6.67137131e-02,
                         -9.26984251e-01,   5.23072064e-01,   6.95120275e-01,
                         -6.96381032e-01,  -3.27290565e-01,   6.99093401e-01,
                          1.33365422e-01,  -4.93584186e-01,   8.94956000e-04,
                          2.49112561e-01,   8.88586566e-02,   5.44407032e-02,
                         -2.63234884e-01,  -1.81070477e-01,   5.31396329e-01,
                          2.48485699e-01,  -6.95933044e-01,  -4.12494987e-02,
                          8.34470630e-01,  -2.29968816e-01,  -6.63934648e-01,
                          5.41446745e-01,   5.14595509e-01,  -6.71085477e-01,
                         -1.67179123e-01,   6.27776623e-01,  -8.36129710e-02,
                         -3.52335185e-01,   1.93732873e-01,   1.65370315e-01,
                          7.20581925e-03,  -7.26806447e-02,  -2.04140991e-01,
                          3.14774722e-01,   3.01010638e-01,  -6.33557856e-01,
                         -2.25890540e-02,   8.64624858e-01,  -3.92746478e-01,
                         -7.35095799e-01,   7.82490194e-01,   4.51203108e-01,
                         -9.00640786e-01,  -3.67703550e-02,   8.07430565e-01,
                         -1.33261383e-01,  -5.84142268e-01,   2.45812654e-01,
                          3.30757201e-01,  -9.19448659e-02,  -9.69956741e-02,
                         -1.27993971e-01,   2.31817774e-02,   4.56663847e-01,
                         -4.56474535e-02,  -6.28200233e-01,   2.63827860e-01,
                          6.88402832e-01,  -4.75133032e-01,  -5.59807718e-01,
                          6.81954682e-01,   2.49112919e-01,  -7.75230467e-01,
                          5.44923507e-02,   6.10018969e-01,  -3.26137006e-01,
                         -4.26854461e-01,   3.33819777e-01,   1.38198316e-01,
                         -1.68617964e-01,  -5.75754307e-02,  -6.25201985e-02,
                          2.34835297e-01,   7.37359673e-02,  -5.57824433e-01,
                          1.36742979e-01,   6.48773372e-01,  -6.16836607e-01,
                         -4.96590108e-01,   8.80697072e-01,   4.32646275e-02,
                         -9.38715875e-01,   1.93701595e-01,   7.62011349e-01,
                         -4.69341993e-01,  -5.21385312e-01,   4.48562980e-01,
                          2.29157686e-01,  -3.43909085e-01,  -1.42507315e-01,
                          2.04739720e-02,   9.76421759e-02,   2.21079677e-01,
                         -2.69786805e-01,  -4.31062102e-01,   4.60800856e-01,
                          4.25047040e-01,  -7.31840312e-01,  -3.50343645e-01,
                          7.47083545e-01,  -2.45890301e-02,  -7.89466619e-01,
                          3.24712604e-01,   5.44958949e-01,  -5.60789108e-01,
                         -3.30714256e-01,   4.67053980e-01,  -1.99885108e-03,
                         -3.27685446e-01,   1.81153789e-02,   5.15739247e-02,
                          9.87498313e-02,  -7.12402835e-02,  -4.16201442e-01,
                          2.69016832e-01,   4.10372734e-01,  -7.45227039e-01,
                         -2.20668077e-01,   8.67336214e-01,  -2.19834447e-01,
                         -9.03538942e-01,   5.30389428e-01,   5.42350233e-01,
                         -7.87043095e-01,  -3.43801349e-01,   6.70557320e-01,
                          5.59719838e-02,  -5.47435284e-01,  -1.64751150e-02,
                          1.71539724e-01,   2.74475981e-02,  -6.40759850e-03,
                         -3.25548559e-01,  -2.05323905e-01,   5.07310510e-01,
                          1.27516508e-01,  -7.68660367e-01,  -4.57749330e-02,
                          7.18928039e-01,  -3.50384414e-01,  -7.18838871e-01,
                          5.18005490e-01,   4.24079329e-01,  -7.09170938e-01,
                         -1.48499474e-01,   5.49229562e-01,  -2.04858556e-01,
                         -4.25672770e-01,   1.42274201e-01,   9.63173807e-02,
                         -5.66216484e-02,  -1.14605732e-01,  -2.46478856e-01,
                          2.83766448e-01,   1.74019337e-01,  -7.03094482e-01,
                          3.51400406e-04,   7.58783638e-01,  -5.10268688e-01,
                         -7.33762264e-01,   7.87515044e-01,   2.67333776e-01,
                         -9.52074409e-01,  -4.46421579e-02,   7.63664007e-01,
                         -2.49053329e-01,  -6.27280116e-01,   2.31050372e-01,
                          2.50414342e-01,  -1.75670236e-01,  -1.49064988e-01,
                         -2.00004905e-01,   2.10599319e-04,   4.03528184e-01,
                         -1.34017542e-01,  -6.37700200e-01,   3.06885660e-01,
                          5.93126595e-01,  -5.96612096e-01,  -5.48718572e-01,
                          7.14953303e-01,   1.95607364e-01,  -7.79441714e-01,
                          9.57413912e-02,   5.64968407e-01,  -3.87353510e-01,
                         -3.83067727e-01,   3.10582787e-01,   5.92941642e-02,
                         -1.99139699e-01,  -7.92544261e-02,  -7.59940296e-02,
                          2.25241199e-01,   2.79114358e-02,  -5.91201961e-01,
                          2.06899881e-01,   5.71752071e-01,  -6.88555717e-01,
                         -3.94172758e-01,   9.17843103e-01,  -3.16472650e-02,
                         -9.59526777e-01,   2.88291097e-01,   7.41395950e-01,
                         -5.68377316e-01,  -4.77068573e-01,   4.88604516e-01,
                          1.99146926e-01,  -3.59973162e-01,  -1.31623641e-01,
                          3.06382440e-02,   9.47494954e-02,   1.91524833e-01,
                         -3.17733556e-01,  -4.20894355e-01,   4.78041798e-01,
                          3.87609839e-01,  -7.06675351e-01,  -2.10041076e-01,
                          7.94198275e-01,  -7.36545920e-02,  -7.29358435e-01,
                          3.84043902e-01,   5.86941183e-01,  -5.27488410e-01,
                         -2.58148730e-01,   4.72698510e-01,  -3.01282555e-02,
                         -2.78802037e-01,   7.98989460e-02,   7.75327832e-02,
                          1.32033885e-01,  -5.35508990e-02,  -3.66287887e-01,
                          3.55390102e-01,   4.26811546e-01,  -7.11860061e-01,
                         -7.73251578e-02,   9.02430415e-01,  -2.81954437e-01,
                         -8.18813264e-01,   6.67810678e-01,   5.49352407e-01,
                         -7.35314667e-01,  -1.96386069e-01,   7.20998704e-01,
                          3.24516818e-02,  -4.91184294e-01,   7.22233504e-02,
                          2.50212491e-01,   7.17602223e-02,   3.15388478e-02,
                         -2.62491852e-01,  -1.14975743e-01,   5.76403081e-01,
                          1.42883703e-01,  -6.90382421e-01,   8.49181190e-02,
                          7.76291430e-01,  -3.54881316e-01,  -5.96596003e-01,
                          6.48443520e-01,   4.16399002e-01,  -6.61785126e-01,
                         -2.34650094e-02,   5.78936517e-01,  -1.83147028e-01,
                         -3.04611772e-01,   2.55139261e-01,   1.43733829e-01,
                         -1.32850476e-03,  -6.03355430e-02,  -1.75689846e-01,
                          3.83868337e-01,   2.24787012e-01,  -6.42205954e-01,
                          1.25410393e-01,   8.43028724e-01,  -4.93662208e-01,
                         -5.47864377e-01,   8.93989682e-01,   3.01273078e-01,
                         -8.75110924e-01,   6.84961155e-02,   8.43102396e-01,
                         -2.38074571e-01,  -5.01166046e-01,   3.50856066e-01,
                          3.09834391e-01,  -1.04215048e-01,  -7.39503130e-02,
                         -1.00947924e-01,   9.35409889e-02,   4.65634257e-01,
                         -1.43008783e-01,  -5.59604764e-01,   4.02796924e-01,
                          6.39716029e-01,  -5.42750120e-01,  -4.32424545e-01,
                          7.76371717e-01,   1.82142377e-01,  -7.29955614e-01,
                          2.36421242e-01,   5.94501615e-01,  -3.64407212e-01,
                         -2.68171281e-01,   4.26327378e-01,   9.32051241e-02,
                         -1.51712492e-01,   4.81997500e-04,  -1.03772804e-02,
                          2.94487566e-01,   3.73170786e-02,  -5.24361730e-01,
                          3.22407156e-01,   6.14120066e-01,  -6.84777319e-01,
                         -2.90161401e-01,   9.90807891e-01,  -2.87836846e-02,
                         -9.11449015e-01,   4.04137790e-01,   7.47045815e-01,
                         -5.61983883e-01,  -3.87761742e-01,   5.93031228e-01,
                          2.00090721e-01,  -3.14266205e-01,  -6.64895475e-02,
                          9.52152759e-02,   1.61099210e-01,   2.19730765e-01,
                         -2.89174050e-01,  -3.18422437e-01,   5.71091235e-01,
                          3.64465803e-01,  -7.40292609e-01,  -1.45981729e-01,
                          8.37125719e-01,  -1.10118277e-01,  -6.94301367e-01,
                          4.55505848e-01,   5.47671437e-01,  -5.24606049e-01,
                         -1.80730969e-01,   5.04694462e-01,  -4.25797738e-02,
                         -2.73593575e-01,   1.05504654e-01,   1.06832191e-01,
                          1.66763350e-01,  -5.74611090e-02,  -3.33821833e-01,
                          3.95813376e-01,   3.68285298e-01,  -7.54071355e-01,
                         -1.39512336e-02,   9.37302947e-01,  -3.29013467e-01,
                         -7.43424773e-01,   7.37728655e-01,   4.86444920e-01,
                         -7.99422801e-01,  -1.52673051e-01,   7.31035173e-01,
                          7.49197649e-03,  -4.49659646e-01,   1.00692064e-01,
                          2.31603175e-01,   6.86633587e-02,   2.77719907e-02,
                         -2.73006648e-01,  -9.25440490e-02,   5.68368256e-01,
                          4.47482541e-02,  -7.13852763e-01,   1.83230728e-01,
                          7.31792688e-01,  -4.54886109e-01,  -6.05690718e-01,
                          6.83470488e-01,   3.81391317e-01,  -6.62351429e-01,
                          1.04175601e-02,   5.74797928e-01,  -2.51962662e-01,
                         -3.08981240e-01,   2.55131781e-01,   1.40505359e-01,
                         -1.38061093e-02,  -9.06903222e-02,  -1.69118226e-01,
                          3.84678334e-01,   1.39213219e-01,  -6.57029688e-01,
                          2.00182483e-01,   7.71428525e-01,  -6.13796949e-01,
                         -5.17223656e-01,   9.30920660e-01,   1.55862674e-01,
                         -9.06273365e-01,   1.40897945e-01,   7.81718791e-01,
                         -3.18732113e-01,  -5.05208611e-01,   3.54097337e-01,
                          2.67127275e-01,  -1.28743052e-01,  -9.54578370e-02,
                         -1.30977258e-01,   1.03484683e-01,   4.30859149e-01,
                         -2.19861686e-01,  -5.80042779e-01,   4.41631347e-01,
                          5.64783037e-01,  -6.69348240e-01,  -3.90410125e-01,
                          7.91211247e-01,   9.89509076e-02,  -7.37233996e-01,
                          2.69585967e-01,   5.68657219e-01,  -4.43385720e-01,
                         -2.92888969e-01,   3.90782595e-01,   5.53627685e-02,
                         -1.70974538e-01,  -1.99986659e-02,  -6.76781638e-03,
                          2.76719481e-01,  -2.21603041e-04,  -5.49090564e-01,
                          3.65629643e-01,   5.31691909e-01,  -7.54642844e-01,
                         -2.16810316e-01,   9.45833325e-01,  -9.08720717e-02,
                         -9.45307255e-01,   4.95536327e-01,   6.70080364e-01,
                         -6.49844825e-01,  -3.42107147e-01,   5.88277161e-01,
                          1.53698981e-01,  -3.58317107e-01,  -7.49209300e-02,
                          7.12207407e-02,   1.63192809e-01,   1.88934848e-01,
                         -3.41303706e-01,  -3.02543342e-01,   5.89373767e-01,
                          3.19025606e-01,  -7.31117487e-01,  -7.78642222e-02,
                          8.34817827e-01,  -2.32149720e-01,  -6.62907004e-01,
                          5.26826203e-01,   4.65721220e-01,  -6.21443331e-01,
                         -1.29952237e-01,   5.24919033e-01,  -8.00986215e-02,
                         -2.50200570e-01,   1.08889706e-01,   7.66287223e-02,
                          1.46447033e-01,  -8.13007653e-02,  -3.25164586e-01,
                          4.20682162e-01,   3.28695059e-01,  -7.53064215e-01,
                          1.80736405e-03,   9.21104252e-01,  -4.36403662e-01,
                         -7.44733930e-01,   7.80194700e-01,   4.41005021e-01,
                         -8.58861208e-01,  -6.89353198e-02,   7.38184094e-01,
                         -8.78564939e-02,  -5.00645101e-01,   1.26824230e-01,
                          2.34267354e-01,   4.92286943e-02,  -2.01252736e-02,
                         -2.81175107e-01,  -4.50080037e-02,   5.78142822e-01,
                          1.62077660e-03,  -7.25469768e-01,   2.42311746e-01,
                          7.20067143e-01,  -4.80044574e-01,  -5.74350953e-01,
                          6.72221720e-01,   2.24674255e-01,  -7.41198123e-01,
                          6.09489046e-02,   5.44504583e-01,  -2.92786717e-01,
                         -3.28981578e-01,   2.34814718e-01,   8.07023942e-02,
                         -4.29343730e-02,  -1.14560090e-01,  -1.66572794e-01,
                          3.64500076e-01,   8.86702538e-02,  -6.79742932e-01,
                          1.89539909e-01,   6.86541319e-01,  -6.63575530e-01,
                         -4.97972071e-01,   8.96256685e-01,   4.95836884e-02,
                         -9.11991835e-01,   1.49396524e-01,   7.12815583e-01,
                         -3.90467405e-01,  -4.87545162e-01,   3.23217362e-01,
                          1.85443163e-01,  -1.89191967e-01,  -1.39806688e-01,
                         -1.45235449e-01,   9.49606225e-02,   3.67969900e-01,
                         -2.74237901e-01,  -5.60020983e-01,   4.64175493e-01,
                          5.09845614e-01,  -7.46880531e-01,  -3.89732599e-01,
                          7.52082050e-01,  -1.85541715e-02,  -7.66384482e-01,
                          3.17987233e-01,   4.94375616e-01,  -5.11850834e-01,
                         -2.68666148e-01,   3.68766576e-01,  -2.12243814e-02,
                         -1.97067842e-01,  -6.93186000e-02,  -4.02870402e-02,
                          2.28960544e-01,  -8.30010995e-02,  -5.59996784e-01,
                          3.22823256e-01,   4.25135046e-01,  -7.29192674e-01,
                         -1.61454096e-01,   7.91350782e-01,  -1.66616887e-01,
                         -7.64084220e-01,   3.69486988e-01,   4.48222488e-01,
                         -5.32308757e-01,  -2.36172900e-01,   4.22579914e-01,
                          5.62756136e-02,  -3.08251739e-01,  -7.23626539e-02,
                          2.12443024e-02,   7.52103105e-02,   7.81625435e-02,
                         -2.44818836e-01,  -1.84375197e-01,   3.43330264e-01,
                          1.32376999e-01,  -4.29605961e-01,  -4.85551693e-02,
                          3.99019659e-01,  -1.71895772e-01,  -3.66243035e-01,
                          1.74398705e-01,   1.66372478e-01,  -2.71166116e-01,
                         -4.72339541e-02,   1.73342884e-01,  -6.78873062e-02,
                         -1.15242444e-01,   7.21284468e-03,  -1.00490013e-02,
                          6.40357984e-03,  -5.59188053e-02,  -1.03268690e-01,
                          9.69104469e-02,   2.68180277e-02,  -1.84381709e-01,
                         -2.96586175e-02,   1.22160621e-01,  -6.84340596e-02,
                         -1.18358426e-01,   7.56306127e-02,  -3.69493812e-02,
                         -5.78372926e-02,  -3.72501463e-02,   2.02914234e-02,
                         -2.35701278e-02,  -2.03870442e-02,  -2.69200671e-02,
                         -2.55803671e-02,  -2.92499512e-02,  -2.16945652e-02,
                         -1.60218161e-02,  -2.06623599e-02,  -2.77295653e-02,
                         -1.85808446e-02,  -2.26815287e-02,  -1.92347616e-02,
                         -9.79337469e-03,  -2.37158481e-02,  -2.30227951e-02,
                         -1.47885382e-02,  -2.65755914e-02,  -2.47708801e-02,
                         -1.57960113e-02,  -2.04677563e-02,  -2.19781008e-02,
                         -2.31556911e-02,  -1.80422086e-02,  -1.85184777e-02,
                         -2.17501298e-02,  -2.57606786e-02,  -9.50257014e-03,
                         -1.67878456e-02,  -1.97529383e-02,  -1.20028146e-02,
                         -1.93497296e-02,  -2.57135145e-02,  -1.75377689e-02,
                         -2.50004996e-02,  -1.84719507e-02,  -1.47221517e-02,
                         -1.80970151e-02,  -2.40750238e-02,  -1.76676176e-02,
                         -1.24619855e-02,  -1.91105120e-02,  -2.11735740e-02,
                         -1.33574372e-02,  -1.33566372e-02,  -2.35665739e-02,
                         -1.39659625e-02,  -1.58700421e-02,  -1.66226476e-02,
                         -1.50946183e-02,  -1.57235004e-02,  -1.60560515e-02,
                         -1.21119004e-02,  -1.83339845e-02,  -1.64643750e-02,
                         -1.40722943e-02,  -1.94942150e-02,  -1.71066802e-02,
                         -2.06591319e-02,  -1.01000415e-02,  -1.73137672e-02,
                         -1.77725833e-02,  -1.09337633e-02,  -6.87932130e-03,
                         -2.10578870e-02,  -1.92034412e-02,  -1.57539807e-02,
                         -1.30737498e-02,  -1.50288390e-02,  -1.07052261e-02,
                         -1.56719349e-02,  -1.60900448e-02,  -1.20978802e-02,
                         -1.32225174e-02,  -1.14561925e-02,  -1.28784459e-02,
                         -1.46174701e-02,  -1.34536866e-02,  -1.19013824e-02,
                         -1.01386402e-02,  -1.65710095e-02,  -1.44038033e-02,
                         -1.07465889e-02,  -1.06880469e-02,  -9.13406257e-03,
                         -8.00686423e-03,  -1.17683560e-02,  -1.49317291e-02,
                         -1.22825447e-02,  -1.05163101e-02,  -1.02886232e-02,
                         -9.85199679e-03,  -8.60977080e-03,  -1.01596862e-02,
                         -1.33278072e-02,  -1.13678286e-02,  -8.90456326e-03,
                         -8.78325943e-03,  -9.27873049e-03], dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri2",
    rate = 41000,
    data = numpy.array([  3.45277903e-03,   1.05040532e-03,  -1.70586747e-03,
                         -4.20548022e-03,  -8.46356095e-04,  -1.27851171e-02,
                          7.28679588e-03,   3.74309383e-02,  -1.13154645e-03,
                         -4.96725067e-02,   5.57878017e-02,  -1.03407223e-02,
                         -1.07655369e-01,   1.14796702e-02,   1.19533427e-01,
                         -5.54141477e-02,  -1.01145893e-01,   8.16244707e-02,
                          4.92093936e-02,  -1.02504432e-01,  -3.08566652e-02,
                          5.36649562e-02,   6.71367627e-03,  -7.43500656e-03,
                         -3.56725231e-02,  -6.16267733e-02,   7.98781142e-02,
                          7.29599521e-02,  -1.90582216e-01,  -1.32074073e-01,
                          2.25889936e-01,   7.07712322e-02,  -2.69882083e-01,
                          2.97672935e-02,   1.82538733e-01,  -2.61630714e-01,
                         -2.26548702e-01,   2.30113655e-01,   6.06124848e-02,
                         -2.40811601e-01,   1.63522400e-02,   8.66633952e-02,
                         -6.19831979e-02,  -5.31105511e-02,  -1.26621962e-01,
                          1.93309318e-02,   2.09057137e-01,  -2.68404514e-01,
                         -2.45373413e-01,   4.77214187e-01,  -4.51506861e-02,
                         -6.50430262e-01,   2.17066258e-01,   5.43692350e-01,
                         -5.34489632e-01,  -3.64954889e-01,   5.24222195e-01,
                          9.01661962e-02,  -5.76818228e-01,  -3.55105251e-02,
                          3.03016126e-01,  -7.06612542e-02,  -1.71655580e-01,
                         -1.04319565e-01,  -5.79721332e-02,   2.44282231e-01,
                          8.16416368e-02,  -5.22895157e-01,  -1.03766464e-01,
                          6.04311168e-01,  -1.68965325e-01,  -6.59630597e-01,
                          3.99846017e-01,   5.23989022e-01,  -6.25991523e-01,
                         -3.02477747e-01,   6.25772536e-01,  -2.77551077e-02,
                         -5.03113806e-01,   2.20991656e-01,   2.38232061e-01,
                         -2.28669435e-01,  -1.21373363e-01,  -4.54198122e-02,
                          1.16045512e-01,   1.97224647e-01,  -4.39357072e-01,
                         -1.55625656e-01,   6.97640240e-01,  -2.24025682e-01,
                         -7.99672484e-01,   6.11659229e-01,   5.14992177e-01,
                         -9.38042760e-01,  -1.83787704e-01,   8.69770706e-01,
                         -1.37512863e-01,  -7.72990108e-01,   2.70528823e-01,
                          4.40984905e-01,  -3.08033794e-01,  -2.68208206e-01,
                          6.05107136e-02,   8.29987973e-02,   1.93407997e-01,
                         -1.12026393e-01,  -4.99840766e-01,   2.02589318e-01,
                          5.72574794e-01,  -4.81179655e-01,  -6.18008554e-01,
                          6.41678751e-01,   3.87616336e-01,  -7.93822825e-01,
                         -1.09777756e-01,   6.82122350e-01,  -2.82508165e-01,
                         -5.54663420e-01,   3.82735133e-01,   2.31046721e-01,
                         -3.67535353e-01,  -6.68638647e-02,   9.58374441e-02,
                          4.83531505e-02,   3.35652456e-02,  -3.55480552e-01,
                         -1.91253759e-02,   5.64694107e-01,  -4.14704442e-01,
                         -5.72619617e-01,   7.47521043e-01,   2.04774469e-01,
                         -9.67304647e-01,   1.21630654e-01,   8.32334697e-01,
                         -4.79510069e-01,  -7.03269064e-01,   5.92694581e-01,
                          3.18951100e-01,  -5.52154541e-01,  -1.87344089e-01,
                          2.78145015e-01,   6.56111911e-02,  -3.95714492e-02,
                         -1.96468204e-01,  -2.85669148e-01,   3.43266129e-01,
                          3.30491424e-01,  -6.15193963e-01,  -3.30924153e-01,
                          7.60344982e-01,   1.07454725e-01,  -7.87331641e-01,
                          2.40904048e-01,   6.70279682e-01,  -5.06359339e-01,
                         -4.67108488e-01,   5.93298376e-01,   1.33736640e-01,
                         -4.75825220e-01,   7.89919794e-02,   2.13446766e-01,
                         -5.11648022e-02,  -4.81042489e-02,  -1.94193259e-01,
                          1.13078609e-01,   3.76497120e-01,  -4.61221725e-01,
                         -3.26463312e-01,   8.04145932e-01,  -1.04969963e-02,
                         -9.19380784e-01,   4.47907180e-01,   6.85013235e-01,
                         -7.43413746e-01,  -3.82718027e-01,   8.37224305e-01,
                          9.84931141e-02,  -6.92089200e-01,   5.10662422e-02,
                          4.47114080e-01,  -6.98699802e-02,  -1.65601090e-01,
                         -8.85941014e-02,  -2.41770782e-02,   3.50155562e-01,
                          1.05341248e-01,  -5.72395682e-01,   7.17532239e-04,
                          7.58213460e-01,  -2.06311196e-01,  -7.23759174e-01,
                          4.75056797e-01,   5.94578564e-01,  -6.38631284e-01,
                         -2.04394639e-01,   7.37142920e-01,  -4.68348563e-02,
                         -4.87330854e-01,   2.91560024e-01,   3.14206839e-01,
                         -1.78301349e-01,  -6.69806227e-02,   3.87392053e-03,
                          1.77196518e-01,   2.38418683e-01,  -4.15352494e-01,
                         -2.58050431e-02,   7.53786862e-01,  -2.16034606e-01,
                         -6.95063055e-01,   7.24165797e-01,   5.13125300e-01,
                         -8.67378712e-01,  -2.09527146e-02,   9.32714581e-01,
                         -1.69118971e-01,  -6.67950749e-01,   4.14068401e-01,
                          4.87088054e-01,  -2.55553097e-01,  -1.65169343e-01,
                          1.34871647e-01,   1.49270803e-01,   2.45243743e-01,
                         -7.33437091e-02,  -4.10985917e-01,   3.27896923e-01,
                          6.36853039e-01,  -4.27745491e-01,  -4.95394677e-01,
                          7.57143199e-01,   4.09890652e-01,  -7.14125037e-01,
                          5.62851764e-02,   7.77591169e-01,  -2.73076385e-01,
                         -4.39943522e-01,   5.16811550e-01,   2.83729225e-01,
                         -2.99236387e-01,   2.97751240e-02,   1.80199504e-01,
                          1.32470265e-01,   9.48733091e-02,  -2.78157353e-01,
                          1.25320390e-01,   6.28428221e-01,  -3.81909698e-01,
                         -4.43359435e-01,   8.93710732e-01,   2.27871194e-01,
                         -8.76133084e-01,   2.55378604e-01,   9.31427896e-01,
                         -4.46870834e-01,  -5.11173487e-01,   7.14200795e-01,
                          3.83385688e-01,  -4.77363318e-01,  -7.99684823e-02,
                          3.73977542e-01,   1.42142683e-01,   6.03619628e-02,
                         -1.17989793e-01,  -1.43466845e-01,   4.66609210e-01,
                          3.95295322e-01,  -5.69778442e-01,  -1.99867442e-01,
                          8.47783029e-01,   4.25290950e-02,  -7.55470216e-01,
                          3.37205738e-01,   7.24393070e-01,  -4.70124155e-01,
                         -3.49598169e-01,   6.60608411e-01,   1.42135784e-01,
                         -4.22312170e-01,   1.76351428e-01,   2.67908961e-01,
                         -4.74137394e-03,   4.89683403e-03,  -1.33599356e-01,
                          2.15920120e-01,   4.19395834e-01,  -4.50606078e-01,
                         -1.98323369e-01,   8.58550012e-01,  -5.33974431e-02,
                         -8.06105375e-01,   5.64875424e-01,   6.98979497e-01,
                         -7.42307603e-01,  -2.74074286e-01,   8.92178297e-01,
                          1.13375686e-01,  -6.48790896e-01,   1.30569905e-01,
                          4.86295402e-01,  -4.84334342e-02,  -1.23895489e-01,
                         -4.64116372e-02,   4.32465859e-02,   4.09194976e-01,
                          9.27366167e-02,  -5.71217835e-01,   8.64138603e-02,
                          7.45480835e-01,  -2.85648048e-01,  -6.51303530e-01,
                          6.02628648e-01,   5.43668628e-01,  -7.10423350e-01,
                         -1.70567572e-01,   7.41047919e-01,  -9.02513713e-02,
                         -4.84871000e-01,   3.18350077e-01,   2.88965076e-01,
                         -1.69492006e-01,  -4.81474400e-02,   1.34728970e-02,
                          1.82961732e-01,   2.01252893e-01,  -4.27263439e-01,
                         -3.88478376e-02,   7.58830011e-01,  -3.10674995e-01,
                         -6.42704844e-01,   7.63019323e-01,   3.88783127e-01,
                         -9.44765389e-01,   1.35756955e-02,   9.22403336e-01,
                         -2.28080511e-01,  -6.40063167e-01,   4.37817037e-01,
                          4.32098567e-01,  -3.20380181e-01,  -1.98080972e-01,
                          1.18720174e-01,   1.21456183e-01,   2.15223670e-01,
                         -1.18020847e-01,  -4.03894216e-01,   3.39478999e-01,
                          5.42267263e-01,  -5.33899069e-01,  -5.11844933e-01,
                          7.18941271e-01,   2.47223988e-01,  -8.16647112e-01,
                          6.54987097e-02,   6.95927918e-01,  -3.80974740e-01,
                         -4.91546571e-01,   4.77912635e-01,   2.03832328e-01,
                         -3.64802748e-01,  -1.51122352e-02,   1.09447956e-01,
                          6.09093830e-02,  -3.03264544e-03,  -3.41587812e-01,
                          7.57328272e-02,   5.34385562e-01,  -4.86101598e-01,
                         -4.72565293e-01,   8.30871999e-01,   5.13995923e-02,
                         -9.56648648e-01,   2.91946471e-01,   7.98916638e-01,
                         -6.29030108e-01,  -5.45903265e-01,   6.88258290e-01,
                          2.25124508e-01,  -5.75647533e-01,  -1.05224110e-01,
                          2.83032060e-01,   3.90111990e-02,  -4.90285493e-02,
                         -2.04777852e-01,  -2.22988859e-01,   3.97568464e-01,
                          2.74439514e-01,  -6.78164601e-01,  -2.04449773e-01,
                          7.81471729e-01,  -9.28459391e-02,  -8.64624977e-01,
                          3.21941972e-01,   5.97404957e-01,  -6.19900465e-01,
                         -3.74424130e-01,   5.94968855e-01,   1.22741489e-02,
                         -4.78905886e-01,   1.03172950e-01,   1.71814203e-01,
                         -1.10882640e-01,  -9.58869755e-02,  -2.06494927e-01,
                          1.40487328e-01,   3.20921540e-01,  -5.68721294e-01,
                         -2.39370868e-01,   7.68999517e-01,  -1.91133037e-01,
                         -8.98790002e-01,   5.82852066e-01,   5.49580514e-01,
                         -8.76238048e-01,  -2.78496802e-01,   8.04116786e-01,
                         -1.97082702e-02,  -7.39992797e-01,   1.13127120e-01,
                          3.87704700e-01,  -1.54940411e-01,  -1.98428720e-01,
                         -1.11563697e-01,  -3.09664793e-02,   3.26613456e-01,
                         -1.50704170e-02,  -6.33462071e-01,   9.18552652e-02,
                          6.94854259e-01,  -4.19658393e-01,  -6.80007279e-01,
                          5.83126843e-01,   4.60696101e-01,  -7.53040791e-01,
                         -1.61525249e-01,   6.70553625e-01,  -2.14515731e-01,
                         -5.08532226e-01,   2.92402595e-01,   1.98238790e-01,
                         -2.57708132e-01,  -8.95911753e-02,  -2.90500876e-02,
                          1.35087296e-01,   1.22979239e-01,  -4.90219027e-01,
                         -2.94633172e-02,   6.68486774e-01,  -4.09592271e-01,
                         -6.48773015e-01,   7.63804138e-01,   2.97102153e-01,
                         -9.86493111e-01,   5.56210196e-03,   8.74511063e-01,
                         -3.84928435e-01,  -6.98536038e-01,   4.30570006e-01,
                          3.68407488e-01,  -3.90116662e-01,  -2.03476384e-01,
                          9.28237140e-02,   6.81924149e-02,   1.64111525e-01,
                         -2.05937073e-01,  -4.43227857e-01,   3.33783776e-01,
                          4.85575587e-01,  -6.00709498e-01,  -4.59530443e-01,
                          7.48323798e-01,   1.79956675e-01,  -8.29276383e-01,
                          1.13405824e-01,   6.57478631e-01,  -4.26853269e-01,
                         -4.83402610e-01,   4.58793193e-01,   9.03532133e-02,
                         -3.91375333e-01,   2.65217107e-03,   9.58905295e-02,
                          3.87025513e-02,  -1.96387973e-02,  -3.61559987e-01,
                          9.90922824e-02,   4.79755700e-01,  -5.46640992e-01,
                         -4.13076460e-01,   8.58468056e-01,  -1.55786565e-02,
                         -9.63608801e-01,   3.17790121e-01,   7.23732412e-01,
                         -6.77174866e-01,  -5.03639877e-01,   6.71398103e-01,
                          1.54185727e-01,  -5.98790944e-01,  -9.15787071e-02,
                          2.75076300e-01,   1.33160111e-02,  -5.94906397e-02,
                         -2.43767262e-01,  -1.83909282e-01,   3.94595653e-01,
                          1.91029951e-01,  -6.87710106e-01,  -1.62616327e-01,
                          7.72832632e-01,  -1.28023669e-01,  -7.68912494e-01,
                          4.13665473e-01,   5.72004616e-01,  -6.67249382e-01,
                         -3.63127053e-01,   5.84295154e-01,  -4.04029191e-02,
                         -4.64809209e-01,   1.59859449e-01,   1.81063995e-01,
                         -1.20269910e-01,  -8.42166469e-02,  -2.04813331e-01,
                          1.60167933e-01,   2.72204936e-01,  -5.73193431e-01,
                         -1.57363936e-01,   7.89315104e-01,  -2.68197358e-01,
                         -8.27271104e-01,   6.32479906e-01,   4.98925924e-01,
                         -9.14196730e-01,  -2.15401590e-01,   8.04658532e-01,
                         -7.40134418e-02,  -6.97111428e-01,   1.63071766e-01,
                          3.61402273e-01,  -1.80798411e-01,  -1.92523912e-01,
                         -1.07068986e-01,   1.28426356e-02,   3.24192494e-01,
                         -6.68283254e-02,  -6.32052660e-01,   1.70978472e-01,
                          6.41355157e-01,  -4.76157248e-01,  -6.55746520e-01,
                          6.27647161e-01,   3.78882796e-01,  -7.81544805e-01,
                         -1.09984383e-01,   6.21624887e-01,  -2.58157939e-01,
                         -5.03434896e-01,   3.12303066e-01,   1.87507555e-01,
                         -2.63308287e-01,  -8.26107562e-02,  -5.11339419e-02,
                          1.43956646e-01,   9.52294171e-02,  -5.01686871e-01,
                         -4.61945357e-03,   6.64164603e-01,  -5.00960052e-01,
                         -6.04241133e-01,   8.03112030e-01,   1.82750240e-01,
                         -9.77151692e-01,   9.69783589e-02,   8.17444324e-01,
                         -4.46467429e-01,  -6.58354938e-01,   4.68655616e-01,
                          3.03664237e-01,  -4.16108012e-01,  -1.91355839e-01,
                          9.09462199e-02,   8.20779502e-02,   1.34698212e-01,
                         -2.52653033e-01,  -4.26519454e-01,   3.92731667e-01,
                          4.06006843e-01,  -6.52582288e-01,  -3.93822700e-01,
                          7.65908003e-01,   1.25128731e-01,  -7.79330850e-01,
                          2.26239488e-01,   6.32884383e-01,  -4.86829430e-01,
                         -4.26341861e-01,   5.10810435e-01,   1.06334537e-01,
                         -3.76266211e-01,   2.42643189e-02,   1.13287248e-01,
                          5.38825169e-02,  -2.18998939e-02,  -3.33284050e-01,
                          1.52221352e-01,   4.51733857e-01,  -5.76372445e-01,
                         -3.34250927e-01,   8.71499777e-01,  -4.85158414e-02,
                         -9.35717106e-01,   4.58567590e-01,   6.75156474e-01,
                         -7.25057960e-01,  -3.81992698e-01,   7.44801700e-01,
                          1.27835333e-01,  -5.85965097e-01,  -2.13062577e-02,
                          3.08164537e-01,   4.35019918e-02,  -4.81504649e-02,
                         -2.32523799e-01,  -1.24837384e-01,   4.42875683e-01,
                          1.81356221e-01,  -6.44182384e-01,  -5.84928580e-02,
                          7.96000242e-01,  -1.78521127e-01,  -7.34413028e-01,
                          4.48262453e-01,   5.81677318e-01,  -6.01980031e-01,
                         -1.97239622e-01,   6.63756609e-01,  -4.46365438e-02,
                         -4.15759295e-01,   2.16996089e-01,   2.29725391e-01,
                         -6.10780604e-02,  -5.14203422e-02,  -1.39041856e-01,
                          2.47983009e-01,   3.01855981e-01,  -5.50273418e-01,
                         -2.39446424e-02,   8.27096224e-01,  -2.63096958e-01,
                         -7.20360518e-01,   7.46123791e-01,   4.90411371e-01,
                         -8.62817228e-01,  -3.53792571e-02,   8.70904207e-01,
                         -1.22867271e-01,  -6.05942309e-01,   3.11983556e-01,
                          4.14800048e-01,  -1.20342709e-01,  -1.14427820e-01,
                         -4.41542491e-02,   1.08385593e-01,   4.02747512e-01,
                         -4.96027358e-02,  -5.45889735e-01,   3.02800000e-01,
                          7.21456349e-01,  -4.30362046e-01,  -5.46955884e-01,
                          7.33890295e-01,   4.23644960e-01,  -6.85480535e-01,
                          4.80134748e-02,   7.12022960e-01,  -2.46276170e-01,
                         -3.80653620e-01,   4.46166545e-01,   2.32412547e-01,
                         -1.87374786e-01,   6.92750048e-03,   6.12853058e-02,
                          2.34656036e-01,   1.43891022e-01,  -4.09524590e-01,
                          1.47541240e-01,   7.08814383e-01,  -4.55899715e-01,
                         -4.63729411e-01,   9.44563687e-01,   2.11747378e-01,
                         -8.81807148e-01,   2.36068577e-01,   9.06489253e-01,
                         -4.03913856e-01,  -4.79443401e-01,   6.11688018e-01,
                          3.65683824e-01,  -3.32323164e-01,  -9.77808461e-02,
                          2.09941477e-01,   1.77563563e-01,   2.24048704e-01,
                         -1.67329550e-01,  -2.95926511e-01,   5.20198345e-01,
                          4.94335145e-01,  -6.02787852e-01,  -2.64339358e-01,
                          8.59766960e-01,   7.78622627e-02,  -7.50372589e-01,
                          3.25562924e-01,   6.85040414e-01,  -4.13770884e-01,
                         -3.23759913e-01,   5.78505099e-01,   1.31144077e-01,
                         -3.18110824e-01,   1.12839557e-01,   1.82262003e-01,
                          1.09929442e-01,   2.92389859e-02,  -2.74095833e-01,
                          2.84023255e-01,   4.92740095e-01,  -5.44654131e-01,
                         -1.94796711e-01,   9.24313903e-01,  -7.51867890e-02,
                         -8.29400539e-01,   5.66692948e-01,   6.95329547e-01,
                         -7.00445712e-01,  -2.80863404e-01,   8.07760656e-01,
                          1.56716555e-01,  -5.39656341e-01,   7.27658197e-02,
                          3.56456280e-01,   6.11146651e-02,   8.16331152e-03,
                         -1.74555406e-01,  -5.72904535e-02,   5.25400758e-01,
                          1.83006659e-01,  -6.61851645e-01,   1.39549375e-02,
                          8.01637173e-01,  -2.67397970e-01,  -6.66638196e-01,
                          5.78519821e-01,   5.40269852e-01,  -6.55924439e-01,
                         -1.63947627e-01,   6.55700147e-01,  -6.71467483e-02,
                         -4.02637869e-01,   2.42181122e-01,   2.25636899e-01,
                         -6.67313933e-02,  -4.20157835e-02,  -1.12988532e-01,
                          2.69157231e-01,   2.69699752e-01,  -5.57904780e-01,
                         -2.15944313e-02,   8.38784039e-01,  -3.68695855e-01,
                         -6.66618645e-01,   8.00523639e-01,   3.90581906e-01,
                         -9.29648995e-01,   1.70088839e-03,   8.73997092e-01,
                         -1.71675950e-01,  -5.95579565e-01,   3.38957280e-01,
                          3.77040446e-01,  -1.75890148e-01,  -1.31175876e-01,
                         -3.80584523e-02,   7.64195621e-02,   3.63171786e-01,
                         -7.98520222e-02,  -5.29428661e-01,   3.26183289e-01,
                          6.09841168e-01,  -5.26761413e-01,  -5.46737790e-01,
                          6.91916049e-01,   2.54827738e-01,  -7.86930323e-01,
                          6.66918978e-02,   6.34968936e-01,  -3.41961622e-01,
                         -4.29041147e-01,   4.03023392e-01,   1.57417223e-01,
                         -2.40546420e-01,  -4.38348651e-02,  -8.13618582e-03,
                          1.79058775e-01,   3.76282781e-02,  -4.76783425e-01,
                          1.18752986e-01,   6.06846690e-01,  -5.72547972e-01,
                         -4.81797427e-01,   8.75647724e-01,   4.56619002e-02,
                         -9.66624260e-01,   2.72026807e-01,   7.75329947e-01,
                         -5.66338420e-01,  -5.32367408e-01,   5.83832204e-01,
                          2.21738368e-01,  -4.34340566e-01,  -1.43605337e-01,
                          1.30255222e-01,   8.37731361e-02,   1.16320558e-01,
                         -2.69534767e-01,  -3.65318626e-01,   4.44443583e-01,
                          3.72334689e-01,  -7.03699172e-01,  -2.74896562e-01,
                          7.86945045e-01,  -6.89046606e-02,  -8.52790534e-01,
                          2.98318684e-01,   5.60243845e-01,  -5.81484616e-01,
                         -3.41620773e-01,   5.21633267e-01,  -4.28900385e-04,
                         -3.84345055e-01,   5.01382127e-02,   7.80367553e-02,
                          9.13881697e-03,  -7.27703720e-02,  -3.56108278e-01,
                          2.18760803e-01,   3.84121478e-01,  -6.84230447e-01,
                         -2.37894908e-01,   8.37586164e-01,  -2.10116997e-01,
                         -9.29653704e-01,   5.89130342e-01,   5.51435053e-01,
                         -8.53403032e-01,  -2.93204308e-01,   7.37882435e-01,
                          2.13978551e-02,  -6.44625306e-01,   2.39907168e-02,
                          2.84293741e-01,  -4.78815064e-02,  -9.12742913e-02,
                         -2.46285304e-01,  -1.26611397e-01,   4.37852085e-01,
                          6.73386827e-02,  -7.31538057e-01,   5.54442666e-02,
                          7.48175263e-01,  -4.11363244e-01,  -7.08403766e-01,
                          5.68377316e-01,   4.50557142e-01,  -7.13447154e-01,
                         -1.52635440e-01,   6.06485546e-01,  -2.07686514e-01,
                         -4.21566069e-01,   2.28088707e-01,   1.26801580e-01,
                         -1.37749135e-01,  -9.93588567e-02,  -1.52496457e-01,
                          2.37544119e-01,   1.71130076e-01,  -6.28217518e-01,
                         -3.07499272e-06,   7.45683789e-01,  -4.77986753e-01,
                         -6.63187981e-01,   7.98724234e-01,   2.82785565e-01,
                         -9.88872409e-01,  -5.56074723e-04,   8.29959154e-01,
                         -3.28213274e-01,  -6.32611871e-01,   3.19907486e-01,
                          3.18531334e-01,  -2.42867202e-01,  -1.81393981e-01,
                         -7.21568018e-02,   6.53591305e-02,   3.02290916e-01,
                         -1.95351273e-01,  -5.74450850e-01,   3.38628143e-01,
                          5.68425655e-01,  -6.08077705e-01,  -5.06685495e-01,
                          7.49446332e-01,   1.97141528e-01,  -8.05318356e-01,
                          8.75875428e-02,   6.25318229e-01,  -4.01366293e-01,
                         -4.26004261e-01,   3.88491631e-01,   7.40027502e-02,
                         -2.80224890e-01,  -3.65525596e-02,  -3.47061804e-03,
                          1.64128929e-01,   1.93877481e-02,  -5.14638484e-01,
                          1.73856825e-01,   5.55397511e-01,  -6.36279643e-01,
                         -3.97410125e-01,   9.09956694e-01,  -3.62831205e-02,
                         -9.64699030e-01,   3.13282788e-01,   7.14767933e-01,
                         -6.35145783e-01,  -4.86137688e-01,   5.83426416e-01,
                          1.70775309e-01,  -4.58909005e-01,  -1.31485939e-01,
                          1.30481616e-01,   8.48034099e-02,   8.08687881e-02,
                         -3.08235914e-01,  -3.04190576e-01,   4.69270676e-01,
                          2.91106224e-01,  -7.36794233e-01,  -2.13741198e-01,
                          8.06468129e-01,  -1.09000795e-01,  -7.54643679e-01,
                          4.04903919e-01,   5.49080968e-01,  -6.23054802e-01,
                         -3.23363632e-01,   5.16366065e-01,  -3.16909850e-02,
                         -3.71037155e-01,   1.13222092e-01,   1.06594294e-01,
                          2.52877921e-02,  -8.95238742e-02,  -3.22204649e-01,
                          2.56392241e-01,   3.20741236e-01,  -6.72082841e-01,
                         -1.35379091e-01,   8.71199131e-01,  -2.98931599e-01,
                         -8.49680483e-01,   6.56876385e-01,   5.09257555e-01,
                         -8.83084595e-01,  -2.23899499e-01,   7.53097475e-01,
                         -1.42471744e-02,  -6.04460418e-01,   8.27794746e-02,
                          2.76878238e-01,  -4.78285477e-02,  -1.00802861e-01,
                         -2.34038711e-01,  -7.89671168e-02,   4.73892003e-01,
                          9.28849354e-03,  -7.11478472e-01,   1.24524750e-01,
                          7.05464602e-01,  -4.49702948e-01,  -6.79861903e-01,
                          6.26494408e-01,   3.85043591e-01,  -7.55307317e-01,
                         -8.85496885e-02,   5.88497162e-01,  -2.41985574e-01,
                         -4.29920882e-01,   2.61395752e-01,   1.30274683e-01,
                         -1.38696969e-01,  -9.43794474e-02,  -1.43949077e-01,
                          2.55150825e-01,   1.44085467e-01,  -6.22567177e-01,
                          3.43671069e-02,   7.57902920e-01,  -5.73671997e-01,
                         -5.99504352e-01,   8.46352756e-01,   1.86474249e-01,
                         -9.50231373e-01,   6.47804141e-02,   7.90418983e-01,
                         -3.60587209e-01,  -6.06210828e-01,   3.50436628e-01,
                          2.87739575e-01,  -2.54056215e-01,  -1.73270211e-01,
                         -5.90807311e-02,   6.71468750e-02,   3.00548434e-01,
                         -2.31544957e-01,  -5.59073329e-01,   3.90825719e-01,
                          5.14812768e-01,  -6.51215017e-01,  -4.28124666e-01,
                          7.70160377e-01,   1.44925445e-01,  -7.54173040e-01,
                          2.23479912e-01,   6.04783356e-01,  -4.54993516e-01,
                         -3.74360591e-01,   4.50637490e-01,   8.21986794e-02,
                         -2.58583426e-01,  -1.58924181e-02,   2.29695234e-02,
                          1.82966143e-01,   1.28007159e-02,  -4.76419538e-01,
                          2.35416159e-01,   5.30251920e-01,  -6.61016822e-01,
                         -3.27432573e-01,   9.31303203e-01,  -5.02802022e-02,
                         -9.51317310e-01,   4.51991826e-01,   6.68132663e-01,
                         -6.54745638e-01,  -3.81026715e-01,   6.48766100e-01,
                          1.70309126e-01,  -4.52442974e-01,  -6.51967600e-02,
                          1.62905961e-01,   1.13684081e-01,   1.04790576e-01,
                         -2.92112023e-01,  -2.63424873e-01,   5.07945716e-01,
                          3.08337122e-01,  -6.97737336e-01,  -1.02514714e-01,
                          8.32389832e-01,  -1.52257562e-01,  -7.40402579e-01,
                          4.45161074e-01,   5.71890712e-01,  -5.71517169e-01,
                         -1.65562689e-01,   6.00628197e-01,  -3.48115452e-02,
                         -3.13144952e-01,   1.45133480e-01,   1.35773987e-01,
                          7.57494271e-02,  -4.56945039e-02,  -2.61575490e-01,
                          3.52050334e-01,   3.50975603e-01,  -6.53723717e-01,
                         -2.03236658e-03,   9.04954791e-01,  -3.06403339e-01,
                         -7.47723222e-01,   7.64436185e-01,   5.02764881e-01,
                         -8.21205974e-01,  -5.84640615e-02,   8.01173747e-01,
                         -5.44146821e-02,  -5.18032908e-01,   2.03935891e-01,
                          3.37788850e-01,   3.40352813e-03,  -2.99172457e-02,
                         -1.65361434e-01,   1.30373174e-02,   5.31725645e-01,
                          2.99339741e-02,  -6.39070213e-01,   2.60429651e-01,
                          7.77244747e-01,  -4.09342796e-01,  -5.60904026e-01,
                          7.20803380e-01,   4.21717584e-01,  -6.54886127e-01,
                          4.83010784e-02,   6.67055428e-01,  -2.22558647e-01,
                         -3.10404956e-01,   3.56405824e-01,   1.88253760e-01,
                         -5.60725816e-02,  -1.74773112e-02,  -4.83954065e-02,
                          3.41929317e-01,   1.85806185e-01,  -5.48129618e-01,
                          1.97956100e-01,   7.91907609e-01,  -5.43020546e-01,
                         -4.68785197e-01,   9.78541672e-01,   2.12849975e-01,
                         -8.67720604e-01,   2.04701483e-01,   8.69888127e-01,
                         -3.26424927e-01,  -4.55510437e-01,   4.95170295e-01,
                          3.50286394e-01,  -1.93486765e-01,  -8.02253485e-02,
                          3.69063057e-02,   1.74924314e-01,   3.86446476e-01,
                         -1.71957806e-01,  -4.14182156e-01,   5.22408247e-01,
                          5.85682929e-01,  -6.10177457e-01,  -3.09500366e-01,
                          8.54387343e-01,   8.62089097e-02,  -7.32905805e-01,
                          3.20316166e-01,   6.53541327e-01,  -3.93179387e-01,
                         -2.69536585e-01,   5.07668197e-01,   9.58185121e-02,
                         -2.01396421e-01,   6.90929145e-02,   7.63032362e-02,
                          2.43323848e-01,   4.48214076e-02,  -4.24379200e-01,
                          3.65630388e-01,   5.56487143e-01,  -6.41324878e-01,
                         -1.85878128e-01,   9.70046222e-01,  -8.97310376e-02,
                         -8.33766043e-01,   5.52956045e-01,   6.81500077e-01,
                         -6.45448565e-01,  -2.96285391e-01,   7.16228366e-01,
                          1.86602652e-01,  -4.14790332e-01,   1.28846364e-02,
                          2.15395778e-01,   1.50242925e-01,   1.38981417e-01,
                         -2.55079955e-01,  -1.80886224e-01,   5.95427513e-01,
                          2.72266299e-01,  -7.13979661e-01,  -3.70202325e-02,
                          8.03935528e-01,  -2.30752885e-01,  -6.81866884e-01,
                          5.62981009e-01,   5.23867130e-01,  -6.40096962e-01,
                         -1.35422409e-01,   5.96971154e-01,  -7.76950866e-02,
                         -3.11663955e-01,   1.88914225e-01,   1.24941602e-01,
                          6.44395947e-02,  -4.92817760e-02,  -2.45418504e-01,
                          3.64668995e-01,   3.17748189e-01,  -6.67801023e-01,
                         -1.37359109e-02,   9.05984998e-01,  -4.11780119e-01,
                         -6.84394240e-01,   7.99422085e-01,   3.98197144e-01,
                         -8.88061047e-01,  -4.88174036e-02,   8.11281204e-01,
                         -1.11346453e-01,  -5.14675915e-01,   2.25741237e-01,
                          2.92706639e-01,  -4.92239222e-02,  -6.14655688e-02,
                         -1.82420745e-01,   5.21334447e-03,   4.89954621e-01,
                         -4.10357155e-02,  -6.21317565e-01,   2.93280214e-01,
                          6.70473218e-01,  -5.20298481e-01,  -6.01205289e-01,
                          6.89711809e-01,   2.47885823e-01,  -7.57793546e-01,
                          5.99373095e-02,   5.82381606e-01,  -3.19706321e-01,
                         -3.68685097e-01,   3.18354934e-01,   1.11355796e-01,
                         -1.26603872e-01,  -8.90946612e-02,  -1.17124245e-01,
                          2.94835150e-01,   7.55649284e-02,  -6.27517462e-01,
                          1.67912558e-01,   6.82150364e-01,  -6.63973629e-01,
                         -4.88317281e-01,   8.92446101e-01,   2.68418044e-02,
                         -9.45167243e-01,   2.49745950e-01,   7.34285414e-01,
                         -5.01877666e-01,  -5.17122567e-01,   4.56361413e-01,
                          2.17448711e-01,  -2.98342139e-01,  -1.48300096e-01,
                         -4.63680290e-02,   9.72073525e-02,   2.75200605e-01,
                         -2.93495834e-01,  -5.09654224e-01,   4.52213526e-01,
                          4.54602122e-01,  -7.25784540e-01,  -3.15262765e-01,
                          7.86717117e-01,  -7.00498521e-02,  -8.35024476e-01,
                          2.71123558e-01,   5.28962195e-01,  -5.47195017e-01,
                         -3.12473923e-01,   4.37017471e-01,  -1.15436548e-02,
                         -2.91967005e-01,  -2.32961439e-02,  -4.84797033e-03,
                          1.36309534e-01,  -7.76595473e-02,  -4.89457220e-01,
                          3.08393955e-01,   4.29249883e-01,  -7.91357696e-01,
                         -2.27152109e-01,   8.64187539e-01,  -2.34034330e-01,
                         -9.18358803e-01,   5.61784208e-01,   5.30350029e-01,
                         -7.92269766e-01,  -3.13269049e-01,   6.34212971e-01,
                          5.89607544e-02,  -5.25817394e-01,  -5.05247042e-02,
                          1.33821130e-01,   5.71115427e-02,   2.09115390e-02,
                         -3.53162944e-01,  -2.38848239e-01,   5.07380724e-01,
                          1.54138401e-01,  -7.85821199e-01,  -2.63356837e-03,
                          7.68375993e-01,  -3.87579083e-01,  -7.15567827e-01,
                          5.40480614e-01,   4.39793408e-01,  -6.93311572e-01,
                         -1.35393292e-01,   5.28173387e-01,  -1.92681283e-01,
                         -3.44353229e-01,   1.41810834e-01,   6.47455901e-02,
                         -1.21287489e-02,  -1.30223677e-01,  -2.74556041e-01,
                          3.40030730e-01,   2.05115855e-01,  -7.38878071e-01,
                          1.56934895e-02,   8.02980602e-01,  -5.18717825e-01,
                         -6.86964989e-01,   7.88485169e-01,   2.95767188e-01,
                         -9.36379671e-01,  -4.84451540e-02,   7.59103060e-01,
                         -2.52773881e-01,  -5.76247931e-01,   2.03189239e-01,
                          2.54566789e-01,  -1.06881939e-01,  -1.19777329e-01,
                         -2.29363337e-01,  -1.55762332e-02,   4.56016332e-01,
                         -1.54025033e-01,  -6.84898674e-01,   3.02838087e-01,
                          6.35545671e-01,  -5.90596855e-01,  -5.53392231e-01,
                          7.36249387e-01,   1.96652010e-01,  -7.79238343e-01,
                          9.48578492e-02,   5.50930738e-01,  -3.62575650e-01,
                         -3.53088349e-01,   2.91329175e-01,   4.19891179e-02,
                         -1.51417673e-01,  -8.86391997e-02,  -1.03725381e-01,
                          2.94769704e-01,   4.21439260e-02,  -6.47490919e-01,
                          2.42191344e-01,   6.11821294e-01,  -7.20054030e-01,
                         -3.96212280e-01,   9.33173120e-01,  -2.99794879e-02,
                         -9.46529150e-01,   2.74831414e-01,   6.92625940e-01,
                         -5.44019818e-01,  -4.76194918e-01,   4.69660610e-01,
                          1.73193872e-01,  -3.13003451e-01,  -1.37014970e-01,
                         -3.93008180e-02,   1.16149567e-01,   2.38293469e-01,
                         -3.39054734e-01,  -4.21980798e-01,   4.89399582e-01,
                          3.90657455e-01,  -7.59863377e-01,  -2.49574497e-01,
                          8.08500528e-01,  -9.25014094e-02,  -7.32143760e-01,
                          3.89243364e-01,   5.15350819e-01,  -5.70812941e-01,
                         -2.76563376e-01,   4.35334235e-01,  -2.66588535e-02,
                         -2.53322750e-01,   3.26284841e-02,   2.63342466e-02,
                          1.68639749e-01,  -8.71898010e-02,  -4.48732018e-01,
                          3.54687899e-01,   3.77917916e-01,  -7.68926620e-01,
                         -1.07648201e-01,   9.21205878e-01,  -3.24276179e-01,
                         -8.42812002e-01,   6.40673816e-01,   5.08109033e-01,
                         -8.08596671e-01,  -2.42524713e-01,   6.63731992e-01,
                          2.89600678e-02,  -4.65696692e-01,   4.78687789e-03,
                          1.49731606e-01,   7.08098710e-02,   3.83890010e-02,
                         -3.34616721e-01,  -1.93909630e-01,   5.72333455e-01,
                          9.06591639e-02,  -7.70175636e-01,   9.61294919e-02,
                          7.43820310e-01,  -4.33252782e-01,  -6.74295902e-01,
                          6.18865311e-01,   3.55537981e-01,  -6.97171271e-01,
                         -6.60329536e-02,   5.22361159e-01,  -2.15325236e-01,
                         -3.30334187e-01,   1.78380385e-01,   8.32729787e-02,
                          2.02765223e-03,  -1.31322861e-01,  -2.53207356e-01,
                          3.78647625e-01,   1.85733512e-01,  -7.32670963e-01,
                          8.89867321e-02,   8.15989614e-01,  -6.21528327e-01,
                         -5.93584597e-01,   8.57363999e-01,   1.89415216e-01,
                         -9.15306151e-01,   5.50909787e-02,   7.42577076e-01,
                         -2.90777177e-01,  -5.26093423e-01,   2.30149552e-01,
                          2.37865731e-01,  -1.02399647e-01,  -1.09914899e-01,
                         -2.12181881e-01,   2.31765565e-02,   4.58101213e-01,
                         -1.98582739e-01,  -6.64104283e-01,   3.91713589e-01,
                          5.86722553e-01,  -6.50195658e-01,  -4.44534212e-01,
                          7.76870370e-01,   1.31297439e-01,  -7.12813377e-01,
                          2.32237756e-01,   5.50965309e-01,  -4.27186251e-01,
                         -3.11953396e-01,   3.74573767e-01,   6.87327161e-02,
                         -1.41286001e-01,  -6.86034560e-02,  -5.98680191e-02,
                          3.15287262e-01,   2.02385932e-02,  -5.95777452e-01,
                          3.20456624e-01,   5.82236052e-01,  -7.42176473e-01,
                         -3.12535524e-01,   9.69861388e-01,  -5.47409989e-02,
                         -9.28478837e-01,   4.20317173e-01,   6.44969523e-01,
                         -5.73193610e-01,  -3.68541002e-01,   5.34457624e-01,
                          1.87331200e-01,  -3.02431643e-01,  -9.75484699e-02,
                          5.68135455e-03,   1.72128230e-01,   2.50682503e-01,
                         -3.36666167e-01,  -3.79127115e-01,   5.46634495e-01,
                          3.88638914e-01,  -7.05934584e-01,  -1.30170494e-01,
                          8.34916651e-01,  -1.38366118e-01,  -7.08528161e-01,
                          4.32987273e-01,   5.21811187e-01,  -5.24203241e-01,
                         -1.28687814e-01,   5.19462883e-01,  -3.02842595e-02,
                         -2.30161637e-01,   7.15261251e-02,   8.75810161e-02,
                          2.13408917e-01,  -8.42555761e-02,  -3.64695400e-01,
                          4.57554311e-01,   3.78344446e-01,  -7.59493470e-01,
                          2.82014087e-02,   9.50672805e-01,  -3.23713303e-01,
                         -7.39873528e-01,   7.32068002e-01,   5.13473690e-01,
                         -7.71796227e-01,  -9.49053243e-02,   7.26900756e-01,
                         -4.34829434e-03,  -4.13468719e-01,   1.13498867e-01,
                          2.21166909e-01,   1.28078222e-01,   6.96949810e-02,
                         -2.79205739e-01,  -8.72061104e-02,   6.26132727e-01,
                          1.02650128e-01,  -7.13694215e-01,   2.26042420e-01,
                          8.21365058e-01,  -3.95664155e-01,  -5.73944151e-01,
                          7.06803799e-01,   3.99177969e-01,  -6.25029266e-01,
                          6.85572401e-02,   5.93939781e-01,  -2.02680051e-01,
                         -2.31734276e-01,   2.83565372e-01,   1.42698601e-01,
                          6.59460500e-02,  -6.06935136e-02,  -1.52845532e-01,
                          4.57763582e-01,   1.93414152e-01,  -6.63910329e-01,
                          2.52976358e-01,   8.28331828e-01,  -5.78396857e-01,
                         -4.70893055e-01,   9.72235084e-01,   2.18601555e-01,
                         -8.41367185e-01,   1.67013943e-01,   8.00752521e-01,
                         -2.28535131e-01,  -4.01738673e-01,   3.59229892e-01,
                          2.95321107e-01,  -2.97782384e-02,  -4.23145778e-02,
                         -1.48570925e-01,   1.53726548e-01,   5.35838962e-01,
                         -1.54809624e-01,  -5.32554507e-01,   5.18057227e-01,
                          6.48635268e-01,  -6.03585124e-01,  -3.32666487e-01,
                          8.24606001e-01,   9.09909159e-02,  -6.96986735e-01,
                          3.11616123e-01,   5.83810210e-01,  -3.36757720e-01,
                         -2.15635061e-01,   4.13380444e-01,   9.22902972e-02,
                         -9.23651159e-02,  -2.51183123e-03,  -5.20414021e-03,
                          3.80534530e-01,   3.15270238e-02,  -5.53308010e-01,
                          4.50393170e-01,   5.97286046e-01,  -7.19320834e-01,
                         -1.71564713e-01,   9.84806955e-01,  -9.68415812e-02,
                         -8.15671444e-01,   5.11435330e-01,   6.60269260e-01,
                         -5.62630296e-01,  -2.83205360e-01,   5.90756178e-01,
                          2.01025665e-01,  -2.53891796e-01,  -4.22107913e-02,
                          4.25013490e-02,   2.11536154e-01,   3.05728883e-01,
                         -3.27303022e-01,  -3.15843493e-01,   6.48146808e-01,
                          3.64087760e-01,  -7.52072990e-01,  -8.94843265e-02,
                          8.08559179e-01,  -2.17790008e-01,  -6.62767887e-01,
                          5.28207242e-01,   4.97176796e-01,  -5.82668662e-01,
                         -1.18041702e-01,   5.05568385e-01,  -6.76315129e-02,
                         -2.05834836e-01,   9.35377255e-02,   7.20349401e-02,
                          2.04920724e-01,  -9.07693133e-02,  -3.60473126e-01,
                          4.78246987e-01,   3.43656778e-01,  -7.86319137e-01,
                          2.26720031e-02,   9.40443516e-01,  -4.28902835e-01,
                         -6.69312298e-01,   7.56285012e-01,   3.89412344e-01,
                         -8.16379786e-01,  -7.48572722e-02,   7.11888552e-01,
                         -4.91199121e-02,  -4.03077126e-01,   1.13477707e-01,
                          1.78648442e-01,   7.82887265e-02,   4.59568352e-02,
                         -3.24813843e-01,  -9.31553692e-02,   5.98463893e-01,
                          2.11558994e-02,  -6.88581526e-01,   2.57688493e-01,
                          6.87871397e-01,  -4.94318843e-01,  -6.01310611e-01,
                          6.36429310e-01,   2.44622186e-01,  -7.06723332e-01,
                          6.12013340e-02,   5.07891953e-01,  -2.83295691e-01,
                         -2.80892223e-01,   2.22946212e-01,   5.68679050e-02,
                          1.44117372e-03,  -1.45595968e-01,  -2.27241635e-01,
                          4.37158227e-01,   6.68103322e-02,  -7.34613240e-01,
                          2.22254768e-01,   7.10331142e-01,  -7.00378180e-01,
                         -4.93264109e-01,   8.83543789e-01,   4.69569899e-02,
                         -9.14219201e-01,   1.88852280e-01,   6.92436159e-01,
                         -4.14052904e-01,  -4.65578586e-01,   3.11845005e-01,
                          1.77717954e-01,  -1.43992156e-01,  -1.22482993e-01,
                         -2.17212275e-01,   7.91921839e-02,   4.26640600e-01,
                         -3.08190912e-01,  -6.05554461e-01,   4.44512099e-01,
                          4.99780566e-01,  -7.22461343e-01,  -3.33980769e-01,
                          7.75212824e-01,  -7.52525628e-02,  -8.03537130e-01,
                          2.58142233e-01,   4.74326670e-01,  -4.94978607e-01,
                         -2.52098650e-01,   3.22974026e-01,  -2.67363079e-02,
                         -1.60898834e-01,  -1.07058205e-01,  -8.98877680e-02,
                          2.78023988e-01,  -9.41990018e-02,  -6.16680682e-01,
                          3.96304250e-01,   4.77786243e-01,  -8.88282955e-01,
                         -2.16727600e-01,   9.06958282e-01,  -2.40792558e-01,
                         -9.18146133e-01,   5.18648624e-01,   5.22169650e-01,
                         -7.15069771e-01,  -3.07258487e-01,   5.10663271e-01,
                          7.52986372e-02,  -3.67255300e-01,  -1.19662315e-01,
                         -2.95236763e-02,   1.36701673e-01,   1.68630332e-01,
                         -4.43801016e-01,  -3.62914920e-01,   5.82685709e-01,
                          2.08679453e-01,  -8.21068347e-01,  -1.64384525e-02,
                          7.56496727e-01,  -3.76953214e-01,  -6.82928085e-01,
                          5.11884034e-01,   3.92398506e-01,  -6.31272435e-01,
                         -1.20082639e-01,   4.38672066e-01,  -1.62226588e-01,
                         -2.67156452e-01,   5.15862405e-02,   2.82435734e-02,
                          1.26929611e-01,  -1.87459961e-01,  -3.81035656e-01,
                          4.51517463e-01,   2.10220188e-01,  -8.30200434e-01,
                          6.23639151e-02,   8.25643778e-01,  -5.42761028e-01,
                         -6.81138098e-01,   7.70095885e-01,   2.96703190e-01,
                         -8.75410080e-01,  -1.01147324e-01,   6.68992817e-01,
                         -1.60535336e-01,  -4.76519406e-01,   7.14033842e-02,
                          1.50013104e-01,   4.66970839e-02,  -3.04007418e-02,
                         -3.74319553e-01,  -9.58344489e-02,   5.74918270e-01,
                         -1.05405077e-01,  -7.60760844e-01,   2.67353803e-01,
                          6.57134533e-01,  -5.61019540e-01,  -5.36621988e-01,
                          6.97208762e-01,   1.73107982e-01,  -7.24956214e-01,
                          8.76930505e-02,   4.91320729e-01,  -3.30801189e-01,
                         -2.83831835e-01,   2.13717327e-01,   1.94151364e-02,
                         -4.12753113e-02,  -1.55701190e-01,  -1.72261089e-01,
                          4.22027230e-01,   3.19278836e-02,  -7.50740826e-01,
                          3.11593086e-01,   6.36786699e-01,  -7.61085153e-01,
                         -3.94759685e-01,   9.45228398e-01,  -9.11447220e-03,
                         -9.26458001e-01,   2.14822099e-01,   6.57659292e-01,
                         -4.35490966e-01,  -4.50055033e-01,   3.34032089e-01,
                          1.61946103e-01,  -1.43508121e-01,  -1.24269672e-01,
                         -2.05900088e-01,   1.15372755e-01,   3.78646940e-01,
                         -3.44831556e-01,  -5.21518171e-01,   5.10491371e-01,
                          4.47644323e-01,  -7.58396089e-01,  -2.81112969e-01,
                          8.00834537e-01,  -6.57559410e-02,  -6.99606061e-01,
                          3.60489160e-01,   4.62873101e-01,  -5.09983301e-01,
                         -2.17486560e-01,   3.45080733e-01,  -2.01109722e-02,
                         -1.40954077e-01,  -6.05368614e-02,  -2.31737662e-02,
                          3.05181652e-01,  -1.22388139e-01,  -5.49871087e-01,
                          4.60821837e-01,   4.00546104e-01,  -8.39584589e-01,
                         -7.87596479e-02,   9.37357128e-01,  -3.22903305e-01,
                         -8.33223939e-01,   6.01191819e-01,   5.12510777e-01,
                         -7.20619440e-01,  -2.51601845e-01,   5.32380044e-01,
                          8.43547881e-02,  -3.19552541e-01,  -7.34149292e-02,
                          2.01866850e-02,   1.78179905e-01,   1.74092889e-01,
                         -4.20752823e-01,  -2.92688042e-01,   6.37530327e-01,
                          1.59738719e-01,  -7.96956062e-01,   6.34188429e-02,
                          7.55531013e-01,  -4.00273800e-01,  -6.74418747e-01,
                          5.86827278e-01,   3.62402171e-01,  -6.36415601e-01,
                         -6.51020482e-02,   4.32398468e-01,  -1.58149749e-01,
                         -2.35600725e-01,   6.56229928e-02,   4.58661206e-02,
                          1.63332194e-01,  -1.85646653e-01,  -3.54200900e-01,
                          5.13137281e-01,   1.91871420e-01,  -8.14541876e-01,
                          1.28587872e-01,   8.46321344e-01,  -6.29235625e-01,
                         -5.89897931e-01,   8.22200239e-01,   2.14919955e-01,
                         -8.37255239e-01,   2.07264698e-03,   6.54872656e-01,
                         -1.84549570e-01,  -4.45132881e-01,   1.12851165e-01,
                          1.58959627e-01,   6.47236556e-02,  -3.10420617e-02,
                         -3.71699691e-01,  -2.07475256e-02,   5.75672567e-01,
                         -1.64714664e-01,  -7.22654045e-01,   3.73566002e-01,
                          6.21027172e-01,  -6.20788634e-01,  -4.58784342e-01,
                          7.52770662e-01,   1.54515833e-01,  -6.78118706e-01,
                          2.01498330e-01,   4.89486754e-01,  -3.42949659e-01,
                         -2.45747879e-01,   2.45358601e-01,   6.09558858e-02,
                          8.17892049e-03,  -1.52851120e-01,  -1.34891361e-01,
                          4.53123420e-01,   5.45246108e-03,  -6.88364863e-01,
                          3.83643061e-01,   6.20963454e-01,  -7.95640647e-01,
                         -3.06656152e-01,   9.62394834e-01,  -1.61820371e-02,
                         -8.95843983e-01,   3.48978788e-01,   6.25520825e-01,
                         -4.56581175e-01,  -3.62098932e-01,   3.89789701e-01,
                          1.92722544e-01,  -1.34363517e-01,  -1.06773794e-01,
                         -1.63115412e-01,   1.93960518e-01,   4.09062743e-01,
                         -3.63188148e-01,  -4.87829149e-01,   5.65940320e-01,
                          4.51641738e-01,  -7.11328387e-01,  -1.46222010e-01,
                          8.30703676e-01,  -1.20490327e-01,  -6.84998572e-01,
                          4.11598146e-01,   4.84391659e-01,  -4.59238112e-01,
                         -1.17096767e-01,   4.12112474e-01,   2.80506536e-03,
                         -1.10411480e-01,  -3.75265405e-02,   1.53864492e-02,
                          3.68368357e-01,  -1.17966920e-01,  -4.80363250e-01,
                          5.45379221e-01,   4.12672073e-01,  -8.43764007e-01,
                          4.58108746e-02,   9.76561308e-01,  -3.20035189e-01,
                         -7.47821093e-01,   6.89000070e-01,   5.10573387e-01,
                         -6.76406741e-01,  -1.17089935e-01,   5.90846181e-01,
                          6.64128363e-02,  -2.67467439e-01,   1.77959597e-03,
                          8.10177475e-02,   2.41311908e-01,   1.97172284e-01,
                         -4.10867900e-01,  -1.77451357e-01,   7.16966748e-01,
                          1.47091314e-01,  -7.57798493e-01,   2.01203227e-01,
                          8.17069471e-01,  -3.74743491e-01,  -5.54992437e-01,
                          6.76163852e-01,   3.68134260e-01,  -5.80132067e-01,
                          7.36485720e-02,   5.07301927e-01,  -1.42925143e-01,
                         -1.60310403e-01,   1.35046721e-01,   1.36988744e-01,
                          2.10846022e-01,  -1.54551223e-01,  -2.41894081e-01,
                          5.96600115e-01,   1.83148116e-01,  -7.62024462e-01,
                          2.90761948e-01,   8.74545157e-01,  -6.11728370e-01,
                         -5.07876635e-01,   9.68506694e-01,   2.26469919e-01,
                         -7.82660246e-01,   1.18131407e-01,   7.30742395e-01,
                         -1.64293736e-01,  -3.20748478e-01,   2.16476962e-01,
                          2.15321317e-01,   1.29106015e-01,   1.10081891e-02,
                         -3.17124844e-01,   1.25676259e-01,   6.71775877e-01,
                         -1.72047630e-01,  -6.07627213e-01,   5.22793233e-01,
                          6.73470795e-01,  -6.06569648e-01,  -3.45017195e-01,
                          8.10510874e-01,   9.28489119e-02,  -6.55472219e-01,
                          2.69706964e-01,   5.40788889e-01,  -2.82668412e-01,
                         -1.66758120e-01,   2.87268847e-01,   1.04174621e-01,
                          4.43350300e-02,  -1.25009939e-01,  -5.62305264e-02,
                          5.08133113e-01,  -7.40907248e-03,  -6.42616570e-01,
                          5.18955410e-01,   6.23718917e-01,  -7.79090881e-01,
                         -1.76578343e-01,   1.00000000e+00,  -8.60582292e-02,
                         -8.02125335e-01,   4.51899469e-01,   6.42015040e-01,
                         -4.72761184e-01,  -2.80832857e-01,   4.50738132e-01,
                          2.16528192e-01,  -1.02931947e-01,  -7.34451637e-02,
                         -1.15423799e-01,   2.59254426e-01,   4.25293118e-01,
                         -3.74664605e-01,  -3.86780679e-01,   6.74207866e-01,
                          3.81198406e-01,  -7.47184336e-01,  -9.67955440e-02,
                          7.70647585e-01,  -2.08947748e-01,  -6.26805246e-01,
                          4.95437115e-01,   4.49563861e-01,  -5.14949441e-01,
                         -8.66527632e-02,   3.90679538e-01,  -1.82804335e-02,
                         -1.12135194e-01,  -3.36767584e-02,   2.39705052e-02,
                          3.51330489e-01,  -1.48832813e-01,  -4.59180802e-01,
                          5.95543087e-01,   3.56334418e-01,  -8.64360631e-01,
                          2.72775982e-02,   9.77071047e-01,  -4.36346233e-01,
                         -6.91640615e-01,   7.28215098e-01,   4.12174582e-01,
                         -7.43462443e-01,  -1.25748247e-01,   6.02837741e-01,
                          2.70706769e-02,  -2.97267199e-01,  -1.38775641e-02,
                          7.16749951e-02,   2.22405255e-01,   1.31399810e-01,
                         -4.42140400e-01,  -1.57165751e-01,   6.64698780e-01,
                          3.83438244e-02,  -7.17249572e-01,   2.47651279e-01,
                          7.08991885e-01,  -4.98397738e-01,  -5.94331503e-01,
                          6.08152509e-01,   2.29746789e-01,  -6.50956213e-01,
                          5.04344516e-02,   4.35255766e-01,  -2.04450727e-01,
                         -2.09607467e-01,   7.98004046e-02,   5.31720184e-02,
                          1.45014256e-01,  -2.40134656e-01,  -2.92706668e-01,
                          5.55811167e-01,   5.80730885e-02,  -8.20955455e-01,
                          2.61602223e-01,   7.59372115e-01,  -7.41984844e-01,
                         -5.15889645e-01,   8.75476420e-01,   7.16483071e-02,
                         -8.70779574e-01,   1.25530064e-01,   6.31434262e-01,
                         -2.99824059e-01,  -4.21663761e-01,   1.61380634e-01,
                          1.43661350e-01,   3.13808210e-02,  -9.77069736e-02,
                         -3.76851469e-01,   5.98665625e-02,   5.48714995e-01,
                         -2.85850227e-01,  -6.90268517e-01,   4.27864432e-01,
                          5.52374840e-01,  -7.16700494e-01,  -3.55932117e-01,
                          7.56766677e-01,  -5.82886040e-02,  -7.57974863e-01,
                          2.31698871e-01,   4.05254394e-01,  -4.21462029e-01,
                         -2.09369048e-01,   2.12439269e-01,   4.61988105e-03,
                         -4.82786484e-02,  -2.14241907e-01,  -1.46844268e-01,
                          4.13978904e-01,  -1.25888452e-01,  -7.10781693e-01,
                          4.70718563e-01,   4.98764694e-01,  -9.24164236e-01,
                         -2.14725614e-01,   8.96553814e-01,  -2.15515316e-01,
                         -9.03252840e-01,   4.67571914e-01,   5.02301574e-01,
                         -6.05888069e-01,  -3.25858593e-01,   3.73457789e-01,
                          1.09488711e-01,  -2.09221691e-01,  -1.58688888e-01,
                         -1.88251302e-01,   1.88924432e-01,   2.97558725e-01,
                         -4.91645336e-01,  -4.61832672e-01,   6.10249996e-01,
                          2.80068696e-01,  -8.34869206e-01,  -5.46572022e-02,
                          7.68557310e-01,  -3.58800441e-01,  -6.70979977e-01,
                          4.74249482e-01,   3.54252160e-01,  -5.65627158e-01,
                         -1.06852196e-01,   3.35457057e-01,  -1.15227692e-01,
                         -1.58694863e-01,  -8.44424143e-02,  -9.55887977e-03,
                          2.88721889e-01,  -2.51704782e-01,  -4.82414961e-01,
                          5.64208269e-01,   2.08955973e-01,  -9.09409106e-01,
                          9.19475853e-02,   8.43914866e-01,  -5.42798102e-01,
                         -6.81171656e-01,   7.29659855e-01,   3.02507222e-01,
                         -8.03762853e-01,  -1.33577451e-01,   5.60256898e-01,
                         -8.02247152e-02,  -3.62852842e-01,  -4.03854772e-02,
                          3.03015169e-02,   1.75567299e-01,   6.17143884e-02,
                         -5.03751993e-01,  -1.63392827e-01,   6.66291714e-01,
                         -6.36062920e-02,  -8.15763235e-01,   2.52422541e-01,
                          6.79814994e-01,  -5.60345113e-01,  -5.38385451e-01,
                          6.77993357e-01,   1.61986843e-01,  -6.79629326e-01,
                          8.20271000e-02,   4.02796745e-01,  -2.59597152e-01,
                         -2.15666994e-01,   7.39573687e-02,   3.76074761e-02,
                          1.09878391e-01,  -2.56743520e-01,  -2.48622626e-01,
                          5.48713326e-01,   2.43159737e-02,  -8.45117152e-01,
                          3.60480577e-01,   6.63515389e-01,  -7.84495771e-01,
                         -3.96384627e-01,   9.25196290e-01,   6.22482365e-03,
                         -8.81937146e-01,   1.76648304e-01,   5.95817208e-01,
                         -3.45301718e-01,  -3.85489315e-01,   1.89484105e-01,
                          1.28124267e-01,   1.76841412e-02,  -8.98927003e-02,
                         -3.56713325e-01,   9.12081599e-02,   5.12074232e-01,
                         -3.31813723e-01,  -6.16288245e-01,   5.32940567e-01,
                          4.95333642e-01,  -7.58913815e-01,  -2.80176759e-01,
                          7.80350626e-01,  -6.94705918e-02,  -6.52616322e-01,
                          3.42720270e-01,   4.12450522e-01,  -4.41153884e-01,
                         -1.78448185e-01,   2.38848716e-01,   1.75992120e-02,
                         -2.42262986e-02,  -1.77677512e-01,  -6.04826026e-02,
                          4.58711028e-01,  -1.73267752e-01,  -6.33616805e-01,
                          5.44711351e-01,   4.18374628e-01,  -8.82483661e-01,
                         -6.66211396e-02,   9.40675914e-01,  -2.99528897e-01,
                         -8.10678542e-01,   5.44923425e-01,   5.05787790e-01,
                         -6.18624806e-01,  -2.61810511e-01,   4.24709320e-01,
                          1.09414183e-01,  -1.68930635e-01,  -1.10549673e-01,
                         -1.27279267e-01,   2.43992761e-01,   3.21871698e-01,
                         -4.68271285e-01,  -3.97878706e-01,   6.87649846e-01,
                          2.27544293e-01,  -8.30541492e-01,   5.38353920e-02,
                          7.64807045e-01,  -3.87372583e-01,  -6.20357037e-01,
                          5.54082572e-01,   3.13210160e-01,  -5.56311846e-01,
                         -3.30276191e-02,   3.46343666e-01,  -1.09589450e-01,
                         -1.34643734e-01,  -4.49939966e-02,   3.25042307e-02,
                          2.94144303e-01,  -2.51384556e-01,  -4.20680255e-01,
                          6.31325305e-01,   1.97335601e-01,  -8.78415167e-01,
                          1.64072990e-01,   8.75401974e-01,  -6.33952737e-01,
                         -5.86667299e-01,   8.05722535e-01,   2.40300938e-01,
                         -7.76018918e-01,  -2.41283979e-02,   5.67431033e-01,
                         -9.34650004e-02,  -3.36385548e-01,   1.67205278e-03,
                          5.95694408e-02,   1.98380157e-01,   7.18283430e-02,
                         -4.81290102e-01,  -1.05407983e-01,   6.81007922e-01,
                         -1.00302555e-01,  -7.91172981e-01,   3.58595788e-01,
                          6.57706499e-01,  -6.12036288e-01,  -4.43645090e-01,
                          7.28596985e-01,   1.37336731e-01,  -6.14514053e-01,
                          1.97477862e-01,   4.05735642e-01,  -2.73384601e-01,
                         -1.71738684e-01,   1.20902188e-01,   7.92173073e-02,
                          1.30084231e-01,  -2.46390730e-01,  -1.85588330e-01,
                          5.86344540e-01,  -2.07001176e-02,  -7.69997954e-01,
                          4.37788874e-01,   6.44482195e-01,  -8.09386969e-01,
                         -3.11401099e-01,   9.53865767e-01,  -5.04896510e-03,
                         -8.48851264e-01,   3.02560002e-01,   5.82644701e-01,
                         -3.54307950e-01,  -3.17360312e-01,   2.47411728e-01,
                          1.56890601e-01,   3.74502242e-02,  -7.85349980e-02,
                         -3.29163283e-01,   1.78943381e-01,   5.49362779e-01,
                         -3.53783458e-01,  -5.80389500e-01,   5.83677828e-01,
                          4.89485770e-01,  -7.09864318e-01,  -1.55938596e-01,
                          8.23948503e-01,  -1.18361905e-01,  -6.38367236e-01,
                          3.87906045e-01,   4.19711322e-01,  -3.88183326e-01,
                         -1.00984327e-01,   2.51748562e-01,   3.62091064e-02,
                          2.19831429e-03,  -1.39324680e-01,  -2.57454477e-02,
                          4.38310593e-01,  -1.50925785e-01,  -4.73683357e-01,
                          5.37390947e-01,   3.54622424e-01,  -7.52567589e-01,
                          6.88709766e-02,   7.98300982e-01,  -2.56792635e-01,
                         -5.69583058e-01,   4.80755806e-01,   4.00171846e-01,
                         -4.38461542e-01,  -1.29802689e-01,   3.71068776e-01,
                          1.02395669e-01,  -8.78291950e-02,  -5.16724214e-02,
                         -5.07438146e-02,   2.27399498e-01,   2.40724742e-01,
                         -3.25249106e-01,  -2.03630209e-01,   4.83657330e-01,
                          1.20228745e-01,  -4.96715456e-01,   1.10324547e-01,
                          5.31108141e-01,  -1.93905577e-01,  -3.53025734e-01,
                          3.60263199e-01,   1.83343872e-01,  -2.80029655e-01,
                          4.02735770e-02,   2.14801714e-01,  -4.31480035e-02,
                         -3.45493853e-02,   1.21001573e-02,   5.61961308e-02,
                          1.84389189e-01,  -1.28175691e-01,  -1.38451695e-01,
                          3.28611076e-01,   8.92591551e-02,  -3.58628243e-01,
                          1.38508976e-01,   3.84372532e-01,  -2.49597445e-01,
                         -2.15629950e-01,   3.81014228e-01,   7.24661872e-02,
                         -2.67191976e-01,   2.77652182e-02,   2.35508129e-01,
                         -2.69762482e-02,  -7.46056587e-02,   2.90200189e-02,
                          4.61065322e-02,   8.84462968e-02,   4.83231023e-02,
                         -1.15145288e-01,  -5.24002174e-03,   2.07969129e-01,
                         -1.31839495e-02,  -1.74461976e-01,   1.42448738e-01,
                          2.05586761e-01,  -9.93716940e-02,  -9.71269831e-02,
                          1.31050989e-01,  -1.77919888e-03,  -1.25172600e-01,
                          4.26791869e-02,   7.46158883e-02,  -2.19100770e-02,
                         -3.53807438e-04,   2.62554381e-02,   1.45007893e-02,
                          2.02095844e-02,  -3.22410837e-02,  -7.45555386e-03,
                          7.64155611e-02,   2.37427205e-02,  -3.31042223e-02,
                          5.50431646e-02,   3.01269861e-03,   2.46745255e-02,
                         -1.78620417e-03,   3.91692994e-03,   1.12253418e-02,
                          1.63546130e-02,   1.54126780e-02,   1.38422726e-02,
                          8.85900296e-03,   1.37303313e-02,   1.10821109e-02,
                          7.76696298e-03,   9.45678353e-03,   1.27724810e-02], dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri3",
    rate = 41000,
    data = numpy.array([  7.33931898e-04,  -1.43160718e-03,   5.56060222e-05,
                          1.38725003e-03,  -2.23273208e-04,  -2.85330287e-04,
                         -1.40505529e-03,  -1.73085020e-04,   3.35581973e-03,
                         -2.53796406e-05,  -3.09776282e-03,  -1.94940440e-04,
                          3.00379982e-03,   2.00303411e-03,  -2.60460493e-03,
                         -1.52379670e-03,   2.00100150e-03,  -1.09513814e-03,
                         -1.55460162e-04,   2.58510513e-03,  -3.23157408e-04,
                         -1.68062444e-03,  -4.94701962e-04,   8.98341590e-04,
                          1.12346339e-03,  -1.46486179e-03,  -5.15129708e-04,
                          2.03950494e-03,   6.24365493e-05,  -6.92238624e-04,
                         -2.89744959e-04,  -8.87757691e-04,   8.79642204e-04,
                         -7.68441416e-04,  -2.13369334e-04,   4.03485214e-03,
                         -1.45423657e-03,  -2.29388755e-03,   3.69600463e-03,
                         -2.50698999e-03,  -2.17962847e-03,   4.45826538e-03,
                          1.03389635e-03,  -3.01317382e-03,  -3.84549098e-03,
                          1.72276853e-03,   5.41081931e-03,  -1.26131368e-03,
                         -3.10884626e-03,  -1.48027367e-03,   1.89058227e-03,
                          4.17511817e-03,  -3.54474504e-03,  -1.97614799e-03,
                          3.23360297e-03,  -2.29346659e-03,  -6.94601913e-04,
                          1.76419504e-03,   2.31516431e-04,   5.92993165e-04,
                          8.75858765e-04,  -5.45660383e-04,  -2.33198144e-03,
                          5.18875604e-04,   2.76021915e-03,  -2.52685789e-03,
                         -3.44960223e-04,   4.57656337e-03,  -6.63864543e-04,
                         -4.10698587e-03,  -4.98064677e-04,   2.24033277e-03,
                         -2.66683492e-04,  -1.75856298e-03,   5.61575755e-04,
                         -6.52780873e-04,  -1.03399775e-03,   2.26665172e-03,
                          5.56022678e-05,  -2.93143676e-03,   2.83436675e-04,
                          1.76324451e-03,  -2.26766616e-03,   4.61007759e-04,
                          3.90773965e-03,  -6.21077954e-04,   7.43760611e-04,
                          8.36292049e-04,  -5.37996180e-03,   6.33859832e-04,
                          4.62628575e-03,  -3.57526820e-03,  -1.09436782e-03,
                          5.43246791e-03,  -1.03705609e-03,  -1.43815216e-03,
                          1.61960057e-03,  -3.11463978e-03,   2.26903381e-03,
                          5.22283698e-03,  -1.60591328e-03,   1.82621076e-03,
                          3.99770495e-03,  -1.53090525e-03,  -9.58467484e-04,
                          3.00411927e-03,   1.92433666e-03,  -9.81495134e-04,
                          2.76782736e-03,   3.04424949e-03,  -2.56063859e-03,
                          3.84624611e-04,   5.54580288e-03,   1.40397693e-04,
                         -4.67890128e-03,   3.69896530e-04,   4.70800791e-03,
                         -1.07357954e-03,  -2.39988833e-04,   4.71729552e-03,
                          2.12238799e-03,  -1.89663877e-03,  -3.17288708e-04,
                          1.58574479e-03,  -7.41423690e-04,   6.57248194e-04,
                          7.34280562e-03,  -1.35700114e-03,  -8.56238825e-04,
                          8.06404185e-03,  -4.08014841e-03,  -4.39768145e-03,
                          5.83104650e-03,   4.55558347e-03,   3.12874047e-03,
                         -6.31259847e-03,  -3.76558723e-03,   1.10082868e-02,
                          6.89521804e-03,  -1.62277918e-03,  -7.12806452e-03,
                          1.72107026e-03,   8.09588376e-03,  -6.94698049e-03,
                          2.75400863e-03,   8.73912871e-03,  -8.58541206e-03,
                          1.53550773e-03,   6.79642754e-03,  -3.27144517e-03,
                          7.32527440e-03,   5.12244925e-03,  -4.57636081e-03,
                          1.11736928e-03,  -1.32793197e-04,   1.43482321e-04,
                          9.25766304e-03,  -1.49492663e-03,  -7.79173383e-03,
                          8.65179766e-03,   1.01272361e-02,  -3.12925153e-03,
                         -4.90066037e-03,   5.40310226e-04,   6.20168727e-03,
                          1.98814087e-03,   1.60403841e-03,   7.12381164e-03,
                         -6.23227423e-03,  -8.93137977e-03,   4.76546632e-03,
                          9.41934064e-03,   5.40098315e-03,  -8.61859508e-03,
                         -4.29060962e-03,   1.18697407e-02,   4.53166151e-03,
                         -2.12369557e-03,  -1.03645865e-03,  -2.32936640e-04,
                          1.00649232e-02,   2.28831940e-03,  -8.90704431e-03,
                          4.18523978e-03,   9.15184245e-03,  -2.34018336e-03,
                         -3.54555645e-03,   1.41383579e-03,   2.18858549e-04,
                          3.02313804e-03,   2.13605654e-03,  -1.16036250e-03,
                          4.07870952e-03,  -6.89631153e-04,  -3.69280344e-04,
                          5.72827319e-03,   1.04304124e-03,  -1.70721760e-04,
                          8.39198567e-03,  -3.69432149e-03,  -4.94615966e-03,
                          1.45834535e-02,  -4.01032530e-03,  -1.17340358e-02,
                          7.94510543e-03,   9.33897495e-03,   5.34173613e-03,
                         -2.32944149e-04,  -1.09407408e-02,   3.88119905e-03,
                          1.16600459e-02,   1.45018252e-03,  -6.11103792e-03,
                         -2.54042121e-03,   5.42694516e-03,   1.90753455e-03,
                         -2.09637336e-03,   2.53047608e-03,   1.39972381e-03,
                          3.30870855e-04,   1.00044254e-02,  -5.98589843e-03,
                         -2.14787666e-03,   3.20836226e-03,   1.24393683e-03,
                          4.74337023e-03,  -1.62375218e-03,  -3.18210735e-03,
                          1.30184330e-02,  -3.83095816e-03,  -6.39967108e-03,
                          3.98552045e-03,  -1.19204284e-03,  -8.41488189e-04,
                          9.69273504e-03,   1.01916790e-02,  -1.16034551e-02,
                          6.15884783e-03,  -7.69405905e-03,   8.80081765e-03,
                          3.68805439e-03,   2.97260401e-03,   3.96510772e-03,
                         -1.33807063e-02,   8.36272910e-03,   3.43197375e-03,
                         -2.64299195e-03,   3.10003583e-04,   6.44394150e-03,
                         -3.10605485e-03,  -1.70929160e-03,   4.93410649e-03,
                         -2.13971967e-03,   1.98385003e-03,   2.47264956e-03,
                          1.13857840e-03,  -2.66014715e-04,   4.02535021e-04,
                          2.55777943e-03,   5.54519793e-05,   1.00961747e-03,
                         -3.44728795e-03,   1.06571615e-02,  -1.67411705e-03,
                         -1.71994313e-03,   8.62147007e-03,  -2.51189317e-03,
                         -7.90725555e-03,   1.35802571e-02,   6.79533789e-03,
                         -1.86225586e-02,   6.19374821e-03,   8.56545009e-03,
                         -4.74497071e-03,   2.69657653e-03,  -7.44906545e-04,
                          5.71794854e-03,  -1.76677620e-03,  -4.11840761e-03,
                          3.38997622e-03,   8.30664951e-03,   2.35430268e-03,
                         -5.69383148e-03,   1.82821706e-03,   7.50634726e-03,
                         -2.78567756e-03,  -5.26277209e-03,   4.26116074e-03,
                          1.12936739e-02,  -4.97104321e-03,  -3.07832309e-03,
                          9.02260281e-03,   1.45487150e-03,  -5.24741272e-03,
                         -2.03393307e-03,   1.84237410e-03,   6.07716711e-03,
                          2.16268725e-03,   9.07336245e-04,  -4.21889639e-03,
                          6.41882885e-03,  -1.71835383e-03,   6.97173644e-03,
                          5.43207349e-03,  -1.55637879e-03,  -5.54054650e-03,
                         -2.16005347e-03,   9.77899507e-03,  -1.11591141e-03,
                         -2.96616810e-04,  -2.18169857e-03,   1.16975382e-02,
                         -7.39728427e-03,  -9.17642564e-03,   1.48009220e-02,
                          6.07458234e-04,  -3.23262997e-03,  -3.71122500e-03,
                          3.90352029e-03,   4.93152160e-03,  -3.16331023e-03,
                          1.60812736e-02,  -9.31415893e-03,  -3.27498056e-02,
                          3.03725507e-02,   3.93811800e-02,  -6.34819642e-02,
                          1.70100033e-02,   4.20661598e-01,   8.58501077e-01,
                         -1.40246511e-01,  -9.99967456e-01,   4.17699248e-01,
                          9.96395528e-01,  -1.68839619e-01,  -1.14811420e-01,
                          4.38325614e-01,   1.45125002e-01,   1.04597613e-01,
                          2.26303399e-01,   1.92861840e-01,   1.99216008e-01,
                          1.29122809e-01,   2.14595690e-01,   3.64469379e-01,
                          1.01084232e-01,   1.00711249e-01,   4.85454828e-01,
                          2.14165732e-01,  -4.52958457e-02,   4.65747058e-01,
                          5.29636443e-01,  -6.31148219e-02,   1.46060064e-01,
                          6.36317611e-01,   3.30849648e-01,   9.81876533e-03,
                          2.95595586e-01,   5.27390838e-01,   3.23493600e-01,
                          1.71695858e-01,   2.54392862e-01,   3.87100279e-01,
                          4.41944331e-01,   3.13891143e-01,   1.03037901e-01,
                          3.44307691e-01,   6.58013105e-01,   2.17925772e-01,
                          1.05942702e-02,   6.07155085e-01,   5.90579152e-01,
                          4.24050242e-02,   2.81430125e-01,   6.47594929e-01,
                          3.16894442e-01,   2.25619271e-01,   4.56844240e-01,
                          4.31457609e-01,   4.06283587e-01,   3.62476736e-01,
                          2.93837994e-01,   5.21552801e-01,   4.64639306e-01,
                          1.67220697e-01,   4.62612540e-01,   6.84052467e-01,
                          1.94362491e-01,   1.71508193e-01,   6.65060341e-01,
                          5.53251326e-01,   1.08596593e-01,   3.20962310e-01,
                          7.21114397e-01,   4.42193747e-01,   9.49279591e-02,
                          4.45588291e-01,   7.01494098e-01,   3.51541609e-01,
                          2.95161426e-01,   4.74793285e-01,   4.65700865e-01,
                          5.44946909e-01,   4.07571614e-01,   1.78288847e-01,
                          5.86685717e-01,   7.65035272e-01,   1.59950331e-01,
                          1.91523939e-01,   8.06930304e-01,   5.44789195e-01,
                          8.21699798e-02,   4.38436359e-01,   7.05049694e-01,
                          3.67189914e-01,   2.41431281e-01,   5.04643321e-01,
                          5.58366835e-01,   3.92330050e-01,   3.64914089e-01,
                          4.60055888e-01,   5.37236989e-01,   4.55274940e-01,
                          2.83820778e-01,   4.80245084e-01,   6.93056047e-01,
                          3.14129263e-01,   2.03237191e-01,   7.51388609e-01,
                          5.63564479e-01,   2.87593864e-02,   4.81035739e-01,
                          8.25894058e-01,   2.76605606e-01,   1.22682564e-01,
                          6.41434669e-01,   5.53333580e-01,   2.80994445e-01,
                          3.72199625e-01,   3.85598898e-01,   5.24262547e-01,
                          5.99369347e-01,   1.77311659e-01,   2.50722349e-01,
                          7.26912916e-01,   5.37710845e-01,   1.15590043e-01,
                          3.52551520e-01,   7.20898867e-01,   4.70473021e-01,
                          1.04342975e-01,   3.84557366e-01,   7.51344383e-01,
                          3.19363654e-01,   1.19871423e-01,   5.73998630e-01,
                          5.20369053e-01,   2.12619111e-01,   3.88573796e-01,
                          4.30913150e-01,   3.60225916e-01,   4.61829722e-01,
                          2.57404119e-01,   2.97418743e-01,   6.29927039e-01,
                          2.25928470e-01,   1.40019789e-01,   7.36304104e-01,
                          4.04864460e-01,  -5.24960905e-02,   5.38050711e-01,
                          6.66291118e-01,   7.65446275e-02,   2.20846578e-01,
                          6.22931242e-01,   3.40465814e-01,   2.30412170e-01,
                          3.06624770e-01,   3.10597092e-01,   4.65713292e-01,
                          3.78804952e-01,   1.08543336e-01,   2.51916736e-01,
                          5.44761002e-01,   3.70760679e-01,   2.02264655e-02,
                          2.17799902e-01,   6.57426834e-01,   3.45718086e-01,
                         -7.62650743e-02,   3.96032721e-01,   6.05225682e-01,
                          9.43991765e-02,   1.56203151e-01,   5.05862355e-01,
                          2.78885454e-01,   2.08283946e-01,   3.18021029e-01,
                          2.11557940e-01,   3.40268135e-01,   3.41257095e-01,
                          7.37892091e-02,   2.99939513e-01,   4.44085330e-01,
                          2.23591924e-02,   1.46273971e-01,   5.18374503e-01,
                          1.51785925e-01,   1.97710586e-03,   4.09380466e-01,
                          3.16358179e-01,   7.29435682e-03,   1.85129076e-01,
                          4.02223557e-01,   2.19072610e-01,   6.02922365e-02,
                          2.09992394e-01,   3.24467927e-01,   1.69229627e-01,
                          1.62567809e-01,   1.88808650e-01,   1.16894349e-01,
                          2.99952179e-01,   3.08352768e-01,  -1.19071394e-01,
                          1.07884169e-01,   5.46579719e-01,   3.19047645e-02,
                         -1.73609570e-01,   3.82127881e-01,   3.03671062e-01,
                         -9.89608392e-02,   1.27145067e-01,   2.40687594e-01,
                          1.06179044e-01,   1.60876453e-01,   1.01126626e-01,
                          6.70937225e-02,   2.06740096e-01,   1.48085192e-01,
                          1.52392555e-02,   1.51237190e-01,   1.85675874e-01,
                         -3.33232991e-03,   1.18598528e-01,   2.40067661e-01,
                         -4.57647219e-02,  -3.14622335e-02,   3.23879242e-01,
                          9.89862010e-02,  -2.13145345e-01,   1.53818697e-01,
                          2.91070551e-01,  -1.36237070e-01,  -1.00598045e-01,
                          2.62663662e-01,   5.34762032e-02,  -9.43673030e-02,
                          1.06289461e-01,   1.96209382e-02,  -4.50334251e-02,
                          1.84006318e-01,   2.39933003e-02,  -1.94190264e-01,
                          1.56126574e-01,   2.00249150e-01,  -1.74985111e-01,
                         -1.24841899e-01,   1.94417909e-01,   9.66058969e-02,
                         -1.70984879e-01,  -2.19220705e-02,   1.17684960e-01,
                         -1.21743180e-01,  -9.02980641e-02,   1.06653646e-01,
                         -8.27974454e-02,  -1.57574654e-01,   9.33233202e-02,
                         -5.22903726e-02,  -1.96563929e-01,   5.44057302e-02,
                         -6.53066263e-02,  -1.34041607e-01,   1.00104384e-01,
                         -1.89512625e-01,  -1.96335509e-01,   2.59346962e-01,
                         -1.52912080e-01,  -4.25981164e-01,   2.30386347e-01,
                          1.40085131e-01,  -4.99540329e-01,  -9.64214131e-02,
                          2.23521203e-01,  -2.23010287e-01,  -2.58713931e-01,
                         -4.22977749e-03,  -1.05653472e-01,  -1.59736365e-01,
                         -7.86703601e-02,  -2.06288576e-01,  -1.93402424e-01,
                         -1.72067471e-02,  -7.26533085e-02,  -2.66875029e-01,
                         -2.22782627e-01,   1.05105303e-02,  -1.36074305e-01,
                         -3.37349653e-01,  -5.21784835e-02,  -6.98353024e-03,
                         -3.66117299e-01,  -1.83890983e-01,   5.15755005e-02,
                         -3.32823366e-01,  -2.86847264e-01,   6.57780021e-02,
                         -2.37696901e-01,  -3.59361231e-01,  -8.28805193e-02,
                         -2.09938869e-01,  -2.19112173e-01,  -1.44287378e-01,
                         -3.86987090e-01,  -1.51130065e-01,   4.59556393e-02,
                         -4.69956160e-01,  -4.30268854e-01,   1.41427234e-01,
                         -1.54324099e-01,  -5.73150814e-01,  -1.70068264e-01,
                          5.98830506e-02,  -3.24358165e-01,  -4.60499078e-01,
                         -1.09870255e-01,  -6.35964796e-02,  -3.66955698e-01,
                         -3.12537849e-01,  -1.50420547e-01,  -2.95575291e-01,
                         -2.51846701e-01,  -1.73992753e-01,  -4.11312997e-01,
                         -2.83756942e-01,  -6.35817125e-02,  -4.33289349e-01,
                         -4.51744109e-01,  -1.24866068e-02,  -2.85509646e-01,
                         -5.41857421e-01,  -9.90737900e-02,  -1.73426285e-01,
                         -5.25764167e-01,  -2.73098171e-01,  -9.24533978e-02,
                         -3.43359917e-01,  -3.76364470e-01,  -2.58298248e-01,
                         -2.40365103e-01,  -2.33557850e-01,  -3.98283124e-01,
                         -4.27406967e-01,  -9.33621824e-02,  -1.86830103e-01,
                         -6.13667548e-01,  -3.45939636e-01,   1.10267643e-02,
                         -3.82067561e-01,  -6.61765873e-01,  -1.85685635e-01,
                         -1.42988786e-02,  -5.13537824e-01,  -5.75216174e-01,
                         -8.73260200e-02,  -1.74981892e-01,  -5.51736295e-01,
                         -3.22935522e-01,  -1.92980438e-01,  -3.71362180e-01,
                         -2.86647469e-01,  -3.25648397e-01,  -4.49065983e-01,
                         -1.96127221e-01,  -2.02124506e-01,  -5.56267440e-01,
                         -3.57390970e-01,  -9.96328369e-02,  -4.76522774e-01,
                         -5.27051985e-01,  -1.46460176e-01,  -2.53997445e-01,
                         -5.98661065e-01,  -3.95520687e-01,  -8.99246931e-02,
                         -3.98364305e-01,  -5.83504140e-01,  -2.38861531e-01,
                         -1.88124955e-01,  -4.21470076e-01,  -4.57775593e-01,
                         -3.66744161e-01,  -1.94372341e-01,  -2.35384628e-01,
                         -6.31462097e-01,  -4.20356512e-01,   1.16300061e-01,
                         -4.68416303e-01,  -7.99441516e-01,  -3.88074592e-02,
                         -5.84854819e-02,  -7.34414697e-01,  -4.43080842e-01,
                         -1.87254306e-02,  -4.07572150e-01,  -5.37151217e-01,
                         -3.26076806e-01,  -2.90984958e-01,  -2.96716034e-01,
                         -3.73617768e-01,  -4.90134954e-01,  -3.15340698e-01,
                         -1.69489533e-01,  -4.09152597e-01,  -5.26723981e-01,
                         -2.44709134e-01,  -1.28784060e-01,  -4.76240516e-01,
                         -5.54767966e-01,  -1.12788729e-01,  -1.70268029e-01,
                         -6.77052677e-01,  -3.83132070e-01,   6.27412573e-02,
                         -4.78127241e-01,  -6.49807334e-01,  -1.02249317e-01,
                         -2.18233407e-01,  -5.01894593e-01,  -3.71671855e-01,
                         -3.57615232e-01,  -2.01410145e-01,  -2.38396734e-01,
                         -6.91305399e-01,  -3.01419318e-01,   1.13275602e-01,
                         -5.65865755e-01,  -6.65166318e-01,   8.02784637e-02,
                         -1.64553404e-01,  -6.90698981e-01,  -3.32341462e-01,
                         -2.82569304e-02,  -2.86519259e-01,  -5.15465081e-01,
                         -3.09426546e-01,  -1.64413050e-01,  -2.96419024e-01,
                         -3.96527171e-01,  -3.45197380e-01,  -2.54935592e-01,
                         -1.87793329e-01,  -3.35358292e-01,  -5.42935967e-01,
                         -1.86153710e-01,  -1.78256296e-02,  -5.56870580e-01,
                         -4.81165320e-01,   8.78607631e-02,  -2.33677715e-01,
                         -6.62086010e-01,  -1.47499934e-01,   1.91152319e-02,
                         -4.57694739e-01,  -3.85710150e-01,  -1.10044047e-01,
                         -1.97254941e-01,  -3.13148022e-01,  -3.72931927e-01,
                         -2.38549590e-01,  -2.19734982e-02,  -3.19867373e-01,
                         -5.40448964e-01,  -7.94983655e-02,  -4.50963713e-03,
                         -5.29534757e-01,  -3.89935046e-01,   3.41741517e-02,
                         -1.30329639e-01,  -4.88532811e-01,  -3.51714790e-01,
                          3.08195669e-02,  -2.15705752e-01,  -4.61132288e-01,
                         -1.12989239e-01,  -8.08807611e-02,  -3.37947398e-01,
                         -2.10229188e-01,  -1.88171327e-01,  -2.48265713e-01,
                         -5.19244112e-02,  -2.20878154e-01,  -4.36056048e-01,
                          3.04758578e-04,  -1.52141461e-02,  -5.31814814e-01,
                         -2.20738664e-01,   1.56791881e-01,  -2.96915472e-01,
                         -4.54778731e-01,  -4.80707688e-03,  -2.30615046e-02,
                         -3.73715132e-01,  -2.72230208e-01,  -1.68122929e-02,
                         -8.81015956e-02,  -2.82116175e-01,  -2.57561684e-01,
                         -7.85250813e-02,  -2.47044601e-02,  -2.09326431e-01,
                         -3.16392332e-01,  -1.52720325e-02,   4.96412516e-02,
                         -3.48734587e-01,  -2.91541278e-01,   1.65136933e-01,
                         -8.70765522e-02,  -4.47802871e-01,  -1.54233035e-02,
                          9.37471539e-02,  -3.78689855e-01,  -2.05999941e-01,
                          9.86819342e-02,  -1.91489890e-01,  -1.99615344e-01,
                         -5.17154150e-02,  -1.70933813e-01,  -9.88174006e-02,
                          8.42589419e-03,  -2.17550635e-01,  -1.71355665e-01,
                          1.09611012e-01,  -6.19749650e-02,  -2.90325731e-01,
                         -6.02710173e-02,   1.23670898e-01,  -1.32102728e-01,
                         -2.46608540e-01,   7.50104338e-02,   1.05901726e-01,
                         -3.01581532e-01,  -1.68149784e-01,   1.97004557e-01,
                         -1.10620715e-01,  -2.47801259e-01,   5.55724837e-02,
                         -8.70408956e-03,  -1.09685183e-01,  -3.18470187e-02,
                         -1.53360784e-01,   1.18027236e-02,   1.74840137e-01,
                         -2.80470133e-01,  -1.31924644e-01,   3.18080425e-01,
                         -1.19483411e-01,  -2.95113355e-01,   2.56354034e-01,
                          8.36163685e-02,  -3.02778244e-01,   1.08890347e-01,
                          1.32629648e-01,  -1.89601451e-01,  -6.82288921e-03,
                          1.26373127e-01,  -6.34350777e-02,  -6.24289587e-02,
                          4.98877689e-02,  -2.15027258e-02,  -4.69202399e-02,
                          9.62695032e-02,   1.71635468e-02,  -1.34179085e-01,
                          6.88097477e-02,   1.78122804e-01,  -1.18089847e-01,
                         -1.26463398e-01,   2.70549804e-01,   9.96947885e-02,
                         -2.23856568e-01,   1.25013769e-01,   2.19517171e-01,
                         -1.19179770e-01,  -2.15125848e-02,   1.83120966e-01,
                          3.86335477e-02,   2.63138078e-02,   5.80854081e-02,
                         -4.44167107e-02,   1.50524631e-01,   1.26674414e-01,
                         -1.46784708e-01,   8.74169990e-02,   2.53103912e-01,
                         -1.02227181e-01,  -2.80954950e-02,   2.58731812e-01,
                          2.27743927e-02,  -8.44364315e-02,   2.05521137e-01,
                          2.04581231e-01,  -1.11195303e-01,   3.25690731e-02,
                          3.23176384e-01,   4.51638997e-02,  -1.15558431e-01,
                          2.61809438e-01,   1.83132604e-01,  -8.29605311e-02,
                          1.78954244e-01,   1.49603680e-01,  -7.37833381e-02,
                          2.14669451e-01,   2.26515859e-01,  -1.47721574e-01,
                          1.01086333e-01,   3.70959461e-01,  -4.57741581e-02,
                         -5.21222875e-02,   3.44338775e-01,   1.72717690e-01,
                         -4.71884049e-02,   1.39001533e-01,   2.34351158e-01,
                          8.93427655e-02,   1.02442630e-01,   1.83762997e-01,
                          1.36928454e-01,   1.58669397e-01,   1.47455826e-01,
                          7.74569437e-02,   1.82954937e-01,   2.13834077e-01,
                          4.98436354e-02,   1.10458948e-01,   3.20989490e-01,
                          6.14095703e-02,  -6.07279912e-02,   3.71947885e-01,
                          2.46353164e-01,  -1.72817647e-01,   2.16561139e-01,
                          4.76431757e-01,  -7.45646730e-02,  -4.22260873e-02,
                          4.22440827e-01,   2.12982759e-01,   1.40112936e-02,
                          2.17676103e-01,   1.87984303e-01,   1.48610428e-01,
                          2.45829627e-01,   1.33850187e-01,   1.05242908e-01,
                          2.87190109e-01,   2.57330596e-01,   4.22884747e-02,
                          9.51581672e-02,   3.49087566e-01,   2.42145777e-01,
                         -5.40792271e-02,   2.17948616e-01,   4.42694902e-01,
                          1.41780553e-02,   1.25345709e-02,   4.11084682e-01,
                          1.92910805e-01,   7.76237398e-02,   2.94193566e-01,
                          1.38690025e-01,   1.71674728e-01,   3.25284272e-01,
                          4.76321429e-02,   2.03532547e-01,   4.77999836e-01,
                         -8.42756219e-03,   2.07302608e-02,   6.40454412e-01,
                          1.23503394e-01,  -2.39346743e-01,   5.54465532e-01,
                          4.63416398e-01,  -1.69817820e-01,   1.11751385e-01,
                          4.56617355e-01,   2.10290506e-01,   7.86512047e-02,
                          1.45330161e-01,   2.72525698e-01,   3.36805105e-01,
                          1.13366149e-01,   8.71498659e-02,   2.61467516e-01,
                          3.17543447e-01,   2.54304469e-01,   5.44977337e-02,
                          1.59828007e-01,   5.01847386e-01,   1.95703179e-01,
                         -1.29683107e-01,   4.19418722e-01,   5.11461556e-01,
                         -1.15305550e-01,   1.24431029e-01,   5.03686488e-01,
                          1.28003806e-01,   7.54344240e-02,   2.87101746e-01,
                          2.10559875e-01,   2.57888526e-01,   1.94034725e-01,
                          1.64932385e-02,   3.50734442e-01,   4.05108780e-01,
                         -1.25680655e-01,   1.89093351e-01,   6.22561157e-01,
                          2.42823921e-02,  -1.03563130e-01,   5.07972062e-01,
                          4.33601350e-01,  -1.08620882e-01,   1.08806998e-01,
                          5.44579208e-01,   2.66738862e-01,  -8.74156430e-02,
                          1.94368780e-01,   4.27107573e-01,   2.02328950e-01,
                          1.17297135e-01,   1.40404403e-01,   1.61349609e-01,
                          4.04434115e-01,   2.37172544e-01,  -1.77334040e-01,
                          2.89520979e-01,   6.08264923e-01,  -7.52062500e-02,
                         -1.18362613e-01,   5.40540040e-01,   3.35078716e-01,
                         -1.11164346e-01,   1.79905474e-01,   4.16392595e-01,
                          1.79186940e-01,   5.21350205e-02,   1.79611221e-01,
                          3.03865671e-01,   2.32524797e-01,   6.46798164e-02,
                          1.31888196e-01,   3.42916310e-01,   2.00715259e-01,
                         -5.93835041e-02,   2.12866694e-01,   4.46589559e-01,
                          1.51771903e-02,  -8.91800523e-02,   4.37071651e-01,
                          3.46451521e-01,  -1.86726749e-01,   7.28395134e-02,
                          5.55918097e-01,   1.60829216e-01,  -1.55379310e-01,
                          2.59168357e-01,   3.56522053e-01,   9.55617428e-02,
                          1.10763595e-01,   1.05996996e-01,   1.89676329e-01,
                          3.79757106e-01,   4.53392081e-02,  -1.45739302e-01,
                          3.52749407e-01,   3.99167597e-01,  -1.66224271e-01,
                         -5.80027513e-02,   4.66458708e-01,   2.45212793e-01,
                         -2.39928082e-01,   1.04656249e-01,   4.44779128e-01,
                          5.42406812e-02,  -7.64976144e-02,   2.35005841e-01,
                          2.15453833e-01,   6.58076257e-02,   9.96219814e-02,
                          8.97059217e-02,   2.30887622e-01,   2.17297912e-01,
                         -1.31161690e-01,   1.52408257e-01,   4.32869256e-01,
                         -1.45214140e-01,  -8.74486491e-02,   5.03466845e-01,
                          1.15990631e-01,  -3.00562501e-01,   2.36595556e-01,
                          3.53845835e-01,  -9.56088975e-02,  -4.26975004e-02,
                          2.06151322e-01,   1.93731412e-01,   8.45914930e-02,
                         -6.81612492e-02,   2.93421224e-02,   2.76498944e-01,
                          1.76154688e-01,  -8.80161747e-02,  -2.07551699e-02,
                          2.84115881e-01,   2.37126231e-01,  -1.71690270e-01,
                         -1.17492639e-01,   4.25303549e-01,   1.70962542e-01,
                         -3.56939048e-01,   1.24509171e-01,   3.68248135e-01,
                         -1.61866188e-01,  -1.02242664e-01,   2.46596277e-01,
                          3.58373076e-02,  -1.19401840e-02,   6.56943917e-02,
                         -7.01210350e-02,   1.55637920e-01,   1.25495642e-01,
                         -2.22645700e-01,   1.47148103e-01,   2.91484922e-01,
                         -2.85059005e-01,  -3.89624797e-02,   4.18625802e-01,
                         -9.71793532e-02,  -2.58245617e-01,   2.63137013e-01,
                          2.06179798e-01,  -2.15604246e-01,  -8.28072429e-02,
                          1.84386805e-01,   9.44073498e-02,  -8.08562562e-02,
                         -8.19246173e-02,   3.62604409e-02,   7.26233125e-02,
                          4.24947962e-02,  -1.25721991e-01,  -1.33832157e-01,
                          2.42989466e-01,   1.45892709e-01,  -3.94094646e-01,
                         -3.89686264e-02,   4.22260940e-01,  -1.32161483e-01,
                         -3.26024592e-01,   2.22241461e-01,   1.50388300e-01,
                         -2.12276638e-01,  -7.11338744e-02,   8.42072219e-02,
                          1.66774672e-02,  -2.53405925e-02,  -7.99383521e-02,
                         -3.95159312e-02,   7.01545253e-02,  -7.74039477e-02,
                         -1.60462096e-01,   8.71974751e-02,   3.91041897e-02,
                         -2.29719475e-01,  -3.67456861e-02,   1.44788191e-01,
                         -1.30268872e-01,  -2.34440193e-01,   1.48534253e-01,
                          9.87180248e-02,  -2.76483685e-01,  -1.06264561e-01,
                          2.17268541e-01,  -5.97243048e-02,  -2.64859170e-01,
                          6.78877085e-02,   4.31962535e-02,  -1.19150907e-01,
                          3.38291191e-02,  -1.85018912e-01,  -1.92083508e-01,
                          2.80921459e-01,  -3.98118868e-02,  -4.58996475e-01,
                          5.98118417e-02,   2.39224926e-01,  -2.84889340e-01,
                         -2.61156261e-01,   1.31259620e-01,   4.83883359e-02,
                         -2.08244950e-01,  -1.26179352e-01,   3.35640609e-02,
                         -4.55036648e-02,  -1.22886427e-01,  -4.34849150e-02,
                         -4.84205149e-02,  -6.66430369e-02,  -2.82140784e-02,
                         -1.32651478e-01,  -6.61170781e-02,   1.16179539e-02,
                         -1.71282500e-01,  -8.04595128e-02,   8.59196633e-02,
                         -2.31133834e-01,  -2.19045937e-01,   1.95693284e-01,
                         -1.09474912e-01,  -3.87877017e-01,   6.98316395e-02,
                          1.12039827e-01,  -3.09130043e-01,  -1.80519566e-01,
                          6.76487684e-02,  -1.03743009e-01,  -1.16660066e-01,
                         -3.80676799e-02,  -1.91413894e-01,  -6.04211316e-02,
                          5.84267005e-02,  -1.67444333e-01,  -2.11716592e-01,
                          5.84900205e-04,   4.84743267e-02,  -1.89691857e-01,
                         -2.55717605e-01,   6.48873746e-02,   3.72059154e-03,
                         -2.97698796e-01,  -8.22594017e-02,   4.77538705e-02,
                         -2.65989304e-01,  -9.98564288e-02,   4.42340448e-02,
                         -3.04241359e-01,  -1.03867896e-01,   8.25326592e-02,
                         -2.52638966e-01,  -1.25650212e-01,   3.09877079e-02,
                         -2.66495794e-01,  -2.43926868e-02,   6.39413819e-02,
                         -3.80197883e-01,  -5.59136868e-02,   2.25505903e-01,
                         -3.54596585e-01,  -2.96053201e-01,   2.06894234e-01,
                         -6.53669685e-02,  -4.01517302e-01,  -5.83899915e-02,
                          7.07130432e-02,  -2.12224364e-01,  -2.21672177e-01,
                         -9.62223411e-02,  -6.40946031e-02,  -9.45213214e-02,
                         -1.40650749e-01,  -1.71689406e-01,  -1.57701805e-01,
                         -1.91995390e-02,  -2.27608830e-02,  -2.86031991e-01,
                         -1.45967126e-01,   1.30385682e-01,  -1.87362880e-01,
                         -2.69199759e-01,   8.65097642e-02,  -7.85644129e-02,
                         -2.91326761e-01,   1.39402347e-02,  -2.60064043e-02,
                         -3.02921236e-01,  -1.00411668e-01,   2.32451968e-02,
                         -1.95998013e-01,  -1.61223650e-01,  -1.06146462e-01,
                         -1.24047056e-01,  -1.65264178e-02,  -1.96542189e-01,
                         -3.02978426e-01,   6.55943975e-02,   9.63754058e-02,
                         -3.80548120e-01,  -2.73589343e-01,   2.32720494e-01,
                         -1.65288597e-02,  -4.85976368e-01,  -9.12571326e-02,
                          2.75224894e-01,  -2.24768072e-01,  -3.87896627e-01,
                          9.43264961e-02,  -3.25737149e-02,  -2.64782429e-01,
                         -4.20974046e-02,  -1.17747471e-01,  -2.16547281e-01,
                          4.86746654e-02,  -1.40095308e-01,  -3.53196502e-01,
                          5.90220988e-02,   2.55381856e-02,  -3.74189168e-01,
                         -1.01428494e-01,   1.04300044e-01,  -2.24651858e-01,
                         -2.48827994e-01,   4.82253842e-02,  -1.44432550e-02,
                         -2.55382091e-01,  -1.38009697e-01,   4.85681482e-02,
                         -9.20526311e-02,  -2.54304856e-01,  -9.77963358e-02,
                          4.76880223e-02,  -8.34800005e-02,  -2.38661334e-01,
                         -1.94791108e-01,   4.16544341e-02,   2.81551182e-02,
                         -3.97762537e-01,  -1.96326539e-01,   2.87887484e-01,
                         -1.46213666e-01,  -5.44079483e-01,   8.23517218e-02,
                          2.48168603e-01,  -3.92333537e-01,  -2.73327142e-01,
                          1.79763719e-01,  -6.43666312e-02,  -2.30730459e-01,
                         -8.37345272e-02,  -9.85774323e-02,  -3.19409519e-02,
                          7.71793956e-03,  -2.28020966e-01,  -1.86612070e-01,
                          9.36553329e-02,  -7.01765418e-02,  -2.89919466e-01,
                         -6.27634823e-02,   1.11574642e-01,  -1.89095780e-01,
                         -2.94168442e-01,   1.28551990e-01,   5.80449179e-02,
                         -3.97858679e-01,  -9.06121656e-02,   2.42989197e-01,
                         -2.10826144e-01,  -2.67159164e-01,   6.56252652e-02,
                         -1.75580792e-02,  -6.98872879e-02,  -1.05203107e-01,
                         -2.03383923e-01,   1.39250800e-01,   7.11130127e-02,
                         -4.85599369e-01,  -3.18623334e-02,   4.17169005e-01,
                         -3.07260096e-01,  -4.35735077e-01,   2.88136452e-01,
                          8.35239142e-02,  -4.05236423e-01,  -9.73369852e-02,
                          1.59274176e-01,  -6.19600751e-02,  -1.77614897e-01,
                         -1.29173860e-01,   9.77609120e-03,   3.04703582e-02,
                         -1.16614662e-01,  -1.40698820e-01,  -1.55531364e-02,
                          7.11743087e-02,  -3.93031277e-02,  -2.37980828e-01,
                         -4.68847435e-03,   2.29482457e-01,  -1.95147350e-01,
                         -2.78953731e-01,   2.74748087e-01,   4.57022712e-02,
                         -4.15244401e-01,   7.93180391e-02,   2.38334566e-01,
                         -2.53362626e-01,  -1.56982079e-01,   1.26960605e-01,
                         -7.34992139e-03,  -7.23341033e-02,  -1.34090170e-01,
                         -9.14357007e-02,   2.43519425e-01,  -7.08272308e-03,
                         -4.36007529e-01,   1.30883858e-01,   3.57926607e-01,
                         -2.74480611e-01,  -2.79350847e-01,   3.25414985e-01,
                          1.44432336e-01,  -3.52053672e-01,  -3.75445001e-02,
                          2.72982061e-01,  -5.59723414e-02,  -2.16325119e-01,
                          6.96366876e-02,   8.32621902e-02,  -5.00812978e-02,
                         -3.40764523e-02,  -1.12495765e-01,  -4.29218402e-03,
                          2.11866796e-01,  -9.54687521e-02,  -2.80254334e-01,
                          2.18634501e-01,   2.04046965e-01,  -3.20856363e-01,
                         -7.48792961e-02,   3.60328615e-01,  -3.15592624e-02,
                         -2.50988781e-01,   1.38734490e-01,   1.98170438e-01,
                         -1.16001561e-01,  -1.34337932e-01,   1.33442625e-01,
                          1.68163672e-01,  -9.13187042e-02,  -1.44634545e-01,
                          8.97520110e-02,   1.84738532e-01,  -8.05984363e-02,
                         -2.11891547e-01,   1.48674488e-01,   2.70018339e-01,
                         -2.30573148e-01,  -2.40233600e-01,   3.95873815e-01,
                          1.48155764e-01,  -3.90522927e-01,   6.66695312e-02,
                          3.74415517e-01,  -1.46294668e-01,  -1.09683603e-01,
                          1.89351499e-01,   2.96831857e-02,   3.76005322e-02,
                          7.77142122e-02,  -1.12434737e-01,   7.47747421e-02,
                          2.44256556e-01,  -1.43163159e-01,  -1.48997247e-01,
                          3.08047414e-01,   1.32532299e-01,  -2.86230534e-01,
                          4.55959234e-03,   3.26111495e-01,  -3.77227142e-02,
                         -2.55290061e-01,   1.73453763e-01,   2.80813962e-01,
                         -1.83191836e-01,  -1.34139702e-01,   2.79863536e-01,
                          9.01080295e-02,  -9.67523456e-02,   5.11763953e-02,
                          6.25320673e-02,   1.41416654e-01,   5.10451980e-02,
                         -2.13882253e-01,   1.85137197e-01,   3.32005113e-01,
                         -2.79075176e-01,  -9.28516015e-02,   4.24056590e-01,
                         -5.77817559e-02,  -2.53822535e-01,   2.64451295e-01,
                          1.20735317e-01,  -1.41966343e-01,   9.27523673e-02,
                          5.99834397e-02,   2.16919705e-02,   8.62900317e-02,
                         -3.09217209e-03,   2.26496477e-02,   1.38440177e-01,
                          8.70089754e-02,  -3.80510651e-02,  -2.43956633e-02,
                          1.76164970e-01,   1.91450983e-01,  -1.55448079e-01,
                         -5.16578481e-02,   3.41345608e-01,  -4.14738506e-02,
                         -2.59915948e-01,   2.98250049e-01,   1.98279366e-01,
                         -3.02863747e-01,   8.17076266e-02,   2.76542485e-01,
                         -1.37814596e-01,  -2.18225271e-02,   1.46045864e-01,
                         -1.77885238e-02,   1.41881838e-01,   4.20800038e-02,
                         -1.74987361e-01,   2.33714759e-01,   2.05201522e-01,
                         -2.48211429e-01,   9.33453664e-02,   3.33219498e-01,
                         -1.60715342e-01,  -3.76683474e-02,   2.52298325e-01,
                         -1.89075246e-02,  -5.27945012e-02,   1.45752102e-01,
                          7.16721192e-02,  -3.35135795e-02,   1.40039334e-02,
                          1.08491257e-01,   3.27222608e-02,  -1.32459262e-02,
                          9.73077938e-02,   4.22013551e-02,  -4.47980314e-02,
                          1.40691683e-01,   7.74331987e-02,  -1.32799014e-01,
                          1.53084233e-01,   2.36169368e-01,  -1.69712648e-01,
                         -4.91993800e-02,   2.93614477e-01,  -1.46136908e-02,
                         -1.47980049e-01,   1.79260015e-01,   1.23917677e-01,
                         -9.91091132e-02,   1.27329305e-02,   9.94120166e-02,
                          3.21242176e-02,   3.36956978e-02,  -2.32549268e-03,
                         -9.48995701e-04,   1.28946170e-01,   1.39772613e-02,
                         -1.21783733e-01,   9.44552124e-02,   1.78631976e-01,
                         -1.14316441e-01,  -3.37899178e-02,   2.25219995e-01,
                         -2.02224087e-02,  -1.54459625e-01,   2.08501101e-01,
                          1.82113126e-01,  -2.26709813e-01,   2.46053990e-02,
                          3.07743132e-01,  -9.32338983e-02,  -1.23324037e-01,
                          2.03958869e-01,   7.87202083e-03,  -6.19947799e-02,
                          1.57010004e-01,  -5.37376888e-02,  -1.02493919e-01,
                          1.94794312e-01,   4.67741899e-02,  -1.79782242e-01,
                          1.22221179e-01,   1.78826943e-01,  -1.45049155e-01,
                         -8.05075765e-02,   1.96855217e-01,   8.38691369e-02,
                         -1.41267255e-01,   2.24898644e-02,   1.83702648e-01,
                         -2.59551369e-02,  -5.12339585e-02,   8.47689807e-02,
                          2.03778110e-02,   4.79694754e-02,   4.40639481e-02,
                         -8.87799188e-02,   8.19212794e-02,   1.18449122e-01,
                         -1.90415308e-01,   2.76230890e-02,   2.54166603e-01,
                         -1.63852826e-01,  -1.64509431e-01,   3.24295342e-01,
                          4.32750130e-05,  -2.87289053e-01,   1.65453911e-01,
                          2.43856803e-01,  -1.63118556e-01,  -9.38644111e-02,
                          1.77687034e-01,   7.25749359e-02,  -6.71313629e-02,
                         -8.60742945e-03,   7.54580498e-02,   3.51416953e-02,
                          3.88533249e-02,   1.01242785e-03,  -1.09866604e-01,
                          1.06779702e-01,   1.87051982e-01,  -1.95136845e-01,
                         -1.27295941e-01,   3.05638582e-01,   3.52723897e-02,
                         -3.19558054e-01,   1.64600164e-01,   2.24078029e-01,
                         -2.16246471e-01,  -1.34051091e-03,   1.59316823e-01,
                         -6.27193525e-02,   3.44555303e-02,   4.15976383e-02,
                         -7.44116455e-02,   1.84994683e-01,   3.58606912e-02,
                         -2.44613215e-01,   2.03643084e-01,   1.92462146e-01,
                         -3.16680163e-01,   5.11134602e-02,   3.47296983e-01,
                         -1.76270053e-01,  -2.39892378e-01,   2.12192446e-01,
                          1.69152662e-01,  -1.97705984e-01,  -1.32205486e-01,
                          1.93746448e-01,   1.24574989e-01,  -1.86807349e-01,
                         -6.24286123e-02,   1.30063355e-01,   3.87299992e-02,
                          2.11272985e-02,  -3.49478349e-02,  -8.42415541e-02,
                          1.76477343e-01,   1.11682370e-01,  -2.69448459e-01,
                          3.38228121e-02,   3.59811634e-01,  -1.55578285e-01,
                         -2.61327058e-01,   2.67799675e-01,   1.21381328e-01,
                         -2.43886486e-01,  -7.63629982e-03,   1.47808388e-01,
                         -1.83170829e-02,  -7.56181255e-02,  -4.81531397e-02,
                          4.68501747e-02,   1.05643742e-01,  -8.81133229e-02,
                         -1.24856278e-01,   2.15397149e-01,   5.99282049e-02,
                         -2.85260051e-01,   7.06595853e-02,   3.37703228e-01,
                         -1.47080213e-01,  -2.78183937e-01,   2.55781204e-01,
                          2.47872949e-01,  -3.72409284e-01,  -1.17031410e-01,
                          3.95962119e-01,  -4.02956381e-02,  -2.65791237e-01,
                          6.65903240e-02,   4.99515571e-02,  -1.02330861e-03,
                          3.97288911e-02,  -2.16464967e-01,   9.03923251e-03,
                          3.44726413e-01,  -1.93480626e-01,  -3.38559419e-01,
                          2.80990928e-01,   2.35577226e-01,  -2.77724236e-01,
                         -1.25018567e-01,   2.84493297e-01,   1.03300765e-01,
                         -2.51628965e-01,  -7.26964176e-02,   2.46756956e-01,
                          2.84132268e-02,  -2.07163766e-01,   2.31086724e-02,
                          1.27759621e-01,  -3.08446344e-02,  -1.07249692e-01,
                         -5.77750914e-02,   1.46356687e-01,   4.28870358e-02,
                         -2.88719505e-01,   2.25074627e-02,   3.32211614e-01,
                         -2.23890141e-01,  -3.34590048e-01,   4.25575852e-01,
                          1.72876433e-01,  -5.25126994e-01,   2.90030055e-02,
                          4.10125315e-01,  -1.32366449e-01,  -2.19472930e-01,
                          9.01728868e-02,   8.15554410e-02,   5.67361265e-02,
                         -7.94843659e-02,  -2.11097553e-01,   1.24192283e-01,
                          2.37679705e-01,  -2.02963844e-01,  -2.62977183e-01,
                          1.97573975e-01,   2.04280630e-01,  -3.10531199e-01,
                         -2.18876451e-01,   3.52015376e-01,   7.87637755e-02,
                         -4.00793433e-01,   2.21575201e-02,   2.79361695e-01,
                         -1.49718225e-01,  -1.46453068e-01,   1.04538970e-01,
                          1.35490764e-02,   3.27277556e-02,  -7.39368051e-02,
                         -1.53447613e-01,   2.32576385e-01,   3.24350409e-02,
                         -3.59185517e-01,   1.49778977e-01,   2.84367800e-01,
                         -3.93448025e-01,  -1.37700632e-01,   3.63458842e-01,
                         -8.38327855e-02,  -3.30934405e-01,   1.00981772e-01,
                          1.84149116e-01,  -1.50714368e-01,  -1.84441656e-01,
                          5.42128235e-02,   1.27525866e-01,  -3.85158099e-02,
                         -1.53176174e-01,  -4.16543558e-02,   1.01055808e-01,
                          1.02496035e-01,  -1.53135344e-01,  -2.25202754e-01,
                          2.25942329e-01,   2.24307522e-01,  -3.92360806e-01,
                         -1.93341598e-01,   4.33264583e-01,  -2.82109827e-02,
                         -3.87505621e-01,   1.46725804e-01,   1.75085172e-01,
                         -2.02239111e-01,  -7.54344836e-02,   5.40625565e-02,
                         -2.59409696e-02,   2.95997616e-02,  -8.82288218e-02,
                         -8.84857327e-02,   1.77774653e-01,  -4.82646078e-02,
                         -2.42619112e-01,   1.85185850e-01,   1.35925472e-01,
                         -2.85287648e-01,  -2.32346877e-02,   2.80175239e-01,
                         -1.22415736e-01,  -2.74478137e-01,   2.00416535e-01,
                          1.54855907e-01,  -2.54848182e-01,  -1.02410786e-01,
                          1.70242563e-01,  -1.82073731e-02,  -1.19826488e-01,
                         -1.27543043e-02,  -6.92750514e-02,   5.20011373e-02,
                          1.31364703e-01,  -2.44612724e-01,  -1.66358128e-01,
                          3.18380415e-01,   5.61890788e-02,  -3.59465033e-01,
                          5.02719320e-02,   3.10431123e-01,  -1.29498065e-01,
                         -2.34585315e-01,   1.28896505e-01,   1.79825559e-01,
                         -1.26117900e-01,  -1.10042624e-01,   9.67818350e-02,
                          3.07063255e-02,  -6.80288672e-02,  -2.96612605e-02,
                         -1.23890787e-02,   3.79206687e-02,   2.14304100e-03,
                         -1.12137869e-01,   1.60425138e-02,   9.67612118e-02,
                         -1.81307077e-01,  -2.33816938e-03,   2.65237957e-01,
                         -1.50656462e-01,  -2.49505818e-01,   3.11075538e-01,
                          1.13059938e-01,  -3.35783660e-01,   9.24952105e-02,
                          2.44776398e-01,  -1.52259693e-01,  -5.93640581e-02,
                          8.62183571e-02,  -7.62623847e-02,   8.68098289e-02,
                          8.63313898e-02,  -2.28939831e-01,  -2.58925017e-02,
                          2.57192999e-01,  -7.39524215e-02,  -2.64405340e-01,
                          1.14225730e-01,   2.25202903e-01,  -1.33047014e-01,
                         -2.02273935e-01,   1.67722687e-01,   1.40618250e-01,
                         -1.75024763e-01,   1.67803802e-02,   1.58483371e-01,
                         -8.16393346e-02,  -3.98718473e-03,   8.64887834e-02,
                         -8.42379704e-02,   6.63987324e-02,   8.50471109e-02,
                         -1.30089477e-01,   8.62097740e-02,   8.27960894e-02,
                         -2.20361426e-01,   1.01251081e-01,   2.00256273e-01,
                         -2.82743245e-01,  -2.15454400e-02,   3.17985892e-01,
                         -1.48602083e-01,  -2.23836377e-01,   1.94688708e-01,
                          1.44065917e-01,  -1.40535563e-01,  -3.39712501e-02,
                          1.00516923e-01,   3.94204482e-02,   9.52734053e-03,
                         -8.51797871e-04,  -2.52587497e-02,   3.79128270e-02,
                          1.37865514e-01,   7.34832464e-03,  -2.05844864e-01,
                          8.54418054e-02,   2.91090131e-01,  -2.01747864e-01,
                         -1.67536899e-01,   2.86470085e-01,  -2.51670722e-02,
                         -2.32308134e-01,   1.71290085e-01,   4.65947352e-02,
                         -1.67014077e-01,   1.47757098e-01,   3.50541472e-02,
                         -1.68681353e-01,   1.31417409e-01,   6.09874651e-02,
                         -9.84189510e-02,   1.29181921e-01,   8.50362238e-03,
                         -1.30655572e-01,   2.11298585e-01,   3.06670982e-02,
                         -2.56262988e-01,   1.70911998e-01,   2.36545116e-01,
                         -2.26350993e-01,  -1.17737636e-01,   2.47674212e-01,
                          5.00997305e-02,  -2.38029018e-01,   1.48126408e-02,
                          2.08062500e-01,  -3.98811512e-02,  -1.29647106e-01,
                          5.86034432e-02,   4.73540239e-02,  -2.77903080e-02,
                          9.37890857e-02,  -2.64704097e-02,  -1.19545646e-01,
                          1.93688691e-01,   1.03691496e-01,  -2.31415927e-01,
                          4.80080843e-02,   2.03463748e-01,  -1.25997245e-01,
                         -6.78631961e-02,   1.56551972e-01,  -4.65816557e-02,
                         -1.18106514e-01,   1.22937344e-01,   5.46686128e-02,
                         -1.53487459e-01,  -1.20907668e-02,   1.38711929e-01,
                         -2.08361521e-02,  -1.26644328e-01,   1.28586302e-02,
                          9.05643702e-02,   5.59675507e-02,  -6.91579729e-02,
                         -1.44321337e-01,   1.51982859e-01,   2.18458861e-01,
                         -2.71433443e-01,  -1.25347987e-01,   4.16919529e-01,
                         -1.26627693e-03,  -4.12710011e-01,   1.81657910e-01,
                          2.84599692e-01,  -2.22201928e-01,  -8.87615234e-02,
                          1.70725554e-01,  -4.07498665e-02,  -3.24961655e-02,
                          4.84930575e-02,  -1.19240656e-01,   2.17569657e-02,
                          1.52817950e-01,  -1.30782396e-01,  -8.27704966e-02,
                          1.80375606e-01,  -1.94950327e-02,  -1.58264160e-01,
                          4.62521017e-02,   1.47863165e-01,  -6.75593466e-02,
                         -1.69620112e-01,   1.36916831e-01,   1.34315893e-01,
                         -2.28500873e-01,  -3.55826579e-02,   2.50491321e-01,
                         -8.73672441e-02,  -1.69006094e-01,   8.31704959e-02,
                          3.38345915e-02,   2.86017172e-02,  -9.70222950e-02,
                         -1.81884736e-01,   2.21304893e-01,   1.41767234e-01,
                         -4.53796774e-01,  -1.52909430e-02,   4.62678552e-01,
                         -2.04612151e-01,  -3.59119982e-01,   2.64349461e-01,
                          1.91699445e-01,  -2.52204776e-01,  -9.22949538e-02,
                          1.50863826e-01,   7.54593760e-02,  -7.24990144e-02,
                         -8.87990445e-02,   3.97977186e-03,   6.69406578e-02,
                          3.53870280e-02,  -1.22646526e-01,  -9.58657712e-02,
                          1.51397139e-01,   5.24852760e-02,  -2.82221556e-01,
                         -7.20790448e-03,   2.83704460e-01,  -2.09402010e-01,
                         -2.25283653e-01,   3.10139954e-01,  -1.59210563e-02,
                         -3.49517882e-01,   1.40917152e-01,   1.75739035e-01,
                         -1.64234340e-01,  -3.65189724e-02,   2.34653018e-02,
                         -4.03019687e-04,   1.36940584e-01,  -1.84329674e-01,
                         -2.01706856e-01,   3.94825071e-01,   1.86998062e-02,
                         -4.99955475e-01,   1.55567735e-01,   3.43167365e-01,
                         -2.93970257e-01,  -2.63145059e-01,   2.61127561e-01,
                          1.20845988e-01,  -2.47808784e-01,  -1.57337561e-01,
                          1.78617775e-01,   9.57508162e-02,  -1.99091598e-01,
                         -4.54668291e-02,   8.73954296e-02,   1.51402429e-02,
                          6.43387996e-03,  -1.14687152e-01,  -8.41112435e-02,
                          2.17477188e-01,   3.85924801e-02,  -3.17230165e-01,
                          1.21265523e-01,   2.57972032e-01,  -3.26940924e-01,
                         -1.24205023e-01,   3.49079013e-01,  -5.37801199e-02,
                         -3.09721261e-01,   1.06217004e-01,   1.55144989e-01,
                         -1.41980678e-01,  -1.05621986e-01,   3.59789357e-02,
                          9.14222673e-02,   1.34750493e-02,  -2.01912746e-01,
                         -3.68207693e-02,   2.89039999e-01,  -5.15532009e-02,
                         -3.34237963e-01,   1.65404573e-01,   3.14759314e-01,
                         -2.74019390e-01,  -2.44580388e-01,   3.35212499e-01,
                          1.13395676e-01,  -3.45916897e-01,   1.67900883e-03,
                          2.48977527e-01,  -1.25505105e-01,  -1.53038740e-01,
                          6.31620586e-02,  -8.42485391e-03,   3.94897684e-02,
                          4.05252166e-03,  -2.14996338e-01,   3.90603356e-02,
                          2.52013087e-01,  -1.86471537e-01,  -2.07064658e-01,
                          2.58011639e-01,   1.07993223e-01,  -2.57350475e-01,
                         -4.69349027e-02,   2.44285569e-01,   9.28743836e-03,
                         -2.27414280e-01,   6.74372092e-02,   2.08679929e-01,
                         -1.56077668e-01,  -1.71364009e-01,   1.60984039e-01,
                          6.86348826e-02,  -1.17513008e-01,  -1.02081254e-01,
                          2.06306577e-02,   1.76418677e-01,  -7.57493526e-02,
                         -3.09157461e-01,   1.91911027e-01,   2.83987731e-01,
                         -3.46347570e-01,  -1.65161401e-01,   4.19742376e-01,
                         -3.91915664e-02,  -3.23837876e-01,   1.62080243e-01,
                          1.70875534e-01,  -1.50885865e-01,  -3.21489237e-02,
                          4.52761650e-02,  -3.16983797e-02,   7.65946209e-02,
                         -1.96446646e-02,  -1.64744809e-01,   8.96873847e-02,
                          1.51019320e-01,  -1.95191517e-01,  -1.59794718e-01,
                          2.33778685e-01,   8.76750797e-02,  -3.04479480e-01,
                         -2.71024508e-03,   3.02956045e-01,  -1.39509797e-01,
                         -2.44118258e-01,   2.51563787e-01,   1.43486544e-01,
                         -2.46634081e-01,   7.70743052e-03,   1.38829693e-01,
                         -2.69520357e-02,   4.60998714e-03,  -8.08498487e-02,
                         -9.78185888e-03,   2.44439662e-01,  -1.15321241e-01,
                         -2.89936751e-01,   2.89193839e-01,   1.42698973e-01,
                         -3.89629632e-01,   3.99845019e-02,   2.91223586e-01,
                         -1.49587572e-01,  -1.68485925e-01,   1.15355507e-01,
                          7.21324608e-02,  -9.85123217e-02,  -3.72462496e-02,
                          9.10705552e-02,   1.14174346e-02,  -5.73723614e-02,
                          4.05273065e-02,  -2.21759714e-02,  -1.24328043e-02,
                          1.69514075e-01,  -8.80028084e-02,  -2.04837263e-01,
                          2.67707705e-01,   1.05255142e-01,  -3.65105212e-01,
                          7.31203407e-02,   3.18499982e-01,  -2.48909488e-01,
                         -1.98553920e-01,   2.72539705e-01,  -1.00097153e-02,
                         -2.10727453e-01,   8.83329809e-02,   5.76686040e-02,
                         -5.97554408e-02,   1.22505631e-02,  -7.88698494e-02,
                          1.57458521e-02,   1.71422705e-01,  -1.16671413e-01,
                         -1.41588822e-01,   2.45243296e-01,   5.03031760e-02,
                         -2.53186256e-01,   5.16728982e-02,   2.16494575e-01,
                         -1.28093347e-01,  -1.21567704e-01,   1.50491476e-01,
                          2.73223948e-02,  -1.93019435e-01,   4.18949202e-02,
                          1.33616120e-01,  -1.70396715e-01,  -3.39308335e-03,
                          1.45905972e-01,  -1.86136097e-01,  -2.49584708e-02,
                          2.00327054e-01,  -1.41718566e-01,  -1.13651074e-01,
                          2.33470246e-01,  -4.45179082e-02,  -1.86405718e-01,
                          1.45684287e-01,   8.26257989e-02,  -1.35693580e-01,
                         -1.70472804e-02,   1.46910429e-01,   1.68352120e-03,
                         -1.47715896e-01,   5.25283776e-02,   1.31566063e-01,
                         -8.73637572e-02,  -8.17046016e-02,   9.00828764e-02,
                         -2.22420488e-02,  -4.12726104e-02,   2.30296180e-02,
                         -5.81803843e-02,   4.97037917e-02,   8.52677673e-02,
                         -1.61648586e-01,   2.31060311e-02,   1.83450460e-01,
                         -1.82123527e-01,  -4.59422097e-02,   2.95060515e-01,
                         -1.14263281e-01,  -2.22133175e-01,   3.19769114e-01,
                          6.55617192e-03,  -3.31766605e-01,   2.26604834e-01,
                          1.77858636e-01,  -2.49211162e-01,   2.15469431e-02,
                          1.11804403e-01,  -1.33920774e-01,   2.21105292e-02,
                          1.02673911e-01,  -1.02549843e-01,  -4.60047647e-02,
                          9.66823325e-02,   8.20656959e-03,  -9.66018066e-02,
                          2.45263372e-02,   1.66488647e-01,  -6.46077543e-02,
                         -1.35205656e-01,   2.01209292e-01,   8.52710679e-02,
                         -2.17984363e-01,   8.84451270e-02,   1.92865700e-01,
                         -1.08833075e-01,  -2.13730615e-02,   7.05688521e-02,
                         -5.59216514e-02,   9.07586068e-02,  -2.36679893e-03,
                         -1.49710268e-01,   1.72597274e-01,   5.90268709e-02,
                         -2.66279995e-01,   1.41270027e-01,   1.97120920e-01,
                         -2.45117202e-01,  -2.47281380e-02,   3.28109980e-01,
                         -8.98446217e-02,  -2.35043541e-01,   1.94540113e-01,
                          1.87435135e-01,  -1.16986521e-01,  -8.26087147e-02,
                          1.42418638e-01,   7.39189237e-02,  -7.25253150e-02,
                          3.30224670e-02,   1.92810427e-02,  -2.80618090e-02,
                          1.26885921e-01,   2.55602109e-03,  -2.03135088e-01,
                          1.53082758e-01,   1.99569553e-01,  -2.82649815e-01,
                         -4.49772887e-02,   3.57323915e-01,  -9.58571285e-02,
                         -2.24238589e-01,   2.22483099e-01,   9.64663997e-02,
                         -1.43084213e-01,   7.50638917e-02,   6.86711520e-02,
                          8.93579423e-03,   7.86648914e-02,  -7.62236714e-02,
                         -2.59281860e-05,   2.30006054e-01,  -6.93727359e-02,
                         -1.81356981e-01,   2.46161863e-01,   1.09192945e-01,
                         -2.83150136e-01,   3.81178074e-02,   2.99905777e-01,
                         -1.03573248e-01,  -2.17488006e-01,   1.73577264e-01,
                          2.00312972e-01,  -1.98828712e-01,  -9.85490009e-02,
                          2.42067173e-01,   7.12692440e-02,  -1.17710069e-01,
                          3.07978354e-02,   3.20427567e-02,   7.23822117e-02,
                          1.26262054e-01,  -1.33871377e-01,  -5.09763323e-02,
                          2.96347380e-01,   4.43915427e-02,  -2.84933805e-01,
                          9.36308950e-02,   2.99717695e-01,  -1.48019016e-01,
                         -2.00972944e-01,   2.07822293e-01,   1.38327494e-01,
                         -1.96989328e-01,  -5.16192578e-02,   1.82130575e-01,
                          1.15586817e-02,  -6.15584701e-02,   7.88054615e-03,
                          3.35425660e-02,   1.15390748e-01,  -4.69730757e-02,
                         -1.37862012e-01,   2.45731518e-01,   1.38485864e-01,
                         -3.16625178e-01,   6.74855560e-02,   4.06342655e-01,
                         -2.18491450e-01,  -2.77230233e-01,   4.00935918e-01,
                          1.38549984e-01,  -3.58790785e-01,   3.36478315e-02,
                          2.31058300e-01,  -4.63040881e-02,  -5.88789135e-02,
                         -2.70705670e-02,   1.07164904e-02,   1.85612887e-01,
                         -4.69840132e-02,  -2.23216653e-01,   1.35072857e-01,
                          2.40810633e-01,  -1.00779183e-01,  -2.04662636e-01,
                          1.54319212e-01,   2.39959285e-01,  -1.97558090e-01,
                         -2.09986031e-01,   2.92304009e-01,   1.82898819e-01,
                         -3.10194671e-01,  -2.07366329e-02,   2.49954984e-01,
                         -8.07662308e-02,  -9.59184691e-02,   5.13077267e-02,
                          2.93610687e-03,   9.11333412e-02,  -8.42860490e-02,
                         -1.70875445e-01,   2.58481085e-01,   5.94134592e-02,
                         -3.73693466e-01,   1.77546784e-01,   3.45991313e-01,
                         -3.73885840e-01,  -1.39101267e-01,   4.15916979e-01,
                          1.29558425e-02,  -3.09933186e-01,   7.42871836e-02,
                          2.26282075e-01,  -1.82123482e-02,  -1.57416627e-01,
                         -3.61957885e-02,   1.60273030e-01,   9.25938785e-02,
                         -1.21257320e-01,  -1.51962698e-01,   7.11984038e-02,
                          2.12461963e-01,  -1.19524755e-01,  -3.01575959e-01,
                          2.49850556e-01,   2.70071059e-01,  -4.04642284e-01,
                         -1.57115027e-01,   4.13351715e-01,  -6.41633198e-02,
                         -3.12682807e-01,   1.59400672e-01,   1.40389800e-01,
                         -1.09119058e-01,  -6.04472198e-02,  -4.37509455e-02,
                          1.05917253e-01,   1.37704268e-01,  -2.49708861e-01,
                         -7.78956860e-02,   3.32391590e-01,  -1.52094856e-01,
                         -3.07306856e-01,   2.46496573e-01,   1.36468902e-01,
                         -3.39997113e-01,  -4.05233167e-02,   2.54882962e-01,
                         -8.70715454e-02,  -2.50433177e-01,   3.44648361e-02,
                          2.37209216e-01,  -7.65580758e-02,  -2.60568529e-01,
                          8.71833414e-02,   1.46171942e-01,  -4.53054048e-02,
                         -7.74825439e-02,  -1.06381111e-01,   7.61934444e-02,
                          2.51615465e-01,  -2.59203434e-01,  -3.26115876e-01,
                          4.13199872e-01,   1.62439555e-01,  -5.13461351e-01,
                         -1.27544664e-02,   3.70082647e-01,  -1.61790505e-01,
                         -2.83367515e-01,   1.02668077e-01,   9.59739089e-02,
                         -8.22598413e-02,  -8.99173990e-02,  -5.46489060e-02,
                          5.88182397e-02,   4.70981374e-02,  -1.58995032e-01,
                         -3.51525508e-02,   1.99841693e-01,  -7.92544857e-02,
                         -2.50218362e-01,   1.83527142e-01,   1.52113587e-01,
                         -3.31794739e-01,  -3.56393382e-02,   3.02012980e-01,
                         -1.32487282e-01,  -3.16846609e-01,   1.98015690e-01,
                          1.16063870e-01,  -2.58694470e-01,  -4.26724888e-02,
                          9.50061977e-02,  -5.05644754e-02,  -1.02720447e-02,
                         -7.80315548e-02,  -1.59293741e-01,   1.73327312e-01,
                          1.28173321e-01,  -3.17414433e-01,  -1.07074790e-01,
                          3.19338888e-01,   6.75923517e-03,  -3.24203968e-01,
                          2.67092790e-02,   2.70874172e-01,  -8.06750506e-02,
                         -2.68674254e-01,   9.46254730e-02,   1.72138393e-01,
                         -1.74553603e-01,  -8.20223764e-02,   9.11685824e-02,
                         -6.79339841e-02,  -1.69392973e-02,  -2.52049286e-02,
                         -1.34625480e-01,   1.31963998e-01,   1.66746993e-02,
                         -2.65494913e-01,   1.52017400e-01,   1.17806323e-01,
                         -3.27558607e-01,   7.22834244e-02,   2.77101606e-01,
                         -2.78290480e-01,  -1.21388607e-01,   3.15571845e-01,
                         -5.84242195e-02,  -2.55441487e-01,   9.47936773e-02,
                          1.02083884e-01,  -9.88010690e-02,  -1.79005098e-02,
                         -4.13044468e-02,  -7.52405971e-02,   8.66095126e-02,
                          1.25371898e-02,  -2.07444221e-01,  -4.60610688e-02,
                          2.32186317e-01,  -4.60982770e-02,  -3.11185569e-01,
                          7.47723728e-02,   2.66306758e-01,  -1.88121051e-01,
                         -2.01785445e-01,   2.36394674e-01,   4.51273993e-02,
                         -1.90126970e-01,   5.49031682e-02,   2.21629161e-02,
                         -4.18535955e-02,   8.37770998e-02,  -8.46286640e-02,
                         -8.81658569e-02,   1.29278466e-01,  -7.71472529e-02,
                         -1.19219877e-01,   1.71581522e-01,  -7.73990452e-02,
                         -2.07956463e-01,   2.21395954e-01,   1.85411517e-03,
                         -2.81858563e-01,   7.23828599e-02,   2.21353099e-01,
                         -1.30535364e-01,  -1.84518501e-01,   1.07935444e-01,
                          1.36285797e-01,  -1.37172937e-01,  -9.31835100e-02,
                          1.34925738e-01,   5.27478755e-03,  -5.91282956e-02,
                          5.92628829e-02,  -1.25006810e-01,  -6.51383102e-02,
                          2.72477567e-01,  -1.01530872e-01,  -3.01922560e-01,
                          2.20692664e-01,   1.51257306e-01,  -3.26047063e-01,
                         -1.03065241e-02,   2.28099361e-01,  -1.39783233e-01,
                         -6.66993633e-02,   1.31831601e-01,  -8.03008005e-02,
                         -6.13294914e-02,   1.03645287e-01,  -2.38409434e-02,
                         -4.59864810e-02,   6.83837309e-02,  -4.52423878e-02,
                         -3.67115857e-03,   9.46515650e-02,  -9.85001326e-02,
                         -4.33839969e-02,   1.89101622e-01,  -5.12248352e-02,
                         -2.33545259e-01,   1.17095932e-01,   2.14890495e-01,
                         -2.23844826e-01,  -1.84506118e-01,   2.86603004e-01,
                          5.90064079e-02,  -3.16710204e-01,   3.41407210e-02,
                          1.95401683e-01,  -1.04429707e-01,  -4.35318276e-02,
                          8.38261321e-02,  -9.97058526e-02,   5.10006510e-02,
                          1.48477405e-01,  -1.68488815e-01,  -7.67820925e-02,
                          2.55014986e-01,  -3.12640355e-03,  -2.26271510e-01,
                          8.38361606e-02,   1.46398962e-01,  -1.27771631e-01,
                         -8.66144076e-02,   1.45106211e-01,  -1.10164247e-02,
                         -1.78295881e-01,   9.25213844e-02,   9.60757434e-02,
                         -2.06714764e-01,   1.87826958e-02,   1.69696212e-01,
                         -1.18034691e-01,  -4.43700850e-02,   3.61208916e-02,
                         -5.22669591e-02,   1.59274131e-01,  -7.94854306e-04,
                         -2.65250355e-01,   1.97221979e-01,   2.73489684e-01,
                         -4.00223672e-01,  -7.46432394e-02,   4.43228066e-01,
                         -1.07196674e-01,  -3.27917039e-01,   1.88594311e-01,
                          1.51799604e-01,  -1.76326349e-01,  -5.35316728e-02,
                          4.75331023e-02,  -6.02960936e-04,   5.03391661e-02,
                         -3.62791605e-02,  -1.34709865e-01,   5.57135195e-02,
                          1.06737442e-01,  -5.63661195e-02,  -9.89336967e-02,
                          7.86802396e-02,   1.07810207e-01,  -1.47275701e-01,
                         -3.99674661e-02,   2.36180753e-01,  -7.48412907e-02,
                         -1.77837774e-01,   2.50948787e-01,   6.93030581e-02,
                         -2.74630398e-01,   7.36870617e-02,   1.79234982e-01,
                         -1.02685757e-01,  -4.65788394e-02,  -3.25405188e-02,
                          3.98660451e-02,   1.53965965e-01,  -1.95000619e-01,
                         -1.63406715e-01,   3.53823990e-01,   4.75223549e-02,
                         -4.14422870e-01,   1.09767720e-01,   3.76559705e-01,
                         -1.73010111e-01,  -2.62698770e-01,   2.17495680e-01,
                          2.27835521e-01,  -1.81589305e-01,  -1.43739924e-01,
                          1.79354176e-01,   7.58013651e-02,  -7.72262439e-02,
                         -6.92098495e-03,  -2.68560592e-02,   3.87363434e-02,
                          1.10146552e-01,  -1.50472075e-01,  -1.32892534e-01,
                          2.74627149e-01,   2.79941019e-02,  -3.21466416e-01,
                          1.58565521e-01,   2.67315120e-01,  -2.82143712e-01,
                         -6.70062229e-02,   3.08725685e-01,  -2.88562421e-02,
                         -1.68436855e-01,   1.12596713e-01,   1.12643227e-01,
                          1.17380973e-02,  -8.75648186e-02,  -6.04294166e-02,
                          2.39769667e-01,   1.00632533e-01,  -3.27649564e-01,
                          4.22553951e-03,   3.84087294e-01,  -8.79110843e-02,
                         -3.68452817e-01,   1.95286602e-01,   3.27205479e-01,
                         -1.95493162e-01,  -2.95928150e-01,   2.91887045e-01,
                          2.28261873e-01,  -2.90409625e-01,  -4.15750183e-02,
                          2.51145095e-01,   2.77115987e-03,  -7.31284469e-02,
                          2.75900662e-02,  -1.00598168e-02,   1.56030685e-01,
                          9.85918269e-02,  -2.39062771e-01,   9.00151394e-03,
                          3.41197550e-01,  -1.07028872e-01,  -2.68102139e-01,
                          2.77656585e-01,   1.75607577e-01,  -2.88065076e-01,
                         -5.59307002e-02,   2.95394957e-01,   1.48601842e-03,
                         -2.41288841e-01,   1.11457922e-01,   2.29136154e-01,
                         -1.15396023e-01,  -1.19669817e-01,   1.02798983e-01,
                          1.32921830e-01,   4.24321331e-02,  -1.26242667e-01,
                         -1.80204362e-02,   3.09700400e-01,   8.32129456e-03,
                         -3.78673285e-01,   2.18582839e-01,   4.22713637e-01,
                         -3.54461700e-01,  -1.99822858e-01,   4.35384333e-01,
                          2.23086216e-02,  -2.90593803e-01,   8.96610171e-02,
                          1.52594641e-01,  -9.36305523e-03,   1.47254327e-02,
                         -1.21705487e-01,   2.22268514e-02,   2.48667508e-01,
                         -5.52824363e-02,  -2.04796627e-01,   1.65771052e-01,
                          2.22083420e-01,  -1.38871267e-01,  -1.30037948e-01,
                          2.17453897e-01,   1.99620396e-01,  -2.08830878e-01,
                         -8.47680867e-02,   3.34904671e-01,  -1.40349604e-02,
                         -3.02404016e-01,   1.98822275e-01,   2.18889758e-01,
                         -2.11318642e-01,  -4.57375087e-02,   1.36966228e-01,
                          1.13925431e-02,   2.03483365e-02,  -1.10512190e-01,
                         -2.76295096e-02,   3.38168949e-01,  -7.50620663e-02,
                         -3.91616702e-01,   3.38367373e-01,   2.74800152e-01,
                         -3.85233611e-01,   1.04244007e-03,   3.81855488e-01,
                         -7.87400007e-02,  -1.91907406e-01,   1.37739599e-01,
                          1.12463042e-01,  -2.59292647e-02,  -3.14609110e-02,
                         -2.56679277e-03,   6.85153231e-02,   6.99656755e-02,
                         -6.34836406e-02,  -1.09903187e-01,   1.10694081e-01,
                          1.88332170e-01,  -1.63563922e-01,  -1.71313018e-01,
                          2.65111774e-01,   1.17159754e-01,  -3.14437687e-01,
                          6.32232428e-02,   3.04637551e-01,  -1.97995752e-01,
                         -1.46566391e-01,   2.48835579e-01,   4.23504040e-02,
                         -1.42255381e-01,   3.11421789e-02,   5.93002066e-02,
                          7.50007257e-02,  -4.39907517e-03,  -1.84583023e-01,
                          8.08183178e-02,   2.48710588e-01,  -2.09428012e-01,
                         -1.93726942e-01,   3.16310257e-01,   4.72012684e-02,
                         -3.27688098e-01,   5.40890694e-02,   2.62781113e-01,
                         -1.16684102e-01,  -1.64550200e-01,   1.44856066e-01,
                          1.05397403e-01,  -1.58016682e-01,  -2.65543186e-03,
                          1.36502028e-01,  -3.61755900e-02,   1.16811343e-03,
                          5.40765785e-02,  -1.13583066e-01,   5.61381839e-02,
                          1.91390932e-01,  -2.03327775e-01,  -1.25661150e-01,
                          3.09216082e-01,  -4.14512716e-02,  -3.11814487e-01,
                          1.66945696e-01,   1.84906200e-01,  -2.40738735e-01,
                         -9.57614481e-02,   1.84926823e-01,  -3.87600511e-02,
                         -1.42747253e-01,   2.81631239e-02,   6.26467839e-02,
                         -2.29158886e-02,  -3.15214358e-02,  -3.46494801e-02,
                          4.24427316e-02,   1.02940217e-01,  -1.54010504e-01,
                         -1.17320761e-01,   2.86621362e-01,  -5.39066596e-03,
                         -3.26789320e-01,   9.72877592e-02,   2.23791555e-01,
                         -2.55590081e-01,  -1.14622571e-01,   2.34066606e-01,
                         -1.15672745e-01,  -1.70503899e-01,   1.54073864e-01,
                         -4.90608290e-02,  -1.59312278e-01,   1.13233909e-01,
                          1.43324153e-03,  -1.47404596e-01,   8.92206281e-02,
                          5.63680120e-02,  -1.73408955e-01,  -2.61239731e-03,
                          1.54528275e-01,  -6.72961622e-02,  -1.55614510e-01,
                          9.34299603e-02,   1.12247132e-01,  -2.16543302e-01,
                         -7.41542652e-02,   2.29957417e-01,  -8.42312053e-02,
                         -2.55955994e-01,   1.34699970e-01,   5.92456646e-02,
                         -2.14922979e-01,   1.62057746e-02,   2.86992937e-02,
                         -1.10150248e-01,   1.04850739e-01,  -7.22109154e-02,
                         -2.09283739e-01,   2.19694048e-01,   4.08494985e-03,
                         -2.91665107e-01,   2.11719602e-01,   1.10785685e-01,
                         -3.59508604e-01,   9.67664570e-02,   2.21645489e-01,
                         -2.79705882e-01,  -7.01728985e-02,   2.40534812e-01,
                         -1.26467779e-01,  -1.69281170e-01,   7.35056102e-02,
                          3.20487190e-03,  -8.85087401e-02,  -2.96528880e-02,
                          1.75313093e-02,  -5.77988327e-02,  -7.62603432e-02,
                          4.63128015e-02,  -4.33883779e-02,  -1.43423006e-01,
                          1.18008547e-01,   6.02258854e-02,  -2.44001374e-01,
                          6.78924620e-02,   1.88169032e-01,  -2.54206926e-01,
                         -5.86208068e-02,   2.51224071e-01,  -1.09324209e-01,
                         -1.70865014e-01,   1.30181432e-01,  -2.87335142e-02,
                         -1.05384424e-01,   6.37443811e-02,  -8.46909508e-02,
                         -4.97021079e-02,   1.14456810e-01,  -1.74353212e-01,
                         -1.03398636e-01,   2.16797933e-01,  -1.04197562e-01,
                         -2.05958679e-01,   1.65983677e-01,   5.30336685e-02,
                         -2.38635644e-01,  -7.97499716e-03,   2.27705017e-01,
                         -5.08630015e-02,  -2.56634444e-01,   7.90289193e-02,
                          2.39527389e-01,  -2.20433459e-01,  -1.84352934e-01,
                          2.45127320e-01,  -3.44674401e-02,  -1.51000708e-01,
                          9.52717811e-02,  -1.16649412e-01,  -9.39624757e-02,
                          2.05930874e-01,  -1.46421045e-01,  -2.18391627e-01,
                          2.79049337e-01,  -7.84214004e-04,  -3.43067706e-01,
                          9.76605043e-02,   2.16533512e-01,  -1.66557804e-01,
                         -1.21183574e-01,   1.28977209e-01,   3.91533747e-02,
                         -8.78905207e-02,  -5.36871590e-02,   1.47940014e-02,
                          8.26988444e-02,  -1.15647232e-02,  -1.59779802e-01,
                          5.11934236e-02,   1.43339336e-01,  -1.52698338e-01,
                         -1.64931223e-01,   2.14990363e-01,   5.30199111e-02,
                         -3.13062936e-01,  -4.11087042e-03,   3.10237199e-01,
                         -1.54483438e-01,  -3.06159765e-01,   2.36555755e-01,
                          1.90215603e-01,  -3.13091516e-01,  -6.33532777e-02,
                          2.04056859e-01,  -2.46194582e-02,  -4.76324484e-02,
                         -1.71980262e-02,  -5.70637882e-02,   1.14288189e-01,
                          6.73778951e-02,  -2.40149155e-01,  -3.71060185e-02,
                          2.81109542e-01,  -3.28864641e-02,  -3.03527862e-01,
                          6.40236512e-02,   2.62357265e-01,  -1.70862824e-01,
                         -2.37909332e-01,   2.38005489e-01,   1.19388185e-01,
                         -2.64688283e-01,  -5.53675927e-03,   1.43950373e-01,
                         -4.94934693e-02,  -1.94267463e-02,  -4.13903818e-02,
                          1.66676305e-02,   1.88130468e-01,  -1.44360378e-01,
                         -2.01411590e-01,   3.41022223e-01,   4.65026796e-02,
                         -4.09088075e-01,   1.76074848e-01,   3.38664144e-01,
                         -3.36617976e-01,  -1.90027267e-01,   3.51939142e-01,
                          1.09282741e-02,  -2.67189831e-01,   1.98605210e-02,
                          1.23418033e-01,   2.32198723e-02,  -6.97359815e-02,
                         -1.18342623e-01,   4.31389138e-02,   1.84368715e-01,
                         -3.07362527e-02,  -1.95818678e-01,   2.64363699e-02,
                          2.81592637e-01,  -6.67150542e-02,  -3.14887941e-01,
                          2.10824102e-01,   3.13693106e-01,  -3.32544625e-01,
                         -2.08937347e-01,   3.89519989e-01,   3.87429819e-02,
                         -3.11465979e-01,   7.83063546e-02,   1.30401120e-01,
                         -6.64954558e-02,  -3.16529833e-02,  -8.51485282e-02,
                          4.77425009e-02,   1.63801774e-01,  -1.97228879e-01,
                         -9.98303443e-02,   3.22403014e-01,  -7.68428892e-02,
                         -3.06425005e-01,   2.39793912e-01,   2.45497331e-01,
                         -3.06205034e-01,  -9.22002420e-02,   3.16927224e-01,
                          3.43206823e-02,  -2.82523155e-01,   2.46923063e-02,
                          2.56302208e-01,  -4.41680811e-02,  -1.63967818e-01,
                          8.50517023e-03,   5.98458797e-02,   6.73194900e-02,
                         -6.53733360e-03,  -2.35198751e-01,   8.13576430e-02,
                          3.35067570e-01,  -2.86046535e-01,  -2.96454966e-01,
                          4.01816756e-01,   1.47724614e-01,  -3.77421767e-01,
                          4.25741868e-03,   3.12254161e-01,  -4.57067154e-02,
                         -1.68741792e-01,   6.83230460e-02,   1.41621009e-01,
                          1.88619457e-02,  -1.07278764e-01,  -3.19853052e-02,
                          1.63514763e-01,   2.48337891e-02,  -2.07017183e-01,
                          5.26780076e-02,   2.24778190e-01,  -1.23222679e-01,
                         -1.90951258e-01,   1.73861176e-01,   1.39913142e-01,
                         -2.42359757e-01,  -6.88569099e-02,   3.26867580e-01,
                         -1.18119363e-02,  -3.23780388e-01,   1.53952092e-01,
                          2.49196962e-01,  -1.53828427e-01,  -8.57150927e-02,
                          1.16145678e-01,   4.84959222e-02,   9.53188837e-02,
                         -8.12656954e-02,  -2.13782653e-01,   2.50478745e-01,
                          2.46390417e-01,  -3.43311459e-01,  -1.39213160e-01,
                          3.62434387e-01,   4.46674824e-02,  -3.21211368e-01,
                          3.35047543e-02,   3.05072904e-01,  -4.24500667e-02,
                         -2.45968461e-01,   9.37877372e-02,   1.97876155e-01,
                         -6.74322769e-02,  -6.53391480e-02,   6.45211041e-02,
                          8.77042338e-02,   5.56174032e-02,  -1.11341052e-01,
                         -2.43701357e-02,   2.69869864e-01,  -7.10706115e-02,
                         -2.14274973e-01,   2.99539983e-01,   1.05471730e-01,
                         -3.80618185e-01,   1.36953041e-01,   3.28695416e-01,
                         -2.23397315e-01,  -1.50676817e-01,   2.64276356e-01,
                          2.43322942e-02,  -1.30455270e-01,   4.67937626e-02,
                         -1.35141425e-03,   9.96447057e-02,   1.23559676e-01,
                         -1.79452717e-01,  -6.47399575e-02,   2.81284422e-01,
                          8.28840733e-02,  -2.29986370e-01,  -2.51141526e-02,
                          3.06529880e-01,   8.90964791e-02,  -3.36109757e-01,
                          2.92441025e-02,   4.15700257e-01,  -1.28830433e-01,
                         -2.70834923e-01,   2.66560316e-01,   9.84006897e-02,
                         -1.68331996e-01,   7.19520152e-02,   2.13378053e-02,
                         -8.85456055e-03,   1.53713554e-01,  -1.33383647e-01,
                         -6.01594932e-02,   3.05117697e-01,  -1.09916441e-01,
                         -1.82777673e-01,   3.42739850e-01,   3.51953544e-02,
                         -2.74095535e-01,   2.20256403e-01,   1.90901071e-01,
                         -2.48481363e-01,   3.08848936e-02,   2.70893425e-01,
                         -5.75829148e-02,  -1.07886873e-01,   6.40967339e-02,
                          7.49854222e-02,   2.24080328e-02,   5.94698172e-03,
                         -4.50360291e-02,  -9.79718007e-03,   1.48474768e-01,
                          7.79657811e-02,  -2.27801472e-01,  -1.88559163e-02,
                          3.62734228e-01,  -2.87516844e-02,  -3.15720230e-01,
                          2.30783537e-01,   2.72854388e-01,  -2.26734415e-01,
                         -3.64356562e-02,   2.16601208e-01,  -1.28034484e-02,
                         -1.97377857e-02,   6.13581687e-02,  -4.05230187e-02,
                          6.13727979e-02,   8.54103863e-02,  -8.95552263e-02,
                          3.06747463e-02,   1.04883701e-01,  -8.76923725e-02,
                          2.10182238e-02,   1.17588826e-01,  -8.27125162e-02,
                         -6.58925250e-02,   1.94498152e-01,   5.36399446e-02,
                         -1.99365839e-01,   4.54105139e-02,   2.63185918e-01,
                         -7.56416842e-02,  -1.71149209e-01,   2.18422651e-01,
                          1.29758984e-01,  -1.79368570e-01,   4.61963974e-02,
                          1.25126645e-01,  -7.48357400e-02,   9.96037647e-02,
                          8.31772834e-02,  -2.07288831e-01,   8.30560997e-02,
                          2.52175599e-01,  -2.04679430e-01,  -1.32550344e-01,
                          2.72299737e-01,   4.35677543e-02,  -2.01290965e-01,
                          4.62941751e-02,   1.02830932e-01,  -6.29063547e-02,
                         -1.02672388e-03,   6.59614280e-02,  -1.48209208e-03,
                         -1.25456089e-02,   6.89614490e-02,   3.88898002e-03,
                         -4.22459841e-02,   7.44717792e-02,   1.77447349e-02,
                         -1.98969468e-02,   8.71816948e-02,  -7.85778165e-02,
                         -8.22149664e-02,   2.42031217e-01,  -2.07749363e-02,
                         -3.11972648e-01,   2.02091441e-01,   2.66416371e-01,
                         -3.71216416e-01,  -9.33277979e-02,   3.65654349e-01,
                         -3.04099564e-02,  -2.41756260e-01,   9.10619423e-02,
                          1.01227686e-01,  -2.72629112e-02,   2.30327621e-02,
                         -3.62174213e-02,  -2.21272781e-02,   1.41368419e-01,
                          3.52988131e-02,  -1.31302118e-01,  -4.30150628e-02,
                          1.59567609e-01,   3.33858468e-02,  -1.81855142e-01,
                          6.20296076e-02,   1.64060593e-01,  -1.96044281e-01,
                         -1.06031813e-01,   2.24452153e-01,  -9.80677381e-02,
                         -1.79582641e-01,   2.08929226e-01,  -2.67864875e-02,
                         -2.00109795e-01,   1.32127807e-01,   1.77755021e-02,
                         -8.21736678e-02,   1.14749715e-01,  -1.13046229e-01,
                         -5.88307008e-02,   3.14185023e-01,  -2.13352829e-01,
                         -3.23184937e-01,   4.41019922e-01,   1.30252153e-01,
                         -5.15123904e-01,   5.12173623e-02,   3.52900118e-01,
                         -1.84699729e-01,  -2.40389436e-01,   1.17943473e-01,
                          1.05813079e-01,  -9.14117247e-02,  -1.12282701e-01,
                         -1.79657545e-02,   4.53593321e-02,   1.69598963e-02,
                         -1.96081717e-02,  -1.08674325e-01,  -3.18365060e-02,
                          1.77676171e-01,  -7.92809948e-02,  -2.16086954e-01,
                          1.77499712e-01,   1.22700147e-01,  -2.84287274e-01,
                          3.65000702e-02,   2.24927187e-01,  -2.51051605e-01,
                         -1.23980515e-01,   2.54155427e-01,  -6.63978383e-02,
                         -2.11144477e-01,   3.83255444e-02,   3.87687534e-02,
                         -2.83913165e-02,  -6.94550052e-02,  -1.45663276e-01,
                          1.08408973e-01,   1.56290680e-01,  -3.00060362e-01,
                         -1.48308247e-01,   3.44244242e-01,  -2.94606714e-03,
                         -3.84283483e-01,   8.10509026e-02,   3.24305892e-01,
                         -1.88405678e-01,  -3.29445541e-01,   2.44016171e-01,
                          1.84446350e-01,  -2.79575735e-01,  -9.50465500e-02,
                          1.36005998e-01,  -4.32217233e-02,  -3.72449420e-02,
                         -4.09775600e-02,  -1.70819506e-01,   1.03958361e-01,
                          1.46729574e-01,  -3.14647913e-01,  -1.20904371e-01,
                          3.02423477e-01,  -1.00268528e-01,  -2.84466118e-01,
                          1.94154948e-01,   1.18904687e-01,  -2.58928239e-01,
                         -3.63640562e-02,   1.87478155e-01,  -3.55100855e-02,
                         -1.77585229e-01,   3.44968550e-02,   1.29422441e-01,
                         -6.88001439e-02,  -1.69127643e-01,  -8.42007808e-03,
                          1.43013313e-01,   1.07685532e-02,  -2.75651008e-01,
                         -5.77897057e-02,   3.11721474e-01,  -9.20572281e-02,
                         -4.35339987e-01,   1.56997770e-01,   3.49464625e-01,
                         -3.10083538e-01,  -2.85586476e-01,   3.13234180e-01,
                          8.89534950e-02,  -2.82453418e-01,  -1.95919108e-02,
                          1.16094701e-01,   8.60517845e-03,  -3.61011140e-02,
                         -1.16591960e-01,  -4.53316271e-02,   1.63750365e-01,
                         -2.68265256e-03,  -2.64636874e-01,   2.17781030e-02,
                          2.32823834e-01,  -1.56546891e-01,  -2.72559404e-01,
                          1.78230673e-01,   1.64677277e-01,  -3.10462832e-01,
                         -1.13806583e-01,   3.13737541e-01,  -9.17385221e-02,
                         -3.10728788e-01,   1.63925588e-01,   1.40870228e-01,
                         -1.67599633e-01,  -5.20050675e-02,   2.51445174e-03,
                          6.99290559e-02,   9.88169387e-02,  -2.96574801e-01,
                         -5.22638634e-02,   4.60434705e-01,  -1.84033081e-01,
                         -4.74676222e-01,   3.69523078e-01,   2.16696233e-01,
                         -4.45629656e-01,  -6.44379333e-02,   2.98395067e-01,
                         -4.80682477e-02,  -1.90646693e-01,  -8.30877051e-02,
                          9.74523425e-02,   9.78563428e-02,  -1.37539849e-01,
                         -1.40591115e-01,   9.81118605e-02,   1.18532501e-01,
                         -7.51141831e-02,  -1.72014073e-01,   4.76674959e-02,
                          2.33072922e-01,  -1.25869274e-01,  -2.66028136e-01,
                          2.52838671e-01,   1.69903129e-01,  -3.93089682e-01,
                         -1.81347877e-02,   3.74775589e-01,  -1.73863202e-01,
                         -2.59786606e-01,   1.92185476e-01,   6.31464124e-02,
                         -1.37537390e-01,  -3.86253893e-02,  -3.28004770e-02,
                          1.23561919e-01,   4.07515019e-02,  -3.27551752e-01,
                          8.07272047e-02,   3.68862152e-01,  -2.67944008e-01,
                         -2.52078772e-01,   3.66264611e-01,   7.42211938e-02,
                         -3.27432334e-01,   3.95752210e-03,   2.57659882e-01,
                         -1.76354647e-02,  -2.13438272e-01,   4.48200814e-02,
                          1.32269412e-01,  -8.01372528e-02,  -7.68466890e-02,
                         -8.42362083e-03,  -1.83747690e-02,   1.15903571e-01,
                         -1.79502964e-02,  -2.77172565e-01,   1.32473618e-01,
                          2.72336453e-01,  -2.88149774e-01,  -1.56929031e-01,
                          3.68084162e-01,  -2.08002627e-02,  -3.09503883e-01,
                          1.53491080e-01,   1.74696326e-01,  -1.67640716e-01,
                         -5.53724170e-02,   1.29318476e-01,   3.79290842e-02,
                         -1.04113951e-01,  -7.29256496e-02,   9.42325071e-02,
                          9.70563963e-02,  -1.09690122e-01,  -1.54684708e-01,
                          1.17390037e-01,   1.48406014e-01,  -2.17312828e-01,
                         -1.31766826e-01,   2.45555177e-01,   7.29575157e-02,
                         -2.62512743e-01,  -2.88996939e-02,   2.79262930e-01,
                         -1.20471120e-01,  -1.76091552e-01,   2.13260099e-01,
                          5.23994416e-02,  -1.68840170e-01,   7.14123994e-02,
                          3.78554538e-02,  -8.77826586e-02,   1.46317914e-01,
                         -3.02348845e-02,  -2.06502065e-01,   1.94444984e-01,
                          1.23481967e-01,  -2.95753896e-01,  -3.48523706e-02,
                          2.69602507e-01,  -9.88079235e-02,  -2.12897852e-01,
                          1.53157368e-01,   9.74549502e-02,  -1.89544797e-01,
                         -4.93453182e-02,   1.99894711e-01,   2.89229467e-03,
                         -1.47390127e-01,   7.81991035e-02,   8.40576962e-02,
                         -4.29426581e-02,   1.32651404e-02,  -4.40651104e-02,
                          5.42391315e-02,   1.40875235e-01,  -1.80592641e-01,
                         -9.57108140e-02,   2.91764587e-01,  -4.47952338e-02,
                         -2.84859478e-01,   1.94542840e-01,   1.44349769e-01,
                         -2.69075841e-01,   7.78784882e-03,   1.82187721e-01,
                         -1.03736058e-01,  -5.18774800e-02,   1.11431465e-01,
                         -4.58208770e-02,  -2.17323638e-02,   7.17845485e-02,
                         -3.28835361e-02,  -1.06776301e-02,   9.60734263e-02,
                          1.81111824e-02,  -9.06069353e-02,   1.45104667e-02,
                          1.37038976e-01,  -4.92923819e-02,  -1.41297162e-01,
                          1.47513345e-01,   1.19725130e-01,  -2.35864580e-01,
                          1.26812244e-02,   2.43485764e-01,  -1.55494973e-01,
                         -1.10255353e-01,   2.04647720e-01,  -3.59029770e-02,
                         -8.43855366e-02,   9.73740667e-02,  -7.22223297e-02,
                          4.64034304e-02,   1.60211116e-01,  -1.94421053e-01,
                         -5.40428562e-03,   3.01433593e-01,  -1.69105500e-01,
                         -1.49489984e-01,   3.08867484e-01,  -1.22854742e-03,
                         -2.52429098e-01,   1.97976589e-01,   1.36653408e-01,
                         -1.93638772e-01,  -1.94600411e-02,   1.83739975e-01,
                         -2.00045109e-02,  -1.27445608e-01,   8.61615762e-02,
                          6.87858313e-02,  -9.79051068e-02,   4.97727059e-02,
                          7.53736347e-02,  -1.03204176e-01,   5.31668961e-02,
                          1.48558915e-01,  -1.37464643e-01,  -3.47086973e-02,
                          2.34649166e-01,  -6.50191456e-02,  -1.35248482e-01,
                          2.20246643e-01,   7.80422091e-02,  -1.91203445e-01,
                          3.34503390e-02,   1.82548344e-01,  -4.92279530e-02,
                         -6.05486110e-02,   6.76767454e-02,   1.62181128e-02,
                          1.01012327e-02,  -1.23414937e-02,  -5.24139293e-02,
                          7.87899941e-02,   9.82349217e-02,  -1.15386739e-01,
                         -3.28162126e-02,   1.99514464e-01,  -1.41482726e-02,
                         -1.87970370e-01,   1.79670081e-01,   2.10101038e-01,
                         -2.48784497e-01,  -4.56984602e-02,   3.76842916e-01,
                         -9.95874256e-02,  -2.73834169e-01,   3.01124215e-01,
                          1.39371440e-01,  -2.49499634e-01,   7.42084607e-02,
                          9.72419605e-02,  -1.07732445e-01,   1.05264455e-01,
                          5.20935319e-02,  -1.75668418e-01,   1.29043758e-01,
                          1.51887670e-01,  -2.06968948e-01,  -2.42786948e-02,
                          2.57767498e-01,   1.83241572e-02,  -1.85624093e-01,
                          7.31128603e-02,   2.22909674e-01,  -9.00591388e-02,
                         -1.33845046e-01,   1.75435215e-01,   1.23008668e-01,
                         -1.12942904e-01,  -4.32917709e-03,   7.23872110e-02,
                          2.36804672e-02,   4.55286056e-02,  -8.34736452e-02,
                          1.48986084e-02,   2.02027172e-01,  -1.24971457e-01,
                         -2.05287397e-01,   3.19090873e-01,   7.71849006e-02,
                         -3.81851315e-01,   1.58455700e-01,   3.72713953e-01,
                         -2.67843753e-01,  -1.89130440e-01,   3.15112591e-01,
                          9.12206322e-02,  -1.44137293e-01,   5.10668429e-03,
                          7.16539174e-02,   9.57844406e-02,   4.48101154e-03,
                         -9.73214507e-02,   4.74876352e-02,   1.51648179e-01,
                          1.45041961e-02,  -1.50773063e-01,  -2.25308724e-02,
                          2.42029846e-01,   1.40038664e-02,  -3.33846688e-01,
                          1.50144488e-01,   3.35119665e-01,  -3.32375228e-01,
                         -1.73001334e-01,   3.70986432e-01,  -1.19742611e-02,
                         -2.00849026e-01,   1.22134902e-01,   3.99555862e-02,
                          2.87098791e-02,   5.44001982e-02,  -1.82839498e-01,
                          1.11748718e-01,   2.89240509e-01,  -3.00007463e-01,
                         -1.23349026e-01,   4.61262375e-01,  -1.13426700e-01,
                         -3.88480395e-01,   2.90835351e-01,   2.42638037e-01,
                         -3.29232454e-01,  -7.97936693e-02,   2.51382709e-01,
                          2.96568517e-02,  -1.79631233e-01,  -7.13731423e-02,
                          1.80747718e-01,   1.18163519e-01,  -1.72345117e-01,
                         -7.90435225e-02,   1.07367478e-01,   1.36821628e-01,
                          1.13913827e-02,  -2.09372208e-01,   2.86466610e-02,
                          3.37917387e-01,  -1.40576392e-01,  -3.37790132e-01,
                          3.14933449e-01,   2.35139057e-01,  -3.84870410e-01,
                         -7.41844177e-02,   2.99869627e-01,  -7.07992390e-02,
                         -1.89850897e-01,   3.72456014e-02,   6.65594488e-02,
                          3.90409380e-02,  -7.00332895e-02,  -1.50315851e-01,
                          1.43451065e-01,   1.39705718e-01,  -2.72591025e-01,
                         -2.11070776e-02,   3.39855671e-01,  -1.22097015e-01,
                         -2.94705659e-01,   2.18821302e-01,   2.27397680e-01,
                         -3.32652807e-01,  -1.06182046e-01,   3.56970757e-01,
                         -2.74508856e-02,  -3.27454686e-01,   6.41771853e-02,
                          1.79429904e-01,  -8.84649307e-02,  -7.15945587e-02,
                         -6.33738339e-02,  -2.95490753e-02,   1.88710466e-01,
                         -6.20110855e-02,  -3.29088479e-01,   1.70052543e-01,
                          2.98234701e-01,  -3.09889793e-01,  -2.19950676e-01,
                          3.30727547e-01,   1.05471008e-01,  -3.24949056e-01,
                         -3.63041013e-02,   2.70293593e-01,  -8.58733244e-03,
                         -2.39937112e-01,   8.94943625e-03,   1.57135382e-01,
                         -5.90884537e-02,  -1.26696780e-01,  -1.33963209e-02,
                          8.14122111e-02,   9.95758455e-03,  -2.06815079e-01,
                         -3.34969088e-02,   2.48104692e-01,  -1.35009587e-01,
                         -2.93201715e-01,   2.68308967e-01,   1.37829900e-01,
                         -3.98218721e-01,  -5.01581351e-04,   3.31803530e-01,
                         -1.29130498e-01,  -2.41268083e-01,   1.70130879e-01,
                          8.00618231e-02,  -1.16291203e-01,  -4.57775258e-02,
                         -2.94296984e-02,   4.38306034e-02,   1.11335419e-01,
                         -1.51103899e-01,  -2.02482790e-01,   1.76628411e-01,
                          1.37762725e-01,  -2.86289185e-01,  -1.89279541e-01,
                          3.07789743e-01,   1.00801170e-01,  -4.34748709e-01,
                         -2.20748386e-03,   3.53462696e-01,  -1.57506630e-01,
                         -2.34187961e-01,   1.62472203e-01,   6.82664663e-02,
                         -9.09855217e-02,  -1.16478354e-02,  -7.93570876e-02,
                          8.35506916e-02,   1.15661308e-01,  -2.57085323e-01,
                          6.03227643e-04,   2.69701272e-01,  -2.65960425e-01,
                         -1.48550332e-01,   3.34079772e-01,  -1.12836733e-01,
                         -3.13664794e-01,   1.95803300e-01,   1.11533523e-01,
                         -2.44392917e-01,  -5.47021553e-02,   1.14220694e-01,
                          4.02444080e-02,  -7.41051510e-02,  -1.28933012e-01,
                          1.70357432e-02,   1.16856046e-01,   4.95635625e-03,
                         -1.26086742e-01,  -7.91120231e-02,   1.39538631e-01,
                          1.38996467e-01,  -2.75445402e-01,  -1.73930243e-01,
                          4.00721908e-01,  -9.25798959e-04,  -4.38244492e-01,
                          1.55983791e-01,   2.52902091e-01,  -2.84293413e-01,
                         -1.17253073e-01,   1.82093009e-01,  -4.53052782e-02,
                         -5.20956963e-02,  -3.02753388e-03,  -1.13679811e-01,
                          9.16110426e-02,   5.95382378e-02,  -2.16621891e-01,
                          8.92425627e-02,   1.80479571e-01,  -2.33394846e-01,
                         -3.93185169e-02,   2.48177394e-01,  -1.04173772e-01,
                         -1.87879339e-01,   2.02967122e-01,   6.09949455e-02,
                         -2.27458477e-01,  -3.02632544e-02,   1.98584244e-01,
                         -4.05897722e-02,  -1.80229291e-01,   4.53281105e-02,
                          6.13157414e-02,  -7.19339848e-02,   4.88995994e-03,
                         -6.48654029e-02,  -9.64892805e-02,   2.07038850e-01,
                          7.08155036e-02,  -3.41934770e-01,   3.99979353e-02,
                          3.36688131e-01,  -1.69793740e-01,  -2.19291791e-01,
                          2.17243224e-01,   1.07636102e-01,  -1.45165503e-01,
                         -5.36278263e-02,   6.85125366e-02,   4.35003713e-02,
                         -3.19221430e-02,  -3.05531733e-02,   4.12314897e-03,
                          7.33038411e-03,   3.54601107e-05,  -7.03163967e-02,
                         -6.67807693e-03,   8.13797638e-02,  -7.05869794e-02,
                         -5.58026396e-02,   1.19149923e-01,  -5.38272262e-02,
                         -1.46873802e-01,   2.02546895e-01,   6.80134073e-02,
                         -2.72719234e-01,   9.34081972e-02,   2.63947517e-01,
                         -2.04732001e-01,  -1.41297728e-01,   2.57553905e-01,
                         -7.66708609e-03,  -1.47006050e-01,   1.15665935e-01,
                         -6.18157350e-02,  -9.66334343e-02,   1.97665274e-01,
                         -3.88565175e-02,  -2.34679505e-01,   1.50994897e-01,
                          1.78066984e-01,  -2.00020730e-01,  -1.13387451e-01,
                          1.87343433e-01,   6.35458529e-02,  -1.47668049e-01,
                         -6.43368438e-03,   1.32261544e-01,  -5.13300188e-02,
                         -4.43197563e-02,   1.08153731e-01,  -6.09207712e-02,
                         -1.94729660e-02,   1.64021209e-01,  -8.48417431e-02,
                         -9.70562994e-02,   1.34280458e-01,  -4.15259711e-02,
                         -2.84380596e-02,   1.28178641e-01,  -1.94954321e-01,
                         -3.59173082e-02,   3.21718305e-01,  -1.96603715e-01,
                         -2.55300134e-01,   3.10005933e-01,   1.28210664e-01,
                         -3.34745556e-01,   1.62581597e-02,   2.49021232e-01,
                         -5.63042462e-02,  -1.30231947e-01,   6.10344149e-02,
                          1.00476809e-01,  -6.74145250e-03,  -2.34122053e-02,
                          4.13626153e-03,  -3.03398035e-02,   6.24134578e-02,
                          1.13124229e-01,  -1.28542036e-01,  -1.05070226e-01,
                          2.20213652e-01,  -3.06108557e-02,  -2.52595484e-01,
                          1.85263142e-01,   1.18869171e-01,  -2.75058270e-01,
                          8.62150341e-02,   1.99758232e-01,  -2.34842479e-01,
                         -9.55280662e-03,   2.33845204e-01,  -1.07881889e-01,
                         -4.68390621e-02,   1.14573509e-01,  -7.35596344e-02,
                          9.43405777e-02,   6.07193895e-02,  -2.33420581e-01,
                          1.81408346e-01,   2.47138530e-01,  -3.24161828e-01,
                         -1.04779452e-01,   3.68939936e-01,  -5.14719402e-03,
                         -3.38005990e-01,   5.30260615e-02,   3.03653359e-01,
                         -7.28878379e-02,  -2.78058410e-01,   1.00882463e-01,
                          1.86998710e-01,  -8.30628425e-02,  -6.70601800e-02,
                          2.93952227e-02,   3.44728027e-03,   9.97948423e-02,
                          2.07593441e-02,  -1.76422521e-01,   1.08922631e-01,
                          2.18399078e-01,  -1.91913888e-01,  -9.02876109e-02,
                          2.50924885e-01,  -3.05034909e-02,  -1.78656444e-01,
                          1.62697971e-01,   1.20369717e-01,  -1.77942336e-01,
                         -4.21649776e-02,   1.47212103e-01,   1.14587857e-03,
                         -9.70273390e-02,   1.38365822e-02,   8.52893740e-02,
                          3.13351490e-02,  -8.41099992e-02,  -9.41053182e-02,
                          1.55748293e-01,   1.72747567e-01,  -2.32776031e-01,
                         -9.23275277e-02,   3.61280113e-01,   4.73074727e-02,
                         -4.18568522e-01,   1.39649361e-01,   4.35589373e-01,
                         -2.35377625e-01,  -2.56080508e-01,   3.14539731e-01,
                          7.12736398e-02,  -1.86760753e-01,   4.37862687e-02,
                         -2.37872428e-03,   2.51960922e-02,   1.59236223e-01,
                         -1.71203390e-01,  -1.60853386e-01,   2.90165424e-01,
                          6.58325031e-02,  -2.66530663e-01,   6.52955547e-02,
                          2.23107412e-01,  -8.74905661e-02,  -1.40195683e-01,
                          1.62680224e-01,   1.32474676e-01,  -1.39931217e-01,
                         -3.94932851e-02,   2.13066265e-01,  -6.64298469e-03,
                         -1.72644272e-01,   1.01387382e-01,   1.25003636e-01,
                         -4.19341885e-02,  -5.66907562e-02,  -7.63270184e-02,
                          1.38722926e-01,   1.44807756e-01,  -2.94778258e-01,
                         -5.65499254e-02,   4.51203316e-01,  -8.96687657e-02,
                         -4.54981506e-01,   2.86908269e-01,   3.47314388e-01,
                         -3.39647949e-01,  -1.06745347e-01,   3.24290156e-01,
                          4.50378060e-02,  -1.53417215e-01,  -3.67994653e-03,
                          7.64515176e-02,   8.11011568e-02,   3.25264782e-02,
                         -1.11550406e-01,  -2.67818980e-02,   1.77366629e-01,
                          3.12015358e-02,  -2.27118328e-01,   3.06161270e-02,
                          2.87499160e-01,  -1.30953148e-01,  -2.58877337e-01,
                          2.77150661e-01,   1.74158275e-01,  -3.37236404e-01,
                          3.09534092e-02,   3.31076950e-01,  -1.55069485e-01,
                         -1.38077110e-01,   1.85946360e-01,   3.17591764e-02,
                         -1.23789150e-03,  -5.07437671e-03,  -9.49174613e-02,
                          2.30422467e-01,   9.64879319e-02,  -3.93577516e-01,
                          1.25442550e-01,   4.23246324e-01,  -2.80915618e-01,
                         -2.94311017e-01,   3.71803701e-01,   1.24854065e-01,
                         -3.15445811e-01,  -3.70573476e-02,   2.46674255e-01,
                          4.44707870e-02,  -1.83583766e-01,  -2.22891103e-02,
                          1.64327979e-01,   3.77617814e-02,  -7.54396990e-02,
                         -3.83915938e-02,   4.10583019e-02,   1.87752724e-01,
                          1.75379924e-02,  -2.56959647e-01,   1.00709304e-01,
                          3.21283042e-01,  -2.07422733e-01,  -2.10228071e-01,
                          3.39038461e-01,   6.33687153e-02,  -3.38670284e-01,
                          8.05421248e-02,   2.23154470e-01,  -1.65485874e-01,
                         -1.22617014e-01,   1.32632762e-01,   7.15043545e-02,
                         -6.10662512e-02,  -1.01229414e-01,   1.09444410e-02,
                          2.10260615e-01,  -2.58730017e-02,  -2.58561045e-01,
                          1.47662431e-01,   2.85244465e-01,  -2.22786412e-01,
                         -2.15069219e-01,   3.33973944e-01,   1.56931788e-01,
                         -3.61376971e-01,  -2.08772738e-02,   3.27821225e-01,
                         -1.14775881e-01,  -1.96458042e-01,   1.28180191e-01,
                          3.46710011e-02,  -2.87476368e-02,   4.17227298e-02,
                         -1.84251696e-01,   1.06248837e-02,   2.85928637e-01,
                         -1.53805897e-01,  -2.46614099e-01,   2.60970026e-01,
                          1.49350747e-01,  -2.81827629e-01,  -3.58826555e-02,
                          2.52976954e-01,  -1.46875009e-02,  -1.94811672e-01,
                          6.68058395e-02,   1.87200770e-01,  -1.13834724e-01,
                         -1.81182399e-01,   1.43903732e-01,   9.36026126e-02,
                         -1.60295844e-01,  -5.16033880e-02,   5.51853701e-02,
                          3.05183623e-02,  -3.08911633e-02,  -1.58648357e-01,
                          3.80156524e-02,   2.44272575e-01,  -2.02664301e-01,
                         -2.58370191e-01,   3.57425302e-01,   5.38822301e-02,
                         -3.76100779e-01,   1.28890455e-01,   2.45609835e-01,
                         -2.50507474e-01,  -4.30807956e-02,   1.53181851e-01,
                         -1.13097936e-01,   2.56103836e-02,   6.06112145e-02,
                         -1.58388734e-01,   3.32464725e-02,   1.29866898e-01,
                         -1.72588959e-01,  -1.37715906e-01,   1.72178626e-01,
                          8.22932348e-02,  -2.41630360e-01,  -1.05934121e-01,
                          2.33759701e-01,  -3.40583585e-02,  -2.62891978e-01,
                          1.29921243e-01,   1.74889028e-01,  -2.49083862e-01,
                         -4.59517129e-02,   2.10167781e-01,  -1.17543668e-01,
                         -9.01425332e-02,   1.08825348e-01,  -6.68409020e-02,
                          1.81117766e-02,   2.43728645e-02,  -2.11417645e-01,
                          9.84169990e-02,   1.71736285e-01,  -3.05372387e-01,
                         -4.88800630e-02,   2.81902581e-01,  -2.01809019e-01,
                         -2.18843818e-01,   2.41360888e-01,  -1.44678233e-02,
                         -2.08715528e-01,   7.10316375e-02,   3.50955650e-02,
                         -9.04404894e-02,  -2.75761504e-02,   4.38495465e-02,
                         -4.71992930e-03,  -4.12657298e-02,   1.02372300e-02,
                          1.22792860e-02,  -1.29541546e-01,   2.80640814e-02,
                          1.59316316e-01,  -1.95070550e-01,  -9.50478762e-02,
                          2.26941988e-01,  -1.45075470e-01,  -2.32526019e-01,
                          2.16893837e-01,   1.44565143e-02,  -2.84388870e-01,
                          1.28429800e-01,   1.19697511e-01,  -2.54613221e-01,
                         -5.71981585e-03,   1.14053234e-01,  -9.25531983e-02,
                          7.87998922e-03,  -9.39210132e-03,  -1.03144176e-01,
                          1.09282881e-01,   1.81898493e-02,  -2.21160010e-01,
                          8.95391777e-02,   1.80078089e-01,  -2.40007132e-01,
                         -6.28756732e-02,   1.87319905e-01,  -1.17715053e-01,
                         -1.47146136e-01,   1.18683696e-01,   4.16403376e-02,
                         -2.05441535e-01,  -3.78386527e-02,   1.55273750e-01,
                         -9.02719796e-02,  -1.57059565e-01,   9.61619169e-02,
                          1.53935766e-02,  -1.25134647e-01,   6.91262707e-02,
                         -1.34483883e-02,  -1.54319286e-01,   1.24885164e-01,
                          7.56579787e-02,  -2.01288000e-01,  -4.12179669e-03,
                          1.71506584e-01,  -1.22910291e-01,  -1.43607780e-01,
                          1.55878052e-01,   4.45673764e-02,  -2.02651396e-01,
                         -2.58596186e-02,   1.42339706e-01,  -7.09042624e-02,
                         -1.46928728e-01,   5.70263229e-02,   3.06277070e-02,
                         -5.42088449e-02,  -2.06132401e-02,  -7.91426674e-02,
                          3.60393040e-02,   1.04689412e-01,  -1.78494990e-01,
                         -4.31537554e-02,   2.65332222e-01,  -1.00210443e-01,
                         -2.72272557e-01,   2.69673318e-01,   1.04660772e-01,
                         -3.32087547e-01,   6.75504208e-02,   2.63769805e-01,
                         -2.12474734e-01,  -1.30053401e-01,   1.73164800e-01,
                         -3.71925123e-02,  -9.60792825e-02,   5.27326241e-02,
                         -6.10851943e-02,  -3.53929028e-02,   9.46257338e-02,
                         -6.04529120e-02,  -1.20485567e-01,   1.26808092e-01,
                          9.29927230e-02,  -1.91999927e-01,  -7.51902759e-02,
                          2.40453482e-01,   2.45555900e-02,  -2.70588905e-01,
                          8.76003057e-02,   2.40469009e-01,  -1.66349307e-01,
                         -9.99073312e-02,   1.64239511e-01,  -1.68296918e-02,
                         -5.74486218e-02,   4.26514782e-02,  -7.97704458e-02,
                          7.40002990e-02,   7.25082755e-02,  -2.65335262e-01,
                          8.16009343e-02,   2.61479974e-01,  -2.61428088e-01,
                         -1.23813748e-01,   3.31762105e-01,  -6.31893054e-02,
                         -2.93501377e-01,   1.85876086e-01,   2.19266728e-01,
                         -1.78488150e-01,  -1.20541915e-01,   1.65222898e-01,
                          1.12348832e-01,  -1.37661323e-01,  -7.59894922e-02,
                          1.31711617e-01,   4.15778756e-02,  -2.78231762e-02,
                         -2.62482818e-02,  -8.19356740e-02,   1.12218186e-01,
                          1.42146915e-01,  -2.55443275e-01,  -6.05143085e-02,
                          3.82912576e-01,  -1.46664768e-01,  -3.42836738e-01,
                          3.14501762e-01,   1.73712298e-01,  -3.08945924e-01,
                          8.32179841e-03,   2.13445798e-01,  -3.91511470e-02,
                         -2.88516469e-02,  -1.39509877e-02,  -1.14571927e-02,
                          2.11593941e-01,  -4.49399166e-02,  -2.46965736e-01,
                          2.29727641e-01,   1.55094132e-01,  -3.32899690e-01,
                          3.96732725e-02,   3.46218884e-01,  -1.74039453e-01,
                         -2.52029181e-01,   2.08842590e-01,   2.05819532e-01,
                         -2.46107087e-01,  -1.40784562e-01,   2.84203053e-01,
                          1.03398122e-01,  -2.62260646e-01,   6.10020594e-04,
                          1.85475424e-01,   1.08068809e-03,   1.15036955e-02,
                         -5.22299930e-02,  -4.91276272e-02,   2.49764785e-01,
                          2.14527659e-02,  -3.35710645e-01,   1.56529307e-01,
                          3.53972316e-01,  -2.72858202e-01,  -2.30979323e-01,
                          3.20711851e-01,   1.01743393e-01,  -2.83149779e-01,
                         -3.63267101e-02,   2.39794984e-01,   2.91391425e-02,
                         -1.80288240e-01,  -7.40377652e-03,   1.45188555e-01,
                          5.77243716e-02,  -9.64331403e-02,  -8.07558894e-02,
                          1.96058303e-01,   1.24951892e-01,  -2.74836302e-01,
                         -3.78674013e-03,   3.89479399e-01,  -9.88192409e-02,
                         -3.34624678e-01,   3.00348163e-01,   2.37703457e-01,
                         -3.99804503e-01,  -4.10702191e-02,   3.90127271e-01,
                         -8.05627555e-02,  -2.35119909e-01,   1.12437934e-01,
                          6.50961325e-02,   2.47576125e-02,   1.14704296e-02,
                         -2.15930045e-01,   1.04950808e-01,   3.36282283e-01,
                         -2.14025199e-01,  -2.71738350e-01,   3.08361918e-01,
                          2.19806343e-01,  -2.63037473e-01,  -1.33984119e-01,
                          3.05948228e-01,   1.56794906e-01,  -3.06657851e-01,
                         -6.45230636e-02,   3.67352337e-01,  -1.75441131e-02,
                         -2.48746514e-01,   1.06658787e-01,   1.19850740e-01,
                         -3.18258442e-02,  -4.86200601e-02,  -8.35384801e-02,
                          1.60242110e-01,   1.23774588e-01,  -2.91848868e-01,
                          1.35220438e-02,   3.68168414e-01,  -2.14276880e-01,
                         -2.21049398e-01,   3.77525896e-01,   7.82329142e-02,
                         -3.37393075e-01,   1.26413897e-01,   2.56448328e-01,
                         -1.09570287e-01,  -1.17180541e-01,   1.20788231e-01,
                          7.64079839e-02,   1.50247812e-02,  -5.44407852e-02,
                         -9.30380896e-02,   1.15051717e-01,   1.55207291e-01,
                         -1.46264493e-01,  -1.90511748e-01,   2.19056115e-01,
                          2.19400898e-01,  -3.33941281e-01,  -1.56217113e-01,
                          4.31917101e-01,   4.60138395e-02,  -3.85307491e-01,
                          1.27987087e-01,   2.81807810e-01,  -1.44195259e-01,
                         -7.69929290e-02,   9.76980552e-02,   3.20950411e-02,
                          1.10927500e-01,  -6.41455874e-02,  -1.42583176e-01,
                          2.34899417e-01,   5.84457703e-02,  -2.87874043e-01,
                          1.49486706e-01,   2.24381268e-01,  -2.73058832e-01,
                         -3.67739834e-02,   2.71119446e-01,  -8.27884302e-02,
                         -2.01485157e-01,   1.37516364e-01,   1.81779429e-01,
                         -1.62296027e-01,  -1.27074152e-01,   1.90611616e-01,
                          1.04019001e-01,  -1.09335937e-01,  -5.15251420e-03,
                          5.38578145e-02,   3.14340033e-02,   1.16777211e-01,
                         -7.95644373e-02,  -1.97654366e-01,   2.50358105e-01,
                          2.31558025e-01,  -3.76738906e-01,  -7.17499107e-02,
                          4.05438781e-01,  -1.15261748e-01,  -2.83926517e-01,
                          2.17676952e-01,   1.61179975e-01,  -1.80491060e-01,
                         -4.94936854e-02,   9.83415693e-02,   2.64794044e-02,
                          1.12193497e-02,  -3.80702913e-02,  -1.55454641e-02,
                          1.32788807e-01,   1.65397599e-02,  -1.60547987e-01,
                          9.52533558e-02,   1.74259767e-01,  -1.71193212e-01,
                         -1.15724215e-02,   2.37681985e-01,  -1.04029879e-01,
                         -2.24562973e-01,   2.55847961e-01,   1.15493096e-01,
                         -2.98766196e-01,   3.33754532e-02,   2.50240445e-01,
                         -1.40135169e-01,  -1.11997694e-01,   1.27111465e-01,
                         -3.23756039e-02,   3.32168862e-02,   1.00059420e-01,
                         -1.73926979e-01,  -4.30886000e-02,   2.83184350e-01,
                         -9.46315657e-03,  -2.55778015e-01,   1.33477762e-01,
                          2.46266469e-01,  -1.22236341e-01,  -1.98673785e-01,
                          1.38370156e-01,   2.22598359e-01,  -1.64885625e-01,
                         -1.31521299e-01,   1.66591585e-01,  -1.90084036e-02,
                         -1.09596193e-01,   6.46780729e-02,  -2.78114583e-02,
                         -2.08079237e-02,   9.07253474e-02,  -1.02098219e-01,
                         -2.09113881e-02,   1.32360697e-01,  -1.45828992e-01,
                          2.79271486e-03,   2.38776222e-01,  -1.84364974e-01,
                         -1.28415465e-01,   3.40093553e-01,  -5.07555604e-02,
                         -3.15704048e-01,   2.34215781e-01,   2.02571660e-01,
                         -2.64156610e-01,  -2.40013096e-02,   1.40522331e-01,
                         -5.44942245e-02,   3.36187251e-04,   9.82983410e-03,
                         -1.17220797e-01,   3.72906141e-02,   1.36493161e-01,
                         -1.15194388e-01,  -1.72876477e-01,   1.21870652e-01,
                          1.84008569e-01,  -1.49549380e-01,  -1.72900409e-01,
                          1.99361145e-01,   6.32160529e-02,  -2.01956481e-01,
                          9.87096950e-02,   1.15618415e-01,  -1.52666718e-01,
                          3.06614991e-02,   8.19475725e-02,  -1.45684391e-01,
                          4.49643731e-02,   9.27124470e-02,  -1.43837869e-01,
                          4.04925905e-02,   3.27522345e-02,  -1.81285396e-01,
                          1.16880462e-01,   5.83009310e-02,  -2.70233423e-01,
                          9.16612521e-02,   2.39400610e-01,  -2.67466694e-01,
                         -1.63465649e-01,   2.39135697e-01,   7.50854164e-02,
                         -2.33552262e-01,  -3.29944789e-02,   1.87857091e-01,
                         -2.19441615e-02,  -1.56286180e-01,   2.91268136e-02,
                          6.57226816e-02,  -5.17803729e-02,   2.49576773e-02,
                         -2.58147214e-02,  -1.66723132e-01,   1.08958691e-01,
                          1.29609793e-01,  -2.93502986e-01,  -3.93181816e-02,
                          2.83241808e-01,  -2.03789577e-01,  -2.04462349e-01,
                          2.38579378e-01,  -4.79380488e-02,  -2.09478974e-01,
                          1.67847738e-01,   1.30161112e-02,  -1.89095065e-01,
                          6.28873482e-02,   7.46580809e-02,  -9.39127877e-02,
                         -8.92068259e-03,  -5.94048901e-03,  -1.99340042e-02,
                          9.61531997e-02,  -9.69361886e-02,  -1.86939046e-01,
                          1.69630349e-01,   1.35821596e-01,  -2.95845389e-01,
                         -1.51650518e-01,   3.24831545e-01,   8.33284017e-03,
                         -4.28727180e-01,   4.89932224e-02,   3.19726199e-01,
                         -1.63268596e-01,  -2.56651402e-01,   1.28167644e-01,
                          7.21700788e-02,  -9.42386389e-02,  -1.07659120e-02,
                         -6.89703599e-02,  -4.09262953e-03,   1.46306470e-01,
                         -9.20321643e-02,  -1.86231151e-01,   1.27023309e-01,
                          9.57653672e-02,  -2.07225889e-01,  -5.73866926e-02,
                          1.56345412e-01,  -7.04657286e-02,  -2.03558862e-01,
                          8.17659944e-02,   1.19578637e-01,  -2.09998101e-01,
                         -1.03115581e-01,   1.99467644e-01,  -5.20368479e-02,
                         -2.10787371e-01,   5.33829033e-02,   6.52352422e-02,
                         -9.71921894e-04,  -7.39362240e-02,  -1.49257988e-01,
                          1.45841375e-01,   2.00285882e-01,  -3.89240682e-01,
                         -1.28370762e-01,   5.19679666e-01,  -1.20433807e-01,
                         -5.00472009e-01,   2.42965460e-01,   2.66646177e-01,
                         -3.13903213e-01,  -1.31394833e-01,   1.48767412e-01,
                          1.43184755e-02,  -5.05478419e-02,  -1.31760463e-01,
                         -8.55232775e-02,   1.47796154e-01,   4.29468639e-02,
                         -2.12632507e-01,  -5.79072684e-02,   1.90005645e-01,
                         -3.24641500e-04,  -2.20672980e-01,  -3.24114738e-03,
                          2.41144419e-01,  -8.00921023e-02,  -2.54002899e-01,
                          1.66894108e-01,   1.46002173e-01,  -2.75991350e-01,
                         -3.28441821e-02,   2.43079603e-01,  -1.24014571e-01,
                         -1.56609789e-01,   4.88983095e-02,   4.02974617e-03,
                          3.60354781e-02,  -1.08016379e-01,  -1.91152975e-01,
                          2.75356948e-01,   8.77073035e-02,  -4.71613407e-01,
                          7.48027414e-02,   4.40133393e-01,  -2.40404561e-01,
                         -3.33455622e-01,   3.24281573e-01,   1.60031557e-01,
                         -2.67209083e-01,  -1.18667901e-01,   1.87261343e-01,
                          1.27478763e-01,  -1.33998439e-01,  -1.23955719e-01,
                          5.09462133e-02,   8.41995403e-02,   1.23593854e-02,
                         -1.61007389e-01,  -1.02243789e-01,   2.40811199e-01,
                          6.19994849e-02,  -3.66719335e-01,   4.89782989e-02,
                          3.30371052e-01,  -2.60138869e-01,  -1.83455542e-01,
                          3.48412216e-01,  -1.31060202e-02,  -2.92675167e-01,
                          1.44074515e-01,   1.73862875e-01,  -1.18608892e-01,
                         -3.53715904e-02,   2.93214135e-02,   5.73307388e-02,
                          9.79264900e-02,  -1.83469936e-01,  -9.39740762e-02,
                          3.37086976e-01,  -2.85374913e-02,  -3.97457749e-01,
                          1.88233078e-01,   3.00883383e-01,  -2.92220771e-01,
                         -2.17976928e-01,   2.81886756e-01,   1.43835470e-01,
                         -2.64113098e-01,  -1.22131281e-01,   2.63963819e-01,
                          5.97625226e-02,  -1.99956834e-01,   3.41593325e-02,
                          1.11082770e-01,   2.86054742e-02,   1.77731812e-02,
                         -1.33158967e-01,  -1.85203571e-02,   2.94824451e-01,
                         -4.26652730e-02,  -3.20763886e-01,   2.25108802e-01,
                          2.60728985e-01,  -3.00761104e-01,  -1.17848679e-01,
                          3.13089639e-01,  -1.56290084e-02,  -2.42270783e-01,
                          1.05800867e-01,   1.45830929e-01,  -1.28557071e-01,
                         -7.50216320e-02,   1.17747828e-01,   7.06733093e-02,
                         -2.96408776e-02,  -6.66007325e-02,   1.58203151e-02,
                          2.00114116e-01,  -3.54101043e-03,  -2.78132647e-01,
                          1.66062444e-01,   3.57528925e-01,  -3.07318121e-01,
                         -2.23406702e-01,   4.23501015e-01,   5.69507107e-02,
                         -3.54431778e-01,   9.45874751e-02,   2.42021412e-01,
                         -1.64170414e-01,  -5.99515662e-02,   6.86237291e-02,
                         -5.05928788e-03,   9.74103436e-02,  -1.63900554e-02,
                         -1.69790998e-01,   1.19716443e-01,   2.15121865e-01,
                         -1.59759730e-01,  -1.34671152e-01,   2.39519149e-01,
                          1.49325401e-01,  -2.13742822e-01,  -6.45988062e-02,
                          2.74898052e-01,   8.90071318e-03,  -2.52923667e-01,
                          1.36089548e-01,   2.24532500e-01,  -2.00107872e-01,
                         -9.85704511e-02,   2.05057666e-01,  -7.44675100e-03,
                         -6.80362061e-02,   1.00795310e-02,  -1.61205921e-02,
                          1.44611582e-01,  -2.31514173e-03,  -2.70714492e-01,
                          2.17533335e-01,   2.61634529e-01,  -3.59335005e-01,
                         -1.96398478e-02,   4.22375858e-01,  -1.11937962e-01,
                         -2.60976166e-01,   2.28723571e-01,   1.51975602e-01,
                         -1.45446688e-01,  -3.72198154e-03,   7.88028240e-02,
                          1.00052822e-02,   3.05936635e-02,  -7.73224292e-06,
                         -6.94755763e-02,   3.74992937e-02,   1.46612301e-01,
                         -9.02646258e-02,  -1.98789120e-01,   2.09038958e-01,
                          1.67184904e-01,  -2.95674890e-01,   1.39853694e-02,
                          3.19568694e-01,  -1.37880445e-01,  -1.83361098e-01,
                          2.61884481e-01,   6.82345927e-02,  -1.69965029e-01,
                          1.11107752e-01,   9.86794084e-02,  -5.58147356e-02,
                          4.30903398e-02,  -2.64731441e-02,   2.93997303e-03,
                          1.77419037e-01,  -9.64582860e-02,  -1.62242591e-01,
                          2.40140766e-01,   4.39461172e-02,  -2.74441838e-01,
                          9.63236541e-02,   2.18473747e-01,  -1.46117523e-01,
                         -7.46024922e-02,   1.27736345e-01,   5.50083593e-02,
                         -1.12474442e-01,   3.29052806e-02,   1.52547404e-01,
                         -2.36324351e-02,  -6.96566999e-02,   1.51109457e-01,
                         -4.11728211e-02,  -8.68872404e-02,   2.58824497e-01,
                         -6.15764223e-02,  -2.28992417e-01,   2.78715283e-01,
                          8.53018612e-02,  -3.13189745e-01,   1.14603497e-01,
                          2.12878674e-01,  -2.15555727e-01,  -3.96588407e-02,
                          2.00006604e-01,  -8.81798044e-02,  -1.12400718e-01,
                          1.51064306e-01,   4.98711281e-02,  -6.86918795e-02,
                          2.08311360e-02,   4.60494459e-02,   2.20102128e-02,
                          3.98422256e-02,  -1.14965187e-02,  -1.13138910e-02,
                          1.29638463e-01,   7.65531510e-03,  -1.47957504e-01,
                          8.52528811e-02,   1.56390712e-01,  -1.44558981e-01,
                         -5.14089204e-02,   2.20703095e-01,  -6.42296895e-02,
                         -2.21445337e-01,   1.91402510e-01,   1.22130394e-01,
                         -2.66938895e-01,   6.74581528e-02,   2.33155817e-01,
                         -1.87832430e-01,  -4.93946299e-02,   1.83652803e-01,
                         -6.78985938e-02,  -1.43486382e-02,   1.41620561e-01,
                         -7.42016062e-02,  -5.47526740e-02,   1.19541392e-01,
                          3.26275788e-02,  -8.78630504e-02,   2.17300411e-02,
                          1.30720183e-01,  -5.48514500e-02,  -1.33474231e-01,
                          1.40318230e-01,   9.93841067e-02,  -2.18864009e-01,
                          2.85847764e-02,   2.24811226e-01,  -1.66375592e-01,
                         -1.08391717e-01,   1.65539891e-01,  -2.83938516e-02,
                         -1.67261041e-03,   5.79164550e-02,  -1.38331577e-01,
                          1.26857027e-01,   1.64679736e-01,  -2.86508709e-01,
                          4.96368855e-02,   3.37601811e-01,  -2.03933522e-01,
                         -2.04907104e-01,   3.68454486e-01,  -1.47860097e-02,
                         -3.15750539e-01,   1.86625436e-01,   1.76860034e-01,
                         -1.89761832e-01,  -5.18841296e-02,   9.98051316e-02,
                         -3.66371940e-03,  -2.47695912e-02,  -9.60351340e-03,
                         -1.61291137e-02,   2.67685782e-02,   4.85490225e-02,
                         -2.07027495e-02,  -9.33625028e-02,   1.04484037e-01,
                          1.70082092e-01,  -1.99867263e-01,  -7.93427452e-02,
                          3.12899202e-01,  -1.19884219e-02,  -3.01598698e-01,
                          1.44443557e-01,   2.19166234e-01,  -1.86294928e-01,
                         -7.15322345e-02,   1.08072817e-01,  -5.65492222e-03,
                          5.29345311e-03,  -7.69211203e-02,  -4.77380157e-02,
                          1.95734665e-01,  -5.66470474e-02,  -2.46844158e-01,
                          1.91013381e-01,   1.70150518e-01,  -2.81987429e-01,
                         -3.49712335e-02,   3.22134227e-01,  -5.18706888e-02,
                         -2.70621598e-01,   1.19765230e-01,   2.51947165e-01,
                         -1.61528900e-01,  -1.58691198e-01,   2.02435076e-01,
                          7.85581321e-02,  -1.52277917e-01,  -7.06609804e-04,
                          2.20976826e-02,  -1.05848173e-02,   9.32837948e-02,
                         -1.04028501e-01,  -1.76655278e-01,   2.37580225e-01,
                          7.52372667e-02,  -3.53670210e-01,   5.48317842e-02,
                          3.27324778e-01,  -1.95318684e-01,  -2.24026307e-01,
                          2.39760906e-01,   1.05305754e-01,  -1.92807570e-01,
                         -5.49226515e-02,   1.24512225e-01,   6.50113747e-02,
                         -8.18698257e-02,  -1.27760723e-01,   8.63758251e-02,
                          1.62664473e-01,  -1.58186123e-01,  -1.79493815e-01,
                          2.27732807e-01,   8.77454802e-02,  -3.29673171e-01,
                         -1.56135364e-02,   3.31138790e-01,  -1.59735650e-01,
                         -3.00930977e-01,   2.22829878e-01,   1.90149173e-01,
                         -3.15499395e-01,  -9.66460034e-02,   2.53899336e-01,
                         -1.29867531e-02,  -1.28895402e-01,   5.54299634e-03,
                         -5.73023083e-03,   8.19303021e-02,   3.34222168e-02,
                         -2.24003345e-01,   2.33982247e-03,   2.63936728e-01,
                         -9.70127806e-02,  -3.11588585e-01,   1.31489784e-01,
                          2.47821733e-01,  -2.45462850e-01,  -2.55336434e-01,
                          2.70072579e-01,   1.52197868e-01,  -3.82123262e-01,
                         -6.73075020e-02,   2.87964910e-01,  -7.50503764e-02,
                         -1.61974385e-01,   3.23272794e-02,   2.39725839e-02,
                          6.54254332e-02,  -6.28550425e-02,  -2.03743294e-01,
                          2.06644982e-01,   1.50443345e-01,  -3.85879993e-01,
                          2.74763331e-02,   3.85139227e-01,  -2.97087938e-01,
                         -2.81781495e-01,   3.88043016e-01,   3.01791616e-02,
                         -3.88103187e-01,   5.46597615e-02,   1.69786707e-01,
                         -9.74032804e-02,  -1.05475456e-01,  -6.56912699e-02,
                          6.34617060e-02,   1.45784900e-01,  -1.78750589e-01,
                         -1.98664442e-01,   1.45049021e-01,   1.78042188e-01,
                         -1.52805001e-01,  -2.29352847e-01,   1.62927896e-01,
                          2.41197079e-01,  -2.99007684e-01,  -2.61466295e-01,
                          3.81590933e-01,   8.88504162e-02,  -4.39381242e-01,
                          5.73368520e-02,   2.50665843e-01,  -1.84063226e-01,
                         -1.33427247e-01,   3.97715308e-02,   1.09387115e-02,
                          6.55186251e-02,  -1.51845515e-01,  -1.87737629e-01,
                          2.74925023e-01,   7.37230293e-03,  -3.80837291e-01,
                          1.69324905e-01,   2.77000755e-01,  -3.45287800e-01,
                         -1.17961019e-01,   3.12179357e-01,  -3.85528319e-02,
                         -2.71346867e-01,   6.15718998e-02,   1.84616521e-01,
                         -9.02488902e-02,  -1.85275465e-01,   1.22127961e-02,
                          1.18500464e-01,  -1.68769434e-02,  -1.26708269e-01,
                         -1.11036070e-01,   4.92744185e-02,   1.70018464e-01,
                         -1.70221001e-01,  -2.98583925e-01,   2.98386395e-01,
                          2.09767208e-01,  -4.68202293e-01,  -7.96961188e-02,
                          4.28429484e-01,  -1.11376069e-01,  -2.91262507e-01,
                          1.35713786e-01,   1.23958312e-01,  -4.58040945e-02,
                         -1.12844177e-01,  -9.13233906e-02,   1.58988014e-01,
                          8.91425833e-02,  -2.69279927e-01,  -4.81120721e-02,
                          2.53688604e-01,  -1.17345549e-01,  -2.58810550e-01,
                          1.81914806e-01,   1.17755346e-01,  -2.58352309e-01,
                         -4.25377488e-02,   2.25610986e-01,  -4.80852537e-02,
                         -2.56485164e-01,   1.30073696e-01,   1.76505595e-01,
                         -1.81333125e-01,  -8.42894912e-02,   1.55362949e-01,
                         -7.21995765e-03,  -5.08683957e-02,   1.87563282e-02,
                         -9.27416310e-02,   5.84997088e-02,   2.03587234e-01,
                         -2.50939488e-01,  -2.15364799e-01,   3.84895235e-01,
                          7.95629770e-02,  -4.14470047e-01,   4.36494052e-02,
                          3.16048175e-01,  -1.45364970e-01,  -2.33630344e-01,
                          1.36856377e-01,   1.41232535e-01,  -1.06050387e-01,
                         -6.93288520e-02,   5.90676256e-02,   3.81353050e-02,
                          2.23685596e-02,  -4.30012420e-02,  -6.58353493e-02,
                          1.64465934e-01,   3.32615152e-02,  -2.27775171e-01,
                          1.35991216e-01,   1.66904196e-01,  -2.79426485e-01,
                          3.40698548e-02,   2.85931021e-01,  -2.22758293e-01,
                         -1.68523818e-01,   3.14086169e-01,  -5.52219078e-02,
                         -2.66437232e-01,   1.53752401e-01,   1.17966361e-01,
                         -1.10480465e-01,  -5.38242236e-03,   7.05206860e-03,
                         -3.77909318e-02,   1.08563967e-01,   4.54268605e-02,
                         -1.40763998e-01,  -9.61690769e-03,   1.72887459e-01,
                          3.26715061e-03,  -1.79364473e-01,   3.26848291e-02,
                          2.14086577e-01,  -1.05377562e-01,  -2.06104055e-01,
                          1.68210387e-01,   8.81046206e-02,  -1.74113929e-01,
                          3.17681320e-02,   9.24746618e-02,  -7.87460878e-02,
                          4.08798903e-02,   2.41728406e-02,  -1.13849789e-01,
                          8.44188333e-02,   6.24564402e-02,  -1.13969669e-01,
                          7.11199865e-02,   5.44812344e-02,  -9.66309011e-02,
                          6.34749308e-02,   8.27664360e-02,  -1.24169827e-01,
                          3.88598479e-02,   1.16543204e-01,  -6.91553801e-02,
                         -6.13835342e-02,   6.61997795e-02,   3.53338048e-02,
                         -4.05871682e-02,  -6.54238323e-03,   2.57261898e-02,
                          4.70461138e-03,  -7.86080956e-03,   5.68004651e-03,
                         -4.68676124e-04,  -3.16247996e-03,   2.80210581e-02,
                          1.60767161e-03,  -1.17984638e-02,   1.01154493e-02,
                          2.45848466e-02,  -4.34496440e-03,  -6.72717905e-03,
                         -1.92985591e-03,   1.03759335e-03,   4.57322737e-03,
                          2.37977621e-03,   1.92724087e-03,   3.07278894e-03,
                          2.25289678e-03,   4.19788295e-03,   3.23891174e-03,
                          3.16528650e-03,   4.14843857e-03,   2.77587888e-03,
                          4.67249518e-03,   4.38669510e-03,   1.92700047e-03,
                          3.93252913e-03,   3.44179105e-03,   2.85997568e-03,
                          3.87532660e-03,   5.42508531e-03,   1.82869425e-03,
                          5.11386804e-03,   4.29757545e-03,   2.03726953e-03,
                          4.32911282e-03,   4.56145220e-03,   2.84492434e-03,
                          4.07651160e-03,   5.79714216e-03,   4.39038873e-03,
                          3.02666589e-03,   3.94314341e-03,   4.37525846e-03,
                          3.92329786e-03,   3.44719016e-03,   4.82463790e-03,
                          4.67100367e-03,   3.50921717e-03,   4.71522566e-03,
                          4.86151082e-03,   3.57924704e-03,   4.24464466e-03,
                          4.62238956e-03,   4.38777357e-03,   3.06866341e-03,
                          4.22596373e-03,   5.03714290e-03,   4.71241865e-03,
                          4.93584992e-03,   4.45610518e-03,   4.17512562e-03,
                          4.81571071e-03,   3.98797402e-03,   5.00772055e-03,
                          5.25595248e-03,   4.49378556e-03,   3.78807774e-03,
                          4.63940948e-03,   4.89179697e-03,   4.53109061e-03,
                          5.12550771e-03,   4.83032595e-03,   3.64384777e-03,
                          5.49208652e-03],
                          dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri4",
    rate = 41000,
    data = numpy.array([ -8.36461782e-04,   4.39845026e-05,   1.76519156e-04,
                         -3.65726650e-04,   1.02970749e-04,   9.98850912e-04,
                          1.06483698e-03,   1.00135058e-03,   1.08228624e-03,
                          6.85647130e-04,   5.65242022e-04,   1.06070936e-03,
                          7.65003264e-04,  -1.80959702e-04,  -2.06615776e-04,
                          1.41456723e-04,  -2.46498734e-04,  -4.95541841e-04,
                         -1.69534236e-04,  -4.40105796e-05,   2.12464482e-04,
                          8.87867063e-04,   9.51264054e-04,   6.19258732e-04,
                          1.10625476e-03,   1.65161863e-03,   1.17629766e-03,
                          5.67574054e-04,   3.18616629e-04,  -2.24981457e-04,
                         -7.04165548e-04,  -7.14972615e-04,  -1.00323930e-03,
                         -1.37347728e-03,  -9.71414149e-04,  -5.60343266e-04,
                         -8.17034394e-04,  -7.64980912e-04,  -2.23498791e-04,
                         -8.65720212e-05,  -1.04561448e-04,   9.64291394e-05,
                         -5.69075346e-05,  -2.70020217e-04,   9.76398587e-05,
                          2.47966498e-04,  -1.57434493e-04,  -9.14968550e-05,
                          3.00858170e-04,   1.32516026e-04,  -1.90511346e-05,
                          2.85550952e-04,   3.37056816e-04,   3.25106084e-04,
                          6.91924244e-04,   5.83034009e-04,  -1.83619559e-05,
                          2.38716602e-05,   1.93726271e-04,  -4.81527299e-04,
                         -1.06395409e-03,  -1.06703117e-03,  -1.42114237e-03,
                         -1.80989504e-03,  -1.52774900e-03,  -1.37559697e-03,
                         -1.32554024e-03,  -3.63409519e-04,   5.23488969e-04,
                          2.37025321e-04,   1.65633857e-04,   8.67161900e-04,
                          9.19669867e-04,   4.90773469e-04,   5.00306487e-04,
                          1.32452697e-04,  -5.82989305e-04,  -3.88354063e-04,
                         -1.84021890e-04,  -1.00065023e-03,  -1.13644451e-03,
                         -1.02963299e-04,   1.29502267e-04,  -2.73387879e-04,
                          1.59543008e-04,   6.29939139e-04,   6.97631389e-04,
                          1.42308697e-03,   1.85995176e-03,   9.24229622e-04,
                          5.36382198e-04,   1.30554289e-03,   9.75113362e-04,
                         -2.25633383e-04,  -2.66496092e-04,   7.85067677e-05,
                         -1.27099454e-04,   1.88931823e-04,   4.79657203e-04,
                         -2.67807394e-04,  -2.21818686e-04,   1.13688409e-03,
                          1.25000626e-03,   2.43771821e-04,   4.53267246e-04,
                          1.03155896e-03,   5.49115241e-04,   2.04291195e-04,
                          9.47974622e-05,  -7.13072717e-04,  -8.14672559e-04,
                          1.09195709e-04,  -4.38295305e-04,  -2.08144262e-03,
                         -2.05375254e-03,  -1.17057934e-03,  -1.37057155e-03,
                         -1.59899518e-03,  -1.35461241e-03,  -1.54678896e-03,
                         -1.18421391e-03,   1.67265534e-05,  -1.40365213e-04,
                         -1.22417510e-03,  -6.41994178e-04,   5.78254461e-04,
                          3.41627747e-04,  -6.65150583e-05,   3.35324556e-04,
                          5.37306070e-04,   8.56753439e-04,   1.41807273e-03,
                          6.40433282e-04,  -5.89821488e-04,   1.51716173e-04,
                          1.47541985e-03,   1.10089406e-03,   3.93696129e-04,
                          6.18800521e-04,   8.82510096e-04,   1.27581879e-03,
                          1.84501708e-03,   1.29972398e-03,   5.23615628e-04,
                          1.38890371e-03,   2.24852934e-03,   1.31493434e-03,
                          4.55699861e-04,   8.37400556e-04,   1.14234909e-03,
                          1.14611164e-03,   9.75701958e-04,  -1.08696520e-04,
                         -8.47335905e-04,   2.08418816e-04,   9.07078385e-04,
                         -2.22507864e-04,  -8.43629241e-04,  -3.07671726e-05,
                          5.19495457e-04,   6.48718327e-04,   6.07784837e-04,
                         -2.82336026e-04,  -6.46293163e-04,   7.46257603e-04,
                          1.41248107e-03,   2.30595469e-04,  -4.95687127e-05,
                          9.54072922e-04,   1.02794170e-03,   6.08891249e-04,
                          6.02960587e-04,   1.56387687e-04,   2.81780958e-04,
                          1.85143203e-03,   1.97936222e-03,  -7.19204545e-05,
                         -7.04027712e-04,   2.49031931e-04,  -1.40849501e-04,
                         -1.07793510e-03,  -1.11904368e-03,  -1.55423209e-03,
                         -1.63063407e-03,  -8.07009637e-05,   1.89721584e-04,
                         -1.67655572e-03,  -1.72530487e-03,  -6.57476485e-05,
                         -3.55556607e-04,  -1.31536275e-03,  -7.38248229e-04,
                         -6.37490302e-04,  -9.78931785e-04,   1.90697610e-04,
                          4.89480793e-04,  -1.13159791e-03,  -5.64809889e-04,
                          1.84356794e-03,   1.45091861e-03,  -2.49110162e-04,
                          1.29245222e-04,   3.46519053e-04,  -3.51332128e-04,
                          5.08617610e-04,   8.29376280e-04,  -1.27111375e-03,
                         -1.63967907e-03,   1.73535198e-04,  -6.27808273e-04,
                         -2.58447975e-03,  -1.62549689e-03,  -5.69704920e-04,
                         -1.32485852e-03,  -6.36931509e-04,   5.05000353e-04,
                         -5.49484044e-04,  -3.06546688e-04,   2.14561075e-03,
                          1.70344859e-03,  -6.10679388e-04,   1.65686011e-04,
                          1.41917914e-03,   1.53724104e-04,  -7.69831240e-05,
                          8.66334885e-04,  -2.43544579e-04,  -4.95266169e-04,
                          2.06831843e-03,   2.50717998e-03,   7.27675855e-04,
                          1.82053447e-03,   3.64332274e-03,   2.41949782e-03,
                          1.80446729e-03,   3.09151039e-03,   2.36191601e-03,
                          1.18118152e-03,   2.31857598e-03,   1.73157454e-03,
                         -1.34465098e-03,  -1.57234073e-03,  -5.26979566e-05,
                         -1.17433071e-03,  -1.88683346e-03,   1.04565173e-04,
                          7.98888505e-04,   4.32703644e-04,   2.22581625e-03,
                          3.06120142e-03,   1.12925470e-03,   1.19669735e-03,
                          3.18560004e-03,   2.38439813e-03,   7.18839467e-04,
                          1.24876201e-03,   7.37853348e-04,  -1.30254030e-03,
                         -1.14070624e-03,  -4.98991460e-04,  -2.02717260e-03,
                         -2.19720602e-03,  -1.75856054e-04,  -2.22403556e-04,
                         -1.34548172e-03,   4.51132655e-06,   1.40376389e-03,
                          9.89302993e-04,   1.56236440e-03,   2.49624252e-03,
                          1.19068101e-03,   3.32295895e-04,   1.74060464e-03,
                          1.88553706e-03,   3.33771110e-04,   3.30518931e-04,
                          8.71688128e-04,  -8.52718949e-05,  -4.83676791e-04,
                          1.18974596e-04,  -6.14587218e-04,  -1.51089579e-03,
                         -6.05251640e-04,  -1.90183520e-04,  -1.41031295e-03,
                         -1.60901621e-03,  -5.72465360e-04,  -5.19298017e-04,
                         -9.05439258e-04,  -6.40168786e-04,  -8.98420811e-04,
                         -1.53215975e-03,  -1.03282556e-03,  -5.60741872e-04,
                         -1.71509013e-03,  -2.86889449e-03,  -2.60730460e-03,
                         -2.39834189e-03,  -3.01907957e-03,  -3.25991958e-03,
                         -2.92354450e-03,  -2.71375105e-03,  -2.22805887e-03,
                         -1.44796073e-03,  -1.58619881e-03,  -2.23214179e-03,
                         -1.49969384e-03,   2.59540975e-05,   1.94232911e-04,
                         -3.86301428e-04,  -2.48961151e-05,   3.81655991e-04,
                         -1.11605972e-04,  -4.31846827e-04,  -6.56623393e-04,
                         -1.63443759e-03,  -1.80733204e-03,  -5.91997057e-04,
                         -6.98115677e-04,  -2.17749923e-03,  -1.72324106e-03,
                          1.12794340e-04,   4.49094921e-04,   3.68766487e-04,
                          1.01640448e-03,   5.26417047e-04,  -3.59471887e-04,
                          4.20812517e-04,   2.68045813e-04,  -2.12389231e-03,
                         -2.68387422e-03,  -1.16087496e-03,  -1.78952888e-03,
                         -3.39693576e-03,  -2.77800113e-03,  -2.30326876e-03,
                         -2.83579528e-03,  -1.56373531e-03,  -4.65489924e-04,
                         -2.22470239e-03,  -2.53630430e-03,   7.37123191e-05,
                          2.24847347e-04,  -1.64685771e-03,  -8.57077539e-04,
                          2.86947936e-04,  -8.74459743e-04,  -6.12352043e-04,
                          5.95808029e-04,  -9.26725566e-04,  -1.50715560e-03,
                          1.42771006e-03,   1.99369341e-03,  -5.65432012e-04,
                         -8.20942223e-05,   1.66719034e-03,   4.36067581e-04,
                         -1.17570162e-04,   1.16725639e-03,  -3.06893140e-04,
                         -1.95835903e-03,   1.97850168e-04,   7.53976405e-04,
                         -2.04659253e-03,  -1.59142539e-03,   1.27795339e-03,
                          6.61384314e-04,  -3.06852162e-05,   1.97624415e-03,
                          1.88012421e-03,   5.52032143e-04,   2.66971067e-03,
                          3.60121951e-03,   3.66710126e-04,  -1.72715634e-04,
                          2.35100836e-03,   1.41409412e-03,  -6.44452870e-04,
                          4.20689583e-04,  -9.41194594e-05,  -2.38187611e-03,
                         -1.29567459e-03,  -3.28794122e-05,  -2.73646042e-03,
                         -3.41761857e-03,  -6.21154904e-04,  -1.12538412e-03,
                         -3.18510458e-03,  -1.95660070e-03,  -1.14322081e-03,
                         -2.87143514e-03,  -1.73391029e-03,  -2.78279185e-06,
                         -1.90069526e-03,  -2.40506604e-03,   7.43515790e-04,
                          1.42242759e-03,  -3.25094908e-04,   1.16781145e-03,
                          2.30480358e-03,   1.08707696e-03,   1.55439973e-03,
                          3.07526439e-03,   9.29851085e-04,  -6.74776733e-04,
                          1.34517625e-03,   1.31160393e-03,  -6.11968338e-04,
                         -3.18184495e-04,   5.07421792e-04,  -1.38539076e-03,
                         -1.37024745e-03,  -1.67418271e-04,  -1.45298988e-03,
                         -2.28446722e-03,  -3.61528248e-04,  -1.25974417e-04,
                         -2.62437016e-03,  -2.63522565e-03,  -2.38768384e-03,
                         -3.43278795e-03,  -3.45121324e-03,  -2.37207860e-03,
                         -3.77304852e-03,  -4.34577093e-03,  -1.96244568e-03,
                         -1.02151930e-03,  -1.86984614e-03,  -1.53416768e-03,
                         -1.64262950e-04,  -4.40809876e-04,   9.29176807e-04,
                          1.44096464e-03,  -2.69368291e-04,  -1.73464417e-03,
                          1.42492354e-05,   2.94972211e-04,  -1.05001777e-03,
                         -3.04363668e-04,   6.33321702e-04,   9.69573855e-04,
                          1.21704489e-03,   1.04043633e-03,  -2.51352787e-03,
                         -2.30897591e-03,   7.11794943e-04,   1.85260922e-03,
                          2.12676823e-05,  -5.99063933e-05,   5.84140420e-04,
                          1.02974474e-04,   2.30762735e-03,   1.91662833e-03,
                         -4.50108200e-04,  -1.34013221e-03,   2.53349915e-03,
                          2.01231614e-03,  -2.90814787e-04,   4.46926802e-04,
                          6.79310411e-04,   4.09681350e-04,   5.48485667e-04,
                          1.16467848e-03,  -3.18805128e-03,  -2.06159055e-03,
                          1.44744664e-03,   1.26877055e-03,  -1.90218166e-03,
                         -2.45340168e-04,   2.37140432e-03,   1.14206225e-03,
                          3.56161222e-03,   3.37409228e-03,   8.31730664e-04,
                          1.64080411e-04,   5.14101982e-03,   3.25868651e-03,
                         -8.97217542e-04,   1.12446398e-03,   2.37219781e-03,
                         -1.62139535e-04,  -1.89309195e-03,   4.36306000e-05,
                         -3.39486450e-03,  -1.70204788e-03,   2.77651101e-03,
                          2.52956897e-03,  -2.00036168e-03,   1.93769112e-03,
                          5.92337176e-03,   3.67868319e-03,   2.69025192e-03,
                          1.63323805e-03,   1.78028271e-03,   2.08073482e-03,
                          9.33918729e-03,   4.86143306e-03,  -3.32545489e-04,
                         -1.23500451e-03,   5.00468910e-03,   3.65152583e-03,
                          1.27620995e-03,   2.12480128e-03,   3.59453261e-05,
                          2.74600089e-03,   3.90347466e-03,   3.23226675e-03,
                         -7.04856589e-03,  -1.69076771e-03,   2.89802253e-03,
                          2.71151215e-03,  -2.74092332e-03,  -3.21627036e-03,
                         -1.09888986e-03,  -1.57332420e-03,   7.26216286e-03,
                          3.10157239e-03,   1.39405206e-03,  -1.08007342e-03,
                          8.44031572e-03,   4.61659208e-03,   1.17715821e-03,
                          2.55854428e-03,  -1.11433119e-03,   1.50383636e-03,
                         -5.19011170e-04,   5.54296747e-03,  -3.79992276e-03,
                          3.07637453e-03,   2.57162377e-03,   4.22411412e-03,
                          2.49242410e-03,   4.87023965e-03,   7.34176487e-03,
                         -1.13141537e-03,   7.54673034e-03,   1.19454041e-03,
                          5.69065660e-03,  -2.03146413e-03,   1.81160495e-03,
                         -4.62855399e-03,  -1.07627362e-03,   5.20337000e-03,
                         -2.39952654e-03,   1.12351030e-04,  -6.53515756e-03,
                          7.73502141e-03,   1.34363025e-03,   9.71448049e-03,
                         -4.35369462e-03,  -1.48119032e-03,   4.57028300e-03,
                          8.78572837e-03,   1.48650259e-03,  -7.55174458e-03,
                          4.97462973e-03,  -8.77200812e-03,   6.37061894e-03,
                         -4.69391793e-03,  -1.24109164e-03,  -1.53296925e-02,
                          2.50465795e-03,  -8.41505826e-05,  -6.21966273e-03,
                         -1.57357380e-03,  -6.65360317e-03,  -2.36852840e-03,
                         -6.52161986e-03,   3.51588428e-03,  -2.12422758e-03,
                          8.39401037e-04,  -7.38194957e-03,  -1.70975924e-04,
                          2.25893036e-03,   2.28726491e-03,  -4.34128940e-03,
                         -5.46915084e-03,   1.10756233e-03,  -8.90731812e-04,
                          1.56210363e-03,  -3.59622762e-03,  -1.86850131e-03,
                         -2.86460668e-03,   3.62228230e-03,   1.09592825e-03,
                         -3.73916700e-03,  -6.74325973e-04,   1.01152807e-03,
                          2.69526616e-03,  -2.27236003e-03,  -2.47497112e-04,
                         -3.07480618e-03,  -2.54053622e-04,  -1.68599933e-03,
                         -4.44296747e-04,  -6.08464330e-03,  -1.02657452e-03,
                          1.07408315e-03,  -1.49451569e-03,  -4.82115522e-03,
                         -2.24012136e-03,  -8.84838402e-04,  -1.10953674e-03,
                         -4.94204462e-04,  -3.07163969e-03,  -3.94802913e-03,
                         -1.63688883e-03,   3.31966951e-03,  -3.60741839e-03,
                         -4.49590385e-03,  -4.51391935e-03,   6.21072948e-04,
                         -6.49690628e-05,  -1.28723681e-03,  -3.17651778e-04,
                         -5.45347482e-03,  -5.16831875e-04,  -1.86699256e-03,
                         -4.76814806e-04,  -4.82799113e-03,  -1.97936594e-03,
                         -1.16986036e-03,   7.39287585e-04,  -3.83332372e-05,
                         -4.85981256e-03,   3.82147729e-04,  -2.74220482e-03,
                          4.62366641e-03,   5.41768968e-05,  -1.72760338e-04,
                         -2.94764712e-03,  -2.17732042e-04,  -9.89399850e-04,
                          8.73971730e-04,  -2.95917690e-03,  -3.80072370e-03,
                          4.86807525e-03,   9.00089741e-04,   1.12466514e-03,
                         -3.26449424e-03,   4.62405384e-03,  -1.73114240e-05,
                          1.35135278e-03,  -4.87063080e-04,  -3.11966985e-04,
                          1.88983977e-04,   2.64886394e-03,   2.07591057e-03,
                         -3.29069793e-03,  -2.21155584e-04,   2.55427137e-03,
                          2.82955170e-03,  -2.62637064e-03,   6.77455217e-04,
                         -3.26488167e-04,  -3.97674739e-04,   2.74269283e-03,
                         -3.15345824e-04,  -7.05938786e-04,  -1.89622864e-03,
                          2.35475227e-03,  -1.46115199e-03,  -2.09704041e-03,
                          4.03989106e-04,   7.63308257e-04,   1.36654824e-03,
                         -2.06208229e-03,  -9.52817500e-05,  -3.00436467e-03,
                          1.03607774e-04,  -1.10852346e-03,  -1.77100301e-03,
                         -3.35248932e-03,  -2.35454738e-03,   1.79600343e-03,
                         -3.88646126e-03,  -4.69423831e-04,  -4.57539782e-03,
                          1.08551979e-03,   1.20231323e-02,   1.27967186e-02,
                          9.02612507e-03,   1.51926354e-02,   1.26808017e-01,
                          1.16216689e-01,   1.05227731e-01,   9.79814827e-02,
                          1.43979400e-01,   1.38332233e-01,   1.41843110e-01,
                          1.42142475e-01,   4.10374068e-02,   6.38957396e-02,
                          8.50676224e-02,   9.39438641e-02,  -4.18825150e-02,
                         -1.88310370e-02,  -2.13439763e-03,   1.09667704e-03,
                          1.65206939e-03,  -8.45797732e-03,  -1.83087736e-02,
                         -3.48674022e-02,   1.00767970e-01,   6.50393963e-02,
                          3.75712141e-02,   1.96186826e-02,   9.24505740e-02,
                          7.78967515e-02,   7.29740262e-02,   7.59949610e-02,
                         -2.39552818e-02,   6.12458959e-03,   2.42797583e-02,
                          4.73201089e-02,  -8.49586278e-02,  -5.74799851e-02,
                         -3.52519676e-02,  -2.91246921e-02,  -1.06146671e-02,
                         -2.05501430e-02,  -2.92026587e-02,  -4.28669192e-02,
                          9.34107900e-02,   6.02004342e-02,   3.31365950e-02,
                          1.93225034e-02,   7.56196454e-02,   6.63166791e-02,
                          6.05523773e-02,   6.52799755e-02,  -3.68270688e-02,
                         -1.21420845e-02,   1.15429908e-02,   2.89138965e-02,
                         -9.05592144e-02,  -6.49146959e-02,  -4.61636074e-02,
                         -4.23947573e-02,  -6.80592284e-03,  -2.06639394e-02,
                         -3.28988023e-02,  -4.68182750e-02,   8.58221054e-02,
                          5.62074333e-02,   2.85967626e-02,   1.59664825e-02,
                          5.45118265e-02,   4.76358198e-02,   4.86794785e-02,
                          5.39641492e-02,  -6.30632341e-02,  -3.45328040e-02,
                         -1.04475878e-02,   8.44633207e-03,  -1.02304548e-01,
                         -7.93527141e-02,  -6.41576946e-02,  -6.37060478e-02,
                         -7.19006360e-03,  -2.64824852e-02,  -4.10181284e-02,
                         -5.93441278e-02,   7.93561935e-02,   4.65881974e-02,
                          2.52890140e-02,   9.81420279e-03,   3.76303233e-02,
                          3.17589343e-02,   3.55160013e-02,   4.56124097e-02,
                         -7.80165419e-02,  -4.87214215e-02,  -2.37304717e-02,
                         -7.79876858e-03,  -1.02336347e-01,  -8.21785554e-02,
                         -7.06161559e-02,  -6.99715689e-02,  -2.31958181e-03,
                         -2.01153606e-02,  -3.64024378e-02,  -5.19537106e-02,
                          8.08302313e-02,   4.93357480e-02,   2.94055194e-02,
                          1.77609771e-02,   2.88541280e-02,   2.82710604e-02,
                          3.37532870e-02,   4.28804308e-02,  -8.58862475e-02,
                         -5.22835962e-02,  -3.04978229e-02,  -1.23447254e-02,
                         -9.61308330e-02,  -7.93963596e-02,  -6.91212714e-02,
                         -7.25410134e-02,   1.32840350e-02,  -1.11390725e-02,
                         -2.96213552e-02,  -4.64767069e-02,   8.26291442e-02,
                          5.42032830e-02,   3.28593403e-02,   2.48288475e-02,
                          1.56191140e-02,   2.17071734e-02,   3.00646797e-02,
                          4.26184759e-02,  -9.42217112e-02,  -5.90667501e-02,
                         -3.66483033e-02,  -1.96350329e-02,  -8.72479677e-02,
                         -7.50434771e-02,  -6.94544166e-02,  -7.08538741e-02,
                          2.47574337e-02,  -3.21660191e-04,  -2.16021650e-02,
                         -3.91259566e-02,   8.59618336e-02,   5.80720231e-02,
                          3.99478041e-02,   3.34069841e-02,   6.04002550e-03,
                          1.87377110e-02,   2.72897892e-02,   4.27660197e-02,
                         -9.67372879e-02,  -6.40492737e-02,  -3.86867672e-02,
                         -2.35943757e-02,  -7.72381127e-02,  -6.74872249e-02,
                         -6.74061179e-02,  -6.99545369e-02,   3.91334556e-02,
                          1.17440931e-02,  -1.24133155e-02,  -3.06810811e-02,
                          8.73769820e-02,   6.22033738e-02,   4.82070297e-02,
                          4.10685055e-02,  -4.65989113e-04,   1.35078132e-02,
                          2.80612782e-02,   4.39778864e-02,  -9.62121412e-02,
                         -6.31297082e-02,  -4.05639037e-02,  -2.45335326e-02,
                         -6.29990995e-02,  -5.71615137e-02,  -5.84848821e-02,
                         -6.46717995e-02,   5.33685684e-02,   2.53590196e-02,
                          3.94191593e-04,  -1.78857297e-02,   9.02259499e-02,
                          6.64025545e-02,   5.44729121e-02,   5.00942618e-02,
                         -5.84616885e-03,   1.05255507e-02,   2.70740800e-02,
                          4.25693654e-02,  -9.53219533e-02,  -6.33838102e-02,
                         -4.09067795e-02,  -2.77645849e-02,  -5.02819233e-02,
                         -4.77101989e-02,  -5.21671027e-02,  -6.00415021e-02,
                          6.71453401e-02,   3.47380191e-02,   1.12616234e-02,
                         -7.30389729e-03,   8.95143300e-02,   6.89073280e-02,
                          5.84196113e-02,   5.75193465e-02,  -1.45284794e-02,
                          5.64846769e-03,   2.44689807e-02,   4.10484970e-02,
                         -9.50342044e-02,  -6.30597770e-02,  -4.23698872e-02,
                         -3.07816453e-02,  -3.69731374e-02,  -3.91082317e-02,
                         -4.54228297e-02,  -5.62069900e-02,   7.74036795e-02,
                          4.42570485e-02,   1.99147835e-02,   2.13832036e-03,
                          8.53051096e-02,   6.83384687e-02,   6.09453246e-02,
                          6.14698604e-02,  -2.42990144e-02,  -7.82914460e-04,
                          1.98494531e-02,   3.73660102e-02,  -9.36330259e-02,
                         -6.38765022e-02,  -4.43138368e-02,  -3.48987728e-02,
                         -2.38013081e-02,  -3.01644877e-02,  -3.98063324e-02,
                         -5.13924025e-02,   8.56359154e-02,   5.25875278e-02,
                          2.75213495e-02,   1.13992728e-02,   7.90390521e-02,
                          6.64001405e-02,   6.14907630e-02,   6.40382692e-02,
                         -3.39215510e-02,  -8.21113959e-03,   1.39447600e-02,
                          3.17156650e-02,  -9.18719098e-02,  -6.42917305e-02,
                         -4.71377485e-02,  -3.93424407e-02,  -1.18978433e-02,
                         -2.19307281e-02,  -3.40230130e-02,  -4.75156121e-02,
                          9.16862190e-02,   5.86386546e-02,   3.45285684e-02,
                          1.88924670e-02,   7.12047592e-02,   6.21150061e-02,
                          6.06295653e-02,   6.52027428e-02,  -4.42290902e-02,
                         -1.59531571e-02,   6.83406740e-03,   2.53323950e-02,
                         -8.96106362e-02,  -6.45155236e-02,  -4.96809110e-02,
                         -4.39128242e-02,  -3.39943916e-04,  -1.40152499e-02,
                         -2.85739079e-02,  -4.36453596e-02,   9.60494503e-02,
                          6.30490035e-02,   4.01657335e-02,   2.56405957e-02,
                          6.16181456e-02,   5.65723814e-02,   5.80679215e-02,
                          6.47123307e-02,  -5.44622652e-02,  -2.42968500e-02,
                         -3.36319208e-04,   1.76943727e-02,  -8.67619514e-02,
                         -6.42795116e-02,  -5.18834330e-02,  -4.84653078e-02,
                          1.08926855e-02,  -6.32461160e-03,  -2.32510902e-02,
                         -3.94553468e-02,   9.86773372e-02,   6.65943176e-02,
                          4.45087254e-02,   3.18493210e-02,   5.11262901e-02,
                          4.99566272e-02,   5.44340648e-02,   6.32339418e-02,
                         -6.40065372e-02,  -3.25018428e-02,  -7.83622637e-03,
                          9.77833197e-03,  -8.26410353e-02,  -6.33230954e-02,
                         -5.35755493e-02,  -5.22963032e-02,   2.17877068e-02,
                          1.28856674e-03,  -1.77567974e-02,  -3.47485840e-02,
                          9.99807194e-02,   6.86663166e-02,   4.83091772e-02,
                          3.72060090e-02,   4.00027111e-02,   4.26847674e-02,
                          5.00453785e-02,   6.05339073e-02,  -7.26528764e-02,
                         -3.98852229e-02,  -1.51795037e-02,   1.87653303e-03,
                         -7.73444697e-02,  -6.13435842e-02,  -5.45053631e-02,
                         -5.51960245e-02,   3.24325040e-02,   8.74671340e-03,
                         -1.20313764e-02,  -2.94742286e-02,   9.95148793e-02,
                          7.01122731e-02,   5.14500737e-02,   4.20268998e-02,
                          2.81336568e-02,   3.48873399e-02,   4.51073460e-02,
                          5.70342317e-02,  -7.99941346e-02,  -4.69046086e-02,
                         -2.21941769e-02,  -5.94095886e-03,  -7.06044063e-02,
                         -5.85645773e-02,  -5.46295755e-02,  -5.72929233e-02,
                          4.25883979e-02,   1.63860284e-02,  -5.94147667e-03,
                         -2.38945968e-02,   9.77005959e-02,   7.05470443e-02,
                          5.39372824e-02,   4.64128442e-02,   1.59472451e-02,
                          2.65255384e-02,   3.93438451e-02,   5.30291349e-02,
                         -8.61752629e-02,  -5.30693755e-02,  -2.89957486e-02,
                         -1.36130042e-02,  -6.29379153e-02,  -5.47325425e-02,
                         -5.37338033e-02,  -5.86097389e-02,   5.22165969e-02,
                          2.37291828e-02,   2.98812985e-04,  -1.77960545e-02,
                          9.45800543e-02,   7.00229183e-02,   5.57012670e-02,
                          5.02796695e-02,   3.59717384e-03,   1.79873668e-02,
                          3.32376026e-02,   4.81892377e-02,  -9.09422487e-02,
                         -5.82242943e-02,  -3.51283699e-02,  -2.13154927e-02,
                         -5.41884117e-02,  -4.98769209e-02,  -5.19516245e-02,
                         -5.90151362e-02,   6.11525737e-02,   3.08976173e-02,
                          6.62180781e-03,  -1.11730918e-02,   9.02257860e-02,
                          6.86148405e-02,   5.67906983e-02,   5.37019596e-02,
                         -8.55489075e-03,   9.25078243e-03,   2.68349573e-02,
                          4.28011008e-02,  -9.42339972e-02,  -6.24251179e-02,
                         -4.05811183e-02,  -2.84345709e-02,  -4.45651859e-02,
                         -4.41907197e-02,  -4.93186451e-02,  -5.83447069e-02,
                          6.94749802e-02,   3.78936492e-02,   1.30540319e-02,
                         -4.32385132e-03,   8.48892927e-02,   6.64782226e-02,
                          5.73955514e-02,   5.64433262e-02,  -2.04574168e-02,
                          6.43249601e-04,   2.02973485e-02,   3.71076576e-02,
                         -9.61623043e-02,  -6.56736493e-02,  -4.53391522e-02,
                         -3.47999372e-02,  -3.41301262e-02,  -3.78209986e-02,
                         -4.58352640e-02,  -5.66179194e-02,   7.70933628e-02,
                          4.44190092e-02,   1.95228457e-02,   2.77217850e-03,
                          7.85831660e-02,   6.35739490e-02,   5.73782735e-02,
                          5.85641973e-02,  -3.18638794e-02,  -7.72660598e-03,
                          1.36491321e-02,   3.10692675e-02,  -9.65753496e-02,
                         -6.77080452e-02,  -4.93084230e-02,  -4.05378938e-02,
                         -2.30801404e-02,  -3.06751244e-02,  -4.15139832e-02,
                         -5.39604425e-02,   8.37434232e-02,   5.05286604e-02,
                          2.59162039e-02,   9.99012962e-03,   7.13429227e-02,
                          5.99408597e-02,   5.67131452e-02,   6.00720942e-02,
                         -4.25669514e-02,  -1.58718377e-02,   6.90359622e-03,
                          2.47597881e-02,  -9.53165516e-02,  -6.86248243e-02,
                         -5.23592867e-02,  -4.55398187e-02,  -1.15321279e-02,
                         -2.29060315e-02,  -3.63944285e-02,  -5.03770784e-02,
                          8.92722309e-02,   5.61442673e-02,   3.21028270e-02,
                          1.72761939e-02,   6.31792843e-02,   5.56427315e-02,
                          5.53360134e-02,   6.08662814e-02,  -5.25541976e-02,
                         -2.37000994e-02,   1.68096274e-04,   1.81844458e-02,
                         -9.25917551e-02,  -6.85478151e-02,  -5.45799322e-02,
                         -4.97839451e-02,   4.25931066e-04,  -1.46766789e-02,
                         -3.05688903e-02,  -4.58644070e-02,   9.37743634e-02,
                          6.10832237e-02,   3.80163044e-02,   2.44860910e-02,
                          5.41879311e-02,   5.06468192e-02,   5.33237457e-02,
                          6.08764589e-02,  -6.18397295e-02,  -3.11029702e-02,
                         -6.54502213e-03,   1.13434717e-02,  -8.85118246e-02,
                         -6.73443377e-02,  -5.60134724e-02,  -5.32908663e-02,
                          1.24830157e-02,  -6.15415722e-03,  -2.42780596e-02,
                         -4.05948237e-02,   9.70211327e-02,   6.51737303e-02,
                          4.34861295e-02,   3.14457566e-02,   4.43958379e-02,
                          4.48338129e-02,   5.05761243e-02,   6.00258596e-02,
                         -7.02197254e-02,  -3.81149314e-02,  -1.31387450e-02,
                          4.35700640e-03,  -8.30110908e-02,  -6.50468245e-02,
                         -5.65599874e-02,  -5.59813902e-02,   2.43964233e-02,
                          2.58531049e-03,  -1.76110044e-02,  -3.47416289e-02,
                          9.86755416e-02,   6.83054104e-02,   4.82648201e-02,
                          3.78989875e-02,   3.38242389e-02,   3.82515416e-02,
                          4.70053032e-02,   5.82141317e-02,  -7.74801895e-02,
                         -4.46067713e-02,  -1.95106156e-02,  -2.70899758e-03,
                         -7.61591047e-02,  -6.18334264e-02,  -5.62563464e-02,
                         -5.78148849e-02,   3.59248146e-02,   1.12624988e-02,
                         -1.06841363e-02,  -2.83444412e-02,   9.86776650e-02,
                          7.02947229e-02,   5.21390215e-02,   4.36528847e-02,
                          2.25616731e-02,   3.10364440e-02,   4.25830595e-02,
                          5.53968213e-02,  -8.36678445e-02,  -5.04244529e-02,
                         -2.56544054e-02,  -9.84913111e-03,  -6.82335347e-02,
                         -5.77042624e-02,  -5.50385192e-02,  -5.88300265e-02,
                          4.68643196e-02,   1.95706375e-02,  -3.64790484e-03,
                         -2.16182210e-02,   9.72425640e-02,   7.10566565e-02,
                          5.51345311e-02,   4.86831442e-02,   1.09563358e-02,
                          2.32811719e-02,   3.73886116e-02,   5.17205447e-02,
                         -8.87459069e-02,  -5.54432347e-02,  -3.15022916e-02,
                         -1.68308131e-02,  -5.94493710e-02,  -5.26569523e-02,
                         -5.30831106e-02,  -5.90459965e-02,   5.70014827e-02,
                          2.75364108e-02,   3.40672582e-03,  -1.46695599e-02,
                          9.43140537e-02,   7.06136152e-02,   5.72985597e-02,
                          5.28947376e-02,  -8.35485756e-04,   1.50658302e-02,
                          3.15885022e-02,   4.71534729e-02,  -9.25120264e-02,
                         -5.97150847e-02,  -3.69837694e-02,  -2.36636214e-02,
                         -4.97761294e-02,  -4.69309837e-02,  -5.04396893e-02,
                         -5.83914444e-02,   6.62423670e-02,   3.50584984e-02,
                          1.03736147e-02,  -7.48995692e-03,   8.97905678e-02,
                          6.91611394e-02,   5.85640110e-02,   5.62976412e-02,
                         -1.26954950e-02,   6.69750571e-03,   2.52864659e-02,
                          4.18276563e-02,  -9.48262885e-02,  -6.31533563e-02,
                         -4.19096909e-02,  -3.01988684e-02,  -3.93629521e-02,
                         -4.06761803e-02,  -4.70773950e-02,  -5.68919070e-02,
                          7.43995607e-02,   4.20233421e-02,   1.71103179e-02,
                         -1.95145607e-04,   8.39663893e-02,   6.67958781e-02,
                          5.89396246e-02,   5.88500127e-02,  -2.42371559e-02,
                         -1.73419341e-03,   1.87282786e-02,   3.59008722e-02,
                         -9.57108065e-02,  -6.57524019e-02,  -4.61528040e-02,
                         -3.62787060e-02,  -2.84912772e-02,  -3.38353105e-02,
                         -4.30899635e-02,  -5.45815863e-02,   8.13427269e-02,
                          4.83890586e-02,   2.34647505e-02,   7.07077608e-03,
                          7.69535005e-02,   6.34721443e-02,   5.84923103e-02,
                          6.06024824e-02,  -3.53417546e-02,  -1.01343021e-02,
                          1.19611621e-02,   2.95113400e-02,  -9.52124968e-02,
                         -6.73412532e-02,  -4.97014262e-02,  -4.17818278e-02,
                         -1.71918720e-02,  -2.64839455e-02,  -3.84896435e-02,
                         -5.15396111e-02,   8.72004777e-02,   5.40229678e-02,
                          2.95512415e-02,   1.41428225e-02,   6.88680559e-02,
                          5.91720715e-02,   5.71987219e-02,   6.14494681e-02,
                         -4.59720157e-02,  -1.83333382e-02,   5.00491634e-03,
                          2.28536092e-02,  -9.33578536e-02,  -6.78699911e-02,
                         -5.25315516e-02,  -4.65515815e-02,  -5.68005443e-03,
                         -1.87142678e-02,  -3.32709812e-02,  -4.77187373e-02,
                          9.17954072e-02,   5.88748232e-02,   3.52146365e-02,
                          2.09207870e-02,   5.98351434e-02,   5.40005043e-02,
                          5.50639406e-02,   6.13138899e-02,  -5.58671840e-02,
                         -2.63606682e-02,  -2.06162408e-03,   1.57777630e-02,
                         -9.01723504e-02,  -6.74788356e-02,  -5.46430610e-02,
                         -5.06552160e-02,   5.83313778e-03,  -1.06214210e-02,
                         -2.76082121e-02,  -4.31314483e-02,   9.50181484e-02,
                          6.29451647e-02,   4.04027142e-02,   2.75205113e-02,
                          5.00276983e-02,   4.80876677e-02,   5.22327237e-02,
                          6.03359528e-02,  -6.48968965e-02,  -3.39696631e-02,
                         -9.01952758e-03,   8.45760480e-03,  -8.56874734e-02,
                         -6.60578758e-02,  -5.59389666e-02,  -5.40572144e-02,
                          1.72674321e-02,  -2.42223963e-03,  -2.15616934e-02,
                         -3.79584506e-02,   9.69193131e-02,   6.60133362e-02,
                          4.49590012e-02,   3.37150991e-02,   3.94989252e-02,
                          4.15112488e-02,   4.85928506e-02,   5.85781150e-02,
                         -7.30243623e-02,  -4.09780592e-02,  -1.59006007e-02,
                          1.03112683e-03,  -8.00292119e-02,  -6.37317672e-02,
                         -5.64160831e-02,  -5.67772873e-02,   2.84446701e-02,
                          5.68565354e-03,  -1.51509941e-02,  -3.23277041e-02,
                          9.74347442e-02,   6.81323111e-02,   4.89185117e-02,
                          3.94686423e-02,   2.83849537e-02,   3.44255678e-02,
                          4.42677550e-02,   5.60409017e-02,  -8.01347196e-02,
                         -4.74092737e-02,  -2.25810669e-02,  -6.39855117e-03,
                         -7.31604397e-02,  -6.05067760e-02,  -5.61444573e-02,
                         -5.87104037e-02,   3.92711163e-02,   1.37360655e-02,
                         -8.57128575e-03,  -2.61921622e-02,   9.65940356e-02,
                          6.93268180e-02,   5.22158481e-02,   4.46723551e-02,
                          1.68069638e-02,   2.67623812e-02,   3.93025205e-02,
                          5.25989905e-02,  -8.62009674e-02,  -5.32107539e-02,
                         -2.89128944e-02,  -1.37556382e-02,  -6.52884990e-02,
                         -5.63765913e-02,  -5.50245233e-02,  -5.96887805e-02,
                          4.96631972e-02,   2.17088014e-02,  -1.77180767e-03,
                         -1.96395963e-02,   9.44578052e-02,   6.95160553e-02,
                          5.47633804e-02,   4.91660945e-02,   4.99028340e-03,
                          1.86836869e-02,   3.37110013e-02,   4.84301783e-02,
                         -9.10338685e-02,  -5.82087450e-02,  -3.48754227e-02,
                         -2.08206847e-02,  -5.64795695e-02,  -5.14221936e-02,
                         -5.30986451e-02,  -5.97735494e-02,   5.93698211e-02,
                          2.94300094e-02,   5.16120344e-03,  -1.27774663e-02,
                          9.10236686e-02,   6.88200891e-02,   5.66324443e-02,
                          5.30065298e-02,  -6.83649257e-03,   1.04074329e-02,
                          2.77814455e-02,   4.36253361e-02,  -9.44913477e-02,
                         -6.24550916e-02,  -4.02932502e-02,  -2.76202522e-02,
                         -4.67639156e-02,  -4.56940308e-02,  -5.04220016e-02,
                         -5.89884631e-02,   6.82231933e-02,   3.68350185e-02,
                          1.19086355e-02,  -5.62550500e-03,   8.62239227e-02,
                          6.71985373e-02,   5.76567352e-02,   5.61904982e-02,
                         -1.85641237e-02,   1.96248293e-03,   2.15271413e-02,
                          3.81780714e-02,  -9.65013951e-02,  -6.57827556e-02,
                         -4.49908301e-02,  -3.40142809e-02,  -3.62626277e-02,
                         -3.92319933e-02,  -4.69024926e-02,  -5.72922304e-02,
                          7.61529654e-02,   4.37219776e-02,   1.85134225e-02,
                          1.55699253e-03,   8.01148042e-02,   6.45220280e-02,
                          5.78228794e-02,   5.85417412e-02,  -3.00451815e-02,
                         -6.49633631e-03,   1.48903206e-02,   3.22765559e-02,
                         -9.70641673e-02,  -6.79446980e-02,  -4.90109436e-02,
                         -3.97632532e-02,  -2.51671486e-02,  -3.20893526e-02,
                         -4.26553711e-02,  -5.47857434e-02,   8.30052346e-02,
                          4.98887412e-02,   2.49571018e-02,   8.72148573e-03,
                          7.29091316e-02,   6.08620271e-02,   5.72041050e-02,
                          6.01014160e-02,  -4.10502478e-02,  -1.47872157e-02,
                          8.06112960e-03,   2.59759389e-02,  -9.61274356e-02,
                         -6.90704733e-02,  -5.23374006e-02,  -4.50254232e-02,
                         -1.36594288e-02,  -2.44621970e-02,  -3.77006792e-02,
                         -5.14664054e-02,   8.86019170e-02,   5.53724058e-02,
                          3.10734138e-02,   1.59021355e-02,   6.45824522e-02,
                          5.64055778e-02,   5.57287075e-02,   6.08666167e-02,
                         -5.14423065e-02,  -2.28509344e-02,   1.06386468e-03,
                          1.91727430e-02,  -9.37262326e-02,  -6.92054331e-02,
                         -5.48451170e-02,  -4.96621802e-02,  -1.87044963e-03,
                         -1.65152662e-02,  -3.21630500e-02,  -4.72889580e-02,
                          9.29219350e-02,   6.00156635e-02,   3.67307030e-02,
                          2.28789039e-02,   5.52332401e-02,   5.10642976e-02,
                          5.34124263e-02,   6.05970137e-02,  -6.10900484e-02,
                         -3.05633731e-02,  -5.92494383e-03,   1.20422207e-02,
                         -8.99159014e-02,  -6.82113990e-02,  -5.65303452e-02,
                         -5.34249097e-02,   9.88924876e-03,  -8.18720460e-03,
                         -2.61644870e-02,  -4.23332602e-02,   9.58039910e-02,
                          6.37187660e-02,   4.18174267e-02,   2.94235125e-02,
                          4.51146439e-02,   4.48044837e-02,   5.03032543e-02,
                          5.93399219e-02,  -6.97480142e-02,  -3.78846228e-02,
                         -1.27980150e-02,   4.77191433e-03,  -8.47366303e-02,
                         -6.62045702e-02,  -5.73710985e-02,  -5.63503392e-02,
                          2.14472488e-02,   2.68835574e-04,  -1.98147930e-02,
                         -3.67594026e-02,   9.71796662e-02,   6.65194839e-02,
                          4.61892262e-02,   3.55033167e-02,   3.43213342e-02,
                          3.79717462e-02,   4.64585125e-02,   5.72486222e-02,
                         -7.73434788e-02,  -4.46099266e-02,  -1.94040127e-02,
                         -2.59885564e-03,  -7.83335343e-02,  -6.33109212e-02,
                         -5.73189184e-02,  -5.85265346e-02,   3.26871537e-02,
                          8.54304060e-03,  -1.32367909e-02,  -3.06869261e-02,
                          9.71344262e-02,   6.83516860e-02,   4.98440564e-02,
                          4.11407724e-02,   2.30434090e-02,   3.06970701e-02,
                          4.18885946e-02,   5.43446280e-02,  -8.37833732e-02,
                         -5.06468639e-02,  -2.57427953e-02,  -9.94231924e-03,
                         -7.08103776e-02,  -5.95240071e-02,  -5.64741790e-02,
                         -5.98852634e-02,   4.33648750e-02,   1.66894197e-02,
                         -6.40353188e-03,  -2.41855904e-02,   9.56613570e-02,
                          6.91369623e-02,   5.28996103e-02,   4.61270064e-02,
                          1.14419423e-02,   2.29340605e-02,   3.67241092e-02,
                          5.06295413e-02,  -8.89986306e-02,  -5.58983646e-02,
                         -3.18333656e-02,  -1.70777105e-02,  -6.22267239e-02,
                         -5.48042729e-02,  -5.48657104e-02,  -6.03000075e-02,
                          5.34271896e-02,   2.45662630e-02,   5.18858433e-04,
                         -1.73948891e-02,   9.27777961e-02,   6.88582212e-02,
                          5.52011319e-02,   5.03567830e-02,  -3.40156257e-04,
                          1.48241594e-02,   3.10259871e-02,   4.61920425e-02,
                         -9.29430574e-02,  -6.03052862e-02,  -3.73871513e-02,
                         -2.38909684e-02,  -5.27749807e-02,  -4.92970385e-02,
                         -5.23507930e-02,  -5.98229654e-02,   6.27403781e-02,
                          3.20682116e-02,   7.42227212e-03,  -1.03098527e-02,
                          8.86210799e-02,   6.76398873e-02,   5.65418713e-02,
                          5.38972951e-02,  -1.20509975e-02,   6.60333037e-03,
                          2.48645879e-02,   4.10831124e-02,  -9.54806954e-02,
                         -6.38895333e-02,  -4.23229486e-02,  -3.04297879e-02,
                         -4.25614081e-02,  -4.31266129e-02,  -4.90460917e-02,
                         -5.84609769e-02,   7.11208284e-02,   3.92012633e-02,
                          1.42303184e-02,  -3.00512835e-03,   8.31572264e-02,
                          6.54858872e-02,   5.71398623e-02,   5.66981994e-02,
                         -2.35750116e-02,  -1.76370889e-03,   1.84241831e-02,
                          3.53705585e-02,  -9.66255218e-02,  -6.65324479e-02,
                         -4.66420874e-02,  -3.64968367e-02,  -3.17422152e-02,
                         -3.63255888e-02,  -4.51625399e-02,  -5.62679283e-02,
                          7.84284398e-02,   4.57385108e-02,   2.07913630e-02,
                          4.26400080e-03,   7.65572339e-02,   6.24066629e-02,
                          5.70131317e-02,   5.86559698e-02,  -3.46762687e-02,
                         -1.00716650e-02,   1.17701180e-02,   2.92809382e-02,
                         -9.64554548e-02,  -6.82376623e-02,  -5.03914356e-02,
                         -4.19804864e-02,  -2.05272809e-02,  -2.89861895e-02,
                         -4.05914485e-02,  -5.33513837e-02,   8.46658796e-02,
                          5.15847392e-02,   2.71529555e-02,   1.14149004e-02,
                          6.89181983e-02,   5.84736131e-02,   5.60831092e-02,
                          5.98596297e-02,  -4.52738777e-02,  -1.81580260e-02,
                          4.85781953e-03,   2.27989219e-02,  -9.48969573e-02,
                         -6.89414293e-02,  -5.33725098e-02,  -4.69049662e-02,
                         -9.05230269e-03,  -2.13283710e-02,  -3.54027189e-02,
                         -4.96766120e-02,   8.97378102e-02,   5.67565113e-02,
                          3.31409760e-02,   1.85022503e-02,   6.03004061e-02,
                          5.37468307e-02,   5.42668141e-02,   6.02098592e-02,
                         -5.53258955e-02,  -2.60855407e-02,  -2.17045844e-03,
                          1.58719271e-02,  -9.19477344e-02,  -6.86974376e-02,
                         -5.54911643e-02,  -5.11738174e-02,   2.69931927e-03,
                         -1.32884309e-02,  -2.96528973e-02,  -4.51832376e-02,
                          9.35088545e-02,   6.11289479e-02,   3.85411121e-02,
                          2.53508277e-02,   5.07737808e-02,   4.82561439e-02,
                          5.16949594e-02,   5.96726276e-02,  -6.46195114e-02,
                         -3.36877070e-02,  -9.10246745e-03,   8.68602842e-03,
                         -8.77955109e-02,  -6.75546676e-02,  -5.69689274e-02,
                         -5.47958277e-02,   1.43943913e-02,  -4.98870388e-03,
                         -2.35386863e-02,  -4.00787517e-02,   9.59615558e-02,
                          6.45879656e-02,   4.34061214e-02,   3.17792743e-02,
                          4.04551364e-02,   4.18833904e-02,   4.83527631e-02,
                          5.82338981e-02,  -7.29349107e-02,  -4.07840833e-02,
                         -1.58757046e-02,   1.41493231e-03,  -8.23851377e-02,
                         -6.53561354e-02,  -5.75790517e-02,  -5.75511381e-02,
                          2.57599242e-02,   3.34031135e-03,  -1.71261951e-02,
                         -3.44064236e-02,   9.70675796e-02,   6.71694055e-02,
                          4.76923548e-02,   3.77836004e-02,   2.96072103e-02,
                          3.49389911e-02,   4.42557782e-02,   5.58954775e-02,
                         -8.02759826e-02,  -4.73244339e-02,  -2.25016326e-02,
                         -5.94789907e-03,  -7.56765604e-02,  -6.21944703e-02,
                         -5.72892465e-02,  -5.94828241e-02,   3.68665047e-02,
                          1.16040036e-02,  -1.04503818e-02,  -2.82516070e-02,
                          9.66793150e-02,   6.87353015e-02,   5.12152649e-02,
                          4.32254188e-02,   1.82135105e-02,   2.75194645e-02,
                          3.95564511e-02,   5.27969152e-02,  -8.65295678e-02,
                         -5.32119647e-02,  -2.88070515e-02,  -1.32415667e-02,
                         -6.78940341e-02,  -5.81768043e-02,  -5.62193766e-02,
                         -6.06195107e-02,   4.75307293e-02,   1.97754949e-02,
                         -3.55858728e-03,  -2.16486305e-02,   9.48925465e-02,
                          6.92847520e-02,   5.39675802e-02,   4.80482318e-02,
                          6.45058230e-03,   1.95492022e-02,   3.41781825e-02,
                          4.88788597e-02,  -9.14837867e-02,  -5.83787933e-02,
                         -3.47203799e-02,  -2.03545019e-02,  -5.90588860e-02,
                         -5.32460921e-02,  -5.43347113e-02,  -6.08405434e-02,
                          5.74244782e-02,   2.76176892e-02,   3.34562361e-03,
                         -1.47447512e-02,   9.16958600e-02,   6.87978789e-02,
                          5.59837706e-02,   5.21615557e-02,  -5.35311550e-03,
                          1.13829821e-02,   2.83396840e-02,   4.42108214e-02,
                         -9.51152816e-02,  -6.26077503e-02,  -4.01279107e-02,
                         -2.71931030e-02,  -4.93112504e-02,  -4.74922135e-02,
                         -5.16098179e-02,  -6.00483082e-02,   6.64754510e-02,
                          3.49870250e-02,   1.01921707e-02,  -7.57068396e-03,
                          8.70102346e-02,   6.71589971e-02,   5.70968240e-02,
                          5.53535558e-02,  -1.70033835e-02,   3.10231373e-03,
                          2.21261084e-02,   3.88487354e-02,  -9.72228795e-02,
                         -6.58580065e-02,  -4.48848046e-02,  -3.35472785e-02,
                         -3.89143527e-02,  -4.10926305e-02,  -4.81734052e-02,
                         -5.83940558e-02,   7.45394379e-02,   4.19797115e-02,
                          1.69209652e-02,  -2.76509672e-04,   8.09625983e-02,
                          6.45440668e-02,   5.73298484e-02,   5.77059910e-02,
                         -2.85303965e-02,  -5.39428741e-03,   1.55624337e-02,
                          3.29236574e-02,  -9.76764411e-02,  -6.80459142e-02,
                         -4.88321893e-02,  -3.92951854e-02,  -2.79044881e-02,
                         -3.40561941e-02,  -4.40330207e-02,  -5.59075586e-02,
                          8.13281685e-02,   4.81730811e-02,   2.32387595e-02,
                          6.88333437e-03,   7.38763511e-02,   6.10655285e-02,
                          5.68084270e-02,   5.93427867e-02,  -3.95413749e-02,
                         -1.37133598e-02,   8.78295675e-03,   2.65894569e-02,
                         -9.68580619e-02,  -6.93031177e-02,  -5.21639697e-02,
                         -4.45351489e-02,  -1.64527744e-02,  -2.64895856e-02,
                         -3.91721800e-02,  -5.26047423e-02,   8.68892670e-02,
                          5.35933450e-02,   2.92223953e-02,   1.39326826e-02,
                          6.57589436e-02,   5.67092635e-02,   5.54228127e-02,
                          6.01216443e-02,  -4.97819670e-02,  -2.16847621e-02,
                          1.93282589e-03,   1.99331827e-02,  -9.46991295e-02,
                         -6.95513561e-02,  -5.47269098e-02,  -4.91639413e-02,
                         -4.87164035e-03,  -1.86246485e-02,  -3.37470695e-02,
                         -4.85424660e-02,   9.13276002e-02,   5.83549179e-02,
                          3.48787755e-02,   2.08522379e-02,   5.66394515e-02,
                          5.15251905e-02,   5.31648919e-02,   5.99264540e-02,
                         -5.93483411e-02,  -2.93258876e-02,  -4.91686538e-03,
                          1.29832402e-02,  -9.10556167e-02,  -6.87590912e-02,
                         -5.64337149e-02,  -5.29304147e-02,   6.70862943e-03,
                         -1.05416663e-02,  -2.78838798e-02,  -4.37807478e-02,
                          9.43611562e-02,   6.22080788e-02,   3.99613418e-02,
                          2.73369476e-02,   4.68534194e-02,   4.56599854e-02,
                          5.02569005e-02,   5.89209646e-02,  -6.80234283e-02,
                         -3.65365073e-02,  -1.16766505e-02,   5.88523969e-03,
                         -8.62295777e-02,  -6.69724196e-02,  -5.73833100e-02,
                         -5.59883974e-02,   1.81796253e-02,  -2.27559358e-03,
                         -2.16566771e-02,  -3.84005494e-02,   9.60174650e-02,
                          6.50752485e-02,   4.44430970e-02,   3.34366709e-02,
                          3.63477357e-02,   3.90312597e-02,   4.65932377e-02,
                          5.70191555e-02,  -7.55868256e-02,  -4.31118496e-02,
                         -1.81983784e-02,  -1.21283531e-03,  -8.01984966e-02,
                         -6.42923713e-02,  -5.75501323e-02,  -5.82511798e-02,
                          2.91607827e-02,   5.83850220e-03,  -1.52123012e-02,
                         -3.26095186e-02,   9.63868424e-02,   6.71568364e-02,
                          4.82906811e-02,   3.90767828e-02,   2.54524946e-02,
                          3.20060551e-02,   4.23195437e-02,   5.44179641e-02,
                         -8.21343064e-02,  -4.92228679e-02,  -2.44719051e-02,
                         -8.34944844e-03,  -7.29693770e-02,  -6.06707186e-02,
                         -5.68318963e-02,  -5.96587881e-02,   3.96870188e-02,
                          1.38449669e-02,  -8.65234435e-03,  -2.63946466e-02,
                          9.53086689e-02,   6.82239756e-02,   5.14382608e-02,
                          4.41040248e-02,   1.43749453e-02,   2.47173570e-02,
                          3.75834629e-02,   5.11248522e-02,  -8.76255184e-02,
                         -5.46256378e-02,  -3.04255709e-02,  -1.53513625e-02,
                         -6.49154484e-02,  -5.63825369e-02,  -5.54060824e-02,
                         -6.03204258e-02,   4.97949608e-02,   2.17140391e-02,
                         -1.88734755e-03,  -1.97730847e-02,   9.29038525e-02,
                          6.82744235e-02,   5.38025722e-02,   4.84870225e-02,
                          3.10448557e-03,   1.70476548e-02,   3.23013254e-02,
                          4.71163727e-02,  -9.17604938e-02,  -5.90804182e-02,
                         -3.58599871e-02,  -2.20557377e-02,  -5.61569445e-02,
                         -5.14059439e-02,  -5.33531085e-02,  -6.02459162e-02,
                          5.91169707e-02,   2.91373245e-02,   4.82504070e-03,
                         -1.29324421e-02,   8.93949717e-02,   6.75049573e-02,
                          5.55319674e-02,   5.22270426e-02,  -8.32726434e-03,
                          9.07019526e-03,   2.65023224e-02,   4.23896462e-02,
                         -9.46599990e-02,  -6.27956167e-02,  -4.08362001e-02,
                         -2.84551680e-02,  -4.65706661e-02,  -4.56335843e-02,
                         -5.04971221e-02,  -5.93086146e-02,   6.74920976e-02,
                          3.61129642e-02,   1.13853961e-02,  -6.05649501e-03,
                          8.46990943e-02,   6.57806769e-02,   5.65024205e-02,
                          5.52750118e-02,  -1.95387974e-02,   1.03287399e-03,
                          2.04143897e-02,   3.71926874e-02,  -9.64666307e-02,
                         -6.57543987e-02,  -4.53369729e-02,  -3.44957225e-02,
                         -3.63780931e-02,  -3.93151157e-02,  -4.69737314e-02,
                         -5.75816520e-02,   7.50563219e-02,   4.26117033e-02,
                          1.78204142e-02,   9.12070274e-04,   7.88348988e-02,
                          6.31570220e-02,   5.65828495e-02,   5.74962832e-02,
                         -3.04712988e-02,  -6.98722526e-03,   1.40239038e-02,
                          3.14642750e-02,  -9.69531387e-02,  -6.78274781e-02,
                         -4.91895080e-02,  -4.00842056e-02,  -2.57648751e-02,
                         -3.25434990e-02,  -4.28753234e-02,  -5.51077016e-02,
                          8.16298127e-02,   4.85822745e-02,   2.40169279e-02,
                          7.88424164e-03,   7.19407424e-02,   5.97768202e-02,
                          5.60137890e-02,   5.89995310e-02,  -4.11068648e-02,
                         -1.50293820e-02,   7.42095709e-03,   2.52715982e-02,
                         -9.61254835e-02,  -6.90566823e-02,  -5.24350442e-02,
                         -4.51705493e-02,  -1.47179849e-02,  -2.52485499e-02,
                         -3.81928273e-02,  -5.18551432e-02,   8.69897678e-02,
                          5.38663678e-02,   2.98179574e-02,   1.47297047e-02,
                          6.40928894e-02,   5.56112006e-02,   5.47389910e-02,
                          5.97263537e-02,  -5.10167740e-02,  -2.27350518e-02,
                          8.43700022e-04,   1.87951662e-02,  -9.41482410e-02,
                         -6.94612265e-02,  -5.50450273e-02,  -4.97494973e-02,
                         -3.57874855e-03,  -1.77437179e-02,  -3.30823399e-02,
                         -4.80127782e-02,   9.13279206e-02,   5.85299022e-02,
                          3.53411287e-02,   2.14662217e-02,   5.52210212e-02,
                          5.05586825e-02,   5.26268184e-02,   5.96361980e-02,
                         -6.03336021e-02,  -3.01534422e-02,  -5.80466911e-03,
                          1.20727606e-02,  -9.07521993e-02,  -6.87487423e-02,
                         -5.68138510e-02,  -5.35561889e-02,   7.57805258e-03,
                         -1.00268461e-02,  -2.75176130e-02,  -4.35622595e-02,
                          9.44298431e-02,   6.23177998e-02,   4.03315499e-02,
                          2.78344005e-02,   4.56906632e-02,   4.48994748e-02,
                          4.98279370e-02,   5.86844422e-02,  -6.89479262e-02,
                         -3.72859873e-02,  -1.24402978e-02,   5.10879606e-03,
                         -8.60308185e-02,  -6.70671016e-02,  -5.77459000e-02,
                         -5.65245189e-02,   1.86788589e-02,  -2.05659866e-03,
                         -2.15611123e-02,  -3.83975208e-02,   9.59975868e-02,
                          6.51287958e-02,   4.45942730e-02,   3.37100513e-02,
                          3.55971940e-02,   3.86299901e-02,   4.63778712e-02,
                          5.69162183e-02,  -7.64326602e-02,  -4.38221879e-02,
                         -1.88387036e-02,  -1.90425292e-03,  -8.01794380e-02,
                         -6.44867644e-02,  -5.79141565e-02,  -5.87680489e-02,
                          2.95449235e-02,   5.95099851e-03,  -1.52614117e-02,
                         -3.27112228e-02,   9.62832868e-02,   6.70676008e-02,
                          4.83304486e-02,   3.91573943e-02,   2.49486603e-02,
                          3.17305513e-02,   4.21897881e-02,   5.43793254e-02,
                         -8.27709958e-02,  -4.97011244e-02,  -2.49605440e-02,
                         -8.75399262e-03,  -7.32751414e-02,  -6.10277429e-02,
                         -5.72490655e-02,  -6.01722784e-02,   3.98756154e-02,
                          1.37825944e-02,  -8.79101828e-03,  -2.66261995e-02,
                          9.52971429e-02,   6.80875182e-02,   5.13746180e-02,
                          4.40525934e-02,   1.40181780e-02,   2.44469717e-02,
                          3.74191068e-02,   5.10210991e-02,  -8.80584493e-02,
                         -5.48593961e-02,  -3.07459421e-02,  -1.56440921e-02,
                         -6.53890222e-02,  -5.67955896e-02,  -5.59647568e-02,
                         -6.08406030e-02,   4.96595241e-02,   2.13740915e-02,
                         -2.24297866e-03,  -2.01566480e-02,   9.29859951e-02,
                          6.82107210e-02,   5.38179837e-02,   4.84210402e-02,
                          2.93880329e-03,   1.70203187e-02,   3.23603377e-02,
                          4.71033044e-02,  -9.20963585e-02,  -5.93155064e-02,
                         -3.61142531e-02,  -2.21683532e-02,  -5.67008704e-02,
                         -5.19304425e-02,  -5.39219081e-02,  -6.06188551e-02,
                          5.87306283e-02,   2.86727473e-02,   4.34570760e-03,
                         -1.34853572e-02,   8.94954354e-02,   6.75191283e-02,
                          5.55389971e-02,   5.19805625e-02,  -8.08927417e-03,
                          9.32821631e-03,   2.66703479e-02,   4.25076038e-02,
                         -9.48656425e-02,  -6.28360510e-02,  -4.09102440e-02,
                         -2.82673538e-02,  -4.72479835e-02,  -4.62352335e-02,
                         -5.10883667e-02,  -5.95504157e-02,   6.67997599e-02,
                          3.53684835e-02,   1.07666999e-02,  -6.69209287e-03,
                          8.48746747e-02,   6.57806098e-02,   5.63479252e-02,
                          5.48608378e-02,  -1.89563520e-02,   1.48367882e-03,
                          2.07540207e-02,   3.73494849e-02,  -9.64675546e-02,
                         -6.55929744e-02,  -4.50670533e-02,  -3.41145620e-02,
                         -3.72686088e-02,  -4.00180928e-02,  -4.74041328e-02,
                         -5.77198230e-02,   7.41992742e-02,   4.17412594e-02,
                          1.70202181e-02,   9.46968794e-05,   7.91465491e-02,
                          6.32111728e-02,   5.63945360e-02,   5.70672266e-02,
                         -2.94259787e-02,  -6.13202527e-03,   1.45565718e-02,
                          3.18923816e-02,  -9.67966765e-02,  -6.75796643e-02,
                         -4.87689860e-02,  -3.95574160e-02,  -2.69034356e-02,
                         -3.34181413e-02,  -4.32802103e-02,  -5.53144328e-02,
                          8.05640966e-02,   4.76338863e-02,   2.32566446e-02,
                          6.99098408e-03,   7.24247694e-02,   5.99991493e-02,
                          5.59678338e-02,   5.86984791e-02,  -3.96188609e-02,
                         -1.39266849e-02,   8.18088278e-03,   2.59969607e-02,
                         -9.60044563e-02,  -6.87508732e-02,  -5.20114414e-02,
                         -4.45305295e-02,  -1.63346119e-02,  -2.63994373e-02,
                         -3.88108194e-02,  -5.22660166e-02,   8.59120190e-02,
                          5.28755523e-02,   2.89443322e-02,   1.37198865e-02,
                          6.49726838e-02,   5.58775105e-02,   5.46502322e-02,
                          5.93492202e-02,  -4.92893867e-02,  -2.14512646e-02,
                          1.82319805e-03,   1.96211934e-02,  -9.39614773e-02,
                         -6.89121485e-02,  -5.43392077e-02,  -4.86927330e-02,
                         -5.45489788e-03,  -1.89329758e-02,  -3.37833166e-02,
                         -4.83046733e-02,   9.00935382e-02,   5.74499033e-02,
                          3.43432985e-02,   2.03075148e-02,   5.65354899e-02,
                          5.12691177e-02,   5.28301895e-02,   5.93529977e-02,
                         -5.83150312e-02,  -2.85906941e-02,  -4.49717045e-03,
                          1.31396316e-02,  -9.06961560e-02,  -6.83641583e-02,
                         -5.60530983e-02,  -5.24359271e-02,   5.50393388e-03,
                         -1.14102848e-02,  -2.83504203e-02,  -4.39453609e-02,
                          9.30889994e-02,   6.10872209e-02,   3.89836580e-02,
                          2.64493786e-02,   4.72654626e-02,   4.58391123e-02,
                          5.00121042e-02,   5.84468693e-02,  -6.66192621e-02,
                         -3.54733914e-02,  -1.09212175e-02,   6.45907223e-03,
                         -8.61385912e-02,  -6.67923689e-02,  -5.69972992e-02,
                         -5.53855188e-02,   1.64329559e-02,  -3.58484685e-03,
                         -2.25267597e-02,  -3.88691798e-02,   9.50839221e-02,
                          6.41836077e-02,   4.35380228e-02,   3.24241556e-02,
                          3.75999250e-02,   3.97789553e-02,   4.67961393e-02,
                          5.69799431e-02,  -7.41121247e-02,  -4.19059731e-02,
                         -1.72922239e-02,  -3.72610986e-04,  -8.06968063e-02,
                         -6.44554347e-02,  -5.73221780e-02,  -5.77926561e-02,
                          2.71726698e-02,   4.26248088e-03,  -1.62706636e-02,
                         -3.34577002e-02,   9.57887322e-02,   6.63325191e-02,
                          4.74639274e-02,   3.79453562e-02,   2.73371600e-02,
                          3.33465189e-02,   4.30058464e-02,   5.47334626e-02,
                         -8.06868225e-02,  -4.77592498e-02,  -2.32577883e-02,
                         -6.90905005e-03,  -7.41759539e-02,  -6.11960515e-02,
                         -5.68018518e-02,  -5.92216924e-02,   3.75785753e-02,
                          1.21202283e-02,  -9.87149402e-03,  -2.75351778e-02,
                          9.53465551e-02,   6.76648170e-02,   5.05206026e-02,
                          4.28543985e-02,   1.66065432e-02,   2.62253210e-02,
                          3.84460650e-02,   5.17232791e-02,  -8.64237249e-02,
                         -5.32251932e-02,  -2.90411785e-02,  -1.37463361e-02,
                         -6.68952018e-02,  -5.75915389e-02,  -5.56971990e-02,
                         -6.02354482e-02,   4.74250540e-02,   1.95299163e-02,
                         -3.51326168e-03,  -2.15043798e-02,   9.35433656e-02,
                          6.82057142e-02,   5.32649085e-02,   4.73727323e-02,
                          5.73290139e-03,   1.89454556e-02,   3.35283540e-02,
                          4.81372066e-02,  -9.08087045e-02,  -5.80362640e-02,
                         -3.45454216e-02,  -2.02036276e-02,  -5.83577640e-02,
                         -5.28028011e-02,  -5.39654195e-02,  -6.03548288e-02,
                          5.68726324e-02,   2.72128694e-02,   3.16110998e-03,
                         -1.49193145e-02,   9.07250792e-02,   6.81143403e-02,
                          5.53182960e-02,   5.14283329e-02,  -5.18853590e-03,
                          1.13576129e-02,   2.81398036e-02,   4.38997336e-02,
                         -9.40453112e-02,  -6.20376058e-02,  -3.96764576e-02,
                         -2.66644359e-02,  -4.92114536e-02,  -4.74617630e-02,
                         -5.14488220e-02,  -5.96368723e-02,   6.53920472e-02,
                          3.44794542e-02,   9.66179371e-03,  -8.00854340e-03,
                          8.62923637e-02,   6.68536425e-02,   5.65685332e-02,
                          5.47592640e-02,  -1.63548701e-02,   3.55178118e-03,
                          2.23219059e-02,   3.92301530e-02,  -9.63771492e-02,
                         -6.52651489e-02,  -4.41656671e-02,  -3.26511264e-02,
                         -3.94064561e-02,  -4.14752215e-02,  -4.80977967e-02,
                         -5.83088584e-02,   7.34310895e-02,   4.10875529e-02,
                          1.63480490e-02,  -9.58818942e-04,   8.11537057e-02,
                          6.47728443e-02,   5.73821068e-02,   5.74952960e-02,
                         -2.72404738e-02,  -4.19433415e-03,   1.64971091e-02,
                          3.37548181e-02,  -9.71086919e-02,  -6.74339682e-02,
                         -4.81776185e-02,  -3.83817442e-02,  -2.90388279e-02,
                         -3.45947035e-02,  -4.44223769e-02,  -5.61204329e-02,
                          8.04124400e-02,   4.74425778e-02,   2.25468054e-02,
                          6.01015612e-03,   7.47456998e-02,   6.16357736e-02,
                          5.69902323e-02,   5.93828969e-02,  -3.77797000e-02,
                         -1.22640841e-02,   9.91973281e-03,   2.78069824e-02,
                         -9.66166332e-02,  -6.88039064e-02,  -5.15648797e-02,
                         -4.33971919e-02,  -1.77720934e-02,  -2.74745189e-02,
                         -3.95823531e-02,  -5.29912859e-02,   8.61844942e-02,
                          5.28500229e-02,   2.86304951e-02,   1.29492432e-02,
                          6.71072304e-02,   5.76808862e-02,   5.57711758e-02,
                          6.01723120e-02,  -4.78709005e-02,  -2.00239681e-02,
                          3.23057920e-03,   2.13586837e-02,  -9.48811620e-02,
                         -6.95609525e-02,  -5.42856753e-02,  -4.82568219e-02,
                         -6.04628548e-02,  -6.59178719e-02,  -7.53075629e-02,
                         -8.73937756e-02,  -4.65573072e-02,  -6.63887113e-02,
                         -8.27155858e-02,  -9.49131846e-02,  -6.42624795e-02,
                         -7.45642632e-02,  -8.03101361e-02,  -8.14675391e-02,
                         -6.04674779e-02,  -5.95545955e-02,  -5.65867759e-02,
                         -5.20395078e-02,  -4.56250757e-02,  -4.01166826e-02,
                         -3.47238965e-02,  -2.98492312e-02,  -2.81882286e-02,
                         -2.40989290e-02,  -2.07523741e-02,  -1.82299763e-02,
                         -1.67049989e-02,  -1.56096816e-02,  -1.53046586e-02,
                         -1.52473785e-02,  -1.20259114e-02,  -1.30712837e-02,
                         -1.45049654e-02,  -1.52924173e-02,  -1.20454021e-02,
                         -1.31337009e-02,  -1.46698430e-02,  -1.50175802e-02,
                         -1.19690374e-02,  -1.24663971e-02,  -1.28632300e-02,
                         -1.28367841e-02,  -9.95193049e-03,  -9.89635661e-03,
                         -9.53305513e-03,  -9.45319235e-03,  -7.98600912e-03,
                         -7.75426999e-03,  -7.29246438e-03,  -6.92695752e-03,
                         -6.14834577e-03,  -5.99782169e-03,  -6.08749688e-03,
                         -5.66234440e-03,  -4.99720499e-03,  -4.85168025e-03,
                         -5.19063696e-03,  -4.78933007e-03,  -3.81932408e-03,
                         -3.71741131e-03,  -3.69520113e-03,  -3.55781615e-03,
                         -9.22948122e-04,  -9.90837812e-04,  -9.64485109e-04,
                         -8.49235803e-04,   3.56361270e-03,   3.14325839e-03,
                          2.71613523e-03,   2.71069631e-03,   7.41439685e-03,
                          7.12491199e-03,   6.42892718e-03,   6.67496398e-03,
                          1.01740398e-02,   1.01350173e-02,   9.94746387e-03,
                          1.01975985e-02,   1.20368935e-02,   1.24205761e-02,
                          1.25906505e-02,   1.31978989e-02,   1.36856996e-02,
                          1.42054260e-02,   1.45704225e-02,   1.49796382e-02,
                          1.49139389e-02,   1.54456310e-02,   1.55431107e-02,
                          1.56896934e-02,   1.55919977e-02,   1.57799870e-02,
                          1.54046230e-02,   1.55015737e-02,   1.54301934e-02,
                          1.54313371e-02,   1.49001442e-02,   1.50251687e-02,
                          1.47130191e-02,   1.47744715e-02,   1.45493522e-02,
                          1.46878473e-02,   1.43054612e-02,   1.44569278e-02,
                          1.42680854e-02,   1.43537819e-02,   1.41416043e-02,
                          1.44014433e-02,   1.41631141e-02,   1.43033229e-02,
                          1.41140223e-02,   1.42221339e-02,   1.42595284e-02,
                          1.43408291e-02,   1.40884779e-02,   1.43225566e-02,
                          1.42167509e-02,   1.44138820e-02,   1.40976086e-02,
                          1.42326355e-02,   1.40892565e-02,   1.43196732e-02,
                          1.38116591e-02,   1.40821338e-02,   1.39636546e-02,
                          1.40491426e-02,   1.37128644e-02,   1.38588548e-02,
                          1.37831308e-02,   1.37108043e-02,   1.33909881e-02,
                          1.34316608e-02,   1.33673027e-02,   1.34673342e-02,
                          1.29818767e-02,   1.31103285e-02,   1.29778795e-02,
                          1.31209977e-02,   1.23892017e-02,   1.27369836e-02,
                          1.25893950e-02,   1.27069429e-02,   1.21031143e-02,
                          1.21125691e-02,   1.21717602e-02,   1.21912397e-02,
                          1.15192346e-02,   1.16025358e-02,   1.17349774e-02,
                          1.16602071e-02,   1.08398087e-02,   1.10721476e-02,
                          1.09613501e-02,   1.10453293e-02,   1.00454800e-02,
                          1.01820491e-02,   1.00930184e-02,   1.01088285e-02,
                          9.21162218e-03,   9.39445943e-03,   9.19478759e-03,
                          9.25572589e-03,   8.17111507e-03,   8.33911821e-03,
                          8.21845233e-03,   8.26570019e-03,   7.23338872e-03,
                          7.29283690e-03,   7.23427534e-03,   7.23578781e-03,
                          6.17078319e-03,   6.21778890e-03,   6.23682886e-03,
                          6.08133152e-03,   5.01516834e-03,   5.24340197e-03,
                          5.17824665e-03,   5.17985225e-03,   4.08094376e-03,
                          4.26394865e-03,   4.19009104e-03,   4.26878780e-03,
                          3.26395035e-03,   3.34178284e-03,   3.22547182e-03,
                          3.25751305e-03,   2.44982913e-03,   2.36717239e-03,
                          2.37690657e-03,   2.34206393e-03,   1.57708302e-03,
                          1.62192062e-03,   1.47201866e-03,   1.56253204e-03,
                          7.13486224e-04,   8.74117017e-04,   7.44428486e-04,
                          7.24565238e-04,  -3.54163349e-05,   1.69329345e-04,
                          7.68899918e-06,   5.20311296e-05,  -5.13106585e-04,
                         -3.46489251e-04,  -4.59741801e-04,  -4.65132296e-04,
                         -9.62529331e-04,  -8.98916274e-04,  -9.89403576e-04,
                         -9.87261534e-04,  -1.50244683e-03,  -1.47489458e-03,
                         -1.50414556e-03,  -1.38781220e-03,  -2.01221555e-03,
                         -1.87052786e-03,  -1.99054554e-03,  -1.85025483e-03,
                         -2.31410936e-03,  -2.27076188e-03,  -2.33482569e-03,
                         -2.40181759e-03,  -2.72213295e-03,  -2.59864330e-03,
                         -2.75487080e-03,  -2.70584598e-03,  -2.97511742e-03,
                         -2.94154882e-03,  -3.04951519e-03,  -2.95413658e-03,
                         -3.20364907e-03,  -3.12940776e-03,  -3.20428982e-03,
                         -3.18028405e-03,  -3.61201540e-03,  -3.45099345e-03,
                         -3.37749720e-03,  -3.45895067e-03,  -3.62804160e-03,
                         -3.73478606e-03,  -3.60554829e-03,  -3.68962064e-03,
                         -3.78753245e-03,  -3.85826826e-03,  -3.87541577e-03,
                         -3.98620218e-03,  -3.98823991e-03,  -3.99038568e-03,
                         -4.05520573e-03,  -4.09016386e-03,  -4.20325994e-03,
                         -4.11415473e-03,  -4.08378989e-03,  -4.11019474e-03,
                         -4.20041382e-03,  -4.16205451e-03,  -4.13150713e-03,
                         -4.08734381e-03,  -4.14916873e-03,  -4.21973690e-03,
                         -4.29044664e-03,  -4.22564894e-03,  -4.20703366e-03,
                         -4.23213094e-03,  -4.25524637e-03,  -4.29679826e-03,
                         -4.28439304e-03,  -4.25264612e-03,  -4.16167453e-03,
                         -4.23644111e-03,  -4.22445685e-03,  -4.17578220e-03,
                         -4.19292226e-03,  -4.19948995e-03,  -4.05733660e-03,
                         -4.09061089e-03,  -4.17620316e-03,  -4.13675979e-03,
                         -4.05083224e-03,  -4.05777246e-03,  -4.06101719e-03,
                         -4.04182076e-03,  -3.94605473e-03,  -3.96149233e-03,
                         -3.99089605e-03,  -4.00606915e-03,  -3.78046557e-03,
                         -3.87004390e-03,  -3.82146612e-03,  -3.86722386e-03,
                         -3.68322060e-03,  -3.76735628e-03,  -3.68286669e-03,
                         -3.72316688e-03,  -3.52483615e-03,  -3.58436629e-03,
                         -3.63412499e-03,  -3.65165994e-03,  -3.46622244e-03,
                         -3.50063294e-03,  -3.48463655e-03,  -3.42905521e-03,
                         -3.34987789e-03,  -3.42278928e-03,  -3.32356244e-03],
                         dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri5",
    rate = 41000,
    data = numpy.array([ -4.82169387e-04,   1.45155611e-03,   3.05013818e-04,
                         -6.31548185e-03,  -5.78345556e-04,   7.94119481e-03,
                         -5.25217922e-03,  -1.82885677e-02,   1.04723172e-02,
                          1.11134779e-02,  -3.20074633e-02,  -7.34922569e-03,
                          3.14497203e-02,  -1.28545761e-02,  -5.69576286e-02,
                          2.79858783e-02,   3.27172801e-02,  -7.54349455e-02,
                         -2.85365656e-02,   6.79169744e-02,  -1.31898886e-02,
                         -1.16263546e-01,   4.59547974e-02,   6.86258078e-02,
                         -1.28275931e-01,  -6.57838508e-02,   1.15566812e-01,
                         -4.49128170e-03,  -1.95986718e-01,   6.14843518e-02,
                          1.18929654e-01,  -1.83841676e-01,  -1.23598218e-01,
                          1.70217082e-01,   1.39841577e-02,  -2.89494812e-01,
                          7.14878365e-02,   1.83620259e-01,  -2.40484715e-01,
                         -2.05543280e-01,   2.28454188e-01,   4.80486117e-02,
                         -3.94936979e-01,   7.26096183e-02,   2.60292619e-01,
                         -2.87993640e-01,  -3.10726970e-01,   2.89314389e-01,
                          9.89015624e-02,  -5.06417036e-01,   5.66146597e-02,
                          3.47671241e-01,  -3.25208902e-01,  -4.32383239e-01,
                          3.45358044e-01,   1.68403804e-01,  -6.14352882e-01,
                          2.18032710e-02,   4.40025806e-01,  -3.42417419e-01,
                         -5.66275775e-01,   3.95427346e-01,   2.54975975e-01,
                         -7.14706898e-01,  -5.37795797e-02,   5.33915579e-01,
                         -3.36627930e-01,  -7.02791274e-01,   4.29248035e-01,
                          3.49879533e-01,  -7.82223463e-01,  -1.68852806e-01,
                          5.93298852e-01,  -2.81369716e-01,  -7.84908772e-01,
                          4.25240785e-01,   4.25824970e-01,  -8.07688951e-01,
                         -2.89439231e-01,   6.34189606e-01,  -1.98000789e-01,
                         -8.56280506e-01,   4.05912280e-01,   5.00129282e-01,
                         -8.22334349e-01,  -4.15874392e-01,   6.67918265e-01,
                         -8.73111710e-02,  -9.19146538e-01,   3.76112014e-01,
                          5.71663201e-01,  -8.25450838e-01,  -5.40378451e-01,
                          6.95775568e-01,   3.34533602e-02,  -9.71876740e-01,
                          3.31713825e-01,   6.38313949e-01,  -8.18033397e-01,
                         -6.53682649e-01,   7.05169141e-01,   1.31971315e-01,
                         -9.95074987e-01,   2.61494368e-01,   6.71581089e-01,
                         -7.60605156e-01,  -7.27286696e-01,   6.85164928e-01,
                          2.18755424e-01,  -9.95721579e-01,   1.77113771e-01,
                          6.96018815e-01,  -6.92788363e-01,  -7.89099753e-01,
                          6.58353567e-01,   3.00157458e-01,  -9.92421627e-01,
                          8.41634944e-02,   7.13359237e-01,  -6.12266541e-01,
                         -8.43145072e-01,   6.27469540e-01,   3.73491615e-01,
                         -9.82694089e-01,  -2.09116749e-02,   7.25182295e-01,
                         -5.19224405e-01,  -8.84717822e-01,   5.88318467e-01,
                          4.38839793e-01,  -9.67633426e-01,  -1.68002486e-01,
                          7.32454836e-01,  -4.12096381e-01,  -9.19858396e-01,
                          5.43601930e-01,   4.97819513e-01,  -9.46277797e-01,
                         -3.02089155e-01,   7.35332310e-01,  -2.93557793e-01,
                         -9.47478473e-01,   4.92523074e-01,   5.48107088e-01,
                         -9.19755340e-01,  -4.21433002e-01,   7.32848346e-01,
                         -1.58534795e-01,  -9.69302595e-01,   4.34691757e-01,
                          5.92092097e-01,  -8.83561909e-01,  -5.27305663e-01,
                          7.25065827e-01,  -9.61388089e-03,  -9.83005643e-01,
                          3.67679387e-01,   6.29428148e-01,  -8.40417922e-01,
                         -6.18641078e-01,   7.10855603e-01,   9.20768231e-02,
                         -9.93490160e-01,   2.96098024e-01,   6.61317408e-01,
                         -7.86665797e-01,  -6.97739005e-01,   6.93890095e-01,
                          1.83860376e-01,  -9.95907962e-01,   2.14380935e-01,
                          6.87247157e-01,  -7.22169638e-01,  -7.65300512e-01,
                          6.70006335e-01,   2.68458247e-01,  -9.94478285e-01,
                          1.25384361e-01,   7.07412660e-01,  -6.47762537e-01,
                         -8.22742879e-01,   6.41842008e-01,   3.43184292e-01,
                         -9.85561669e-01,   2.97592618e-02,   7.22131610e-01,
                         -5.60824752e-01,  -8.68861675e-01,   6.05361283e-01,
                          4.12876457e-01,  -9.74617243e-01,  -1.06315888e-01,
                          7.30543852e-01,  -4.61088896e-01,  -9.07417238e-01,
                          5.65462530e-01,   4.74150926e-01,  -9.55141842e-01,
                         -2.47131020e-01,   7.34559119e-01,  -3.47043931e-01,
                         -9.36922014e-01,   5.16314983e-01,   5.26980460e-01,
                         -9.29889679e-01,  -3.73087943e-01,   7.34184980e-01,
                         -2.18860283e-01,  -9.60252523e-01,   4.60908383e-01,
                          5.73798120e-01,  -8.98177147e-01,  -4.84752953e-01,
                          7.27866232e-01,  -7.50610679e-02,  -9.76936877e-01,
                          3.98106754e-01,   6.13863587e-01,  -8.57558370e-01,
                         -5.82503200e-01,   7.17463613e-01,   5.03931902e-02,
                         -9.88370657e-01,   3.28116477e-01,   6.48819447e-01,
                         -8.08912873e-01,  -6.66769505e-01,   7.01792479e-01,
                          1.45228013e-01,  -9.94429767e-01,   2.49925107e-01,
                          6.76598549e-01,  -7.49367714e-01,  -7.38649905e-01,
                          6.80682421e-01,   2.32065901e-01,  -9.94574785e-01,
                          1.64441973e-01,   6.99173033e-01,  -6.81719244e-01,
                         -7.98944414e-01,   6.53819561e-01,   3.11232507e-01,
                         -9.89913285e-01,   6.98280856e-02,   7.16229200e-01,
                         -5.99446952e-01,  -8.49945724e-01,   6.21023417e-01,
                          3.83207917e-01,  -9.78789687e-01,  -4.44784015e-02,
                          7.26900518e-01,  -5.05128086e-01,  -8.90762150e-01,
                          5.82571208e-01,   4.48187619e-01,  -9.63569164e-01,
                         -1.89296931e-01,   7.34060466e-01,  -3.97528946e-01,
                         -9.25023496e-01,   5.37731886e-01,   5.04311919e-01,
                         -9.40899432e-01,  -3.21893007e-01,   7.35049725e-01,
                         -2.75250256e-01,  -9.51860726e-01,   4.84719157e-01,
                          5.53982675e-01,  -9.12882686e-01,  -4.37982231e-01,
                          7.31286466e-01,  -1.38836399e-01,  -9.71421659e-01,
                          4.25646365e-01,   5.97381592e-01,  -8.76946449e-01,
                         -5.41312277e-01,   7.23289490e-01,   6.62247092e-03,
                         -9.85593677e-01,   3.59253019e-01,   6.34285867e-01,
                         -8.32107067e-01,  -6.32288992e-01,   7.09704995e-01,
                          1.05575681e-01,  -9.93217170e-01,   2.84553617e-01,
                          6.64456487e-01,  -7.77056396e-01,  -7.08637118e-01,
                          6.91533327e-01,   1.95421278e-01,  -9.95975554e-01,
                          2.02185348e-01,   6.89637780e-01,  -7.12730348e-01,
                         -7.74851501e-01,   6.66215122e-01,   2.78298438e-01,
                         -9.94209051e-01,   1.11098081e-01,   7.09305525e-01,
                         -6.36286914e-01,  -8.28966916e-01,   6.36870623e-01,
                          3.51971030e-01,  -9.85113740e-01,   1.41578494e-02,
                          7.23247111e-01,  -5.47707677e-01,  -8.74251366e-01,
                          5.99858880e-01,   4.20472324e-01,  -9.72138941e-01,
                         -1.26763716e-01,   7.31435359e-01,  -4.45931643e-01,
                         -9.12478924e-01,   5.58133781e-01,   4.81849343e-01,
                         -9.52710509e-01,  -2.66662300e-01,   7.35700667e-01,
                         -3.29718173e-01,  -9.41825569e-01,   5.09236395e-01,
                          5.34365058e-01,  -9.27174568e-01,  -3.88245910e-01,
                          7.34552026e-01,  -1.99986309e-01,  -9.64459062e-01,
                          4.52552170e-01,   5.80141246e-01,  -8.93710971e-01,
                         -4.97992039e-01,   7.28245020e-01,  -5.47800884e-02,
                         -9.80480731e-01,   3.88691485e-01,   6.19575918e-01,
                         -8.52335632e-01,  -5.93653619e-01,   7.17634559e-01,
                          6.28881231e-02,  -9.90763724e-01,   3.17630500e-01,
                          6.52396500e-01,  -8.01020086e-01,  -6.76602542e-01,
                          7.00154424e-01,   1.56333297e-01,  -9.94999468e-01,
                          2.37915739e-01,   6.80170417e-01,  -7.41367221e-01,
                         -7.46926427e-01,   6.78054035e-01,   2.43900627e-01,
                         -9.95433629e-01,   1.51060581e-01,   7.00691164e-01,
                         -6.70119047e-01,  -8.05792153e-01,   6.51517451e-01,
                          3.22011918e-01,  -9.89384651e-01,   5.61912730e-02,
                          7.17772007e-01,  -5.87731600e-01,  -8.55855405e-01,
                          6.17042243e-01,   3.93191725e-01,  -9.78286862e-01,
                         -6.34321943e-02,   7.28247285e-01,  -4.91030216e-01,
                         -8.96793783e-01,   5.77472389e-01,   4.56761628e-01,
                         -9.61519122e-01,  -2.08086208e-01,   7.34324813e-01,
                         -3.81577551e-01,  -9.28849697e-01,   5.31638980e-01,
                          5.12396038e-01,  -9.38611805e-01,  -3.37531954e-01,
                          7.36091852e-01,  -2.57401735e-01,  -9.55212057e-01,
                          4.77973610e-01,   5.61003149e-01,  -9.08312201e-01,
                         -4.51673865e-01,   7.31717944e-01,  -1.18113205e-01,
                         -9.73654211e-01,   4.17552501e-01,   6.02733374e-01,
                         -8.70803475e-01,  -5.53322136e-01,   7.23025978e-01,
                          2.16266960e-02,  -9.86934066e-01,   3.49093199e-01,
                          6.38635933e-01,  -8.24612141e-01,  -6.41008258e-01,
                          7.07907140e-01,   1.17397361e-01,  -9.93546665e-01,
                          2.73321688e-01,   6.68810189e-01,  -7.68733978e-01,
                         -7.16742158e-01,   6.87585890e-01,   2.07018822e-01,
                         -9.96131003e-01,   1.90100387e-01,   6.92561090e-01,
                         -7.02939332e-01,  -7.80271530e-01,   6.63060427e-01,
                          2.89133698e-01,  -9.92064893e-01,   9.92028788e-02,
                          7.10631728e-01,  -6.26038194e-01,  -8.34344387e-01,
                          6.31837547e-01,   3.63318503e-01,  -9.83093321e-01,
                          1.39244797e-03,   7.23253429e-01,  -5.35062969e-01,
                         -8.79565001e-01,   5.94240904e-01,   4.29959744e-01,
                         -9.69214261e-01,  -1.46044225e-01,   7.31103420e-01,
                         -4.31362242e-01,  -9.15109575e-01,   5.50912797e-01,
                          4.88831639e-01,  -9.49483514e-01,  -2.81948119e-01,
                          7.34601676e-01,  -3.13351005e-01,  -9.43891823e-01,
                          5.01680136e-01,   5.39910197e-01,  -9.22988236e-01,
                         -4.03737813e-01,   7.33164191e-01,  -1.79988846e-01,
                         -9.65106070e-01,   4.43809032e-01,   5.84635794e-01,
                         -8.87925088e-01,  -5.11330545e-01,   7.26470649e-01,
                         -3.23691964e-02,  -9.80690300e-01,   3.77733529e-01,
                          6.23322368e-01,  -8.46500456e-01,  -6.04514539e-01,
                          7.14345813e-01,   7.68694058e-02,  -9.90640521e-01,
                          3.06487411e-01,   6.55912161e-01,  -7.94388354e-01,
                         -6.86560214e-01,   6.97177351e-01,   1.68777645e-01,
                         -9.95189905e-01,   2.27001876e-01,   6.83034897e-01,
                         -7.32260346e-01,  -7.56106913e-01,   6.74771309e-01,
                          2.53966630e-01,  -9.94014621e-01,   1.38835669e-01,
                          7.04161346e-01,  -6.59780443e-01,  -8.14110756e-01,
                          6.47029817e-01,   3.31841230e-01,  -9.87932622e-01,
                          4.41529080e-02,   7.19875216e-01,  -5.74854076e-01,
                         -8.62961352e-01,   6.12162113e-01,   4.02014554e-01,
                         -9.76452947e-01,  -8.45363736e-02,   7.28730738e-01,
                         -4.76502091e-01,  -9.02043462e-01,   5.71181536e-01,
                          4.64390934e-01,  -9.59262192e-01,  -2.28220969e-01,
                          7.35112429e-01,  -3.64704013e-01,  -9.33297753e-01,
                          5.23658156e-01,   5.19850552e-01,  -9.35868204e-01,
                         -3.54238451e-01,   7.35799968e-01,  -2.36759022e-01,
                         -9.58358705e-01,   4.69184160e-01,   5.67592859e-01,
                         -9.05098498e-01,  -4.68990028e-01,   7.31131792e-01,
                         -9.67833474e-02,  -9.75624859e-01,   4.07654971e-01,
                          6.08271301e-01,  -8.65976512e-01,  -5.67352414e-01,
                          7.21297860e-01,   3.57588083e-02,  -9.88625050e-01,
                          3.37919265e-01,   6.43741012e-01,  -8.17633033e-01,
                         -6.54187441e-01,   7.06381321e-01,   1.29904330e-01,
                         -9.94787514e-01,   2.60487109e-01,   6.72998726e-01,
                         -7.59901106e-01,  -7.28194535e-01,   6.85340405e-01,
                          2.18055084e-01,  -9.96416271e-01,   1.77138969e-01,
                          6.95630550e-01,  -6.92077875e-01,  -7.89555609e-01,
                          6.58469558e-01,   2.99622327e-01,  -9.91528749e-01,
                          8.36075917e-02,   7.13767588e-01,  -6.11217201e-01,
                         -8.43491673e-01,   6.26644135e-01,   3.72502953e-01,
                         -9.82261658e-01,  -2.02655811e-02,   7.25064635e-01,
                         -5.19076705e-01,  -8.86187375e-01,   5.88026285e-01,
                          4.39028025e-01,  -9.67030048e-01,  -1.68525517e-01,
                          7.33476937e-01,  -4.13717270e-01,  -9.21041429e-01,
                          5.44323504e-01,   4.97871518e-01,  -9.45215106e-01,
                         -3.01893502e-01,   7.35427201e-01,  -2.93280154e-01,
                         -9.49006677e-01,   4.92734790e-01,   5.47659397e-01,
                         -9.17747378e-01,  -4.20622528e-01,   7.32612252e-01,
                         -1.58958420e-01,  -9.69635308e-01,   4.34107691e-01,
                          5.91332257e-01,  -8.81088436e-01,  -5.26748240e-01,
                          7.24607050e-01,  -9.61227529e-03,  -9.83594000e-01,
                          3.67304683e-01,   6.28999472e-01,  -8.38245153e-01,
                         -6.17372036e-01,   7.11187601e-01,   9.19627249e-02,
                         -9.93030012e-01,   2.93931365e-01,   6.60342336e-01,
                         -7.84717500e-01,  -6.97035730e-01,   6.93391919e-01,
                          1.82599336e-01,  -9.95701551e-01,   2.13434815e-01,
                          6.85349107e-01,  -7.21486151e-01,  -7.64187098e-01,
                          6.70133829e-01,   2.66838968e-01,  -9.94099200e-01,
                          1.23975568e-01,   7.05894291e-01,  -6.47546411e-01,
                         -8.21787119e-01,   6.41687572e-01,   3.41853261e-01,
                         -9.86503959e-01,   2.87858937e-02,   7.20688879e-01,
                         -5.60677350e-01,  -8.69057238e-01,   6.05690062e-01,
                          4.12218571e-01,  -9.74411309e-01,  -1.06666848e-01,
                          7.30823994e-01,  -4.60701615e-01,  -9.07840073e-01,
                          5.64395010e-01,   4.73378748e-01,  -9.56309080e-01,
                         -2.46565685e-01,   7.35386312e-01,  -3.47248465e-01,
                         -9.37405050e-01,   5.16141951e-01,   5.26764095e-01,
                         -9.31344271e-01,  -3.71394008e-01,   7.34057844e-01,
                         -2.19147369e-01,  -9.61140811e-01,   4.61601645e-01,
                          5.73239863e-01,  -8.99550796e-01,  -4.82967585e-01,
                          7.28758395e-01,  -7.53760859e-02,  -9.78337586e-01,
                          3.98472965e-01,   6.12176418e-01,  -8.58703971e-01,
                         -5.80224335e-01,   7.18249440e-01,   4.90531437e-02,
                         -9.89123344e-01,   3.27909589e-01,   6.46973729e-01,
                         -8.10091615e-01,  -6.65114403e-01,   7.03001201e-01,
                          1.44558102e-01,  -9.95133102e-01,   2.49810204e-01,
                          6.75377250e-01,  -7.51578450e-01,  -7.36344278e-01,
                          6.82063580e-01,   2.31222272e-01,  -9.95253861e-01,
                          1.64379448e-01,   6.97909057e-01,  -6.82437301e-01,
                         -7.97129273e-01,   6.55843079e-01,   3.10177892e-01,
                         -9.91082489e-01,   7.03849122e-02,   7.15189457e-01,
                         -5.99593103e-01,  -8.49294603e-01,   6.23443186e-01,
                          3.82625997e-01,  -9.80489492e-01,  -4.40626256e-02,
                          7.27366686e-01,  -5.04613638e-01,  -8.91067266e-01,
                          5.83755255e-01,   4.47564244e-01,  -9.64642227e-01,
                         -1.88054740e-01,   7.33688712e-01,  -3.97365063e-01,
                         -9.24549878e-01,   5.37952900e-01,   5.04286349e-01,
                         -9.42007363e-01,  -3.20035428e-01,   7.34920681e-01,
                         -2.74338365e-01,  -9.50693250e-01,   4.85150963e-01,
                          5.53751528e-01,  -9.13360357e-01,  -4.37245637e-01,
                          7.31744885e-01,  -1.37966767e-01,  -9.71183240e-01,
                          4.25717980e-01,   5.95979273e-01,  -8.76818180e-01,
                         -5.40079355e-01,   7.23711193e-01,   7.18994951e-03,
                         -9.84847367e-01,   3.58476758e-01,   6.33082807e-01,
                         -8.32496822e-01,  -6.30002379e-01,   7.10417390e-01,
                          1.04917981e-01,  -9.92856085e-01,   2.83099234e-01,
                          6.64037943e-01,  -7.77595580e-01,  -7.06709206e-01,
                          6.91580355e-01,   1.95268065e-01,  -9.95002747e-01,
                          2.01453000e-01,   6.88793123e-01,  -7.12851882e-01,
                         -7.72571087e-01,   6.66733265e-01,   2.77743340e-01,
                         -9.93075967e-01,   1.10481046e-01,   7.08629727e-01,
                         -6.34644032e-01,  -8.27976584e-01,   6.37169003e-01,
                          3.52587402e-01,  -9.85425591e-01,   1.37075521e-02,
                          7.22699523e-01,  -5.45875609e-01,  -8.73584986e-01,
                          6.00760639e-01,   4.21007067e-01,  -9.72810209e-01,
                         -1.26682058e-01,   7.31291115e-01,  -4.44996387e-01,
                         -9.10971105e-01,   5.58098555e-01,   4.80941802e-01,
                         -9.52796340e-01,  -2.65302807e-01,   7.35738695e-01,
                         -3.28926384e-01,  -9.40779448e-01,   5.08710146e-01,
                          5.34306228e-01,  -9.27116275e-01,  -3.87462884e-01,
                          7.34184980e-01,  -2.00266689e-01,  -9.62950647e-01,
                          4.53055590e-01,   5.79461992e-01,  -8.93283248e-01,
                         -4.97246057e-01,   7.27470696e-01,  -5.45055643e-02,
                         -9.79816973e-01,   3.88560772e-01,   6.18516386e-01,
                         -8.51931214e-01,  -5.92563748e-01,   7.16724753e-01,
                          6.27365932e-02,  -9.89865005e-01,   3.17278266e-01,
                          6.52270555e-01,  -8.02268445e-01,  -6.75780237e-01,
                          7.00331092e-01,   1.56809792e-01,  -9.94207919e-01,
                          2.38019809e-01,   6.79539204e-01,  -7.42362678e-01,
                         -7.46338427e-01,   6.78149402e-01,   2.45095640e-01,
                         -9.95469451e-01,   1.51182309e-01,   7.01333523e-01,
                         -6.70123935e-01,  -8.05130124e-01,   6.50530934e-01,
                          3.22125942e-01,  -9.90005553e-01,   5.72025515e-02,
                          7.17801213e-01,  -5.87203443e-01,  -8.55961382e-01,
                          6.17541790e-01,   3.93149436e-01,  -9.80189145e-01,
                         -6.30336478e-02,   7.28986979e-01,  -4.91393298e-01,
                         -8.97030234e-01,   5.77777207e-01,   4.55470949e-01,
                         -9.62808132e-01,  -2.07720026e-01,   7.35519111e-01,
                         -3.81395102e-01,  -9.29351866e-01,   5.31664550e-01,
                          5.11577129e-01,  -9.40136194e-01,  -3.37419659e-01,
                          7.36539304e-01,  -2.56700814e-01,  -9.54579592e-01,
                          4.77337748e-01,   5.60765564e-01,  -9.09980237e-01,
                         -4.51762199e-01,   7.31520653e-01,  -1.18144318e-01,
                         -9.73670244e-01,   4.16876823e-01,   6.02245510e-01,
                         -8.71995389e-01,  -5.53197324e-01,   7.23797798e-01,
                          2.13864930e-02,  -9.86474812e-01,   3.47952783e-01,
                          6.38927162e-01,  -8.26037884e-01,  -6.41853571e-01,
                          7.09404826e-01,   1.18641660e-01,  -9.93707776e-01,
                          2.71710217e-01,   6.69205606e-01,  -7.69277513e-01,
                         -7.17786372e-01,   6.89142346e-01,   2.08772659e-01,
                         -9.96386886e-01,   1.88205823e-01,   6.93054736e-01,
                         -7.03402281e-01,  -7.80816674e-01,   6.63241446e-01,
                          2.90899128e-01,  -9.93349373e-01,   9.73574594e-02,
                          7.11676717e-01,  -6.24661982e-01,  -8.34288776e-01,
                          6.31826103e-01,   3.64428669e-01,  -9.85494792e-01,
                          6.30156283e-05,   7.25462317e-01,  -5.33168912e-01,
                         -8.80075932e-01,   5.94978154e-01,   4.30361003e-01,
                         -9.70596790e-01,  -1.48314878e-01,   7.32811093e-01,
                         -4.29933339e-01,  -9.16710198e-01,   5.51685095e-01,
                          4.88852769e-01,  -9.50172901e-01,  -2.83325702e-01,
                          7.36590981e-01,  -3.12376320e-01,  -9.45455670e-01,
                          5.01026273e-01,   5.40328205e-01,  -9.24076736e-01,
                         -4.03967142e-01,   7.33597338e-01,  -1.79346293e-01,
                         -9.66542363e-01,   4.43030268e-01,   5.85331559e-01,
                         -8.89410079e-01,  -5.10808110e-01,   7.26402223e-01,
                         -3.20819467e-02,  -9.82515275e-01,   3.78086954e-01,
                          6.23896420e-01,  -8.46762300e-01,  -6.04102194e-01,
                          7.14781463e-01,   7.73121566e-02,  -9.91759002e-01,
                          3.05304259e-01,   6.56122684e-01,  -7.94501066e-01,
                         -6.85764909e-01,   6.97916389e-01,   1.69640809e-01,
                         -9.96467233e-01,   2.26155281e-01,   6.83983266e-01,
                         -7.33298779e-01,  -7.55313814e-01,   6.74778759e-01,
                          2.55026847e-01,  -9.95190978e-01,   1.37892261e-01,
                          7.05297530e-01,  -6.60437822e-01,  -8.13132405e-01,
                          6.47264719e-01,   3.32371205e-01,  -9.89260435e-01,
                          4.35172096e-02,   7.21329689e-01,  -5.74757814e-01,
                         -8.62285972e-01,   6.12141252e-01,   4.02122349e-01,
                         -9.77912545e-01,  -8.51738080e-02,   7.30812967e-01,
                         -4.76619154e-01,  -9.02669489e-01,   5.71363688e-01,
                          4.63920712e-01,  -9.60495055e-01,  -2.28173837e-01,
                          7.35896707e-01,  -3.64766628e-01,  -9.33675051e-01,
                          5.23432970e-01,   5.19511282e-01,  -9.36018884e-01,
                         -3.54372859e-01,   7.35842049e-01,  -2.36993089e-01,
                         -9.58664119e-01,   4.68411088e-01,   5.67591250e-01,
                         -9.05036151e-01,  -4.68700558e-01,   7.30787516e-01,
                         -9.67025608e-02,  -9.76905644e-01,   4.06953901e-01,
                          6.08935237e-01,  -8.66282344e-01,  -5.66705644e-01,
                          7.20551491e-01,   3.61422040e-02,  -9.88387108e-01,
                          3.36621493e-01,   6.44718885e-01,  -8.18738639e-01,
                         -6.54789627e-01,   7.05994964e-01,   1.32119432e-01,
                         -9.95329797e-01,   2.60362625e-01,   6.73447192e-01,
                         -7.60852635e-01,  -7.27697015e-01,   6.84662163e-01,
                          2.19479457e-01,  -9.95873988e-01,   1.76805988e-01,
                          6.96710050e-01,  -6.92711532e-01,  -7.89851725e-01,
                          6.58845961e-01,   3.00366282e-01,  -9.92148936e-01,
                          8.38113278e-02,   7.14230061e-01,  -6.11531198e-01,
                         -8.42963457e-01,   6.26712143e-01,   3.73315960e-01,
                         -9.83620822e-01,  -1.94745865e-02,   7.26457059e-01,
                         -5.19378245e-01,  -8.85311484e-01,   5.88498175e-01,
                          4.37390119e-01,  -9.67850149e-01,  -1.68068439e-01,
                          7.34009981e-01,  -4.13224667e-01,  -9.20623839e-01,
                          5.44423044e-01,   4.96048957e-01,  -9.46223438e-01,
                         -3.01583380e-01,   7.35746920e-01,  -2.94378310e-01,
                         -9.47877407e-01,   4.92635816e-01,   5.46755433e-01,
                         -9.18228090e-01,  -4.19647574e-01,   7.32627690e-01,
                         -1.59584314e-01,  -9.69629169e-01,   4.35230315e-01,
                          5.91293216e-01,  -8.82570624e-01,  -5.25671840e-01,
                          7.24009097e-01,  -9.53574199e-03,  -9.83970821e-01,
                          3.68705601e-01,   6.29327476e-01,  -8.39120090e-01,
                         -6.18106723e-01,   7.11758733e-01,   9.18861255e-02,
                         -9.93748307e-01,   2.95780659e-01,   6.60476863e-01,
                         -7.86234260e-01,  -6.96914375e-01,   6.93657041e-01,
                          1.83141604e-01,  -9.96750712e-01,   2.13615134e-01,
                          6.87223375e-01,  -7.23313093e-01,  -7.63929725e-01,
                          6.69768929e-01,   2.67844558e-01,  -9.94603574e-01,
                          1.24061219e-01,   7.06848919e-01,  -6.48910761e-01,
                         -8.21068823e-01,   6.41752839e-01,   3.42833549e-01,
                         -9.87324059e-01,   2.90494040e-02,   7.21241176e-01,
                         -5.60509086e-01,  -8.68929625e-01,   6.05816543e-01,
                          4.12222564e-01,  -9.75070417e-01,  -1.06835797e-01,
                          7.31555462e-01,  -4.60404098e-01,  -9.06786799e-01,
                          5.63681602e-01,   4.73054409e-01,  -9.56249952e-01,
                         -2.47497559e-01,   7.35461473e-01,  -3.47269952e-01,
                         -9.36438501e-01,   5.14744937e-01,   5.27213812e-01,
                         -9.31639194e-01,  -3.72270316e-01,   7.35376656e-01,
                         -2.19261825e-01,  -9.61236894e-01,   4.60023105e-01,
                          5.74280679e-01,  -8.98770630e-01,  -4.83598739e-01,
                          7.29086816e-01,  -7.48411193e-02,  -9.78600919e-01,
                          3.97278845e-01,   6.13881648e-01,  -8.58933270e-01,
                         -5.80191612e-01,   7.18131840e-01,   5.01865372e-02,
                         -9.90228653e-01,   3.27576816e-01,   6.48956895e-01,
                         -8.10696542e-01,  -6.65460527e-01,   7.03140914e-01,
                          1.44583538e-01,  -9.95706081e-01,   2.49568030e-01,
                          6.76987112e-01,  -7.51124382e-01,  -7.37023890e-01,
                          6.81634188e-01,   2.32062921e-01,  -9.95839536e-01,
                          1.64002627e-01,   6.99444115e-01,  -6.82294071e-01,
                         -7.98122644e-01,   6.55402601e-01,   3.10572118e-01,
                         -9.91542578e-01,   7.03095272e-02,   7.15632975e-01,
                         -6.00218892e-01,  -8.49662066e-01,   6.21599615e-01,
                          3.83181930e-01,  -9.81741071e-01,  -4.34899293e-02,
                          7.27599025e-01,  -5.05110741e-01,  -8.90884101e-01,
                          5.82656741e-01,   4.47673231e-01,  -9.64192092e-01,
                         -1.89027756e-01,   7.34543562e-01,  -3.98235798e-01,
                         -9.25109863e-01,   5.37762165e-01,   5.04503369e-01,
                         -9.42196846e-01,  -3.21236849e-01,   7.35943913e-01,
                         -2.75282204e-01,  -9.50855553e-01,   4.84552175e-01,
                          5.54651558e-01,  -9.12891984e-01,  -4.38036501e-01,
                          7.31913507e-01,  -1.39027014e-01,  -9.71637428e-01,
                          4.25933957e-01,   5.97483218e-01,  -8.77005160e-01,
                         -5.40681183e-01,   7.23461449e-01,   6.65407907e-03,
                         -9.85496640e-01,   3.58550906e-01,   6.34511113e-01,
                         -8.32660317e-01,  -6.31047189e-01,   7.10765064e-01,
                          1.04854792e-01,  -9.94163156e-01,   2.83648670e-01,
                          6.64835215e-01,  -7.76531577e-01,  -7.07373977e-01,
                          6.91932797e-01,   1.94592983e-01,  -9.96499956e-01,
                          2.01152146e-01,   6.90282762e-01,  -7.13773251e-01,
                         -7.71975279e-01,   6.66599751e-01,   2.77606010e-01,
                         -9.93574381e-01,   1.10403970e-01,   7.09671855e-01,
                         -6.36650026e-01,  -8.27909827e-01,   6.36844516e-01,
                          3.52467895e-01,  -9.85796869e-01,   1.30171794e-02,
                          7.23582387e-01,  -5.48483431e-01,  -8.73108566e-01,
                          6.00515425e-01,   4.19946671e-01,  -9.72668827e-01,
                         -1.27692863e-01,   7.31817961e-01,  -4.45901185e-01,
                         -9.10438001e-01,   5.57308614e-01,   4.81319457e-01,
                         -9.53624308e-01,  -2.66938895e-01,   7.35763371e-01,
                         -3.29034895e-01,  -9.40545082e-01,   5.08091450e-01,
                          5.34319580e-01,  -9.27779734e-01,  -3.88734788e-01,
                          7.34873414e-01,  -2.00133845e-01,  -9.63193774e-01,
                          4.51982945e-01,   5.80464363e-01,  -8.94238949e-01,
                         -4.98023510e-01,   7.27626681e-01,  -5.43340705e-02,
                         -9.79672253e-01,   3.87282550e-01,   6.20179951e-01,
                         -8.52924645e-01,  -5.93828678e-01,   7.16522634e-01,
                          6.36148900e-02,  -9.90948319e-01,   3.16809446e-01,
                          6.53232098e-01,  -8.02175403e-01,  -6.76111102e-01,
                          7.00730503e-01,   1.57291919e-01,  -9.95914936e-01,
                          2.37919271e-01,   6.79768384e-01,  -7.42558300e-01,
                         -7.46970475e-01,   6.78336263e-01,   2.44256824e-01,
                         -9.95414376e-01,   1.51421353e-01,   7.02296317e-01,
                         -6.70675278e-01,  -8.06114972e-01,   6.50705397e-01,
                          3.23071033e-01,  -9.90608871e-01,   5.66263609e-02,
                          7.19001293e-01,  -5.88057756e-01,  -8.56147707e-01,
                          6.16006017e-01,   3.93727481e-01,  -9.79497135e-01,
                         -6.35564104e-02,   7.29088902e-01,  -4.91314083e-01,
                         -8.96800101e-01,   5.76715052e-01,   4.56569344e-01,
                         -9.62639153e-01,  -2.08697632e-01,   7.35149682e-01,
                         -3.81094247e-01,  -9.29653227e-01,   5.30823171e-01,
                          5.12166798e-01,  -9.39895391e-01,  -3.38488132e-01,
                          7.35360682e-01,  -2.56778955e-01,  -9.55250025e-01,
                          4.77659822e-01,   5.61001360e-01,  -9.08495784e-01,
                         -4.52330232e-01,   7.30675995e-01,  -1.18187711e-01,
                         -9.74096656e-01,   4.17567581e-01,   6.03304386e-01,
                         -8.71886909e-01,  -5.53478181e-01,   7.21555531e-01,
                          2.19273064e-02,  -9.87323463e-01,   3.48615557e-01,
                          6.39438629e-01,  -8.25111210e-01,  -6.41512454e-01,
                          7.07394600e-01,   1.19303204e-01,  -9.94255066e-01,
                          2.72766888e-01,   6.68710589e-01,  -7.69308448e-01,
                         -7.17419982e-01,   6.88501775e-01,   2.09051475e-01,
                         -9.96263027e-01,   1.88366279e-01,   6.92510605e-01,
                         -7.03574955e-01,  -7.81032920e-01,   6.62960529e-01,
                          2.91363239e-01,  -9.92232502e-01,   9.62488949e-02,
                          7.11997092e-01,  -6.25603557e-01,  -8.34921658e-01,
                          6.31267190e-01,   3.65068018e-01,  -9.83840287e-01,
                         -1.24674209e-03,   7.25140333e-01,  -5.34200728e-01,
                         -8.79557014e-01,   5.93659997e-01,   4.31902975e-01,
                         -9.69967961e-01,  -1.48672312e-01,   7.32441485e-01,
                         -4.29808944e-01,  -9.15800571e-01,   5.50430357e-01,
                          4.90470797e-01,  -9.49929059e-01,  -2.84160018e-01,
                          7.34884977e-01,  -3.12796801e-01,  -9.45941269e-01,
                          5.00463367e-01,   5.41857362e-01,  -9.22568619e-01,
                         -4.05287296e-01,   7.31778860e-01,  -1.80640757e-01,
                         -9.66856003e-01,   4.43512678e-01,   5.86997151e-01,
                         -8.88488770e-01,  -5.13227999e-01,   7.25747883e-01,
                         -3.24167311e-02,  -9.82172966e-01,   3.78169477e-01,
                          6.26100004e-01,  -8.46914351e-01,  -6.05895340e-01,
                          7.14050591e-01,   7.74163753e-02,  -9.91132915e-01,
                          3.06409597e-01,   6.57614052e-01,  -7.95252085e-01,
                         -6.85821295e-01,   6.96984112e-01,   1.70302764e-01,
                         -9.95743036e-01,   2.25988641e-01,   6.83361411e-01,
                         -7.34116077e-01,  -7.55325735e-01,   6.73845708e-01,
                          2.55606562e-01,  -9.94807780e-01,   1.37297362e-01,
                          7.04127789e-01,  -6.60574317e-01,  -8.13612700e-01,
                          6.45273745e-01,   3.33350539e-01,  -9.88320827e-01,
                          4.39983420e-02,   7.19622076e-01,  -5.75212777e-01,
                         -8.62806082e-01,   6.11104727e-01,   4.03833807e-01,
                         -9.76859093e-01,  -8.50122645e-02,   7.29743242e-01,
                         -4.75841820e-01,  -9.01834846e-01,   5.70252180e-01,
                          4.65593874e-01,  -9.59308326e-01,  -2.27727681e-01,
                          7.34243631e-01,  -3.65214974e-01,  -9.32411313e-01,
                          5.22581577e-01,   5.20808458e-01,  -9.34944034e-01,
                         -3.55389655e-01,   7.34179914e-01,  -2.37849995e-01,
                         -9.58309591e-01,   4.69151169e-01,   5.67969918e-01,
                         -9.04803276e-01,  -4.68327016e-01,   7.28619874e-01,
                         -9.72848758e-02,  -9.75965977e-01,   4.08585042e-01,
                          6.09250605e-01,  -8.65481973e-01,  -5.66758633e-01,
                          7.19929159e-01,   3.56214270e-02,  -9.87838626e-01,
                          3.38703424e-01,   6.45180643e-01,  -8.17577422e-01,
                         -6.53715432e-01,   7.05596149e-01,   1.31042078e-01,
                         -9.94039476e-01,   2.60802358e-01,   6.73353016e-01,
                         -7.60549963e-01,  -7.26379991e-01,   6.84553564e-01,
                          2.19394222e-01,  -9.95512962e-01,   1.76310644e-01,
                          6.96028471e-01,  -6.92648470e-01,  -7.88334250e-01,
                          6.57587767e-01,   3.00091773e-01,  -9.92257893e-01,
                          8.37972611e-02,   7.13722289e-01,  -6.12226188e-01,
                         -8.42325389e-01,   6.25754058e-01,   3.74439150e-01,
                         -9.83443737e-01,  -1.88002437e-02,   7.26274908e-01,
                         -5.19713819e-01,  -8.85840714e-01,   5.88083923e-01,
                          4.40039068e-01,  -9.68167782e-01,  -1.67937502e-01,
                          7.34047472e-01,  -4.14175302e-01,  -9.20734525e-01,
                          5.44149578e-01,   4.98131603e-01,  -9.46386933e-01,
                         -3.01465094e-01,   7.34816372e-01,  -2.96207249e-01,
                         -9.47956860e-01,   4.92632687e-01,   5.49588919e-01,
                         -9.20521021e-01,  -4.20639306e-01,   7.31991410e-01,
                         -1.60327643e-01,  -9.70216215e-01,   4.34162587e-01,
                          5.92907727e-01,  -8.85661304e-01,  -5.26223361e-01,
                          7.24556804e-01,  -9.97328199e-03,  -9.84945714e-01,
                          3.68417025e-01,   6.31406724e-01,  -8.40927541e-01,
                         -6.17528498e-01,   7.12897897e-01,   9.03316885e-02,
                         -9.93552983e-01,   2.95122415e-01,   6.61995411e-01,
                         -7.87280858e-01,  -6.96043015e-01,   6.94113255e-01,
                          1.82003275e-01,  -9.97138500e-01,   2.13194624e-01,
                          6.88272893e-01,  -7.23796844e-01,  -7.62764573e-01,
                          6.70049608e-01,   2.66393393e-01,  -9.96026754e-01,
                          1.25068307e-01,   7.07837582e-01,  -6.49142265e-01,
                         -8.20884407e-01,   6.41204178e-01,   3.43227386e-01,
                         -9.88566339e-01,   3.05847898e-02,   7.21283734e-01,
                         -5.61718464e-01,  -8.68387878e-01,   6.07397616e-01,
                          4.12755400e-01,  -9.75865424e-01,  -1.05751209e-01,
                          7.31581271e-01,  -4.60245967e-01,  -9.07242656e-01,
                          5.64454138e-01,   4.73202586e-01,  -9.56573546e-01,
                         -2.46780992e-01,   7.36480474e-01,  -3.48598957e-01,
                         -9.36550975e-01,   5.16338587e-01,   5.26355743e-01,
                         -9.32063997e-01,  -3.72234046e-01,   7.35658526e-01,
                         -2.19621003e-01,  -9.60790515e-01,   4.61838275e-01,
                          5.73020458e-01,  -9.01058495e-01,  -4.83415633e-01,
                          7.28315651e-01,  -7.61746615e-02,  -9.78713870e-01,
                          3.98892879e-01,   6.13423586e-01,  -8.59911621e-01,
                         -5.80528498e-01,   7.19345570e-01,   4.84276004e-02,
                         -9.89623725e-01,   3.29802006e-01,   6.49120152e-01,
                         -8.11417460e-01,  -6.65804267e-01,   7.03739107e-01,
                          1.44500494e-01,  -9.94989812e-01,   2.50392139e-01,
                          6.77719891e-01,  -7.51520574e-01,  -7.36865759e-01,
                          6.81328654e-01,   2.31615081e-01,  -9.94854093e-01,
                          1.65612265e-01,   6.99927509e-01,  -6.81709468e-01,
                         -7.98625767e-01,   6.54341280e-01,   3.11547577e-01,
                         -9.91756320e-01,   6.98187947e-02,   7.16972530e-01,
                         -5.99749625e-01,  -8.51317942e-01,   6.21541977e-01,
                          3.86632949e-01,  -9.81268644e-01,  -4.22558822e-02,
                          7.28203118e-01,  -5.04540741e-01,  -8.92328024e-01,
                          5.82992673e-01,   4.50490355e-01,  -9.65155780e-01,
                         -1.88192308e-01,   7.33579576e-01,  -3.96865040e-01,
                         -9.25334394e-01,   5.37049949e-01,   5.07173002e-01,
                         -9.42885518e-01,  -3.21087033e-01,   7.35261619e-01,
                         -2.74917930e-01,  -9.50304866e-01,   4.84064370e-01,
                          5.56517661e-01,  -9.14879918e-01,  -4.38393801e-01,
                          7.31637776e-01,  -1.37484223e-01,  -9.70882475e-01,
                          4.24470156e-01,   5.97988486e-01,  -8.78682017e-01,
                         -5.40207267e-01,   7.22796023e-01,   7.02769496e-03,
                         -9.83402133e-01,   3.56518030e-01,   6.34353399e-01,
                         -8.31568182e-01,  -6.31106496e-01,   7.08895266e-01,
                          1.04610056e-01,  -9.91698980e-01,   2.81953335e-01,
                          6.65194273e-01,  -7.77131855e-01,  -7.08439887e-01,
                          6.89328969e-01,   1.94838688e-01,  -9.95016873e-01,
                          1.99685752e-01,   6.89943612e-01,  -7.12121189e-01,
                         -7.73443162e-01,   6.64908648e-01,   2.79012948e-01,
                         -9.92330432e-01,   1.10764749e-01,   7.08719552e-01,
                         -6.34337008e-01,  -8.30541432e-01,   6.36121154e-01,
                          3.56083542e-01,  -9.84611034e-01,   1.34708239e-02,
                          7.23353982e-01,  -5.46344817e-01,  -8.76255155e-01,
                          6.01346254e-01,   4.24071699e-01,  -9.72404003e-01,
                         -1.27005860e-01,   7.32498348e-01,  -4.44870085e-01,
                         -9.11142945e-01,   5.56675792e-01,   4.84149426e-01,
                         -9.53160584e-01,  -2.66137838e-01,   7.36286759e-01,
                         -3.29759836e-01,  -9.40485358e-01,   5.07068992e-01,
                          5.36803544e-01,  -9.26808655e-01,  -3.87657851e-01,
                          7.34714508e-01,  -1.98779747e-01,  -9.62115824e-01,
                          4.52684641e-01,   5.82442582e-01,  -8.93417299e-01,
                         -4.96534705e-01,   7.28529811e-01,  -5.40260561e-02,
                         -9.78510320e-01,   3.88363034e-01,   6.21106744e-01,
                         -8.51176858e-01,  -5.93372822e-01,   7.16457725e-01,
                          6.36114553e-02,  -9.89425182e-01,   3.17116410e-01,
                          6.55120909e-01,  -8.01911354e-01,  -6.76984191e-01,
                          7.00085759e-01,   1.57859012e-01,  -9.94199216e-01,
                          2.37659052e-01,   6.81777000e-01,  -7.41425514e-01,
                         -7.47682750e-01,   6.76804543e-01,   2.45028257e-01,
                         -9.94454265e-01,   1.52307570e-01,   7.03205764e-01,
                         -6.68782115e-01,  -8.07551026e-01,   6.50354326e-01,
                          3.24477494e-01,  -9.90072429e-01,   5.72182685e-02,
                          7.19399989e-01,  -5.85239172e-01,  -8.58152270e-01,
                          6.17238760e-01,   3.97113293e-01,  -9.77820277e-01,
                         -6.25262186e-02,   7.27666259e-01,  -4.88570601e-01,
                         -8.98290753e-01,   5.77567995e-01,   4.59882140e-01,
                         -9.60955262e-01,  -2.06511930e-01,   7.32733905e-01,
                         -3.80304009e-01,  -9.30755258e-01,   5.31579852e-01,
                          5.14374554e-01,  -9.38813031e-01,  -3.38456631e-01,
                          7.33573675e-01,  -2.56730884e-01,  -9.55973923e-01,
                          4.77914304e-01,   5.61807930e-01,  -9.08500075e-01,
                         -4.53229189e-01,   7.29727745e-01,  -1.17830403e-01,
                         -9.73576844e-01,   4.17500615e-01,   6.04293585e-01,
                         -8.72654557e-01,  -5.54167867e-01,   7.23050296e-01,
                          2.24324036e-02,  -9.86950099e-01,   3.48917723e-01,
                          6.38548851e-01,  -8.24667394e-01,  -6.43331766e-01,
                          7.09240079e-01,   1.19208887e-01,  -9.93797660e-01,
                          2.72817016e-01,   6.69318318e-01,  -7.67703712e-01,
                         -7.19900012e-01,   6.89705729e-01,   2.08678260e-01,
                         -9.97119784e-01,   1.88720629e-01,   6.93930089e-01,
                         -7.02312708e-01,  -7.84799576e-01,   6.64386451e-01,
                          2.92311162e-01,  -9.94287491e-01,   9.82849970e-02,
                          7.13061929e-01,  -6.23429835e-01,  -8.38664770e-01,
                          6.32844627e-01,   3.66375566e-01,  -9.84505773e-01,
                         -5.97903971e-04,   7.26166904e-01,  -5.33433855e-01,
                         -8.84563625e-01,   5.95318854e-01,   4.33406353e-01,
                         -9.70546663e-01,  -1.47468477e-01,   7.33773589e-01,
                         -4.30570722e-01,  -9.18293297e-01,   5.51679909e-01,
                          4.91393417e-01,  -9.49793816e-01,  -2.85342306e-01,
                          7.35710382e-01,  -3.13184023e-01,  -9.47260201e-01,
                          5.00391006e-01,   5.41918814e-01,  -9.22049165e-01,
                         -4.05192763e-01,   7.33316064e-01,  -1.80032030e-01,
                         -9.67148900e-01,   4.44070637e-01,   5.85987866e-01,
                         -8.87358010e-01,  -5.12824893e-01,   7.27873623e-01,
                         -3.20553966e-02,  -9.81871188e-01,   3.78105938e-01,
                          6.24054551e-01,  -8.45407248e-01,  -6.06293917e-01,
                          7.15022087e-01,   7.70998225e-02,  -9.92677331e-01,
                          3.04799557e-01,   6.57363415e-01,  -7.92920351e-01,
                         -6.87446773e-01,   6.97591066e-01,   1.68597594e-01,
                         -9.96078014e-01,   2.25538507e-01,   6.83735728e-01,
                         -7.31660426e-01,  -7.56905079e-01,   6.74238563e-01,
                          2.55308717e-01,  -9.95800197e-01,   1.36731729e-01,
                          7.04969049e-01,  -6.57311440e-01,  -8.15453410e-01,
                          6.45364940e-01,   3.33322525e-01,  -9.88573432e-01,
                          4.14961688e-02,   7.20663190e-01,  -5.72581291e-01,
                         -8.63670707e-01,   6.11065924e-01,   4.03684586e-01,
                         -9.77060854e-01,  -8.63780007e-02,   7.29055583e-01,
                         -4.74859297e-01,  -9.02949691e-01,   5.69671333e-01,
                          4.65444356e-01,  -9.59428430e-01,  -2.29380950e-01,
                          7.35930979e-01,  -3.64375144e-01,  -9.34516549e-01,
                          5.21855474e-01,   5.20464897e-01,  -9.35915351e-01,
                         -3.56901348e-01,   7.35911548e-01,  -2.37900600e-01,
                         -9.61276829e-01,   4.68774199e-01,   5.68311155e-01,
                         -9.04084444e-01,  -4.69336778e-01,   7.30977714e-01,
                         -9.67414230e-02,  -9.76796150e-01,   4.07452285e-01,
                          6.10108674e-01,  -8.65457654e-01,  -5.68472266e-01,
                          7.20346630e-01,   3.59960571e-02,  -9.89236891e-01,
                          3.38264346e-01,   6.45633280e-01,  -8.17136586e-01,
                         -6.55978441e-01,   7.06180453e-01,   1.31730676e-01,
                         -9.95989919e-01,   2.60032773e-01,   6.76044822e-01,
                         -7.58212686e-01,  -7.28976667e-01,   6.86027825e-01,
                          2.19198033e-01,  -9.98224139e-01,   1.75599560e-01,
                          6.97920561e-01,  -6.90339565e-01,  -7.91965306e-01,
                          6.60693526e-01,   3.00899327e-01,  -9.92999852e-01,
                          8.30719024e-02,   7.15225637e-01,  -6.10126913e-01,
                         -8.44576478e-01,   6.27544522e-01,   3.74413252e-01,
                         -9.84819293e-01,  -2.14157682e-02,   7.27619469e-01,
                         -5.18375933e-01,  -8.87582421e-01,   5.88598669e-01,
                          4.39414680e-01,  -9.68198538e-01,  -1.69167265e-01,
                          7.34868944e-01,  -4.13194478e-01,  -9.21417058e-01,
                          5.43613911e-01,   4.98414159e-01,  -9.47427213e-01,
                         -3.04747045e-01,   7.36069739e-01,  -2.92918086e-01,
                         -9.49800074e-01,   4.90280122e-01,   5.48539817e-01,
                         -9.18524384e-01,  -4.22310591e-01,   7.33736217e-01,
                         -1.57425553e-01,  -9.69843984e-01,   4.32570130e-01,
                          5.91508865e-01,  -8.83035362e-01,  -5.26625752e-01,
                          7.24723637e-01,  -1.10502299e-02,  -9.82980728e-01,
                          3.66317391e-01,   6.30046546e-01,  -8.40388477e-01,
                         -6.18837476e-01,   7.13849664e-01,   9.21561420e-02,
                         -9.92771924e-01,   2.93751806e-01,   6.62699103e-01,
                         -7.85531104e-01,  -6.97544456e-01,   6.94588542e-01,
                          1.83281228e-01,  -9.96092319e-01,   2.13448301e-01,
                          6.86596394e-01,  -7.22560465e-01,  -7.66191900e-01,
                          6.71606958e-01,   2.67713875e-01,  -9.95041907e-01,
                          1.23167925e-01,   7.07088590e-01,  -6.47809863e-01,
                         -8.24044704e-01,   6.42693520e-01,   3.44556749e-01,
                         -9.88313138e-01,   2.77745165e-02,   7.21505702e-01,
                         -5.61174631e-01,  -8.70956838e-01,   6.07434928e-01,
                          4.13634211e-01,  -9.75505114e-01,  -1.05898552e-01,
                          7.30572402e-01,  -4.60103035e-01,  -9.07763004e-01,
                          5.64480960e-01,   4.75723416e-01,  -9.58002150e-01,
                         -2.47276604e-01,   7.36820102e-01,  -3.45507324e-01,
                         -9.38637435e-01,   5.13960421e-01,   5.28714240e-01,
                         -9.31752026e-01,  -3.73433888e-01,   7.34691501e-01,
                         -2.17990488e-01,  -9.62075412e-01,   4.59148139e-01,
                          5.75086653e-01,  -8.98865938e-01,  -4.84323293e-01,
                          7.29187608e-01,  -7.57117942e-02,  -9.77957964e-01,
                          3.97165537e-01,   6.13820016e-01,  -8.57365966e-01,
                         -5.80742419e-01,   7.19014525e-01,   4.96795923e-02,
                         -9.89312053e-01,   3.27628434e-01,   6.48696542e-01,
                         -8.09368134e-01,  -6.64837122e-01,   7.02015102e-01,
                          1.46627769e-01,  -9.94666696e-01,   2.50489444e-01,
                          6.76267087e-01,  -7.50768304e-01,  -7.36456811e-01,
                          6.81953073e-01,   2.32324466e-01,  -9.96086895e-01,
                          1.63952157e-01,   6.98252857e-01,  -6.82750523e-01,
                         -7.96605706e-01,   6.57416761e-01,   3.09562445e-01,
                         -9.92986083e-01,   6.89004064e-02,   7.16761827e-01,
                         -6.01408958e-01,  -8.48768413e-01,   6.25535786e-01,
                          3.82270128e-01,  -9.82982159e-01,  -4.24381271e-02,
                          7.29302704e-01,  -5.05862594e-01,  -8.90511572e-01,
                          5.85491538e-01,   4.46639836e-01,  -9.67214048e-01,
                         -1.86649024e-01,   7.35565662e-01,  -3.96370083e-01,
                         -9.25219238e-01,   5.40387511e-01,   5.04420936e-01,
                         -9.43690240e-01,  -3.18906695e-01,   7.36806154e-01,
                         -2.76469886e-01,  -9.52327847e-01,   4.88097638e-01,
                          5.54594338e-01,  -9.13488269e-01,  -4.36935753e-01,
                          7.32535183e-01,  -1.40155807e-01,  -9.74443316e-01,
                          4.28198308e-01,   5.98757029e-01,  -8.76277566e-01,
                         -5.41927636e-01,   7.25452900e-01,   3.92272556e-03,
                         -9.87642229e-01,   3.59998584e-01,   6.35195315e-01,
                         -8.30342174e-01,  -6.31539762e-01,   7.11814940e-01,
                          1.03308260e-01,  -9.95355666e-01,   2.86710292e-01,
                          6.64596498e-01,  -7.76515067e-01,  -7.08307862e-01,
                          6.93002760e-01,   1.94863886e-01,  -9.97806251e-01,
                          2.03052312e-01,   6.89725161e-01,  -7.11920023e-01,
                         -7.75670946e-01,   6.69393420e-01,   2.78312922e-01,
                         -9.97801363e-01,   1.12113960e-01,   7.09429145e-01,
                         -6.36729181e-01,  -8.29228401e-01,   6.39759362e-01,
                          3.51713449e-01,  -9.88282442e-01,   1.42996591e-02,
                          7.25453913e-01,  -5.46759367e-01,  -8.75643134e-01,
                          6.02550983e-01,   4.22444820e-01,  -9.73094761e-01,
                         -1.25002593e-01,   7.34829605e-01,  -4.43647027e-01,
                         -9.12095964e-01,   5.58360457e-01,   4.83838558e-01,
                         -9.53480780e-01,  -2.63889283e-01,   7.40352869e-01,
                         -3.29189688e-01,  -9.42171514e-01,   5.09396672e-01,
                          5.35541296e-01,  -9.27260995e-01,  -3.88354748e-01,
                          7.38894582e-01,  -1.99313790e-01,  -9.66362119e-01,
                          4.50883687e-01,   5.84597230e-01,  -8.93339396e-01,
                         -5.00976861e-01,   7.32744217e-01,  -5.56978434e-02,
                         -9.81663108e-01,   3.86654884e-01,   6.22499108e-01,
                         -8.51978540e-01,  -5.94921649e-01,   7.19194412e-01,
                          6.21034838e-02,  -9.93176937e-01,   3.17854345e-01,
                          6.55544400e-01,  -8.00862730e-01,  -6.77311480e-01,
                          6.99498773e-01,   1.56463876e-01,  -9.98580873e-01,
                          2.40243003e-01,   6.81629419e-01,  -7.41884530e-01,
                         -7.48356938e-01,   6.77822888e-01,   2.43316546e-01,
                         -9.97472882e-01,   1.52972654e-01,   7.01748133e-01,
                         -6.72109365e-01,  -8.06046188e-01,   6.50248885e-01,
                          3.21218759e-01,  -9.90406930e-01,   5.73881231e-02,
                          7.19881535e-01,  -5.88919580e-01,  -8.57246578e-01,
                          6.15661025e-01,   3.94230992e-01,  -9.78627980e-01,
                         -6.09377511e-02,   7.31557488e-01,  -4.89655226e-01,
                         -8.99101257e-01,   5.77408731e-01,   4.57703769e-01,
                         -9.61769700e-01,  -2.06413075e-01,   7.36468911e-01,
                         -3.80136043e-01,  -9.31483269e-01,   5.29240906e-01,
                          5.13308764e-01,  -9.37590063e-01,  -3.38407904e-01,
                          7.38133669e-01,  -2.56105185e-01,  -9.56577659e-01,
                          4.75811630e-01,   5.62005818e-01,  -9.06314433e-01,
                         -4.54760194e-01,   7.33853936e-01,  -1.16537213e-01,
                         -9.75346029e-01,   4.13935751e-01,   6.05302274e-01,
                         -8.68997753e-01,  -5.56657851e-01,   7.23339260e-01,
                          2.32063532e-02,  -9.87696052e-01,   3.48371953e-01,
                          6.39807582e-01,  -8.22405457e-01,  -6.44108057e-01,
                          7.07218170e-01,   1.19913720e-01,  -9.96170044e-01,
                          2.72198290e-01,   6.68910980e-01,  -7.69265950e-01,
                         -7.19568670e-01,   6.86341345e-01,   2.10724086e-01,
                         -9.97569621e-01,   1.87741533e-01,   6.93159282e-01,
                         -7.03092396e-01,  -7.84616768e-01,   6.62328184e-01,
                          2.93265343e-01,  -9.92070973e-01,   9.65795815e-02,
                          7.08743036e-01,  -6.26405299e-01,  -8.36680651e-01,
                          6.29830897e-01,   3.66216630e-01,  -9.81781602e-01,
                         -2.11968878e-03,   7.22067535e-01,  -5.33373654e-01,
                         -8.82666111e-01,   5.90864480e-01,   4.33936417e-01,
                         -9.66638446e-01,  -1.48503006e-01,   7.30682731e-01,
                         -4.28675860e-01,  -9.19708610e-01,   5.47273993e-01,
                          4.91778076e-01,  -9.46782649e-01,  -2.87277490e-01,
                          7.34323919e-01,  -3.11060160e-01,  -9.45684612e-01,
                          4.98824090e-01,   5.42644262e-01,  -9.19126093e-01,
                         -4.09481168e-01,   7.34219372e-01,  -1.76162645e-01,
                         -9.69301581e-01,   4.39606428e-01,   5.89900613e-01,
                         -8.86428654e-01,  -5.16643286e-01,   7.25912333e-01,
                         -2.87507996e-02,  -9.85819042e-01,   3.73503745e-01,
                          6.28479719e-01,  -8.45519781e-01,  -6.08200908e-01,
                          7.12850630e-01,   7.80342743e-02,  -9.95780528e-01,
                          3.02941769e-01,   6.58290327e-01,  -7.95114636e-01,
                         -6.89615071e-01,   6.94614172e-01,   1.70495152e-01,
                         -1.00000000e+00,   2.23655492e-01,   6.84617937e-01,
                         -7.33533978e-01,  -7.58769631e-01,   6.71988368e-01,
                          2.56283909e-01,  -9.95383799e-01,   1.36405692e-01,
                          7.03669548e-01,  -6.59646034e-01,  -8.16922665e-01,
                          6.43122256e-01,   3.34930778e-01,  -9.88486648e-01,
                          3.99730317e-02,   7.17220426e-01,  -5.74403942e-01,
                         -8.64330709e-01,   6.10261977e-01,   4.04725820e-01,
                         -9.75212038e-01,  -8.83654952e-02,   7.28125870e-01,
                         -4.76881772e-01,  -9.02467310e-01,   5.69326758e-01,
                          4.65497762e-01,  -9.58354294e-01,  -2.30562419e-01,
                          7.33245254e-01,  -3.64893019e-01,  -9.32472825e-01,
                          5.21191716e-01,   5.20365417e-01,  -9.34731245e-01,
                         -3.58700722e-01,   7.35476971e-01,  -2.37258375e-01,
                         -9.54722345e-01,   4.67534572e-01,   5.66456258e-01,
                         -9.01101172e-01,  -4.68836218e-01,   7.29276478e-01,
                         -9.68582332e-02,  -9.75234091e-01,   4.05401736e-01,
                          6.06978834e-01,  -8.61283600e-01,  -5.69730222e-01,
                          7.19222724e-01,   3.52519900e-02,  -9.87416327e-01,
                          3.34306866e-01,   6.43161476e-01,  -8.15785229e-01,
                         -6.56923175e-01,   7.04661310e-01,   1.30717486e-01,
                         -9.95087564e-01,   2.59724438e-01,   6.70563877e-01,
                         -7.63573289e-01,  -7.27847219e-01,   6.83128297e-01,
                          2.17145965e-01,  -9.95416760e-01,   1.76901653e-01,
                          6.93299651e-01,  -6.95352316e-01,  -7.89664865e-01,
                          6.59657538e-01,   3.00430179e-01,  -9.93486345e-01,
                          8.44440162e-02,   7.12840021e-01,  -6.14729047e-01,
                         -8.44399929e-01,   6.29460394e-01,   3.70602161e-01,
                         -9.83840287e-01,  -1.89480092e-02,   7.25387275e-01,
                         -5.21710932e-01,  -8.85834157e-01,   5.88479757e-01,
                          4.39107865e-01,  -9.70304191e-01,  -1.67720750e-01,
                          7.32126772e-01,  -4.15040731e-01,  -9.19912994e-01,
                          5.43202519e-01,   4.95110154e-01,  -9.48321402e-01,
                         -3.02696168e-01,   7.35141814e-01,  -2.95127541e-01,
                         -9.47961628e-01,   4.91723806e-01,   5.47644615e-01,
                         -9.21056807e-01,  -4.21809286e-01,   7.36244261e-01,
                         -1.58568442e-01,  -9.68691707e-01,   4.35578316e-01,
                          5.92144608e-01,  -8.83593142e-01,  -5.25963783e-01,
                          7.26513982e-01,  -1.04413005e-02,  -9.84368145e-01,
                          3.65246743e-01,   6.29420459e-01,  -8.39130044e-01,
                         -6.19334459e-01,   7.12911069e-01,   8.91494080e-02,
                         -9.95232284e-01,   2.91730821e-01,   6.60314739e-01,
                         -7.85501659e-01,  -6.96348071e-01,   6.93880320e-01,
                          1.80751324e-01,  -9.96743619e-01,   2.07956314e-01,
                          6.86781347e-01,  -7.22928405e-01,  -7.66873956e-01,
                          6.69739187e-01,   2.65640855e-01,  -9.96058226e-01,
                          1.23608410e-01,   7.07769156e-01,  -6.48584783e-01,
                         -8.23584557e-01,   6.44939661e-01,   3.43595147e-01,
                         -9.88931358e-01,   2.52074674e-02,   7.23691225e-01,
                         -5.60547411e-01,  -8.70041907e-01,   6.08857155e-01,
                          4.12003517e-01,  -9.75840271e-01,  -1.08451985e-01,
                          7.30329931e-01,  -4.60765719e-01,  -9.07205939e-01,
                          5.65443575e-01,   4.76256728e-01,  -9.56602335e-01,
                         -2.52181053e-01,   7.34955370e-01,  -3.45911860e-01,
                         -9.36394095e-01,   5.17409801e-01,   5.27246058e-01,
                         -9.29294050e-01,  -3.70575339e-01,   7.27123618e-01,
                         -2.13262931e-01,  -9.38203573e-01,   4.45430845e-01,
                          5.51797032e-01,  -8.63000333e-01,  -4.54660982e-01,
                          6.85994625e-01,  -6.72247410e-02,  -9.17493165e-01,
                          3.58208269e-01,   5.61732650e-01,  -7.82452285e-01,
                         -5.13268352e-01,   6.41523778e-01,   4.06444259e-02,
                         -8.87083948e-01,   2.75829226e-01,   5.54702938e-01,
                         -6.90206945e-01,  -5.52367806e-01,   5.90236723e-01,
                          1.13048725e-01,  -8.45793605e-01,   1.91870362e-01,
                          5.47693312e-01,  -5.93970358e-01,  -5.74191332e-01,
                          5.29891908e-01,   1.70629501e-01,  -7.99570799e-01,
                          1.15251027e-01,   5.24249434e-01,  -4.94309187e-01,
                         -5.80333233e-01,   4.68999237e-01,   2.07600623e-01,
                         -7.38183975e-01,   4.22368832e-02,   4.94952172e-01,
                         -3.90344530e-01,  -5.73632956e-01,   4.02030379e-01,
                          2.33069316e-01,  -6.70657396e-01,  -2.33792644e-02,
                          4.57096785e-01,  -2.92305052e-01,  -5.58247626e-01,
                          3.39385599e-01,   2.46504053e-01,  -5.95113933e-01,
                         -9.37644914e-02,   4.17644531e-01,  -1.95069492e-01,
                         -5.24765790e-01,   2.70006001e-01,   2.50065535e-01,
                         -5.14138520e-01,  -1.43559188e-01,   3.66425663e-01,
                         -1.13299720e-01,  -4.81087804e-01,   2.10454926e-01,
                          2.38086894e-01,  -4.23460990e-01,  -1.68317005e-01,
                          3.12741905e-01,  -4.84872907e-02,  -4.22416180e-01,
                          1.53251439e-01,   2.15707392e-01,  -3.39219302e-01,
                         -1.73123375e-01,   2.54962534e-01,  -1.96455210e-03,
                         -3.53073388e-01,   1.00566961e-01,   1.86446726e-01,
                         -2.47450128e-01,  -1.64208785e-01,   1.91747859e-01,
                          2.23536622e-02,  -2.72688985e-01,   5.74639179e-02,
                          1.45674899e-01,  -1.63838401e-01,  -1.30383745e-01,
                          1.31698355e-01,   2.59623136e-02,  -1.80146635e-01,
                          2.46007442e-02,   9.37984586e-02,  -8.53565335e-02,
                          9.07036476e-04,   3.41989961e-03,  -6.33335090e-04,
                         -8.84785084e-04,  -7.20460783e-04],
                         dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri6",
    rate = 41000,
    data = numpy.array([ -1.66400452e-03,  -4.61504236e-03,  -4.37995279e-03,
                         -2.06184876e-03,  -7.35455938e-03,  -8.29592068e-03,
                          3.93814733e-03,  -2.34191291e-04,  -1.37219252e-02,
                         -1.96055416e-03,   8.43970384e-03,  -1.44007220e-03,
                          4.45127458e-04,   6.52575400e-03,  -3.14644980e-03,
                         -4.14997153e-03,   3.75330797e-03,  -2.82484828e-03,
                         -1.06096482e-02,  -6.00386132e-03,  -4.06970689e-03,
                         -8.91786441e-03,  -5.65893156e-03,   2.15125433e-03,
                         -3.64821078e-03,  -7.28524290e-03,   5.68892481e-03,
                         -5.88826486e-04,  -2.07792241e-02,  -4.58723260e-03,
                          1.40856598e-02,  -8.36516451e-03,  -2.12536883e-02,
                         -3.49444081e-03,   4.69072074e-05,  -1.28452517e-02,
                         -7.65311485e-03,   1.27574448e-02,   5.92704443e-03,
                         -1.96095314e-02,  -5.86541742e-03,   1.26664815e-02,
                         -1.02010118e-02,  -6.73568714e-03,   1.50355045e-02,
                         -1.65203735e-02,  -3.33470851e-02,  -1.98972225e-03,
                         -1.75152975e-03,  -1.59817357e-02,  -2.80638837e-04,
                          1.36926007e-02,   2.21492909e-03,  -2.91354768e-02,
                         -2.31836215e-02,   2.93796360e-02,   1.15343463e-02,
                         -4.66261320e-02,  -6.91753859e-03,   3.06623857e-02,
                         -2.37685814e-02,  -2.87632067e-02,   2.51350962e-02,
                          1.08254841e-02,  -2.59392057e-02,  -5.34583395e-03,
                          1.11940550e-02,  -9.57275834e-03,  -7.14386348e-03,
                          1.08122891e-02,  -1.13390293e-02,  -1.77228078e-02,
                          2.95466725e-02,   2.90898867e-02,  -2.38955449e-02,
                         -1.60499848e-02,   2.63535976e-02,   1.46350181e-02,
                         -1.75055917e-02,  -8.84492323e-03,   2.17598360e-02,
                          1.65920723e-02,  -2.19153091e-02,  -2.80903969e-02,
                          1.07280648e-04,  -9.43336345e-04,  -3.44274342e-02,
                         -3.93728241e-02,  -1.53562077e-03,  -9.64575156e-05,
                         -5.64743578e-02,  -5.33026569e-02,   1.59638077e-02,
                          1.35260746e-02,  -3.30679305e-02,  -1.57326888e-02,
                          2.02768692e-03,  -2.55671032e-02,  -1.62902884e-02,
                          1.27665019e-02,  -1.97177846e-02,  -3.86641510e-02,
                          1.93417128e-02,   2.27771681e-02,  -4.18499932e-02,
                         -6.89047016e-03,   4.93287370e-02,  -2.79272050e-02,
                         -6.77179173e-02,   2.30644103e-02,   4.80314158e-02,
                         -1.99743956e-02,  -3.70781012e-02,   7.14650657e-03,
                          3.43117453e-02,   3.91620863e-03,  -1.57654509e-02,
                          2.86797564e-02,   2.31682118e-02,  -4.41409163e-02,
                         -2.95813251e-02,   1.79147087e-02,   2.88105337e-03,
                          6.91044517e-03,   3.34769115e-02,   4.65970347e-03,
                         -2.55232453e-02,   5.23781125e-03,   3.17046233e-02,
                         -1.39812735e-04,  -1.07456474e-02,   3.50289978e-02,
                          1.60588976e-02,  -4.66253981e-02,  -1.56277267e-04,
                          6.18922003e-02,   8.41496512e-03,  -3.46661098e-02,
                          3.32419574e-03,   2.55528837e-02,   4.52329637e-03,
                         -9.36301332e-03,   8.19347706e-03,   2.11960711e-02,
                          4.59267525e-03,   1.65961668e-04,  -2.16097018e-04,
                         -1.78080872e-02,  -2.27682781e-03,   1.32061029e-02,
                         -1.21945161e-02,  -1.75829942e-03,   1.95902996e-02,
                         -1.00412033e-02,  -5.20822546e-03,   3.38765234e-02,
                          1.77533031e-02,  -7.86124077e-03,  -3.66401719e-03,
                         -1.06042363e-02,  -8.04600678e-03,   1.62965469e-02,
                          9.79950093e-03,  -2.10202690e-02,  -2.02061515e-02,
                          2.56495713e-03,   2.60485453e-03,  -9.70124640e-03,
                         -4.11906932e-03,   7.25398539e-03,   2.12107296e-03,
                         -4.91252169e-03,   9.36408900e-03,   9.93346330e-03,
                         -2.59315055e-02,  -2.06667837e-02,   2.84242425e-02,
                          1.93498190e-02,  -1.31606478e-02,  -6.93193451e-03,
                         -1.32719399e-02,  -1.50629077e-02,  -3.17143928e-03,
                         -2.66893450e-02,  -1.65409017e-02,   2.43268311e-02,
                          1.05195423e-03,  -9.25225392e-03,   1.55146588e-02,
                         -1.22567173e-02,  -1.75277088e-02,   2.57458314e-02,
                          2.00227443e-02,  -1.29659567e-02,  -2.35924870e-02,
                          5.18162735e-04,   3.44881527e-02,   2.86696013e-03,
                         -2.03753002e-02,   2.34431569e-02,  -3.89570114e-03,
                         -5.89628294e-02,  -1.39341988e-02,   1.55631015e-02,
                         -1.04868114e-02,  -2.65339133e-03,   1.45587334e-02,
                          1.23265879e-02,  -1.16687482e-02,  -3.73641402e-02,
                         -8.16493575e-03,   2.50735115e-02,   1.06755057e-02,
                         -9.95530840e-03,  -2.27234811e-02,  -1.78544093e-02,
                         -2.14199945e-02,  -2.58872733e-02,   2.55044512e-02,
                         -6.12154719e-04,  -5.10599501e-02,   5.67062907e-02,
                         -9.74326134e-02,  -5.07486939e-01,  -3.48910719e-01,
                          6.01226315e-02,  -5.77796623e-02,  -1.22255221e-01,
                          6.62193373e-02,  -2.12146536e-01,  -6.03265166e-01,
                         -3.74677807e-01,   6.08986355e-02,  -3.41016017e-02,
                         -5.59575140e-01,  -7.47481704e-01,  -5.81906915e-01,
                         -7.30844080e-01,  -7.58880675e-01,  -2.58878827e-01,
                         -1.93306208e-01,  -5.14790416e-01,  -2.94542998e-01,
                         -1.63514867e-01,  -6.24537826e-01,  -8.20558667e-01,
                         -6.39637291e-01,  -6.06225193e-01,  -6.46292329e-01,
                         -6.58086598e-01,  -6.65904403e-01,  -6.31572127e-01,
                         -6.48194253e-01,  -6.91289783e-01,  -6.72381103e-01,
                         -6.48455918e-01,  -6.43106163e-01,  -6.86229110e-01,
                         -7.09847927e-01,  -6.12136126e-01,  -6.49574876e-01,
                         -7.78132439e-01,  -4.55859512e-01,  -5.06942794e-02,
                         -3.90147626e-01,  -8.57212126e-01,  -5.31164289e-01,
                         -1.23393349e-01,  -4.06713575e-01,  -7.24860311e-01,
                         -6.36157751e-01,  -6.10910237e-01,  -7.01714814e-01,
                         -6.57701910e-01,  -6.29227817e-01,  -6.72699153e-01,
                         -6.72983348e-01,  -6.52445972e-01,  -6.33308053e-01,
                         -6.59377813e-01,  -6.77214742e-01,  -6.03546560e-01,
                         -6.56479239e-01,  -7.19200790e-01,  -3.95594627e-01,
                         -1.51658535e-01,  -4.52855051e-01,  -7.32377589e-01,
                         -6.70416951e-01,  -5.98223329e-01,  -6.39581919e-01,
                         -6.96748495e-01,  -5.13350487e-01,  -1.43569335e-01,
                         -2.79669553e-01,  -7.78865576e-01,  -6.16201818e-01,
                         -7.77876303e-02,  -2.58982927e-01,  -7.83346355e-01,
                         -5.96585274e-01,  -8.50266069e-02,  -2.72332549e-01,
                         -7.48068213e-01,  -6.48780584e-01,  -5.30858874e-01,
                         -7.53552496e-01,  -4.98888850e-01,  -8.81147310e-02,
                         -3.66204292e-01,  -4.74572003e-01,  -9.72132161e-02,
                         -3.91356379e-01,  -8.66849542e-01,  -3.97663862e-01,
                         -4.22315001e-02,  -4.61272150e-01,  -4.38119709e-01,
                         -7.61032030e-02,  -4.87724721e-01,  -8.61677825e-01,
                         -3.14700902e-01,  -3.45683768e-02,  -5.28252125e-01,
                         -4.88150209e-01,   1.36064529e-01,  -2.55038356e-03,
                         -5.85835576e-01,  -3.65469128e-01,  -9.81611200e-03,
                         -5.17731786e-01,  -8.27457845e-01,  -2.69578993e-01,
                         -1.25684977e-01,  -5.54939449e-01,  -3.53447795e-01,
                         -4.56153601e-02,  -5.60880423e-01,  -8.33471835e-01,
                         -2.92242408e-01,  -1.18180946e-01,  -5.58080971e-01,
                         -7.49646783e-01,  -6.29250884e-01,  -5.64315677e-01,
                         -5.99750400e-01,  -6.82446659e-01,  -6.59843981e-01,
                         -5.85820198e-01,  -6.37031794e-01,  -4.37747180e-01,
                          5.72174862e-02,   6.55777380e-03,  -5.40554225e-01,
                         -5.27551413e-01,   7.09963078e-03,   1.00592867e-01,
                         -3.71348381e-01,  -7.00784683e-01,  -6.36165917e-01,
                         -6.72332764e-01,  -7.72025049e-01,  -3.76843959e-01,
                         -7.89158270e-02,  -4.44514483e-01,  -4.51292306e-01,
                         -7.09483027e-02,  -4.69929665e-01,  -8.53906989e-01,
                         -3.31227243e-01,  -1.42841741e-01,  -5.10058165e-01,
                         -3.74552608e-01,  -1.87531129e-01,  -5.16980529e-01,
                         -7.08248973e-01,  -5.92136443e-01,  -6.02456987e-01,
                         -7.42291868e-01,  -6.85490131e-01,  -3.30643833e-01,
                         -1.48602009e-01,  -4.12949651e-01,  -6.77729607e-01,
                         -7.46094644e-01,  -6.11016989e-01,  -1.89734414e-01,
                         -1.65561482e-01,  -7.29053259e-01,  -6.99948549e-01,
                         -1.20529629e-01,  -2.21124694e-01,  -6.76414371e-01,
                         -7.08882272e-01,  -6.40780866e-01,  -4.51956391e-01,
                          2.73624691e-03,   5.80039397e-02,  -3.48880023e-01,
                         -6.10449314e-01,  -7.54863620e-01,  -7.26849854e-01,
                         -2.67278314e-01,  -7.21820518e-02,  -5.54282844e-01,
                         -8.16596806e-01,  -5.91280103e-01,  -5.77474654e-01,
                         -7.20312536e-01,  -6.36111736e-01,  -5.43052614e-01,
                         -6.09156370e-01,  -7.06628561e-01,  -6.94453359e-01,
                         -5.93999743e-01,  -6.36404872e-01,  -6.97167933e-01,
                         -5.78871429e-01,  -6.39590859e-01,  -6.95567429e-01,
                         -2.60897309e-01,  -8.70066658e-02,  -5.78000128e-01,
                         -7.97199249e-01,  -6.29511178e-01,  -6.03550196e-01,
                         -5.81739008e-01,  -6.30821109e-01,  -7.56009996e-01,
                         -4.91690665e-01,  -1.63323864e-01,  -3.13638151e-01,
                         -6.02124631e-01,  -6.80402517e-01,  -6.15605772e-01,
                         -6.25076950e-01,  -7.33708620e-01,  -5.05258799e-01,
                         -1.53825611e-01,  -3.45454365e-01,  -4.81245130e-01,
                         -1.50136337e-01,  -2.73790926e-01,  -7.52972066e-01,
                         -7.27123380e-01,  -5.55904508e-01,  -6.17999077e-01,
                         -6.53186262e-01,  -6.71361625e-01,  -6.27258599e-01,
                         -5.65051794e-01,  -7.11427867e-01,  -6.16363049e-01,
                         -1.46139652e-01,  -1.57200858e-01,  -6.42659128e-01,
                         -7.51673281e-01,  -5.76439023e-01,  -6.08873546e-01,
                         -7.03502059e-01,  -6.81738377e-01,  -6.35593832e-01,
                         -5.90712965e-01,  -5.76185346e-01,  -6.56800389e-01,
                         -7.10982144e-01,  -5.17780364e-01,  -1.23644091e-01,
                          9.43312198e-02,  -1.73624996e-02,  -5.97024709e-02,
                          5.76793812e-02,  -2.46593297e-01,  -7.80146837e-01,
                         -6.10393703e-01,  -1.30580708e-01,  -2.72782058e-01,
                         -4.52670932e-01,  -1.95619121e-01,  -2.80879587e-01,
                         -6.73894823e-01,  -6.64123595e-01,  -5.81699014e-01,
                         -7.28218496e-01,  -5.46993613e-01,  -3.35311741e-02,
                          7.50337541e-02,  -3.16471249e-01,  -4.83039349e-01,
                         -1.68449014e-01,   5.48803881e-02,  -1.48649048e-02,
                         -2.33157128e-02,   7.39854109e-03,  -4.31464203e-02,
                         -3.86075582e-03,   6.30762354e-02,   1.26090441e-02,
                         -4.78531979e-02,  -4.63967957e-02,  -1.22356564e-02,
                         -1.95560437e-02,  -3.33295651e-02,   7.56072849e-02,
                         -3.43548809e-03,  -4.19679552e-01,  -4.61754978e-01,
                         -3.26160640e-02,   5.93936779e-02,  -1.05861336e-01,
                         -2.67444737e-02,   3.65363061e-02,  -1.70951188e-02,
                          2.39258204e-02,   1.20695587e-02,  -6.46518096e-02,
                         -4.13040444e-02,  -8.27937294e-03,   5.48486318e-03,
                          3.63626778e-02,   1.68008450e-02,  -1.79140607e-03,
                          1.09762345e-02,  -2.57026427e-03,  -3.73932975e-03,
                         -1.69496220e-02,  -5.04313707e-02,   7.76196225e-03,
                          4.83250692e-02,  -4.88431491e-02,  -7.82181472e-02,
                          2.33837236e-02,   5.90061247e-02,   1.34146567e-02,
                         -1.43622346e-02,  -2.09732987e-02,  -1.51310330e-02,
                         -9.38674901e-03,  -2.12743003e-02,  -1.87883526e-02,
                          2.22706329e-02,   4.58514504e-02,  -4.17822041e-03,
                         -4.38814424e-02,  -1.08292028e-02,  -2.14144979e-02,
                         -2.31086221e-02,   9.16155428e-02,  -4.82931212e-02,
                         -4.94389057e-01,  -4.37663615e-01,   1.09143659e-01,
                          4.33363877e-02,  -5.18320501e-01,  -4.55510497e-01,
                          1.43168215e-02,   3.57493535e-02,  -8.16373900e-02,
                          8.77525732e-02,   7.69973965e-03,  -4.64884907e-01,
                         -4.73984122e-01,   6.48966655e-02,   3.93625349e-02,
                         -5.43321192e-01,  -4.47192937e-01,  -1.32265892e-02,
                         -4.24189389e-01,  -8.23782265e-01,  -2.93138206e-01,
                         -6.79470375e-02,  -5.30074954e-01,  -4.10427749e-01,
                         -6.22186735e-02,  -5.09792626e-01,  -7.71354973e-01,
                         -2.23667949e-01,  -1.08540565e-01,  -5.31040370e-01,
                         -3.61884117e-01,  -1.21063411e-01,  -6.43445015e-01,
                         -7.98617125e-01,  -1.04833074e-01,  -6.56015351e-02,
                         -6.59497976e-01,  -3.07305485e-01,   3.31813931e-01,
                         -1.58134818e-01,  -6.46487772e-01,  -2.15493098e-01,
                         -1.67733788e-01,  -6.08823955e-01,  -2.27788970e-01,
                          3.09317708e-01,  -1.89541399e-01,  -6.31152987e-01,
                         -1.87492356e-01,  -1.24338984e-01,  -7.33066916e-01,
                         -6.55234277e-01,  -4.78885286e-02,  -1.98837712e-01,
                         -7.15497851e-01,  -7.00693548e-01,  -5.93072057e-01,
                         -5.34039319e-01,  -6.59021735e-02,   1.35896131e-01,
                         -3.97160292e-01,  -5.40867507e-01,  -8.50471482e-02,
                         -2.70800084e-01,  -8.16022933e-01,  -4.89583224e-01,
                          4.22464274e-02,  -2.99515694e-01,  -7.61604071e-01,
                         -6.46318078e-01,  -5.70765734e-01,  -6.90086365e-01,
                         -6.00108743e-01,  -5.77700973e-01,  -6.82181597e-01,
                         -4.10705477e-01,  -1.49681821e-01,  -4.93262708e-01,
                         -8.03571939e-01,  -6.21774018e-01,  -5.51001668e-01,
                         -6.47581637e-01,  -3.43947768e-01,   9.40364078e-02,
                         -1.21054342e-02,  -5.04671872e-01,  -6.89695477e-01,
                         -4.15673673e-01,  -1.39193356e-01,  -5.42274502e-04,
                          1.36910260e-01,  -7.83406049e-02,  -5.85988879e-01,
                         -4.15306091e-01,   2.24103257e-01,   3.99282714e-03,
                         -6.33714080e-01,  -4.16717917e-01,  -7.47418627e-02,
                         -5.07051349e-01,  -7.81886458e-01,  -3.66460353e-01,
                          3.32421670e-03,   8.66957530e-02,   1.73652675e-02,
                         -3.04507852e-01,  -4.70532864e-01,  -1.79052308e-01,
                         -1.51358649e-01,  -6.77033722e-01,  -7.97189713e-01,
                         -1.68889076e-01,   1.78760931e-01,  -2.28526443e-01,
                         -5.37944555e-01,  -2.78783113e-01,   1.21366186e-02,
                          4.81732227e-02,   2.06666682e-02,  -1.05760396e-02,
                          2.33592675e-03,  -3.19653600e-02,  -3.65418881e-01,
                         -7.20179379e-01,  -7.38486052e-01,  -6.06716871e-01,
                         -2.81397283e-01,   1.75139904e-01,   1.52834551e-02,
                         -5.47052860e-01,  -4.46531266e-01,  -1.01141548e-02,
                          1.89552549e-02,   6.17568381e-02,   1.56914338e-01,
                         -1.85958683e-01,  -4.96411979e-01,  -3.66239786e-01,
                         -2.95959055e-01,  -3.47590268e-01,  -1.23785481e-01,
                          8.85777101e-02,  -2.06513405e-01,  -6.95862770e-01,
                         -7.16318667e-01,  -3.17042172e-01,  -7.80082541e-03,
                          1.03346355e-01,   2.39590425e-02,  -3.20244133e-01,
                         -5.25825858e-01,  -2.72436887e-01,   4.32610437e-02,
                          1.46696001e-01,   1.38021216e-01,   1.15148425e-02,
                         -8.55602622e-02,   8.48303828e-03,   7.94978067e-02,
                          4.35888432e-02,   4.21077535e-02,   2.37831138e-02,
                         -4.75264676e-02,  -7.71118999e-02,  -4.30615470e-02,
                          3.97405383e-05,  -3.00047025e-02,  -6.00396581e-02,
                          1.35109369e-02,  -5.18855359e-03,  -1.12603284e-01,
                         -1.40629895e-02,   1.07236952e-01,   3.46609168e-02,
                          2.94158757e-02,   6.61524013e-02,  -3.39515205e-03,
                          5.17769903e-03,   3.02462699e-03,  -5.44940978e-02,
                          8.07079077e-02,   2.44822092e-02,  -4.46500421e-01,
                         -4.95081037e-01,   3.28408740e-02,   2.38626435e-01,
                          1.69562865e-02,  -1.19122498e-01,  -1.36181712e-01,
                         -1.11290306e-01,  -1.71970706e-02,   5.81540950e-02,
                          7.54643902e-02,   5.80888316e-02,   4.00910378e-02,
                          5.43078184e-02,   3.26625742e-02,  -1.47404177e-02,
                          4.77246894e-03,   2.76610963e-02,   3.94056998e-02,
                          7.72816092e-02,   7.86766541e-05,  -1.10036179e-01,
                          6.27918262e-03,   1.06727354e-01,  -8.59809145e-02,
                         -2.09437609e-01,  -3.09834126e-02,   8.91804099e-02,
                          1.09690055e-02,  -1.19164158e-02,   1.56291053e-02,
                         -3.06532644e-02,   1.10348323e-02,   1.01028115e-01,
                         -1.40285090e-01,  -5.74190378e-01,  -6.43610537e-01,
                         -4.82949883e-01,  -5.75435877e-01,  -6.24879539e-01,
                         -2.36071050e-01,   8.78053829e-02,  -1.96331944e-02,
                         -6.72028512e-02,   3.06736156e-02,  -2.06533998e-01,
                         -4.62103039e-01,  -1.87101305e-01,   1.12020805e-01,
                         -4.31117900e-02,  -1.69144258e-01,   1.44644594e-02,
                          1.32619262e-01,   4.00116928e-02,  -1.63485315e-02,
                          4.39647064e-02,   2.89049745e-03,  -1.26049623e-01,
                         -6.52304804e-03,   2.02444538e-01,   8.10046941e-02,
                         -6.68870360e-02,   1.18693728e-02,  -4.59218733e-02,
                         -1.23931341e-01,   3.99023630e-02,   7.54593834e-02,
                          5.46369702e-04,   1.08778588e-01,   7.57820532e-02,
                         -1.12893105e-01,  -6.40601739e-02,   6.62269294e-02,
                          1.38516262e-01,   1.46285951e-01,  -1.92384496e-01,
                         -5.21984994e-01,  -2.84887582e-01,   3.20288055e-02,
                          5.39501235e-02,   1.19759209e-01,   1.43670350e-01,
                         -2.01407634e-02,  -8.23894367e-02,  -2.77338717e-02,
                          2.48658564e-02,   5.04729934e-02,  -3.09025627e-02,
                          1.94170866e-02,   1.73779979e-01,  -1.58931479e-01,
                         -5.67307115e-01,  -1.86930716e-01,   2.60509521e-01,
                          3.41001935e-02,  -7.26756379e-02,   1.14769176e-01,
                         -1.91030011e-01,  -5.64799905e-01,  -2.22008079e-01,
                          1.67604357e-01,  -1.02550596e-01,  -5.25089383e-01,
                         -6.52801096e-01,  -6.75802469e-01,  -6.32880509e-01,
                         -4.85571980e-01,  -4.69208568e-01,  -6.12528145e-01,
                         -6.65384471e-01,  -6.25257313e-01,  -6.19234383e-01,
                         -5.80964863e-01,  -5.07473886e-01,  -5.35534739e-01,
                         -6.15429819e-01,  -6.02878630e-01,  -5.82239330e-01,
                         -6.69180632e-01,  -7.20004618e-01,  -6.22012079e-01,
                         -5.63136280e-01,  -6.68694437e-01,  -7.34438002e-01,
                         -6.00020289e-01,  -4.39319998e-01,  -4.63049561e-01,
                         -5.98158360e-01,  -6.65059268e-01,  -6.70829177e-01,
                         -6.89218879e-01,  -6.60142779e-01,  -5.54419816e-01,
                         -5.08768380e-01,  -5.81771910e-01,  -5.93938589e-01,
                         -4.80234027e-01,  -5.12862206e-01,  -6.87223673e-01,
                         -5.32044351e-01,  -1.68463051e-01,  -2.69897878e-01,
                         -6.38338089e-01,  -6.38656139e-01,  -5.24903476e-01,
                         -6.40378356e-01,  -6.93279505e-01,  -6.13058805e-01,
                         -6.06139779e-01,  -6.65041387e-01,  -7.24709630e-01,
                         -6.39330804e-01,  -4.00028855e-01,  -3.85858119e-01,
                         -6.12242222e-01,  -6.94621265e-01,  -6.81339443e-01,
                         -6.92027509e-01,  -5.98151922e-01,  -5.34140408e-01,
                         -5.94725668e-01,  -6.10629380e-01,  -6.20633125e-01,
                         -6.56889319e-01,  -6.06762171e-01,  -5.67402244e-01,
                         -5.99854410e-01,  -6.27140522e-01,  -6.62883043e-01,
                         -6.24628186e-01,  -5.02448082e-01,  -5.28681040e-01,
                         -6.62682116e-01,  -6.63200557e-01,  -5.86702406e-01,
                         -6.10427022e-01,  -7.19056129e-01,  -6.84508562e-01,
                         -4.63753492e-01,  -4.40653086e-01,  -6.29016459e-01,
                         -6.01700604e-01,  -5.02845585e-01,  -5.73297620e-01,
                         -5.85939705e-01,  -6.34134889e-01,  -7.54501164e-01,
                         -6.24957442e-01,  -5.44494569e-01,  -6.38586819e-01,
                         -3.67726147e-01,  -1.37589365e-01,  -4.05858725e-01,
                         -3.65108579e-01,  -6.51937574e-02,  -3.99711013e-01,
                         -8.31369460e-01,  -7.12945938e-01,  -5.88733256e-01,
                         -6.19058251e-01,  -5.59920728e-01,  -5.56462169e-01,
                         -5.76446533e-01,  -5.69771111e-01,  -6.61290407e-01,
                         -6.62414014e-01,  -5.53482771e-01,  -5.87654769e-01,
                         -6.20005727e-01,  -5.51443040e-01,  -5.78449488e-01,
                         -6.14036918e-01,  -5.74245036e-01,  -6.23837650e-01,
                         -6.95801854e-01,  -6.26650870e-01,  -5.30985534e-01,
                         -5.92828453e-01,  -7.31151223e-01,  -6.82905853e-01,
                         -5.34251094e-01,  -5.86217582e-01,  -6.55262172e-01,
                         -5.51442683e-01,  -5.38772166e-01,  -6.02185249e-01,
                         -6.08134627e-01,  -6.79660857e-01,  -5.56187153e-01,
                         -2.34648034e-01,  -3.53151143e-01,  -5.26208878e-01,
                         -1.10776395e-01,  -9.10359919e-02,  -7.56806314e-01,
                         -6.67156398e-01,  -3.48415971e-02,  -2.49134317e-01,
                         -5.93484700e-01,  -2.22978085e-01,  -2.34222651e-01,
                         -7.48899877e-01,  -4.86806691e-01,   1.39518753e-01,
                         -1.26380801e-01,  -7.53566623e-01,  -7.82366693e-01,
                         -6.08111382e-01,  -6.49653256e-01,  -4.85074103e-01,
                         -1.54602140e-01,  -3.18937629e-01,  -7.36518979e-01,
                         -5.44716775e-01,  -6.33591861e-02,  -2.00445265e-01,
                         -6.39146149e-01,  -6.75814450e-01,  -5.85705698e-01,
                         -6.79212928e-01,  -6.87540591e-01,  -6.01559758e-01,
                         -6.22610331e-01,  -6.26791894e-01,  -5.52304745e-01,
                         -5.98764658e-01,  -7.03717768e-01,  -4.99659956e-01,
                         -4.56470139e-02,   4.33934107e-02,  -3.76463175e-01,
                         -6.81985021e-01,  -5.25823474e-01,  -1.46695554e-01,
                          1.03618287e-01,  -7.93797821e-02,  -5.25834441e-01,
                         -6.89772487e-01,  -6.13503993e-01,  -6.22875631e-01,
                         -6.02378666e-01,  -5.65832913e-01,  -6.65393651e-01,
                         -6.73596859e-01,  -5.30269027e-01,  -5.09567797e-01,
                         -6.23350859e-01,  -6.90895200e-01,  -6.63558960e-01,
                         -6.13788545e-01,  -5.26410341e-01,  -2.29956314e-01,
                          7.30330274e-02,  -1.29643247e-01,  -5.98016620e-01,
                         -6.02454662e-01,  -2.25876912e-01,  -2.80073434e-02,
                          2.21704994e-03,   1.55496458e-02,  -2.53107548e-01,
                         -6.74319625e-01,  -5.88711917e-01,  -1.84005007e-01,
                         -2.47264177e-01,  -4.67025220e-01,  -2.09722564e-01,
                          2.29056459e-02,  -9.44011360e-02,  -2.07145046e-02,
                          1.32471636e-01,  -1.87459633e-01,  -6.44833207e-01,
                         -6.31859243e-01,  -2.20511645e-01,   5.26187196e-02,
                         -1.54161006e-01,  -4.83120382e-01,  -5.61348617e-01,
                         -6.38815403e-01,  -5.91300845e-01,  -1.61158964e-01,
                         -1.30596414e-01,  -6.92034841e-01,  -6.83905005e-01,
                         -1.26342386e-01,  -1.30456850e-01,  -5.56140661e-01,
                         -6.91990912e-01,  -5.97426653e-01,  -5.92942536e-01,
                         -7.56517887e-01,  -7.43924558e-01,  -3.23872268e-01,
                         -9.84499529e-02,  -3.85518283e-01,  -6.08064115e-01,
                         -6.33932531e-01,  -7.08250105e-01,  -6.59230411e-01,
                         -5.58272898e-01,  -6.22917414e-01,  -6.34318709e-01,
                         -5.70309877e-01,  -6.01641476e-01,  -6.43296361e-01,
                         -7.02796519e-01,  -6.38885438e-01,  -2.32828423e-01,
                         -4.68384884e-02,  -4.60369796e-01,  -7.33285427e-01,
                         -5.46814919e-01,  -4.91092533e-01,  -6.45239115e-01,
                         -6.24119520e-01,  -5.55731595e-01,  -7.16423631e-01,
                         -7.13571787e-01,  -2.02383623e-01,   1.16519285e-02,
                         -6.04912460e-01,  -9.05180931e-01,  -2.87568420e-01,
                          5.08185178e-02,  -3.95929754e-01,  -7.41826594e-01,
                         -6.61481619e-01,  -5.96915543e-01,  -6.78529620e-01,
                         -7.01937616e-01,  -6.27327740e-01,  -5.90754032e-01,
                         -6.09832883e-01,  -6.20862961e-01,  -6.12870157e-01,
                         -5.70183575e-01,  -5.71052432e-01,  -6.51265442e-01,
                         -6.13505065e-01,  -4.80260491e-01,  -5.06754041e-01,
                         -6.14416540e-01,  -6.28742993e-01,  -6.19888544e-01,
                         -6.03668332e-01,  -5.61460018e-01,  -6.14042163e-01,
                         -7.52184451e-01,  -7.70022690e-01,  -6.25792384e-01,
                         -5.13653755e-01,  -5.19419312e-01,  -5.50498605e-01,
                         -5.85791111e-01,  -6.45207942e-01,  -6.72442496e-01,
                         -6.58400416e-01,  -6.28324270e-01,  -5.62616110e-01,
                         -5.39385498e-01,  -6.43242419e-01,  -6.93307102e-01,
                         -5.61239123e-01,  -5.12912929e-01,  -6.63499534e-01,
                         -7.10217357e-01,  -5.89728594e-01,  -5.40942848e-01,
                         -5.70955575e-01,  -5.85658848e-01,  -6.29427850e-01,
                         -6.95554137e-01,  -7.11618006e-01,  -6.71098590e-01,
                         -6.06252432e-01,  -5.43584943e-01,  -5.31405926e-01,
                         -5.88740945e-01,  -6.09066665e-01,  -5.42630970e-01,
                         -5.21522045e-01,  -5.95379651e-01,  -6.95259154e-01,
                         -7.47484326e-01,  -6.60192311e-01,  -5.45179725e-01,
                         -5.64779818e-01,  -5.63922226e-01,  -5.03189802e-01,
                         -5.72064042e-01,  -6.78002000e-01,  -6.71743155e-01,
                         -6.03647351e-01,  -5.25241613e-01,  -5.46188235e-01,
                         -6.68074727e-01,  -6.96324825e-01,  -6.57616735e-01,
                         -6.49766862e-01,  -5.81395626e-01,  -5.34028888e-01,
                         -6.23714864e-01,  -6.57660604e-01,  -5.79811871e-01,
                         -5.84213734e-01,  -5.97121596e-01,  -5.05060256e-01,
                         -5.34922421e-01,  -6.93073392e-01,  -6.77334130e-01,
                         -5.70753813e-01,  -5.98815084e-01,  -6.30328119e-01,
                         -5.88316560e-01,  -5.85701227e-01,  -6.03340507e-01,
                         -5.81977367e-01,  -5.72984755e-01,  -6.27239525e-01,
                         -6.70608461e-01,  -6.20348155e-01,  -5.70760369e-01,
                         -5.80628633e-01,  -5.76702833e-01,  -5.97383142e-01,
                         -6.39085710e-01,  -5.78089476e-01,  -5.17015696e-01,
                         -6.23408794e-01,  -7.20944703e-01,  -6.12459898e-01,
                         -5.32858789e-01,  -6.45648956e-01,  -6.37044191e-01,
                         -5.09408116e-01,  -5.73824584e-01,  -5.90659976e-01,
                         -5.05368710e-01,  -6.78652346e-01,  -6.79504693e-01,
                         -2.02667549e-01,  -6.02481179e-02,  -4.89609957e-01,
                         -7.54426301e-01,  -6.50296688e-01,  -5.52050471e-01,
                         -5.87582886e-01,  -5.86471260e-01,  -5.37254214e-01,
                         -5.74787915e-01,  -5.82289934e-01,  -5.70702612e-01,
                         -7.09400773e-01,  -6.21665299e-01,  -1.92170158e-01,
                         -1.82377771e-01,  -6.36991680e-01,  -6.03825748e-01,
                         -7.32817650e-02,  -4.64162305e-02,  -5.28723836e-01,
                         -6.45903885e-01,  -5.45900047e-01,  -7.01579630e-01,
                         -5.42937934e-01,  -4.90043871e-02,  -1.50478780e-01,
                         -6.94186687e-01,  -8.34968388e-01,  -6.27509952e-01,
                         -5.24634600e-01,  -5.68142951e-01,  -5.88584602e-01,
                         -6.03731394e-01,  -6.55783594e-01,  -5.14671922e-01,
                         -1.70702994e-01,   6.23728596e-02,   1.01058885e-01,
                         -4.52178903e-02,  -3.34920019e-01,  -5.62728167e-01,
                         -6.50379360e-01,  -6.29167259e-01,  -6.42636716e-01,
                         -6.99095190e-01,  -4.19951558e-01,  -1.20583862e-01,
                         -3.72784466e-01,  -4.46416140e-01,  -1.09439984e-01,
                         -3.35301161e-01,  -7.38773525e-01,  -5.98076880e-01,
                         -6.16083264e-01,  -6.98443592e-01,  -1.90933153e-01,
                         -1.81031208e-02,  -5.52624106e-01,  -4.68427956e-01,
                          2.03295335e-01,   7.01324269e-02,  -5.21895170e-01,
                         -3.66758466e-01,  -6.57996833e-02,  -4.97080505e-01,
                         -7.73206890e-01,  -2.80972958e-01,  -6.26020432e-02,
                         -5.17593920e-01,  -7.36870468e-01,  -5.96527934e-01,
                         -5.07436097e-01,  -1.70024440e-01,   1.50185511e-01,
                         -2.13825867e-01,  -5.07786155e-01,  -1.56690702e-01,
                         -1.43406004e-01,  -6.64622605e-01,  -7.28141189e-01,
                         -2.14126706e-01,   1.33153260e-01,  -9.53831673e-02,
                         -4.64848220e-01,  -3.34637016e-01,  -1.97327752e-02,
                         -4.58705686e-02,  -7.09986240e-02,   9.19286758e-02,
                          1.17664248e-01,   3.66766118e-02,   1.13030700e-02,
                          1.30234677e-02,   6.03027977e-02,   8.30536634e-02,
                         -5.00032911e-03,  -4.47982103e-02,   3.03139146e-02,
                          2.58499775e-02,  -4.53325883e-02,   8.40966869e-03,
                          7.80339539e-02,   3.22022699e-02,   4.73189261e-03,
                         -5.31927729e-03,  -5.04852347e-02,  -1.13776829e-02,
                          7.10516572e-02,   7.23421574e-02,   1.74314086e-03,
                         -9.62171853e-02,  -6.04828857e-02,   1.22081257e-01,
                          1.33991092e-01,  -2.59999130e-02,  -4.10341211e-02,
                          3.58112417e-02,   1.22136967e-02,   2.49148323e-03,
                          6.89187273e-02,   3.62449922e-02,  -6.73461705e-02,
                         -2.34303065e-02,   8.14933032e-02,   6.49073124e-02,
                          3.07630524e-02,   1.82639956e-02,  -5.96908629e-02,
                         -7.98590630e-02,   3.06199491e-02,   8.39432627e-02,
                          2.18307190e-02,   3.78591311e-03,   2.67458316e-02,
                         -2.68501565e-02,  -4.48151156e-02,   5.61441258e-02,
                          9.30011570e-02,   2.53932644e-02,  -7.51585094e-03,
                          1.56317800e-02,   6.18566908e-02,   6.37394860e-02,
                         -2.80984631e-03,  -3.37709635e-02,  -2.46076267e-02,
                         -1.26963919e-02,   2.20493227e-02,   3.77497301e-02,
                          3.91728356e-02,   9.83232539e-03,  -3.18538807e-02,
                          4.89023849e-02,  -2.99076382e-02,  -4.25534993e-01,
                         -4.59867060e-01,  -3.53998654e-02,   1.15415841e-01,
                          9.65918694e-03,   7.04590173e-04,  -1.42475683e-02,
                         -1.21493433e-02,   5.44084013e-02,   5.79814985e-02,
                          1.95605885e-02,  -8.38534813e-03,  -4.49122395e-03,
                          1.95749216e-02,   2.01670709e-03,   1.94389001e-02,
                          5.24170920e-02,  -2.72721536e-02,  -7.84468949e-02,
                         -1.32989250e-02,   4.26403657e-02,   7.36436769e-02,
                          4.68372442e-02,  -4.30288911e-02,  -4.28603701e-02,
                          2.27821935e-02,   2.48465296e-02,   6.48346404e-03,
                         -1.93065475e-03,  -2.38578729e-02,  -1.35156382e-02,
                          2.68404614e-02,   2.31400058e-02,   5.74246608e-03,
                          4.46187109e-02,   3.94444168e-02,  -6.02840893e-02,
                         -6.59036115e-02,   3.75159867e-02,   3.43300365e-02,
                         -3.14470120e-02,   1.04051577e-02,   6.07174225e-02,
                          1.28782541e-02,  -2.14624610e-02,   3.73809715e-03,
                          3.61101935e-04,  -2.08837893e-02,  -1.09982258e-03,
                          1.95055120e-02,   3.77371092e-03,  -1.69147402e-02,
                         -2.20903493e-02,  -2.88070440e-02,  -2.56354995e-02,
                          2.73924302e-02,   7.67892301e-02,   6.24421425e-02,
                          4.47659604e-02,   2.16493681e-02,  -2.48177256e-02,
                         -1.36102466e-02,   7.70040846e-04,  -4.23417799e-02,
                         -4.16087322e-02,   1.28681725e-02,   5.31792231e-02,
                         -5.12516079e-03,  -9.70506594e-02,   5.54499924e-02,
                          1.32735819e-01,  -3.31775904e-01,  -6.14072382e-01,
                         -1.90105081e-01,   1.43164545e-01,   4.99001704e-02,
                         -4.62562544e-03,   5.27864061e-02,   3.32794413e-02,
                         -1.70662701e-01,  -4.71925676e-01,  -6.58964157e-01,
                         -6.99637353e-01,  -4.50094819e-01,  -6.02503642e-02,
                         -2.54951060e-01,  -7.38400340e-01,  -5.33682108e-01,
                         -1.30663797e-01,  -3.59061748e-01,  -6.91557229e-01,
                         -6.56121910e-01,  -6.22725666e-01,  -6.51907623e-01,
                         -5.59091926e-01,  -6.08658433e-01,  -6.90503299e-01,
                         -3.01727980e-01,  -2.98020821e-02,  -4.96173382e-01,
                         -7.75589585e-01,  -5.18076897e-01,  -5.98092377e-01,
                         -7.06902266e-01,  -2.31090948e-01,  -1.34290531e-02,
                         -5.06629348e-01,  -8.38755012e-01,  -4.64592963e-01,
                          8.25276226e-02,   5.42219207e-02,  -3.84174258e-01,
                         -5.96532345e-01,  -6.58198535e-01,  -6.49703681e-01,
                         -3.07969034e-01,  -1.52046129e-01,  -5.39055526e-01,
                         -6.94941700e-01,  -5.21155775e-01,  -6.52614594e-01,
                         -6.68340325e-01,  -2.09345266e-01,  -1.42452925e-01,
                         -6.36039078e-01,  -6.56446099e-01,  -1.34811759e-01,
                         -1.12172455e-01,  -6.22759879e-01,  -7.24849463e-01,
                         -5.04901707e-01,  -6.54487252e-01,  -6.98292732e-01,
                         -1.97064355e-01,  -9.13142115e-02,  -6.91606224e-01,
                         -8.14022481e-01,  -1.86658219e-01,  -2.89193075e-02,
                         -6.20374441e-01,  -7.72088647e-01,  -2.04978511e-01,
                         -4.11226712e-02,  -5.50687850e-01,  -7.85150766e-01,
                         -3.78449768e-01,   7.78536052e-02,   5.13143875e-02,
                         -3.62536520e-01,  -7.02764571e-01,  -6.10353827e-01,
                         -1.01087011e-01,   1.47973716e-01,  -2.90528506e-01,
                         -5.31325758e-01,  -2.27860153e-01,  -2.89056510e-01,
                         -4.37654823e-01,  -1.10746302e-01,  -2.23638520e-01,
                         -7.56076992e-01,  -7.24579096e-01,  -5.23698807e-01,
                         -6.06669724e-01,  -6.34369910e-01,  -6.59409940e-01,
                         -6.79947674e-01,  -5.94740331e-01,  -6.48316860e-01,
                         -6.37506366e-01,  -2.46849731e-01,   9.72629711e-02,
                         -6.30386472e-02,  -4.98118997e-01,  -6.84756339e-01,
                         -6.08188629e-01,  -6.15786254e-01,  -6.29913449e-01,
                         -5.74048162e-01,  -6.63748622e-01,  -6.50263429e-01,
                         -2.53968924e-01,   1.26221433e-01,   2.94427350e-02,
                         -5.04156768e-01,  -8.26447070e-01,  -4.08975750e-01,
                         -2.62402464e-03,  -4.45050746e-01,  -8.81010413e-01,
                         -4.08629805e-01,   5.74770197e-02,  -3.51076186e-01,
                         -7.96769559e-01,  -6.40251994e-01,  -5.87534487e-01,
                         -7.36362755e-01,  -3.79041582e-01,  -2.02246644e-02,
                         -4.55517709e-01,  -8.41555953e-01,  -3.79202724e-01,
                          1.39108496e-02,  -4.24468309e-01,  -8.23955834e-01,
                         -4.25710738e-01,  -3.32689732e-02,  -3.63420576e-01,
                         -7.22000837e-01,  -6.25723422e-01,  -5.79045892e-01,
                         -6.72993064e-01,  -6.25104845e-01,  -5.92513800e-01,
                         -6.28558159e-01,  -5.89062750e-01,  -5.51218152e-01,
                         -5.81058621e-01,  -6.69411719e-01,  -6.97345018e-01,
                         -5.90608656e-01,  -6.40065491e-01,  -6.77833855e-01,
                         -2.83816993e-01,  -1.51200235e-01,  -5.13494968e-01,
                         -3.09578329e-01,   1.89062264e-02,  -5.70889175e-01,
                         -8.73744428e-01,  -2.41591111e-01,  -1.34439468e-01,
                         -5.11075675e-01,  -2.30119407e-01,  -6.56603947e-02,
                         -6.52869582e-01,  -7.59184122e-01,  -1.49981111e-01,
                         -1.23330958e-01,  -5.74619949e-01,  -3.30586910e-01,
                          1.46909937e-01,  -1.68549955e-01,  -4.98204559e-01,
                         -1.53455645e-01,  -1.79217130e-01,  -5.97438514e-01,
                         -2.16113403e-01,   2.19835714e-01,  -2.61884540e-01,
                         -4.60930675e-01,  -1.06815830e-01,  -3.15352321e-01,
                         -5.02520382e-01,  -9.78238881e-02,  -2.35125929e-01,
                         -8.13177407e-01,  -5.64336181e-01,  -8.50617792e-03,
                         -2.72847831e-01,  -7.40977287e-01,  -6.25127017e-01,
                         -5.45992792e-01,  -7.09247947e-01,  -3.96940023e-01,
                         -6.51274398e-02,  -4.28772956e-01,  -5.51123440e-01,
                          2.11030822e-02,   1.55597210e-01,  -3.95568252e-01,
                         -6.99277520e-01,  -5.79266191e-01,  -5.75632453e-01,
                         -6.78337693e-01,  -5.94129145e-01,  -6.00158274e-01,
                         -6.79548442e-01,  -3.09386551e-01,  -4.42029610e-02,
                         -5.11530876e-01,  -7.84332752e-01,  -5.15390217e-01,
                         -5.81175804e-01,  -7.27257967e-01,  -3.02135199e-01,
                         -6.00203015e-02,  -5.24334729e-01,  -7.49368608e-01,
                         -2.66182631e-01,  -5.31728603e-02,  -4.96234268e-01,
                         -7.32384980e-01,  -5.82582116e-01,  -6.08443379e-01,
                         -7.15721786e-01,  -6.23440623e-01,  -5.15312672e-01,
                         -5.52978992e-01,  -6.48999751e-01,  -6.64009511e-01,
                         -6.32396400e-01,  -6.41066611e-01,  -6.00025713e-01,
                         -5.35281360e-01,  -5.81020713e-01,  -6.50259376e-01,
                         -6.39122963e-01,  -6.06806159e-01,  -6.60811424e-01,
                         -6.82125092e-01,  -3.36815983e-01,   1.13989063e-01,
                          1.14334496e-02,  -4.40977871e-01,  -6.40638649e-01,
                         -6.14436567e-01,  -5.90069830e-01,  -6.09881520e-01,
                         -6.11051559e-01,  -5.51720977e-01,  -6.22509837e-01,
                         -7.52121925e-01,  -4.96057123e-01,  -4.94299605e-02,
                          4.19305936e-02,  -2.84151640e-02,   3.81734930e-02,
                          6.64649680e-02,   4.67934906e-02,   1.65673848e-02,
                         -7.35102519e-02,   3.92811410e-02,   1.68045059e-01,
                         -2.31310710e-01,  -5.84273577e-01,  -2.36904308e-01,
                          1.37888238e-01,   6.69910908e-02,  -6.27648830e-02,
                         -2.75056865e-02,   5.56000024e-02,  -1.39274299e-01,
                         -4.79886651e-01,  -2.97136962e-01,   1.02110229e-01,
                          3.49510089e-02,  -7.17080310e-02,   4.04201820e-02,
                         -8.69172800e-04,  -8.61685425e-02,  -2.47278288e-02,
                          7.60631636e-02,   1.10756181e-01,   6.01494592e-03,
                         -6.33123443e-02,   2.48064962e-03,  -3.00060911e-03,
                         -1.96217969e-02,   6.19360171e-02,   8.99347812e-02,
                          3.51320878e-02,  -4.28559296e-02,  -6.65729046e-02,
                          1.34984113e-03,   2.59048976e-02,   1.07931606e-02,
                          5.29837282e-03,  -3.93540934e-02,  -6.21893490e-03,
                          7.00986683e-02,   3.84263955e-02,  -5.41647663e-03,
                         -5.28244004e-02,  -1.49750998e-02,   1.62374794e-01,
                         -4.98048924e-02,  -5.53191841e-01,  -4.28743213e-01,
                          8.11341256e-02,   1.18039176e-01,  -5.02287187e-02,
                          8.73311888e-03,   2.78867111e-02,  -7.05899820e-02,
                         -3.36509682e-02,   4.42677215e-02,  -3.96181084e-02,
                         -2.71979384e-02,   1.34890303e-01,  -8.96985456e-02,
                         -5.04064918e-01,  -3.02517653e-01,   1.02049045e-01,
                         -2.27171090e-02,  -1.14952452e-01,   6.45238459e-02,
                         -1.62402645e-01,  -4.91522104e-01,  -2.62024552e-01,
                          4.68562283e-02,   3.59260626e-02,  -7.50674121e-03,
                          3.21719944e-02,   1.03469521e-01,  -3.88453640e-02,
                         -5.25982797e-01,  -7.42299676e-01,  -5.34275830e-01,
                         -6.05471611e-01,  -7.31755614e-01,  -3.03796351e-01,
                         -3.97875719e-02,  -5.09128273e-01,  -7.44923055e-01,
                         -2.54694074e-01,  -1.04509354e-01,  -5.33236742e-01,
                         -3.83840203e-01,   1.69150040e-01,  -2.60083433e-02,
                         -5.47410786e-01,  -6.56663775e-01,  -6.93404496e-01,
                         -5.72099686e-01,  -1.17199436e-01,  -1.18034095e-01,
                         -6.56690180e-01,  -6.66453242e-01,  -1.34193972e-01,
                         -1.50184706e-01,  -6.56182528e-01,  -7.12191164e-01,
                         -5.46495795e-01,  -7.08031476e-01,  -5.92283666e-01,
                         -8.71872008e-02,  -1.92228869e-01,  -7.77814806e-01,
                         -6.58270478e-01,  -4.46644910e-02,  -1.41472667e-01,
                         -6.84085965e-01,  -6.56433105e-01,  -5.11732578e-01,
                         -7.47899234e-01,  -5.49035370e-01,  -6.63536340e-02,
                         -2.73061961e-01,  -5.03174841e-01,  -1.51438266e-01,
                         -2.24180356e-01,  -7.27684379e-01,  -5.48994243e-01,
                         -8.38973150e-02,  -2.96632826e-01,  -7.08742738e-01,
                         -6.78037286e-01,  -6.03943586e-01,  -7.23717749e-01,
                         -5.26148260e-01,   3.94440629e-02,   1.61037982e-01,
                         -3.58105123e-01,  -5.42092144e-01,  -6.24492168e-02,
                          1.45092428e-01,  -2.51685679e-01,  -6.29607499e-01,
                         -6.53794885e-01,  -2.91876972e-01,   1.43664137e-01,
                         -5.10905907e-02,  -5.95120609e-01,  -4.14822876e-01,
                          2.11575538e-01,   8.30435529e-02,  -5.66275179e-01,
                         -5.17262042e-01,   8.76300111e-02,   1.30633578e-01,
                         -4.01325256e-01,  -7.65461147e-01,  -6.56642914e-01,
                         -1.07421592e-01,   2.60327816e-01,  -1.78308949e-01,
                         -6.30246699e-01,  -2.92596757e-01,   1.35447502e-01,
                          1.22797482e-01,  -5.57625592e-02,  -3.66898358e-01,
                         -6.61984503e-01,  -6.38357341e-01,  -5.62241554e-01,
                         -6.46928430e-01,  -6.69831574e-01,  -6.45485580e-01,
                         -6.05408490e-01,  -3.29714954e-01,  -2.41655279e-02,
                         -1.98266320e-02,  -2.35222299e-02,   1.02870435e-01,
                         -6.21460453e-02,  -4.88864720e-01,  -6.80742025e-01,
                         -5.80508292e-01,  -5.67479908e-01,  -7.58319259e-01,
                         -7.45103836e-01,  -4.81802106e-01,  -5.74085593e-01,
                         -7.71661878e-01,  -3.47876400e-01,  -4.37488705e-02,
                         -4.53877985e-01,  -4.46372747e-01,   1.31247371e-01,
                         -4.05677361e-03,  -5.55258930e-01,  -3.98607969e-01,
                          1.10537624e-02,   4.01065946e-02,   1.82628781e-02,
                         -1.50178254e-01,  -6.48055196e-01,  -7.07772672e-01,
                         -1.86728090e-01,  -1.55229509e-01,  -6.67506576e-01,
                         -7.39864588e-01,  -5.36471605e-01,  -6.42374575e-01,
                         -5.36011755e-01,  -1.29561186e-01,  -2.78794646e-01,
                         -7.44089544e-01,  -6.83195829e-01,  -5.04244447e-01,
                         -6.76131487e-01,  -5.98407388e-01,  -1.00239657e-01,
                          1.07211858e-01,  -5.74576743e-02,  -1.69501230e-02,
                          2.91966870e-02,  -3.68213475e-01,  -5.60202718e-01,
                         -1.41314462e-01,   9.92036238e-02,  -1.35344015e-02,
                          2.47444194e-02,   5.56728281e-02,  -3.19954678e-02,
                         -4.09785025e-02,  -3.56292538e-02,   3.48236822e-02,
                          7.81199783e-02,  -6.91079944e-02,  -3.36688124e-02,
                          5.43710962e-02,  -3.04754496e-01,  -5.58226049e-01,
                         -2.56881207e-01,   2.88401507e-02,   6.63091382e-03,
                         -5.74571192e-02,   3.67640741e-02,   1.06147617e-01,
                         -2.02829018e-01,  -5.09566128e-01,  -2.49162927e-01,
                          9.60193500e-02,   1.82059407e-02,  -1.05158344e-01,
                         -2.11551934e-02,   9.24252719e-03,  -7.27828443e-02,
                         -2.02786755e-02,   2.53700614e-02,  -2.90004432e-01,
                         -5.31762838e-01,  -2.15306133e-01,   7.88594559e-02,
                         -2.75135953e-02,  -6.36085123e-02,   3.43498252e-02,
                          2.63907900e-03,  -3.46885808e-02,  -1.36268055e-02,
                         -3.53133231e-02,  -3.89960818e-02,   4.06343862e-03,
                          1.75176170e-02,  -5.78894513e-03,  -3.19488235e-02,
                         -2.77893562e-02,   9.39141866e-03,   9.60965734e-03,
                         -1.01875663e-02,   3.27361859e-02,   7.57376943e-03,
                         -1.26640990e-01,  -7.10071623e-02,   6.12209477e-02,
                         -2.26118729e-01,  -6.83989942e-01,  -7.37984955e-01,
                         -6.29007220e-01,  -6.89253032e-01,  -5.53684890e-01,
                         -9.98903736e-02,   8.74827579e-02,  -2.60360837e-01,
                         -6.56590700e-01,  -6.20690107e-01,  -2.32670635e-01,
                          2.49582808e-02,  -6.42771572e-02,  -7.97456279e-02,
                          8.60102773e-02,  -1.31837741e-01,  -5.16927481e-01,
                         -3.12724859e-01,   3.12438048e-02,  -7.42204189e-02,
                         -3.96679752e-02,   1.56491086e-01,  -2.64887154e-01,
                         -7.37111926e-01,  -2.76984543e-01,   2.55894274e-01,
                         -1.58145517e-01,  -6.29039526e-01,  -2.91799992e-01,
                          1.11326322e-01,   1.12189921e-02,  -9.92643163e-02,
                         -1.94632635e-02,  -3.09103765e-02,  -5.89809678e-02,
                          2.34258361e-02,   2.85585076e-02,  -4.44818847e-02,
                         -3.82897072e-02,  -3.00251469e-02,  -3.00159641e-02,
                          2.50788704e-02,  -1.95188308e-03,  -2.94521898e-02,
                          3.31035964e-02,  -1.67400986e-01,  -4.66946065e-01,
                         -2.67923951e-01,   6.27539605e-02,  -2.14526821e-02,
                         -1.21162489e-01,   3.59957553e-02,   8.88700187e-02,
                         -8.51540491e-02,  -1.29972279e-01,   4.51565571e-02,
                         -1.13153599e-01,  -5.61589420e-01,  -4.00171638e-01,
                          8.36171061e-02,   1.32297131e-03,  -5.06778806e-02,
                          1.87743500e-01,  -1.78867653e-01,  -6.23955727e-01,
                         -2.54992276e-01,  -1.07005708e-01,  -7.07408011e-01,
                         -7.88873672e-01,  -1.69647872e-01,  -9.76766050e-02,
                         -6.13804638e-01,  -7.43124783e-01,  -5.53633749e-01,
                         -6.26535118e-01,  -7.35462129e-01,  -6.38596654e-01,
                         -6.18936062e-01,  -6.83022201e-01,  -6.33676827e-01,
                         -5.93868434e-01,  -6.73638999e-01,  -7.13515818e-01,
                         -6.14213765e-01,  -5.57830393e-01,  -6.52813733e-01,
                         -6.79508567e-01,  -5.92363596e-01,  -6.07740402e-01,
                         -6.61913157e-01,  -6.37298226e-01,  -6.59408331e-01,
                         -7.06355333e-01,  -6.51862085e-01,  -5.71853995e-01,
                         -5.88275492e-01,  -6.80593789e-01,  -7.21530080e-01,
                         -6.78089738e-01,  -6.49766028e-01,  -6.42362118e-01,
                         -6.16071522e-01,  -5.96682429e-01,  -5.95539927e-01,
                         -6.37485385e-01,  -6.74405873e-01,  -6.28892601e-01,
                         -6.30204618e-01,  -7.05969214e-01,  -6.64506078e-01,
                         -5.67466795e-01,  -6.03844166e-01,  -7.11502552e-01,
                         -7.24749267e-01,  -6.09111249e-01,  -5.47577322e-01,
                         -6.49223447e-01,  -7.10322618e-01,  -6.52783334e-01,
                         -6.26111090e-01,  -6.36524737e-01,  -6.40533030e-01,
                         -6.24974906e-01,  -5.89709997e-01,  -6.49294376e-01,
                         -7.45767891e-01,  -6.70769036e-01,  -5.51403761e-01,
                         -6.04788065e-01,  -7.06937075e-01,  -6.81701601e-01,
                         -6.11218870e-01,  -6.51456058e-01,  -7.24949360e-01,
                         -6.63176596e-01,  -5.63548446e-01,  -6.02149427e-01,
                         -6.92066729e-01,  -6.60759747e-01,  -5.58061957e-01,
                         -5.46237350e-01,  -6.13248825e-01,  -6.94573700e-01,
                         -7.68318594e-01,  -6.87313318e-01,  -5.36741495e-01,
                         -6.00144207e-01,  -6.74258351e-01,  -5.96591055e-01,
                         -6.34267032e-01,  -6.90032780e-01,  -6.38688326e-01,
                         -6.53926134e-01,  -6.25963867e-01,  -6.36994183e-01,
                         -7.35994458e-01,  -4.29383278e-01,  -1.19261459e-01,
                         -4.25588608e-01,  -4.78489667e-01,  -9.41222906e-02,
                         -3.34895104e-01,  -8.30403507e-01,  -7.10833132e-01,
                         -5.00472128e-01,  -6.33166194e-01,  -6.94928825e-01,
                         -5.52928746e-01,  -5.77049732e-01,  -7.32475281e-01,
                         -4.69587207e-01,  -7.97208399e-02,  -3.49135131e-01,
                         -7.66993403e-01,  -6.93407536e-01,  -6.14772379e-01,
                         -6.28153622e-01,  -5.39476752e-01,  -6.44874632e-01,
                         -6.34713054e-01,  -2.27969363e-01,  -1.82210594e-01,
                         -5.97863197e-01,  -6.92818642e-01,  -5.75417697e-01,
                         -6.56761765e-01,  -5.23495257e-01,  -1.79221094e-01,
                         -3.33519012e-01,  -6.06637836e-01,  -1.62940130e-01,
                          2.06295609e-01,  -2.66108841e-01,  -5.38601100e-01,
                         -1.56024471e-01,  -1.80384934e-01,  -6.88552082e-01,
                         -6.54266417e-01,  -1.35019690e-01,  -1.60262138e-01,
                         -7.13194132e-01,  -7.13725686e-01,  -1.90630555e-01,
                         -1.67139426e-01,  -5.50213099e-01,  -7.04363823e-01,
                         -6.48396075e-01,  -3.22856277e-01,   2.14931136e-03,
                         -3.74974161e-01,  -8.36105824e-01,  -4.55213130e-01,
                         -6.89906031e-02,  -4.41551656e-01,  -7.57412076e-01,
                         -5.91277003e-01,  -6.00744605e-01,  -7.52471507e-01,
                         -3.62089962e-01,   8.54110569e-02,  -3.08296502e-01,
                         -7.83592761e-01,  -4.23333198e-01,  -9.68540013e-02,
                         -4.48255032e-01,  -7.06095874e-01,  -5.71256399e-01,
                         -5.25047481e-01,  -6.93147719e-01,  -7.82729745e-01,
                         -4.69575763e-01,  -9.71205831e-02,  -3.16254109e-01,
                         -5.02136230e-01,   1.08936299e-02,   1.45865753e-01,
                         -4.57479298e-01,  -4.77414757e-01,  -3.31635438e-02,
                         -2.94286311e-01,  -7.40701735e-01,  -6.23309672e-01,
                         -5.51116347e-01,  -6.71965539e-01,  -3.65566522e-01,
                         -2.50445940e-02,  -4.00182039e-01,  -7.70454705e-01,
                         -3.32471013e-01,  -6.13584407e-02,  -4.98312414e-01,
                         -4.62454289e-01,  -6.99486211e-02,  -4.83640760e-01,
                         -7.86619961e-01,  -2.06886739e-01,  -1.04585312e-01,
                         -5.26754797e-01,  -2.88494170e-01,  -7.48105422e-02,
                         -4.53217864e-01,  -3.47183913e-01,   1.62475750e-01,
                         -5.17314747e-02,  -6.49216175e-01,  -7.02758908e-01,
                         -5.00466406e-01,  -6.27377391e-01,  -6.68398619e-01,
                         -2.18614414e-01,  -2.55778320e-02,  -5.24224937e-01,
                         -7.79374897e-01,  -2.92191356e-01,   1.50728434e-01,
                         -1.41559159e-02,  -4.54090446e-01,  -6.59619212e-01,
                         -6.14507496e-01,  -6.24562263e-01,  -6.47991180e-01,
                         -5.70715666e-01,  -6.03374362e-01,  -6.81803167e-01,
                         -5.97723067e-01,  -5.25728941e-01,  -5.61294138e-01,
                         -6.21929467e-01,  -6.58652186e-01,  -5.80330491e-01,
                         -5.61403871e-01,  -6.57380879e-01,  -4.59511548e-01,
                         -1.90623835e-01,  -3.75058323e-01,  -6.02247536e-01,
                         -5.91256917e-01,  -6.38991356e-01,  -5.95538497e-01,
                         -5.26815951e-01,  -7.28564918e-01,  -6.03520036e-01,
                         -7.24386573e-02,  -1.77583337e-01,  -6.98751330e-01,
                         -6.17480040e-01,  -4.64064270e-01,  -7.65750527e-01,
                         -6.22151136e-01,  -4.85075898e-02,  -1.78023681e-01,
                         -7.04020798e-01,  -6.75187826e-01,  -4.97086793e-01,
                         -6.33232117e-01,  -6.83048189e-01,  -5.82434654e-01,
                         -5.72190762e-01,  -5.71386456e-01,  -5.61110556e-01,
                         -6.18357360e-01,  -6.63878798e-01,  -6.23268962e-01,
                         -5.55494606e-01,  -5.89459062e-01,  -6.62146151e-01,
                         -6.31653011e-01,  -6.27823949e-01,  -6.51699066e-01,
                         -5.97872198e-01,  -6.78687274e-01,  -6.84448481e-01,
                         -2.55470067e-01,  -6.75410405e-02,  -4.99908328e-01,
                         -7.31674314e-01,  -5.69876134e-01,  -5.53122222e-01,
                         -6.15285814e-01,  -6.03436172e-01,  -6.55804157e-01,
                         -6.87041223e-01,  -6.41240120e-01,  -6.16509795e-01,
                         -5.99493563e-01,  -6.03427231e-01,  -6.36848152e-01,
                         -6.16846085e-01,  -5.84978878e-01,  -6.20662570e-01,
                         -6.65962934e-01,  -6.63942039e-01,  -6.15695894e-01,
                         -5.73773146e-01,  -6.19831622e-01,  -6.75932646e-01,
                         -6.29468918e-01,  -6.01266086e-01,  -6.48931146e-01,
                         -6.22977078e-01,  -5.66290915e-01,  -6.35157883e-01,
                         -7.22212970e-01,  -6.54613376e-01,  -5.36687911e-01,
                         -5.77549815e-01,  -6.84784830e-01,  -6.43415272e-01,
                         -5.72613835e-01,  -6.17030859e-01,  -6.49199426e-01,
                         -6.40699506e-01,  -6.53807163e-01,  -6.39910877e-01,
                         -6.13894105e-01,  -6.27901912e-01,  -6.53461814e-01,
                         -6.37696385e-01,  -6.03972018e-01,  -6.52382791e-01,
                         -6.90084696e-01,  -5.98250329e-01,  -5.80109179e-01,
                         -6.62309289e-01,  -6.33717537e-01,  -6.06522858e-01,
                         -6.59560919e-01,  -6.37537777e-01,  -5.92825949e-01,
                         -6.01736009e-01,  -6.04756832e-01,  -6.26181483e-01,
                         -6.79017067e-01,  -6.99004591e-01,  -6.47414684e-01,
                         -5.78994274e-01,  -5.90059936e-01,  -6.29211187e-01,
                         -6.23154998e-01,  -6.31914794e-01,  -6.46869421e-01,
                         -6.37107730e-01,  -6.62674308e-01,  -6.89144611e-01,
                         -6.42906547e-01,  -5.89140952e-01,  -6.06080890e-01,
                         -6.38628602e-01,  -6.17159665e-01,  -6.01982474e-01,
                         -6.31798208e-01,  -6.25836968e-01,  -5.98540723e-01,
                         -6.42433047e-01,  -6.90833032e-01,  -6.43842280e-01,
                         -6.00698709e-01,  -6.60936832e-01,  -6.98037922e-01,
                         -6.30095065e-01,  -5.90833306e-01,  -6.17421985e-01,
                         -6.10482275e-01,  -5.94350874e-01,  -6.26242459e-01,
                         -6.45034552e-01,  -6.27685785e-01,  -6.48240387e-01,
                         -6.83468461e-01,  -6.44450068e-01,  -5.97377121e-01,
                         -6.19000614e-01,  -6.32719636e-01,  -6.14339292e-01,
                         -6.28402829e-01,  -6.52816772e-01,  -6.28507674e-01,
                         -6.20146930e-01,  -6.70096517e-01,  -6.19977176e-01,
                         -5.60624599e-01,  -7.30594397e-01,  -6.75466001e-01,
                         -1.88924640e-01,  -1.24238297e-01,  -5.67798018e-01,
                         -7.15852559e-01,  -6.43503249e-01,  -5.45304418e-01,
                         -1.35567173e-01,   1.50485456e-01,  -2.06960365e-01,
                         -6.64024293e-01,  -6.50855601e-01,  -5.62704742e-01,
                         -7.37485766e-01,  -5.98529041e-01,  -1.01102665e-01,
                         -1.92340657e-01,  -6.99494660e-01,  -6.79349542e-01,
                         -5.27260065e-01,  -7.27096736e-01,  -5.79560637e-01,
                         -8.69667977e-02,  -2.52928734e-01,  -8.03188741e-01,
                         -5.84526658e-01,  -5.69152310e-02,  -2.72828996e-01,
                         -6.93950176e-01,  -6.89523995e-01,  -6.08838320e-01,
                         -4.15028363e-01,  -2.91367935e-04,   8.74076262e-02,
                         -3.60162348e-01,  -7.80714691e-01,  -5.83468080e-01,
                         -9.41997319e-02,  -2.39648029e-01,  -7.91998208e-01,
                         -6.49292648e-01,  -4.21786271e-02,  -1.56140879e-01,
                         -7.82015502e-01,  -6.81288719e-01,  -1.14357494e-01,
                         -2.46403798e-01,  -5.80353677e-01,  -2.19246551e-01,
                          1.28132686e-01,  -3.67675014e-02,  -7.01110139e-02,
                          6.37855828e-02,  -2.33256444e-01,  -7.50415385e-01,
                         -6.93145275e-01,  -1.62423491e-01,  -1.33900419e-01,
                         -6.76608682e-01,  -7.45482385e-01,  -1.80102780e-01,
                         -8.50512832e-02,  -6.82695150e-01,  -7.89742231e-01,
                         -2.10002363e-01,  -1.39350966e-01,  -5.59499800e-01,
                         -3.48305047e-01,   1.61304310e-01,  -9.80497375e-02,
                         -6.17863476e-01,  -3.79392147e-01,   1.09326214e-01,
                         -5.20339869e-02,  -5.00748992e-01,  -6.66960120e-01,
                         -7.11865306e-01,  -6.26214623e-01,  -2.34181702e-01,
                          5.63266464e-02,  -2.38113105e-02,  -4.78543565e-02,
                          6.03048578e-02,  -1.83307275e-01,  -6.67591929e-01,
                         -7.60590851e-01,  -3.37219775e-01,   9.29819569e-02,
                         -3.42434123e-02,  -5.05412579e-01,  -4.76824373e-01,
                          1.21965008e-02,   7.17126876e-02,  -4.27337795e-01,
                         -7.92184889e-01,  -5.90017736e-01,  -1.13511913e-01,
                          5.88284507e-02,  -5.98379374e-02,  -6.70388117e-02,
                          7.85483699e-03,  -8.47610121e-04,  -2.63649225e-02,
                         -3.67023088e-02,  -2.65377797e-02,  -6.90115755e-03,
                         -3.06740031e-02,  -3.90133113e-02,  -1.14773791e-02,
                         -1.59989838e-02,  -2.96393167e-02,  -3.29909772e-02,
                         -3.37336175e-02,  -2.11664550e-02,  -1.53062502e-02,
                         -1.01979617e-02,  -2.28009559e-02,  -5.70851639e-02,
                         -3.95431630e-02,  -8.56566336e-03,  -1.02041252e-02,
                         -7.96677638e-03,  -3.57211120e-02,  -5.41715771e-02,
                         -2.70571634e-02,  -2.75504105e-02,  -2.33446304e-02,
                         -1.13854976e-02,  -2.48937383e-02,  -1.87913626e-02,
                         -3.30279395e-02,  -4.67874743e-02,  -2.43759733e-02,
                         -3.80444415e-02,  -2.44258270e-02,   4.35427390e-03,
                         -3.47966850e-02,  -3.20923962e-02,  -1.02249878e-02,
                         -3.20351683e-02,  -2.08172314e-02,  -1.85617357e-02,
                         -2.94297710e-02,  -2.00305171e-02,  -3.20477039e-02,
                         -2.20244695e-02,  -8.86160694e-03,  -3.28485742e-02,
                         -3.84653956e-02,  -3.74902375e-02,  -2.44446415e-02,
                         -7.76718603e-03,  -3.44056524e-02,  -3.66718881e-02,
                         -9.75541398e-03,  -1.15262503e-02,  -2.44980995e-02,
                         -3.90250199e-02,  -2.93125659e-02,  -1.11605618e-02,
                         -2.50591580e-02,  -2.79374737e-02,  -2.31450610e-02,
                         -2.71394867e-02,  -1.86409559e-02,  -1.32363681e-02,
                         -8.72958824e-03,  -2.20043808e-02,  -4.55766320e-02,
                         -2.32468359e-02,  -5.59447333e-03,  -2.59684045e-02,
                         -3.07545383e-02,  -2.50260290e-02,  -2.92302221e-02,
                         -3.29991058e-02,  -1.94653533e-02,  -4.11174586e-03,
                         -1.64993759e-02,  -2.77703516e-02,  -2.63770614e-02,
                         -1.54668111e-02,   3.01385601e-03,  -1.96625199e-02,
                         -4.95594926e-02,  -3.79928760e-02,  -2.58092545e-02,
                         -9.17123631e-03,   4.55592247e-03,  -1.04207341e-02,
                         -2.61451583e-02,  -3.26536000e-02,  -1.71168484e-02,
                         -2.52546743e-04,  -1.86830685e-02,  -3.02450154e-02,
                         -2.06192378e-02,  -7.22720986e-03,  -5.42712212e-03,
                         -2.80446280e-02,  -2.70905010e-02,  -1.18631991e-02,
                         -2.23908890e-02,  -2.73561999e-02,  -2.02807859e-02,
                         -6.68022363e-03,  -1.10920919e-02,  -3.09404023e-02,
                         -8.43314268e-03,   2.98117776e-03,  -1.59670468e-02,
                         -8.87294207e-03,  -7.21854903e-03,  -2.21649627e-03,
                         -4.75508487e-03,  -2.89655570e-02,  -1.16094090e-02,
                         -9.89287626e-03,  -2.22262554e-02,   4.80408175e-03,
                         -1.08475899e-02,  -2.85958573e-02,  -1.53423036e-02,
                         -1.19978609e-02,   6.34335913e-03,  -1.67765450e-02,
                         -5.59411803e-03,   3.52855884e-02,  -5.57176769e-02,
                         -6.96001621e-03,   6.96700960e-02,  -3.09517801e-01,
                         -5.15041828e-01,  -1.58965647e-01,  -2.02946573e-01,
                         -7.16736794e-01,  -7.04494476e-01,  -1.83496565e-01,
                          1.26918525e-01,  -6.04890920e-02,  -5.91548622e-01,
                         -7.94124424e-01,  -3.35950166e-01,  -7.87168443e-02,
                         -4.19924021e-01,  -6.96965873e-01,  -7.37313688e-01,
                         -5.51902175e-01,  -1.53586105e-01,  -2.03793377e-01,
                         -6.49621725e-01,  -7.26801038e-01,  -5.90284467e-01,
                         -6.11260295e-01,  -6.40773416e-01,  -6.36272430e-01,
                         -6.53137326e-01,  -6.50287271e-01,  -6.04804814e-01,
                         -6.18324101e-01,  -6.99489713e-01,  -5.10815501e-01,
                         -2.51081958e-02,   1.32547051e-01,  -2.99600154e-01,
                         -7.00162292e-01,  -6.34361684e-01,  -5.84791660e-01,
                         -7.70301700e-01,  -5.68104506e-01,  -6.50588945e-02,
                         -1.89914525e-01,  -7.64165521e-01,  -6.70210779e-01,
                         -1.03725635e-01,  -2.08839789e-01,  -6.90368354e-01,
                         -6.52002990e-01,  -5.61838090e-01,  -7.55714178e-01,
                         -5.43343008e-01,  -9.09504443e-02,  -2.54990071e-01,
                         -7.06285655e-01,  -6.79907680e-01,  -5.76114535e-01,
                         -7.36918449e-01,  -5.02419949e-01,  -5.32166027e-02,
                         -3.16089988e-01,  -8.08142304e-01,  -5.43891191e-01,
                         -2.93168798e-02,  -2.73486704e-01,  -8.26425970e-01,
                         -5.80089331e-01,  -6.65581003e-02,  -3.23320746e-01,
                         -5.66809535e-01,  -7.73852989e-02,   1.69862047e-01,
                         -2.90256023e-01,  -6.79370642e-01,  -6.76847935e-01,
                         -6.12533689e-01,  -6.22930467e-01,  -6.33995295e-01,
                         -6.20369077e-01,  -6.41061187e-01,  -6.67427957e-01,
                         -5.96373796e-01,  -6.34128273e-01,  -7.70554066e-01,
                         -4.60117310e-01,  -4.39259373e-02,  -3.24759394e-01,
                         -7.41403103e-01,  -6.70859933e-01,  -5.72419763e-01,
                         -6.24543250e-01,  -6.25120282e-01,  -6.23178780e-01,
                         -6.47933424e-01,  -6.53819561e-01,  -6.33274615e-01,
                         -6.28398776e-01,  -6.07278705e-01,  -5.79243243e-01,
                         -7.04300821e-01,  -6.60835147e-01,  -2.14759588e-01,
                         -1.26394227e-01,  -5.74918628e-01,  -7.16325700e-01,
                         -5.72380126e-01,  -6.62768126e-01,  -6.43093646e-01,
                         -1.90178022e-01,   1.50072619e-01,  -1.02676161e-01,
                         -5.54630220e-01,  -6.94935918e-01,  -6.69016838e-01,
                         -5.57784855e-01,  -1.38700128e-01,   1.51990741e-01,
                         -1.72849149e-01,  -5.86675584e-01,  -6.62932217e-01,
                         -6.20570302e-01,  -5.72453320e-01,  -6.64061069e-01,
                         -7.30333209e-01,  -3.36997360e-01,  -4.89169173e-02,
                         -4.03715432e-01,  -7.24551499e-01,  -6.57918513e-01,
                         -5.90866089e-01,  -6.36089385e-01,  -6.30552053e-01,
                         -5.65929234e-01,  -6.64394796e-01,  -7.11607158e-01,
                         -3.01210523e-01,  -5.24070226e-02,  -4.53810453e-01,
                         -7.45526254e-01,  -6.17474258e-01,  -5.66247046e-01,
                         -6.02041304e-01,  -5.88774979e-01,  -6.77685559e-01,
                         -6.46891654e-01,  -1.98247477e-01,   1.73586756e-01,
                         -7.64463916e-02,  -5.39324760e-01,  -6.72352612e-01,
                         -6.03815138e-01,  -5.89010477e-01,  -6.19928241e-01,
                         -6.26548171e-01,  -6.11613691e-01,  -5.99153042e-01,
                         -5.88557482e-01,  -6.00330174e-01,  -6.28434122e-01,
                         -6.21880710e-01,  -5.97110450e-01,  -6.04462802e-01,
                         -6.21958494e-01,  -6.01381600e-01,  -5.80537438e-01,
                         -6.07571423e-01,  -6.29337549e-01,  -6.23206258e-01,
                         -6.10842943e-01,  -5.87282181e-01,  -5.92011154e-01,
                         -6.12455666e-01,  -6.06507480e-01,  -6.18343949e-01,
                         -6.21028543e-01,  -5.88991165e-01,  -5.93067765e-01,
                         -6.14364684e-01,  -6.08494341e-01,  -5.98677099e-01,
                         -6.04176044e-01,  -6.16443038e-01,  -6.04149401e-01,
                         -6.00973487e-01,  -6.07788861e-01,  -5.71826994e-01,
                         -5.99578381e-01,  -6.51075721e-01,  -5.72937608e-01,
                         -6.00752115e-01,  -6.81898415e-01,  -3.56797844e-01,
                         -5.30077256e-02,  -3.72863829e-01,  -7.03795671e-01,
                         -5.92281759e-01,  -5.44829845e-01,  -6.39787674e-01,
                         -6.00906849e-01,  -5.69758296e-01,  -5.96318066e-01,
                         -6.13239825e-01,  -6.28077090e-01,  -5.63034296e-01,
                         -6.02900326e-01,  -7.26341963e-01,  -4.11217391e-01,
                         -1.33058196e-02,  -3.03036243e-01,  -7.13446796e-01,
                         -6.08031332e-01,  -5.61190009e-01,  -6.97980404e-01,
                         -3.70639354e-01,   2.76967743e-03,  -4.00672555e-01,
                         -8.04735243e-01,  -3.65015894e-01,  -2.15030685e-02,
                         -3.74192327e-01,  -6.57325983e-01,  -6.78794324e-01,
                         -5.83388865e-01,  -1.66946352e-01,  -5.28222919e-02,
                         -6.26970470e-01,  -7.70834744e-01,  -1.68256432e-01,
                         -4.22436818e-02,  -5.59596121e-01,  -7.02144563e-01,
                         -5.19201338e-01,  -6.47001863e-01,  -6.10635996e-01,
                         -1.35765880e-01,  -1.27592459e-01,  -6.11064553e-01,
                         -6.84668064e-01,  -5.20692468e-01,  -5.92013776e-01,
                         -6.37512982e-01,  -5.94855130e-01,  -5.96873999e-01,
                         -5.88429809e-01,  -6.12320662e-01,  -6.09408736e-01,
                         -5.53172529e-01,  -6.23721719e-01,  -6.23738945e-01,
                         -2.71025449e-01,   1.04259357e-01,   1.99583173e-02,
                         -4.56058174e-01,  -7.20839322e-01,  -4.33398694e-01,
                         -2.73564924e-02,   7.63825774e-02,   2.17459518e-02,
                          1.02637988e-02,   3.24612707e-02,   3.58299837e-02,
                          3.04445233e-02,   3.77993733e-02,   2.30933689e-02,
                          7.35677406e-03,   2.58042403e-02,   3.29743773e-02,
                          3.40463482e-02,   3.12252101e-02,   1.50797376e-02,
                          4.44777906e-02,   3.45740095e-02,  -1.24076465e-02,
                          1.03328452e-01,   6.14564754e-02,  -3.82071942e-01,
                         -4.92455393e-01,  -5.97686954e-02,   1.29904926e-01,
                          8.39809328e-03,   9.72296577e-03,   5.99814691e-02,
                          1.61199905e-02,  -1.01016192e-02,   1.09001376e-01,
                          5.84353581e-02,  -3.97313505e-01,  -5.03000915e-01,
                         -2.30407901e-02,   1.16208732e-01,  -3.13408673e-02,
                          1.16423301e-01,   1.43962717e-02,  -4.62160766e-01,
                         -4.25269932e-01,   3.29539105e-02,   1.09368324e-01,
                         -1.97313130e-02,   3.38854529e-02,   4.72729579e-02,
                          1.46414638e-02,   4.83048558e-02,   3.65288667e-02,
                          2.31688917e-02,   2.01610215e-02,   2.61810236e-02,
                          7.79420212e-02,   1.96206160e-02,   1.09641468e-02,
                          1.43526748e-01,  -1.00188278e-01,  -5.04274368e-01,
                         -3.10662985e-01,   9.05332938e-02,   8.36667269e-02,
                         -1.44282710e-02,   3.87666859e-02,   5.16964532e-02,
                          2.08902135e-02,   5.38569763e-02,   4.91804630e-02,
                         -3.61586660e-02,   4.94179875e-02,   1.53426141e-01,
                         -2.01056376e-01,  -5.23026228e-01,  -2.07470223e-01,
                          1.17798984e-01,   4.59039584e-02,   9.41769313e-03,
                          6.29715994e-02,   3.20821293e-02,   1.48210060e-02,
                          5.94745390e-02,   4.42581102e-02,  -2.23650020e-02,
                          7.67776221e-02,   9.92585346e-02,  -3.44860643e-01,
                         -5.47917664e-01,   1.38675151e-02,   2.15200663e-01,
                         -3.66932541e-01,  -4.59522873e-01,  -7.52961636e-02,
                         -3.09619367e-01,  -5.02373815e-01,   5.23863658e-02,
                          2.00761497e-01,  -4.14756656e-01,  -5.42171299e-01,
                          4.85161580e-02,   1.98483810e-01,  -3.59415948e-01,
                         -5.25096178e-01,  -4.61130440e-02,   1.44584596e-01,
                         -2.29719225e-02,   3.53701226e-02,   1.09132193e-01,
                         -2.83969343e-01,  -7.61408150e-01,  -5.27758479e-01,
                         -2.88569387e-02,  -2.56990761e-01,  -5.37847519e-01,
                         -6.73345029e-02,   2.02271253e-01,  -2.47058570e-01,
                         -5.98167717e-01,  -6.22096717e-01,  -6.36601925e-01,
                         -4.35055256e-01,   2.29223520e-02,   1.53880343e-01,
                         -2.76542425e-01,  -7.11358011e-01,  -5.88590443e-01,
                         -1.33074522e-01,   6.85333014e-02,   5.71458079e-02,
                          3.66742797e-02,  -2.99818456e-01,  -7.53904462e-01,
                         -5.57750046e-01,  -2.35086083e-02,  -1.98214188e-01,
                         -7.71391034e-01,  -5.85410416e-01,  -3.46257538e-02,
                         -2.46787474e-01,  -5.73490202e-01,  -7.38175586e-02,
                          2.34408125e-01,  -3.26281846e-01,  -5.31693161e-01,
                         -9.72305685e-02,  -1.93001077e-01,  -7.17623174e-01,
                         -6.73100710e-01,  -1.00596271e-01,   1.97448298e-01,
                         -2.00565994e-01,  -5.53524435e-01,  -1.93995193e-01,
                         -9.16858092e-02,  -6.86317086e-01,  -7.08012760e-01,
                         -1.00308686e-01,  -1.66487709e-01,  -5.89055359e-01,
                         -2.06474200e-01,   2.47664630e-01,  -2.29208514e-01,
                         -5.87165356e-01,  -1.79224476e-01,  -1.31954178e-01,
                         -6.52062654e-01,  -7.39010394e-01,  -2.15613842e-01,
                          1.75030962e-01,  -1.04856074e-01,  -5.41291416e-01,
                         -3.50428492e-01,   5.68062365e-02,   4.31481972e-02,
                         -4.09389697e-02,   2.75595523e-02,  -8.70021153e-03,
                         -7.04121077e-03,   6.80018067e-02,  -2.00355709e-01,
                         -6.69380367e-01,  -7.14242041e-01,  -2.80841708e-01,
                          1.06103249e-01,   2.54211994e-03,  -4.98002440e-01,
                         -7.83158660e-01,  -4.87501383e-01,  -6.45990297e-02,
                          2.26422977e-02,   2.50319019e-02,  -4.51970398e-02,
                         -5.41103184e-01,  -8.34102571e-01,  -3.43700618e-01,
                         -7.50596896e-02,  -5.01345456e-01,  -4.75853473e-01,
                          1.16885751e-01,   5.74577041e-02,  -5.65189838e-01,
                         -5.04645824e-01,   1.15938425e-01,   2.25763973e-02,
                         -5.46723485e-01,  -3.98480982e-01,  -1.09463766e-01,
                         -4.74834412e-01,  -4.78317380e-01,   1.05338611e-01,
                          2.06939448e-02,  -5.89042485e-01,  -4.90675271e-01,
                          1.05783492e-01,   3.16948146e-02,  -5.34440935e-01,
                         -4.91034031e-01,  -2.08577756e-02,   5.51374815e-02,
                         -6.99346289e-02,  -3.56867537e-02,  -8.12344067e-03,
                         -3.31450626e-02,  -2.81653758e-02,  -2.52488125e-02,
                         -2.72904355e-02,  -2.14665979e-02,  -2.93702427e-02,
                         -3.37623470e-02,  -2.71443650e-02,  -3.47848907e-02,
                         -3.38342413e-02,  -1.78477224e-02,  -2.14058068e-02,
                         -3.34499478e-02,  -3.13017853e-02,  -2.39377934e-02,
                         -3.08247115e-02,  -3.75510491e-02,  -2.40992829e-02,
                         -2.52899956e-02,  -3.86845954e-02,  -3.31737399e-02,
                         -2.69796997e-02,  -2.38700658e-02,  -2.75493767e-02,
                         -3.98358256e-02,  -3.64529379e-02,  -2.89003979e-02,
                         -2.71650720e-02,  -2.25948151e-02,  -2.64715869e-02,
                         -3.69905531e-02,  -3.09640337e-02,  -1.53600946e-02,
                         -2.58062668e-02,  -3.97354290e-02,  -3.05156149e-02,
                         -3.24788429e-02,  -3.84527519e-02,  -3.05171814e-02,
                         -2.82196682e-02,  -3.24007943e-02,  -1.91144478e-02,
                         -1.62221324e-02,  -6.50147051e-02,  -4.64674924e-03,
                          5.96185066e-02,  -2.94827253e-01,  -5.88085592e-01,
                         -2.34879673e-01,   7.68420920e-02,  -2.64890548e-02,
                         -5.92437536e-02,  -7.39011029e-03,  -3.69638614e-02,
                         -4.26999778e-02,   4.08423878e-03,  -2.06535682e-02,
                         -8.16036984e-02,   5.26497886e-02,   1.14070596e-02,
                         -4.54102337e-01,  -4.84120220e-01,  -1.22180358e-01,
                         -3.74788463e-01,  -7.72344351e-01,  -6.44712985e-01,
                         -6.14131033e-01,  -7.41432488e-01,  -4.26250488e-01,
                          6.21587364e-03,   2.00208742e-02,  -8.21747035e-02,
                          1.87257435e-02,  -2.21028235e-02,  -4.83226180e-01,
                         -8.13249886e-01,  -4.98953551e-01,  -8.35046321e-02,
                          1.82838235e-02,   6.21018335e-02,  -1.66822985e-01,
                         -5.59834182e-01,  -3.70085865e-01,   5.10367975e-02,
                          3.04450355e-02,  -7.69986510e-02,  -1.64827965e-02,
                          6.40768139e-03,  -3.68697457e-02,  -3.78246158e-02,
                          3.87262553e-02,  -8.91590789e-02,  -5.69521606e-01,
                         -7.95088828e-01,  -4.09457624e-01,  -3.16483155e-02,
                          9.86708235e-03,   1.97308231e-02,  -1.49336949e-01,
                         -6.24197185e-01,  -7.83941269e-01,  -3.56166333e-01,
                          3.32673453e-02,  -2.05072984e-02,  -6.10706583e-02,
                          1.02393121e-01,  -1.49855182e-01,  -5.70115328e-01,
                         -3.12369585e-01,  -8.77740011e-02,  -6.16764605e-01,
                         -8.29443157e-01,  -2.52810091e-01,  -5.33398576e-02,
                         -6.22192800e-01,  -8.37511420e-01,  -2.82021552e-01,
                         -9.57150981e-02,  -5.62380672e-01,  -4.22405332e-01,
                          1.79531336e-01,  -1.02785468e-01,  -6.03851616e-01,
                         -2.92437613e-01,  -1.94060653e-01,  -5.25061965e-01,
                         -2.93988824e-01,  -1.54733092e-01,  -6.71467960e-01,
                         -7.83947468e-01,  -2.43869931e-01,   1.10754326e-01,
                         -9.09300521e-02,  -5.43036699e-01,  -7.23155141e-01,
                         -6.37805820e-01,  -6.34944499e-01,  -6.72483385e-01,
                         -6.59688413e-01,  -6.59660041e-01,  -6.58937931e-01,
                         -6.57397628e-01,  -6.58989012e-01,  -6.61943614e-01,
                         -6.69126809e-01,  -6.58010066e-01,  -6.58624351e-01,
                         -6.70531750e-01,  -6.59373760e-01,  -6.59237146e-01,
                         -6.65716171e-01,  -6.60371900e-01,  -6.66756392e-01,
                         -6.68262959e-01,  -6.65933669e-01,  -6.68544114e-01,
                         -6.57984078e-01,  -6.61877275e-01,  -6.70970798e-01,
                         -6.60126269e-01,  -6.67563498e-01,  -6.73947394e-01,
                         -6.60841107e-01,  -6.62822366e-01,  -6.65599704e-01,
                         -6.68863058e-01,  -6.74703300e-01,  -6.68465018e-01,
                         -6.72813237e-01,  -6.71947658e-01,  -6.65997684e-01,
                         -6.77563012e-01,  -6.71252072e-01,  -6.62512422e-01,
                         -6.70937538e-01,  -6.72865510e-01,  -6.81293309e-01,
                         -6.80081666e-01,  -6.70691252e-01,  -6.79928839e-01,
                         -6.73227489e-01,  -6.60867989e-01,  -6.75123453e-01,
                         -6.84210420e-01,  -6.78963840e-01,  -6.82383180e-01,
                         -6.80498600e-01,  -6.71477854e-01,  -6.93838298e-01,
                         -6.74291492e-01,  -6.31534636e-01,  -7.48313785e-01,
                         -6.94425285e-01,  -2.41914347e-01,  -1.80973962e-01,
                         -6.61754847e-01,  -7.60904729e-01,  -5.99276483e-01,
                         -7.60029137e-01,  -6.83962584e-01,  -1.83324024e-01,
                         -2.00741962e-01,  -7.71138728e-01,  -7.77155876e-01,
                         -1.91728339e-01,  -1.55814961e-01,  -7.30506599e-01,
                         -8.09851110e-01,  -2.42924869e-01,  -1.08727202e-01,
                         -6.74927413e-01,  -8.47360551e-01,  -3.02323699e-01,
                         -1.25769287e-01,  -5.92967927e-01,  -7.82572448e-01,
                         -6.22817338e-01,  -7.29897141e-01,  -7.52086818e-01,
                         -2.74573058e-01,  -1.23973712e-01,  -6.81888580e-01,
                         -8.45653772e-01,  -2.86244094e-01,  -1.34872869e-01,
                         -6.01876497e-01,  -7.91642427e-01,  -6.54555202e-01,
                         -6.66848302e-01,  -7.16128349e-01,  -6.79483891e-01,
                         -6.77437782e-01,  -6.83648407e-01,  -7.06851721e-01,
                         -7.03255415e-01,  -6.31323576e-01,  -7.29596198e-01,
                         -7.74649501e-01,  -3.66952479e-01,  -1.46007583e-01,
                         -5.33786416e-01,  -7.94309556e-01,  -6.88839674e-01,
                         -6.39632225e-01,  -6.96558356e-01,  -7.47956812e-01,
                         -5.65108359e-01,  -8.94715711e-02,   7.06160516e-02,
                         -3.62335712e-01,  -7.52256036e-01,  -6.95517540e-01,
                         -6.41070127e-01,  -7.98651695e-01,  -5.85328758e-01,
                         -1.41810432e-01,  -3.22313368e-01,  -7.58992732e-01,
                         -7.42052197e-01,  -6.45089507e-01,  -7.10219026e-01,
                         -7.04133749e-01,  -6.61149323e-01,  -6.93085074e-01,
                         -7.18686044e-01,  -6.56297565e-01,  -7.12556779e-01,
                         -7.84290195e-01,  -4.21474874e-01,  -1.43021256e-01,
                         -4.70066607e-01,  -7.62985945e-01,  -7.83091903e-01,
                         -6.36196375e-01,  -2.17113972e-01,  -1.97871000e-01,
                         -7.56279111e-01,  -7.88126171e-01,  -1.99970469e-01,
                         -1.53194189e-01,  -7.41627753e-01,  -8.10086787e-01,
                         -2.42925018e-01,  -1.67753473e-01,  -6.28031909e-01,
                         -7.74157584e-01,  -6.57763600e-01,  -6.68386161e-01,
                         -7.21689105e-01,  -6.79316938e-01,  -6.37603581e-01,
                         -7.54471481e-01,  -7.24680901e-01,  -2.77930677e-01,
                         -1.35709956e-01,  -6.72807932e-01,  -8.43859792e-01,
                         -2.85898238e-01,  -1.23195782e-01,  -5.98602474e-01,
                         -7.81758189e-01,  -6.21448815e-01,  -6.87148094e-01,
                         -7.40420997e-01,  -3.45476210e-01,   8.33549351e-02,
                         -7.25144371e-02,  -5.56887984e-01,  -7.38670588e-01,
                         -6.67642534e-01,  -6.76322877e-01,  -6.93164766e-01,
                         -6.43947780e-01,  -6.92469716e-01,  -7.03151464e-01,
                         -3.26169014e-01,   9.08331424e-02,  -9.67252329e-02,
                         -5.51571846e-01,  -7.03232527e-01,  -7.45096803e-01,
                         -6.20563447e-01,  -1.74312279e-01,  -1.89540982e-01,
                         -7.77526855e-01,  -7.27592707e-01,  -1.37143061e-01,
                         -2.48762429e-01,  -6.18651152e-01,  -2.19041511e-01,
                          1.81442320e-01,  -2.56767035e-01,  -6.49819911e-01,
                         -2.45727703e-01,   1.50441065e-01,  -1.66554347e-01,
                         -6.32368505e-01,  -7.05847025e-01,  -6.35836482e-01,
                         -6.32016659e-01,  -6.55480683e-01,  -7.08999157e-01,
                         -5.04077137e-01,   3.50897796e-02,   7.20217228e-02,
                         -4.69136596e-01,  -4.43826765e-01,  -1.29355043e-01,
                         -4.13281471e-01,  -4.37758297e-01,  -7.86380023e-02,
                         -4.64749098e-01,  -8.62434626e-01,  -3.48096758e-01,
                         -3.92139666e-02,  -4.58141208e-01,  -7.20919609e-01,
                         -6.28167808e-01,  -6.00488722e-01,  -6.46187246e-01,
                         -6.35126710e-01,  -6.18758917e-01,  -6.24635935e-01,
                         -6.23545587e-01,  -6.23394966e-01,  -6.23807549e-01,
                         -6.10742569e-01,  -6.05415046e-01,  -6.19077384e-01,
                         -6.20272696e-01,  -6.15970314e-01,  -6.21930242e-01,
                         -6.12696588e-01,  -6.13936782e-01,  -6.12903178e-01,
                         -5.95047235e-01,  -6.20967627e-01,  -5.89520872e-01,
                         -5.67366421e-01,  -6.95067823e-01,  -5.18762708e-01,
                         -8.78236145e-02,  -2.09467456e-01,  -6.38250113e-01,
                         -6.68351889e-01,  -5.41235149e-01,  -5.78507721e-01,
                         -6.26720607e-01,  -5.51584542e-01,  -5.61187863e-01,
                         -7.13731706e-01,  -4.88313526e-01,  -4.41098884e-02,
                         -2.00925693e-01,  -6.32545948e-01,  -6.47743106e-01,
                         -5.24849474e-01,  -5.68970740e-01,  -6.05158389e-01,
                         -5.31510949e-01,  -5.64803839e-01,  -7.01579213e-01,
                         -4.48554516e-01,  -2.51309071e-02,  -2.15117961e-01,
                         -6.36779726e-01,  -6.08036101e-01,  -5.07640660e-01,
                         -5.87206244e-01,  -5.71333706e-01,  -5.30017793e-01,
                         -5.71625590e-01,  -5.67503035e-01,  -5.48167467e-01,
                         -5.61604261e-01,  -5.53725243e-01,  -5.55306375e-01,
                         -5.62540710e-01,  -5.43589830e-01,  -5.48255265e-01,
                         -5.58440506e-01,  -5.44993162e-01,  -5.44155061e-01,
                         -5.40652215e-01,  -5.44018030e-01,  -5.63662648e-01,
                         -5.48107088e-01,  -5.35733283e-01,  -5.50707579e-01,
                         -5.42507350e-01,  -5.34380853e-01,  -5.33661842e-01,
                         -5.34859657e-01,  -5.51090002e-01,  -5.34446418e-01,
                         -5.21542311e-01,  -5.53697884e-01,  -5.50738573e-01,
                         -5.30934632e-01,  -5.32312453e-01,  -5.22511303e-01,
                         -5.32229125e-01,  -5.42773306e-01,  -5.23074389e-01,
                         -5.15759051e-01,  -5.20717502e-01,  -5.37584662e-01,
                         -5.46372652e-01,  -5.24687231e-01,  -5.26937962e-01,
                         -5.26873827e-01,  -5.08249044e-01,  -5.34364760e-01,
                         -5.42264938e-01,  -5.10605097e-01,  -5.16319513e-01,
                         -5.27507246e-01,  -5.26821375e-01,  -5.38030028e-01,
                         -5.36486506e-01,  -5.27220964e-01,  -5.21198809e-01,
                         -5.18994391e-01,  -5.24170876e-01,  -5.21425903e-01,
                         -5.25262773e-01,  -5.40753961e-01,  -5.36095619e-01,
                         -5.21323264e-01,  -5.18884838e-01,  -5.22412181e-01,
                         -5.29738009e-01,  -5.33393681e-01,  -5.23176312e-01,
                         -5.18536091e-01,  -5.27435303e-01,  -5.26752353e-01,
                         -5.22369266e-01,  -5.24980843e-01,  -5.32148242e-01,
                         -5.38251221e-01,  -5.20137072e-01,  -5.33125460e-01,
                         -5.63688815e-01,  -4.84297186e-01,  -4.96117830e-01,
                         -6.49816573e-01,  -4.11518425e-01,   1.08645037e-02,
                         -1.90816596e-01,  -6.08576655e-01,  -5.56476176e-01,
                         -4.76312757e-01,  -5.73911905e-01,  -5.22090137e-01,
                         -5.49836040e-01,  -6.18519187e-01,  -2.40924135e-01,
                          4.37777974e-02,  -4.02697027e-01,  -7.20401466e-01,
                         -2.57615864e-01,   4.77081314e-02,  -3.63288164e-01,
                         -6.51582718e-01,  -5.05234003e-01,  -5.69345117e-01,
                         -6.36287689e-01,  -1.91043511e-01,   2.06932556e-02,
                         -4.27412927e-01,  -6.78538263e-01,  -5.36193550e-01,
                         -5.25892675e-01,  -5.65451622e-01,  -5.44337809e-01,
                         -5.66598773e-01,  -5.20664394e-01,  -5.56260169e-01,
                         -6.68744862e-01,  -3.69091064e-01,  -8.76148324e-03,
                         -2.90494680e-01,  -6.59231842e-01,  -5.73910356e-01,
                         -5.12994051e-01,  -5.86571157e-01,  -5.49147785e-01,
                         -5.58091938e-01,  -5.93076408e-01,  -5.63174903e-01,
                         -6.13669515e-01,  -5.54168463e-01,  -1.77721530e-01,
                          1.73846021e-01,   4.32758071e-02,  -5.25141954e-01,
                         -7.49623656e-01,  -2.48227894e-01,  -1.17358072e-02,
                         -4.26980883e-01,  -3.92689884e-01,   1.08415797e-01,
                          1.09010898e-01,  -9.32734646e-03,   1.61466867e-01,
                         -9.75860059e-02,  -5.29659927e-01,  -2.56303966e-01,
                          1.43382609e-01,   2.90965941e-02,   9.65192635e-03,
                          1.77294001e-01,  -1.52175024e-01,  -5.78879356e-01,
                         -2.19409570e-01,   2.57186264e-01,  -1.46256432e-01,
                         -5.72928190e-01,  -1.67610407e-01,  -3.42228003e-02,
                         -6.65726781e-01,  -7.11252987e-01,  -8.67331326e-02,
                         -1.40945807e-01,  -5.34243643e-01,  -2.13018239e-01,
                          1.52951375e-01,   3.38036963e-03,   4.36778292e-02,
                          1.44811779e-01,  -2.92659611e-01,  -5.38770080e-01,
                         -9.87745672e-02,   1.40297920e-01,  -3.69141437e-02,
                          5.94221354e-02,   1.16866469e-01,  -3.54821712e-01,
                         -5.46357095e-01,  -1.65593512e-02,   2.11341605e-01,
                         -3.38456511e-01,  -6.05031908e-01,  -5.21998443e-02,
                          2.27483585e-01,  -2.85586715e-01,  -5.25550723e-01,
                         -1.51725188e-01,   8.32298696e-02,   1.00159362e-01,
                         -4.81386930e-02,  -4.72508311e-01,  -4.40572321e-01,
                          1.43483400e-01,   9.22134593e-02,  -4.94067281e-01,
                         -4.36394632e-01,   2.35860832e-02,   9.92176682e-02,
                          3.34841199e-03,   1.10014221e-02,   1.70826018e-02,
                          3.42611596e-02,   4.43241782e-02,   1.08633749e-02,
                          1.51497228e-02,   3.96486893e-02,   2.92865206e-02,
                          9.63733159e-03,   7.44723482e-03,   2.72509456e-02,
                          2.99635828e-02,   1.11621497e-02,   1.56567581e-02,
                          1.22113461e-02,  -7.59428740e-03,   1.55796707e-02,
                          5.15131317e-02,   4.22252640e-02,   2.64943410e-02,
                          2.98201554e-02,   5.16607147e-03,  -1.73879489e-02,
                          2.32471190e-02,   4.76682559e-02,   1.29335709e-02,
                          5.21279080e-03,   2.86100544e-02,   3.04660648e-02,
                          2.02485472e-02,   2.65906621e-02,   4.03735042e-02,
                          2.43779998e-02,   2.39101402e-03,   8.63287970e-03,
                          2.01127138e-02,   3.08317002e-02,   2.14856323e-02,
                          5.40802488e-03,   2.76223179e-02,   2.38303244e-02,
                         -4.76305606e-03,   1.82824545e-02,   4.01324295e-02,
                          3.13033201e-02,   1.68378800e-02,   8.89254082e-03,
                          2.85475701e-02,   2.18380746e-02,   2.10771104e-03,
                          2.61087082e-02,   2.74725482e-02,   2.91193165e-02,
                          5.03144488e-02,   1.71468090e-02,   2.74273450e-03,
                          2.61714328e-02,   1.57181658e-02,   1.32465223e-02,
                          1.92177482e-02,   2.04968210e-02,   2.08624247e-02,
                          1.71322357e-02,   7.29258358e-02,  -5.55217313e-03,
                         -4.31020617e-01,  -7.41596162e-01,  -4.83682513e-01,
                         -5.10892719e-02,   6.75054789e-02,   1.10754184e-02,
                          2.00266819e-02,   2.40923259e-02,  -7.97102880e-03,
                          7.32173445e-03,   3.34136225e-02,   1.99236125e-02,
                          9.22166463e-03,   2.23596320e-02,   1.71953365e-02,
                         -7.48018501e-04,   2.21146066e-02,   3.56844254e-02,
                          7.88172707e-03,  -3.56880273e-03,  -1.54026765e-02,
                         -2.58521410e-03,   4.76553403e-02,   3.24968435e-02,
                         -3.03199212e-03,   2.71017104e-03,   8.31192639e-03,
                          2.68498529e-02,   7.52870087e-03,  -2.59010531e-02,
                          1.51058240e-02,   2.25952752e-02,  -1.16825486e-02,
                         -6.73213508e-03,  -1.43259205e-03,   1.83965992e-02,
                          1.77784059e-02,  -1.94580499e-02,  -1.13914311e-02,
                         -2.47609476e-03,   8.50830972e-03,   3.09645031e-02,
                         -2.75523961e-03,  -1.37365935e-02,  -7.67252548e-03,
                         -2.33344864e-02,   1.52514139e-02,   8.61181878e-03,
                         -4.60527875e-02,  -2.56826151e-02,  -9.80308373e-03,
                          1.29381358e-03,   2.83788498e-02,  -2.89819692e-03,
                         -3.21981013e-02,  -3.58395316e-02,  -2.29981858e-02,
                          1.60841793e-02,  -5.33271208e-03,  -4.40359861e-02,
                         -1.99806523e-02,   1.72514061e-03,   4.54691751e-03,
                         -5.81822824e-03,  -2.20923126e-02,  -2.14723237e-02,
                         -3.34435329e-02,  -2.67691910e-02,   7.26363854e-03,
                         -2.51489505e-02,  -5.41399121e-02,   2.31098346e-02,
                         -1.36949167e-01,  -6.85008824e-01,  -7.71361113e-01,
                         -2.01568887e-01,  -1.76649123e-01,  -5.71797311e-01,
                         -2.96204418e-01,  -1.20927453e-01,  -6.91764534e-01,
                         -7.88540363e-01,  -1.75022781e-01,  -1.05771117e-01,
                         -7.04566896e-01,  -8.16235840e-01,  -2.37447336e-01,
                         -1.01932734e-01,  -5.98238528e-01,  -7.42010355e-01,
                         -6.00257993e-01,  -7.01805532e-01,  -6.86730027e-01,
                         -6.10533834e-01,  -7.71222353e-01,  -5.89309514e-01,
                         -1.31314054e-01,  -2.65957564e-01,  -7.13502228e-01,
                         -7.51986384e-01,  -6.09805524e-01,  -6.51569426e-01,
                         -7.24333286e-01,  -6.29696250e-01,  -6.17924154e-01,
                         -7.88320661e-01,  -5.67927957e-01,  -1.73730969e-01,
                         -3.74136835e-01,  -4.87118334e-01,  -1.31957754e-01,
                         -3.78755242e-01,  -8.99558067e-01,  -5.23885727e-01,
                         -2.47613229e-02,  -3.97624612e-01,  -8.22099507e-01,
                         -6.67118847e-01,  -6.57461405e-01,  -7.88863003e-01,
                         -3.85634094e-01,  -1.61991820e-01,  -5.36594450e-01,
                         -4.23685044e-01,  -8.36281851e-02,  -5.64090729e-01,
                         -9.04376686e-01,  -3.40823144e-01,  -1.33478269e-01,
                         -6.05714202e-01,  -4.50452536e-01,   1.62864849e-01,
                         -9.51192304e-02,  -6.64046586e-01,  -3.65790904e-01,
                         -8.73858407e-02,  -6.53738022e-01,  -8.87128115e-01,
                         -3.01507443e-01,  -1.31643325e-01,  -5.88893890e-01,
                         -7.77790606e-01,  -7.14178801e-01,  -6.06717527e-01,
                         -2.28563085e-01,   5.67217544e-02,  -2.22656831e-01,
                         -7.38180995e-01,  -7.78042614e-01,  -3.02710235e-01,
                         -1.97007433e-01,  -6.00719512e-01,  -7.65961885e-01,
                         -7.46006072e-01,  -5.91788530e-01,  -1.68508798e-01,
                         -3.20796758e-01,  -9.06901658e-01,  -6.41126096e-01,
                         -1.18084185e-01,  -4.21396822e-01,  -6.01103246e-01,
                         -1.83033645e-01,  -3.71437609e-01,  -9.16752815e-01,
                         -5.56005895e-01,  -1.44866064e-01,  -5.09183645e-01,
                         -5.26898980e-01,  -1.77284256e-01,  -4.54143167e-01,
                         -8.84474695e-01,  -6.58896863e-01,  -5.90011403e-02,
                          1.87070537e-02,  -4.83250886e-01,  -5.21647871e-01,
                         -2.41228253e-01,  -4.67574179e-01,  -5.53499818e-01,
                         -1.80520266e-01,   5.30847535e-03,  -5.97299561e-02,
                         -3.60948890e-01,  -6.01207554e-01,  -3.14435184e-01,
                         -2.61046231e-01,  -7.93909669e-01,  -8.33759665e-01,
                         -2.46457025e-01,  -1.63360145e-02,  -2.06436843e-01,
                         -1.27100468e-01,   3.34824398e-02,  -3.53907287e-01,
                         -6.93370759e-01,  -3.33760470e-01,  -1.33022992e-02,
                         -6.59614876e-02,  -1.17333286e-01,  -4.82722431e-01,
                         -9.25899804e-01,  -6.14539385e-01,  -1.82547450e-01,
                         -4.57215518e-01,  -7.92368829e-01,  -7.77671456e-01,
                         -7.38185048e-01,  -4.84755427e-01,  -2.86316890e-02,
                         -8.24629590e-02,  -6.11532867e-01,  -8.32193971e-01,
                         -7.00443268e-01,  -7.28045940e-01,  -8.47294092e-01,
                         -5.85983396e-01,  -7.53087774e-02,  -4.05291133e-02,
                         -5.23255348e-01,  -7.83302069e-01,  -7.52416372e-01,
                         -7.87219107e-01,  -5.30778646e-01,   6.41810754e-03,
                         -8.61970186e-02,  -6.51475668e-01,  -5.41459382e-01,
                         -1.56378627e-01,  -5.90990067e-01,  -9.74073768e-01,
                         -4.42948103e-01,  -2.13554874e-01,  -6.05141699e-01,
                         -4.63599384e-01,  -2.21818775e-01,  -6.55871034e-01,
                         -8.80490363e-01,  -6.54376090e-01,  -7.68371761e-01,
                         -8.44133019e-01,  -3.67033213e-01,  -2.15166733e-01,
                         -7.52556503e-01,  -8.83914173e-01,  -3.22628528e-01,
                         -1.76384971e-01,  -7.06141412e-01,  -9.07924116e-01,
                         -4.57728058e-01,  -1.03595398e-01,  -1.06186040e-01,
                         -8.25397819e-02,  -2.45379105e-01,  -7.70537436e-01,
                         -8.47961307e-01,  -3.19547415e-01,  -2.23161936e-01,
                         -6.81384742e-01,  -8.51893723e-01,  -7.14711308e-01,
                         -7.06380367e-01,  -7.24857211e-01,  -7.41755188e-01,
                         -8.28255594e-01,  -5.83204210e-01,  -1.63090944e-01,
                         -3.58019590e-01,  -8.34094763e-01,  -8.29359114e-01,
                         -6.78452551e-01,  -7.06871629e-01,  -7.19894946e-01,
                         -7.17257321e-01,  -7.12029934e-01,  -7.25595713e-01,
                         -6.55330598e-01,  -2.23071799e-01,   8.49843919e-02,
                         -3.05068254e-01,  -7.46285856e-01,  -6.95902705e-01,
                         -6.53496027e-01,  -7.83401668e-01,  -7.02434063e-01,
                         -6.17335320e-01,  -7.53680289e-01,  -5.68631113e-01,
                         -1.57370284e-01,  -3.48084033e-01,  -7.85405874e-01,
                         -7.47973442e-01,  -6.22854948e-01,  -6.71852708e-01,
                         -6.88104570e-01,  -7.14278996e-01,  -6.94960654e-01,
                         -6.10533178e-01,  -6.18784070e-01,  -6.99204087e-01,
                         -7.53981173e-01,  -4.95531470e-01,   3.96358594e-02,
                          4.68268506e-02,  -4.52919900e-01,  -4.79642481e-01,
                         -9.11648870e-02,   5.70143536e-02,   8.76665395e-03,
                         -1.90483734e-01,  -5.77934265e-01,  -7.18052268e-01,
                         -5.86732924e-01,  -6.80750906e-01,  -6.83451593e-01,
                         -1.88535511e-01,  -5.08775525e-02,  -6.21749818e-01,
                         -7.55871654e-01,  -2.13106483e-01,  -9.92480963e-02,
                         -5.92757285e-01,  -7.71237135e-01,  -3.26416433e-01,
                          5.34677207e-02,   4.12006164e-03,  -1.23143441e-03,
                          9.87034440e-02,  -2.22387705e-02,  -1.49592729e-02,
                          1.38673246e-01,  -1.81977138e-01,  -5.42346656e-01,
                         -2.24168018e-01,   1.51204750e-01,   7.34683052e-02,
                          7.81659037e-03,   3.22963446e-02,  -2.55820844e-02,
                          5.79041913e-02,   4.78966460e-02,  -3.26313376e-01,
                         -4.05603647e-01,  -4.21315525e-03,   1.37078673e-01,
                          1.22284899e-02,   4.24835458e-02,   8.07044059e-02,
                          5.15448786e-02,   3.01328972e-02,  -6.18997554e-04,
                          3.63349281e-02,   5.95177040e-02,   7.93874711e-02,
                          1.88902453e-01,   9.38584805e-02,  -5.64566888e-02,
                          8.49799514e-02,  -1.44762534e-03,  -3.50330859e-01,
                         -2.87446707e-01,  -4.87005478e-03,   1.45042136e-01,
                          1.53249726e-01,  -1.85201526e-01,  -4.52947289e-01,
                         -1.41934812e-01,   1.86198682e-01,   1.29678339e-01,
                         -5.95201589e-02,  -3.57407004e-01,  -6.27084255e-01,
                         -4.36389744e-01,   8.81612375e-02,   1.91413045e-01,
                         -2.97750831e-01,  -4.98627871e-01,  -3.89203429e-02,
                          2.71222323e-01,   7.72971660e-02,  -5.69303371e-02,
                          7.33624473e-02,   1.41955912e-01,   8.60842094e-02,
                          1.00067616e-01,   1.31541491e-01,   9.79765356e-02,
                          1.15014344e-01,   9.43694562e-02,   1.05184456e-02,
                          6.11970052e-02,  -2.15308685e-02,  -3.43316227e-01,
                         -2.87052065e-01,   9.67649668e-02,   1.60313949e-01,
                          9.83090028e-02,   1.72484145e-01,  -8.63640234e-02,
                         -4.98952121e-01,  -2.25116327e-01,   2.88122594e-01,
                         -9.52507835e-03,  -4.71575081e-01,  -2.08860770e-01,
                         -6.31876364e-02,  -3.87813926e-01,  -2.20218629e-01,
                          1.80513978e-01,  -8.24822709e-02,  -4.18109745e-01,
                         -1.97914630e-01,   8.80773067e-02,   1.92702159e-01,
                          1.08550146e-01,  -3.38390261e-01,  -5.12847185e-01,
                          3.27182151e-02,   2.55058885e-01,  -2.41901621e-01,
                         -5.31111658e-01,  -5.73048651e-01,  -6.42443299e-01,
                         -3.09520453e-01,   1.66002307e-02,  -3.37229729e-01,
                         -6.79928005e-01,  -3.46243143e-01,   1.28204688e-01,
                          8.94080102e-02,  -3.31691712e-01,  -5.89209676e-01,
                         -6.20355725e-01,  -6.41097248e-01,  -3.86075914e-01,
                          1.12948015e-01,   1.31586924e-01,  -3.33410323e-01,
                         -5.83409071e-01,  -6.06538832e-01,  -5.45062304e-01,
                         -1.50940612e-01,  -1.45627558e-03,  -6.05115056e-01,
                         -7.80718625e-01,  -1.35200247e-01,  -8.03325027e-02,
                         -4.52279806e-01,  -1.96049064e-01,  -1.46259725e-01,
                         -5.30375302e-01,  -1.83727488e-01,   2.65047401e-01,
                         -2.12084055e-01,  -5.38098991e-01,  -6.65085986e-02,
                          1.53828681e-01,  -8.58075768e-02,   2.61221118e-02,
                          1.62530661e-01,  -2.95403928e-01,  -4.71367598e-01,
                         -6.35001063e-02,  -2.36758739e-01,  -5.70728064e-01,
                         -1.17918872e-03,   2.40247443e-01,  -4.22674030e-01,
                         -4.56692666e-01,  -2.12881826e-02,  -3.06391150e-01,
                         -4.42919552e-01,   1.66987181e-01,   1.88516617e-01,
                         -5.32945752e-01,  -5.21340728e-01,   1.23005221e-02,
                         -3.21568429e-01,  -8.25703740e-01,  -3.45018834e-01,
                         -2.18653399e-02,  -5.04045069e-01,  -4.63545591e-01,
                          1.38494566e-01,   2.18973041e-01,   1.05448971e-02,
                         -2.07784474e-01,  -6.64173245e-01,  -6.97460413e-01,
                         -6.82698265e-02,   5.68991452e-02,  -6.15527987e-01,
                         -8.00646603e-01,  -1.75288126e-01,  -5.88947907e-02,
                         -5.65262258e-01,  -2.87797958e-01,   3.34191561e-01,
                         -9.01683196e-02,  -5.78913987e-01,  -2.32779369e-01,
                         -1.82083920e-01,  -4.18024659e-01,  -1.45388171e-01,
                         -1.47138968e-01,  -6.64623141e-01,  -7.29263067e-01,
                         -4.82196480e-01,  -5.44233024e-01,  -6.59674048e-01,
                         -5.81888497e-01,  -5.31118751e-01,  -6.26022458e-01,
                         -5.69698453e-01,  -1.44892752e-01,   1.37052789e-01,
                         -1.38582975e-01,  -4.76622254e-01,  -5.48279941e-01,
                         -6.11089706e-01,  -5.21777749e-01,  -9.29693133e-02,
                          1.41614079e-01,  -1.49059236e-01,  -5.26487947e-01,
                         -6.28051639e-01,  -5.67089796e-01,  -5.95492065e-01,
                         -5.97052693e-01,  -1.92077607e-01,   1.60836443e-01,
                         -1.86171010e-01,  -4.44819957e-01,  -1.41039744e-01,
                         -2.09212631e-01,  -4.61181015e-01,  -1.45308569e-01,
                         -1.25412896e-01,  -6.93214118e-01,  -6.61991656e-01,
                         -4.19890769e-02,   1.42985255e-01,  -4.87409048e-02,
                          2.68492792e-02,   1.44850016e-01,  -2.02342778e-01,
                         -4.58192080e-01,  -8.20361599e-02,   1.89497247e-01,
                          3.75222135e-03,  -3.09009124e-02,   8.47505629e-02,
                          5.43637089e-02,   2.39245053e-02,   2.56329812e-02,
                          3.87204066e-02,   1.03233345e-01,   1.04789138e-01,
                          3.92133296e-02,   1.28560020e-02,   4.46068645e-02,
                          6.19395785e-02,  -5.49414009e-03,  -4.56884550e-03,
                          1.25527874e-01,   1.38578251e-01,   2.94061601e-02,
                         -1.36116566e-02,   1.87156834e-02,   7.06417933e-02,
                          5.89715242e-02,   2.91299298e-02,   6.58304766e-02,
                          4.68856990e-02,   8.47052261e-02,   2.02642605e-01,
                         -1.00451976e-01,  -5.72178781e-01,  -3.66122276e-01,
                          1.24548800e-01,   1.29349396e-01,   5.82672879e-02,
                          1.79797307e-01,  -1.28070563e-01,  -6.31206393e-01,
                         -3.23862821e-01,   3.13007295e-01,   7.94714540e-02,
                         -4.95630085e-01,  -3.82055432e-01,   3.59303057e-02,
                          1.57812238e-01,   9.04539973e-02,   5.80210844e-03,
                         -3.00494470e-02,   1.92371588e-02,   1.12888590e-01,
                          1.24081269e-01,  -9.65630356e-03,  -1.84843857e-02,
                          1.02638893e-01,  -1.36055753e-01,  -4.65434581e-01,
                         -1.78554580e-01,   2.08379328e-01,  -1.12574533e-01,
                         -6.11258507e-01,  -5.72367728e-01,  -4.22400475e-01,
                         -6.10802174e-01,  -6.41535223e-01,  -2.28929013e-01,
                          8.47176686e-02,   8.19856375e-02,   3.14325728e-02,
                         -1.81498200e-01,  -5.99056244e-01,  -6.66029930e-01,
                         -1.86095044e-01,   2.06936866e-01,   1.95971727e-02,
                         -4.70801532e-01,  -6.82566285e-01,  -4.20557022e-01,
                         -5.81401363e-02,   5.24815619e-02,   5.47434501e-02,
                          7.27173015e-02,  -4.51712217e-03,  -2.43477970e-02,
                          9.28534120e-02,  -4.58502918e-02,  -5.05976439e-01,
                         -6.97002530e-01,  -3.54890674e-01,   1.61457229e-02,
                          9.20828283e-02,   1.01759367e-01,  -7.05247894e-02,
                         -5.62757194e-01,  -7.14074373e-01,  -2.87557036e-01,
                          3.56249399e-02,   1.56799834e-02,  -8.03928971e-02,
                         -2.22479627e-02,   1.97932124e-01,   6.30974770e-02,
                         -4.31161374e-01,  -4.46294367e-01,  -2.52027418e-02,
                          1.28950775e-01,   4.97457013e-02,   1.05127618e-02,
                         -3.70541867e-03,  -3.83519195e-02,   9.92459338e-03,
                          1.63498148e-01,  -6.82989834e-03,  -4.15791303e-01,
                         -3.42228860e-01,  -1.73768640e-01,  -4.23908770e-01,
                         -3.50500554e-01,   4.90764007e-02,   6.49030209e-02,
                         -5.00039831e-02,  -2.22013265e-01,  -6.57955050e-01,
                         -6.99242175e-01,  -1.54198363e-01,   1.42102331e-01,
                         -1.15012638e-01,  -4.92910981e-01,  -6.74614310e-01,
                         -6.02270484e-01,  -4.40367997e-01,  -5.40294290e-01,
                         -7.72421420e-01,  -5.20900369e-01,  -8.01728070e-02,
                         -2.77119845e-01,  -6.81482792e-01,  -6.33839250e-01,
                         -5.50344467e-01,  -6.33952796e-01,  -6.25860929e-01,
                         -6.26815021e-01,  -6.79830968e-01,  -6.58871114e-01,
                         -5.85146964e-01,  -5.09418428e-01,  -5.22029757e-01,
                         -6.20910048e-01,  -6.78870261e-01,  -6.67409837e-01,
                         -5.79860330e-01,  -5.24988472e-01,  -6.29989743e-01,
                         -6.91380262e-01,  -6.36674583e-01,  -6.50022984e-01,
                         -6.32287204e-01,  -5.31560361e-01,  -5.64731538e-01,
                         -6.91412568e-01,  -6.94029033e-01,  -5.80634773e-01,
                         -5.21416187e-01,  -5.79417169e-01,  -6.28547072e-01,
                         -6.08831227e-01,  -5.98340929e-01,  -6.07066512e-01,
                         -6.05689049e-01,  -5.97676456e-01,  -6.07466161e-01,
                         -6.40818059e-01,  -6.15942657e-01,  -5.54961562e-01,
                         -5.91789842e-01,  -6.63031757e-01,  -6.60527766e-01,
                         -6.25247240e-01,  -5.93445718e-01,  -6.09508216e-01,
                         -6.73263013e-01,  -6.92170978e-01,  -6.66567445e-01,
                         -6.18206441e-01,  -5.60377538e-01,  -5.96303046e-01,
                         -6.77635550e-01,  -6.55317962e-01,  -5.97308993e-01,
                         -6.02356136e-01,  -6.28362715e-01,  -6.37326598e-01,
                         -6.32265270e-01,  -6.34894669e-01,  -6.39640093e-01,
                         -6.25003636e-01,  -6.26747310e-01,  -6.25544786e-01,
                         -5.99491954e-01,  -6.60680711e-01,  -7.53565848e-01,
                         -6.94258034e-01,  -6.08320236e-01,  -6.10676706e-01,
                         -5.84697783e-01,  -6.35267854e-01,  -7.19511628e-01,
                         -4.37261939e-01,  -9.60363895e-02,  -3.41830909e-01,
                         -7.51304030e-01,  -7.41210103e-01,  -6.40515029e-01,
                         -6.69950426e-01,  -6.58565164e-01,  -6.60802901e-01,
                         -6.54128790e-01,  -5.79294682e-01,  -6.36230171e-01,
                         -7.53341556e-01,  -6.71294153e-01,  -5.49921215e-01,
                         -5.94796896e-01,  -6.72660172e-01,  -6.77942276e-01,
                         -6.87097192e-01,  -7.31536627e-01,  -7.10592151e-01,
                         -6.03414476e-01,  -5.97362220e-01,  -7.04084814e-01,
                         -6.86450243e-01,  -6.19967878e-01,  -6.61021113e-01,
                         -6.21114194e-01,  -6.11418486e-01,  -7.92073667e-01,
                         -6.22397721e-01,  -1.41609102e-01,  -2.40509301e-01,
                         -7.02495277e-01,  -7.52290070e-01,  -6.74947739e-01,
                         -7.03470945e-01,  -6.03692412e-01,  -6.37706935e-01,
                         -7.46869564e-01,  -3.88545007e-01,  -6.90075532e-02,
                         -5.24754822e-01,  -8.99496317e-01,  -3.84937644e-01,
                         -3.95408235e-02,  -4.72267419e-01,  -5.06753623e-01,
                          3.17096598e-02,  -4.97856922e-02,  -6.18953645e-01,
                         -7.22609878e-01,  -5.32934606e-01,  -6.43933952e-01,
                         -8.14431548e-01,  -4.57349598e-01,  -4.81314659e-02,
                         -4.53249156e-01,  -8.87996674e-01,  -4.55891013e-01,
                         -1.43624529e-01,  -4.92428452e-01,  -7.11105227e-01,
                         -7.13622093e-01,  -6.91745579e-01,  -3.42888236e-01,
                          6.13716580e-02,  -7.26586580e-02,  -5.89129150e-01,
                         -8.27124476e-01,  -5.14293373e-01,  -4.25097272e-02,
                          7.08413869e-02,  -3.36416066e-01,  -8.06899428e-01,
                         -6.78408384e-01,  -2.29592919e-01,  -6.40570372e-02,
                          6.85040606e-03,  -7.00876862e-02,  -4.67355639e-01,
                         -4.82523948e-01,  -1.36726037e-01,  -4.00507540e-01,
                         -9.07582045e-01,  -5.95741868e-01,  -1.99142732e-02,
                         -3.39788318e-01,  -9.35075343e-01,  -6.11269176e-01,
                         -1.07903272e-01,  -3.71328950e-01,  -5.45427978e-01,
                         -1.58312365e-01,   6.78695589e-02,  -9.28406511e-03,
                         -7.00206906e-02,  -3.05684246e-02,  -7.01690242e-02,
                         -4.06615704e-01,  -5.39834321e-01,  -1.49362996e-01,
                          3.21741253e-02,  -1.10783666e-01,  -4.57644686e-02,
                          1.52246589e-02,  -8.33453462e-02,  -7.92927295e-02,
                         -1.81351826e-02,  -8.07034876e-03,  -4.06470075e-02,
                         -2.56020371e-02,  -2.15996522e-02,  -4.24484879e-01,
                         -8.84809494e-01,  -5.87548256e-01,  -1.18324004e-01,
                         -3.23495328e-01,  -4.86045897e-01,  -8.40336978e-02,
                          2.90761478e-02,  -4.03438181e-01,  -4.93047953e-01,
                         -1.21093608e-01,   8.79692961e-04,  -8.33574608e-02,
                          4.05301247e-03,  -3.02813705e-02,  -4.12242860e-01,
                         -7.37411261e-01,  -6.10041440e-01,  -2.15894714e-01,
                          2.60454621e-02,   6.54514208e-02,  -1.36363313e-01,
                         -5.25939643e-01,  -4.11077082e-01,   1.47301853e-01,
                          5.42494506e-02,  -5.12235880e-01,  -5.08840263e-01,
                         -6.44961372e-02,   1.07896514e-01,  -2.47293890e-01,
                         -7.20355332e-01,  -6.36241496e-01,  -1.41193688e-01,
                          1.18063942e-01,  -1.29642814e-01,  -7.07803309e-01,
                         -8.00353169e-01,  -2.21094444e-01,  -8.26897696e-02,
                         -4.09693152e-01,  -3.13122928e-01,  -2.02860236e-01,
                         -4.81788814e-01,  -6.85870290e-01,  -7.00457990e-01,
                         -4.49092925e-01,  -8.76157880e-02,  -3.19473326e-01,
                         -7.53981650e-01,  -4.40179080e-01,  -9.76286270e-03,
                         -3.40646327e-01,  -7.16621518e-01,  -5.46271622e-01,
                         -5.27219117e-01,  -7.33044028e-01,  -4.32041913e-01,
                         -6.15830719e-02,  -3.35401922e-01,  -6.97772801e-01,
                         -6.70763612e-01,  -5.21097600e-01,  -5.05918443e-01,
                         -6.65686846e-01,  -5.58731794e-01,  -9.62599441e-02,
                         -1.48056343e-01,  -6.54696941e-01,  -6.80493236e-01,
                         -4.60542023e-01,  -5.26452243e-01,  -6.34413779e-01,
                         -6.45324588e-01,  -5.93877494e-01,  -5.35559356e-01,
                         -5.80058753e-01,  -5.90432346e-01,  -5.77063739e-01,
                         -6.23369753e-01,  -5.56865633e-01,  -5.82613230e-01,
                         -7.24900544e-01,  -4.04948741e-01,  -6.96963817e-03,
                         -3.14406335e-01,  -6.93359673e-01,  -5.48131526e-01,
                         -4.79863793e-01,  -6.63088858e-01,  -6.46645606e-01,
                         -5.40956736e-01,  -5.93097925e-01,  -6.07883573e-01,
                         -5.31812668e-01,  -5.43208539e-01,  -5.88764608e-01,
                         -5.74677348e-01,  -5.86317062e-01,  -6.21923447e-01,
                         -6.09049380e-01,  -5.81701338e-01,  -5.68218946e-01,
                         -5.67308187e-01,  -6.02025807e-01,  -6.38477206e-01,
                         -6.21442378e-01,  -5.80503285e-01,  -5.64159691e-01,
                         -5.58328807e-01,  -5.54862261e-01,  -5.70721447e-01,
                         -5.77067256e-01,  -5.74375331e-01,  -6.05027258e-01,
                         -6.17727697e-01,  -5.82439005e-01,  -5.78754127e-01,
                         -6.15264952e-01,  -6.33258522e-01,  -6.05648935e-01,
                         -5.58003008e-01,  -5.68852663e-01,  -6.04714334e-01,
                         -5.94990730e-01,  -6.27015710e-01,  -6.55894160e-01,
                         -5.44613600e-01,  -4.73017216e-01,  -5.89235842e-01,
                         -6.73976779e-01,  -5.84598720e-01,  -5.07666349e-01,
                         -6.00707650e-01,  -6.76521003e-01,  -5.76052845e-01,
                         -5.38809061e-01,  -6.43587232e-01,  -6.33654475e-01,
                         -5.58998644e-01,  -5.90542138e-01,  -6.13472819e-01,
                         -5.98620117e-01,  -6.25399590e-01,  -6.23989046e-01,
                         -5.80397069e-01,  -5.95389485e-01,  -6.30402148e-01,
                         -5.79721510e-01,  -5.46896636e-01,  -6.00806952e-01,
                         -5.82761705e-01,  -5.69908559e-01,  -6.61379993e-01,
                         -6.14876807e-01,  -5.70961416e-01,  -6.87383831e-01,
                         -4.56315815e-01,  -6.71601221e-02,  -2.96634108e-01,
                         -7.33173192e-01,  -7.11362660e-01,  -5.62461317e-01,
                         -6.04238331e-01,  -6.72147512e-01,  -6.09634519e-01,
                         -5.13038993e-01,  -5.57924390e-01,  -6.07873976e-01,
                         -5.90485752e-01,  -6.67511821e-01,  -7.25102007e-01,
                         -6.97762668e-01,  -5.53200185e-01,  -1.73218563e-01,
                         -1.39789179e-01,  -6.29677773e-01,  -6.17198586e-01,
                         -9.97325405e-02,   4.19278555e-02,  -1.28093762e-02,
                         -6.03003136e-05,  -5.88754714e-02,  -1.87136780e-03,
                          6.22273311e-02,  -2.20583603e-02,  -1.81023171e-03,
                          2.72076111e-02,  -3.84419076e-02,  -4.22781240e-03,
                          7.44502014e-03,  -6.21883124e-02,  -2.83865295e-02,
                          3.39636505e-02,   1.92936137e-02,  -1.00186486e-02,
                          1.53871104e-02,   6.76979572e-02,   1.33896675e-02,
                         -5.05685918e-02,   2.92349849e-02,   4.89208959e-02,
                         -2.50260513e-02,   2.00373381e-02,   6.29994944e-02,
                         -1.76586006e-02,  -5.68866692e-02,  -2.22002212e-02,
                         -2.32181698e-02,  -2.57453825e-02,   5.70843294e-02,
                          9.35388580e-02,  -4.17465493e-02,  -9.32405517e-02,
                          4.95136715e-02,   6.27453625e-02,  -3.44672091e-02,
                          3.85492928e-02,   9.54436734e-02,  -3.91018689e-02,
                         -9.03298259e-02,   2.58762715e-03,  -1.10719400e-02,
                         -4.27791141e-02,   4.83226366e-02,   1.10457493e-02,
                         -6.30851984e-02,   9.78633016e-02,  -1.32788355e-02,
                         -4.73488748e-01,  -3.78541768e-01,   5.56889288e-02,
                         -3.54017466e-02,  -1.63811848e-01,   6.72914740e-03,
                         -1.93787068e-01,  -5.42260826e-01,  -3.05747002e-01,
                          1.13711350e-01,  -5.05004153e-02,  -5.86107910e-01,
                         -7.30412722e-01,  -5.69071770e-01,  -6.83437884e-01,
                         -6.64313614e-01,  -2.32718721e-01,  -2.16125324e-01,
                         -4.95874465e-01,  -3.00221622e-01,  -2.35822484e-01,
                         -6.51161373e-01,  -7.36710250e-01,  -5.54664791e-01,
                         -6.12005115e-01,  -6.42885625e-01,  -5.93276262e-01,
                         -6.59806490e-01,  -6.54434562e-01,  -5.75703740e-01,
                         -6.49130225e-01,  -7.76645660e-01,  -7.11312711e-01,
                         -5.44349253e-01,  -5.99992633e-01,  -7.27161586e-01,
                         -5.94237328e-01,  -5.73171794e-01,  -7.78184414e-01,
                         -5.15182793e-01,  -3.26883160e-02,  -3.03179055e-01,
                         -8.32119405e-01,  -5.72864115e-01,  -7.94453993e-02,
                         -2.84279197e-01,  -7.07675457e-01,  -6.84273005e-01,
                         -5.67941725e-01,  -6.50773406e-01,  -6.86986446e-01,
                         -6.57197058e-01,  -6.71124935e-01,  -6.79900587e-01,
                         -6.72282994e-01,  -6.34696245e-01,  -6.15516603e-01,
                         -6.62935793e-01,  -6.70277953e-01,  -6.84416294e-01,
                         -6.59778118e-01,  -3.59668106e-01,  -1.51724041e-01,
                         -4.15416747e-01,  -6.82571530e-01,  -6.60320520e-01,
                         -6.03237987e-01,  -6.51073217e-01,  -7.45618165e-01,
                         -5.72002769e-01,  -1.95946738e-01,  -3.34638953e-01,
                         -7.37793624e-01,  -4.92755860e-01,  -9.22732055e-02,
                         -3.77469003e-01,  -7.82432437e-01,  -5.59735298e-01,
                         -1.30123645e-01,  -2.39348024e-01,  -6.17167950e-01,
                         -6.35307789e-01,  -6.20581925e-01,  -7.35042155e-01,
                         -4.35019076e-01,  -1.89343303e-01,  -4.99848098e-01,
                         -4.13378358e-01,   1.43364724e-02,  -4.05038238e-01,
                         -8.93329382e-01,  -3.76356304e-01,  -7.40333349e-02,
                         -5.21674633e-01,  -4.06370193e-01,  -3.57419346e-03,
                         -5.21752000e-01,  -9.45533991e-01,  -3.07948321e-01,
                         -3.93490866e-03,  -5.52259922e-01,  -4.98485595e-01,
                          1.33656979e-01,  -2.84985118e-02,  -5.71636617e-01,
                         -3.49955142e-01,  -8.33347291e-02,  -5.96858323e-01,
                         -8.07961404e-01,  -2.03285098e-01,  -9.98366326e-02,
                         -5.72677612e-01,  -3.66455525e-01,  -4.07362357e-02,
                         -5.71131945e-01,  -8.46065283e-01,  -2.50017732e-01,
                         -6.63257092e-02,  -5.88411212e-01,  -7.67621994e-01,
                         -5.44198155e-01,  -5.61080575e-01,  -7.19634354e-01,
                         -6.63394153e-01,  -5.66101015e-01,  -6.89738274e-01,
                         -7.62884974e-01,  -3.68815690e-01,   1.28190175e-01,
                         -6.87237596e-03,  -4.77200747e-01,  -4.21316415e-01,
                         -1.69340353e-02,  -3.46876606e-02,  -4.60634172e-01,
                         -6.91648841e-01,  -5.87917626e-01,  -6.14290357e-01,
                         -7.26538897e-01,  -3.90374035e-01,  -1.20872885e-01,
                         -4.33558971e-01,  -3.84963423e-01,  -3.93837616e-02,
                         -5.16778708e-01,  -8.77263427e-01,  -2.81929791e-01,
                         -1.28730386e-01,  -5.24614811e-01,  -3.07776779e-01,
                         -1.00577034e-01,  -5.27200162e-01,  -7.73774683e-01,
                         -5.99793553e-01,  -5.64375639e-01,  -7.71669924e-01,
                         -7.27430463e-01,  -2.58249402e-01,  -8.53592083e-02,
                         -4.50949490e-01,  -6.72080934e-01,  -7.01442480e-01,
                         -6.46247268e-01,  -2.27782890e-01,  -1.17048427e-01,
                         -6.58734977e-01,  -6.82008088e-01,  -1.23825170e-01,
                         -1.76353768e-01,  -6.28436744e-01,  -7.16678619e-01,
                         -6.36828363e-01,  -4.23810363e-01,  -9.13376361e-03,
                          2.69362610e-02,  -3.81739646e-01,  -6.38277411e-01,
                         -7.02242494e-01,  -6.36807382e-01,  -3.00342798e-01,
                         -1.60367996e-01,  -4.70051050e-01,  -6.48637950e-01,
                         -5.98259151e-01,  -6.30223274e-01,  -6.01278603e-01,
                         -5.66908896e-01,  -7.02485621e-01,  -7.25817263e-01,
                         -6.03808701e-01,  -5.89611292e-01,  -6.30665541e-01,
                         -6.50629103e-01,  -6.29757047e-01,  -6.06004834e-01,
                         -7.26908445e-01,  -6.51899576e-01,  -1.59420505e-01,
                         -6.42464384e-02,  -5.99948227e-01,  -8.06789279e-01,
                         -5.90934515e-01,  -5.69351733e-01,  -6.28670633e-01,
                         -6.63950920e-01,  -7.24069536e-01,  -4.71428812e-01,
                         -1.36857718e-01,  -2.92099863e-01,  -6.52190149e-01,
                         -7.31414557e-01,  -5.79658628e-01,  -5.35515189e-01,
                         -7.16313243e-01,  -6.00356460e-01,  -1.76937878e-01,
                         -2.47868136e-01,  -4.59122986e-01,  -1.79105818e-01,
                         -2.06616312e-01,  -6.61891162e-01,  -7.22010016e-01,
                         -6.34334326e-01,  -6.75423324e-01,  -6.04023218e-01,
                         -6.36983693e-01,  -6.92598760e-01,  -5.94422519e-01,
                         -6.55694783e-01,  -5.98962545e-01,  -2.26994067e-01,
                         -2.10454062e-01,  -5.47691345e-01,  -6.58432603e-01,
                         -6.28103852e-01,  -6.55709922e-01,  -6.49426043e-01,
                         -6.27144039e-01,  -6.44373596e-01,  -6.23857677e-01,
                         -5.36648571e-01,  -5.78000963e-01,  -7.28360415e-01,
                         -5.66296995e-01,  -1.24755934e-01,   7.84465149e-02,
                          3.36311106e-03,   7.35553075e-03,   5.01459055e-02,
                         -3.06964338e-01,  -8.36298645e-01,  -6.46127403e-01,
                         -9.31755602e-02,  -2.45261729e-01,  -5.15706897e-01,
                         -2.25618035e-01,  -2.37508804e-01,  -6.76579595e-01,
                         -7.14690924e-01,  -5.52851081e-01,  -6.20223284e-01,
                         -5.14785409e-01,  -7.06599355e-02,   9.79120284e-02,
                         -3.03737074e-01,  -5.37928402e-01,  -1.71661258e-01,
                          9.98109654e-02,  -1.06829759e-02,  -2.39852127e-02,
                          7.11337179e-02,   3.62639539e-02,  -4.86559272e-02,
                         -3.41604091e-02,   7.25034773e-02,   3.54302377e-02,
                         -9.23865438e-02,   7.69932196e-03,   6.82454407e-02,
                         -5.45928553e-02,   2.66167279e-02,  -2.36726683e-02,
                         -4.63078648e-01,  -4.83349353e-01,  -2.94803549e-02,
                          7.29241818e-02,  -7.62725696e-02,  -3.07001825e-02,
                          3.21181267e-02,   7.86832348e-03,   3.07292044e-02,
                          4.16407213e-02,  -4.23164442e-02,  -8.49428251e-02,
                          1.95140038e-02,   7.78767169e-02,  -2.61790175e-02,
                         -5.39476462e-02,   5.81706092e-02,   6.57814592e-02,
                         -4.77106161e-02,  -7.44606256e-02,   3.03608216e-02,
                          9.84269604e-02,   1.84720270e-02,  -5.84464334e-02,
                         -1.26302512e-02,   1.52716814e-02,  -1.98778752e-02,
                         -1.77353434e-02,  -2.42606997e-02,  -5.19390665e-02,
                          1.15925574e-03,   6.41805977e-02,   3.11739873e-02,
                         -7.87171908e-03,  -2.34321877e-03,  -1.44176250e-02,
                         -1.71581451e-02,   2.52800491e-02,   4.78388034e-02,
                          4.91446489e-03,  -6.06696904e-02,  -1.47658773e-02,
                          1.16458163e-01,  -7.02080950e-02,  -5.38501143e-01,
                         -4.57148492e-01,   1.39925927e-01,   9.99637842e-02,
                         -4.90938574e-01,  -4.45093691e-01,   3.51716094e-02,
                          2.96972040e-02,  -1.01867534e-01,   1.07363410e-01,
                          1.32233715e-02,  -5.17105579e-01,  -4.92996544e-01,
                          1.08728863e-01,   5.40143102e-02,  -5.72105110e-01,
                         -4.49249774e-01,   1.99301839e-02,  -4.24529791e-01,
                         -8.93912911e-01,  -3.42853159e-01,  -9.92045645e-03,
                         -4.41681415e-01,  -3.72079223e-01,  -5.17790169e-02,
                         -5.50837159e-01,  -8.64582241e-01,  -2.54159957e-01,
                         -5.45523502e-02,  -4.96858001e-01,  -3.63436878e-01,
                         -8.53664801e-02,  -5.78400254e-01,  -8.00178111e-01,
                         -1.64614335e-01,  -6.63204268e-02,  -6.36489093e-01,
                         -3.62478644e-01,   2.98917145e-01,  -1.16416231e-01,
                         -6.74635530e-01,  -2.77943999e-01,  -9.30453464e-02,
                         -4.81073320e-01,  -2.24379465e-01,   2.23625168e-01,
                         -2.43424013e-01,  -6.24905646e-01,  -1.52836889e-01,
                         -8.44714195e-02,  -7.30815470e-01,  -7.46744275e-01,
                         -1.51166797e-01,  -1.60334215e-01,  -6.13171577e-01,
                         -7.22634792e-01,  -6.72360539e-01,  -4.99659926e-01,
                          2.53799334e-02,   1.36207327e-01,  -4.45024073e-01,
                         -5.11064947e-01,  -2.16790810e-02,  -2.77378380e-01,
                         -8.66845310e-01,  -5.54065883e-01,  -2.00442858e-02,
                         -2.75799453e-01,  -6.86926186e-01,  -6.35212839e-01,
                         -5.57734668e-01,  -6.37425900e-01,  -6.61922872e-01,
                         -7.47212291e-01,  -7.23448992e-01,  -2.76467621e-01,
                         -5.61427660e-02,  -5.02332926e-01,  -7.66645372e-01,
                         -5.82380533e-01,  -6.40172958e-01,  -7.43955612e-01,
                         -3.44237357e-01,   1.36346906e-01,   8.37982371e-02,
                         -4.22428340e-01,  -7.42342889e-01,  -4.94276017e-01,
                         -1.40449777e-01,  -3.40521038e-02,   2.12124530e-02,
                         -1.39275685e-01,  -4.77241248e-01,  -2.81120121e-01,
                          1.54532358e-01,  -1.66726485e-01,  -6.33447409e-01,
                         -2.57398188e-01,   2.50627613e-03,  -6.04563475e-01,
                         -8.55875969e-01,  -3.04562956e-01,   2.24953704e-02,
                          6.20946847e-02,   1.05462931e-01,  -2.45247617e-01,
                         -5.60070038e-01,  -2.88625866e-01,  -2.22391769e-01,
                         -6.71815932e-01,  -7.11076677e-01,  -1.43965259e-01,
                          1.50454536e-01,  -2.20311850e-01,  -5.59728682e-01,
                         -2.87923753e-01,   1.03685647e-01,   8.71249586e-02,
                         -6.89230040e-02,  -5.28200977e-02,   4.34339121e-02,
                         -4.92069982e-02,  -4.12761480e-01,  -6.94758296e-01,
                         -7.03866363e-01,  -5.94346046e-01,  -2.39556089e-01,
                          1.74992919e-01,  -6.95997700e-02,  -5.93929827e-01,
                         -3.73527139e-01,   8.52552205e-02,  -1.76779684e-02,
                         -3.68159860e-02,   1.58593759e-01,  -1.85105503e-01,
                         -5.08626401e-01,  -2.34182894e-01,  -2.40156159e-01,
                         -5.18454790e-01,  -1.89798847e-01,   1.80937290e-01,
                         -1.89241245e-01,  -7.05908716e-01,  -6.87436461e-01,
                         -3.04707676e-01,  -8.59696325e-03,   8.69119540e-02,
                          1.06853684e-02,  -3.05997282e-01,  -4.81710047e-01,
                         -1.75810248e-01,   5.87711595e-02,  -2.07891911e-02,
                          3.53565551e-02,   1.16393082e-01,   5.93837956e-03,
                         -3.58685218e-02,  -7.00712204e-03,  -2.35702340e-02,
                         -4.18853154e-03,   2.28872281e-02,   2.05743369e-02,
                          3.88540025e-03,  -1.28771886e-02,   1.05035687e-02,
                         -1.02375979e-02,  -6.64602220e-02,  -4.44843294e-03,
                          5.76003268e-02,   5.95403975e-03,   3.37486388e-03,
                          5.54949865e-02,   3.93613838e-02,  -1.77496150e-02,
                         -5.85695095e-02,  -1.79127548e-02,   8.78543407e-02,
                          7.26866871e-02,   5.41440817e-03,   1.02353662e-01,
                          2.80567687e-02,  -4.20751274e-01,  -5.37127137e-01,
                         -1.09043472e-01,   8.64919275e-02,  -3.66608985e-02,
                         -1.32570323e-02,   1.88851245e-02,  -3.89835052e-02,
                         -2.14638915e-02,   2.67825532e-03,   3.77600193e-02,
                          7.86533356e-02,   8.66221543e-03,  -3.49767841e-02,
                         -2.23396369e-03,  -2.93419743e-03,   3.45634893e-02,
                          6.29200935e-02,  -1.54358149e-03,  -3.03331371e-02,
                         -1.69879217e-02,  -2.08719950e-02,  -1.22207170e-02,
                          1.26680810e-04,   2.84233540e-02,   3.32518294e-02,
                         -3.11210100e-02,  -5.48433438e-02,  -3.97850433e-03,
                          4.90903892e-02,   4.12726924e-02,  -3.94088775e-02,
                          1.84916786e-03,   1.13697350e-01,  -1.47246540e-01,
                         -6.25745833e-01,  -7.17027247e-01,  -5.66764951e-01,
                         -6.52749777e-01,  -6.77742839e-01,  -2.26404443e-01,
                          1.47992373e-01,   3.93268361e-04,  -3.36459465e-02,
                          1.08598076e-01,  -2.63554305e-01,  -5.87271571e-01,
                         -1.63526654e-01,   1.63713455e-01,  -4.45307456e-02,
                         -9.90000889e-02,   5.84977381e-02,   3.03741097e-02,
                         -5.45141250e-02,  -1.99395325e-02,   1.23459352e-02,
                         -3.32240947e-03,   3.76775302e-02,   8.74541551e-02,
                          7.01519754e-03,  -8.15520287e-02,   2.39487941e-04,
                          1.06225148e-01,   2.83984803e-02,  -9.94835868e-02,
                         -4.20818478e-02,   5.38640469e-02,  -8.59089289e-03,
                         -2.01493092e-02,   8.34885016e-02,   5.67016937e-02,
                         -5.83568625e-02,  -5.35950251e-02,   8.99183378e-02,
                          1.19909123e-01,  -2.47778475e-01,  -5.58868885e-01,
                         -2.60714054e-01,   7.39203617e-02,  -1.66368484e-02,
                         -7.02699572e-02,  -4.43800678e-03,  -1.30823990e-02,
                          3.45347486e-02,   4.66240831e-02,  -2.17970796e-02,
                         -1.24216452e-02,  -2.33892091e-02,   2.26413365e-02,
                          1.30347505e-01,  -1.68697193e-01,  -5.52957892e-01,
                         -2.70612806e-01,   9.94319767e-02,  -5.29794246e-02,
                         -5.26484735e-02,   1.47911280e-01,  -2.01967180e-01,
                         -5.86675227e-01,  -2.13139206e-01,   1.73730269e-01,
                         -1.46010026e-01,  -5.72177887e-01,  -6.24207556e-01,
                         -6.17580771e-01,  -6.81160867e-01,  -6.27447844e-01,
                         -5.54916620e-01,  -6.06916428e-01,  -6.35007739e-01,
                         -6.13908231e-01,  -6.59353793e-01,  -6.51427746e-01,
                         -5.57668805e-01,  -5.83562195e-01,  -6.98672593e-01,
                         -7.03819394e-01,  -6.17371976e-01,  -5.97185731e-01,
                         -6.55676126e-01,  -6.42213821e-01,  -5.88690758e-01,
                         -6.44341469e-01,  -6.75133228e-01,  -6.09842241e-01,
                         -6.18618727e-01,  -6.20738089e-01,  -5.36965370e-01,
                         -5.67279518e-01,  -6.57522976e-01,  -6.13555074e-01,
                         -5.88245213e-01,  -6.89147890e-01,  -6.89617097e-01,
                         -5.57534039e-01,  -5.54848731e-01,  -6.49362326e-01,
                         -6.71489716e-01,  -6.92233384e-01,  -5.52988589e-01,
                         -1.97391450e-01,  -2.04014972e-01,  -5.84719121e-01,
                         -6.64938331e-01,  -5.31046033e-01,  -5.73929548e-01,
                         -6.46343112e-01,  -6.41505897e-01,  -5.97900033e-01,
                         -5.74349701e-01,  -6.62456274e-01,  -6.94445133e-01,
                         -6.02641881e-01,  -5.92860818e-01,  -6.28561258e-01,
                         -6.12727880e-01,  -6.01534307e-01,  -6.05748057e-01,
                         -6.44756377e-01,  -6.56117201e-01,  -6.06468260e-01,
                         -6.34794414e-01,  -6.47126138e-01,  -5.33753395e-01,
                         -5.20024002e-01,  -6.30660772e-01,  -6.59851313e-01,
                         -6.14794016e-01,  -5.98612845e-01,  -6.32470965e-01,
                         -6.62789226e-01,  -6.62632883e-01,  -6.57974482e-01,
                         -6.16057694e-01,  -5.77602267e-01,  -6.00613534e-01,
                         -5.97283185e-01,  -5.92749894e-01,  -6.34542882e-01,
                         -6.32084608e-01,  -6.12148583e-01,  -6.06450975e-01,
                         -6.02481961e-01,  -6.27470851e-01,  -6.16075039e-01,
                         -6.34260833e-01,  -6.73243999e-01,  -5.56708992e-01,
                         -6.07373536e-01,  -7.76940644e-01,  -3.95810038e-01,
                         -5.56982979e-02,  -4.04168546e-01,  -4.45850492e-01,
                         -9.68132839e-02,  -3.76164675e-01,  -7.90906072e-01,
                         -6.47225082e-01,  -5.19440711e-01,  -6.40367508e-01,
                         -6.61450744e-01,  -5.98725438e-01,  -6.10896349e-01,
                         -6.58491969e-01,  -6.28389359e-01,  -5.75571716e-01,
                         -6.18693888e-01,  -6.43612981e-01,  -5.92861474e-01,
                         -6.12426043e-01,  -6.73548758e-01,  -6.57474875e-01,
                         -6.18460000e-01,  -6.26446426e-01,  -6.29575968e-01,
                         -5.78100741e-01,  -5.43176711e-01,  -5.93929827e-01,
                         -6.71121657e-01,  -6.85898483e-01,  -6.34618282e-01,
                         -5.94052851e-01,  -5.91553152e-01,  -6.10687912e-01,
                         -6.60972595e-01,  -6.39858007e-01,  -6.05685353e-01,
                         -7.48277605e-01,  -6.48256600e-01,  -1.79865226e-01,
                         -1.80161923e-01,  -4.31752115e-01,  -1.34209424e-01,
                         -1.59373611e-01,  -8.03314269e-01,  -6.79677904e-01,
                         -8.22602287e-02,  -2.46435553e-01,  -4.44433212e-01,
                         -1.40393019e-01,  -3.00551385e-01,  -7.80021966e-01,
                         -5.50232291e-01,  -7.36038163e-02,  -2.85766393e-01,
                         -6.95479035e-01,  -6.32938564e-01,  -5.77071667e-01,
                         -7.41388798e-01,  -4.89442587e-01,  -6.58884421e-02,
                         -3.54351640e-01,  -8.30713749e-01,  -5.01991689e-01,
                         -7.04123173e-03,  -2.54050046e-01,  -6.80959344e-01,
                         -6.83143198e-01,  -6.08841836e-01,  -6.36902213e-01,
                         -5.91620505e-01,  -5.52185535e-01,  -6.11550868e-01,
                         -6.72931671e-01,  -6.55758500e-01,  -6.34240329e-01,
                         -6.63150132e-01,  -4.56038058e-01,   2.59792488e-02,
                          1.15062773e-01,  -3.80234927e-01,  -7.62433171e-01,
                         -6.33683562e-01,  -1.92003176e-01,   1.23461425e-01,
                         -8.86372104e-02,  -5.57512641e-01,  -7.03619599e-01,
                         -6.03115439e-01,  -5.94251692e-01,  -6.54727340e-01,
                         -6.64234638e-01,  -6.22824371e-01,  -5.98087668e-01,
                         -6.18679941e-01,  -6.34112716e-01,  -6.31564856e-01,
                         -6.30273819e-01,  -6.55466139e-01,  -6.87964678e-01,
                         -5.22529304e-01,  -1.13959305e-01,   1.08009592e-01,
                         -1.75953090e-01,  -6.43977940e-01,  -7.06350088e-01,
                         -3.04580033e-01,  -2.08414160e-02,  -3.58816758e-02,
                          1.35481283e-02,  -1.30649850e-01,  -6.72377646e-01,
                         -7.29123950e-01,  -1.88596904e-01,  -1.66609928e-01,
                         -4.99013931e-01,  -2.44991183e-01,   1.13981098e-01,
                          8.71269498e-03,  -3.88373919e-02,   4.55062911e-02,
                         -2.26925120e-01,  -6.81600213e-01,  -7.40715742e-01,
                         -2.67172247e-01,   1.69197813e-01,  -4.64353375e-02,
                         -5.34724295e-01,  -6.69131994e-01,  -6.78466260e-01,
                         -6.09420776e-01,  -2.17484534e-01,  -1.87929705e-01,
                         -7.18548059e-01,  -6.53731346e-01,  -4.35667261e-02,
                         -1.23813719e-01,  -6.71170175e-01,  -7.89327860e-01,
                         -6.20337605e-01,  -5.65816760e-01,  -6.64707839e-01,
                         -6.30098343e-01,  -2.39844218e-01,  -9.69528109e-02,
                         -5.51080942e-01,  -8.06014657e-01,  -6.21630371e-01,
                         -5.80444276e-01,  -6.58728719e-01,  -6.30725086e-01,
                         -5.86815059e-01,  -5.69352567e-01,  -6.48597538e-01,
                         -7.03430414e-01,  -6.15585268e-01,  -6.75457120e-01,
                         -6.73929155e-01,  -2.34839961e-01,  -4.57633734e-02,
                         -4.80989307e-01,  -7.58773327e-01,  -6.36400521e-01,
                         -5.81551313e-01,  -6.44719899e-01,  -6.37769520e-01,
                         -6.18437588e-01,  -7.26913571e-01,  -7.16334641e-01,
                         -2.80051291e-01,  -3.26207057e-02,  -5.13324857e-01,
                         -7.96795368e-01,  -3.00310314e-01,  -3.20951045e-02,
                         -4.31951463e-01,  -7.00601339e-01,  -6.21007800e-01,
                         -6.11796498e-01,  -6.70070827e-01,  -6.64281726e-01,
                         -6.51543140e-01,  -6.14817142e-01,  -5.82071006e-01,
                         -6.23890877e-01,  -6.50021136e-01,  -6.27358615e-01,
                         -6.38926923e-01,  -6.56778991e-01,  -6.40072465e-01,
                         -6.44973218e-01,  -6.66106284e-01,  -6.22364104e-01,
                         -5.55479646e-01,  -5.88175654e-01,  -6.51283145e-01,
                         -6.22810662e-01,  -5.90808272e-01,  -6.09570682e-01,
                         -6.18525147e-01,  -6.38367712e-01,  -6.38399363e-01,
                         -5.64787209e-01,  -5.40235341e-01,  -6.39958203e-01,
                         -7.22841799e-01,  -6.73849523e-01,  -5.91605604e-01,
                         -5.92785716e-01,  -6.15817487e-01,  -6.28381729e-01,
                         -6.59851134e-01,  -6.35991096e-01,  -5.86383045e-01,
                         -6.07909441e-01,  -6.35381401e-01,  -6.25124216e-01,
                         -5.87138891e-01,  -5.56614041e-01,  -6.18922889e-01,
                         -6.74390674e-01,  -6.36322200e-01,  -6.24902666e-01,
                         -6.30938828e-01,  -6.23990417e-01,  -6.42820835e-01,
                         -6.21600688e-01,  -6.18710160e-01,  -6.63537621e-01,
                         -6.17972791e-01,  -5.81548691e-01,  -6.30047262e-01,
                         -6.05069399e-01,  -5.65438509e-01,  -6.33967757e-01,
                         -6.92836881e-01,  -6.38908625e-01,  -5.71647644e-01,
                         -6.14897907e-01,  -6.55678153e-01,  -5.88214934e-01,
                         -5.62150776e-01,  -6.10499442e-01,  -6.36705220e-01,
                         -6.58756673e-01,  -6.51828110e-01,  -6.11618817e-01,
                         -6.21271729e-01,  -6.62569702e-01,  -6.59108281e-01,
                         -6.02719069e-01,  -5.97462952e-01,  -6.69271111e-01,
                         -6.60628974e-01,  -6.04571581e-01,  -6.19682729e-01,
                         -6.03767753e-01,  -5.85249782e-01,  -6.51615381e-01,
                         -6.65776074e-01,  -6.08918846e-01,  -6.03406608e-01,
                         -6.39156818e-01,  -6.37505233e-01,  -6.00876927e-01,
                         -6.19358301e-01,  -6.51019752e-01,  -6.00248456e-01,
                         -5.92019975e-01,  -6.52306736e-01,  -6.39187038e-01,
                         -6.28328919e-01,  -6.84071422e-01,  -6.72607839e-01,
                         -5.95278502e-01,  -5.85611761e-01,  -6.41562223e-01,
                         -6.56882703e-01,  -6.25569820e-01,  -6.17421031e-01,
                         -6.31346643e-01,  -6.28898561e-01,  -6.03498161e-01,
                         -5.95162570e-01,  -6.12599134e-01,  -6.23531878e-01,
                         -6.61567926e-01,  -6.39759183e-01,  -5.53436756e-01,
                         -6.92709446e-01,  -7.40197659e-01,  -2.59609759e-01,
                         -4.92032915e-02,  -5.20374835e-01,  -7.63470650e-01,
                         -6.14048004e-01,  -6.17194235e-01,  -6.68862879e-01,
                         -6.21589363e-01,  -6.27575696e-01,  -6.58431411e-01,
                         -6.04517519e-01,  -5.87874174e-01,  -7.30401337e-01,
                         -6.23872221e-01,  -1.40457109e-01,  -1.37749344e-01,
                         -6.95708513e-01,  -6.97608471e-01,  -1.58451423e-01,
                         -1.66103110e-01,  -6.31561279e-01,  -6.85206532e-01,
                         -5.62433779e-01,  -7.39585876e-01,  -6.02418303e-01,
                         -1.12341382e-01,  -2.05338940e-01,  -6.61718190e-01,
                         -7.05170512e-01,  -5.77936053e-01,  -6.05576515e-01,
                         -6.39995456e-01,  -6.04337871e-01,  -6.21645331e-01,
                         -7.16200888e-01,  -5.60289919e-01,  -1.66383922e-01,
                          1.84518956e-02,   4.16724384e-02,  -3.80050577e-02,
                         -4.00070101e-01,  -7.06961215e-01,  -6.86123610e-01,
                         -5.73018134e-01,  -6.26540482e-01,  -7.62624979e-01,
                         -5.02459943e-01,  -1.18183099e-01,  -3.25115055e-01,
                         -4.49244857e-01,  -1.15107648e-01,  -3.23556721e-01,
                         -7.66679585e-01,  -6.21174634e-01,  -5.96158624e-01,
                         -7.43101299e-01,  -3.30563933e-01,  -9.55527723e-02,
                         -5.18712938e-01,  -4.41891551e-01,   1.80573255e-01,
                          1.09566152e-02,  -5.88643551e-01,  -3.58986199e-01,
                         -2.23651901e-02,  -5.20950735e-01,  -8.26325238e-01,
                         -3.12907398e-01,  -6.65267929e-02,  -4.67784166e-01,
                         -6.97625875e-01,  -6.60698056e-01,  -6.10249341e-01,
                         -1.88110068e-01,   1.96070924e-01,  -2.17868879e-01,
                         -5.71675479e-01,  -1.91955954e-01,  -1.24966308e-01,
                         -6.55807912e-01,  -7.63291419e-01,  -2.31015220e-01,
                          1.65611044e-01,  -1.05462708e-01,  -5.45731723e-01,
                         -3.70204091e-01,   5.44860326e-02,   5.53877503e-02,
                         -6.15713224e-02,   5.47069684e-03,   3.20909657e-02,
                         -5.10431884e-04,   4.15516365e-03,  -2.25380249e-03,
                         -6.21886132e-03,   2.82518240e-03,  -5.96169708e-03,
                          8.40976252e-04,   1.18289739e-02,  -2.81827711e-03,
                          4.20462020e-04,   6.17126469e-03,  -3.92108737e-03,
                          1.11042215e-02,   9.70019121e-03,  -1.24655962e-02,
                          2.16223416e-03,   4.31029173e-03,  -1.07141603e-02,
                          6.41531835e-04,  -8.14346771e-04,  -2.26681959e-03,
                          1.20771853e-02,   2.11935956e-03,  -7.94352125e-03,
                          1.40111521e-03,   1.08646918e-02,   5.79063734e-03,
                         -1.16810966e-02,   1.36774732e-03,   1.31571582e-02,
                         -1.90900322e-02,  -1.46723036e-02,   2.01980658e-02,
                          7.70588266e-03,  -1.08401095e-02,  -4.13163705e-03,
                          7.16361869e-03,   1.26518458e-02,  -6.06908230e-03,
                         -2.14263778e-02,  -3.07415635e-03,   1.77454557e-02,
                          1.44616803e-02,  -7.68638868e-03,  -1.17955543e-02,
                          7.21024396e-03,  -1.73007161e-03,  -1.03691258e-02,
                          1.43831288e-02,   3.06328107e-03,  -2.46160571e-02,
                          1.21190888e-03,   2.49338243e-02,   1.47883175e-02,
                         -4.27179446e-04,  -1.18493773e-02,   1.75686821e-03,
                         -1.34265356e-04,  -1.64980274e-02,   2.03377753e-02,
                         -6.06193673e-03,  -4.95157726e-02,   9.03642401e-02,
                          1.98776666e-02,  -4.44825590e-01,  -5.14027297e-01,
                         -4.96137962e-02,   1.22007355e-01,  -3.19520608e-02,
                         -2.82187499e-02,   2.52650678e-02,  -3.63640557e-03,
                         -4.32552351e-03,  -1.03613632e-02,  -1.97038800e-02,
                          1.27271684e-02,   1.61399338e-02,  -1.47896968e-02,
                         -2.40451042e-02,  -5.27731143e-03,   1.65099576e-02,
                          1.08238850e-02,   2.34671845e-03,  -4.57738107e-03,
                         -3.04500498e-02,  -1.71570275e-02,   1.77714694e-02,
                          1.16563477e-02,  -5.33498963e-03,  -3.10646910e-02,
                         -2.08891276e-02,   3.92373167e-02,   1.77664142e-02,
                         -2.76980996e-02,   9.67256911e-03,   2.19395347e-02,
                         -2.80773593e-03,  -1.28684128e-02,  -1.48567669e-02,
                          1.28068170e-02,   1.78386550e-02,  -2.85679521e-03,
                         -7.45803700e-04,  -1.70283820e-02,  -1.07226428e-02,
                          2.46845689e-02,   9.87672526e-03,  -1.17900800e-02,
                         -1.87256504e-02,  -7.37682171e-03,   3.43699344e-02,
                          2.07774695e-02,  -2.16891412e-02,  -1.65437236e-02,
                          4.54424275e-03,   1.97019465e-02,  -4.43344144e-03,
                         -2.68059541e-02,   8.92062299e-03,   1.61956698e-02,
                         -1.83813577e-03,   4.25612379e-05,  -4.56761289e-03,
                          1.18407477e-02,   1.69181973e-02,  -6.42183702e-03,
                         -2.19159038e-03,   2.41645263e-03,  -1.05959096e-03,
                          3.58542404e-03,   1.97385009e-02,   5.62783051e-03,
                         -5.48777990e-02,   3.68303806e-02,   8.03060159e-02,
                         -3.06520194e-01,  -5.22367835e-01,  -1.65447548e-01,
                          6.83219284e-02,  -1.49374912e-02,  -3.41427214e-02,
                          4.26009372e-02,   6.64633587e-02,  -1.79217875e-01,
                         -5.47040462e-01,  -6.73665822e-01,  -6.76583946e-01,
                         -4.86256957e-01,  -1.00476392e-01,  -2.76512533e-01,
                         -8.03605199e-01,  -5.60138047e-01,  -2.48999856e-02,
                         -2.70730466e-01,  -7.18561113e-01,  -6.65274620e-01,
                         -5.80829680e-01,  -6.42337382e-01,  -5.91381073e-01,
                         -6.63676858e-01,  -7.48812795e-01,  -3.53312641e-01,
                         -4.14401256e-02,  -4.41804647e-01,  -7.57828653e-01,
                         -5.80681622e-01,  -6.39212728e-01,  -7.09080875e-01,
                         -2.53646225e-01,  -8.39046761e-02,  -5.69144428e-01,
                         -7.98821747e-01,  -3.81253928e-01,   1.02903590e-01,
                          2.50017606e-02,  -4.32524532e-01,  -6.36714876e-01,
                         -6.76699400e-01,  -6.48537695e-01,  -2.67560214e-01,
                         -1.16678432e-01,  -5.55581987e-01,  -7.38990724e-01,
                         -5.74619055e-01,  -6.83296382e-01,  -6.60496950e-01,
                         -1.81782126e-01,  -1.12400934e-01,  -6.77214324e-01,
                         -7.70636141e-01,  -1.92979977e-01,  -8.39160755e-02,
                         -5.85599303e-01,  -7.26848543e-01,  -5.50885260e-01,
                         -7.00552464e-01,  -6.88458800e-01,  -1.53731227e-01,
                         -8.55047852e-02,  -6.94678903e-01,  -7.79933512e-01,
                         -1.86248198e-01,  -6.25889152e-02,  -6.29459023e-01,
                         -7.94202328e-01,  -2.45220795e-01,  -7.63590708e-02,
                         -5.66105783e-01,  -7.66994596e-01,  -4.03683394e-01,
                          3.00963223e-02,   7.49945417e-02,  -3.47767293e-01,
                         -7.37307847e-01,  -6.41864300e-01,  -1.20880291e-01,
                          1.64133817e-01,  -2.72582412e-01,  -5.21052122e-01,
                         -1.85570389e-01,  -2.92164713e-01,  -4.92343396e-01,
                         -1.49680719e-01,  -2.45505899e-01,  -7.27120876e-01,
                         -6.96099639e-01,  -5.63892603e-01,  -6.53646111e-01,
                         -6.63358212e-01,  -6.32136941e-01,  -6.06407285e-01,
                         -5.94806910e-01,  -6.84163451e-01,  -6.51572526e-01,
                         -2.55560279e-01,   1.41996652e-01,  -3.16425264e-02,
                         -5.40647149e-01,  -7.12022841e-01,  -6.10004425e-01,
                         -6.18749261e-01,  -6.50482059e-01,  -6.24024928e-01,
                         -6.68347836e-01,  -6.07938230e-01,  -2.31800407e-01,
                          1.12609297e-01,  -4.02000211e-02,  -5.69252729e-01,
                         -8.07341218e-01,  -3.70578200e-01,  -6.16793259e-05,
                         -4.36409712e-01,  -8.52624953e-01,  -4.26304966e-01,
                         -2.53881346e-02,  -3.86625469e-01,  -7.45027483e-01,
                         -6.05917931e-01,  -5.99301636e-01,  -7.36839294e-01,
                         -3.69546771e-01,  -2.72366647e-02,  -4.59719181e-01,
                         -8.53492200e-01,  -4.24230546e-01,   4.95206378e-03,
                         -3.90229732e-01,  -8.44851434e-01,  -4.76353973e-01,
                         -4.49418277e-02,  -3.51964265e-01,  -7.15403438e-01,
                         -6.43984497e-01,  -5.75699866e-01,  -6.39806926e-01,
                         -6.56419277e-01,  -6.37729347e-01,  -6.17307663e-01,
                         -6.26644194e-01,  -6.43642068e-01,  -6.19150341e-01,
                         -6.43789709e-01,  -6.57217264e-01,  -5.81322730e-01,
                         -6.75353885e-01,  -7.22387075e-01,  -3.00035775e-01,
                         -1.32238865e-01,  -5.03729284e-01,  -3.58886540e-01,
                         -4.86872271e-02,  -5.71941555e-01,  -8.23350906e-01,
                         -2.07063258e-01,  -1.24296531e-01,  -5.48124552e-01,
                         -2.94356793e-01,  -6.43560812e-02,  -6.38140559e-01,
                         -7.85897195e-01,  -1.50707558e-01,  -1.45970732e-01,
                         -6.10493004e-01,  -2.65283465e-01,   2.14338377e-01,
                         -2.01031491e-01,  -5.71281016e-01,  -2.30785310e-01,
                         -2.17965066e-01,  -5.85569620e-01,  -1.91734627e-01,
                          2.45388925e-01,  -2.85148591e-01,  -5.23535728e-01,
                         -1.18901402e-01,  -2.96902537e-01,  -5.18203259e-01,
                         -1.44625425e-01,  -2.66897798e-01,  -7.97375143e-01,
                         -5.51799297e-01,  -3.92826237e-02,  -2.96063453e-01,
                         -7.19990253e-01,  -6.01624668e-01,  -5.80405176e-01,
                         -7.79372573e-01,  -4.36502129e-01,  -6.23665191e-02,
                         -3.90816152e-01,  -5.05847394e-01,   2.83971634e-02,
                          1.35496959e-01,  -4.03319657e-01,  -6.91466630e-01,
                         -6.08292520e-01,  -6.33625627e-01,  -6.72393560e-01,
                         -5.72567403e-01,  -6.35834813e-01,  -6.89136624e-01,
                         -3.10731560e-01,  -8.43142942e-02,  -4.88648236e-01,
                         -7.27594674e-01,  -5.45841217e-01,  -6.45671189e-01,
                         -7.13034689e-01,  -2.18503430e-01,  -3.86331305e-02,
                         -6.07957184e-01,  -7.98432291e-01,  -2.41164893e-01,
                         -5.92152104e-02,  -5.38261175e-01,  -7.52094030e-01,
                         -5.75955808e-01,  -5.73158503e-01,  -6.59605205e-01,
                         -6.27530992e-01,  -6.13914430e-01,  -6.23547137e-01,
                         -6.31194770e-01,  -6.51606381e-01,  -6.24281287e-01,
                         -5.96030295e-01,  -6.13282323e-01,  -6.30475342e-01,
                         -6.38219237e-01,  -6.27815366e-01,  -6.03684723e-01,
                         -6.04924262e-01,  -6.63713217e-01,  -6.55878663e-01,
                         -3.18899721e-01,   1.03844836e-01,   7.01593934e-03,
                         -4.58071262e-01,  -6.90994859e-01,  -6.47807002e-01,
                         -5.87985277e-01,  -6.20524943e-01,  -6.62411511e-01,
                         -5.99399805e-01,  -6.03853881e-01,  -7.01754570e-01,
                         -4.79728490e-01,  -2.09843311e-02,   1.08677454e-01,
                         -1.46619081e-02,  -2.33593397e-02,  -2.52713886e-04,
                          3.75524070e-03,   2.53114738e-02,  -2.54015271e-02,
                          1.28292786e-02,   8.77068788e-02,  -2.20845073e-01,
                         -5.34911931e-01,  -2.52383441e-01,   1.09825902e-01,
                          4.10902016e-02,  -7.25271702e-02,   3.98051627e-02,
                          1.08853169e-01,  -1.66726694e-01,  -5.07116199e-01,
                         -3.26801747e-01,   6.64413199e-02,   4.57573757e-02,
                         -6.07900284e-02,   4.06198353e-02,   4.37930301e-02,
                         -2.74392441e-02,  -1.31229553e-02,   8.54655635e-03,
                          2.60311402e-02,   1.48679139e-02,  -1.16682984e-02,
                          1.80903245e-02,   2.00365651e-02,  -5.94519079e-03,
                          8.48859549e-03,   1.56898866e-03,   3.82028404e-03,
                          3.26622725e-02,   7.85565190e-03,  -1.21226609e-02,
                          8.94602947e-03,   1.48988683e-02,   1.16015738e-02,
                          4.30886075e-03,   2.57116277e-03,   1.85900892e-03,
                          6.65291538e-03,   4.12416756e-02,  -4.61221114e-03,
                         -3.62568498e-02,   1.10338017e-01,  -1.94408651e-02,
                         -4.83881384e-01,  -4.47070777e-01,   1.78603213e-02,
                          1.05610378e-01,  -3.54131758e-02,  -9.85863153e-03,
                          1.98128838e-02,  -7.62558682e-03,   1.06674824e-02,
                          2.88915187e-02,  -1.61855668e-02,   2.93441676e-03,
                          9.33723599e-02,  -1.54169306e-01,  -5.46780050e-01,
                         -3.07334661e-01,   1.17958046e-01,  -1.48434669e-03,
                         -3.77035961e-02,   1.26998484e-01,  -2.15377927e-01,
                         -5.52070320e-01,  -2.45245174e-01,   9.07922760e-02,
                          5.25826551e-02,  -4.20122258e-02,   4.02550539e-03,
                          9.13936272e-02,  -8.10954049e-02,  -5.20014107e-01,
                         -7.06282794e-01,  -5.85290968e-01,  -6.57741070e-01,
                         -7.06036747e-01,  -2.61521012e-01,  -3.01123075e-02,
                         -5.74372292e-01,  -8.19667101e-01,  -2.39006922e-01,
                         -6.90193474e-02,  -5.27813077e-01,  -3.76280129e-01,
                          1.64266646e-01,  -2.83632837e-02,  -5.26464939e-01,
                         -6.43862844e-01,  -7.14754224e-01,  -6.12290382e-01,
                         -1.25189036e-01,  -1.24671057e-01,  -7.16555119e-01,
                         -7.03582704e-01,  -1.27606273e-01,  -1.57254532e-01,
                         -6.43738925e-01,  -6.82855964e-01,  -5.42537212e-01,
                         -7.14745939e-01,  -6.14863634e-01,  -1.03927091e-01,
                         -1.57643765e-01,  -7.34260499e-01,  -6.78759277e-01,
                         -1.18610874e-01,  -1.64457902e-01,  -6.45570040e-01,
                         -6.71772182e-01,  -5.53142071e-01,  -7.36437976e-01,
                         -5.44286966e-01,  -1.00521110e-01,  -3.17543298e-01,
                         -5.02422273e-01,  -1.04502439e-01,  -2.81287283e-01,
                         -8.45719874e-01,  -5.22239804e-01,  -1.60888173e-02,
                         -3.25962067e-01,  -7.34982312e-01,  -6.56262875e-01,
                         -5.65843582e-01,  -7.01660872e-01,  -5.43804109e-01,
                          2.71417536e-02,   1.64408967e-01,  -3.64111751e-01,
                         -5.72987556e-01,  -1.16216287e-01,   1.62139118e-01,
                         -1.96052119e-01,  -6.76606953e-01,  -7.10544109e-01,
                         -2.87983388e-01,   1.21779084e-01,  -4.14386429e-02,
                         -5.45194328e-01,  -4.45741057e-01,   1.27374202e-01,
                          5.00073247e-02,  -5.23300231e-01,  -4.82536107e-01,
                          4.23111394e-02,   9.71219912e-02,  -3.75378072e-01,
                         -7.38713920e-01,  -6.31803453e-01,  -1.33065537e-01,
                          1.64695680e-01,  -2.12887436e-01,  -5.68668783e-01,
                         -2.63050169e-01,   6.28549904e-02,   5.21564484e-02,
                         -2.75691636e-02,  -3.36063296e-01,  -6.87779546e-01,
                         -6.70719028e-01,  -6.12861753e-01,  -6.47384107e-01,
                         -5.87121308e-01,  -6.55497730e-01,  -7.11545885e-01,
                         -3.51562113e-01,   4.20034528e-02,   2.07885746e-02,
                         -5.59454747e-02,   6.56641647e-02,  -6.00928776e-02,
                         -5.12182057e-01,  -7.16470242e-01,  -6.07463002e-01,
                         -5.92900157e-01,  -6.78286314e-01,  -6.47222340e-01,
                         -5.64601183e-01,  -6.74948037e-01,  -7.27008581e-01,
                         -3.06873560e-01,  -9.42710266e-02,  -5.05782664e-01,
                         -4.22757179e-01,   1.64642394e-01,  -4.39400300e-02,
                         -5.81618130e-01,  -3.74649286e-01,   1.41682122e-02,
                          5.52736036e-02,   3.03021185e-02,  -2.13377357e-01,
                         -7.13657677e-01,  -7.05177188e-01,  -1.49449095e-01,
                         -1.21278055e-01,  -6.36965156e-01,  -7.05589533e-01,
                         -5.55206418e-01,  -7.32948422e-01,  -6.05322480e-01,
                         -1.24439858e-01,  -2.07820579e-01,  -6.68278813e-01,
                         -7.00074375e-01,  -5.77120245e-01,  -7.09620774e-01,
                         -5.99498332e-01,  -1.02392271e-01,   8.59404728e-02,
                         -6.95251971e-02,   2.15684678e-02,   6.81791082e-02,
                         -3.57761592e-01,  -5.46830535e-01,  -1.33796632e-01,
                          9.65195820e-02,  -3.31042446e-02,  -2.19436511e-02,
                          2.77746562e-02,  -1.68209355e-02,  -4.15705470e-03,
                         -1.48646021e-02,  -8.63704830e-03,   4.98831505e-03,
                         -8.12127069e-02,   2.52822861e-02,   9.89812538e-02,
                         -3.28450978e-01,  -5.55857420e-01,  -1.68358728e-01,
                          9.50332433e-02,   8.74580164e-03,  -6.94266185e-02,
                          1.73748694e-02,   8.62844512e-02,  -2.40991473e-01,
                         -5.60443461e-01,  -2.62253702e-01,   8.36031139e-02,
                          7.01531256e-03,  -5.96042387e-02,   2.15591062e-02,
                          2.14186888e-02,  -5.69479950e-02,   2.23464263e-03,
                          9.08182710e-02,  -2.33458236e-01,  -5.68359435e-01,
                         -2.57584691e-01,   9.45310071e-02,   1.39165018e-03,
                         -5.09913862e-02,   1.62366107e-02,  -3.85869760e-03,
                         -1.21794408e-02,  -6.92063104e-03,  -1.39965052e-02,
                         -1.12605719e-02,  -1.86059382e-02,  -2.77358457e-04,
                          1.59060881e-02,  -6.46186993e-03,  -1.92571320e-02,
                         -9.99725331e-03,   5.79830538e-03,  -6.52354967e-04,
                         -7.71141984e-03,  -5.20538399e-03,  -3.65585275e-02,
                          1.67422071e-02,   4.37824167e-02,  -3.10840428e-01,
                         -7.06476986e-01,  -6.71878219e-01,  -5.92311203e-01,
                         -7.00690329e-01,  -5.54663777e-01,  -9.23041999e-02,
                          1.27596095e-01,  -2.04690188e-01,  -6.83073044e-01,
                         -7.14205503e-01,  -2.77775049e-01,   5.73295616e-02,
                         -1.78585779e-02,  -4.39272337e-02,   1.09217070e-01,
                         -1.72307834e-01,  -5.84882736e-01,  -3.01054925e-01,
                          1.02881938e-01,  -1.72530245e-02,  -4.29256111e-02,
                          1.06106937e-01,  -2.34510377e-01,  -6.24438941e-01,
                         -2.47465566e-01,   1.96067944e-01,  -1.96003184e-01,
                         -6.09959126e-01,  -2.59391755e-01,   1.01142816e-01,
                          1.20883742e-02,  -5.42977154e-02,  -1.27254345e-03,
                          8.97975289e-04,  -8.23543314e-03,  -1.21986950e-02,
                         -1.24514084e-02,  -6.17246609e-03,  -1.11666424e-02,
                         -2.55032498e-02,  -1.77867860e-02,   1.20295472e-02,
                         -3.28027122e-02,  -2.58670487e-02,   1.03048295e-01,
                         -1.18218847e-01,  -5.42976677e-01,  -3.75387639e-01,
                          4.96089682e-02,   4.50266562e-02,  -5.88737167e-02,
                          1.73068792e-03,   1.46401050e-02,  -4.48154509e-02,
                         -1.76569596e-02,   8.89740139e-02,  -1.25243604e-01,
                         -5.45469761e-01,  -3.65624994e-01,   7.86075816e-02,
                         -1.45219807e-02,  -5.94083443e-02,   1.33095145e-01,
                         -2.21560359e-01,  -5.86638391e-01,  -2.22386256e-01,
                         -1.17637448e-01,  -6.92981660e-01,  -7.38977015e-01,
                         -1.55737266e-01,  -1.37334481e-01,  -6.20475411e-01,
                         -7.26781726e-01,  -5.87618053e-01,  -6.18664682e-01,
                         -6.64012492e-01,  -6.33785725e-01,  -6.33261144e-01,
                         -6.45138323e-01,  -6.43318117e-01,  -6.38631344e-01,
                         -6.32593393e-01,  -6.37943566e-01,  -6.39763176e-01,
                         -6.30009174e-01,  -6.29780471e-01,  -6.30023301e-01,
                         -6.31366968e-01,  -6.46888077e-01,  -6.48744881e-01,
                         -6.36273503e-01,  -6.30940557e-01,  -6.22068107e-01,
                         -6.27643168e-01,  -6.45978570e-01,  -6.38092458e-01,
                         -6.36997342e-01,  -6.53796375e-01,  -6.42419875e-01,
                         -6.28098428e-01,  -6.34099126e-01,  -6.36412084e-01,
                         -6.36025786e-01,  -6.37457311e-01,  -6.41760290e-01,
                         -6.37066722e-01,  -6.20793998e-01,  -6.31079495e-01,
                         -6.49236023e-01,  -6.36375308e-01,  -6.27522111e-01,
                         -6.39495909e-01,  -6.49950385e-01,  -6.42400980e-01,
                         -6.18848503e-01,  -6.16456151e-01,  -6.36268914e-01,
                         -6.41590178e-01,  -6.36358082e-01,  -6.37784839e-01,
                         -6.42319798e-01,  -6.35421455e-01,  -6.23343050e-01,
                         -6.26178920e-01,  -6.32519901e-01,  -6.39207900e-01,
                         -6.43723965e-01,  -6.30206525e-01,  -6.27755284e-01,
                         -6.40538096e-01,  -6.39930308e-01,  -6.37022853e-01,
                         -6.31610870e-01,  -6.26076400e-01,  -6.31795108e-01,
                         -6.34436250e-01,  -6.34544134e-01,  -6.30849242e-01,
                         -6.29382908e-01,  -6.35051012e-01,  -6.27846003e-01,
                         -6.28639996e-01,  -6.34331346e-01,  -6.32118165e-01,
                         -6.45173728e-01,  -6.34399951e-01,  -6.26301169e-01,
                         -6.49021864e-01,  -6.31595194e-01,  -6.27324104e-01,
                         -6.29866004e-01,  -6.18310809e-01,  -6.65027261e-01,
                         -6.08123958e-01,  -5.93905032e-01,  -7.60633230e-01,
                         -4.97462034e-01,  -1.05938166e-01,  -3.59954506e-01,
                         -4.50399280e-01,  -1.16837122e-01,  -3.30145955e-01,
                         -7.39875376e-01,  -6.75607204e-01,  -5.63807487e-01,
                         -6.30694866e-01,  -6.53888762e-01,  -5.88009298e-01,
                         -6.38004482e-01,  -7.19765604e-01,  -3.82833451e-01,
                         -6.76495582e-02,  -4.13474888e-01,  -7.26806462e-01,
                         -6.09964907e-01,  -6.17338836e-01,  -6.58344805e-01,
                         -5.77462733e-01,  -6.94907129e-01,  -6.49879396e-01,
                         -1.80327445e-01,  -1.17542975e-01,  -6.09589279e-01,
                         -7.10326135e-01,  -5.41318774e-01,  -7.17426300e-01,
                         -6.01342440e-01,  -9.61756632e-02,  -2.40794480e-01,
                         -6.03355765e-01,  -1.39057785e-01,   2.26453662e-01,
                         -3.14726740e-01,  -5.68370581e-01,  -1.13466613e-01,
                         -1.81128010e-01,  -7.66012192e-01,  -6.54509306e-01,
                         -5.82553893e-02,  -1.63626418e-01,  -7.51050293e-01,
                         -6.53077602e-01,  -1.08555838e-01,  -1.79398194e-01,
                         -5.88335752e-01,  -7.04129636e-01,  -6.79796815e-01,
                         -3.95898104e-01,  -3.56651694e-02,  -3.67084831e-01,
                         -8.30637455e-01,  -4.56517994e-01,  -2.00076792e-02,
                         -3.54263544e-01,  -7.18283594e-01,  -5.93079925e-01,
                         -5.88435471e-01,  -7.31642306e-01,  -3.82543355e-01,
                         -1.72778778e-02,  -4.18759316e-01,  -8.18454504e-01,
                         -4.10658419e-01,  -2.97626033e-02,  -3.51288110e-01,
                         -7.06392050e-01,  -6.61303639e-01,  -5.51430583e-01,
                         -6.11152351e-01,  -7.31875956e-01,  -5.03440797e-01,
                         -8.65924805e-02,  -2.93115258e-01,  -5.67164242e-01,
                         -2.15901658e-02,   1.99559271e-01,  -4.19705093e-01,
                         -4.91577387e-01,  -6.85556233e-02,  -2.92579472e-01,
                         -7.15808570e-01,  -6.25635266e-01,  -5.70010543e-01,
                         -7.32603312e-01,  -4.08417404e-01,   2.70312354e-02,
                         -3.94359797e-01,  -8.55322063e-01,  -3.78714055e-01,
                         -4.24278192e-02,  -4.42422241e-01,  -4.14250821e-01,
                         -2.52033789e-02,  -4.32347715e-01,  -8.40728521e-01,
                         -3.00090998e-01,  -7.29664415e-02,  -4.66241777e-01,
                         -2.98094332e-01,  -1.28929138e-01,  -4.94375736e-01,
                         -3.13170224e-01,   1.92524254e-01,  -4.84683923e-02,
                         -5.87710500e-01,  -6.72907174e-01,  -5.53914845e-01,
                         -6.67528152e-01,  -6.69664621e-01,  -2.08287269e-01,
                         -5.32966703e-02,  -5.67655206e-01,  -7.78073967e-01,
                         -3.18552375e-01,   1.18714653e-01,   4.46152948e-02,
                         -4.03872311e-01,  -6.78466797e-01,  -6.18556857e-01,
                         -5.90477765e-01,  -6.30655468e-01,  -6.05236530e-01,
                         -6.04548693e-01,  -6.17648661e-01,  -6.10368967e-01,
                         -6.12630904e-01,  -6.01391971e-01,  -6.28256619e-01,
                         -6.41097188e-01,  -5.59066713e-01,  -6.19573951e-01,
                         -7.04875469e-01,  -3.52889687e-01,  -5.14642261e-02,
                         -3.98505837e-01,  -7.15635896e-01,  -6.03369534e-01,
                         -5.94570041e-01,  -6.41437650e-01,  -5.73552489e-01,
                         -6.81573689e-01,  -6.13916218e-01,  -1.48675293e-01,
                         -1.28356591e-01,  -6.14839971e-01,  -6.82782888e-01,
                         -5.28861761e-01,  -6.95276260e-01,  -5.73782146e-01,
                         -1.09331407e-01,  -2.00271636e-01,  -6.43300056e-01,
                         -6.87500358e-01,  -5.71493804e-01,  -6.15712464e-01,
                         -6.30779982e-01,  -5.93767703e-01,  -6.03365421e-01,
                         -6.17083073e-01,  -6.12343907e-01,  -6.12079203e-01,
                         -6.17404222e-01,  -6.15087032e-01,  -6.08785689e-01,
                         -6.22788966e-01,  -6.28730536e-01,  -6.03082776e-01,
                         -6.09292030e-01,  -6.14554524e-01,  -5.96059680e-01,
                         -6.89030051e-01,  -6.47842407e-01,  -2.27783069e-01,
                         -8.49667788e-02,  -5.09203732e-01,  -7.26138771e-01,
                         -5.99730670e-01,  -5.99519730e-01,  -6.41516209e-01,
                         -6.21615767e-01,  -6.16888821e-01,  -5.91516495e-01,
                         -6.06622517e-01,  -6.42779291e-01,  -6.24736845e-01,
                         -6.06572390e-01,  -5.92158079e-01,  -6.17803812e-01,
                         -6.67698860e-01,  -6.36061728e-01,  -6.05512917e-01,
                         -6.12831771e-01,  -6.01178229e-01,  -6.22884452e-01,
                         -6.37809157e-01,  -6.18004978e-01,  -6.20345294e-01,
                         -6.13911450e-01,  -6.16498053e-01,  -6.32328272e-01,
                         -6.22370541e-01,  -6.32214248e-01,  -6.29517078e-01,
                         -6.03505909e-01,  -6.19644940e-01,  -6.27306402e-01,
                         -6.22173131e-01,  -6.28311396e-01,  -6.13566935e-01,
                         -6.26209915e-01,  -6.40063286e-01,  -6.10002875e-01,
                         -6.07375562e-01,  -6.19022727e-01,  -6.30616009e-01,
                         -6.51135504e-01,  -6.25645518e-01,  -6.09534204e-01,
                         -6.33238018e-01,  -6.31562769e-01,  -6.27837777e-01,
                         -6.20978832e-01,  -6.09880030e-01,  -6.29566789e-01,
                         -6.28914893e-01,  -6.20266736e-01,  -6.37611508e-01,
                         -6.28606379e-01,  -6.14436567e-01,  -6.15895987e-01,
                         -6.13622367e-01,  -6.23584569e-01,  -6.30863190e-01,
                         -6.46178544e-01,  -6.60754681e-01,  -6.27058089e-01,
                         -6.08995616e-01,  -6.24327421e-01,  -6.20740712e-01,
                         -6.28442824e-01,  -6.34461939e-01,  -6.33974850e-01,
                         -6.49225235e-01,  -6.21626496e-01,  -5.96299827e-01,
                         -6.30961895e-01,  -6.40341520e-01,  -6.21924818e-01,
                         -6.19881153e-01,  -6.28989995e-01,  -6.50057614e-01,
                         -6.36498868e-01,  -6.12343788e-01,  -6.43177152e-01,
                         -6.54140234e-01,  -6.22231245e-01,  -6.16849780e-01,
                         -6.24583423e-01,  -6.26839161e-01,  -6.32401168e-01,
                         -6.37958765e-01,  -6.38288975e-01,  -6.22376025e-01,
                         -6.21676862e-01,  -6.43593669e-01,  -6.32683277e-01,
                         -6.14270449e-01,  -6.31870151e-01,  -6.40725970e-01,
                         -6.29025638e-01,  -6.24588490e-01,  -6.26508534e-01,
                         -6.39487088e-01,  -6.39940083e-01,  -6.17284596e-01,
                         -6.41395807e-01,  -6.70520902e-01,  -6.26771688e-01,
                         -6.20672643e-01,  -6.27583385e-01,  -5.86691260e-01,
                         -6.76944435e-01,  -6.52577221e-01,  -2.64650017e-01,
                         -1.56632870e-01,  -5.11028409e-01,  -6.76561177e-01,
                         -6.58189297e-01,  -5.67001820e-01,  -1.38701767e-01,
                          1.47884861e-01,  -2.12129250e-01,  -6.56011105e-01,
                         -6.45438612e-01,  -5.57113349e-01,  -7.18735337e-01,
                         -6.09570384e-01,  -1.42710015e-01,  -2.05619767e-01,
                         -6.93148017e-01,  -6.97968781e-01,  -5.52475035e-01,
                         -7.12398171e-01,  -5.44523656e-01,  -7.90480077e-02,
                         -2.42172077e-01,  -7.79767811e-01,  -6.05929375e-01,
                         -8.43541399e-02,  -2.41607711e-01,  -6.56937242e-01,
                         -6.95953548e-01,  -6.42832875e-01,  -4.41109627e-01,
                          9.81978886e-03,   1.02761514e-01,  -3.69079620e-01,
                         -7.86422133e-01,  -5.72133005e-01,  -7.09668249e-02,
                         -2.19728902e-01,  -8.02141368e-01,  -6.81622565e-01,
                         -6.64336681e-02,  -1.51004672e-01,  -7.70159125e-01,
                         -7.06062853e-01,  -1.26218647e-01,  -2.05654621e-01,
                         -5.65885484e-01,  -2.45660305e-01,   1.25506327e-01,
                         -1.26389228e-02,  -5.01206741e-02,   5.10609299e-02,
                         -2.58584112e-01,  -7.40012228e-01,  -6.73183382e-01,
                         -1.50645971e-01,  -1.21168986e-01,  -6.97806478e-01,
                         -7.76039898e-01,  -1.70115560e-01,  -5.89098744e-02,
                         -6.70797288e-01,  -8.08951914e-01,  -2.31561765e-01,
                         -1.25544608e-01,  -5.64751327e-01,  -3.69159430e-01,
                          1.93411440e-01,  -6.87451586e-02,  -6.36294782e-01,
                         -3.81701767e-01,   1.32924780e-01,  -5.02568856e-02,
                         -5.23097336e-01,  -6.76429570e-01,  -6.95778549e-01,
                         -6.08392775e-01,  -2.32542217e-01,   4.27381396e-02,
                         -2.84342617e-02,  -3.41943428e-02,   5.56548275e-02,
                         -1.99986130e-01,  -6.58068180e-01,  -7.48313606e-01,
                         -3.40507478e-01,   9.80320871e-02,  -2.84736473e-02,
                         -5.15578389e-01,  -4.74007934e-01,   3.69286351e-02,
                          7.56636113e-02,  -4.41195875e-01,  -7.94468880e-01,
                         -5.97485900e-01,  -1.19362347e-01,   6.78343102e-02,
                         -5.36920913e-02,  -5.00442460e-02,   2.40246803e-02,
                         -1.77275296e-02,  -4.26982418e-02,  -3.44944522e-02,
                         -2.93783508e-02,  -1.11157335e-02,  -1.76130515e-02,
                         -1.12009402e-02,  -1.06540686e-02,  -4.97377068e-02,
                         -3.90364081e-02,  -1.14571741e-02,  -1.72599927e-02,
                         -1.48391733e-02,  -2.67735794e-02,  -2.08424497e-02,
                         -1.86618604e-03,  -3.75632085e-02,  -3.84156257e-02,
                         -7.43364310e-03,  -3.31286080e-02,  -3.42720672e-02,
                         -1.14020137e-02,  -1.78994462e-02,  -6.36469200e-03,
                         -1.38113629e-02,  -4.49305847e-02,  -3.22955288e-02,
                         -1.45878699e-02,  -1.80476680e-02,  -2.46202871e-02,
                         -2.83657387e-02,  -8.78097676e-03,  -2.59234942e-03,
                         -2.81460285e-02,  -3.51409987e-02,  -3.04016378e-02,
                         -2.36757081e-02,  -1.02097243e-02,  -2.79652942e-02,
                         -5.05389944e-02,  -2.63887104e-02,  -2.81558163e-03,
                         -1.81863010e-02,  -2.63194777e-02,  -1.36985974e-02,
                         -2.38432679e-02,  -4.08813469e-02,  -2.54472122e-02,
                         -1.27872499e-02,  -2.37341598e-02,  -2.54973900e-02,
                         -1.48320068e-02,  -1.19297048e-02,  -2.44800877e-02,
                         -3.77337560e-02,  -3.28404903e-02,  -2.11069789e-02,
                         -1.74422208e-02,  -2.05372404e-02,  -1.76632907e-02,
                         -1.32263908e-02,  -3.52361947e-02,  -4.27442938e-02,
                         -3.98045778e-03,   2.97900476e-03,  -2.17752550e-02,
                         -2.17155516e-02,  -2.85966508e-02,  -2.86224764e-02,
                         -8.79961438e-03,  -2.36750282e-02,  -3.95281613e-02,
                         -1.87387094e-02,   2.71627214e-03,   1.77836826e-03,
                         -3.36793214e-02,  -4.48037498e-02,   2.54803291e-03,
                          6.28232723e-04,  -4.40068804e-02,  -2.63843331e-02,
                          2.09714915e-03,  -8.61031469e-03,  -1.50254443e-02,
                         -1.99852921e-02,  -2.86079235e-02,  -1.99866910e-02,
                         -1.12690125e-02,  -2.10925099e-02,  -2.88464073e-02,
                         -2.08315644e-02,  -1.87752731e-02,  -2.32555810e-02,
                         -1.39404777e-02,  -7.57864816e-03,  -1.40067432e-02,
                         -1.52752539e-02,  -1.14877215e-02,  -5.58219803e-03,
                         -4.03950457e-03,  -1.67004596e-02,  -2.44878922e-02,
                         -1.51374266e-02,  -7.66330073e-03,  -1.26228863e-02,
                         -1.70863420e-02,  -1.21751158e-02,  -1.19591653e-02,
                         -1.61058251e-02,  -6.19868841e-03,   4.99106292e-03,
                          1.35291251e-03,  -1.02712791e-02,  -2.19701454e-02,
                         -1.95455868e-02,  -7.05330819e-03,  -2.89171981e-03,
                         -3.57240695e-03,  -1.00176036e-02,  -1.13936253e-02,
                          1.68687303e-03,  -2.35424042e-04,  -3.44780507e-03,
                         -4.14693169e-03,  -2.95482296e-02,  -1.14761358e-02,
                         -1.77367753e-03,  -6.87677041e-02,   2.16403734e-02,
                          8.55232924e-02,  -3.08963418e-01,  -5.31634212e-01,
                         -1.61286309e-01,  -1.96266070e-01,  -7.45491147e-01,
                         -7.06559300e-01,  -1.65375486e-01,   9.71591547e-02,
                         -9.66416672e-02,  -5.94841540e-01,  -7.53257215e-01,
                         -3.04592848e-01,  -1.23323269e-01,  -4.53494370e-01,
                         -6.82224870e-01,  -7.37652540e-01,  -5.54326832e-01,
                         -1.52117118e-01,  -2.11490497e-01,  -6.59139693e-01,
                         -7.34683990e-01,  -5.87638855e-01,  -6.23165727e-01,
                         -6.60175920e-01,  -6.21501565e-01,  -6.30394399e-01,
                         -6.50369704e-01,  -6.27364516e-01,  -6.32429063e-01,
                         -6.83630943e-01,  -5.25277436e-01,  -7.89850652e-02,
                          1.06283531e-01,  -2.76884735e-01,  -6.56098843e-01,
                         -6.26391590e-01,  -5.99403262e-01,  -7.55821407e-01,
                         -5.62109172e-01,  -8.34967345e-02,  -2.22970292e-01,
                         -8.01685095e-01,  -6.47261918e-01,  -4.37816419e-02,
                         -1.92136630e-01,  -7.17453480e-01,  -6.91691577e-01,
                         -5.70351720e-01,  -7.37430274e-01,  -5.36041558e-01,
                         -1.00156926e-01,  -2.89130777e-01,  -7.10536242e-01,
                         -6.31784022e-01,  -5.65349698e-01,  -7.52900541e-01,
                         -4.99460816e-01,  -5.74754328e-02,  -3.22306722e-01,
                         -8.22053254e-01,  -5.59821784e-01,  -2.21403167e-02,
                         -2.65596837e-01,  -8.22512090e-01,  -5.83258569e-01,
                         -7.03703314e-02,  -3.05402458e-01,  -5.71584344e-01,
                         -1.04862154e-01,   1.65779039e-01,  -2.88629025e-01,
                         -6.68860197e-01,  -6.53536439e-01,  -6.09094739e-01,
                         -6.40129507e-01,  -6.53600454e-01,  -6.18034840e-01,
                         -6.19047761e-01,  -6.58543587e-01,  -6.01211429e-01,
                         -6.25099063e-01,  -7.44370818e-01,  -4.76445973e-01,
                         -9.36372951e-02,  -3.02112460e-01,  -6.89058840e-01,
                         -6.80711985e-01,  -6.03439510e-01,  -6.51808679e-01,
                         -6.36041582e-01,  -6.09184504e-01,  -6.47156715e-01,
                         -6.45520926e-01,  -6.09522462e-01,  -6.30189061e-01,
                         -6.32403970e-01,  -6.13469124e-01,  -7.09944963e-01,
                         -6.26451015e-01,  -1.99863046e-01,  -1.47717223e-01,
                         -6.08496249e-01,  -7.28321314e-01,  -5.44318378e-01,
                         -6.46632791e-01,  -6.65093243e-01,  -2.15093657e-01,
                          1.38452381e-01,  -1.11618280e-01,  -5.51603436e-01,
                         -6.52378380e-01,  -6.45362258e-01,  -6.05838478e-01,
                         -1.69510543e-01,   1.73279539e-01,  -1.52084112e-01,
                         -5.77791691e-01,  -6.82504535e-01,  -6.46035314e-01,
                         -5.60904086e-01,  -6.42069101e-01,  -7.27864146e-01,
                         -3.61573309e-01,  -7.01007769e-02,  -4.00860310e-01,
                         -7.33280480e-01,  -6.58007920e-01,  -5.69647849e-01,
                         -6.23407543e-01,  -6.05683446e-01,  -5.51762044e-01,
                         -6.74252927e-01,  -7.09340274e-01,  -3.27647507e-01,
                         -9.26108956e-02,  -4.37855333e-01,  -7.05942094e-01,
                         -5.98509967e-01,  -5.84628344e-01,  -6.32959127e-01,
                         -5.74671090e-01,  -6.53946340e-01,  -6.55404091e-01,
                         -2.09784627e-01,   1.64693266e-01,  -8.16674158e-02,
                         -5.28306067e-01,  -6.60778880e-01,  -6.16629899e-01,
                         -6.14455938e-01,  -6.13767564e-01,  -6.00158155e-01,
                         -6.12902284e-01,  -6.19640470e-01,  -6.08811021e-01,
                         -6.21904910e-01,  -6.35856926e-01,  -6.06443644e-01,
                         -5.84163606e-01,  -6.03090286e-01,  -6.14237964e-01,
                         -6.18625283e-01,  -6.33038223e-01,  -6.14692748e-01,
                         -5.81716478e-01,  -5.94186187e-01,  -6.21100307e-01,
                         -6.12851739e-01,  -5.95253170e-01,  -6.03500843e-01,
                         -6.20818079e-01,  -6.17947102e-01,  -6.01336777e-01,
                         -5.92302203e-01,  -5.95158219e-01,  -6.04192555e-01,
                         -6.12176716e-01,  -6.13155961e-01,  -6.07329249e-01,
                         -5.98742545e-01,  -5.97566187e-01,  -6.09512925e-01,
                         -6.04805052e-01,  -5.85133314e-01,  -6.19101942e-01,
                         -6.35208786e-01,  -5.54595470e-01,  -6.08430266e-01,
                         -7.14336634e-01,  -3.86205256e-01,  -2.84688938e-02,
                         -3.34911644e-01,  -7.10705400e-01,  -6.13587081e-01,
                         -5.52345574e-01,  -6.30627513e-01,  -5.99791229e-01,
                         -5.97442865e-01,  -6.00854695e-01,  -5.98873794e-01,
                         -6.45092905e-01,  -5.52503467e-01,  -5.54206431e-01,
                         -7.25664854e-01,  -4.40110624e-01,  -2.68213116e-02,
                         -3.18194181e-01,  -7.08706975e-01,  -5.78128815e-01,
                         -5.49271762e-01,  -7.14361727e-01,  -3.96587610e-01,
                          1.18437568e-02,  -3.59931529e-01,  -8.19507778e-01,
                         -4.11004424e-01,  -2.49238149e-03,  -3.40429455e-01,
                         -6.62307441e-01,  -6.71971500e-01,  -5.67952931e-01,
                         -1.78146392e-01,  -7.00767264e-02,  -6.25631571e-01,
                         -7.56621480e-01,  -1.71117753e-01,  -5.75029738e-02,
                         -5.42531610e-01,  -6.75763965e-01,  -5.20993948e-01,
                         -6.50084615e-01,  -6.27292335e-01,  -1.80930987e-01,
                         -1.40691191e-01,  -5.77027261e-01,  -6.60481393e-01,
                         -5.42070031e-01,  -6.26901984e-01,  -6.18059397e-01,
                         -5.55674672e-01,  -6.21783495e-01,  -6.21746778e-01,
                         -5.99309862e-01,  -6.10950351e-01,  -5.66728532e-01,
                         -6.14914119e-01,  -6.36301696e-01,  -2.94612080e-01,
                          1.24436349e-01,   5.21285646e-02,  -4.57291543e-01,
                         -7.44425118e-01,  -4.53822911e-01,  -3.39746810e-02,
                          6.96421787e-02,   1.66267250e-02,   2.97240634e-02,
                          5.25155142e-02,   1.97614226e-02,   5.80558693e-03,
                          3.95949595e-02,   3.04399580e-02,   2.16232822e-03,
                          1.43204778e-02,   1.31906411e-02,   2.95051243e-02,
                          4.87502553e-02,   1.35727311e-02,   3.60079892e-02,
                          3.58986929e-02,  -2.76135523e-02,   9.24906805e-02,
                          6.90163895e-02,  -3.74353528e-01,  -4.74512815e-01,
                         -3.51452008e-02,   1.39851287e-01,  -1.23482966e-03,
                         -4.43148799e-03,   4.93120030e-02,  -3.79426032e-03,
                         -2.70506237e-02,   9.75191146e-02,   4.91728373e-02,
                         -3.73634279e-01,  -4.59321231e-01,   1.60504878e-02,
                          1.19837813e-01,  -1.03660822e-01,   6.29750267e-02,
                          4.95044366e-02,  -4.32974815e-01,  -4.37843800e-01,
                          2.20297351e-02,   1.17728487e-01,  -1.10013075e-02,
                          2.26486903e-02,   4.89547029e-02,   1.27764996e-02,
                          1.21618062e-02,   3.11359819e-02,   5.33379465e-02,
                          2.56094765e-02,  -1.54500222e-03,   4.44525518e-02,
                          1.29696866e-02,   2.38359650e-03,   1.30711034e-01,
                         -5.94696254e-02,  -4.74959522e-01,  -3.45294446e-01,
                          6.73498884e-02,   7.85511211e-02,  -1.72541942e-02,
                          5.39306067e-02,   4.72662523e-02,   9.71837994e-03,
                          7.40672871e-02,   6.98071644e-02,  -2.22114101e-02,
                          4.77994159e-02,   1.18495628e-01,  -2.28090078e-01,
                         -5.24977207e-01,  -1.81221411e-01,   1.49812400e-01,
                          2.07552072e-02,  -8.51285364e-03,   9.46011096e-02,
                          3.37474048e-02,   1.39943212e-02,   6.84807599e-02,
                          3.11252940e-02,  -2.16343887e-02,   5.90330660e-02,
                          1.06497549e-01,  -2.69763112e-01,  -5.54077685e-01,
                         -4.09132801e-02,   2.25429982e-01,  -3.63859236e-01,
                         -4.48468268e-01,  -3.90157029e-02,  -3.09532434e-01,
                         -5.15742540e-01,   2.65086424e-02,   1.79159567e-01,
                         -3.92719507e-01,  -5.26719570e-01,   4.34527583e-02,
                          1.92508996e-01,  -3.71067405e-01,  -5.31626701e-01,
                         -5.56882359e-02,   1.59276918e-01,   3.43209393e-02,
                          4.03530896e-02,   5.62679544e-02,  -2.68221319e-01,
                         -7.10026443e-01,  -5.48309982e-01,  -4.54548933e-02,
                         -2.32147530e-01,  -5.53436756e-01,  -8.14627334e-02,
                          2.22684413e-01,  -2.46893153e-01,  -6.06466293e-01,
                         -6.22191846e-01,  -6.02762461e-01,  -3.84440452e-01,
                         -6.79232040e-03,   1.11690000e-01,  -2.48498514e-01,
                         -7.08598793e-01,  -6.14038587e-01,  -1.19761057e-01,
                          9.37472284e-02,   5.52759357e-02,   1.81935189e-04,
                         -3.14961791e-01,  -7.12490141e-01,  -5.37438035e-01,
                         -4.67818640e-02,  -1.89891830e-01,  -7.36858189e-01,
                         -5.93284905e-01,  -6.13316335e-02,  -2.33051538e-01,
                         -5.43194890e-01,  -6.37743101e-02,   2.15773702e-01,
                         -3.65942210e-01,  -5.33436537e-01,  -4.28275466e-02,
                         -1.71260491e-01,  -7.60796368e-01,  -6.95868433e-01,
                         -8.63179415e-02,   2.01282129e-01,  -1.89430609e-01,
                         -5.56402087e-01,  -2.14982793e-01,  -6.08582161e-02,
                         -6.74509704e-01,  -7.47254193e-01,  -8.90593752e-02,
                         -1.57438040e-01,  -6.14266098e-01,  -2.00295910e-01,
                          2.53193647e-01,  -2.27624238e-01,  -5.90058327e-01,
                         -2.06823707e-01,  -1.31062075e-01,  -6.35402501e-01,
                         -7.36229122e-01,  -2.13262856e-01,   1.71234220e-01,
                         -8.62783715e-02,  -5.34694135e-01,  -3.94335270e-01,
                          3.92412543e-02,   5.35011403e-02,  -3.70407738e-02,
                          3.73588651e-02,  -2.06601396e-02,  -1.30023649e-02,
                          9.44099799e-02,  -2.01303631e-01,  -6.93638206e-01,
                         -7.26007223e-01,  -2.88371563e-01,   9.88655388e-02,
                         -3.50225507e-03,  -4.87693638e-01,  -7.78849602e-01,
                         -5.26414156e-01,  -7.45720267e-02,   6.79936036e-02,
                          2.64355335e-02,  -9.10701454e-02,  -5.63829839e-01,
                         -8.19564223e-01,  -3.12207222e-01,  -6.38838559e-02,
                         -4.97682899e-01,  -4.65966552e-01,   7.84807354e-02,
                         -3.71559407e-04,  -5.69443285e-01,  -4.81294453e-01,
                          1.27693951e-01,   2.09135208e-02,  -5.37790954e-01,
                         -3.73818278e-01,  -1.31294191e-01,  -5.33103883e-01,
                         -4.65573788e-01,   1.74315929e-01,   3.46099138e-02,
                         -5.99630058e-01,  -4.49018359e-01,   1.25372365e-01,
                         -1.59818400e-02,  -5.66907883e-01,  -4.81143713e-01,
                         -1.51325474e-02,   3.77830975e-02,  -7.07867816e-02,
                         -7.40392134e-04,   1.32273315e-02,  -3.62525769e-02,
                         -4.77999710e-02,  -6.21298924e-02,  -3.39334048e-02,
                         -1.00155454e-02,  -3.33326161e-02,  -1.98470559e-02,
                         -8.82260874e-03,  -2.29281802e-02,  -1.13987960e-02,
                         -2.65722331e-02,  -6.20835386e-02,  -4.86765802e-02,
                         -1.96324941e-02,  -2.26429980e-02,  -3.22666727e-02,
                         -8.11474863e-03,   1.71093259e-03,  -4.77239564e-02,
                         -7.00297952e-02,  -3.73762473e-02,  -1.99565403e-02,
                         -2.38653012e-02,  -2.94682682e-02,  -1.33746760e-02,
                         -3.35970521e-03,  -4.78441194e-02,  -5.18109538e-02,
                         -1.80604775e-02,  -5.45552336e-02,  -5.84205464e-02,
                         -1.88074615e-02,  -3.83371264e-02,  -1.70747675e-02,
                          1.46652618e-02,  -2.93043740e-02,  -3.01209986e-02,
                         -3.00775282e-02,  -6.39067441e-02,  -2.08379161e-02,
                          8.52665398e-03,  -3.86858056e-03,  -3.13626193e-02,
                         -1.06776051e-01,   8.02241731e-03,   1.21991433e-01,
                         -2.85141915e-01,  -6.16573572e-01,  -2.50006825e-01,
                          8.60618576e-02,  -1.20663308e-02,  -4.76973504e-02,
                          2.01241430e-02,  -3.82500067e-02,  -7.45271668e-02,
                         -3.81264719e-03,  -2.12865323e-02,  -8.16042945e-02,
                          5.03962487e-02,   7.49749551e-03,  -4.38867003e-01,
                         -4.86878514e-01,  -1.29428580e-01,  -3.49971563e-01,
                         -7.53560245e-01,  -6.46219850e-01,  -6.44097030e-01,
                         -7.73760855e-01,  -4.17925924e-01,   2.18355041e-02,
                          4.57155667e-02,  -6.17873333e-02,  -9.44617111e-03,
                         -3.11606359e-02,  -4.62737918e-01,  -8.16205502e-01,
                         -4.97572452e-01,  -7.89537430e-02,  -6.38353825e-03,
                          3.16575691e-02,  -1.62163153e-01,  -5.46476483e-01,
                         -3.96682858e-01,   3.51556689e-02,   5.40786721e-02,
                         -5.89675307e-02,  -3.76506080e-03,   1.99643965e-03,
                         -5.19310758e-02,  -1.37296980e-02,   7.36785606e-02,
                         -7.76314288e-02,  -5.76101065e-01,  -8.22095752e-01,
                         -4.28479105e-01,  -2.99323462e-02,   2.82554817e-03,
                          7.02956226e-03,  -1.46523476e-01,  -6.29431605e-01,
                         -8.09196532e-01,  -3.61586750e-01,   4.06066291e-02,
                         -2.41155699e-02,  -6.07658960e-02,   8.52194503e-02,
                         -1.74506292e-01,  -5.63181818e-01,  -3.04202348e-01,
                         -9.94684398e-02,  -6.44264996e-01,  -8.63296866e-01,
                         -2.69931376e-01,  -5.41347228e-02,  -6.03658020e-01,
                         -8.26507270e-01,  -2.97046006e-01,  -8.18386227e-02,
                         -5.31598866e-01,  -4.19421285e-01,   1.70461372e-01,
                         -1.09019600e-01,  -5.92462122e-01,  -2.98377454e-01,
                         -2.28415534e-01,  -5.13519406e-01,  -2.74808347e-01,
                         -1.90859437e-01,  -7.08757401e-01,  -7.98249722e-01,
                         -2.43680045e-01,   1.22932687e-01,  -8.96194205e-02,
                         -5.63269734e-01,  -7.45726764e-01,  -6.25197470e-01,
                         -6.06090665e-01,  -6.72023535e-01,  -6.75560117e-01,
                         -6.77684486e-01,  -6.56526387e-01,  -6.45758927e-01,
                         -6.87714636e-01,  -6.73300147e-01,  -6.40064359e-01,
                         -6.70891881e-01,  -6.87631786e-01,  -6.61523044e-01,
                         -6.42545998e-01,  -6.73242390e-01,  -7.15936661e-01,
                         -6.69002235e-01,  -6.11695111e-01,  -6.55651510e-01,
                         -6.90358162e-01,  -6.65873468e-01,  -6.63985133e-01,
                         -6.72204137e-01,  -6.64708376e-01,  -6.77720845e-01,
                         -7.06732094e-01,  -6.89160049e-01,  -6.29257679e-01,
                         -6.38432026e-01,  -7.11611569e-01,  -7.04141676e-01,
                         -6.32696152e-01,  -6.40462101e-01,  -7.00064063e-01,
                         -6.81748211e-01,  -6.36397600e-01,  -6.70012593e-01,
                         -6.84967577e-01,  -6.44194484e-01,  -6.66602015e-01,
                         -6.97582960e-01,  -6.84866726e-01,  -7.02722728e-01,
                         -6.90919757e-01,  -6.54169977e-01,  -6.77059233e-01,
                         -6.82867646e-01,  -6.74039602e-01,  -6.76990628e-01,
                         -6.35977805e-01,  -6.51428223e-01,  -7.09648669e-01,
                         -6.91427410e-01,  -6.86536729e-01,  -6.60136223e-01,
                         -6.31559014e-01,  -7.71929443e-01,  -6.89086080e-01,
                         -2.25456208e-01,  -1.91494927e-01,  -6.63346171e-01,
                         -7.79007077e-01,  -6.39293790e-01,  -7.51214445e-01,
                         -6.50261164e-01,  -1.83695152e-01,  -2.04164177e-01,
                         -7.52285898e-01,  -7.78886259e-01,  -2.24214390e-01,
                         -1.73283353e-01,  -7.32959270e-01,  -8.21316838e-01,
                         -2.52256930e-01,  -1.04754157e-01,  -6.67489171e-01,
                         -8.68360758e-01,  -3.25497150e-01,  -8.04114714e-02,
                         -5.48098564e-01,  -8.14744651e-01,  -6.37805641e-01,
                         -6.88271642e-01,  -7.18966424e-01,  -2.62313753e-01,
                         -1.32904798e-01,  -6.99518919e-01,  -8.46895039e-01,
                         -2.97479004e-01,  -1.58535346e-01,  -6.08944893e-01,
                         -7.85947502e-01,  -6.44431353e-01,  -6.62075222e-01,
                         -7.14583933e-01,  -6.77078247e-01,  -7.00081229e-01,
                         -7.03045845e-01,  -6.76334739e-01,  -6.72354400e-01,
                         -6.40803635e-01,  -7.40599334e-01,  -7.68848956e-01,
                         -3.69875103e-01,  -1.53236523e-01,  -5.24960935e-01,
                         -8.02423477e-01,  -7.11587310e-01,  -6.23787165e-01,
                         -6.82611525e-01,  -7.59089172e-01,  -5.42582691e-01,
                         -7.05579072e-02,   4.81893532e-02,  -3.66079301e-01,
                         -7.24864900e-01,  -6.76365435e-01,  -6.58855498e-01,
                         -8.33805740e-01,  -5.85367680e-01,  -1.27502009e-01,
                         -3.24033380e-01,  -7.45296299e-01,  -7.13559210e-01,
                         -6.29345775e-01,  -7.06044555e-01,  -7.08039343e-01,
                         -6.84515774e-01,  -7.12612987e-01,  -6.94933653e-01,
                         -6.24988198e-01,  -6.91101253e-01,  -7.54931867e-01,
                         -4.43492919e-01,  -1.86300889e-01,  -4.40589160e-01,
                         -7.26385176e-01,  -7.92378306e-01,  -6.42807186e-01,
                         -2.05678478e-01,  -1.79262385e-01,  -7.49370992e-01,
                         -7.85738230e-01,  -1.86229154e-01,  -1.39613762e-01,
                         -7.21349955e-01,  -8.00338030e-01,  -2.48966292e-01,
                         -1.66101009e-01,  -6.39190614e-01,  -7.69828677e-01,
                         -6.34965301e-01,  -6.83821023e-01,  -7.16562212e-01,
                         -6.36069953e-01,  -6.19570196e-01,  -7.46093810e-01,
                         -7.23382592e-01,  -2.70571321e-01,  -1.07303470e-01,
                         -6.63485110e-01,  -8.38841140e-01,  -2.92333454e-01,
                         -1.31822050e-01,  -5.46292901e-01,  -7.64950991e-01,
                         -6.89304471e-01,  -7.13255167e-01,  -7.19989240e-01,
                         -3.34042877e-01,   9.15249512e-02,  -8.27542320e-02,
                         -5.76789260e-01,  -7.25580931e-01,  -6.21106744e-01,
                         -6.60138369e-01,  -7.17743695e-01,  -6.35925412e-01,
                         -6.66731298e-01,  -6.79323375e-01,  -2.60036260e-01,
                          1.32301882e-01,  -1.21604368e-01,  -5.69997907e-01,
                         -7.01208472e-01,  -7.31780589e-01,  -6.10482812e-01,
                         -1.79710016e-01,  -1.62452400e-01,  -7.51196623e-01,
                         -7.35467911e-01,  -9.44362953e-02,  -1.98049456e-01,
                         -6.50613606e-01,  -2.52624959e-01,   1.89332008e-01,
                         -2.54679114e-01,  -6.41498029e-01,  -2.12773144e-01,
                          1.63426995e-01,  -2.22300202e-01,  -6.81651890e-01,
                         -6.64127350e-01,  -5.86747050e-01,  -6.03443384e-01,
                         -6.04154587e-01,  -6.98616683e-01,  -5.26578724e-01,
                          1.65761821e-02,   5.31886779e-02,  -4.25123721e-01,
                         -4.14199710e-01,  -1.85971603e-01,  -4.25156683e-01,
                         -4.16871786e-01,  -7.02289566e-02,  -3.98986280e-01,
                         -8.13701868e-01,  -3.88946295e-01,  -1.10284798e-01,
                         -4.72889423e-01,  -6.67848349e-01,  -6.43203735e-01,
                         -6.61384642e-01,  -6.03163838e-01,  -5.80208004e-01,
                         -6.28769457e-01,  -6.17927611e-01,  -5.79661429e-01,
                         -5.84614813e-01,  -6.45911694e-01,  -6.36041880e-01,
                         -5.77633440e-01,  -6.44762039e-01,  -6.61939383e-01,
                         -5.90648711e-01,  -6.40876710e-01,  -6.63582861e-01,
                         -6.07126057e-01,  -6.07530355e-01,  -6.12936080e-01,
                         -6.04341924e-01,  -5.26951015e-01,  -5.35886824e-01,
                         -7.41215467e-01,  -5.30091465e-01,  -3.90365534e-02,
                         -2.39367485e-01,  -7.03819633e-01,  -6.51421726e-01,
                         -5.27847886e-01,  -5.98598421e-01,  -5.94373226e-01,
                         -5.45094728e-01,  -6.41857505e-01,  -7.44607389e-01,
                         -4.19306844e-01,   7.37931859e-03,  -2.19419390e-01,
                         -6.36001170e-01,  -6.04496300e-01,  -5.39108098e-01,
                         -6.33241892e-01,  -6.04109585e-01,  -4.86935318e-01,
                         -5.37454784e-01,  -7.11256206e-01,  -4.99678284e-01,
                         -4.37917560e-02,  -1.88343912e-01,  -6.25879943e-01,
                         -5.94362319e-01,  -4.90394652e-01,  -6.01832271e-01,
                         -5.91610193e-01,  -5.09006798e-01,  -5.15712261e-01,
                         -5.69276989e-01,  -6.31026387e-01,  -6.05314791e-01,
                         -5.12845039e-01,  -5.00718296e-01,  -5.59626281e-01,
                         -5.82813084e-01,  -5.56895435e-01,  -5.60935676e-01,
                         -5.87896049e-01,  -5.61462164e-01,  -5.23782670e-01,
                         -5.11133194e-01,  -5.08732140e-01,  -5.36773384e-01,
                         -5.37138939e-01,  -5.08696973e-01,  -5.50924540e-01,
                         -5.91025829e-01,  -5.56998193e-01,  -5.37816584e-01,
                         -5.47242284e-01,  -5.56290507e-01,  -5.68317115e-01,
                         -5.45256734e-01,  -5.11528909e-01,  -5.35719275e-01,
                         -5.70987821e-01,  -5.40538728e-01,  -4.99123335e-01,
                         -5.41507661e-01,  -6.03646278e-01,  -5.67043602e-01,
                         -4.88048375e-01,  -4.70354646e-01,  -4.90514308e-01,
                         -5.14786482e-01,  -5.55962026e-01,  -5.84693491e-01,
                         -5.61133742e-01,  -5.11875153e-01,  -4.84345824e-01,
                         -4.96672243e-01,  -5.42023122e-01,  -5.72515011e-01,
                         -5.59006393e-01,  -5.30089438e-01,  -4.85006452e-01,
                         -4.62504119e-01,  -5.36321700e-01,  -5.89187026e-01,
                         -5.27261436e-01,  -5.03180861e-01,  -5.32660604e-01,
                         -5.14550984e-01,  -5.44244111e-01,  -5.93057990e-01,
                         -5.23290634e-01,  -4.95593905e-01,  -5.73063135e-01,
                         -5.35631776e-01,  -4.65055943e-01,  -5.53009629e-01,
                         -6.03733659e-01,  -5.11108279e-01,  -4.88516569e-01,
                         -5.53085029e-01,  -5.52210510e-01,  -5.06685913e-01,
                         -5.16440213e-01,  -5.90696633e-01,  -5.83713889e-01,
                         -4.51985538e-01,  -4.89680052e-01,  -6.21135950e-01,
                         -3.44421297e-01,  -2.66770795e-02,  -3.07832807e-01,
                         -5.87715805e-01,  -4.16927189e-01,  -4.61911500e-01,
                         -7.15395212e-01,  -6.27372503e-01,  -5.32775998e-01,
                         -5.42558372e-01,  -1.84866071e-01,   3.01179588e-02,
                         -4.85570848e-01,  -8.05830479e-01,  -2.75601983e-01,
                          8.98739845e-02,  -3.01204354e-01,  -6.18352354e-01,
                         -5.65891206e-01,  -6.37166023e-01,  -5.71250618e-01,
                         -1.26155108e-01,  -5.05471453e-02,  -4.75670069e-01,
                         -6.18018031e-01,  -5.07574558e-01,  -5.84730089e-01,
                         -6.07508898e-01,  -5.15119731e-01,  -5.59765577e-01,
                         -5.69988430e-01,  -5.49710512e-01,  -6.34837747e-01,
                         -4.21238542e-01,  -4.36206199e-02,  -2.28329167e-01,
                         -6.32947922e-01,  -6.10905468e-01,  -5.17135024e-01,
                         -5.91981590e-01,  -6.04849815e-01,  -5.77375114e-01,
                         -5.34606874e-01,  -5.31070292e-01,  -6.42595887e-01,
                         -5.32724261e-01,  -1.12717204e-01,   1.41013309e-01,
                         -4.79764529e-02,  -5.30319750e-01,  -7.12742507e-01,
                         -2.50927418e-01,   5.32335183e-03,  -3.80170792e-01,
                         -4.03019935e-01,   5.85792474e-02,   1.02854952e-01,
                         -3.01229942e-04,   1.44722521e-01,  -9.95891541e-02,
                         -5.25054276e-01,  -2.66533494e-01,   1.58824444e-01,
                          5.00144623e-02,   2.77858879e-03,   1.80885062e-01,
                         -1.50156617e-01,  -6.17506742e-01,  -2.66095698e-01,
                          2.57142276e-01,  -8.75042155e-02,  -5.23375213e-01,
                         -1.97436079e-01,  -1.01207703e-01,  -6.88226759e-01,
                         -6.81490541e-01,  -6.73535913e-02,  -1.57877296e-01,
                         -5.27702749e-01,  -1.71741679e-01,   1.68532640e-01,
                         -2.73429528e-02,  -1.33636342e-02,   1.19350471e-01,
                         -2.51054347e-01,  -4.94641185e-01,  -8.98466408e-02,
                          1.33262113e-01,  -6.64333031e-02,   4.06578407e-02,
                          1.32787958e-01,  -3.52628201e-01,  -5.53510249e-01,
                         -2.36877948e-02,   1.75140485e-01,  -3.32933187e-01,
                         -5.36124468e-01,  -5.63642755e-02,   1.46331787e-01,
                         -3.09757620e-01,  -4.94492829e-01,  -1.62621111e-01,
                          2.23783422e-02,   9.41306874e-02,   2.82473750e-02,
                         -4.46263105e-01,  -4.80836987e-01,   1.44604474e-01,
                          1.00997455e-01,  -5.18071115e-01,  -4.35809284e-01,
                          2.81740054e-02,   5.91105521e-02,  -2.63021775e-02,
                          6.69974387e-02,   8.90412778e-02,   2.48157931e-03,
                         -1.47897797e-02,   8.66608042e-03,  -3.52513418e-03,
                          3.77250016e-02,   9.54708084e-02,   3.39813791e-02,
                         -2.54934095e-02,   3.57221588e-02,   8.78973305e-02,
                          3.47671732e-02,  -4.94297706e-02,  -2.79018078e-02,
                          6.18378893e-02,   3.34625058e-02,  -3.57725024e-02,
                          6.90724840e-03,   4.19126265e-02,   3.18335071e-02,
                          3.74826938e-02,  -6.53242925e-04,  -1.44748436e-02,
                          4.03878689e-02,   1.15997763e-02,  -4.41690907e-02,
                          2.41381358e-02,   9.01748314e-02,   4.08602320e-02,
                         -7.25354673e-03,   3.64169180e-02,   7.36280382e-02,
                          1.09400246e-02,  -2.82779634e-02,   3.49291041e-02,
                          4.09460552e-02,  -1.38305435e-02,   3.48472074e-02,
                          7.55257681e-02,  -2.35046893e-02,  -6.07859530e-02,
                          4.63030785e-02,   8.42601210e-02,   2.39608493e-02,
                          1.60397999e-02,   3.22209150e-02,  -1.09804869e-02,
                         -4.61153649e-02,   6.83463085e-03,   8.06358904e-02,
                          5.04929461e-02,  -2.60805227e-02,  -1.71990658e-03,
                          4.83710058e-02,   2.21299846e-02,   1.31504415e-02,
                          1.91977508e-02,  -2.99053099e-02,  -3.05377841e-02,
                          2.33798902e-02,  -8.68592970e-03,  -4.09120694e-02,
                          4.82123792e-02,   1.37559301e-03,  -3.86685848e-01,
                         -6.86497748e-01,  -4.66623336e-01,  -9.42223817e-02,
                         -1.52080171e-02,  -3.30909975e-02,   1.44339958e-02,
                         -8.56770109e-03,  -3.16754021e-02,   2.21402850e-02,
                          3.53875197e-02,   2.75512990e-02,   4.86218184e-02,
                          1.49996504e-02,  -4.71291877e-02,  -3.70772034e-02,
                          1.71243269e-02,   3.17855999e-02,  -8.95146281e-03,
                         -3.82186659e-02,   7.22882920e-04,   5.11626527e-02,
                          1.78116914e-02,  -7.62010291e-02,  -9.64962319e-02,
                         -2.06891075e-03,   7.37061873e-02,   4.69034985e-02,
                         -8.63388274e-03,  -2.86900774e-02,  -2.84938309e-02,
                         -3.25573534e-02,  -3.49131711e-02,  -2.44587865e-02,
                         -1.96481552e-02,  -5.84302943e-05,   6.91070631e-02,
                          9.12231728e-02,  -7.31013855e-03,  -8.75965878e-02,
                         -4.36798036e-02,   1.49924001e-02,  -1.16893910e-02,
                         -4.60475311e-02,  -4.37993184e-03,   2.48594414e-02,
                         -3.25856023e-02,  -5.95918670e-02,   2.41100951e-03,
                          1.80586278e-02,  -5.46558313e-02,  -7.17893913e-02,
                          6.79491134e-03,   3.01709678e-02,  -4.02612314e-02,
                         -5.82349971e-02,  -6.11934299e-03,   7.75082596e-03,
                         -9.91088711e-03,  -1.92099120e-02,  -3.11401486e-02,
                         -3.53727899e-02,  -3.32802795e-02,  -3.87388989e-02,
                         -4.18748707e-02,  -3.00711449e-02,  -7.64982402e-03,
                         -5.45976916e-03,  -2.72726025e-02,  -6.59281835e-02,
                         -8.34533423e-02,  -8.25842656e-03,  -1.26841262e-01,
                         -6.23577058e-01,  -7.21535087e-01,  -2.15898380e-01,
                         -2.27357045e-01,  -5.85016549e-01,  -2.30733112e-01,
                         -4.38008122e-02,  -7.35311985e-01,  -8.97241652e-01,
                         -1.85236871e-01,  -7.22088441e-02,  -7.19455779e-01,
                         -8.24358344e-01,  -2.36334354e-01,  -1.48453102e-01,
                         -6.57901824e-01,  -7.20461547e-01,  -5.26242554e-01,
                         -6.96492851e-01,  -7.16099441e-01,  -6.08628631e-01,
                         -7.90268302e-01,  -6.01273715e-01,  -1.02997385e-01,
                         -2.83847809e-01,  -7.70967603e-01,  -7.39656091e-01,
                         -5.46537280e-01,  -6.49664223e-01,  -7.44847953e-01,
                         -5.98462105e-01,  -6.47918284e-01,  -8.71446311e-01,
                         -5.19482434e-01,  -8.00250694e-02,  -4.22739953e-01,
                         -5.64525843e-01,  -1.07066907e-01,  -3.67189676e-01,
                         -9.58104670e-01,  -5.27012348e-01,   1.98170207e-02,
                         -3.94192457e-01,  -7.93754399e-01,  -6.15916371e-01,
                         -6.96853817e-01,  -8.76190960e-01,  -3.78962517e-01,
                         -6.23749904e-02,  -5.15659094e-01,  -5.11967957e-01,
                         -1.10571869e-01,  -5.38215280e-01,  -9.07872498e-01,
                         -3.14695954e-01,  -1.09229915e-01,  -6.33448124e-01,
                         -4.68220830e-01,   1.92332715e-01,  -3.11893243e-02,
                         -6.43987775e-01,  -4.22487974e-01,  -1.32330015e-01,
                         -6.56111121e-01,  -8.81220579e-01,  -3.18915874e-01,
                         -1.43811345e-01,  -5.20318091e-01,  -7.12442458e-01,
                         -7.54187703e-01,  -6.88868940e-01,  -2.65654981e-01,
                          1.11406177e-01,  -1.89565584e-01,  -8.05904925e-01,
                         -7.74641573e-01,  -2.70131081e-01,  -2.68123597e-01,
                         -6.18483603e-01,  -7.41604149e-01,  -7.98968554e-01,
                         -6.23564005e-01,  -1.47233501e-01,  -2.87724972e-01,
                         -8.87024820e-01,  -6.54091597e-01,  -1.20506309e-01,
                         -4.58057135e-01,  -6.78626418e-01,  -1.71649933e-01,
                         -3.03043813e-01,  -9.02499020e-01,  -5.91208160e-01,
                         -1.68729618e-01,  -4.85668719e-01,  -5.26900709e-01,
                         -2.23636106e-01,  -4.82754618e-01,  -9.11052227e-01,
                         -6.67068899e-01,  -3.18380520e-02,   9.00256913e-03,
                         -5.33303797e-01,  -5.56190252e-01,  -2.04359517e-01,
                         -4.02626902e-01,  -5.76706707e-01,  -1.93242326e-01,
                          7.16068521e-02,  -8.88913944e-02,  -4.76343960e-01,
                         -6.44317865e-01,  -2.94478297e-01,  -2.56405532e-01,
                         -8.07374120e-01,  -8.08026373e-01,  -2.37580225e-01,
                         -8.36067721e-02,  -2.11969808e-01,  -7.97179118e-02,
                          8.39178357e-03,  -3.67754489e-01,  -6.80807114e-01,
                         -3.46814007e-01,  -5.41942287e-03,  -8.77752304e-02,
                         -1.37243882e-01,  -3.99270058e-01,  -8.84832978e-01,
                         -6.95971310e-01,  -2.35740170e-01,  -4.13041651e-01,
                         -7.16041744e-01,  -7.63443232e-01,  -7.72130847e-01,
                         -5.00106633e-01,  -9.70350578e-02,  -1.90775484e-01,
                         -6.10001385e-01,  -7.58255661e-01,  -6.83893085e-01,
                         -7.64472485e-01,  -8.52755606e-01,  -5.53481340e-01,
                         -1.06174164e-01,  -8.18188116e-02,  -4.56725478e-01,
                         -7.45484948e-01,  -7.87434816e-01,  -7.45276272e-01,
                         -4.85282868e-01,  -3.34784053e-02,  -1.15418307e-01,
                         -6.61530674e-01,  -5.77172279e-01,  -1.85986996e-01,
                         -5.75233042e-01,  -9.48538721e-01,  -4.85302776e-01,
                         -2.54197419e-01,  -5.43103337e-01,  -4.00109410e-01,
                         -2.39622682e-01,  -6.95611715e-01,  -9.13034976e-01,
                         -6.84295237e-01,  -7.70364881e-01,  -7.90439427e-01,
                         -2.87125260e-01,  -1.69645742e-01,  -7.70027459e-01,
                         -9.63944435e-01,  -3.59625012e-01,  -9.40754563e-02,
                         -6.75378740e-01,  -1.00000000e+00,  -4.87549454e-01,
                         -4.13754992e-02,  -7.33524784e-02,  -9.63571966e-02,
                         -2.71140426e-01,  -8.09204400e-01,  -8.89375210e-01,
                         -2.97822148e-01,  -1.66822493e-01,  -6.85395420e-01,
                         -8.47465098e-01,  -6.90611124e-01,  -7.53546417e-01,
                         -7.36841083e-01,  -6.77957118e-01,  -8.13983858e-01,
                         -6.23567522e-01,  -2.28826791e-01,  -3.67108136e-01,
                         -7.12789476e-01,  -7.35017598e-01,  -6.90757155e-01,
                         -7.57423341e-01,  -7.92453349e-01,  -7.14962661e-01,
                         -6.50367141e-01,  -7.40747094e-01,  -6.54406369e-01,
                         -1.77919894e-01,   5.48502691e-02,  -3.37292761e-01,
                         -7.41548002e-01,  -7.20685124e-01,  -6.39142454e-01,
                         -7.01658130e-01,  -6.63084745e-01,  -6.73115909e-01,
                         -8.33973229e-01,  -5.96137822e-01,  -1.57161623e-01,
                         -3.46831679e-01,  -7.43581831e-01,  -6.83680296e-01,
                         -6.17536187e-01,  -7.44399190e-01,  -7.38472164e-01,
                         -6.75294697e-01,  -6.72129035e-01,  -6.55235648e-01,
                         -6.20962501e-01,  -6.41958952e-01,  -7.23363400e-01,
                         -5.06796479e-01,   1.72000788e-02,   6.66138763e-03,
                         -5.17457366e-01,  -4.98819619e-01,  -4.45306227e-02,
                          7.95029774e-02,   1.93866659e-02,  -1.50646091e-01,
                         -5.98775208e-01,  -8.02348554e-01,  -6.18121982e-01,
                         -6.26018703e-01,  -6.32710338e-01,  -2.58558095e-01,
                         -1.70530781e-01,  -6.37097239e-01,  -7.33261228e-01,
                         -2.07682475e-01,  -3.14696580e-02,  -5.22861481e-01,
                         -7.69060135e-01,  -3.29633951e-01,   7.48580620e-02,
                          2.27371156e-02,  -5.15196919e-02,   1.31811863e-02,
                          1.28883878e-02,   6.52624592e-02,   1.05863340e-01,
                         -2.31142536e-01,  -5.78486621e-01,  -3.20363730e-01,
                          1.00404657e-01,   1.21711165e-01,   5.80246747e-02,
                          5.04685827e-02,   5.58441272e-03,   1.41345471e-01,
                          9.72974151e-02,  -4.07998651e-01,  -4.94649440e-01,
                         -1.13520250e-02,   1.30573332e-01,   3.44593935e-02,
                          1.12012669e-01,   5.73929660e-02,  -4.18130644e-02,
                          6.52992874e-02,   1.21885404e-01,   1.50713595e-02,
                         -5.37272878e-02,   7.14714900e-02,   1.76540330e-01,
                         -1.10576591e-02,  -5.26330844e-02,   2.08828971e-01,
                          4.32804674e-02,  -3.89938772e-01,  -2.93398201e-01,
                          5.29449284e-02,   1.59465179e-01,   5.07834256e-02,
                         -2.62456566e-01,  -4.44800943e-01,  -1.83533326e-01,
                          1.28021643e-01,   1.77531391e-01,   3.76997814e-02,
                         -3.13273370e-01,  -6.61685050e-01,  -5.17274439e-01,
                          1.94172543e-02,   1.95294961e-01,  -1.92695022e-01,
                         -4.29738462e-01,  -1.73013210e-01,   1.07516944e-01,
                          1.76840723e-01,   1.71239749e-01,   6.76153898e-02,
                         -4.93875444e-02,   2.14033201e-02,   1.25546068e-01,
                          8.08129013e-02,   8.83943215e-02,   1.85221285e-01,
                          1.09892920e-01,   2.39765421e-02,   1.36640251e-01,
                         -1.76296930e-03,  -4.11095023e-01,  -3.25647771e-01,
                          1.07733466e-01,   9.35269743e-02,  -4.98957075e-02,
                          1.24077410e-01,   5.82895707e-03,  -4.00513351e-01,
                         -1.90420821e-01,   2.65003920e-01,  -4.93189581e-02,
                         -4.70662177e-01,  -1.79963961e-01,  -9.03949142e-02,
                         -4.85909522e-01,  -2.48110637e-01,   2.58148164e-01,
                         -8.29534307e-02,  -4.87475663e-01,  -1.79861173e-01,
                          1.10317126e-01,   1.44392490e-01,   8.50628242e-02,
                         -3.07635844e-01,  -4.66082722e-01,   2.02123988e-02,
                          1.65006787e-01,  -2.86050111e-01,  -5.12372613e-01,
                         -5.62433600e-01,  -6.20336592e-01,  -3.00845116e-01,
                         -1.26369903e-02,  -3.74638379e-01,  -7.51490235e-01,
                         -4.12443936e-01,   1.23262174e-01,   9.14574191e-02,
                         -3.09990615e-01,  -5.21142483e-01,  -5.76296628e-01,
                         -6.41273320e-01,  -4.21273023e-01,   6.35461360e-02,
                          1.37493595e-01,  -3.04512113e-01,  -6.14962995e-01,
                         -6.65725946e-01,  -5.83398700e-01,  -1.82596877e-01,
                         -2.53250450e-02,  -5.99385202e-01,  -7.78135121e-01,
                         -1.69920281e-01,  -8.83507058e-02,  -4.16290462e-01,
                         -1.93640649e-01,  -1.63711697e-01,  -5.34363389e-01,
                         -1.79775834e-01,   3.04488301e-01,  -2.30996653e-01,
                         -6.82393253e-01,  -1.42629534e-01,   2.37331018e-01,
                          1.55283129e-02,   4.01747823e-02,   7.43487403e-02,
                         -3.59980494e-01,  -4.30342406e-01,  -8.53498057e-02,
                         -3.34209591e-01,  -5.66204071e-01,   4.40363623e-02,
                          2.27967277e-01,  -4.23206776e-01,  -4.23984498e-01,
                          1.91720936e-03,  -3.43678296e-01,  -5.41530073e-01,
                          8.62275437e-02,   1.46860838e-01,  -5.30052900e-01,
                         -4.68167543e-01,   2.14391649e-02,  -3.57974529e-01,
                         -8.30356479e-01,  -3.59633565e-01,  -1.31122358e-02,
                         -4.10361141e-01,  -4.27198350e-01,   4.89785746e-02,
                          1.21728875e-01,  -4.26212586e-02,  -2.09884092e-01,
                         -6.12898827e-01,  -6.82635069e-01,  -1.52943343e-01,
                         -4.61368859e-02,  -6.27363145e-01,  -7.38552213e-01,
                         -1.51360720e-01,  -9.72312167e-02,  -5.81289351e-01,
                         -2.68922567e-01,   3.12911928e-01,  -1.40551507e-01,
                         -5.77013135e-01,  -2.00992733e-01,  -2.00629756e-01,
                         -4.67825800e-01,  -1.60461664e-01,  -1.21964842e-01,
                         -6.39656663e-01,  -7.44544208e-01,  -5.23618102e-01,
                         -5.46455681e-01,  -6.26927316e-01,  -6.09564006e-01,
                         -6.27574801e-01,  -6.75107360e-01,  -5.38403571e-01,
                         -1.07762054e-01,   1.62015423e-01,  -1.28662989e-01,
                         -5.25042832e-01,  -6.37275696e-01,  -6.69187188e-01,
                         -4.77640063e-01,   4.82538007e-02,   1.96342140e-01,
                         -2.95765042e-01,  -6.83443427e-01,  -6.15102291e-01,
                         -4.63681072e-01,  -5.53807557e-01,  -6.60253465e-01,
                         -2.48609543e-01,   2.36038655e-01,  -7.05656335e-02,
                         -4.72428679e-01,  -2.69996554e-01,  -2.38153607e-01,
                         -3.76317322e-01,  -1.16079502e-01,  -1.60607398e-01,
                         -6.80802763e-01,  -6.57908380e-01,  -9.92545635e-02,
                          1.47520199e-01,   2.36405544e-02,   5.66176279e-03,
                          3.92109267e-02,  -2.46827379e-01,  -4.73958999e-01,
                         -1.50957629e-01,   1.81803003e-01,   9.50652808e-02,
                         -9.31357779e-03,   2.56751459e-02,   4.09795791e-02,
                          4.50381711e-02,   4.61586043e-02,   4.05411571e-02,
                          2.17028372e-02,   1.22377770e-02,   8.48628059e-02,
                          1.17936872e-01,   2.12655440e-02,  -1.77889057e-02,
                          6.41579777e-02,   9.17607024e-02,   4.86365054e-03,
                         -1.32625587e-02,   8.96693021e-02,   5.72901256e-02,
                         -5.97678684e-02,   2.09367350e-02,   1.05935991e-01,
                          4.90889139e-02,   3.05229072e-02,  -1.71930175e-02,
                         -1.88288242e-02,   1.43731371e-01,   8.69987649e-04,
                         -4.13148999e-01,  -3.39168578e-01,   3.57393846e-02,
                          4.39341255e-02,   2.44896784e-02,   1.97565600e-01,
                         -9.28325206e-02,  -5.98930299e-01,  -3.03815544e-01,
                          2.53933102e-01,  -4.06910330e-02,  -5.09225130e-01,
                         -2.69629121e-01,   4.30415422e-02,  -1.72285885e-02,
                          1.55974303e-05,   1.15823552e-01,   4.45220657e-02,
                          4.14197939e-03,   1.45216331e-01,   1.05936155e-01,
                         -1.13836095e-01,  -2.10355315e-02,   1.56092241e-01,
                         -1.81942090e-01,  -5.29790223e-01,  -1.82621062e-01,
                          2.39141390e-01,  -4.90257628e-02,  -5.95225692e-01,
                         -6.95817709e-01,  -5.52516282e-01,  -5.58760941e-01,
                         -5.09008944e-01,  -2.47037008e-01,  -1.57474503e-02,
                          1.05236948e-01,   6.40326142e-02,  -3.15298498e-01,
                         -6.94791436e-01,  -5.59089601e-01,  -1.25967100e-01,
                          9.94273797e-02,  -4.42306884e-02,  -4.82026994e-01,
                         -7.50527561e-01,  -4.00685310e-01,   8.18982199e-02,
                          9.42469537e-02,  -1.13440957e-02,   5.94707988e-02,
                          3.82654704e-02,   1.09828683e-02,   1.03662536e-01,
                         -8.65125135e-02,  -5.68183541e-01,  -6.78037643e-01,
                         -2.95147955e-01,  -4.45879325e-02,  -2.93143820e-02,
                          8.63434151e-02,  -6.45536184e-02,  -6.20068252e-01,
                         -7.18694806e-01,  -2.46817365e-01,   2.55006179e-02,
                          2.46964470e-02,  -2.45540328e-02,  -5.33644930e-02,
                          9.31559056e-02,   7.72887990e-02,  -3.25557202e-01,
                         -4.60345298e-01,  -1.07066438e-01,   1.05559587e-01,
                         -1.90624315e-02,  -6.07263520e-02,   6.31250292e-02,
                         -5.01415087e-03,  -8.02609473e-02,   1.34948328e-01,
                          3.50080300e-05,  -4.99061853e-01,  -3.96589845e-01,
                         -1.16885439e-01,  -3.81386429e-01,  -3.71729255e-01,
                          6.39422461e-02,   1.04011729e-01,  -8.43109190e-02,
                         -2.51416355e-01,  -6.12716138e-01,  -6.98630035e-01,
                         -1.92288384e-01,   1.72975212e-01,  -9.63063091e-02,
                         -5.46762049e-01,  -7.08331466e-01,  -6.12005651e-01,
                         -4.99865443e-01,  -6.18491173e-01,  -7.62356579e-01,
                         -4.12174910e-01,  -1.22033963e-02,  -3.33709300e-01,
                         -7.65547514e-01,  -6.30492866e-01,  -4.67734396e-01,
                         -5.99293828e-01,  -7.27069259e-01,  -7.04891622e-01,
                         -5.53636849e-01,  -5.12514830e-01,  -6.63723528e-01,
                         -6.69237673e-01,  -5.72927594e-01,  -6.39823079e-01,
                         -6.81161404e-01,  -6.00067496e-01,  -5.64314246e-01,
                         -5.66394210e-01,  -5.66058099e-01,  -5.93318403e-01,
                         -6.36542201e-01,  -6.51605189e-01,  -6.08527720e-01,
                         -5.98542571e-01,  -6.55175507e-01,  -6.18753254e-01,
                         -5.24182379e-01,  -5.80736399e-01,  -7.07537949e-01,
                         -6.84002936e-01,  -5.62000155e-01,  -5.46807170e-01,
                         -6.40397251e-01,  -6.72664762e-01,  -6.25338554e-01,
                         -6.11501396e-01,  -6.23958111e-01,  -6.03841841e-01,
                         -5.88828743e-01,  -6.05175257e-01,  -5.92356324e-01,
                         -5.60057580e-01,  -6.09341502e-01,  -6.88071728e-01,
                         -6.54237926e-01,  -5.75604737e-01,  -5.87217569e-01,
                         -6.41948223e-01,  -6.39930665e-01,  -6.00508809e-01,
                         -6.25767708e-01,  -6.93362474e-01,  -6.58223033e-01,
                         -5.83055973e-01,  -6.17774606e-01,  -6.37466073e-01,
                         -5.57104409e-01,  -5.51470935e-01,  -6.48040414e-01,
                         -6.91412508e-01,  -6.63078427e-01,  -6.50468647e-01,
                         -6.72767401e-01,  -6.57961488e-01,  -5.94341755e-01,
                         -5.94432950e-01,  -6.41444385e-01,  -6.33904576e-01,
                         -6.56535447e-01,  -6.86383605e-01,  -5.99114299e-01,
                         -6.10841095e-01,  -7.05163062e-01,  -4.47715819e-01,
                         -1.35133386e-01,  -3.54381859e-01,  -6.77105129e-01,
                         -6.45267367e-01,  -6.02913558e-01,  -6.70304060e-01,
                         -6.64944112e-01,  -6.67993724e-01,  -6.91080093e-01,
                         -6.67280614e-01,  -6.60343230e-01,  -6.56457126e-01,
                         -6.54182017e-01,  -6.93095744e-01,  -6.96752429e-01,
                         -6.71315551e-01,  -6.64081573e-01,  -6.11260593e-01,
                         -5.88420749e-01,  -6.78438842e-01,  -7.03973949e-01,
                         -6.05735302e-01,  -5.68872631e-01,  -6.52462721e-01,
                         -7.69956827e-01,  -7.75523484e-01,  -6.15031540e-01,
                         -5.98424315e-01,  -7.67647743e-01,  -5.51783979e-01,
                         -1.12853020e-01,  -2.73098260e-01,  -7.12526023e-01,
                         -7.26806462e-01,  -6.57440841e-01,  -6.95365250e-01,
                         -6.01541638e-01,  -6.57913744e-01,  -7.49662042e-01,
                         -3.52500349e-01,  -8.72408599e-02,  -5.87546587e-01,
                         -8.83508325e-01,  -3.72847497e-01,  -1.39031440e-01,
                         -5.38361669e-01,  -4.77207690e-01,   2.86649428e-02,
                         -6.75178096e-02,  -5.41099429e-01,  -6.19655609e-01,
                         -5.56852400e-01,  -7.42999077e-01,  -8.21435094e-01,
                         -4.26101327e-01,  -9.66978818e-02,  -4.76655662e-01,
                         -8.28974366e-01,  -4.26727712e-01,  -1.70687541e-01,
                         -5.27075887e-01,  -7.17949986e-01,  -6.72692418e-01,
                         -6.31955445e-01,  -2.77834356e-01,   9.76586863e-02,
                         -1.26194343e-01,  -6.42667294e-01,  -7.91706681e-01,
                         -4.87258404e-01,  -7.37794563e-02,   5.57655469e-02,
                         -3.05529475e-01,  -7.91135848e-01,  -7.37219512e-01,
                         -2.90997922e-01,  -5.31254858e-02,   2.02681869e-02,
                         -7.72459656e-02,  -4.52801526e-01,  -4.65234369e-01,
                         -1.27048373e-01,  -4.24211204e-01,  -9.51370358e-01,
                         -5.64694345e-01,   1.40163647e-02,  -3.95666361e-01,
                         -9.40687537e-01,  -5.12428045e-01,  -2.56597996e-02,
                         -3.71004730e-01,  -6.24417484e-01,  -2.25961566e-01,
                          6.01637177e-02,  -5.89402951e-02,  -1.41321898e-01,
                         -2.08166670e-02,  -4.19307314e-02,  -4.20794189e-01,
                         -5.53736925e-01,  -1.28684103e-01,   6.98017925e-02,
                         -1.06320329e-01,  -5.80703914e-02,   3.42748570e-03,
                         -1.36009544e-01,  -9.47457626e-02,   3.85433398e-02,
                         -2.85816807e-02,  -1.06840454e-01,  -1.28690817e-03,
                         -8.65573809e-03,  -4.95870620e-01,  -8.98273468e-01,
                         -4.72343475e-01,  -2.70825401e-02,  -4.14484084e-01,
                         -6.30133212e-01,  -6.82619363e-02,   1.01824388e-01,
                         -4.41956401e-01,  -5.50823390e-01,  -1.09002113e-01,
                          5.05828951e-03,  -1.11303598e-01,   2.69715190e-02,
                          2.61147898e-02,  -4.40095216e-01,  -8.19276810e-01,
                         -6.25291646e-01,  -1.96647048e-01,   1.91376805e-02,
                          9.28504691e-02,  -6.54540658e-02,  -5.29972792e-01,
                         -5.18042266e-01,   1.02814406e-01,   1.36153579e-01,
                         -4.61637646e-01,  -5.15905678e-01,  -4.33041491e-02,
                          6.30717799e-02,  -3.79383862e-01,  -7.68802583e-01,
                         -5.92307925e-01,  -1.24790184e-01,   9.91576836e-02,
                         -1.21232137e-01,  -6.23825192e-01,  -6.94941819e-01,
                         -2.29865164e-01,  -2.05943227e-01,  -4.87156987e-01,
                         -2.56822586e-01,  -1.44233987e-01,  -5.59059024e-01,
                         -7.50350416e-01,  -6.09963953e-01,  -3.98656458e-01,
                         -1.67982042e-01,  -3.39187413e-01,  -7.37185895e-01,
                         -5.18432915e-01,  -3.58401574e-02,  -2.52878666e-01,
                         -7.08012104e-01,  -6.14913106e-01,  -5.33701360e-01,
                         -7.44599700e-01,  -4.85676914e-01,  -2.37644352e-02,
                         -2.38928810e-01,  -6.87409341e-01,  -6.82188749e-01,
                         -4.91657257e-01,  -5.60976326e-01,  -7.75155962e-01,
                         -5.55494606e-01,  -8.14229026e-02,  -2.36847118e-01,
                         -6.54688597e-01,  -5.72655380e-01,  -5.15302420e-01,
                         -6.93280995e-01,  -6.34579659e-01,  -5.49385846e-01,
                         -6.13408923e-01,  -5.85620344e-01,  -5.33204973e-01,
                         -5.78520715e-01,  -6.68451726e-01,  -6.32907510e-01,
                         -4.63096261e-01,  -5.61931014e-01,  -7.51376092e-01,
                         -4.14372057e-01,  -6.31162599e-02,  -3.45743179e-01,
                         -6.73133850e-01,  -6.29435599e-01,  -5.80188870e-01,
                         -5.98951042e-01,  -5.59678674e-01,  -5.81152081e-01,
                         -6.34854496e-01,  -5.73873341e-01,  -5.32890797e-01,
                         -6.19091928e-01,  -6.55351520e-01,  -6.25247836e-01,
                         -6.47757471e-01,  -6.21146381e-01,  -5.39798141e-01,
                         -5.48078537e-01,  -5.73822141e-01,  -5.53451419e-01,
                         -5.86367965e-01,  -6.39605939e-01,  -6.05551720e-01,
                         -5.59806943e-01,  -6.21036589e-01,  -6.55835927e-01,
                         -5.43424070e-01,  -5.23773849e-01,  -6.60541177e-01,
                         -6.47224903e-01,  -5.44395089e-01,  -6.14590883e-01,
                         -6.80392921e-01,  -5.78234553e-01,  -5.32422543e-01,
                         -6.37122512e-01,  -6.58247411e-01,  -5.48835635e-01,
                         -5.57640314e-01,  -6.45278215e-01,  -5.83892047e-01,
                         -5.29192448e-01,  -6.18777215e-01,  -6.50979757e-01,
                         -5.87491930e-01,  -5.62210202e-01,  -5.86531222e-01,
                         -6.13118291e-01,  -5.97184360e-01,  -5.68113327e-01,
                         -5.89037955e-01,  -6.37565434e-01,  -6.62853301e-01,
                         -6.06413007e-01,  -5.43490231e-01,  -6.29079878e-01,
                         -7.01323926e-01,  -6.03873432e-01,  -5.37675858e-01,
                         -5.83185494e-01,  -6.44055128e-01,  -6.78249836e-01,
                         -6.34829819e-01,  -5.87119102e-01,  -6.08458221e-01,
                         -6.15689754e-01,  -5.93612790e-01,  -5.58124304e-01,
                         -5.71734309e-01,  -6.47818029e-01,  -5.92488825e-01,
                         -5.60171425e-01,  -6.76406860e-01,  -4.43542063e-01,
                         -9.72234756e-02,  -3.82918179e-01,  -7.50084937e-01,
                         -5.97045839e-01,  -4.81973052e-01,  -6.19814396e-01,
                         -6.58847094e-01,  -6.14253879e-01,  -6.35571301e-01,
                         -6.72662377e-01,  -6.29257381e-01,  -5.68623006e-01,
                         -5.76885581e-01,  -6.19451642e-01,  -7.28237331e-01,
                         -6.49496794e-01,  -2.03550726e-01,  -1.82361692e-01,
                         -7.16722608e-01,  -6.25117660e-01,  -1.72417108e-02,
                          1.01006828e-01,   3.20493244e-03,   2.57580858e-02,
                         -5.91530912e-02,  -5.68341427e-02,   3.35416645e-02,
                         -2.37173494e-02,  -3.49098705e-02,   2.86420956e-02,
                          1.19812610e-02,   1.35413278e-02,   1.51249422e-02,
                         -4.20468710e-02,  -1.45948492e-02,   7.53840208e-02,
                          4.26289253e-02,  -5.25374822e-02,  -1.10358140e-02,
                          6.69323877e-02,  -4.26096097e-03,  -6.15529232e-02,
                         -2.66786059e-03,   3.89224314e-03,  -1.01219174e-02,
                          3.78797762e-02,   2.97237076e-02,  -2.78211143e-02,
                         -1.95235331e-02,   3.89132500e-02,   4.73931432e-02,
                         -2.19495967e-02,  -4.79204878e-02,  -5.52752870e-04,
                          1.22426664e-02,   1.82137340e-02,   1.14804711e-02,
                         -6.40180185e-02,  -4.24461253e-02,   8.36229250e-02,
                          5.93323521e-02,  -6.19007908e-02,  -3.93452644e-02,
                          5.19521460e-02,   2.00185347e-02,  -2.29250155e-02,
                          4.43244390e-02,   5.02266502e-03,  -6.36100620e-02,
                          9.84195769e-02,  -2.48672459e-02,  -5.38790047e-01,
                         -4.33979094e-01,   1.00226045e-01,  -1.22350715e-02,
                         -2.24036723e-01,   6.36372045e-02,  -4.61671092e-02,
                         -5.98962426e-01,  -4.74274039e-01,   1.65007532e-01,
                          8.61227959e-02,  -6.67412460e-01,  -8.72166872e-01,
                         -5.31505048e-01,  -6.12804592e-01,  -7.09866643e-01,
                         -2.70378411e-01,  -1.80187151e-01,  -4.94375646e-01,
                         -3.32922846e-01,  -1.82339922e-01,  -5.68826020e-01,
                         -7.94463038e-01,  -6.52087092e-01,  -5.50458729e-01,
                         -5.72392285e-01,  -6.99721754e-01,  -7.57430613e-01,
                         -6.17990077e-01,  -5.82430840e-01,  -6.84825420e-01,
                         -6.38416946e-01,  -5.52073538e-01,  -6.39929295e-01,
                         -7.56769776e-01,  -6.74473941e-01,  -5.35129011e-01,
                         -6.84334695e-01,  -8.21349680e-01,  -4.05356288e-01,
                         -4.57901880e-02,  -4.84529912e-01,  -8.77135456e-01,
                         -4.21118677e-01,  -2.67259516e-02,  -4.05395120e-01,
                         -7.97326505e-01,  -7.29773760e-01,  -6.40801251e-01,
                         -6.62048221e-01,  -6.55006707e-01,  -6.80300415e-01,
                         -6.73845291e-01,  -6.16677165e-01,  -6.33180678e-01,
                         -6.40166998e-01,  -6.25983834e-01,  -6.78469062e-01,
                         -6.89073086e-01,  -6.72447443e-01,  -6.12706780e-01,
                         -3.36095214e-01,  -1.83741316e-01,  -4.99678224e-01,
                         -8.20120215e-01,  -7.53366530e-01,  -5.59910715e-01,
                         -5.97914994e-01,  -7.91637123e-01,  -5.79122066e-01,
                         -5.13914973e-02,  -2.10949838e-01,  -8.56023669e-01,
                         -6.95747912e-01,  -5.31241260e-02,  -2.12040722e-01,
                         -7.99207807e-01,  -6.50234520e-01,  -1.07802816e-01,
                         -2.50908315e-01,  -7.44397521e-01,  -6.98017299e-01,
                         -5.73977709e-01,  -7.42014706e-01,  -5.01149774e-01,
                         -1.86906323e-01,  -4.74466056e-01,  -4.37901080e-01,
                          1.41909141e-02,  -4.00879830e-01,  -9.77356851e-01,
                         -4.58467722e-01,  -3.36919427e-02,  -4.42988485e-01,
                         -4.50456828e-01,  -1.29497930e-01,  -5.25384367e-01,
                         -8.62269044e-01,  -3.58947843e-01,  -9.30703655e-02,
                         -4.72866893e-01,  -4.02493149e-01,   9.50300470e-02,
                         -6.87600225e-02,  -5.74951589e-01,  -4.02112067e-01,
                         -1.19796589e-01,  -5.61025918e-01,  -7.94228315e-01,
                         -2.53848761e-01,  -1.37731835e-01,  -5.44086516e-01,
                         -3.38814259e-01,  -1.17347367e-01,  -6.72962010e-01,
                         -8.26023340e-01,  -1.94633007e-01,  -7.27391019e-02,
                         -5.64117491e-01,  -7.65773952e-01,  -6.84451044e-01,
                         -6.63751721e-01,  -6.62008286e-01,  -6.60055757e-01,
                         -6.62680447e-01,  -6.26111925e-01,  -5.53875029e-01,
                         -3.43511492e-01,  -4.38165143e-02,  -9.07236785e-02,
                         -4.69919801e-01,  -4.68157470e-01,  -1.07602421e-02,
                          8.72112587e-02,  -3.98687214e-01,  -7.61687219e-01,
                         -6.71979368e-01,  -6.34667993e-01,  -7.38501012e-01,
                         -4.47385103e-01,  -1.48043633e-01,  -3.99200469e-01,
                         -3.88499796e-01,  -7.91517124e-02,  -5.27277827e-01,
                         -8.94818187e-01,  -3.03690970e-01,  -1.19065218e-01,
                         -5.35363674e-01,  -3.47681999e-01,  -1.18781209e-01,
                         -5.34736574e-01,  -7.98515022e-01,  -6.28646553e-01,
                         -5.53582847e-01,  -7.12178707e-01,  -7.03687787e-01,
                         -3.04750532e-01,  -1.14388771e-01,  -4.38918293e-01,
                         -6.72250867e-01,  -7.07824409e-01,  -6.44781470e-01,
                         -2.35701591e-01,  -1.33903340e-01,  -6.95417345e-01,
                         -7.38478839e-01,  -1.48518160e-01,  -1.75500035e-01,
                         -6.68578386e-01,  -7.67320216e-01,  -6.37610972e-01,
                         -4.22741473e-01,  -2.13180725e-02,   6.79525509e-02,
                         -3.23740959e-01,  -6.43499553e-01,  -7.45547414e-01,
                         -6.88962400e-01,  -3.43379736e-01,  -1.46025896e-01,
                         -4.62320507e-01,  -7.12905347e-01,  -5.90570807e-01,
                         -5.23552895e-01,  -6.44746721e-01,  -7.44304299e-01,
                         -6.87523365e-01,  -5.53884208e-01,  -5.97240269e-01,
                         -6.96540236e-01,  -6.08818233e-01,  -5.83916605e-01,
                         -6.62413895e-01,  -6.39634371e-01,  -6.95699692e-01,
                         -6.47450924e-01,  -2.43145064e-01,  -1.72659680e-01,
                         -5.83115935e-01,  -6.59108460e-01,  -5.32595515e-01,
                         -6.61031485e-01,  -6.86409175e-01,  -6.42421067e-01,
                         -7.01277018e-01,  -4.33647603e-01,  -8.65318552e-02,
                         -2.92678118e-01,  -7.11479425e-01,  -7.84395337e-01,
                         -5.77982783e-01,  -5.32284915e-01,  -7.45796502e-01,
                         -5.91832876e-01,  -1.51693746e-01,  -2.89775759e-01,
                         -5.13978660e-01,  -1.98432893e-01,  -2.39104718e-01,
                         -7.10726321e-01,  -7.29386508e-01,  -5.38504243e-01,
                         -5.31525552e-01,  -5.75504780e-01,  -6.83537960e-01,
                         -6.54006481e-01,  -5.58140099e-01,  -7.21921027e-01,
                         -6.33523643e-01,  -1.68838173e-01,  -1.81234404e-01,
                         -6.12667263e-01,  -7.31641948e-01,  -6.09883547e-01,
                         -6.00537419e-01,  -6.48476601e-01,  -6.34703279e-01,
                         -6.46431148e-01,  -6.78419650e-01,  -5.76508522e-01,
                         -5.44669390e-01,  -7.14889348e-01,  -6.00413501e-01,
                         -1.36200055e-01,   6.02439083e-02,  -7.94236064e-02,
                         -5.10522388e-02,   1.19693480e-01,  -1.94049627e-01,
                         -8.00491631e-01,  -6.45890057e-01,  -9.16968435e-02,
                         -2.79913753e-01,  -5.17005682e-01,  -1.51481554e-01,
                         -2.05213517e-01,  -6.86228156e-01,  -6.72719181e-01,
                         -5.50234795e-01,  -7.18529224e-01,  -5.52038193e-01,
                          2.38968711e-02,   1.57603785e-01,  -3.86724114e-01,
                         -6.26861095e-01,  -1.42474949e-01,   1.35616109e-01,
                         -3.84976454e-02,  -2.49899141e-02,   6.92034364e-02,
                          2.25262828e-02,   3.93135063e-02,   1.45778302e-02,
                         -7.38746822e-02,  -5.96910715e-02,  -3.29919830e-02,
                         -2.03970931e-02,  -1.39498487e-02,   2.78858338e-02,
                          1.83005542e-01,   2.07179841e-02,  -5.07189929e-01,
                         -5.31214476e-01,  -7.20900297e-02,   5.57255447e-02,
                         -1.79525800e-02,   4.89962697e-02,   4.72412631e-02,
                          1.14563908e-02,   3.68179083e-02,  -3.45786549e-02,
                         -9.48005095e-02,   1.33322198e-02,   8.13340098e-02,
                         -9.80156939e-03,  -4.15905304e-02,   4.86982688e-02,
                          4.43757027e-02,  -3.96465249e-02,   1.03013031e-03,
                          7.67624527e-02,   3.12613025e-02,  -3.24256569e-02,
                         -4.46911603e-02,  -5.67427613e-02,  -2.77066771e-02,
                          5.96220717e-02,   6.90874234e-02,  -4.18061279e-02,
                         -8.51565674e-02,   1.56498216e-02,   6.66908473e-02,
                          1.53787737e-03,  -1.80489961e-02,   2.43229233e-02,
                          1.55809242e-02,  -2.18656845e-02,  -3.07063982e-02,
                         -2.10614204e-02,   3.07774600e-02,   5.71310893e-02,
                         -6.79884702e-02,  -1.08899437e-01,   1.13080397e-01,
                          5.37262522e-02,  -4.43797678e-01,  -4.67253119e-01,
                          7.40303993e-02,   5.76936714e-02,  -4.87315327e-01,
                         -4.55526799e-01,   1.81398839e-02,   6.75887242e-02,
                         -6.18411675e-02,   8.99603367e-02,  -1.39118209e-02,
                         -5.09364724e-01,  -4.62999552e-01,   1.19495854e-01,
                          5.49238808e-02,  -5.22407293e-01,  -4.11534011e-01,
                         -2.69807223e-02,  -4.45656091e-01,  -8.51810515e-01,
                         -3.63735288e-01,  -8.12193900e-02,  -4.61023629e-01,
                         -3.61835063e-01,  -7.24594221e-02,  -5.95516741e-01,
                         -8.66800070e-01,  -1.97053760e-01,  -4.78029996e-02,
                         -5.51216006e-01,  -3.33248943e-01,   6.40546670e-03,
                         -5.65133214e-01,  -8.52673829e-01,  -2.31020138e-01,
                         -8.60475302e-02,  -5.28562844e-01,  -2.85375059e-01,
                          1.80988982e-01,  -1.93039432e-01,  -5.35541534e-01,
                         -1.61121562e-01,  -1.56192526e-01,  -5.82738459e-01,
                         -2.25889355e-01,   2.90527672e-01,  -2.34089613e-01,
                         -6.85826302e-01,  -1.93754077e-01,  -1.12655148e-01,
                         -7.45418906e-01,  -6.90952897e-01,  -1.25444546e-01,
                         -2.54893422e-01,  -6.64169133e-01,  -6.01458251e-01,
                         -5.37672102e-01,  -5.19119859e-01,  -3.74216288e-02,
                          1.80982128e-01,  -3.83465856e-01,  -5.22198498e-01,
                         -3.97292450e-02,  -3.03843617e-01,  -9.17942703e-01,
                         -5.63900828e-01,  -3.18911560e-02,  -3.43860507e-01,
                         -6.98172927e-01,  -5.78573167e-01,  -5.94787359e-01,
                         -7.24460721e-01,  -5.98945260e-01,  -6.12520397e-01,
                         -7.16090977e-01,  -3.08068275e-01,   2.55546090e-03,
                         -4.53481138e-01,  -7.87269294e-01,  -5.79853892e-01,
                         -5.74687719e-01,  -7.06294537e-01,  -4.18317437e-01,
                          3.62946056e-02,   5.11398166e-02,  -4.54884320e-01,
                         -7.53705502e-01,  -4.05893892e-01,  -7.82352239e-02,
                         -5.60503118e-02,   3.98334637e-02,  -1.22186705e-01,
                         -5.71303725e-01,  -3.61822724e-01,   2.42685989e-01,
                         -1.90713629e-02,  -6.28435731e-01,  -3.42739195e-01,
                          1.92614156e-03,  -5.37230551e-01,  -8.12520623e-01,
                         -3.08652550e-01,  -2.51189675e-02,   2.52586845e-02,
                          9.57547352e-02,  -2.70518929e-01,  -5.70474148e-01,
                         -2.68781185e-01,  -2.13120013e-01,  -6.77884221e-01,
                         -7.40026951e-01,  -1.45915344e-01,   2.37771839e-01,
                         -1.65662766e-01,  -6.29722238e-01,  -3.71944368e-01,
                          7.40196928e-02,   9.98739898e-02,  -1.31778957e-04,
                          4.19927426e-02,   8.62812996e-02,  -7.57160708e-02,
                         -4.07349169e-01,  -6.08480155e-01,  -6.92219496e-01,
                         -7.25624144e-01,  -3.43911588e-01,   1.67463630e-01,
                         -6.03914633e-02,  -5.65896809e-01,  -3.05257559e-01,
                          1.30176693e-01,  -4.27906998e-02,  -8.41617510e-02,
                          1.56842858e-01,  -1.58190012e-01,  -5.11438906e-01,
                         -2.60879666e-01,  -2.49848604e-01,  -5.20400703e-01,
                         -2.03823388e-01,   1.93591103e-01,  -1.52915657e-01,
                         -7.14254916e-01,  -7.06972897e-01,  -2.90477753e-01,
                         -2.39979476e-02,   7.85686001e-02,   7.87070915e-02,
                         -2.63855547e-01,  -5.04010975e-01,  -1.76182032e-01,
                          6.94435015e-02,  -3.89669053e-02,  -5.87045262e-03,
                          5.74923456e-02,  -2.86410395e-02,  -2.28175465e-02,
                          2.29589473e-02,   1.04236491e-02,   2.42662802e-02,
                          3.40379179e-02,   2.09819917e-02,  -4.12484631e-03,
                         -2.47081369e-02,   1.22663286e-02,   4.59250510e-02,
                          4.52726558e-02,   5.31410836e-02,   1.11581068e-02,
                         -5.96632622e-02,  -5.53565547e-02,  -1.39075695e-02,
                          4.90067480e-03,   2.06645690e-02,   2.84780879e-02,
                          2.53595002e-02,   5.04423715e-02,   3.78761068e-02,
                         -5.17298244e-02,  -1.26436763e-02,   3.64803746e-02,
                         -2.79808342e-01,  -4.92769718e-01,  -1.25519305e-01,
                          1.22248501e-01,  -6.97710589e-02,  -8.40325207e-02,
                          8.48367959e-02,   7.03447536e-02,  -7.15082092e-03,
                         -3.82202864e-03,   3.69140208e-02,   2.39586867e-02,
                         -3.70549299e-02,   2.12585982e-02,   1.08104140e-01,
                          2.06037462e-02,  -7.85665438e-02,  -5.04334196e-02,
                         -1.11232344e-02,  -8.20472930e-03,   1.37040718e-02,
                          4.74603251e-02,   7.75163015e-03,  -4.10956554e-02,
                          3.53519693e-02,   8.97987932e-02,   2.64382809e-02,
                         -3.25976894e-03,  -7.08957016e-03,  -1.91994123e-02,
                         -6.87019248e-03,  -2.59347335e-02,   1.57544184e-02,
                          6.23287633e-02,  -2.17078209e-01,  -6.04461670e-01,
                         -6.22597992e-01,  -5.07443547e-01,  -6.14507437e-01,
                         -6.15733922e-01,  -2.43837744e-01,   3.36008035e-02,
                         -3.19674909e-02,   1.75672099e-02,   1.05372585e-01,
                         -2.40042865e-01,  -5.11454225e-01,  -2.12987766e-01,
                          5.60459644e-02,  -1.39705129e-02,  -1.44060291e-02,
                          5.98052591e-02,  -1.06960554e-02,  -5.96491508e-02,
                          2.01281123e-02,   5.44653609e-02,   2.38468628e-02,
                          3.04014497e-02,   1.47571126e-02,  -2.12552752e-02,
                          7.58736115e-03,   2.96712853e-02,   1.86297670e-02,
                          2.88122036e-02,   2.20657885e-02,   4.83452436e-03,
                         -8.63919035e-03,  -2.04644650e-02,   2.07804460e-02,
                          4.41024490e-02,   2.40906440e-02,   2.59050969e-02,
                         -2.66057476e-02,  -1.96341462e-02,   5.88593632e-02,
                         -1.93385661e-01,  -4.87621039e-01,  -2.32443541e-01,
                          6.58047050e-02,  -3.28839906e-02,  -7.72334263e-02,
                          4.28796224e-02,   8.39148834e-02,   3.76626030e-02,
                         -4.09418531e-02,  -5.60425175e-03,   8.16993415e-02,
                         -1.87622048e-02,  -3.33609618e-02,   1.10054381e-01,
                         -1.57021716e-01,  -5.69556713e-01,  -3.36512804e-01,
                          8.48314911e-02,   4.04730737e-02,   1.89295243e-02,
                          1.16712406e-01,  -2.38657936e-01,  -5.51671624e-01,
                         -1.58725873e-01,   1.66937381e-01,  -2.04354674e-01,
                         -6.13827109e-01,  -6.25658154e-01,  -5.91707110e-01,
                         -6.56198800e-01,  -6.39162064e-01,  -5.84408104e-01,
                         -6.34923100e-01,  -6.85286105e-01,  -6.34252548e-01,
                         -5.99452794e-01,  -6.15422845e-01,  -6.04598880e-01,
                         -5.97087681e-01,  -6.29940093e-01,  -6.71806097e-01,
                         -6.79066300e-01,  -6.27282739e-01,  -5.80455840e-01,
                         -5.86679757e-01,  -5.87772131e-01,  -5.79352021e-01,
                         -6.16616964e-01,  -6.70707822e-01,  -6.71693563e-01,
                         -6.35023475e-01,  -6.30665541e-01,  -6.46341860e-01,
                         -6.39493525e-01,  -6.35221601e-01,  -6.31381273e-01,
                         -6.00410581e-01,  -5.76944768e-01,  -6.24210417e-01,
                         -7.11678922e-01,  -6.87955260e-01,  -6.24553800e-01,
                         -6.96494997e-01,  -5.79158902e-01,  -1.83380917e-01,
                         -1.82910413e-01,  -5.77505350e-01,  -6.87869132e-01,
                         -6.02840185e-01,  -6.20893836e-01,  -6.18315756e-01,
                         -6.36073828e-01,  -6.55137360e-01,  -5.74721813e-01,
                         -6.00497603e-01,  -7.12067544e-01,  -6.66744947e-01,
                         -5.68944633e-01,  -5.84837198e-01,  -6.63882971e-01,
                         -7.03256607e-01,  -6.69107080e-01,  -6.20288789e-01,
                         -5.80313087e-01,  -5.90617776e-01,  -6.87520742e-01,
                         -6.70459569e-01,  -5.07377684e-01,  -5.24172723e-01,
                         -7.10429966e-01,  -7.42504299e-01,  -6.31987751e-01,
                         -5.94581902e-01,  -6.23753130e-01,  -6.01559401e-01,
                         -5.86766660e-01,  -6.59216285e-01,  -7.06509292e-01,
                         -6.80206239e-01,  -6.43548012e-01,  -5.85284173e-01,
                         -5.55440128e-01,  -6.10219479e-01,  -6.65600538e-01,
                         -6.53116047e-01,  -5.97612858e-01,  -6.03915930e-01,
                         -6.48301601e-01,  -5.93265653e-01,  -6.19012356e-01,
                         -7.44387209e-01,  -6.42536879e-01,  -6.03448927e-01,
                         -7.48791158e-01,  -4.29774404e-01,  -4.70808595e-02,
                         -3.21873665e-01,  -4.50161189e-01,  -1.70928270e-01,
                         -3.76028329e-01,  -7.58598328e-01,  -6.73768282e-01,
                         -5.78970194e-01,  -6.47716701e-01,  -6.06642663e-01,
                         -6.08531058e-01,  -6.87613308e-01,  -6.48827612e-01,
                         -5.84653318e-01,  -6.31737411e-01,  -7.00152099e-01,
                         -6.63080573e-01,  -5.88122308e-01,  -6.27964556e-01,
                         -6.85698152e-01,  -6.29916966e-01,  -6.01201057e-01,
                         -6.46967173e-01,  -6.48681104e-01,  -6.41372800e-01,
                         -6.42954350e-01,  -5.94162107e-01,  -5.62544525e-01,
                         -5.93714178e-01,  -6.70212448e-01,  -7.35966265e-01,
                         -6.51196718e-01,  -5.56396067e-01,  -6.39717281e-01,
                         -6.10995889e-01,  -5.15619695e-01,  -7.05736637e-01,
                         -6.55983746e-01,  -1.92000985e-01,  -2.44732156e-01,
                         -5.49261212e-01,  -2.29570270e-01,  -1.61710128e-01,
                         -7.31294692e-01,  -6.26797080e-01,  -8.07060897e-02,
                         -2.95024306e-01,  -5.09427726e-01,  -1.27567366e-01,
                         -2.54479378e-01,  -8.11658502e-01,  -6.02136254e-01,
                         -8.84229466e-02,  -2.95212120e-01,  -6.88352108e-01,
                         -6.05634928e-01,  -5.72192371e-01,  -7.82181382e-01,
                         -5.25126100e-01,  -1.17394011e-02,  -2.56931692e-01,
                         -7.96840072e-01,  -5.17376840e-01,  -5.40457219e-02,
                         -3.46834809e-01,  -7.50818610e-01,  -6.68375134e-01,
                         -5.43421865e-01,  -6.08324468e-01,  -6.40382230e-01,
                         -6.18108451e-01,  -6.52893364e-01,  -6.78457737e-01,
                         -6.07101321e-01,  -6.17864728e-01,  -7.26059914e-01,
                         -4.94898915e-01,   1.01766912e-02,   7.14419559e-02,
                         -3.82149607e-01,  -7.11164355e-01,  -5.81888318e-01,
                         -1.57083422e-01,   1.13903664e-01,  -1.15394920e-01,
                         -5.51500678e-01,  -6.98829830e-01,  -6.27942801e-01,
                         -6.23678684e-01,  -6.41144216e-01,  -6.10225856e-01,
                         -6.51420534e-01,  -7.32437968e-01,  -6.84515178e-01,
                         -5.82869411e-01,  -5.77568114e-01,  -5.81449568e-01,
                         -5.82122147e-01,  -6.97454631e-01,  -6.63318932e-01,
                         -1.98007688e-01,   1.97276711e-01,  -8.44661221e-02,
                         -6.76256835e-01,  -7.80761123e-01,  -3.39060605e-01,
                          3.02793663e-02,   8.44935179e-02,   6.26774952e-02,
                         -2.17717901e-01,  -7.71543324e-01,  -7.37791002e-01,
                         -1.84301406e-01,  -2.34105751e-01,  -5.22410929e-01,
                         -1.57269686e-01,   1.27701893e-01,  -8.80741775e-02,
                         -5.30435070e-02,   7.85414279e-02,  -2.85914660e-01,
                         -7.07650900e-01,  -6.41435802e-01,  -2.27304220e-01,
                          5.91828264e-02,  -1.20344266e-01,  -4.92788911e-01,
                         -6.63236320e-01,  -7.05714583e-01,  -5.28288722e-01,
                         -1.17525697e-01,  -1.94431856e-01,  -7.41789520e-01,
                         -6.71500623e-01,  -1.10806338e-01,  -1.36681587e-01,
                         -5.91503084e-01,  -7.62205839e-01,  -6.77907884e-01,
                         -6.05840206e-01,  -6.49384618e-01,  -6.07036531e-01,
                         -2.70707786e-01,  -1.42261386e-01,  -5.17493665e-01,
                         -7.52385437e-01,  -6.31566226e-01,  -5.79509735e-01,
                         -6.14029765e-01,  -6.24120772e-01,  -6.44793272e-01,
                         -6.38973236e-01,  -6.58230901e-01,  -6.45091891e-01,
                         -5.70128918e-01,  -6.98759973e-01,  -7.55103827e-01,
                         -3.07925165e-01,  -3.54822204e-02,  -4.27464336e-01,
                         -7.47283876e-01,  -6.65609539e-01,  -6.21583045e-01,
                         -6.66061163e-01,  -6.24879718e-01,  -5.81031203e-01,
                         -6.59243464e-01,  -6.74012840e-01,  -3.28244448e-01,
                         -8.84908065e-02,  -5.08467257e-01,  -7.83267498e-01,
                         -3.05166513e-01,  -7.22007006e-02,  -5.19809663e-01,
                         -7.56885350e-01,  -5.84136367e-01,  -5.44588327e-01,
                         -6.46029770e-01,  -6.62102759e-01,  -6.39725327e-01,
                         -6.32224798e-01,  -6.22922421e-01,  -6.07932091e-01,
                         -6.02265120e-01,  -6.52271807e-01,  -6.96746409e-01,
                         -6.38013661e-01,  -5.85847855e-01,  -6.17638111e-01,
                         -6.27945721e-01,  -6.17700338e-01,  -6.33304238e-01,
                         -6.41421556e-01,  -6.59670770e-01,  -6.63754642e-01,
                         -6.11272812e-01,  -5.86814046e-01,  -6.21199846e-01,
                         -6.48392975e-01,  -6.57065153e-01,  -6.53876781e-01,
                         -6.24011993e-01,  -5.86634398e-01,  -6.06619954e-01,
                         -6.69231951e-01,  -6.56480908e-01,  -5.93312860e-01,
                         -6.07572913e-01,  -6.62544966e-01,  -6.63933039e-01,
                         -6.26551330e-01,  -6.16763413e-01,  -6.43767893e-01,
                         -6.38122559e-01,  -6.08208835e-01,  -6.16012931e-01,
                         -6.22336149e-01,  -6.18638039e-01,  -6.40353560e-01,
                         -6.42210960e-01,  -6.17867708e-01,  -6.24153733e-01,
                         -6.59193754e-01,  -6.58867538e-01,  -6.03241920e-01,
                         -5.94186604e-01,  -6.62477314e-01,  -6.79951906e-01,
                         -6.31693482e-01,  -6.12515867e-01,  -6.22654617e-01,
                         -6.25071585e-01,  -6.17732644e-01,  -6.14848673e-01,
                         -6.22282267e-01,  -6.34094179e-01,  -6.53100789e-01,
                         -6.50983691e-01,  -6.15161419e-01,  -5.97917497e-01,
                         -6.17878616e-01,  -6.58811510e-01,  -6.79800987e-01,
                         -6.35642707e-01,  -5.93690991e-01,  -6.09975576e-01,
                         -6.37021244e-01,  -6.55255318e-01,  -6.49909914e-01,
                         -6.30478978e-01,  -6.35312259e-01,  -6.25437379e-01,
                         -6.19444251e-01,  -6.55763686e-01,  -6.45240605e-01,
                         -6.04996204e-01,  -6.29070103e-01,  -6.55272484e-01,
                         -6.35730624e-01,  -6.27190411e-01,  -6.45442724e-01,
                         -6.48354173e-01,  -6.23646259e-01,  -6.13995790e-01,
                         -6.23686016e-01,  -6.27234101e-01,  -6.34020329e-01,
                         -6.35312736e-01,  -6.37594223e-01,  -6.53432846e-01,
                         -6.48227274e-01,  -6.36505306e-01,  -6.34134829e-01,
                         -6.17786765e-01,  -6.23905957e-01,  -6.51340246e-01,
                         -6.42453313e-01,  -6.18566215e-01,  -6.31161690e-01,
                         -6.53008223e-01,  -6.28383279e-01,  -6.11152649e-01,
                         -6.35989428e-01,  -6.36006713e-01,  -6.50250316e-01,
                         -6.36834860e-01,  -5.69997728e-01,  -6.88464522e-01,
                         -7.04467714e-01,  -2.62673885e-01,  -1.08290888e-01,
                         -5.33664286e-01,  -7.17214167e-01,  -5.98040223e-01,
                         -6.24342978e-01,  -6.68000340e-01,  -6.25340164e-01,
                         -6.13772333e-01,  -6.52656317e-01,  -6.37271941e-01,
                         -5.98548234e-01,  -7.11640418e-01,  -6.02322698e-01,
                         -1.10677183e-01,  -1.54684320e-01,  -7.54520237e-01,
                         -7.08369970e-01,  -1.35536000e-01,  -1.56005308e-01,
                         -6.29400194e-01,  -6.89332306e-01,  -5.52563667e-01,
                         -7.20742881e-01,  -6.02831721e-01,  -1.10497199e-01,
                         -1.98478088e-01,  -6.66507244e-01,  -7.06110537e-01,
                         -5.81058502e-01,  -6.26849890e-01,  -6.73852384e-01,
                         -6.21632099e-01,  -5.88829398e-01,  -6.85977876e-01,
                         -5.87804377e-01,  -1.89876139e-01,   3.10516637e-02,
                          5.61709031e-02,  -2.55377889e-02,  -3.99278969e-01,
                         -7.08495438e-01,  -6.66871846e-01,  -5.57745576e-01,
                         -6.14795923e-01,  -7.47917175e-01,  -5.04165828e-01,
                         -1.22822471e-01,  -3.44415009e-01,  -4.77260351e-01,
                         -1.01917639e-01,  -3.09204012e-01,  -7.73734868e-01,
                         -6.12338960e-01,  -6.03431463e-01,  -7.55189180e-01,
                         -3.14764202e-01,  -9.18364152e-02,  -5.17129898e-01,
                         -4.38184708e-01,   1.69721231e-01,   2.48546358e-02,
                         -5.78172445e-01,  -3.77638787e-01,  -2.48913579e-02,
                         -5.25425613e-01,  -8.27857196e-01,  -2.86846012e-01,
                         -6.62861019e-02,  -4.86820966e-01,  -6.96221590e-01,
                         -6.58086181e-01,  -6.08861566e-01,  -1.88354358e-01,
                          1.98129654e-01,  -2.01815367e-01,  -5.77533901e-01,
                         -2.25139767e-01,  -1.41489029e-01,  -6.49577022e-01,
                         -7.55300403e-01,  -2.30755463e-01,   1.68513089e-01,
                         -1.00605585e-01,  -5.57219326e-01,  -3.84252816e-01,
                          5.81838563e-02,   7.94939175e-02,  -2.62051765e-02,
                          8.31051543e-03,  -1.10981511e-02,  -3.90333980e-02,
                          7.49218836e-03,   2.48839092e-02,  -8.40732828e-03,
                         -1.50165642e-02,   2.16101203e-02,   2.44796705e-02,
                         -1.87969413e-02,  -2.50966735e-02,   1.13874720e-02,
                          2.30965354e-02,  -3.62882111e-03,  -1.61147472e-02,
                          9.39902384e-03,   2.16452219e-02,  -7.80163007e-03,
                         -3.00491136e-02,  -3.91360745e-03,   2.78060287e-02,
                          1.13607794e-02,  -1.39989182e-02,  -6.70818007e-03,
                          5.90306846e-03,   1.16466107e-02,   1.05674313e-02,
                          1.51558337e-03,   2.19231122e-04,  -6.08733343e-03,
                         -1.69391744e-02,  -1.92872202e-03,   1.35702863e-02,
                          3.64119024e-03,  -2.60003842e-03,   3.25686461e-03,
                          8.94259289e-03,   4.17612074e-03,  -1.01360101e-02,
                          4.38951189e-03,   2.66014952e-02,   1.43787835e-03,
                         -1.32250227e-02,   5.56343514e-03,  -1.85497644e-04,
                         -4.98665404e-03,   3.12135601e-03,   8.11638869e-03,
                          1.88417267e-02,  -2.40852311e-03,  -1.41526777e-02,
                          1.97123941e-02,   1.49454409e-02,   2.53664562e-04,
                          5.23423869e-03,  -8.45158193e-03,   5.02447225e-03,
                          1.19931912e-02,  -3.18858284e-03,  -7.56647729e-04,
                         -1.51673257e-02,   2.40739919e-02,   3.44582945e-02,
                         -4.90523204e-02,   4.64303941e-02,   1.93521492e-02,
                         -4.21934485e-01,  -4.85039175e-01,  -3.18808667e-02,
                          9.52443480e-02,  -5.02707772e-02,  -1.74128544e-02,
                          5.05916476e-02,   2.11399291e-02,  -2.17277631e-02,
                         -1.59896426e-02,   2.10114419e-02,   2.77567506e-02,
                          3.88821051e-03,  -1.56227751e-02,   3.11067910e-03,
                          2.05136929e-02,  -1.26654264e-02,  -9.73565876e-03,
                          2.34195571e-02,   7.59412022e-03,   3.92735557e-04,
                          5.75791718e-03,  -1.07079023e-03,   1.09402128e-02,
                          9.73709021e-03,   5.09523042e-03,   2.03196481e-02,
                          1.12877861e-02,  -1.11539382e-02,  -1.63305104e-02,
                         -3.04915663e-03,   9.07470565e-03,   2.33545667e-03,
                          1.44406194e-02,   2.59768777e-02,  -2.13146769e-03,
                         -6.39343169e-03,   7.76988128e-03,  -9.96462628e-03,
                         -2.50248378e-03,   2.87223496e-02,   7.52355065e-03,
                         -2.88390629e-02,  -1.45233283e-02,   2.10821051e-02,
                          3.26895826e-02,   3.42522911e-03,  -2.57113148e-02,
                          2.90104887e-03,   2.28395686e-02,  -3.72290704e-03,
                         -8.09112797e-04,   4.45463881e-03,  -8.71332176e-03,
                          7.55048310e-03,   8.47477466e-03,  -3.69760441e-03,
                          1.41879367e-02,   2.60390583e-02,   1.09622981e-02,
                         -1.32516623e-02,   3.09472671e-04,   1.16783902e-02,
                         -2.84789950e-02,  -1.12697445e-02,   2.57461127e-02,
                          6.94898423e-03,  -7.41244620e-03,  -4.02245075e-02,
                          4.86437343e-02,   1.00319207e-01,  -3.20269763e-01,
                         -5.75562716e-01,  -1.58794224e-01,   1.11012615e-01,
                         -7.45018106e-03,  -4.90299203e-02,   1.88959986e-02,
                          6.70402721e-02,  -1.66794389e-01,  -5.60818136e-01,
                         -6.88167930e-01,  -7.06407905e-01,  -5.01202106e-01,
                         -5.81173636e-02,  -2.67265856e-01,  -8.23358774e-01,
                         -5.61638355e-01,  -5.24412878e-02,  -2.78225631e-01,
                         -7.00307667e-01,  -6.75034463e-01,  -5.79241574e-01,
                         -6.46560252e-01,  -6.05995774e-01,  -6.41675234e-01,
                         -7.34727204e-01,  -3.61039191e-01,  -5.91706112e-02,
                         -4.67770219e-01,  -7.45800376e-01,  -5.67635298e-01,
                         -6.64676845e-01,  -7.27359653e-01,  -2.51950413e-01,
                         -5.41568696e-02,  -5.35874486e-01,  -8.07208598e-01,
                         -3.99953634e-01,   9.01715681e-02,   2.34415699e-02,
                         -4.09845054e-01,  -6.29792452e-01,  -6.93553448e-01,
                         -6.62274718e-01,  -2.66051680e-01,  -1.02163322e-01,
                         -5.48519075e-01,  -7.17383265e-01,  -5.38365722e-01,
                         -6.90063179e-01,  -7.03370094e-01,  -2.04375431e-01,
                         -7.88584575e-02,  -6.37198567e-01,  -7.86559224e-01,
                         -2.06796229e-01,  -9.62560028e-02,  -6.21105373e-01,
                         -6.98750496e-01,  -5.00168264e-01,  -6.92221999e-01,
                         -6.80001676e-01,  -1.78347886e-01,  -1.14545874e-01,
                         -6.68322325e-01,  -7.57859409e-01,  -1.88846245e-01,
                         -8.61112997e-02,  -6.34340882e-01,  -7.45786309e-01,
                         -2.30474815e-01,  -7.05857649e-02,  -5.42042971e-01,
                         -8.07089031e-01,  -4.04138625e-01,   8.82479399e-02,
                          4.79358658e-02,  -3.86298150e-01,  -7.31197417e-01,
                         -6.45185292e-01,  -9.77186710e-02,   2.00056762e-01,
                         -2.71386385e-01,  -5.54361939e-01,  -2.15284899e-01,
                         -2.60323316e-01,  -4.68191534e-01,  -1.93489939e-01,
                         -2.64458716e-01,  -6.95336521e-01,  -6.75186753e-01,
                         -5.70893168e-01,  -6.60188496e-01,  -6.52383626e-01,
                         -6.35394752e-01,  -6.10844672e-01,  -5.76277673e-01,
                         -6.92894697e-01,  -6.86266541e-01,  -2.71988690e-01,
                          1.50231972e-01,  -1.38459112e-02,  -5.49445152e-01,
                         -7.22593427e-01,  -5.93933403e-01,  -6.39887094e-01,
                         -6.88966691e-01,  -5.98128140e-01,  -6.24596655e-01,
                         -6.15577042e-01,  -2.61115491e-01,   1.06332690e-01,
                         -2.68089008e-02,  -5.56333423e-01,  -8.17482591e-01,
                         -3.88688952e-01,   2.94519700e-02,  -4.04976785e-01,
                         -8.85838687e-01,  -4.50506687e-01,  -1.93597225e-03,
                         -3.61945510e-01,  -7.46539772e-01,  -6.40162587e-01,
                         -6.05150938e-01,  -7.15611279e-01,  -3.90490532e-01,
                         -2.03819871e-02,  -4.14375901e-01,  -8.60809982e-01,
                         -4.39928025e-01,   2.12313402e-02,  -3.71132225e-01,
                         -8.47521424e-01,  -5.06857812e-01,  -2.75379270e-02,
                         -3.11289519e-01,  -7.48049498e-01,  -6.70428514e-01,
                         -5.57837605e-01,  -6.33706450e-01,  -6.46859586e-01,
                         -6.48522317e-01,  -6.36861861e-01,  -5.92572033e-01,
                         -6.09601200e-01,  -6.28808498e-01,  -6.64238155e-01,
                         -6.54604375e-01,  -5.47284544e-01,  -6.65873766e-01,
                         -7.46453345e-01,  -2.98118562e-01,  -1.07358888e-01,
                         -4.82653230e-01,  -3.56576174e-01,  -5.28432578e-02,
                         -5.45269847e-01,  -8.13806117e-01,  -2.49297410e-01,
                         -1.41083822e-01,  -5.18956304e-01,  -2.73399293e-01,
                         -6.53887838e-02,  -6.47484601e-01,  -7.91015506e-01,
                         -1.44647375e-01,  -1.31240845e-01,  -5.93769312e-01,
                         -2.57975489e-01,   2.01318845e-01,  -2.20002770e-01,
                         -5.57272077e-01,  -1.88129574e-01,  -1.86345428e-01,
                         -5.71044683e-01,  -2.05661118e-01,   2.04316899e-01,
                         -2.94525772e-01,  -4.98585224e-01,  -1.19824171e-01,
                         -3.24057132e-01,  -5.20960391e-01,  -1.00060701e-01,
                         -2.27151468e-01,  -8.23931754e-01,  -5.92552066e-01,
                         -2.34111585e-02,  -2.75018513e-01,  -7.38644540e-01,
                         -6.19419098e-01,  -5.90509593e-01,  -7.69810915e-01,
                         -3.80597472e-01,  -4.43165526e-02,  -4.30075049e-01,
                         -4.92525846e-01,   5.62750287e-02,   9.70638022e-02,
                         -4.44720924e-01,  -6.92887366e-01,  -5.86205006e-01,
                         -6.15363955e-01,  -6.67667508e-01,  -5.63994229e-01,
                         -6.62324607e-01,  -7.22669363e-01,  -2.72273898e-01,
                         -5.76092601e-02,  -5.14485955e-01,  -7.41572917e-01,
                         -5.66562593e-01,  -6.53489292e-01,  -6.87135637e-01,
                         -2.03088984e-01,  -3.01438570e-02,  -6.29406929e-01,
                         -8.23394239e-01,  -2.05850199e-01,  -5.23981713e-02,
                         -5.63889265e-01,  -7.25856483e-01,  -5.78207314e-01,
                         -6.20930851e-01,  -6.68943405e-01,  -6.18072987e-01,
                         -6.11559570e-01,  -6.22942865e-01,  -6.33318245e-01,
                         -6.50503993e-01,  -6.30132318e-01,  -6.04983389e-01,
                         -6.17573082e-01,  -6.13148212e-01,  -5.81565201e-01,
                         -6.09252870e-01,  -6.61709547e-01,  -6.44827068e-01,
                         -6.55415416e-01,  -6.45054877e-01,  -3.14177871e-01,
                          1.12705715e-01,   2.00697966e-02,  -4.67194736e-01,
                         -7.15118229e-01,  -6.55143321e-01,  -6.08798504e-01,
                         -6.32294834e-01,  -6.20654464e-01,  -5.94661057e-01,
                         -6.48293078e-01,  -6.81515276e-01,  -4.35073942e-01,
                         -4.77866605e-02,   6.59896061e-02,   6.37848210e-03,
                          2.56412774e-02,  -9.88902152e-03,  -4.78653051e-02,
                          1.05769066e-02,  -4.64588217e-03,   4.18878123e-02,
                          8.49405155e-02,  -2.83044577e-01,  -5.64503312e-01,
                         -2.24997669e-01,   1.11441538e-01,   3.24282497e-02,
                         -1.01115622e-01,  -2.27820687e-02,   1.06152780e-01,
                         -1.33166969e-01,  -4.86024290e-01,  -2.73697346e-01,
                          9.33308452e-02,   3.19121219e-02,  -5.85621856e-02,
                          5.74186025e-03,  -9.03104781e-04,  -2.74014357e-03,
                          2.70112697e-02,   1.04878349e-02,  -1.14430496e-02,
                         -9.15481430e-03,   2.73967031e-02,   3.88005972e-02,
                         -2.22561117e-02,  -4.87575047e-02,  -7.33182626e-03,
                          9.09289438e-03,  -1.55484751e-02,  -2.38955356e-02,
                          1.26702115e-02,   3.86109836e-02,   1.14054829e-02,
                          1.63135747e-03,   2.58109886e-02,   2.10303292e-02,
                          1.08082881e-02,   2.19466188e-03,  -1.87180229e-02,
                         -1.05450116e-02,  -3.95694487e-02,  -4.52058464e-02,
                          1.01760939e-01,   2.75622169e-03,  -4.36544091e-01,
                         -4.63340998e-01,  -6.53383434e-02,   4.29813564e-02,
                         -5.35678454e-02,  -1.02638826e-02,   3.90459783e-02,
                          2.55901068e-02,   3.90626416e-02,   3.93621176e-02,
                         -4.07734476e-02,  -2.24602991e-03,   1.37745813e-01,
                         -1.65345311e-01,  -5.90575576e-01,  -2.77991951e-01,
                          1.32658616e-01,  -4.22726832e-02,  -5.96948564e-02,
                          1.04077496e-01,  -2.45695278e-01,  -5.71836948e-01,
                         -2.58449852e-01,   9.51047316e-02,   3.14252600e-02,
                         -7.93220922e-02,   6.48253458e-03,   8.65109339e-02,
                         -9.72923711e-02,  -5.09745598e-01,  -6.93386793e-01,
                         -5.70974171e-01,  -6.50824606e-01,  -7.05176175e-01,
                         -2.54044056e-01,  -5.33106364e-02,  -5.90719819e-01,
                         -8.01084280e-01,  -2.56287307e-01,  -1.16503201e-01,
                         -5.76734781e-01,  -4.01488394e-01,   2.08083287e-01,
                         -5.37323626e-03,  -5.80687821e-01,  -6.58525050e-01,
                         -6.56663656e-01,  -5.72680891e-01,  -1.40632108e-01,
                         -1.39903963e-01,  -7.05298364e-01,  -7.08731711e-01,
                         -1.32274270e-01,  -1.33853778e-01,  -6.28047466e-01,
                         -6.91682041e-01,  -5.88811398e-01,  -7.63977110e-01,
                         -6.05210185e-01,  -8.07567760e-02,  -1.55927688e-01,
                         -7.41463542e-01,  -7.00782835e-01,  -1.33203909e-01,
                         -2.01551959e-01,  -6.98229671e-01,  -6.41347170e-01,
                         -5.00525296e-01,  -7.44321227e-01,  -5.52888036e-01,
                         -1.03753962e-01,  -3.25926065e-01,  -5.09528399e-01,
                         -1.18785337e-01,  -2.59469777e-01,  -8.19628537e-01,
                         -5.26399195e-01,   2.14515328e-02,  -2.94919223e-01,
                         -7.55155742e-01,  -6.40886545e-01,  -5.49032986e-01,
                         -7.21607625e-01,  -5.42639136e-01,   7.82542862e-03,
                          1.19650982e-01,  -3.51806402e-01,  -5.29289901e-01,
                         -9.60572511e-02,   1.56020775e-01,  -2.17423707e-01,
                         -6.93053186e-01,  -7.39971340e-01,  -3.04552197e-01,
                          1.88617706e-01,   4.28011678e-02,  -5.15135825e-01,
                         -4.35180634e-01,   1.10843919e-01,   2.93422025e-02,
                         -5.01371801e-01,  -4.82060343e-01,   3.75281693e-03,
                          8.12800601e-02,  -3.54251921e-01,  -6.90986514e-01,
                         -5.91632724e-01,  -1.12838820e-01,   1.86822429e-01,
                         -1.94354430e-01,  -5.31075597e-01,  -2.09843338e-01,
                          8.04284066e-02,   3.13196927e-02,  -8.22840482e-02,
                         -3.50543112e-01,  -6.06975675e-01,  -6.23970866e-01,
                         -6.16848409e-01,  -6.23290360e-01,  -5.86834013e-01,
                         -6.44307315e-01,  -6.70309722e-01,  -3.51000220e-01,
                          7.52545893e-02,   8.54600221e-02,  -4.53147776e-02,
                          5.46658784e-02,  -9.73184034e-02,  -5.42142451e-01,
                         -6.84811592e-01,  -5.81119537e-01,  -5.63774168e-01,
                         -6.47595942e-01,  -6.76509082e-01,  -5.84991813e-01,
                         -6.49462938e-01,  -6.68554723e-01,  -2.19850972e-01,
                         -7.31401443e-02,  -5.36695540e-01,  -4.10946637e-01,
                          1.94614515e-01,  -1.52129475e-02,  -5.73809326e-01,
                         -3.99683684e-01,   1.65778436e-02,   7.10237995e-02,
                          2.72284020e-02,  -2.04566821e-01,  -6.94653451e-01,
                         -6.85302913e-01,  -1.33107796e-01,  -9.37253460e-02,
                         -5.84722579e-01,  -6.96560442e-01,  -5.94128251e-01,
                         -7.37154126e-01,  -5.81651509e-01,  -1.10559739e-01,
                         -1.97305053e-01,  -6.43434584e-01,  -6.50870442e-01,
                         -5.47811866e-01,  -7.27862000e-01,  -6.13526464e-01,
                         -9.13619399e-02,   9.34183598e-02,  -5.78876734e-02,
                          4.17775847e-02,   5.30303940e-02,  -3.83436948e-01,
                         -5.03519714e-01,  -6.63146228e-02,   1.06853180e-01,
                         -5.19683808e-02,  -2.15738472e-02,   5.34506924e-02,
                         -2.27555330e-03,  -9.44221206e-03,   1.25056915e-02,
                          2.33352389e-02,  -3.74874263e-03,  -8.53985548e-02,
                          3.33864912e-02,   1.20811656e-01,  -2.65881717e-01,
                         -4.93281633e-01,  -1.43986046e-01,   7.86896423e-02,
                         -1.33770369e-02,  -4.20917198e-02,   3.81979831e-02,
                          5.46953939e-02,  -2.43472487e-01,  -5.24273634e-01,
                         -2.42864251e-01,   1.08483940e-01,   4.07660827e-02,
                         -7.23110139e-02,  -7.94169307e-03,   5.80272339e-02,
                         -1.07697593e-02,  -1.67233180e-02,   8.89939740e-02,
                         -1.98080510e-01,  -5.77794075e-01,  -2.84951538e-01,
                          9.15207267e-02,  -4.00433969e-03,  -5.10666445e-02,
                          4.30017188e-02,   2.98725050e-02,   2.95849721e-04,
                         -1.73153414e-03,   1.40440604e-02,   2.78387591e-02,
                          8.45005643e-03,  -8.34875158e-04,  -1.32744992e-02,
                         -2.07522195e-02,   1.79636851e-03,   5.02752280e-03,
                         -1.77648780e-03,   1.70686245e-02,   4.68930826e-02,
                          1.27731878e-02,  -5.84591478e-02,   2.26643719e-02,
                          3.95457745e-02,  -3.63571614e-01,  -7.25341499e-01,
                         -6.11878335e-01,  -5.44878304e-01,  -7.44899571e-01,
                         -5.93435705e-01,  -5.47385477e-02,   1.33122995e-01,
                         -2.29520202e-01,  -6.63668036e-01,  -7.14209020e-01,
                         -2.96066463e-01,   6.30691051e-02,  -3.01537495e-02,
                         -5.71204759e-02,   1.27466351e-01,  -1.27823323e-01,
                         -5.24925649e-01,  -2.67457038e-01,   1.12755559e-01,
                         -2.93849315e-02,  -9.34015512e-02,   8.12314823e-02,
                         -2.15171978e-01,  -5.91094315e-01,  -2.07495376e-01,
                          1.83459088e-01,  -2.45566398e-01,  -6.15261674e-01,
                         -2.43294507e-01,   1.08914025e-01,   1.66723467e-02,
                         -3.21112014e-02,   6.78046197e-02,   5.60287386e-02,
                         -7.18946476e-03,  -1.81484409e-02,  -2.37328019e-02,
                         -2.45561525e-02,  -1.79437511e-02,  -3.44278626e-02,
                         -2.47616358e-02,   3.25339921e-02,   1.04196994e-02,
                         -1.24255102e-02,   7.70991519e-02,  -1.16616197e-01,
                         -5.22295892e-01,  -3.75531703e-01,   6.24711551e-02,
                          5.79469725e-02,  -7.77087584e-02,  -8.37684423e-03,
                          3.54226641e-02,  -2.07065754e-02,  -1.03907716e-02,
                          8.39208215e-02,  -1.35700792e-01,  -5.34051657e-01,
                         -3.14510852e-01,   9.90093946e-02,  -3.70416194e-02,
                         -5.18947281e-02,   1.47172809e-01,  -1.97168276e-01,
                         -5.36068678e-01,  -2.44551539e-01,  -1.74862891e-01,
                         -6.98233306e-01,  -7.65339673e-01,  -1.99127659e-01,
                         -1.30062431e-01,  -5.61279416e-01,  -6.54615045e-01,
                         -6.00387096e-01,  -6.68999016e-01,  -6.24859154e-01,
                         -6.06055617e-01,  -6.77170873e-01,  -6.42916679e-01,
                         -5.94094753e-01,  -6.23704135e-01,  -6.63533270e-01,
                         -6.65971756e-01,  -6.29012585e-01,  -6.27040446e-01,
                         -6.64252043e-01,  -6.67028844e-01,  -6.38100743e-01,
                         -5.98016083e-01,  -5.82238078e-01,  -6.27903700e-01,
                         -6.75292432e-01,  -6.69342756e-01,  -6.50806427e-01,
                         -6.40737534e-01,  -6.16374850e-01,  -6.08755767e-01,
                         -6.13110065e-01,  -5.83481193e-01,  -5.94872177e-01,
                         -6.59515500e-01,  -6.73065484e-01,  -6.72288835e-01,
                         -6.79699242e-01,  -6.36102796e-01,  -6.03866160e-01,
                         -6.14425480e-01,  -6.22791767e-01,  -6.30271554e-01,
                         -6.20038331e-01,  -6.10853970e-01,  -6.42484546e-01,
                         -6.49791002e-01,  -6.07561111e-01,  -6.06254935e-01,
                         -6.39921486e-01,  -6.19914353e-01,  -6.09112918e-01,
                         -6.56986892e-01,  -6.38611495e-01,  -5.88073373e-01,
                         -6.34791911e-01,  -6.80376470e-01,  -6.57455802e-01,
                         -6.41730785e-01,  -6.31846547e-01,  -5.97542524e-01,
                         -5.78556061e-01,  -6.31972492e-01,  -6.79145038e-01,
                         -6.19366467e-01,  -5.92805505e-01,  -6.51686192e-01,
                         -6.27722919e-01,  -5.87749779e-01,  -6.64217710e-01,
                         -7.15465903e-01,  -6.53667808e-01,  -6.00174546e-01,
                         -6.03515148e-01,  -6.04005814e-01,  -6.26100838e-01,
                         -6.75954580e-01,  -6.64601564e-01,  -6.23680472e-01,
                         -6.13785148e-01,  -6.06929064e-01,  -6.33343577e-01,
                         -6.73801959e-01,  -6.36507094e-01,  -5.69376528e-01,
                         -6.13254130e-01,  -6.94868743e-01,  -6.05849802e-01,
                         -5.93204260e-01,  -7.67580271e-01,  -5.09599149e-01,
                         -1.01054989e-01,  -3.50060612e-01,  -4.99131471e-01,
                         -1.36347145e-01,  -2.65755177e-01,  -7.09043920e-01,
                         -6.71736777e-01,  -5.32961488e-01,  -6.17890894e-01,
                         -6.56883597e-01,  -5.91241956e-01,  -6.32280886e-01,
                         -6.96158111e-01,  -3.91397685e-01,  -1.05485529e-01,
                         -4.37000185e-01,  -7.41306245e-01,  -6.06612861e-01,
                         -6.04995549e-01,  -6.63867116e-01,  -5.93400776e-01,
                         -7.13926733e-01,  -6.44315422e-01,  -1.60218224e-01,
                         -1.36320069e-01,  -6.19444788e-01,  -6.72945499e-01,
                         -5.13419092e-01,  -7.02956557e-01,  -5.91681123e-01,
                         -1.14857532e-01,  -2.67806321e-01,  -6.00092649e-01,
                         -7.52114803e-02,   3.03358972e-01,  -3.24254245e-01,
                         -6.03506327e-01,  -7.76042640e-02,  -1.54850289e-01,
                         -7.79073715e-01,  -6.33573353e-01,  -4.43973057e-02,
                         -1.89561158e-01,  -7.49094844e-01,  -6.36176169e-01,
                         -1.40341640e-01,  -2.46837080e-01,  -6.31489694e-01,
                         -6.81161880e-01,  -6.35642946e-01,  -3.84280056e-01,
                         -3.49452440e-03,  -3.03785920e-01,  -8.11356723e-01,
                         -4.70653385e-01,  -2.57300045e-02,  -3.64527315e-01,
                         -7.18196034e-01,  -5.68227470e-01,  -5.83985507e-01,
                         -7.57581115e-01,  -3.74728411e-01,   2.10546199e-02,
                         -4.30750847e-01,  -8.61413479e-01,  -4.24992234e-01,
                         -4.40644324e-02,  -3.66167724e-01,  -6.96160793e-01,
                         -6.47384346e-01,  -5.32271683e-01,  -5.81333280e-01,
                         -7.02264905e-01,  -4.79399562e-01,  -8.45617950e-02,
                         -2.77450502e-01,  -5.09091616e-01,   1.49955032e-02,
                          1.91490442e-01,  -4.41050649e-01,  -5.11004806e-01,
                         -6.73889741e-02,  -2.83564240e-01,  -7.16388106e-01,
                         -6.39128089e-01,  -5.97277880e-01,  -7.15403676e-01,
                         -3.57166022e-01,   2.21794527e-02,  -4.04950172e-01,
                         -8.13869596e-01,  -3.60647947e-01,  -7.06077293e-02,
                         -4.51948285e-01,  -3.75697494e-01,  -1.82510410e-02,
                         -5.08223295e-01,  -8.56730163e-01,  -2.12689564e-01,
                         -6.56225905e-02,  -5.46418965e-01,  -3.02904189e-01,
                         -6.89300820e-02,  -4.85231310e-01,  -3.39451820e-01,
                          2.19279721e-01,  -6.06205128e-03,  -5.83261669e-01,
                         -6.35392845e-01,  -5.02541363e-01,  -6.88393772e-01,
                         -6.94708586e-01,  -1.76788509e-01,  -2.33696941e-02,
                         -5.79203129e-01,  -7.82977104e-01,  -2.43408248e-01,
                          1.84161291e-01,  -2.90087033e-02,  -4.84902412e-01,
                         -6.46081388e-01,  -5.90439796e-01,  -6.11118793e-01,
                         -6.26586437e-01,  -5.78705251e-01,  -5.78732491e-01,
                         -5.94033241e-01,  -6.15255892e-01,  -6.50507808e-01,
                         -6.19119108e-01,  -6.01651073e-01,  -6.09717250e-01,
                         -5.33128679e-01,  -6.06571198e-01,  -7.48417914e-01,
                         -3.99186403e-01,  -1.37207452e-02,  -3.41732532e-01,
                         -7.16783822e-01,  -6.06848061e-01,  -5.63222289e-01,
                         -6.23066068e-01,  -5.64590096e-01,  -6.47184432e-01,
                         -6.17072940e-01,  -2.23097250e-01,  -1.58378452e-01,
                         -5.40176332e-01,  -6.05430841e-01,  -5.37774920e-01,
                         -7.51848876e-01,  -5.95777094e-01,  -1.14266537e-01,
                         -2.33886987e-01,  -6.33550763e-01,  -6.08361900e-01,
                         -5.32002628e-01,  -6.38201475e-01,  -6.46103919e-01,
                         -5.98471165e-01,  -6.07072771e-01,  -5.88968933e-01,
                         -5.64031065e-01,  -6.07674062e-01,  -6.44361198e-01,
                         -5.93812704e-01,  -5.72936773e-01,  -6.35324657e-01,
                         -6.38046920e-01,  -6.18941545e-01,  -6.81721628e-01,
                         -6.42513812e-01,  -5.12563705e-01,  -5.98515689e-01,
                         -6.57239497e-01,  -3.26279014e-01,  -1.38855904e-01,
                         -4.53273654e-01,  -6.82404637e-01,  -6.16821826e-01,
                         -5.90355337e-01,  -5.96999586e-01,  -5.92217445e-01,
                         -6.25966489e-01,  -6.08311415e-01,  -5.98753333e-01,
                         -6.70339286e-01,  -6.68541431e-01,  -5.78462303e-01,
                         -5.85342228e-01,  -6.61930203e-01,  -6.20566010e-01,
                         -5.44473469e-01,  -5.99395990e-01,  -6.59966290e-01,
                         -6.21946692e-01,  -5.72927773e-01,  -5.67884088e-01,
                         -6.11995935e-01,  -6.50603950e-01,  -6.37320042e-01,
                         -6.21510506e-01,  -6.12770617e-01,  -6.03523672e-01,
                         -6.08218610e-01,  -6.08052909e-01,  -6.05011702e-01,
                         -6.00393653e-01,  -6.20564818e-01,  -6.70845687e-01,
                         -6.43764019e-01,  -5.81911087e-01,  -6.16292000e-01,
                         -6.51831388e-01,  -6.15516424e-01,  -5.90815008e-01,
                         -6.08309329e-01,  -6.29539967e-01,  -6.16780043e-01,
                         -6.15906060e-01,  -6.63745224e-01,  -6.67332172e-01,
                         -6.11104369e-01,  -5.88335216e-01,  -6.16543651e-01,
                         -6.41303480e-01,  -6.17504120e-01,  -5.91653883e-01,
                         -6.03653193e-01,  -5.89028955e-01,  -5.68741500e-01,
                         -6.06670797e-01,  -6.32401705e-01,  -6.06741846e-01,
                         -6.06366992e-01,  -6.63006008e-01,  -7.15322912e-01,
                         -7.09273338e-01,  -6.39514923e-01,  -5.46937704e-01,
                         -5.35368621e-01,  -6.06596231e-01,  -6.35550261e-01,
                         -6.40109181e-01,  -6.64988160e-01,  -6.42616570e-01,
                         -6.17832363e-01,  -6.35191441e-01,  -6.25698686e-01,
                         -6.03510499e-01,  -6.12149537e-01,  -6.48317218e-01,
                         -6.62013054e-01,  -5.72138667e-01,  -5.02665639e-01,
                         -6.11263394e-01,  -6.96695983e-01,  -6.08347297e-01,
                         -5.81697524e-01,  -6.88882768e-01,  -7.09846199e-01,
                         -6.44510984e-01,  -6.15629196e-01,  -6.02815092e-01,
                         -6.26686156e-01,  -6.58157170e-01,  -5.99242568e-01,
                         -5.65814853e-01,  -6.33436382e-01,  -6.65010512e-01,
                         -6.30950212e-01,  -6.11364543e-01,  -6.42819822e-01,
                         -6.65118873e-01,  -6.10642910e-01,  -5.94988823e-01,
                         -6.51950955e-01,  -6.45394981e-01,  -6.19148552e-01,
                         -6.30364001e-01,  -6.48328066e-01,  -6.81102455e-01,
                         -6.15665853e-01,  -5.44309676e-01,  -7.02213168e-01,
                         -6.99246287e-01,  -2.74947077e-01,  -9.84193906e-02,
                         -4.35675651e-01,  -7.07347155e-01,  -7.15444028e-01,
                         -5.44201016e-01,  -1.26786739e-01,   1.03333391e-01,
                         -2.75718570e-01,  -6.78789556e-01,  -5.84223509e-01,
                         -4.88404423e-01,  -6.80851102e-01,  -5.91470361e-01,
                         -1.61064595e-01,  -1.94492787e-01,  -6.81687832e-01,
                         -7.77145267e-01,  -6.10354900e-01,  -6.92778111e-01,
                         -5.27733147e-01,  -6.26497716e-02,  -2.34676600e-01,
                         -8.04980516e-01,  -6.40067399e-01,  -1.13521852e-01,
                         -2.48515934e-01,  -6.56012356e-01,  -6.96959376e-01,
                         -6.18359506e-01,  -4.14540827e-01,   3.16914916e-02,
                          1.20442919e-01,  -3.80966425e-01,  -7.71944940e-01,
                         -5.51793814e-01,  -1.40007868e-01,  -2.90352285e-01,
                         -7.99527645e-01,  -6.81839526e-01,  -8.57122988e-02,
                         -1.55556217e-01,  -7.43427753e-01,  -6.84404731e-01,
                         -1.92368209e-01,  -2.79291123e-01,  -5.08271575e-01,
                         -1.58685848e-01,   1.01423517e-01,  -6.47437871e-02,
                         -1.21390214e-02,   1.04122169e-01,  -3.11569810e-01,
                         -8.15726757e-01,  -6.60957694e-01,  -1.45266742e-01,
                         -1.90764308e-01,  -7.66222596e-01,  -8.14334691e-01,
                         -1.81196198e-01,  -3.75118107e-02,  -6.61275029e-01,
                         -8.01566601e-01,  -1.78230554e-01,  -8.05516765e-02,
                         -5.68116426e-01,  -3.89765501e-01,   1.33963078e-01,
                         -1.38299361e-01,  -6.24515057e-01,  -3.48716170e-01,
                          1.07339375e-01,  -6.67076111e-02,  -4.86313879e-01,
                         -6.09553039e-01,  -6.61525428e-01,  -6.74260736e-01,
                         -3.09633970e-01,   3.81949395e-02,  -3.19019593e-02,
                         -5.16413376e-02,   2.36549284e-02,  -2.55311936e-01,
                         -6.44822061e-01,  -7.00582206e-01,  -3.46301258e-01,
                          9.15350094e-02,  -7.13502690e-02,  -6.00900590e-01,
                         -4.65711057e-01,   9.06518921e-02,   5.99580668e-02,
                         -4.57651615e-01,  -7.06512392e-01,  -4.55341876e-01,
                         -1.42388687e-01,  -1.32459223e-01,  -1.61891878e-01,
                         -2.84358077e-02,   4.47576568e-02,   9.10428178e-04,
                         -4.96626869e-02,  -7.34711960e-02,  -5.30846789e-02,
                         -2.18721628e-02,  -4.36940137e-03,   3.56097793e-04,
                         -2.28850134e-02,  -4.47856337e-02,  -5.93745075e-02,
                         -5.32715879e-02,   4.56417585e-03,   2.22721901e-02,
                         -2.93986276e-02,  -4.79966030e-02,  -4.98876534e-02,
                         -7.96675459e-02,  -7.39339367e-02,  -1.53448526e-02,
                          1.66388750e-02,  -1.51995756e-02,  -4.81009483e-02,
                         -6.31801039e-02,  -8.98698196e-02,  -7.69012421e-02,
                         -2.06022523e-02,   1.57046802e-02,   3.50450128e-02,
                          2.61424622e-03,  -8.53506327e-02,  -9.91045684e-02,
                         -2.93549597e-02,   4.69038635e-03,  -2.83819735e-02,
                         -7.68730491e-02,  -6.57726526e-02,  -1.13994023e-02,
                          1.45188777e-03,   2.10923632e-03,  -8.59602261e-03,
                         -8.51290300e-02,  -1.05001129e-01,  -2.06822753e-02,
                         -1.33643753e-03,  -5.34642711e-02,  -6.59423396e-02,
                         -5.65439761e-02,  -5.36292307e-02,  -5.57485186e-02,
                         -4.29563783e-02,   1.92862172e-02,   4.90666851e-02,
                         -8.85054376e-03,  -4.66097929e-02,  -4.99948710e-02,
                         -8.71907324e-02,  -8.40729773e-02,  -1.86987910e-02,
                         -1.97531991e-02,  -5.67169264e-02,  -2.92716641e-03,
                          2.94985119e-02,  -5.82428090e-02,  -8.56589973e-02,
                          3.15605066e-05,   1.04695633e-02,  -6.35509118e-02,
                         -8.30779821e-02,  -5.29103279e-02,  -4.34052758e-02,
                         -2.94478852e-02,   1.54896379e-02,  -7.00767571e-03,
                         -1.01005048e-01,  -6.71759471e-02,   6.37440309e-02,
                          3.79754268e-02,  -7.43926466e-02,  -6.32519498e-02,
                         -1.98635310e-02,  -4.29649130e-02,  -3.69252488e-02,
                         -5.21482807e-03,  -2.44854577e-02,  -3.45675312e-02,
                         -3.00700907e-02,  -8.45663399e-02,  -8.11322108e-02,
                          2.34096218e-02,   2.09189747e-02,  -6.00169376e-02,
                         -4.33317386e-02,  -2.63702720e-02,  -4.98656332e-02,
                         -1.49325179e-02,   3.27961822e-03,  -3.05364877e-02,
                         -4.07633781e-02,  -6.26420453e-02,  -9.68025103e-02,
                         -6.34707734e-02,   1.06998263e-02,   3.69882882e-02,
                          8.06713104e-03,  -8.57555680e-03,  -2.11432725e-02,
                         -8.65659490e-02,  -1.09730199e-01,  -2.21960414e-02,
                          2.18356494e-02,  -2.93297302e-02,  -1.32674370e-02,
                          6.56733438e-02,   2.46076994e-02,  -8.53125453e-02,
                         -6.37872145e-02,   9.65357665e-03,  -1.46478359e-02,
                         -4.21674810e-02,  -3.61255072e-02,  -5.69978692e-02,
                         -2.97480710e-02,   3.25449929e-02,   6.04885677e-03,
                         -3.21614817e-02,   1.67695992e-02,   5.74067980e-03,
                         -7.88161755e-02,   1.26286531e-02,   4.65644524e-02,
                         -3.56185228e-01,  -5.37195444e-01,  -1.22217171e-01,
                         -1.68999121e-01,  -7.77755201e-01,  -7.48338401e-01,
                         -1.82933703e-01,   6.35967478e-02,  -1.25054091e-01,
                         -5.79647064e-01,  -7.07647979e-01,  -2.38499776e-01,
                         -9.92057770e-02,  -5.42981267e-01,  -8.10647011e-01,
                         -7.85301566e-01,  -5.21372199e-01,  -1.00867018e-01,
                         -1.69188961e-01,  -6.32013202e-01,  -7.20441043e-01,
                         -5.63144863e-01,  -6.02174401e-01,  -6.71539724e-01,
                         -6.28324389e-01,  -6.41623199e-01,  -7.27543890e-01,
                         -7.09463656e-01,  -6.31413162e-01,  -6.25501931e-01,
                         -4.88048643e-01,  -1.24546796e-01,   4.20241356e-02,
                         -2.60081142e-01,  -6.30658031e-01,  -6.23293817e-01,
                         -5.32883048e-01,  -7.04337835e-01,  -6.15906060e-01,
                         -1.46429047e-01,  -2.23592222e-01,  -7.67349601e-01,
                         -6.43519700e-01,  -1.09353058e-01,  -2.50728250e-01,
                         -7.08414197e-01,  -6.49135351e-01,  -5.34940898e-01,
                         -7.58934379e-01,  -5.82385242e-01,  -7.75038078e-02,
                         -2.70721912e-01,  -7.69685984e-01,  -6.48377120e-01,
                         -5.03397644e-01,  -7.18283296e-01,  -5.03976285e-01,
                         -5.49079366e-02,  -3.13474596e-01,  -8.05855155e-01,
                         -5.34705162e-01,  -2.17049886e-02,  -2.97724575e-01,
                         -8.34203720e-01,  -5.50618231e-01,  -3.02051809e-02,
                         -2.96431273e-01,  -6.20092630e-01,  -1.83773190e-01,
                          1.32175431e-01,  -2.70314574e-01,  -6.39326334e-01,
                         -6.23012125e-01,  -6.01051152e-01,  -6.57495737e-01,
                         -6.50564015e-01,  -6.05597913e-01,  -6.35740340e-01,
                         -6.48455679e-01,  -5.09302497e-01,  -5.40383935e-01,
                         -7.65102386e-01,  -5.48669577e-01,  -1.33155376e-01,
                         -2.89701641e-01,  -6.30788684e-01,  -6.42911971e-01,
                         -6.30308092e-01,  -6.84214652e-01,  -6.51703656e-01,
                         -6.10455275e-01,  -6.17934227e-01,  -6.45040154e-01,
                         -6.38125837e-01,  -6.11529648e-01,  -5.95546007e-01,
                         -5.81068695e-01,  -6.87121868e-01,  -6.73826098e-01,
                         -2.40658462e-01,  -1.10015966e-01,  -5.97036898e-01,
                         -7.30400681e-01,  -4.88644600e-01,  -6.22107148e-01,
                         -6.98514998e-01,  -2.34020442e-01,   1.45539403e-01,
                         -8.97000581e-02,  -5.15506566e-01,  -5.96509755e-01,
                         -6.27165198e-01,  -7.01712608e-01,  -2.42812440e-01,
                          2.46035159e-01,  -1.09197251e-01,  -6.38352275e-01,
                         -6.79094195e-01,  -5.84237039e-01,  -5.64861715e-01,
                         -6.59253180e-01,  -6.75687253e-01,  -3.24193120e-01,
                         -1.23085454e-01,  -4.38024729e-01,  -6.86116338e-01,
                         -6.33624732e-01,  -6.12594604e-01,  -6.66880906e-01,
                         -6.15001142e-01,  -5.14626920e-01,  -6.21061981e-01,
                         -6.94626451e-01,  -3.33474219e-01,  -8.57530087e-02,
                         -4.11822736e-01,  -6.73140407e-01,  -5.94673097e-01,
                         -5.87608039e-01,  -6.24422371e-01,  -5.96050680e-01,
                         -6.51195228e-01,  -5.83725810e-01,  -1.67019606e-01,
                          1.52681038e-01,  -1.01976477e-01,  -5.63639879e-01,
                         -6.73379183e-01,  -5.83648920e-01,  -5.98367214e-01,
                         -6.26670539e-01,  -6.10479534e-01,  -6.22273803e-01,
                         -6.43458009e-01,  -6.36101127e-01,  -5.85115016e-01,
                         -5.24720848e-01,  -5.41383743e-01,  -6.22840345e-01,
                         -6.54582918e-01,  -6.10315442e-01,  -5.97043037e-01,
                         -6.24567270e-01,  -5.86081445e-01,  -5.51947594e-01,
                         -6.14807725e-01,  -6.47635818e-01,  -6.07770741e-01,
                         -5.83864093e-01,  -5.87727606e-01,  -6.19574070e-01,
                         -6.29018724e-01,  -5.82650363e-01,  -5.74159622e-01,
                         -5.81895053e-01,  -5.59871018e-01,  -5.88741720e-01,
                         -6.16675735e-01,  -5.93743384e-01,  -5.95100403e-01,
                         -6.04054332e-01,  -6.29311740e-01,  -6.43121243e-01,
                         -5.50572097e-01,  -5.27322114e-01,  -6.14442468e-01,
                         -5.86194754e-01,  -6.08536899e-01,  -6.80081487e-01,
                         -3.80772650e-01,  -9.29163024e-02,  -3.73751819e-01,
                         -6.58792019e-01,  -5.59116602e-01,  -5.46848238e-01,
                         -6.49138033e-01,  -5.82947254e-01,  -5.30702591e-01,
                         -6.06559217e-01,  -6.67517781e-01,  -6.39337957e-01,
                         -5.42533338e-01,  -5.80654800e-01,  -6.90337181e-01,
                         -4.11925256e-01,  -5.40759042e-02,  -3.03119719e-01,
                         -6.55607581e-01,  -5.53259611e-01,  -5.80047488e-01,
                         -7.58423805e-01,  -3.69659126e-01,   5.00569493e-02,
                         -3.72914344e-01,  -7.98814058e-01,  -3.68107557e-01,
                         -6.78813132e-03,  -3.61856252e-01,  -6.68558836e-01,
                         -6.34104192e-01,  -5.24156868e-01,  -2.19209000e-01,
                         -1.19973816e-01,  -5.95826328e-01,  -7.19461381e-01,
                         -1.72265619e-01,  -8.85378271e-02,  -5.80302954e-01,
                         -6.72693968e-01,  -4.99994904e-01,  -6.45938396e-01,
                         -6.24201655e-01,  -1.65098324e-01,  -8.40572789e-02,
                         -5.25730073e-01,  -6.99899077e-01,  -5.97876549e-01,
                         -6.28482938e-01,  -6.21887326e-01,  -5.52170038e-01,
                         -5.82310736e-01,  -5.87212324e-01,  -5.69330633e-01,
                         -5.81934035e-01,  -5.85711002e-01,  -6.72817588e-01,
                         -6.45539165e-01,  -2.33058035e-01,   1.60157934e-01,
                          3.12188361e-02,  -4.57931191e-01,  -7.26401031e-01,
                         -4.59135443e-01,  -3.80319059e-02,   8.37226510e-02,
                          3.37982848e-02,   1.35904914e-02,   6.91072736e-03,
                          3.24909091e-02,   5.60406670e-02,   2.20785644e-02,
                          3.95191647e-03,   4.35316451e-02,   6.61323518e-02,
                          3.20790038e-02,   7.40255276e-03,   4.62194812e-03,
                          2.49132654e-03,   5.79397194e-02,   7.82622099e-02,
                          2.75214724e-02,   9.74100903e-02,   2.33533233e-02,
                         -4.06753451e-01,  -4.91785198e-01,  -4.39752676e-02,
                          1.37282491e-01,  -1.23926960e-02,   7.24013289e-03,
                          8.37387517e-02,   5.34001458e-03,  -2.74869241e-02,
                          1.10949419e-01,   5.89149110e-02,  -3.70219022e-01,
                         -4.73876894e-01,  -1.42582767e-02,   1.34720713e-01,
                         -3.52457948e-02,   9.17245671e-02,   8.29313137e-03,
                         -4.42922145e-01,  -3.84819955e-01,   3.47353294e-02,
                          7.94030875e-02,  -1.60065051e-02,   3.84281315e-02,
                          5.53432256e-02,   3.33457813e-02,   2.45259404e-02,
                          1.79215930e-02,   4.52209525e-02,   2.88513284e-02,
                          9.77131445e-03,   6.06517009e-02,   2.75673773e-02,
                          2.47101951e-02,   1.34202614e-01,  -9.30764303e-02,
                         -4.90622222e-01,  -3.28202993e-01,   8.37213248e-02,
                          9.10841450e-02,  -2.85031293e-02,   2.56835353e-02,
                          5.58283739e-02,   2.38375217e-02,   4.63923663e-02,
                          5.16708270e-02,  -7.64559302e-03,   5.11203110e-02,
                          1.12747766e-01,  -2.09745303e-01,  -5.01240253e-01,
                         -1.87709942e-01,   1.40204743e-01,   3.06298118e-02,
                         -2.26193760e-02,   6.59116358e-02,   4.26141955e-02,
                          3.28977071e-02,   6.61658645e-02,   2.26990357e-02,
                         -1.77925210e-02,   8.92030522e-02,   9.98729244e-02,
                         -3.40723693e-01,  -5.52030444e-01,   3.66773941e-02,
                          2.20475391e-01,  -4.07257855e-01,  -4.33697939e-01,
                         -3.81361023e-02,  -3.44956785e-01,  -5.23089945e-01,
                          5.74851371e-02,   2.04230845e-01,  -4.15428400e-01,
                         -5.56091428e-01,   5.99535331e-02,   2.09845126e-01,
                         -3.80897492e-01,  -5.33317566e-01,  -4.02973853e-02,
                          1.48099020e-01,  -2.86375303e-02,   2.21848208e-02,
                          1.16375498e-01,  -2.83935189e-01,  -7.86511719e-01,
                         -5.35033286e-01,  -1.02132764e-02,  -2.42568597e-01,
                         -5.53896546e-01,  -8.26534778e-02,   2.23483339e-01,
                         -2.39645943e-01,  -6.16130888e-01,  -6.15550458e-01,
                         -6.27125204e-01,  -4.57806498e-01,   5.73375309e-03,
                          1.74914867e-01,  -2.50503242e-01,  -7.09019005e-01,
                         -5.92853069e-01,  -1.30608246e-01,   6.55584335e-02,
                          4.12804447e-02,   3.94005291e-02,  -2.77920514e-01,
                         -7.57672966e-01,  -5.54842234e-01,   5.92712779e-04,
                         -2.09070966e-01,  -7.83644497e-01,  -5.64649820e-01,
                         -2.17472482e-02,  -2.56701946e-01,  -5.95239103e-01,
                         -7.45504647e-02,   2.47356340e-01,  -3.40064853e-01,
                         -5.32961905e-01,  -7.19676614e-02,  -1.90808207e-01,
                         -7.40191340e-01,  -6.86576962e-01,  -7.74728432e-02,
                          2.25793839e-01,  -2.12113544e-01,  -5.67302823e-01,
                         -1.78125292e-01,  -8.30973312e-02,  -7.15317428e-01,
                         -7.36125350e-01,  -8.48024786e-02,  -1.49408549e-01,
                         -6.03637516e-01,  -2.18631715e-01,   2.63724148e-01,
                         -2.09068373e-01,  -6.01013243e-01,  -1.88333884e-01,
                         -1.16405189e-01,  -6.68179393e-01,  -7.58627057e-01,
                         -2.10395440e-01,   1.78368375e-01,  -9.08011794e-02,
                         -5.44278085e-01,  -3.63917410e-01,   7.30215684e-02,
                          3.85019705e-02,  -4.84968498e-02,   5.11669777e-02,
                         -1.31045682e-02,  -2.61418782e-02,   6.20961487e-02,
                         -2.04202831e-01,  -6.59433842e-01,  -7.12859869e-01,
                         -2.89079070e-01,   9.73724574e-02,  -2.45419033e-02,
                         -4.87554908e-01,  -7.35065579e-01,  -4.96951520e-01,
                         -1.02414042e-01,   3.32461037e-02,   5.75850010e-02,
                         -4.66513596e-02,  -5.77054679e-01,  -8.37709248e-01,
                         -3.18216622e-01,  -9.37565714e-02,  -5.19083142e-01,
                         -4.51397687e-01,   1.23442516e-01,   3.90443392e-02,
                         -5.87296069e-01,  -5.06503224e-01,   1.47226512e-01,
                          3.24650519e-02,  -5.54284215e-01,  -3.91152740e-01,
                         -1.11690015e-01,  -4.73592937e-01,  -4.75453913e-01,
                          9.94513482e-02,   3.48882042e-02,  -5.91281414e-01,
                         -5.26001513e-01,   9.73357707e-02,   5.17739505e-02,
                         -5.22399783e-01,  -4.81964469e-01,   3.86775518e-03,
                          7.40175620e-02,  -8.55080709e-02,  -5.93305230e-02,
                         -7.77695375e-03,  -2.12420076e-02,  -3.63001302e-02,
                         -4.52778675e-02,  -1.82784442e-02,  -1.83189881e-03,
                         -3.63735519e-02,  -5.29242940e-02,  -3.40210460e-02,
                         -1.75939649e-02,  -2.16421392e-02,  -3.51646431e-02,
                         -3.02270669e-02,  -2.35329177e-02,  -2.57537179e-02,
                         -2.40534004e-02,  -3.76557484e-02,  -3.90814245e-02,
                         -1.04836253e-02,  -1.60090011e-02,  -4.58712466e-02,
                         -4.70722914e-02,  -2.52108797e-02,   8.71230848e-04,
                         -2.09325254e-02,  -7.19667003e-02,  -4.81330007e-02,
                         -1.09656306e-03,  -2.36482006e-02,  -5.38106337e-02,
                         -4.09070849e-02,  -1.41655905e-02,  -1.68981813e-02,
                         -3.95976119e-02,  -2.64423043e-02,  -2.45698486e-02,
                         -5.49784675e-02,  -3.56206670e-02,  -1.71356834e-02,
                         -3.45360450e-02,  -3.34983282e-02,  -4.83265743e-02,
                         -3.23222727e-02,  -8.23598634e-03,  -7.08085448e-02,
                         -4.94191982e-03,   5.42740524e-02,  -3.11601877e-01,
                         -5.66303372e-01,  -2.18773752e-01,   5.87330572e-02,
                         -4.12097573e-02,  -5.81019521e-02,   1.94846280e-02,
                         -2.99811121e-02,  -7.13904127e-02,  -5.49446372e-03,
                         -2.12838892e-02,  -8.48644897e-02,   5.72747663e-02,
                          9.67431441e-03,  -4.71751243e-01,  -5.10334969e-01,
                         -1.16523594e-01,  -3.58699024e-01,  -7.88741708e-01,
                         -6.39875472e-01,  -5.94187975e-01,  -7.64426470e-01,
                         -4.74022150e-01,  -9.62654967e-03,   7.51975626e-02,
                         -3.90511900e-02,  -1.86008606e-02,  -5.45328595e-02,
                         -4.85598326e-01,  -8.20467234e-01,  -5.12259245e-01,
                         -9.67898071e-02,   4.15339731e-02,   8.82368013e-02,
                         -1.75221741e-01,  -5.55322468e-01,  -3.71444106e-01,
                          4.43329103e-02,   5.58091626e-02,  -7.26025254e-02,
                         -3.13792080e-02,   1.20892199e-02,  -4.43824306e-02,
                         -5.45071252e-02,   4.08520401e-02,  -9.02374983e-02,
                         -5.77435255e-01,  -7.85524309e-01,  -3.99852574e-01,
                         -4.13122959e-02,   3.50742647e-03,   1.96589362e-02,
                         -1.41878486e-01,  -6.06643856e-01,  -7.83760130e-01,
                         -3.61199468e-01,   4.37177680e-02,  -2.67340802e-03,
                         -4.73712347e-02,   8.55086520e-02,  -1.67475715e-01,
                         -5.66771030e-01,  -3.30330640e-01,  -9.71997455e-02,
                         -6.06063247e-01,  -8.37101877e-01,  -2.54322112e-01,
                         -5.39675280e-02,  -6.30130470e-01,  -8.29053402e-01,
                         -2.78287739e-01,  -9.29753706e-02,  -5.48321843e-01,
                         -4.19065833e-01,   1.68854475e-01,  -1.16741262e-01,
                         -6.07254505e-01,  -2.94910401e-01,  -1.98750213e-01,
                         -5.13670564e-01,  -2.86975473e-01,  -1.53132141e-01,
                         -6.69763565e-01,  -7.96091616e-01,  -2.36264780e-01,
                          1.31029651e-01,  -9.42330956e-02,  -5.50259411e-01,
                         -7.20561385e-01,  -6.21397138e-01,  -6.36497676e-01,
                         -7.07993627e-01,  -6.61300600e-01,  -6.47715569e-01,
                         -6.92368209e-01,  -6.80829585e-01,  -6.41849041e-01,
                         -6.43842399e-01,  -6.85592592e-01,  -6.90618873e-01,
                         -6.48294687e-01,  -6.42898560e-01,  -6.56360686e-01,
                         -6.57585919e-01,  -6.74186110e-01,  -6.67439461e-01,
                         -6.53261304e-01,  -6.74175143e-01,  -6.64027274e-01,
                         -6.40729249e-01,  -6.74287438e-01,  -6.95506632e-01,
                         -6.58689141e-01,  -6.37843847e-01,  -6.71170294e-01,
                         -6.90747678e-01,  -6.59857929e-01,  -6.60046875e-01,
                         -6.88043892e-01,  -6.60062730e-01,  -6.44332111e-01,
                         -6.79144263e-01,  -6.83298051e-01,  -6.83958352e-01,
                         -6.92932904e-01,  -6.61426604e-01,  -6.60211384e-01,
                         -6.99636102e-01,  -6.82862639e-01,  -6.44299924e-01,
                         -6.66086078e-01,  -7.04735339e-01,  -6.87992811e-01,
                         -6.58463299e-01,  -6.76130652e-01,  -6.81465626e-01,
                         -6.59922838e-01,  -6.67388558e-01,  -6.70955002e-01,
                         -6.74302816e-01,  -6.93531930e-01,  -6.85340166e-01,
                         -6.90036416e-01,  -6.63222373e-01,  -6.19411349e-01,
                         -7.52660215e-01,  -7.18714774e-01,  -2.52989620e-01,
                         -1.65635258e-01,  -6.57481909e-01,  -7.77040839e-01,
                         -5.91128409e-01,  -7.25370407e-01,  -6.70772135e-01,
                         -2.02939883e-01,  -2.07767919e-01,  -7.52366126e-01,
                         -7.79241502e-01,  -2.01362029e-01,  -1.39382645e-01,
                         -7.24628747e-01,  -8.09251070e-01,  -2.27773756e-01,
                         -1.10040866e-01,  -6.83934450e-01,  -8.51801991e-01,
                         -3.04561347e-01,  -1.15213372e-01,  -5.91965318e-01,
                         -7.83551812e-01,  -6.06744468e-01,  -7.31110096e-01,
                         -7.63044178e-01,  -2.68131137e-01,  -1.09521173e-01,
                         -6.70762241e-01,  -8.55500698e-01,  -2.95197308e-01,
                         -1.24079198e-01,  -6.09200060e-01,  -8.04579854e-01,
                         -6.47749662e-01,  -6.48536205e-01,  -6.91010833e-01,
                         -6.93784833e-01,  -7.09750593e-01,  -6.71268702e-01,
                         -7.06080317e-01,  -7.02391982e-01,  -5.91045201e-01,
                         -7.38449275e-01,  -7.94816434e-01,  -3.32820773e-01,
                         -1.50835574e-01,  -5.73661804e-01,  -8.00053120e-01,
                         -6.62576318e-01,  -6.06086850e-01,  -7.11408317e-01,
                         -7.71518290e-01,  -5.40620327e-01,  -9.31593776e-02,
                          4.98573147e-02,  -3.50970209e-01,  -7.52057135e-01,
                         -6.93515003e-01,  -6.28485739e-01,  -7.84817338e-01,
                         -5.63782215e-01,  -1.61631897e-01,  -3.54156405e-01,
                         -7.47994006e-01,  -7.27778256e-01,  -6.35013223e-01,
                         -7.17225909e-01,  -7.23292589e-01,  -6.39818490e-01,
                         -6.73112392e-01,  -7.21424162e-01,  -6.46960735e-01,
                         -7.03890681e-01,  -7.76211560e-01,  -4.32982236e-01,
                         -1.64449051e-01,  -4.54081118e-01,  -7.47025907e-01,
                         -7.70883024e-01,  -6.19757235e-01,  -2.30559349e-01,
                         -1.93526104e-01,  -7.45648205e-01,  -8.18105698e-01,
                         -2.05663562e-01,  -1.20463625e-01,  -7.04753935e-01,
                         -7.89710939e-01,  -2.59094447e-01,  -1.84668601e-01,
                         -6.36224031e-01,  -7.70347476e-01,  -6.31872892e-01,
                         -6.94166243e-01,  -7.80299008e-01,  -6.70645058e-01,
                         -6.00566149e-01,  -7.62605250e-01,  -7.40005016e-01,
                         -2.32242242e-01,  -9.83463228e-02,  -7.24677980e-01,
                         -8.61630559e-01,  -2.21825376e-01,  -1.01359695e-01,
                         -6.28162742e-01,  -8.15702021e-01,  -6.29477620e-01,
                         -6.53286755e-01,  -7.31148779e-01,  -3.64180297e-01,
                          6.49255291e-02,  -1.21109039e-01,  -5.70027113e-01,
                         -6.82212055e-01,  -6.34108424e-01,  -6.71278954e-01,
                         -6.82810068e-01,  -6.50791585e-01,  -7.00161994e-01,
                         -6.84477329e-01,  -3.10753942e-01,   5.80405034e-02,
                         -1.41306207e-01,  -5.30898809e-01,  -6.77281559e-01,
                         -7.79951274e-01,  -6.28968060e-01,  -1.64135858e-01,
                         -2.35838845e-01,  -7.92503059e-01,  -6.90602958e-01,
                         -1.52815849e-01,  -2.87408203e-01,  -5.86414397e-01,
                         -1.44043475e-01,   1.76233456e-01,  -3.36594850e-01,
                         -6.51435256e-01,  -2.02387512e-01,   1.32356197e-01,
                         -1.71676189e-01,  -6.36172414e-01,  -7.75496960e-01,
                         -6.80356383e-01,  -5.98878920e-01,  -6.02706373e-01,
                         -7.08379388e-01,  -5.46171129e-01,   4.76786494e-02,
                          1.08105883e-01,  -4.89213586e-01,  -4.56013948e-01,
                         -1.09337226e-01,  -4.14546907e-01,  -4.60281610e-01,
                         -1.04956619e-01,  -4.86070663e-01,  -8.72916341e-01,
                         -3.51683080e-01,  -5.72815798e-02,  -5.04379511e-01,
                         -7.38139510e-01,  -5.87164402e-01,  -5.89958012e-01,
                         -6.85869992e-01,  -6.26884282e-01,  -5.86842179e-01,
                         -6.58732951e-01,  -6.57315552e-01,  -6.20462179e-01,
                         -6.57446444e-01,  -6.31679237e-01,  -5.56796014e-01,
                         -6.02047086e-01,  -6.93309188e-01,  -6.68215930e-01,
                         -5.66881478e-01,  -5.69321394e-01,  -6.68706119e-01,
                         -6.62525237e-01,  -6.00140512e-01,  -5.93595147e-01,
                         -5.52003860e-01,  -6.17675722e-01,  -7.61514366e-01,
                         -5.03196478e-01,  -1.06073320e-01,  -2.64426142e-01,
                         -6.14004314e-01,  -5.89863062e-01,  -5.15961111e-01,
                         -6.27037942e-01,  -6.33673429e-01,  -5.39524138e-01,
                         -6.42955840e-01,  -7.43953764e-01,  -4.07953143e-01,
                         -5.04758023e-02,  -3.12564701e-01,  -6.92628622e-01,
                         -5.80130696e-01,  -4.57261741e-01,  -6.51457906e-01,
                         -6.87567890e-01,  -4.90474135e-01,  -5.22461653e-01,
                         -6.60451293e-01,  -3.85353863e-01,  -2.79312897e-02,
                         -2.59987712e-01,  -6.86306655e-01,  -6.74078882e-01,
                         -5.16428232e-01,  -5.21982491e-01,  -5.34972668e-01,
                         -5.47812581e-01,  -6.08442307e-01,  -6.45544708e-01,
                         -6.15002871e-01,  -5.21385908e-01,  -5.03660381e-01,
                         -5.92576623e-01,  -5.84461749e-01,  -5.14312506e-01,
                         -5.57072759e-01,  -6.19101226e-01,  -5.80877066e-01,
                         -4.93596226e-01,  -4.64222997e-01,  -5.17940521e-01,
                         -5.64029515e-01,  -6.02877498e-01,  -6.41616344e-01,
                         -5.55133283e-01,  -4.33347434e-01,  -4.80161697e-01,
                         -6.00536227e-01,  -6.25067890e-01,  -5.50032973e-01,
                         -4.82638061e-01,  -5.17820895e-01,  -5.64622343e-01,
                         -5.56475282e-01,  -5.66960573e-01,  -5.30435562e-01,
                         -4.49918717e-01,  -5.13139606e-01,  -6.39734745e-01,
                         -6.05515242e-01,  -4.70833838e-01,  -4.43749666e-01,
                         -5.57170808e-01,  -6.05053127e-01,  -5.19148946e-01,
                         -5.16540706e-01,  -5.79180479e-01,  -5.08234262e-01,
                         -4.31187391e-01,  -5.04706919e-01,  -6.13294065e-01,
                         -6.26818180e-01,  -5.34304976e-01,  -4.57060486e-01,
                         -4.84600693e-01,  -5.14087141e-01,  -5.16018212e-01,
                         -5.48321426e-01,  -5.36347330e-01,  -4.86048341e-01,
                         -5.09664118e-01,  -5.67122757e-01,  -5.69151580e-01,
                         -5.31146109e-01,  -5.27549207e-01,  -5.73081911e-01,
                         -5.62320411e-01,  -4.95174557e-01,  -5.04773438e-01,
                         -5.52243710e-01,  -5.38952768e-01,  -5.28797686e-01,
                         -5.60097933e-01,  -5.59907377e-01,  -4.97977525e-01,
                         -4.63778317e-01,  -5.22729456e-01,  -5.68743765e-01,
                         -5.43240607e-01,  -5.10091066e-01,  -4.77546960e-01,
                         -5.49850821e-01,  -6.63977385e-01,  -3.81357908e-01,
                          4.41769473e-02,  -1.76688984e-01,  -6.61734879e-01,
                         -6.19495690e-01,  -4.37599123e-01,  -5.26694000e-01,
                         -5.93246877e-01,  -6.14711404e-01,  -5.53124070e-01,
                         -1.61651179e-01,   3.49261761e-02,  -4.43260580e-01,
                         -7.38582790e-01,  -2.62934178e-01,   1.93131715e-02,
                         -3.92416805e-01,  -6.14506602e-01,  -4.62048590e-01,
                         -5.85448086e-01,  -6.33773506e-01,  -1.70983568e-01,
                          3.20592476e-03,  -4.21635091e-01,  -6.43656731e-01,
                         -5.33641934e-01,  -5.38892031e-01,  -5.76755464e-01,
                         -5.58670163e-01,  -5.73736548e-01,  -5.26068807e-01,
                         -5.43195665e-01,  -6.31390274e-01,  -3.63631397e-01,
                         -3.75248790e-02,  -2.95624256e-01,  -6.45377576e-01,
                         -5.74976325e-01,  -5.35848022e-01,  -6.28391266e-01,
                         -5.70742309e-01,  -5.16652524e-01,  -5.14114499e-01,
                         -5.02379179e-01,  -6.10315859e-01,  -6.09689474e-01,
                         -2.36032978e-01,   1.64150819e-01,   7.64434040e-02,
                         -4.87150192e-01,  -7.40090191e-01,  -2.60373652e-01,
                         -2.84386277e-02,  -4.57211524e-01,  -4.21596348e-01,
                          1.08071409e-01,   1.25570163e-01,   1.06116952e-02,
                          1.77870855e-01,  -1.17972024e-01,  -5.86893737e-01,
                         -2.61031628e-01,   2.20280781e-01,   4.60225753e-02,
                         -9.18997526e-02,   1.06983997e-01,  -1.21630706e-01,
                         -5.28476477e-01,  -2.01498091e-01,   2.37736762e-01,
                         -1.57452762e-01,  -5.28710246e-01,  -1.36046275e-01,
                         -6.46923110e-02,  -6.75273716e-01,  -6.64171457e-01,
                         -4.26814444e-02,  -1.28113389e-01,  -5.66396594e-01,
                         -2.76179999e-01,   1.41016871e-01,   3.31414379e-02,
                          1.96853671e-02,   1.00211136e-01,  -2.85399884e-01,
                         -5.23640394e-01,  -1.05642743e-01,   1.51832417e-01,
                         -2.57689077e-02,   8.34846962e-03,   6.11329004e-02,
                         -3.10991526e-01,  -4.81372774e-01,  -4.91411388e-02,
                          1.57646045e-01,  -3.29194814e-01,  -5.86092770e-01,
                         -5.51332608e-02,   2.22005591e-01,  -2.99008936e-01,
                         -5.31501889e-01,  -1.33723661e-01,   7.47380480e-02,
                          6.99158758e-02,  -1.64979650e-03,  -3.80900949e-01,
                         -4.46407825e-01,   6.43454492e-02,   7.16093406e-02,
                         -4.85805184e-01,  -4.91492510e-01,  -1.09556429e-02,
                          1.40871868e-01,  -3.59089836e-03,  -1.32560087e-02,
                          8.38205069e-02,   4.07151431e-02,  -4.86857221e-02,
                          1.61460154e-02,   5.91700263e-02,  -3.79857086e-02,
                         -4.60883081e-02,   5.48734404e-02,   6.41991869e-02,
                          8.05333070e-03,   4.54403413e-03,   1.81779750e-02,
                         -5.85889816e-03,  -7.83492438e-03,   3.74168567e-02,
                          3.57986949e-02,   5.35781635e-03,   3.72146107e-02,
                          3.99790853e-02,  -2.23086812e-02,   5.92031656e-03,
                          8.64815637e-02,   2.81649996e-02,  -8.35682824e-02,
                         -3.93121280e-02,   6.23846240e-02,   2.35115010e-02,
                         -4.36379761e-02,   5.08471020e-03,   4.45657149e-02,
                          1.35195768e-02,   1.79683957e-02,   5.02510965e-02,
                          3.45797949e-02,  -2.34983694e-02,  -5.64025231e-02,
                         -8.35296232e-03,   4.46608327e-02,   9.80192423e-03,
                         -1.85088105e-02,   5.26123270e-02,   1.12646922e-01,
                          4.36967500e-02,  -5.81098199e-02,  -4.24195267e-02,
                          1.33454455e-02,  -1.49206715e-02,  -2.91001145e-02,
                          2.53585801e-02,   2.96851378e-02,  -5.64121362e-03,
                          2.30305828e-02,   5.63386902e-02,  -2.02736305e-03,
                         -5.12285642e-02,   2.61829775e-02,   7.31813461e-02,
                         -2.93583851e-02,  -5.70652820e-02,   4.79042418e-02,
                          3.65685672e-02,  -2.49552820e-02,   6.05058484e-02,
                          8.61179736e-03,  -4.26622242e-01,  -7.74191678e-01,
                         -5.33719063e-01,  -5.60993925e-02,   8.70353729e-02,
                          3.89907556e-03,  -1.62059292e-02,  -2.14564223e-02,
                         -1.16679640e-02,   5.11203408e-02,   5.16386405e-02,
                          4.82383696e-03,  -1.79755427e-02,  -4.93900403e-02,
                         -1.93503629e-02,   7.12377056e-02,   3.18577029e-02,
                         -8.42755288e-02,  -3.69884036e-02,   9.05082822e-02,
                          5.52917719e-02,  -5.94362579e-02,  -3.79932933e-02,
                          4.17100564e-02,   1.72347836e-02,  -5.01825437e-02,
                         -6.26270324e-02,  -2.28865799e-02,   2.98577342e-02,
                          3.41832899e-02,  -3.12345597e-04,  -1.81084704e-02,
                         -3.49478759e-02,  -3.23895961e-02,   1.18231028e-02,
                          2.16323193e-02,   2.68200575e-03,   2.02499889e-02,
                          2.80852374e-02,  -1.33445989e-02,  -6.88985810e-02,
                         -7.30285868e-02,  -4.72143525e-04,   1.34467082e-02,
                         -6.64902031e-02,  -2.31789723e-02,   1.05739072e-01,
                          6.04874827e-02,  -4.49793525e-02,  -1.49047077e-02,
                         -5.64970681e-03,  -6.81596622e-02,  -2.48975214e-02,
                          4.40600142e-02,  -2.83006541e-02,  -7.34587014e-02,
                          3.08862552e-02,   4.84383143e-02,  -8.80834535e-02,
                         -1.03623465e-01,   1.17084887e-02,  -6.37912937e-03,
                         -9.38774422e-02,  -1.77483708e-02,   9.51824039e-02,
                          2.69158576e-02,  -9.47049558e-02,  -6.09578602e-02,
                          3.23665589e-02,  -8.53890833e-03,  -4.64362353e-02,
                          6.08802810e-02,  -1.18845545e-01,  -7.06026554e-01,
                         -7.91446149e-01,  -2.31270969e-01,  -1.68350831e-01,
                         -5.28435290e-01,  -3.20963919e-01,  -1.33372501e-01,
                         -6.34697676e-01,  -7.94669211e-01,  -2.26411715e-01,
                         -8.47841725e-02,  -6.25005782e-01,  -7.75646627e-01,
                         -2.77954251e-01,  -1.09358601e-01,  -5.45367956e-01,
                         -7.82100677e-01,  -6.76176727e-01,  -6.41386747e-01,
                         -6.08432591e-01,  -6.62858367e-01,  -8.19657028e-01,
                         -5.48681378e-01,  -1.36131778e-01,  -3.04672420e-01,
                         -6.54543757e-01,  -6.99197114e-01,  -6.93945467e-01,
                         -7.24868834e-01,  -6.42654002e-01,  -5.44066012e-01,
                         -6.64963126e-01,  -8.01067650e-01,  -4.75343138e-01,
                         -1.67729110e-01,  -4.42962408e-01,  -4.67390150e-01,
                         -7.45273829e-02,  -3.69113058e-01,  -9.07689393e-01,
                         -5.75875282e-01,  -1.41328678e-01,  -4.21196193e-01,
                         -6.74563527e-01,  -5.46470881e-01,  -6.72635376e-01,
                         -8.57060075e-01,  -4.46837842e-01,  -1.34443924e-01,
                         -4.29653347e-01,  -3.71369958e-01,  -1.01071700e-01,
                         -6.06639624e-01,  -9.24968541e-01,  -3.14749628e-01,
                         -1.42633975e-01,  -6.29691064e-01,  -4.05000716e-01,
                          2.44355708e-01,  -2.34058723e-02,  -6.80655539e-01,
                         -4.51786488e-01,  -7.92381316e-02,  -6.00996196e-01,
                         -9.15372372e-01,  -3.27419072e-01,  -7.17785284e-02,
                         -5.12348294e-01,  -8.03381801e-01,  -7.98786104e-01,
                         -6.27010465e-01,  -1.99845180e-01,   1.24831051e-01,
                         -1.60911739e-01,  -7.77488172e-01,  -8.04919600e-01,
                         -2.28201002e-01,  -1.02666609e-01,  -5.56857169e-01,
                         -8.23889971e-01,  -8.13763022e-01,  -5.98094940e-01,
                         -2.18854666e-01,  -3.46690238e-01,  -8.30203533e-01,
                         -5.76180875e-01,  -8.50713104e-02,  -4.16462451e-01,
                         -6.07040524e-01,  -1.25938237e-01,  -3.20179045e-01,
                         -9.19664204e-01,  -5.54482758e-01,  -1.23910353e-01,
                         -4.94929582e-01,  -5.84741473e-01,  -2.37548739e-01,
                         -3.86531144e-01,  -8.08530569e-01,  -6.70201242e-01,
                         -7.15531260e-02,   3.19237188e-02,  -4.66598719e-01,
                         -5.20461202e-01,  -2.08352044e-01,  -3.80492896e-01,
                         -5.50076067e-01,  -2.33399779e-01,   5.48683032e-02,
                          2.34558713e-02,  -3.27356160e-01,  -6.05463982e-01,
                         -3.66373092e-01,  -2.92382330e-01,  -7.48988450e-01,
                         -7.82175541e-01,  -2.50148773e-01,  -1.54742599e-02,
                         -1.35465026e-01,  -1.03932679e-01,  -3.53091657e-02,
                         -3.31006110e-01,  -6.03439331e-01,  -3.49363387e-01,
                         -5.43926284e-02,  -2.22929269e-02,  -5.34269251e-02,
                         -4.75738019e-01,  -9.58286822e-01,  -5.95103443e-01,
                         -9.96770263e-02,  -3.96550328e-01,  -7.82494068e-01,
                         -7.96846509e-01,  -7.52958953e-01,  -4.65823650e-01,
                         -6.86923135e-03,  -1.01572432e-01,  -6.62140310e-01,
                         -8.35451782e-01,  -6.07309341e-01,  -6.42709374e-01,
                         -8.36411536e-01,  -5.78871548e-01,  -6.37993887e-02,
                         -2.84482706e-02,  -4.96909022e-01,  -8.17831039e-01,
                         -8.17425549e-01,  -7.64892638e-01,  -4.81802225e-01,
                         -1.25437295e-02,  -1.09799497e-01,  -5.93103588e-01,
                         -4.57072228e-01,  -1.63345337e-01,  -6.38512313e-01,
                         -9.45902407e-01,  -3.86572152e-01,  -2.12431729e-01,
                         -6.33870423e-01,  -4.50457662e-01,  -1.79694727e-01,
                         -6.57153428e-01,  -8.85194123e-01,  -6.42553627e-01,
                         -7.80707002e-01,  -7.85425901e-01,  -2.69753188e-01,
                         -2.35516772e-01,  -7.92773783e-01,  -8.60892475e-01,
                         -2.99225718e-01,  -1.62130952e-01,  -7.57052183e-01,
                         -9.60923493e-01,  -3.60863984e-01,   2.18523871e-02,
                         -9.56099704e-02,  -1.50237083e-01,  -3.13275099e-01,
                         -7.53009021e-01,  -7.97219515e-01,  -3.03580284e-01,
                         -1.98644698e-01,  -6.87825799e-01,  -8.46838355e-01,
                         -6.24208331e-01,  -6.81608975e-01,  -7.90022612e-01,
                         -7.57897317e-01,  -7.98030138e-01,  -5.76201081e-01,
                         -2.37279102e-01,  -4.03330624e-01,  -7.10513711e-01,
                         -7.40190208e-01,  -7.47734725e-01,  -7.68969595e-01,
                         -7.46182680e-01,  -7.16488659e-01,  -6.73100233e-01,
                         -7.12424576e-01,  -6.19472623e-01,  -1.85594663e-01,
                          3.63935381e-02,  -3.22802931e-01,  -7.08088636e-01,
                         -6.97268784e-01,  -6.56385362e-01,  -8.01946998e-01,
                         -7.43773460e-01,  -5.80219090e-01,  -6.83148265e-01,
                         -5.56403220e-01,  -1.68039113e-01,  -3.64436626e-01,
                         -8.08969617e-01,  -7.50125051e-01,  -6.28279328e-01,
                         -7.14476824e-01,  -7.09772646e-01,  -6.68918073e-01,
                         -6.66834474e-01,  -6.42277300e-01,  -6.11031771e-01,
                         -6.48379982e-01,  -7.65180111e-01,  -5.21636963e-01,
                          8.68035629e-02,   6.09228313e-02,  -5.42425156e-01,
                         -5.34563005e-01,  -6.48641959e-02,   6.11075871e-02,
                          2.29572644e-03,  -1.53554261e-01,  -5.33849061e-01,
                         -6.88333392e-01,  -5.73548555e-01,  -6.84563279e-01,
                         -6.90694094e-01,  -2.20183522e-01,  -1.07646473e-01,
                         -6.72897696e-01,  -7.76987135e-01,  -1.52702644e-01,
                          4.92431689e-04,  -5.62595546e-01,  -7.69940138e-01,
                         -3.20204705e-01,   1.57408882e-02,  -2.03447733e-02,
                         -6.71413494e-03,   4.94962782e-02,  -3.15647498e-02,
                          2.84768958e-02,   1.32865578e-01,  -1.84917986e-01,
                         -4.82375294e-01,  -1.67145863e-01,   1.32980213e-01,
                         -4.95268144e-02,  -7.50489011e-02,   1.51363537e-01,
                          1.10783398e-01,   2.05276068e-02,  -8.16002581e-03,
                         -3.01889926e-01,  -4.03621554e-01,  -2.59280894e-02,
                          1.53345227e-01,   2.47765761e-02,  -5.79783553e-03,
                          1.59472916e-02,   5.87947071e-02,   8.13406408e-02,
                          8.50817363e-04,   3.81882973e-02,   1.19720787e-01,
                          4.81417961e-02,   1.51150804e-02,   3.33026536e-02,
                          1.10614248e-01,   2.51672059e-01,   2.35254806e-03,
                         -4.39427644e-01,  -3.44635665e-01,   2.55612321e-02,
                          1.81139231e-01,   1.04035243e-01,  -2.46337727e-01,
                         -4.42067653e-01,  -1.11367419e-01,   1.71940967e-01,
                          1.03703253e-01,  -3.10872551e-02,  -3.20744663e-01,
                         -6.83389068e-01,  -5.23079336e-01,   9.96796042e-02,
                          2.52304673e-01,  -2.80955642e-01,  -4.81594652e-01,
                         -2.63963677e-02,   1.91987425e-01,   3.65757532e-02,
                          7.33954757e-02,   1.40725642e-01,   4.68135402e-02,
                          6.99225068e-02,   1.20516382e-01,   2.83565260e-02,
                          3.30939665e-02,   1.42622828e-01,   1.12245396e-01,
                          1.09490782e-01,   2.35588178e-01,   1.19623728e-02,
                         -4.55322742e-01,  -3.02120775e-01,   2.11084321e-01,
                          1.27324641e-01,  -9.56203565e-02,   1.54304817e-01,
                          4.93675806e-02,  -5.25712192e-01,  -3.46119821e-01,
                          2.95336485e-01,   1.95983648e-02,  -5.15988410e-01,
                         -1.65388256e-01,   3.19247544e-02,  -4.59748507e-01,
                         -3.04006904e-01,   2.79863030e-01,  -3.29901017e-02,
                         -5.06529570e-01,  -2.18441308e-01,   1.16411135e-01,
                          1.61849052e-01,   6.67478815e-02,  -3.19161355e-01,
                         -4.34097230e-01,   4.95967343e-02,   1.77624911e-01,
                         -2.80011266e-01,  -5.38729727e-01,  -5.80523908e-01,
                         -5.60010910e-01,  -2.39783376e-01,  -8.49385709e-02,
                         -5.04257500e-01,  -7.50483930e-01,  -3.22334170e-01,
                          1.65165782e-01,   1.24056965e-01,  -2.79787779e-01,
                         -5.56514859e-01,  -6.10821605e-01,  -6.31617427e-01,
                         -3.88343573e-01,   1.16183631e-01,   1.15189031e-01,
                         -3.87301177e-01,  -5.87848067e-01,  -5.97155392e-01,
                         -6.03519142e-01,  -1.88696444e-01,   1.62894204e-02,
                         -5.64075649e-01,  -7.22102702e-01,  -1.56845674e-01,
                         -1.85054183e-01,  -5.08304238e-01,  -1.75915986e-01,
                         -4.56393659e-02,  -4.10297751e-01,  -2.10761547e-01,
                          1.57117382e-01,  -2.15879574e-01,  -5.01174867e-01,
                         -9.76170376e-02,   1.44877359e-01,   6.61754142e-03,
                          6.57567531e-02,   4.31549959e-02,  -3.61871988e-01,
                         -4.09000963e-01,  -8.70753974e-02,  -2.96822727e-01,
                         -4.96377230e-01,   5.01728989e-02,   1.42527327e-01,
                         -5.07975042e-01,  -4.13457215e-01,   4.14310060e-02,
                         -3.47248137e-01,  -5.08693755e-01,   1.65130064e-01,
                          1.86937615e-01,  -5.17274797e-01,  -4.46542591e-01,
                          3.93339731e-02,  -3.65357548e-01,  -8.85751009e-01,
                         -4.36205447e-01,  -4.75254022e-02,  -3.82003039e-01,
                         -3.78797024e-01,   5.74245676e-02,   1.19161800e-01,
                         -2.36707972e-03,  -1.78745404e-01,  -6.11906350e-01,
                         -6.73138261e-01,  -1.61010221e-01,  -5.25807850e-02,
                         -5.94520807e-01,  -7.43843377e-01,  -1.91557124e-01,
                         -7.15511143e-02,  -5.47092915e-01,  -3.22587430e-01,
                          2.55024016e-01,  -1.20638505e-01,  -5.59959769e-01,
                         -2.27034852e-01,  -1.82118982e-01,  -4.33834463e-01,
                         -2.19728932e-01,  -1.76867798e-01,  -5.69568992e-01,
                         -6.84092462e-01,  -5.94917536e-01,  -6.23328924e-01,
                         -5.82957089e-01,  -5.08771122e-01,  -5.66384494e-01,
                         -6.65517449e-01,  -5.57550669e-01,  -1.02625616e-01,
                          1.94972619e-01,  -1.76015571e-01,  -6.24134302e-01,
                         -6.07892156e-01,  -5.73235214e-01,  -5.29230177e-01,
                         -1.00142948e-01,   1.43093407e-01,  -2.22774655e-01,
                         -5.76298654e-01,  -5.88693142e-01,  -5.80224633e-01,
                         -6.74572945e-01,  -5.62297165e-01,  -4.02525477e-02,
                          2.16347083e-01,  -2.63216078e-01,  -4.95688200e-01,
                         -1.64322764e-01,  -2.66461641e-01,  -4.73504633e-01,
                         -1.13898285e-01,  -1.37241930e-01,  -6.78924978e-01,
                         -5.78226447e-01,  -6.03804216e-02,   4.88697877e-03,
                         -4.71179150e-02,   1.46448180e-01,   9.74883363e-02,
                         -3.27981591e-01,  -4.73469615e-01,  -1.36270761e-01,
                          1.02816798e-01,   5.76642863e-02,   4.40182984e-02,
                          8.87002796e-02,   8.29091072e-02,   3.17609943e-02,
                         -4.82897051e-02,  -4.78856377e-02,   5.46355322e-02,
                          9.83015746e-02,   4.95677665e-02,   1.70518365e-02,
                          3.45017575e-02,   3.43276337e-02,   1.06634498e-02,
                          4.05051485e-02,   6.04230016e-02,   7.42598576e-03,
                         -1.64095836e-03,   4.67804223e-02,   8.02477151e-02,
                          7.86915198e-02,   2.24383287e-02,   3.69302332e-02,
                          9.36295763e-02,  -4.50389646e-02,  -8.44759718e-02,
                          1.71451285e-01,   5.54479025e-02,  -4.42396581e-01,
                         -3.85846019e-01,   7.88274258e-02,   6.55436292e-02,
                         -1.12292379e-01,   9.30666775e-02,   3.54625797e-03,
                         -5.44997096e-01,  -4.06737804e-01,   2.62657583e-01,
                          6.34459034e-02,  -5.68288028e-01,  -3.40075850e-01,
                          1.75974309e-01,   8.23972151e-02,  -1.27195567e-01,
                         -1.96708143e-02,   8.14382881e-02,   7.19529688e-02,
                          1.26995042e-01,   1.19445927e-01,  -3.34323570e-02,
                         -1.93976460e-03,   1.29786536e-01,  -1.72579646e-01,
                         -5.28607845e-01,  -1.94621727e-01,   2.36241996e-01,
                         -9.28483456e-02,  -6.36330366e-01,  -6.44370377e-01,
                         -5.01774549e-01,  -6.42984271e-01,  -6.31764054e-01,
                         -2.48431921e-01,   1.50297070e-02,   6.97197393e-02,
                          1.12876385e-01,  -1.91929966e-01,  -7.23406494e-01,
                         -6.54361367e-01,  -8.54469612e-02,   1.56663194e-01,
                         -7.70909935e-02,  -4.94197786e-01,  -7.12293684e-01,
                         -3.94449592e-01,   3.59835215e-02,   4.67920601e-02,
                         -1.47037283e-02,   7.87068158e-02,   1.13535924e-02,
                         -6.70879334e-02,   8.22047889e-02,   6.33022701e-03,
                         -5.07280231e-01,  -7.63436735e-01,  -3.67392600e-01,
                          3.79426554e-02,   7.24028125e-02,   7.67014995e-02,
                         -1.15335703e-01,  -6.65623486e-01,  -7.98194051e-01,
                         -2.96325624e-01,   8.32631662e-02,   9.25411433e-02,
                         -3.86078171e-02,  -7.07315803e-02,   1.29251093e-01,
                          8.21294039e-02,  -3.96020830e-01,  -5.14039338e-01,
                         -1.13825187e-01,   6.34217560e-02,  -3.89001146e-02,
                          5.13835251e-02,   1.61238164e-01,  -6.25532046e-02,
                         -1.42670900e-01,   1.90983504e-01,   8.19929466e-02,
                         -4.73357320e-01,  -3.96151483e-01,  -9.53129008e-02,
                         -3.97300869e-01,  -5.03439188e-01,  -4.14344333e-02,
                          1.95450112e-01,   4.50317860e-02,  -2.64807999e-01,
                         -6.40300691e-01,  -6.81592584e-01,  -2.61268169e-01,
                          9.69994888e-02,  -4.38211523e-02,  -4.85256791e-01,
                         -7.15613842e-01,  -6.34895325e-01,  -5.38446009e-01,
                         -5.96506953e-01,  -6.68679774e-01,  -4.49184418e-01,
                         -1.30269274e-01,  -2.83275962e-01,  -6.67315841e-01,
                         -7.13199615e-01,  -6.19581640e-01,  -6.33521855e-01,
                         -6.55788362e-01,  -6.49491727e-01,  -5.59484541e-01,
                         -5.01120746e-01,  -6.13952994e-01,  -6.53213501e-01,
                         -5.86190939e-01,  -6.33418024e-01,  -6.57847166e-01,
                         -5.72390735e-01,  -5.67440987e-01,  -6.42960489e-01,
                         -6.47280753e-01,  -5.87730408e-01,  -6.21645391e-01,
                         -7.20990181e-01,  -6.74573541e-01,  -5.72273433e-01,
                         -5.84358335e-01,  -5.83673656e-01,  -5.53578913e-01,
                         -6.00980639e-01,  -6.66908085e-01,  -6.87122345e-01,
                         -6.38770223e-01,  -5.88058293e-01,  -6.20666206e-01,
                         -6.14546299e-01,  -5.91256618e-01,  -6.85292900e-01,
                         -6.88398421e-01,  -5.52291155e-01,  -5.42140365e-01,
                         -6.11229777e-01,  -6.25095785e-01,  -6.40095055e-01,
                         -6.47479475e-01,  -6.34042561e-01,  -5.93023598e-01,
                         -5.33449650e-01,  -5.87899029e-01,  -7.06612587e-01,
                         -6.93223536e-01,  -6.05567515e-01,  -5.90782106e-01,
                         -6.39746130e-01,  -6.53739154e-01,  -6.04491889e-01,
                         -6.11834168e-01,  -6.69903636e-01,  -6.47326589e-01,
                         -6.16225958e-01,  -6.37342393e-01,  -6.32972836e-01,
                         -6.22243226e-01,  -6.18235826e-01,  -6.24077916e-01,
                         -6.57995343e-01,  -6.43024683e-01,  -6.52871609e-01,
                         -7.19137609e-01,  -6.16376698e-01,  -5.12529254e-01,
                         -6.57613695e-01,  -7.26216435e-01,  -6.60665631e-01,
                         -6.48015141e-01,  -4.08221960e-01,  -1.30012095e-01,
                         -3.75004679e-01,  -7.35853970e-01,  -7.05772996e-01,
                         -6.18058383e-01,  -6.56670690e-01,  -6.76049948e-01,
                         -7.06220806e-01,  -7.04194665e-01,  -6.22306406e-01,
                         -5.86261630e-01,  -6.20091081e-01,  -6.71154141e-01,
                         -6.91112518e-01,  -6.20950520e-01,  -5.81724286e-01,
                         -6.74202204e-01,  -7.35053122e-01,  -7.04814911e-01,
                         -6.87527180e-01,  -6.54535115e-01,  -6.06865704e-01,
                         -6.20379150e-01,  -6.56591713e-01,  -7.06173062e-01,
                         -7.32887387e-01,  -6.37817860e-01,  -6.31528437e-01,
                         -7.78395116e-01,  -5.78776121e-01,  -1.43455505e-01,
                         -2.63000667e-01,  -7.29593396e-01,  -7.81841934e-01,
                         -6.21056974e-01,  -6.30727172e-01,  -6.72118545e-01,
                         -7.54360497e-01,  -7.32690513e-01,  -2.94133067e-01,
                         -6.04368784e-02,  -5.92404604e-01,  -8.87570798e-01,
                         -3.44309866e-01,  -1.08381636e-01,  -5.27478158e-01,
                         -4.94047016e-01,  -4.11886023e-03,  -3.00268717e-02,
                         -4.92639899e-01,  -6.86868608e-01,  -5.87326527e-01,
                         -6.52215660e-01,  -8.12347114e-01,  -5.12722194e-01,
                         -1.28138363e-01,  -4.69966352e-01,  -8.39010298e-01,
                         -4.22208488e-01,  -1.03969119e-01,  -4.49051529e-01,
                         -7.30296135e-01,  -7.01065361e-01,  -6.35300756e-01,
                         -4.04928803e-01,  -5.67368492e-02,  -1.01848014e-01,
                         -5.76184511e-01,  -7.98338294e-01,  -4.60897177e-01,
                         -2.23789066e-02,   5.34780324e-02,  -3.38436276e-01,
                         -7.80426204e-01,  -6.74983263e-01,  -2.79335707e-01,
                         -8.78254548e-02,   4.79009822e-02,  -3.48163359e-02,
                         -4.46381658e-01,  -4.63624358e-01,  -1.69723362e-01,
                         -4.40603822e-01,  -8.62359643e-01,  -5.47885358e-01,
                         -8.41065794e-02,  -4.09971088e-01,  -8.83396685e-01,
                         -5.38698256e-01,  -1.43711701e-01,  -4.63530064e-01,
                         -5.58544457e-01,  -6.08104840e-02,   9.87849310e-02,
                         -1.76340133e-01,  -2.25282222e-01,   2.99285129e-02,
                          5.55085801e-02,  -4.00653422e-01,  -5.90368748e-01,
                         -1.20616592e-01,   9.94737521e-02,  -1.56102210e-01,
                         -1.54044539e-01,   1.60213709e-02,  -1.28314821e-02,
                         -5.47968224e-02,  -2.69551799e-02,  -3.03781740e-02,
                         -8.47271532e-02,  -8.66573304e-02,  -6.96350634e-02,
                         -3.86238545e-01,  -7.76547611e-01,  -5.41519523e-01,
                         -1.71335682e-01,  -3.92183423e-01,  -5.12649596e-01,
                         -8.14077854e-02,   1.49004033e-03,  -4.77766573e-01,
                         -5.26642859e-01,  -6.65886477e-02,   3.98949683e-02,
                         -1.18138663e-01,  -6.17300952e-03,   4.77283465e-04,
                         -4.26463455e-01,  -7.56500304e-01,  -5.85078299e-01,
                         -2.06887811e-01,   3.04797497e-02,   1.07968502e-01,
                         -1.10025577e-01,  -5.57952881e-01,  -4.67378020e-01,
                          1.16095528e-01,   3.17174532e-02,  -5.50779939e-01,
                         -4.75466937e-01,   1.95184760e-02,   5.69896773e-02,
                         -3.66876811e-01,  -7.16719091e-01,  -5.96605420e-01,
                         -1.63202658e-01,   1.09060228e-01,  -1.13871321e-01,
                         -6.99943900e-01,  -7.90131032e-01,  -2.14065105e-01,
                         -1.16559282e-01,  -4.94581759e-01,  -3.43234152e-01,
                         -1.36675730e-01,  -4.91476178e-01,  -7.83645213e-01,
                         -6.75528169e-01,  -3.18139404e-01,  -3.86146493e-02,
                         -4.00076747e-01,  -8.82429600e-01,  -4.71478581e-01,
                          1.00453168e-01,  -2.48484299e-01,  -7.70153999e-01,
                         -6.83717608e-01,  -5.96381545e-01,  -6.83791995e-01,
                         -3.90718520e-01,  -8.56531560e-02,  -3.42541158e-01,
                         -6.82872236e-01,  -6.54342413e-01,  -5.23902714e-01,
                         -5.91636777e-01,  -7.25289643e-01,  -4.91535485e-01,
                         -8.45247209e-02,  -2.42355317e-01,  -6.82484031e-01,
                         -6.72792017e-01,  -5.33362567e-01,  -6.25291169e-01,
                         -6.49185419e-01,  -5.49033344e-01,  -5.20513237e-01,
                         -5.97468793e-01,  -6.63125753e-01,  -6.10275388e-01,
                         -5.96499324e-01,  -6.37183964e-01,  -5.30341685e-01,
                         -5.43233931e-01,  -7.09188998e-01,  -4.43538219e-01,
                         -6.71969354e-02,  -3.27278376e-01,  -6.78227484e-01,
                         -5.53343594e-01,  -4.88966435e-01,  -6.64521158e-01,
                         -6.82822466e-01,  -6.03765070e-01,  -6.03433013e-01,
                         -6.00972950e-01,  -5.98307490e-01,  -6.13667607e-01,
                         -5.97522020e-01,  -5.54889441e-01,  -5.31869233e-01,
                         -5.69083989e-01,  -5.90737641e-01,  -5.68466306e-01,
                         -6.48037910e-01,  -7.06555188e-01,  -5.61476767e-01,
                         -4.85482156e-01,  -5.85718691e-01,  -6.30275249e-01,
                         -6.48014307e-01,  -6.47424519e-01,  -5.35647869e-01,
                         -5.03633857e-01,  -6.04563177e-01,  -6.27396107e-01,
                         -5.59289396e-01,  -5.31574488e-01,  -6.04012311e-01,
                         -6.67488217e-01,  -6.00701451e-01,  -5.55679619e-01,
                         -6.02092743e-01,  -5.95543504e-01,  -6.09273076e-01,
                         -6.91437364e-01,  -6.72576725e-01,  -5.67242563e-01,
                         -5.16149044e-01,  -5.46384811e-01,  -5.88567555e-01,
                         -5.84206164e-01,  -6.13732100e-01,  -6.64135277e-01,
                         -6.01123512e-01,  -5.30771852e-01,  -5.62398732e-01,
                         -5.99659801e-01,  -6.11240089e-01,  -6.08445227e-01,
                         -6.28587902e-01,  -6.74223304e-01,  -6.18688166e-01,
                         -5.60221791e-01,  -6.21062219e-01,  -6.13793314e-01,
                         -5.76221228e-01,  -6.34394407e-01,  -6.10488117e-01,
                         -5.46904087e-01,  -5.93624055e-01,  -6.32605076e-01,
                         -6.26369238e-01,  -6.09867692e-01,  -5.98508775e-01,
                         -6.15033507e-01,  -5.93551338e-01,  -6.56680584e-01,
                         -7.49295056e-01,  -4.25143421e-01,  -5.89167699e-02,
                         -3.29975247e-01,  -6.74599886e-01,  -5.96605837e-01,
                         -5.96717358e-01,  -7.21217334e-01,  -6.28182590e-01,
                         -5.37550509e-01,  -6.26721799e-01,  -6.74927592e-01,
                         -6.46097600e-01,  -6.70882583e-01,  -6.27969205e-01,
                         -5.11622608e-01,  -6.10387802e-01,  -6.43262148e-01,
                         -2.64188796e-01,  -2.08320007e-01,  -6.75157845e-01,
                         -6.13993704e-01,  -8.09330568e-02,   5.07967770e-02,
                         -6.86286949e-04,   2.41763834e-02,  -7.91159198e-02,
                         -6.22656941e-02,   8.64551142e-02,   3.59648019e-02,
                         -3.85758616e-02,  -5.44217648e-04,  -1.53419375e-02,
                         -3.29513624e-02,   1.62778457e-03,   1.81051698e-02,
                         -5.61910728e-03,  -4.40055318e-02,   3.23489448e-03,
                          6.37894794e-02,  -2.79795434e-02,  -7.06344694e-02,
                          5.60984835e-02,   7.67460018e-02,  -2.66910158e-02,
                         -3.87273543e-02,   7.78688909e-03,   1.56704858e-02,
                         -4.34225984e-03,  -1.15880966e-02,   1.52348764e-02,
                          1.06972670e-02,  -4.70946282e-02,  -6.02574609e-02,
                         -1.38877716e-03,   6.66911826e-02,   8.24767575e-02,
                          1.58420783e-02,  -4.70293984e-02,  -1.01989331e-02,
                          2.87818555e-02,  -2.77876947e-02,  -5.45080975e-02,
                          1.45751350e-02,   3.67658287e-02,  -9.11844801e-03,
                         -2.52041835e-02,  -2.75429729e-02,  -4.26248834e-02,
                         -6.30080923e-02,  -7.13553699e-03,   1.42186001e-01,
                         -2.08424702e-02,  -4.81866479e-01,  -4.11462605e-01,
                          4.15508337e-02,   1.14502688e-03,  -1.21686637e-01,
                          4.04520556e-02,  -1.98599041e-01,  -5.59396088e-01,
                         -2.74049431e-01,   9.54989716e-02,  -1.42942846e-01,
                         -6.03664458e-01,  -6.83859766e-01,  -5.68684876e-01,
                         -7.35946834e-01,  -7.23291576e-01,  -2.24660575e-01,
                         -1.68816030e-01,  -5.33090055e-01,  -3.55926454e-01,
                         -1.54905125e-01,  -5.33800542e-01,  -7.87780821e-01,
                         -6.77894175e-01,  -5.76902092e-01,  -5.89138985e-01,
                         -7.16426313e-01,  -7.23445952e-01,  -5.73470116e-01,
                         -6.16450071e-01,  -6.89641118e-01,  -5.87428927e-01,
                         -6.11699879e-01,  -7.37576544e-01,  -7.15851247e-01,
                         -5.96212626e-01,  -5.41239798e-01,  -7.00316966e-01,
                         -8.13710868e-01,  -4.72941637e-01,  -1.50979891e-01,
                         -4.30519879e-01,  -7.25864887e-01,  -4.26381499e-01,
                         -1.36544600e-01,  -4.16012287e-01,  -7.01529682e-01,
                         -6.24665618e-01,  -6.41617000e-01,  -7.56348312e-01,
                         -6.56482935e-01,  -5.79217792e-01,  -6.28312409e-01,
                         -6.29433393e-01,  -6.34969473e-01,  -6.38099432e-01,
                         -6.44923329e-01,  -6.84701681e-01,  -6.33182585e-01,
                         -6.59762383e-01,  -7.23714054e-01,  -4.01773214e-01,
                         -1.57497346e-01,  -5.07843316e-01,  -7.86876738e-01,
                         -6.53676689e-01,  -5.62487066e-01,  -6.54073000e-01,
                         -7.48736918e-01,  -5.29759586e-01,  -1.34048834e-01,
                         -3.23451102e-01,  -7.90454030e-01,  -5.21334589e-01,
                         -3.22415717e-02,  -3.05423021e-01,  -7.98895299e-01,
                         -6.03672266e-01,  -1.22960828e-01,  -2.68974632e-01,
                         -6.95076227e-01,  -6.28488719e-01,  -5.94087660e-01,
                         -8.17697465e-01,  -4.72278029e-01,  -6.62728772e-02,
                         -4.02465969e-01,  -4.52695310e-01,  -4.36413586e-02,
                         -4.10497874e-01,  -9.03162301e-01,  -4.19349343e-01,
                         -8.11219737e-02,  -4.76022869e-01,  -4.27384645e-01,
                         -8.20355117e-02,  -4.74898994e-01,  -8.31932962e-01,
                         -3.56917351e-01,  -1.21517524e-01,  -5.21500945e-01,
                         -4.23598260e-01,   9.54971835e-02,  -9.40454602e-02,
                         -5.70493698e-01,  -3.04134190e-01,  -1.28637217e-02,
                         -5.34431100e-01,  -8.05286050e-01,  -2.55657494e-01,
                         -1.71529680e-01,  -6.26695931e-01,  -3.61461014e-01,
                          1.07968375e-02,  -5.32984912e-01,  -8.54198933e-01,
                         -2.94404119e-01,  -8.16213116e-02,  -5.30138731e-01,
                         -7.52538621e-01,  -6.57737613e-01,  -6.20399475e-01,
                         -6.19545877e-01,  -6.19728744e-01,  -6.44400775e-01,
                         -6.67260289e-01,  -6.25488162e-01,  -3.09637100e-01,
                          7.18817413e-02,  -1.18372589e-01,  -5.72547853e-01,
                         -4.01836097e-01,   8.38746354e-02,   2.94408239e-02,
                         -4.57035005e-01,  -7.46781230e-01,  -6.64677382e-01,
                         -6.13950312e-01,  -6.83158755e-01,  -4.05685663e-01,
                         -1.42775446e-01,  -4.28261429e-01,  -4.55542445e-01,
                         -1.36473611e-01,  -4.43203956e-01,  -7.17842400e-01,
                         -2.96020031e-01,  -2.08244473e-01,  -4.43692625e-01,
                         -2.53638983e-01,  -2.30651289e-01,  -6.01072073e-01,
                         -7.14784145e-01,  -6.08213603e-01,  -6.02996349e-01,
                         -6.98685288e-01,  -6.86601162e-01,  -3.84168148e-01,
                         -1.87234670e-01,  -3.99735540e-01,  -6.62090361e-01,
                         -7.70396709e-01,  -5.68081737e-01,  -8.52410868e-02,
                         -1.70201182e-01,  -7.98440158e-01,  -7.23307788e-01,
                         -1.34534016e-01,  -1.95143312e-01,  -6.04653895e-01,
                         -6.73230946e-01,  -6.31264448e-01,  -4.85464334e-01,
                         -8.81929770e-02,   1.97092388e-02,  -3.31370711e-01,
                         -5.98846138e-01,  -6.93418801e-01,  -6.44957006e-01,
                         -2.92891055e-01,  -1.73252091e-01,  -5.72530150e-01,
                         -7.36708581e-01,  -5.62134802e-01,  -5.98015308e-01,
                         -6.57777965e-01,  -5.93965888e-01,  -6.63255215e-01,
                         -6.95688784e-01,  -5.97141266e-01,  -6.10953689e-01,
                         -6.76728606e-01,  -6.50494695e-01,  -6.02243662e-01,
                         -6.47566855e-01,  -7.65478611e-01,  -6.17495298e-01,
                         -2.03944430e-01,  -1.88879684e-01,  -5.84378362e-01,
                         -7.14251459e-01,  -6.33835912e-01,  -6.44676626e-01,
                         -5.99830866e-01,  -6.38579190e-01,  -7.62001038e-01,
                         -5.00152409e-01,  -1.42345652e-01,  -3.04219455e-01,
                         -6.56229734e-01,  -7.08502114e-01,  -5.61333418e-01,
                         -5.33265769e-01,  -6.83393657e-01,  -5.71328223e-01,
                         -2.26860806e-01,  -3.07479501e-01,  -4.88738418e-01,
                         -2.69880265e-01,  -2.86035657e-01,  -5.93754590e-01,
                         -6.29806280e-01,  -6.37167573e-01,  -6.97066844e-01,
                         -6.32135987e-01,  -6.55022502e-01,  -6.16447449e-01,
                         -5.74435771e-01,  -8.17550719e-01,  -6.58963561e-01,
                         -6.01205602e-02,  -1.63892046e-01,  -7.24804401e-01,
                         -7.39582479e-01,  -5.41050673e-01,  -6.36865795e-01,
                         -7.05623746e-01,  -5.78664124e-01,  -5.66428602e-01,
                         -6.83520257e-01,  -6.25678897e-01,  -5.83221734e-01,
                         -7.41982281e-01,  -5.85948527e-01,  -7.81669542e-02,
                          1.06203727e-01,  -5.31904548e-02,  -7.72667453e-02,
                         -1.23532591e-02,  -2.89983898e-01,  -7.20417917e-01,
                         -5.62880099e-01,  -1.47848904e-01,  -3.10629994e-01,
                         -4.65065777e-01,  -1.84105501e-01,  -2.92116016e-01,
                         -6.94965422e-01,  -6.91496134e-01,  -6.04635417e-01,
                         -6.72259867e-01,  -4.79453236e-01,  -2.99638640e-02,
                          9.01758447e-02,  -3.24547350e-01,  -5.58539391e-01,
                         -2.19416916e-01,   6.36143237e-02,   4.83809635e-02,
                          1.59041770e-02,  -4.92367111e-02,  -6.18822761e-02,
                         -9.45930369e-03,  -6.48896694e-02,  -4.52672094e-02,
                          3.42776030e-02,  -5.91552118e-03,   1.37107261e-02,
                         -1.95045285e-02,  -1.29041329e-01,   4.76132706e-02,
                          7.95145631e-02,  -3.65806907e-01,  -4.74860609e-01,
                         -9.00246352e-02,   4.44665588e-02,  -4.65042666e-02,
                          1.12198072e-03,   3.81862186e-02,  -7.95625616e-03,
                          1.47860090e-03,   6.41424209e-03,  -5.87380640e-02,
                         -7.19328001e-02,  -1.62762571e-02,  -6.93307351e-03,
                         -2.19908822e-02,  -1.45937307e-02,  -3.37004364e-02,
                         -4.68686782e-02,  -5.75933792e-03,   8.23722966e-03,
                         -3.47711965e-02,  -4.26644552e-03,   1.07116558e-01,
                          7.25540742e-02,  -8.57203454e-02,  -4.89981212e-02,
                          1.16011396e-01,   8.43546465e-02,  -6.30578324e-02,
                         -7.37773404e-02,   1.54715125e-02,   1.56075954e-02,
                         -5.90636022e-02,  -2.69207992e-02,   1.80072077e-02,
                         -6.42976090e-02,  -4.59637269e-02,   6.88066930e-02,
                          2.49660425e-02,  -3.77577953e-02,  -2.04807315e-02,
                         -1.13815069e-02,   5.07604219e-02,  -8.39900449e-02,
                         -4.72571492e-01,  -3.83056223e-01,   1.36975914e-01,
                          4.88809980e-02,  -4.98061210e-01,  -4.52063173e-01,
                          2.68653990e-03,   6.75340071e-02,  -1.46234110e-02,
                          9.73944291e-02,  -1.12144597e-01,  -5.65085948e-01,
                         -3.83380711e-01,   1.44704103e-01,  -2.16746926e-02,
                         -5.07362306e-01,  -3.56108814e-01,  -9.12497416e-02,
                         -5.02929330e-01,  -7.91476727e-01,  -3.27667087e-01,
                         -1.30367711e-01,  -4.63521361e-01,  -2.94223040e-01,
                         -3.62423062e-02,  -5.54635525e-01,  -7.80963123e-01,
                         -2.10106060e-01,  -1.54847249e-01,  -5.54502249e-01,
                         -2.87666142e-01,  -5.06886616e-02,  -5.92830122e-01,
                         -7.76754618e-01,  -2.31470570e-01,  -1.88867584e-01,
                         -5.96131504e-01,  -3.01805735e-01,   2.23772123e-01,
                         -8.93278643e-02,  -5.34409046e-01,  -2.89180130e-01,
                         -1.73829645e-01,  -4.61336553e-01,  -2.14955136e-01,
                          1.71830982e-01,  -2.30047435e-01,  -5.30499458e-01,
                         -1.36626408e-01,  -1.83969334e-01,  -7.48678267e-01,
                         -6.47898316e-01,  -1.19145744e-01,  -1.92758620e-01,
                         -6.28304064e-01,  -7.46037662e-01,  -6.44214034e-01,
                         -3.96087468e-01,   7.13260844e-02,   1.08460695e-01,
                         -4.41796035e-01,  -4.86375839e-01,  -5.12803383e-02,
                         -3.20287794e-01,  -8.28239977e-01,  -4.97015357e-01,
                         -5.41153401e-02,  -3.30168486e-01,  -6.71415389e-01,
                         -6.04407728e-01,  -5.73645532e-01,  -6.52793109e-01,
                         -5.95793068e-01,  -6.40639484e-01,  -6.75535023e-01,
                         -2.87849456e-01,  -1.05639987e-01,  -5.37395597e-01,
                         -7.06073046e-01,  -5.16100466e-01,  -6.43233240e-01,
                         -7.14058697e-01,  -3.11636567e-01,   8.08803365e-02,
                          2.67286878e-02,  -4.22901362e-01,  -7.20164001e-01,
                         -4.79631543e-01,  -1.55515388e-01,  -2.13235784e-02,
                          1.05557099e-01,  -7.37724304e-02,  -5.19252598e-01,
                         -3.66472334e-01,   2.14566186e-01,   1.99411530e-02,
                         -5.99463463e-01,  -3.38030815e-01,   8.76263008e-02,
                         -4.66221392e-01,  -8.84307623e-01,  -3.93555880e-01,
                         -1.59366764e-02,   6.67984784e-03,   2.86450516e-03,
                         -2.64318198e-01,  -4.12597150e-01,  -1.54290333e-01,
                         -2.23043382e-01,  -6.77554429e-01,  -6.84973598e-01,
                         -1.25771537e-01,   2.18154207e-01,  -1.42488927e-01,
                         -5.63156724e-01,  -3.39408427e-01,   6.59485608e-02,
                          1.01054557e-01,  -3.37215816e-03,   6.93798356e-04,
                          4.85378467e-02,  -7.01231807e-02,  -4.32210624e-01,
                         -6.96973920e-01,  -6.74304366e-01,  -5.46650410e-01,
                         -2.51426011e-01,   1.00391582e-01,  -8.52761269e-02,
                         -5.60110271e-01,  -3.99888098e-01,   5.56795262e-02,
                          3.20628732e-02,   1.72941554e-02,   1.43468052e-01,
                         -2.14144066e-01,  -4.69387919e-01,  -1.70426056e-01,
                         -2.39522606e-01,  -5.51294565e-01,  -2.14473277e-01,
                          1.69112012e-01,  -1.39278337e-01,  -6.15566552e-01,
                         -6.48024797e-01,  -3.24245930e-01,  -5.84534444e-02,
                          4.84837592e-02,   4.75266986e-02,  -2.34818578e-01,
                         -4.75132167e-01,  -2.18286544e-01,   5.57728596e-02,
                          2.31643990e-02,   4.12853435e-02,   6.74893931e-02,
                         -1.20731844e-02,  -1.32777281e-02,   4.49554902e-03,
                          3.88215133e-03,   3.22370455e-02,  -1.20736435e-02,
                         -2.79386435e-02,   5.09035774e-02,   2.42302157e-02,
                         -4.07291539e-02,   3.31869125e-02,   8.52462053e-02,
                         -5.61142899e-03,  -6.68725446e-02,  -6.07889192e-03,
                          2.70932168e-02,  -1.05517195e-03,   5.84360808e-02,
                          1.08020388e-01,  -2.66187228e-02,  -9.54430923e-02,
                          7.03680739e-02,   1.05759144e-01,  -4.43558320e-02,
                          2.23364606e-02,   4.10243459e-02,  -3.79236281e-01,
                         -5.33167124e-01,  -5.44382893e-02,   1.66215003e-01,
                         -7.32932091e-02,  -1.00388333e-01,   2.18268428e-02,
                          2.47090142e-02,   7.21193403e-02,   7.13477582e-02,
                         -5.38062677e-02,  -5.31720594e-02,   4.27535065e-02,
                          3.24730575e-02,   8.83767323e-04,   5.36587015e-02,
                          6.67295754e-02,  -2.82809827e-02,  -6.58372790e-02,
                          9.01367422e-03,   3.42881568e-02,   8.27121362e-03,
                          4.16935906e-02,   6.50616661e-02,   4.35859896e-03,
                         -1.94640774e-02,   6.13681972e-02,   5.47284484e-02,
                         -7.22785518e-02,  -4.04220633e-02,   5.21248765e-02,
                         -5.03987446e-02,  -2.95464229e-02,   1.45106971e-01,
                         -1.09653100e-01,  -6.13796890e-01,  -6.79243982e-01,
                         -5.31609297e-01,  -6.49366200e-01,  -6.41371667e-01,
                         -2.02536091e-01,   5.17760292e-02,  -9.61202383e-02,
                         -4.98265307e-03,   1.58920124e-01,  -2.35468537e-01,
                         -5.53276598e-01,  -1.99046075e-01,   1.02374479e-01,
                         -1.45723671e-03,  -2.91659087e-02,   5.72866015e-02,
                          4.39009145e-02,   8.83427821e-03,   1.36597129e-03,
                         -1.07113495e-02,  -1.46267954e-02,  -1.63336750e-02,
                         -1.90517232e-02,  -1.73083209e-02,  -1.40120713e-02,
                          1.28898183e-02,   4.67280746e-02,   2.87501793e-02,
                          1.11774029e-02,   4.54277806e-02,   2.81035602e-02,
                         -1.10782497e-02,   3.63297909e-02,   3.10441200e-02,
                         -3.34830545e-02,  -4.42848960e-03,   1.07217235e-02,
                          3.85628454e-02,   8.44351128e-02,  -2.24519625e-01,
                         -5.67288935e-01,  -2.78625458e-01,   1.20253198e-01,
                          6.68749884e-02,  -1.42506184e-02,   1.60302725e-02,
                         -3.68946604e-02,  -4.87047993e-02,  -4.44500649e-04,
                          5.44978194e-02,   6.65885955e-02,  -5.80371507e-02,
                         -3.01996227e-02,   1.39661372e-01,  -1.57233238e-01,
                         -5.64260960e-01,  -2.67163098e-01,   1.20632701e-01,
                         -3.65375802e-02,  -5.43683171e-02,   1.34957641e-01,
                         -2.24457130e-01,  -6.38222635e-01,  -2.62714118e-01,
                          1.82777539e-01,  -1.12236686e-01,  -5.75843990e-01,
                         -6.36720002e-01,  -5.70049882e-01,  -6.09260023e-01,
                         -6.50983334e-01,  -6.32439435e-01,  -6.02802634e-01,
                         -6.32625818e-01,  -6.86720371e-01,  -6.71771646e-01,
                         -6.31913781e-01,  -6.25589132e-01,  -6.06003940e-01,
                         -5.88120878e-01,  -6.27046824e-01,  -6.80130064e-01,
                         -6.65409386e-01,  -5.85360646e-01,  -5.68847895e-01,
                         -6.58881307e-01,  -6.80245161e-01,  -5.94483674e-01,
                         -5.82750857e-01,  -6.44009709e-01,  -6.43640101e-01,
                         -6.12011850e-01,  -6.33695960e-01,  -6.54217780e-01,
                         -5.98641396e-01,  -5.99090397e-01,  -7.08487332e-01,
                         -6.48380041e-01,  -4.93470252e-01,  -6.15145743e-01,
                         -7.36738920e-01,  -6.35881245e-01,  -6.77269995e-01,
                         -6.25865281e-01,  -1.96371332e-01,  -9.65246484e-02,
                         -5.24359465e-01,  -7.60322988e-01,  -6.73173726e-01,
                         -5.96460104e-01,  -6.00944340e-01,  -6.31448388e-01,
                         -6.06982172e-01,  -5.95131099e-01,  -6.78951085e-01,
                         -6.78211689e-01,  -5.87593555e-01,  -6.01010561e-01,
                         -6.62772596e-01,  -6.56343400e-01,  -5.83354652e-01,
                         -5.12935758e-01,  -5.48445821e-01,  -6.34112597e-01,
                         -6.74723148e-01,  -6.87350750e-01,  -6.61052167e-01,
                         -6.39990687e-01,  -6.49639785e-01,  -6.05463803e-01,
                         -5.91271341e-01,  -6.76479399e-01,  -7.09702909e-01,
                         -6.57289863e-01,  -6.00970864e-01,  -5.81911743e-01,
                         -6.19083226e-01,  -6.32101476e-01,  -6.01226270e-01,
                         -6.17678285e-01,  -6.51394010e-01,  -6.43714547e-01,
                         -6.24691606e-01,  -6.45273149e-01,  -6.80023074e-01,
                         -6.24060512e-01,  -5.80179751e-01,  -6.57622933e-01,
                         -6.62065387e-01,  -6.20131850e-01,  -6.46920621e-01,
                         -6.06834710e-01,  -6.76190972e-01,  -7.62983680e-01,
                         -3.76461208e-01,  -1.14808768e-01,  -4.59318191e-01,
                         -4.47631657e-01,  -8.83447677e-02,  -3.64495158e-01,
                         -7.60893524e-01,  -6.26408696e-01,  -5.56931973e-01,
                         -6.90435171e-01,  -6.35240793e-01,  -5.73937058e-01,
                         -6.74462914e-01,  -7.15337038e-01,  -6.29280806e-01,
                         -5.70391357e-01,  -6.27355754e-01,  -7.06018627e-01,
                         -6.76831603e-01,  -6.02661073e-01,  -6.23819590e-01,
                         -6.92026556e-01,  -6.73450112e-01,  -6.06643677e-01,
                         -6.05927110e-01,  -6.40424192e-01,  -6.32254243e-01,
                         -6.23611212e-01,  -6.58397257e-01,  -6.58119977e-01,
                         -6.17201686e-01,  -6.41731441e-01,  -6.69797599e-01,
                         -6.41093612e-01,  -6.48020089e-01,  -6.04065835e-01,
                         -5.70314050e-01,  -7.40327358e-01,  -6.30216360e-01,
                         -1.64620906e-01,  -2.56663591e-01,  -5.42167664e-01,
                         -1.41051859e-01,  -1.18612617e-01,  -8.16672564e-01,
                         -6.56574726e-01,  -1.49283605e-02,  -3.27932209e-01,
                         -6.03924692e-01,  -1.08735211e-01,  -1.75637677e-01,
                         -7.78784096e-01,  -5.83761513e-01,  -7.19872564e-02,
                         -3.08405727e-01,  -6.91576719e-01,  -5.91346383e-01,
                         -6.01482213e-01,  -8.23639452e-01,  -5.11281490e-01,
                          7.54678482e-03,  -2.95613348e-01,  -8.58070970e-01,
                         -5.18369555e-01,   9.12699383e-03,  -3.29993039e-01,
                         -8.01679075e-01,  -6.88938379e-01,  -5.35748661e-01,
                         -6.05361879e-01,  -6.32285178e-01,  -6.46831214e-01,
                         -6.66422009e-01,  -5.97746730e-01,  -5.60532153e-01,
                         -6.52014077e-01,  -7.02404737e-01,  -4.45387691e-01,
                         -7.42847216e-04,   7.58590773e-02,  -3.66723716e-01,
                         -7.70880222e-01,  -6.23205304e-01,  -8.03602487e-02,
                          1.51612654e-01,  -2.17452869e-01,  -5.93236625e-01,
                         -6.08594418e-01,  -5.92852473e-01,  -6.64432406e-01,
                         -6.76615715e-01,  -6.67983949e-01,  -6.56731606e-01,
                         -6.12771451e-01,  -5.96270502e-01,  -6.35479271e-01,
                         -6.77579641e-01,  -6.48549855e-01,  -6.13033473e-01,
                         -6.59288764e-01,  -5.32449901e-01,  -1.05423689e-01,
                          1.04984269e-01,  -2.33019918e-01,  -6.63806260e-01,
                         -6.61378860e-01,  -2.77681857e-01,   3.04244012e-02,
                          5.40785678e-02,  -1.60654690e-02,  -2.42951587e-01,
                         -6.55605316e-01,  -6.39017105e-01,  -2.00038955e-01,
                         -2.35655710e-01,  -5.24201572e-01,  -2.48119801e-01,
                          7.84570575e-02,  -3.52518000e-02,  -3.82726789e-02,
                          6.11929484e-02,  -2.08181739e-01,  -6.03805900e-01,
                         -6.66221023e-01,  -2.98983216e-01,   8.48128051e-02,
                         -9.91409570e-02,  -5.40312052e-01,  -6.45664811e-01,
                         -6.70295358e-01,  -6.13051832e-01,  -1.94307625e-01,
                         -1.41372144e-01,  -6.74663663e-01,  -6.67854428e-01,
                         -1.14267930e-01,  -1.41023830e-01,  -6.29373968e-01,
                         -7.68645227e-01,  -5.91601551e-01,  -5.29741824e-01,
                         -7.01496422e-01,  -7.14198470e-01,  -2.78782398e-01,
                         -6.58730268e-02,  -5.04604280e-01,  -7.99752414e-01,
                         -6.29057586e-01,  -5.65840244e-01,  -6.32069290e-01,
                         -6.03257358e-01,  -6.05486810e-01,  -6.35061026e-01,
                         -6.50283158e-01,  -6.46365762e-01,  -6.18845880e-01,
                         -7.19363570e-01,  -6.92124546e-01,  -2.59053439e-01,
                         -8.60604644e-02,  -4.86635894e-01,  -7.28317440e-01,
                         -6.47716403e-01,  -6.46017373e-01,  -6.49850190e-01,
                         -5.77840388e-01,  -6.00722849e-01,  -7.15892732e-01,
                         -6.70482874e-01,  -2.99672663e-01,  -9.37053412e-02,
                         -4.94885266e-01,  -7.70327926e-01,  -3.65839779e-01,
                         -8.66045877e-02,  -4.04042304e-01,  -7.01755464e-01,
                         -6.71326339e-01,  -6.00345910e-01,  -6.28809273e-01,
                         -6.46091461e-01,  -5.70945084e-01,  -5.32977104e-01,
                         -6.50163352e-01,  -7.33736038e-01,  -6.52152717e-01,
                         -5.94241500e-01,  -6.41763687e-01,  -6.63442969e-01,
                         -6.44722283e-01,  -6.49593472e-01,  -6.48249865e-01,
                         -6.25285029e-01,  -6.42619669e-01,  -6.68385565e-01,
                         -5.90221286e-01,  -5.15640080e-01,  -6.22993946e-01,
                         -7.31632411e-01,  -6.53130472e-01,  -5.84399164e-01,
                         -6.25215352e-01,  -6.32435262e-01,  -6.31852150e-01,
                         -6.86571360e-01,  -6.98495865e-01,  -6.39977038e-01,
                         -6.02419019e-01,  -6.26744092e-01,  -6.46376014e-01,
                         -6.21459723e-01,  -6.25242889e-01,  -6.46644115e-01,
                         -6.20577872e-01,  -6.26570642e-01,  -6.48690939e-01,
                         -5.85075200e-01,  -5.74639380e-01,  -6.71976745e-01,
                         -6.60892665e-01,  -5.74534535e-01,  -6.25994027e-01,
                         -7.00378120e-01,  -6.38439476e-01,  -6.05510294e-01,
                         -6.72975242e-01,  -6.55490875e-01,  -5.94503522e-01,
                         -6.53484821e-01,  -6.95632517e-01,  -6.24302268e-01,
                         -5.94665110e-01,  -6.40125632e-01,  -6.66510701e-01,
                         -6.36772156e-01,  -5.71644366e-01,  -5.60893655e-01,
                         -6.22974396e-01,  -6.82050645e-01,  -7.11114705e-01,
                         -6.64143980e-01,  -5.82166672e-01,  -6.20735526e-01,
                         -6.84928298e-01,  -6.28692210e-01,  -6.17772758e-01,
                         -7.04970479e-01,  -6.80826485e-01,  -5.69594264e-01,
                         -5.87323666e-01,  -6.67804539e-01,  -6.17333353e-01,
                         -5.73972225e-01,  -6.76081121e-01,  -6.76526487e-01,
                         -5.33138096e-01,  -5.64197540e-01,  -7.09604502e-01,
                         -6.66708112e-01,  -5.48612058e-01,  -5.98891199e-01,
                         -7.09266603e-01,  -6.92193687e-01,  -6.43347442e-01,
                         -6.67955279e-01,  -6.45346403e-01,  -5.86242735e-01,
                         -6.25714898e-01,  -6.55411601e-01,  -5.84403038e-01,
                         -5.56142807e-01,  -6.29391491e-01,  -7.02006042e-01,
                         -7.00730205e-01,  -6.62461281e-01,  -6.31851435e-01,
                         -5.85904837e-01,  -5.80898881e-01,  -6.47094965e-01,
                         -6.66560352e-01,  -6.44572973e-01,  -6.30420327e-01,
                         -5.98310769e-01,  -6.14952028e-01,  -6.27704918e-01,
                         -5.99277794e-01,  -6.86144352e-01,  -7.08179832e-01,
                         -5.73740959e-01,  -6.47919178e-01,  -6.84031785e-01,
                         -3.08083624e-01,  -1.34610102e-01,  -4.59244549e-01,
                         -6.70263112e-01,  -6.08721197e-01,  -6.01476550e-01,
                         -6.51493788e-01,  -6.20954931e-01,  -5.91778636e-01,
                         -6.45866752e-01,  -6.50700688e-01,  -6.41608298e-01,
                         -7.57060170e-01,  -6.32273555e-01,  -1.79067031e-01,
                         -1.87949821e-01,  -6.94804370e-01,  -6.58802629e-01,
                         -1.17446341e-01,  -1.48041517e-01,  -6.37074411e-01,
                         -6.89326525e-01,  -5.64635873e-01,  -7.31775165e-01,
                         -5.99531233e-01,  -1.31322756e-01,  -1.95184723e-01,
                         -6.32713497e-01,  -6.91039503e-01,  -5.74900448e-01,
                         -6.74098909e-01,  -7.18052387e-01,  -5.57328820e-01,
                         -5.44566333e-01,  -7.03313828e-01,  -5.62783360e-01,
                         -1.66864574e-01,   3.59143317e-02,   6.23542741e-02,
                         -5.51510304e-02,  -4.24906433e-01,  -7.17104852e-01,
                         -6.77348554e-01,  -5.56319535e-01,  -6.37130797e-01,
                         -7.77596235e-01,  -5.13376355e-01,  -1.21749490e-01,
                         -2.77667642e-01,  -4.17278051e-01,  -1.49997160e-01,
                         -3.35606545e-01,  -7.28137255e-01,  -5.82808435e-01,
                         -5.95821321e-01,  -7.74187684e-01,  -3.40807468e-01,
                         -8.81666616e-02,  -4.93624300e-01,  -4.03040349e-01,
                          1.30338416e-01,  -8.96379128e-02,  -5.95707238e-01,
                         -3.17080617e-01,  -7.53534550e-04,  -5.00945270e-01,
                         -8.06995928e-01,  -3.02796751e-01,  -7.64294267e-02,
                         -4.56178635e-01,  -6.75131559e-01,  -7.31831253e-01,
                         -6.71945632e-01,  -1.24827303e-01,   2.29163826e-01,
                         -2.52798468e-01,  -5.73231637e-01,  -2.00068265e-01,
                         -1.47448570e-01,  -6.27287626e-01,  -7.11484194e-01,
                         -2.40970939e-01,   1.16608225e-01,  -7.33907670e-02,
                         -5.01009524e-01,  -4.28272218e-01,   5.06162532e-02,
                          1.38488159e-01,  -9.51515213e-02,  -8.97363201e-02,
                          5.35321236e-02,   6.22339770e-02,  -2.55597066e-02,
                         -5.04442938e-02,   4.82446589e-02,   6.20952621e-02,
                         -4.35202792e-02,  -2.64764242e-02,   1.87873598e-02,
                         -2.24944726e-02,   3.25924642e-02,   8.79178271e-02,
                         -2.11981405e-02,  -1.00519672e-01,  -3.72608490e-02,
                          5.24144471e-02,   6.00062273e-02,  -2.50674412e-02,
                         -7.41314217e-02,  -3.96271572e-02,  -1.41578494e-02,
                          2.80017443e-02,   9.91331711e-02,   7.55992904e-02,
                         -1.78142600e-02,  -2.52069626e-02,   2.99883522e-02,
                         -5.17617399e-03,  -9.46778730e-02,  -5.71140498e-02,
                          5.95602356e-02,   5.16090766e-02,  -3.37064452e-02,
                         -2.21755654e-02,   3.11833583e-02,   1.20614832e-02,
                         -7.41823402e-04,   2.60847434e-02,  -2.48969253e-02,
                         -8.17033499e-02,   1.05162719e-02,   9.42618921e-02,
                          1.63244084e-02,  -5.12087755e-02,   3.00001376e-03,
                          5.97592928e-02,   5.06567359e-02,   2.27522627e-02,
                         -3.54809687e-03,  -3.97107527e-02,  -2.33850293e-02,
                          5.43236770e-02,   4.17950116e-02,  -3.29824537e-02,
                         -1.35112612e-03,   1.44604687e-02,  -5.43436520e-02,
                         -1.12001672e-02,   6.01478890e-02,   1.22992480e-02,
                          1.01171224e-03,   7.20985746e-03,  -2.62659155e-02,
                          3.74149010e-02,  -4.66198921e-02,  -4.05561984e-01,
                         -4.31048840e-01,  -2.27429643e-02,   1.36718869e-01,
                         -4.92086913e-03,  -3.63121033e-02,   8.58427025e-03,
                          1.88655779e-03,  -3.38840634e-02,  -5.38496301e-02,
                          1.46930506e-02,   4.32947800e-02,  -4.58949544e-02,
                         -1.47782359e-02,   7.52568468e-02,  -1.37561290e-02,
                         -5.25812358e-02,   7.60459229e-02,   7.67642856e-02,
                         -3.50337811e-02,  -1.40370084e-02,   5.59083670e-02,
                          8.76244437e-03,  -4.79053073e-02,  -5.31146303e-03,
                          1.22499168e-02,  -1.28632309e-02,   6.07223213e-02,
                          9.88683105e-02,  -3.12697552e-02,  -7.75636882e-02,
                          3.17533575e-02,   4.32650968e-02,  -3.64563875e-02,
                         -3.69993001e-02,   2.73620500e-03,  -4.03551385e-03,
                         -1.58552211e-02,   2.59237234e-02,   5.92152625e-02,
                          1.75840389e-02,  -1.27337500e-02,   4.96901944e-03,
                         -6.31537149e-03,  -4.72371280e-03,   3.10995933e-02,
                         -8.17117281e-03,  -6.31286204e-02,  -2.34209048e-03,
                          6.53128326e-02,   3.16931754e-02,   2.33459999e-04,
                          2.50219442e-02,   3.69129963e-02,   4.01822925e-02,
                          4.64096256e-02,  -1.72555842e-03,  -4.34141345e-02,
                         -4.65735281e-03,   2.57101638e-04,  -4.36927676e-02,
                         -1.35740899e-02,   2.23937109e-02,  -1.04902908e-02,
                         -1.75035447e-02,   3.85984778e-02,   8.67574587e-02,
                          1.25374300e-02,  -7.73511231e-02,   8.18150267e-02,
                          1.36183023e-01,  -3.03914249e-01,  -5.45673549e-01,
                         -1.74621448e-01,   7.29349330e-02,  -3.63647863e-02,
                         -2.13103723e-02,   1.14447683e-01,   5.49332090e-02,
                         -2.54515290e-01,  -5.52945197e-01,  -6.54609978e-01,
                         -6.76404357e-01,  -4.68175948e-01,  -7.51321018e-02,
                         -2.59369016e-01,  -7.95211375e-01,  -5.95366359e-01,
                         -9.79997218e-02,  -2.64416218e-01,  -6.19039655e-01,
                         -6.27024651e-01,  -5.95668972e-01,  -6.15047276e-01,
                         -5.91711581e-01,  -6.94671154e-01,  -7.32194841e-01,
                         -3.46114218e-01,  -6.65719435e-02,  -4.08459276e-01,
                         -6.93066716e-01,  -6.07799053e-01,  -7.09398389e-01,
                         -6.75761223e-01,  -1.73709840e-01,  -1.10384494e-01,
                         -6.70414627e-01,  -8.28727663e-01,  -3.27871889e-01,
                          1.29988641e-01,   4.93537076e-02,  -3.63954723e-01,
                         -6.54541075e-01,  -7.55571961e-01,  -6.09301031e-01,
                         -1.99194953e-01,  -1.46095961e-01,  -5.59845805e-01,
                         -6.56558573e-01,  -5.35241306e-01,  -7.29014516e-01,
                         -6.81118965e-01,  -1.63561642e-01,  -1.35113955e-01,
                         -7.00261116e-01,  -7.29724228e-01,  -1.59185976e-01,
                         -1.22617006e-01,  -6.01418495e-01,  -6.54886842e-01,
                         -5.22949040e-01,  -7.41153777e-01,  -6.96513653e-01,
                         -1.84930220e-01,  -1.11894228e-01,  -6.23375952e-01,
                         -7.36205876e-01,  -2.17256680e-01,  -8.52158144e-02,
                         -6.26917899e-01,  -7.42282748e-01,  -1.83521077e-01,
                         -4.80036363e-02,  -5.65366745e-01,  -8.33282053e-01,
                         -4.54760313e-01,   4.41003405e-02,   5.53587079e-02,
                         -3.44830364e-01,  -6.92133427e-01,  -6.62489295e-01,
                         -1.60818219e-01,   1.65404946e-01,  -2.44805872e-01,
                         -4.95666444e-01,  -1.76064938e-01,  -2.34960124e-01,
                         -4.42930967e-01,  -1.77562445e-01,  -2.22539544e-01,
                         -6.68971121e-01,  -7.33704627e-01,  -6.28505170e-01,
                         -6.43362999e-01,  -6.18716240e-01,  -6.55709922e-01,
                         -6.54805183e-01,  -5.57095051e-01,  -6.59139276e-01,
                         -6.97617888e-01,  -2.65708417e-01,   1.53728142e-01,
                         -3.53485085e-02,  -5.44558287e-01,  -7.44762957e-01,
                         -6.41033947e-01,  -5.97016037e-01,  -5.98772168e-01,
                         -5.88793516e-01,  -6.55078232e-01,  -5.80775678e-01,
                         -2.28045985e-01,   5.85351288e-02,  -5.69482222e-02,
                         -5.23450494e-01,  -8.09578538e-01,  -4.51555669e-01,
                         -5.37604243e-02,  -4.09424722e-01,  -8.34052384e-01,
                         -4.38013256e-01,  -1.19771133e-03,  -3.75147969e-01,
                         -8.08368683e-01,  -6.74910784e-01,  -5.67839861e-01,
                         -6.33378088e-01,  -3.54791373e-01,  -9.88468900e-02,
                         -4.62727755e-01,  -7.99305439e-01,  -4.15917158e-01,
                         -3.33692133e-02,  -3.92209440e-01,  -7.70745993e-01,
                         -4.27995533e-01,  -7.65594468e-02,  -3.83760124e-01,
                         -7.16278970e-01,  -6.28117323e-01,  -5.64109683e-01,
                         -6.49965525e-01,  -6.65572822e-01,  -6.56126082e-01,
                         -6.26077354e-01,  -5.68415523e-01,  -5.85362136e-01,
                         -6.43935800e-01,  -7.09379554e-01,  -6.69650316e-01,
                         -4.94056314e-01,  -5.76492369e-01,  -7.30637968e-01,
                         -3.77742589e-01,  -1.66819930e-01,  -4.86711830e-01,
                         -3.47951770e-01,  -2.78798789e-02,  -5.29224873e-01,
                         -8.25858116e-01,  -2.44213283e-01,  -1.29771814e-01,
                         -5.40740550e-01,  -3.09495807e-01,  -7.67544508e-02,
                         -6.21418655e-01,  -8.06071579e-01,  -2.25159615e-01,
                         -1.40060693e-01,  -5.39741933e-01,  -2.39610255e-01,
                          2.71187901e-01,  -1.20664962e-01,  -5.70624411e-01,
                         -2.37347201e-01,  -1.81616187e-01,  -5.67589939e-01,
                         -2.19316378e-01,   1.85324252e-01,  -3.35065007e-01,
                         -5.41786015e-01,  -1.07347533e-01,  -2.68374532e-01,
                         -5.06333232e-01,  -1.25378489e-01,  -2.48963147e-01,
                         -8.20299566e-01,  -5.34061253e-01,   6.36170385e-03,
                         -3.26193005e-01,  -7.40195513e-01,  -5.54840684e-01,
                         -5.55822790e-01,  -7.73396790e-01,  -4.06602681e-01,
                         -3.43000963e-02,  -3.91960889e-01,  -5.58437407e-01,
                         -6.85670152e-02,   8.53589922e-02,  -3.53157133e-01,
                         -6.58233047e-01,  -6.59516573e-01,  -6.43779814e-01,
                         -6.35848403e-01,  -6.21347666e-01,  -6.97967708e-01,
                         -6.29720330e-01,  -2.32947126e-01,  -1.14351362e-01,
                         -5.17620921e-01,  -6.40674889e-01,  -4.60943818e-01,
                         -6.63401306e-01,  -7.29022682e-01,  -1.99084848e-01,
                         -8.48919153e-02,  -6.77815497e-01,  -8.02996993e-01,
                         -2.53943056e-01,  -9.39996243e-02,  -5.28122187e-01,
                         -7.83977628e-01,  -6.62559628e-01,  -5.51896572e-01,
                         -5.62903523e-01,  -6.17198646e-01,  -6.56350076e-01,
                         -5.96050501e-01,  -5.47147036e-01,  -6.26185000e-01,
                         -6.73151255e-01,  -6.41574502e-01,  -6.26729012e-01,
                         -5.77061296e-01,  -5.64501762e-01,  -6.77710235e-01,
                         -6.84021115e-01,  -5.67371130e-01,  -6.49257720e-01,
                         -7.49539852e-01,  -3.91501129e-01,   9.98045504e-02,
                          3.61686951e-04,  -4.82638866e-01,  -6.45213068e-01,
                         -5.59674978e-01,  -6.06240928e-01,  -6.63973331e-01,
                         -6.05904996e-01,  -5.67713976e-01,  -6.30309999e-01,
                         -6.89913034e-01,  -4.70712781e-01,  -3.96956801e-02,
                          1.06919751e-01,  -2.37813182e-02,  -4.57675718e-02,
                          3.06428280e-02,   9.06775892e-02,   6.03781417e-02,
                         -6.48823008e-02,  -1.46825304e-02,   3.84383686e-02,
                         -3.01954210e-01,  -5.24358213e-01,  -2.07228005e-01,
                          8.78814310e-02,   4.40425165e-02,  -4.53444980e-02,
                          4.06907499e-02,   1.53922245e-01,  -1.28101513e-01,
                         -5.53875744e-01,  -3.58450681e-01,   1.01239868e-01,
                          8.41841549e-02,  -6.19342290e-02,  -2.16344818e-02,
                         -2.21948829e-02,  -3.90235591e-03,   5.63087501e-02,
                          3.37862894e-02,   2.60486379e-02,   1.71401557e-02,
                         -2.66542435e-02,   7.49587640e-03,   2.52654031e-02,
                         -2.26558466e-02,   9.96054150e-03,   7.87883848e-02,
                          5.79981096e-02,  -2.79006585e-02,  -5.18799275e-02,
                          3.56222540e-02,   6.41650632e-02,  -1.61267705e-02,
                         -4.68832962e-02,  -1.69742461e-02,   4.56153490e-02,
                          9.25377160e-02,   3.35297845e-02,  -3.48356529e-03,
                          1.45292310e-02,   1.77187119e-02,   8.47643688e-02,
                         -5.79334199e-02,  -4.59285617e-01,  -4.12721246e-01,
                          2.26768572e-02,   1.00906767e-01,  -3.70500199e-02,
                         -2.29155086e-02,   1.84546746e-02,   5.06259874e-02,
                          6.19177856e-02,  -4.47033020e-03,  -3.99648994e-02,
                          4.85833101e-02,   1.00148961e-01,  -2.16067165e-01,
                         -5.81694663e-01,  -2.93444604e-01,   1.35205746e-01,
                          1.24338679e-02,  -1.17001412e-02,   1.48136064e-01,
                         -2.45304808e-01,  -5.97993791e-01,  -1.88847601e-01,
                          2.10986510e-01,   7.99193382e-02,  -7.79372007e-02,
                         -6.36945537e-04,   6.89127147e-02,  -1.43258572e-01,
                         -5.58994949e-01,  -6.89310789e-01,  -5.38062096e-01,
                         -6.41506612e-01,  -7.01859176e-01,  -2.19595402e-01,
                         -4.73964447e-03,  -5.50859749e-01,  -7.52981305e-01,
                         -2.36928448e-01,  -1.15039855e-01,  -5.00289261e-01,
                         -3.74237359e-01,   9.95566100e-02,  -1.15200868e-02,
                         -4.66612101e-01,  -6.64647937e-01,  -7.47942626e-01,
                         -5.93536496e-01,  -1.22325800e-01,  -1.61593243e-01,
                         -7.13366807e-01,  -6.26154661e-01,  -6.15172572e-02,
                         -1.68422967e-01,  -6.73764884e-01,  -6.66715980e-01,
                         -5.07510900e-01,  -6.83793128e-01,  -5.70103168e-01,
                         -8.49193186e-02,  -2.02559873e-01,  -7.74626613e-01,
                         -6.58194840e-01,  -9.39370766e-02,  -2.04092413e-01,
                         -7.14314103e-01,  -6.81038201e-01,  -5.07224143e-01,
                         -6.98852181e-01,  -5.17141640e-01,  -7.04805553e-02,
                         -2.81232029e-01,  -4.58749473e-01,  -9.15459767e-02,
                         -2.92839974e-01,  -8.34996104e-01,  -5.09359300e-01,
                         -4.07979870e-03,  -2.83676475e-01,  -7.02583253e-01,
                         -6.79618657e-01,  -6.09679878e-01,  -6.92401826e-01,
                         -4.86425102e-01,   4.43022288e-02,   1.43566936e-01,
                         -3.61382484e-01,  -5.69021285e-01,  -1.32343829e-01,
                          1.39403850e-01,  -1.99515134e-01,  -6.28020227e-01,
                         -6.70303285e-01,  -2.84441978e-01,   1.69403791e-01,
                         -3.29935271e-03,  -5.93903244e-01,  -4.82431263e-01,
                          1.50829226e-01,   8.40462595e-02,  -4.94342208e-01,
                         -4.72915411e-01,   4.48770560e-02,   1.15578800e-01,
                         -3.64671975e-01,  -7.43149936e-01,  -6.47009015e-01,
                         -1.63103178e-01,   1.46915317e-01,  -1.96135208e-01,
                         -5.54203629e-01,  -3.02508980e-01,   3.02707255e-02,
                          1.19109228e-01,   4.39506546e-02,  -3.57281655e-01,
                         -7.05762446e-01,  -6.36610210e-01,  -5.81403255e-01,
                         -6.35624528e-01,  -5.96385896e-01,  -6.48877680e-01,
                         -6.63533509e-01,  -3.25148344e-01,   3.43926176e-02,
                          1.97012573e-02,  -5.56525700e-02,   7.77688846e-02,
                         -3.58123146e-02,  -5.19371152e-01,  -7.49963999e-01,
                         -6.29262030e-01,  -6.01179659e-01,  -6.80519938e-01,
                         -6.28871739e-01,  -5.24847090e-01,  -6.45361423e-01,
                         -7.03625202e-01,  -2.64148176e-01,  -7.13705271e-02,
                         -5.40946364e-01,  -4.71308172e-01,   1.72397047e-01,
                          1.88742913e-02,  -5.45670331e-01,  -3.91346514e-01,
                          9.47469193e-03,   7.90360272e-02,   6.26538917e-02,
                         -1.78507149e-01,  -7.04666853e-01,  -7.19549775e-01,
                         -1.60393417e-01,  -1.26546010e-01,  -6.26637280e-01,
                         -6.96736157e-01,  -5.60250342e-01,  -7.18194127e-01,
                         -5.99620402e-01,  -1.50197148e-01,  -1.98342234e-01,
                         -6.13152742e-01,  -6.47846162e-01,  -5.69307864e-01,
                         -7.56004274e-01,  -6.18683457e-01,  -7.21941516e-02,
                          8.76530558e-02,  -8.59744847e-02,  -6.00334955e-03,
                          1.93700548e-02,  -3.33559841e-01,  -4.67257649e-01,
                         -1.11585863e-01,   8.57421160e-02,  -4.22160365e-02,
                         -2.12905239e-02,   4.83883061e-02,  -3.19026373e-02,
                         -9.23363678e-03,   4.03739847e-02,  -8.23459681e-03,
                         -6.44780835e-03,   2.63905805e-03,   7.49730766e-02,
                          8.03966373e-02,  -3.24515671e-01,  -5.63991606e-01,
                         -1.77897707e-01,   1.01459302e-01,  -1.26613211e-02,
                         -6.07012808e-02,   3.76656018e-02,   5.02352603e-02,
                         -2.20391124e-01,  -4.79901791e-01,  -2.50537246e-01,
                          8.54760930e-02,   6.07292056e-02,  -2.75202394e-02,
                         -9.56979115e-03,  -5.97856306e-02,  -1.15819693e-01,
                          9.88569949e-03,   1.01016708e-01,  -2.18501374e-01,
                         -5.06830990e-01,  -2.13545203e-01,   8.74074847e-02,
                         -3.35987238e-03,  -2.28639003e-02,   4.34615351e-02,
                         -3.13980356e-02,  -5.99019378e-02,  -1.55960927e-02,
                         -1.81238372e-02,  -1.05540697e-02,   2.50796750e-02,
                          4.12440859e-02,   2.59889849e-02,  -1.49280466e-02,
                         -3.19749303e-02,   1.82368644e-02,   2.82868948e-02,
                         -6.21254109e-02,  -5.21153696e-02,   2.44318862e-02,
                         -3.99947464e-02,   1.55026757e-03,   8.97792578e-02,
                         -2.80018240e-01,  -7.12099075e-01,  -6.61234319e-01,
                         -6.02693379e-01,  -7.22834766e-01,  -5.19606590e-01,
                         -5.98372780e-02,   8.73609856e-02,  -2.56798774e-01,
                         -7.01491237e-01,  -7.23448157e-01,  -2.80200809e-01,
                          7.71711841e-02,   1.10801198e-02,  -4.94617596e-02,
                          5.54333292e-02,  -2.06795767e-01,  -5.53661764e-01,
                         -2.58667439e-01,   1.18833236e-01,  -5.55600738e-03,
                         -4.37211022e-02,   8.86011645e-02,  -2.21968174e-01,
                         -5.73358953e-01,  -2.08753899e-01,   1.93421692e-01,
                         -2.28524402e-01,  -6.49050236e-01,  -2.90023267e-01,
                          8.47958922e-02,   3.55624035e-02,   1.60308145e-02,
                          3.29074450e-02,  -5.67621626e-02,  -6.20794855e-02,
                          6.31704275e-03,   6.06740033e-03,  -6.50903862e-03,
                          2.73584258e-02,   1.12207262e-02,  -5.44098243e-02,
                         -5.28092533e-02,  -4.40410525e-02,  -1.10370887e-03,
                          9.68967229e-02,  -1.35181010e-01,  -5.22619247e-01,
                         -3.44591767e-01,   7.87819028e-02,   8.16829279e-02,
                         -4.54123840e-02,   2.67433771e-03,   2.15655528e-02,
                         -6.94584101e-02,  -6.67607412e-02,   7.18095899e-02,
                         -7.42028132e-02,  -4.74587381e-01,  -3.90609711e-01,
                          1.33311013e-02,   7.37331156e-03,  -6.16772324e-02,
                          6.28546327e-02,  -1.97687134e-01,  -5.07106662e-01,
                         -2.01498821e-01,  -1.20263420e-01,  -7.23447144e-01,
                         -7.64008403e-01,  -1.28162295e-01,  -1.57086223e-01,
                         -6.59853339e-01,  -6.82049572e-01,  -5.54023623e-01,
                         -6.20124638e-01,  -6.29329085e-01,  -6.28418684e-01,
                         -6.71872258e-01,  -6.62427902e-01,  -6.50139689e-01,
                         -6.48268223e-01,  -6.35080040e-01,  -6.30239487e-01,
                         -6.51629806e-01,  -6.86181903e-01,  -6.42782211e-01,
                         -5.76587737e-01,  -6.09354556e-01,  -6.31423771e-01,
                         -6.14537954e-01,  -6.57493889e-01,  -6.87437952e-01,
                         -6.66215062e-01,  -6.50623024e-01,  -6.36149168e-01,
                         -6.20906711e-01,  -6.03184640e-01,  -5.92807353e-01,
                         -6.06703460e-01,  -6.33632243e-01,  -6.82789624e-01,
                         -6.87262535e-01,  -6.04754329e-01,  -5.76125801e-01,
                         -6.25892103e-01,  -6.42962754e-01,  -6.35664225e-01,
                         -6.29791319e-01,  -6.35220528e-01,  -6.63721502e-01,
                         -6.72075212e-01,  -6.57495737e-01,  -6.30996346e-01,
                         -6.05319619e-01,  -6.30014837e-01,  -6.46336377e-01,
                         -5.98118424e-01,  -5.76396465e-01,  -6.22719467e-01,
                         -6.69300795e-01,  -6.49808705e-01,  -6.05042458e-01,
                         -6.27971113e-01,  -6.42578840e-01,  -5.85792065e-01,
                         -5.86929560e-01,  -6.59634173e-01,  -6.90283895e-01,
                         -6.63058698e-01,  -6.21524572e-01,  -6.10261500e-01,
                         -6.13391995e-01,  -6.02921665e-01,  -6.21572435e-01,
                         -6.39825106e-01,  -6.16634369e-01,  -6.25137925e-01,
                         -6.62078619e-01,  -6.32215381e-01,  -5.58534861e-01,
                         -5.73947847e-01,  -6.65790558e-01,  -6.63935840e-01,
                         -6.03838921e-01,  -6.18850768e-01,  -6.25921071e-01,
                         -6.03745639e-01,  -6.32114708e-01,  -6.56548202e-01,
                         -6.30231142e-01,  -5.95143974e-01,  -6.45709872e-01,
                         -7.00899482e-01,  -5.77333391e-01,  -5.85200608e-01,
                         -7.63020277e-01,  -4.62458640e-01,  -8.23555514e-02,
                         -3.44123900e-01,  -4.48058248e-01,  -1.38476849e-01,
                         -3.45731497e-01,  -7.65685380e-01,  -6.95512950e-01,
                         -5.69727242e-01,  -6.34379208e-01,  -5.95991790e-01,
                         -5.19676626e-01,  -6.36111200e-01,  -7.27339625e-01,
                         -3.99884313e-01,  -9.15785208e-02,  -4.30453569e-01,
                         -7.92716086e-01,  -6.35330856e-01,  -5.30205011e-01,
                         -5.83243906e-01,  -5.66507995e-01,  -7.28944004e-01,
                         -7.03825414e-01,  -1.90965071e-01,  -1.07822776e-01,
                         -6.15197003e-01,  -7.17144132e-01,  -5.63404202e-01,
                         -7.29192257e-01,  -5.88664770e-01,  -1.05326816e-01,
                         -2.42834583e-01,  -5.50877571e-01,  -8.96064639e-02,
                          2.13946506e-01,  -3.49152595e-01,  -5.76313555e-01,
                         -1.23302273e-01,  -2.13301867e-01,  -7.71051764e-01,
                         -6.13212764e-01,  -4.77631874e-02,  -2.18100548e-01,
                         -7.87003338e-01,  -6.49285674e-01,  -1.10967860e-01,
                         -1.79533795e-01,  -6.01130366e-01,  -7.05564976e-01,
                         -6.11987650e-01,  -3.60871702e-01,  -1.00354187e-01,
                         -4.29563344e-01,  -8.24137449e-01,  -3.92203182e-01,
                          1.11237047e-02,  -3.99986476e-01,  -7.31844306e-01,
                         -5.79246581e-01,  -6.26085162e-01,  -7.52233267e-01,
                         -3.44916672e-01,   2.29348764e-02,  -4.19991881e-01,
                         -8.45703602e-01,  -4.06521142e-01,  -6.88308431e-03,
                         -3.43458325e-01,  -7.09043741e-01,  -6.72716379e-01,
                         -5.29037237e-01,  -5.70372403e-01,  -7.35029221e-01,
                         -5.15542209e-01,  -1.17934570e-01,  -3.54843408e-01,
                         -5.59868097e-01,   3.76938172e-02,   2.16378331e-01,
                         -4.19901043e-01,  -4.64400798e-01,  -6.30339980e-02,
                         -3.37937176e-01,  -7.15183020e-01,  -5.74322522e-01,
                         -5.67732275e-01,  -7.24326789e-01,  -3.96888763e-01,
                         -3.47971581e-02,  -4.23960477e-01,  -8.39796126e-01,
                         -3.86848480e-01,  -1.84500981e-02,  -4.15396750e-01,
                         -4.10992712e-01,  -1.54847801e-02,  -4.42886233e-01,
                         -8.17018688e-01,  -2.42056996e-01,  -6.03037402e-02,
                         -4.77721691e-01,  -3.48797292e-01,  -1.68637678e-01,
                         -4.32733476e-01,  -2.73293555e-01,   1.77734897e-01,
                         -3.27763446e-02,  -6.01363242e-01,  -7.06404448e-01,
                         -5.40343940e-01,  -6.43405318e-01,  -6.79665029e-01,
                         -2.59895444e-01,  -6.26869202e-02,  -5.10778487e-01,
                         -7.77195990e-01,  -3.33101690e-01,   1.72786370e-01,
                          4.44794931e-02,  -4.79367256e-01,  -7.01194525e-01,
                         -6.12503409e-01,  -6.25860512e-01,  -6.19073570e-01,
                         -5.11160553e-01,  -5.77436030e-01,  -6.97013140e-01,
                         -6.78156376e-01,  -6.45540714e-01,  -6.22926772e-01,
                         -6.20104373e-01,  -6.04725003e-01,  -5.18963277e-01,
                         -6.17075980e-01,  -7.33721852e-01,  -3.77091318e-01,
                         -8.34962428e-02,  -3.94209564e-01,  -6.55211806e-01,
                         -6.05517328e-01,  -6.61118031e-01,  -6.48409009e-01,
                         -5.19260108e-01,  -6.34947181e-01,  -6.26659811e-01,
                         -2.31365785e-01,  -1.86653495e-01,  -5.80695093e-01,
                         -6.40639484e-01,  -5.56810498e-01,  -7.41486847e-01,
                         -5.87131977e-01,  -1.24849260e-01,  -2.12567344e-01,
                         -5.93297660e-01,  -6.24300301e-01,  -5.76634049e-01,
                         -6.43309772e-01,  -6.45912826e-01,  -6.19178593e-01,
                         -6.01578295e-01,  -6.03747904e-01,  -6.44073606e-01,
                         -6.37251556e-01,  -6.24223590e-01,  -6.46717191e-01,
                         -6.34055316e-01,  -6.32929146e-01,  -6.31955445e-01,
                         -6.04093134e-01,  -6.23318791e-01,  -5.73067665e-01,
                         -5.26388407e-01,  -7.12733150e-01,  -6.73564553e-01,
                         -1.95968017e-01,  -1.18420862e-01,  -5.65657377e-01,
                         -6.99376702e-01,  -5.59748888e-01,  -6.04232013e-01,
                         -6.12575412e-01,  -5.52504122e-01,  -6.51333928e-01,
                         -6.91865444e-01,  -6.10128105e-01,  -6.41240716e-01,
                         -6.75267339e-01,  -6.02541387e-01,  -5.94884157e-01,
                         -6.57251418e-01,  -6.57490611e-01,  -5.95559895e-01,
                         -5.76391339e-01,  -6.43175006e-01,  -6.54087543e-01,
                         -5.75955689e-01,  -5.84273577e-01,  -6.33635998e-01,
                         -6.11347139e-01,  -6.34052277e-01,  -6.74706697e-01,
                         -6.23713493e-01,  -6.02922916e-01,  -6.32111371e-01,
                         -5.99526048e-01,  -5.80622911e-01,  -6.21463597e-01,
                         -6.35464311e-01,  -6.40060425e-01,  -6.51437938e-01,
                         -6.05191588e-01,  -5.54784954e-01,  -6.00128770e-01,
                         -6.75719142e-01,  -6.50462210e-01,  -5.75846672e-01,
                         -6.23735130e-01,  -7.19276369e-01,  -6.40931666e-01,
                         -5.22210538e-01,  -5.97832143e-01,  -7.02477276e-01,
                         -6.58123314e-01,  -5.97975314e-01,  -6.19127154e-01,
                         -6.39524043e-01,  -5.85201859e-01,  -5.33174694e-01,
                         -5.96158504e-01,  -6.68377221e-01,  -6.37533247e-01,
                         -6.21740937e-01,  -6.56769514e-01,  -6.50052428e-01,
                         -6.22565866e-01,  -6.15219474e-01,  -6.28334999e-01,
                         -6.59941614e-01,  -6.69162333e-01,  -6.43111229e-01,
                         -6.19230866e-01,  -6.39330268e-01,  -6.89677775e-01,
                         -6.61792397e-01,  -5.58801830e-01,  -5.40229619e-01,
                         -6.22499585e-01,  -6.71832502e-01,  -6.43116236e-01,
                         -6.23875380e-01,  -6.57587230e-01,  -6.46440327e-01,
                         -5.99211037e-01,  -6.33104265e-01,  -6.67864978e-01,
                         -6.23098969e-01,  -5.91977358e-01,  -6.05264008e-01,
                         -6.49696112e-01,  -6.81049824e-01,  -6.21812582e-01,
                         -5.81157804e-01,  -6.57810628e-01,  -7.10328579e-01,
                         -6.51526511e-01,  -5.86017072e-01,  -6.13504767e-01,
                         -6.55909717e-01,  -5.95405281e-01,  -5.59062481e-01,
                         -6.61064327e-01,  -7.33139455e-01,  -6.71982527e-01,
                         -5.94345272e-01,  -6.03271663e-01,  -6.40847385e-01,
                         -6.03299677e-01,  -5.68052351e-01,  -6.07534826e-01,
                         -6.52335823e-01,  -6.80378079e-01,  -6.17259920e-01,
                         -5.58162153e-01,  -7.40647078e-01,  -7.27085233e-01,
                         -2.35109493e-01,  -9.21877176e-02,  -5.17415166e-01,
                         -7.33681321e-01,  -6.62451446e-01,  -5.00712931e-01,
                         -9.99209955e-02,   1.27946407e-01,  -2.36064479e-01,
                         -6.52633369e-01,  -6.23494029e-01,  -5.39800346e-01,
                         -6.97253227e-01,  -5.90209603e-01,  -1.53832883e-01,
                         -2.11165518e-01,  -6.93036079e-01,  -7.20056176e-01,
                         -5.35518289e-01,  -6.49637401e-01,  -5.09720743e-01,
                         -1.29229173e-01,  -3.66831839e-01,  -8.18251073e-01,
                         -5.23564577e-01,  -7.82791898e-02,  -3.13903630e-01,
                         -6.82135046e-01,  -6.77940011e-01,  -5.92392325e-01,
                         -4.16960299e-01,  -1.40368519e-02,   1.40439317e-01,
                         -2.94095397e-01,  -7.58072734e-01,  -5.93359470e-01,
                         -1.47572756e-01,  -2.37274423e-01,  -7.10101843e-01,
                         -6.75109982e-01,  -1.69800639e-01,  -1.79229364e-01,
                         -6.90447390e-01,  -6.26236916e-01,  -1.38809606e-01,
                         -2.80467540e-01,  -6.04415298e-01,  -2.56409585e-01,
                          9.95126888e-02,  -3.15400921e-02,  -2.84536090e-02,
                          1.09026507e-01,  -2.38819137e-01,  -7.86976576e-01,
                         -6.95732176e-01,  -1.11734435e-01,  -8.42078030e-02,
                         -7.10688293e-01,  -8.23609829e-01,  -2.00578272e-01,
                         -5.90951517e-02,  -6.40292525e-01,  -7.55613625e-01,
                         -2.54619062e-01,  -2.29047328e-01,  -5.88124812e-01,
                         -3.28970164e-01,   1.69467703e-01,  -7.15814456e-02,
                         -5.51813781e-01,  -3.23441654e-01,   1.41316712e-01,
                         -5.11597171e-02,  -5.42853832e-01,  -6.72163427e-01,
                         -6.75011516e-01,  -6.24543667e-01,  -2.34455511e-01,
                          2.20345613e-02,  -1.21024452e-01,  -4.36679274e-02,
                          1.59629568e-01,  -1.52202070e-01,  -6.95256352e-01,
                         -8.14946175e-01,  -3.93055439e-01,   8.76003727e-02,
                         -2.99886875e-02,  -4.69630659e-01,  -3.65469992e-01,
                          7.95153007e-02,   1.63741987e-02,  -5.34492016e-01,
                         -8.29361200e-01,  -4.93834436e-01,  -1.75193194e-02,
                          2.66176052e-02,  -1.15992844e-01,  -5.05077913e-02,
                          3.84884700e-02,  -7.91213848e-03,  -4.16934863e-02,
                         -3.38078737e-02,  -4.57678735e-02,  -3.94379832e-02,
                         -6.99356198e-03,  -1.69898644e-02,  -6.32584020e-02,
                         -6.70570806e-02,  -3.64818983e-02,  -3.29578295e-02,
                         -2.75974851e-02,   1.79997478e-02,   2.48697735e-02,
                         -4.32490408e-02,  -4.91405465e-02,   2.66791899e-02,
                          7.13849347e-03,  -6.78795129e-02,  -3.37391533e-02,
                          1.04294987e-02,  -3.70242558e-02,  -7.64637962e-02,
                         -4.95362468e-02,  -8.27624928e-03,  -3.56939211e-02,
                         -8.39101225e-02,  -1.57102477e-02,   3.23517136e-02,
                         -8.04988295e-02,  -9.43996683e-02,   6.74936548e-02,
                          7.03960955e-02,  -1.03167556e-01,  -1.19922228e-01,
                          2.67726500e-02,   5.01714498e-02,  -5.92698604e-02,
                         -7.20720515e-02,   1.70303462e-03,   1.30663218e-03,
                         -3.02856434e-02,  -9.86610074e-03,  -4.73317737e-03,
                         -4.52139117e-02,  -6.17242754e-02,  -4.52057421e-02,
                         -4.76209074e-02,  -5.00722975e-02,  -1.94442905e-02,
                         -7.43528362e-03,  -1.68272238e-02,   5.22787636e-03,
                          9.69316065e-03,  -2.22419873e-02,  -1.96256321e-02,
                         -2.18916051e-02,  -6.66690171e-02,  -6.73913285e-02,
                         -2.51036622e-02,  -1.18987085e-02,  -1.69834495e-02,
                         -2.71694697e-02,  -4.55223992e-02,  -3.58166918e-02,
                          6.21600961e-03,   1.24802943e-02,  -4.15221564e-02,
                         -6.47317395e-02,  -2.42475066e-02,  -2.65274360e-03,
                          1.55959674e-03,   2.09963247e-02,   2.37276289e-03,
                         -5.97249232e-02,  -1.01850621e-01,  -6.28713369e-02,
                          2.51367483e-02,   2.16528792e-02,  -4.59976979e-02,
                         -4.63462435e-02,  -3.71919610e-02,  -3.59285176e-02,
                          1.61901116e-02,   2.56998949e-02,  -2.08171476e-02,
                         -1.91879105e-02,   6.89526554e-03,   8.24292307e-04,
                         -1.71197616e-02,  -1.11889672e-02,  -7.05601415e-03,
                         -4.35479209e-02,  -4.49841283e-02,   3.65407160e-03,
                         -7.78328488e-03,  -4.44427393e-02,  -2.49069650e-02,
                          6.66341465e-03,   1.78005956e-02,   2.09551957e-03,
                         -2.62912922e-02,  -2.10980587e-02,   1.13110105e-03,
                         -5.13038458e-03,  -3.40706259e-02,  -1.24444095e-02,
                          7.60565773e-02,   6.59629628e-02,  -6.96581155e-02,
                         -1.01237118e-01,  -1.19717224e-02,   2.20277924e-02,
                         -2.29061791e-03,  -3.14631388e-02,  -4.60021272e-02,
                         -6.98029413e-04,   4.06568274e-02,  -1.06305629e-02,
                         -4.99965325e-02,   1.64479446e-02,   6.89412579e-02,
                          4.43381770e-03,  -1.00782372e-01,  -9.19032246e-02,
                          5.81659414e-02,   9.82049555e-02,  -3.43645327e-02,
                          9.63049941e-03,   5.63379824e-02,  -3.18473190e-01,
                         -5.02031684e-01,  -1.31603211e-01,  -1.64938465e-01,
                         -7.05109298e-01,  -7.26652861e-01,  -2.49033257e-01,
                          5.47869913e-02,  -5.17954603e-02,  -5.37477374e-01,
                         -7.66989648e-01,  -3.48108232e-01,  -1.06124595e-01,
                         -3.99706244e-01,  -6.50236607e-01,  -7.19735205e-01,
                         -5.47413349e-01,  -1.67012706e-01,  -2.26542428e-01,
                         -6.38163626e-01,  -6.97629392e-01,  -6.10282898e-01,
                         -6.69136584e-01,  -6.05078936e-01,  -5.31951606e-01,
                         -6.57956481e-01,  -7.17840850e-01,  -6.19812131e-01,
                         -6.17818356e-01,  -6.79835677e-01,  -4.75554109e-01,
                         -5.83012290e-02,   6.22838512e-02,  -2.85034120e-01,
                         -6.28677070e-01,  -6.30495727e-01,  -6.25371099e-01,
                         -7.66406775e-01,  -5.12636304e-01,  -9.46403574e-03,
                         -2.25324214e-01,  -8.35559845e-01,  -6.24224901e-01,
                          3.73719865e-03,  -1.62761301e-01,  -7.30021060e-01,
                         -7.26257741e-01,  -5.64396322e-01,  -7.30957150e-01,
                         -5.64402580e-01,  -9.09465700e-02,  -2.42500439e-01,
                         -6.86388135e-01,  -6.36402249e-01,  -5.87624490e-01,
                         -7.61563182e-01,  -4.68326628e-01,  -1.46934167e-02,
                         -3.03027719e-01,  -8.19070458e-01,  -5.36466956e-01,
                          7.92371389e-03,  -2.78518498e-01,  -8.38967085e-01,
                         -5.43369472e-01,  -3.11707389e-02,  -3.38293284e-01,
                         -6.15260601e-01,  -7.69977719e-02,   1.86868429e-01,
                         -3.29769135e-01,  -6.44124210e-01,  -5.75973868e-01,
                         -6.38037503e-01,  -6.92851663e-01,  -6.18408978e-01,
                         -6.16434872e-01,  -6.54793978e-01,  -5.79903603e-01,
                         -4.77719933e-01,  -6.44878566e-01,  -8.42876911e-01,
                         -4.46339995e-01,   2.20283661e-02,  -3.06149840e-01,
                         -7.61544645e-01,  -6.45037234e-01,  -5.42606592e-01,
                         -6.87046349e-01,  -6.71008408e-01,  -5.96413910e-01,
                         -6.54716074e-01,  -6.57628596e-01,  -6.02374792e-01,
                         -6.30353391e-01,  -6.14566565e-01,  -5.36255002e-01,
                         -6.19660378e-01,  -6.40399039e-01,  -2.97957480e-01,
                         -1.53518051e-01,  -5.39704263e-01,  -7.36033082e-01,
                         -5.75893998e-01,  -6.31528318e-01,  -6.54609621e-01,
                         -2.04275519e-01,   1.72760248e-01,  -8.10882077e-02,
                         -5.62935531e-01,  -6.97613597e-01,  -6.48437917e-01,
                         -5.73980808e-01,  -1.52710423e-01,   2.25851461e-01,
                         -9.55039561e-02,  -6.05774045e-01,  -7.22474992e-01,
                         -6.24413729e-01,  -5.36640048e-01,  -6.61990225e-01,
                         -7.40143180e-01,  -3.25003505e-01,  -4.39744331e-02,
                         -3.95701021e-01,  -7.08547831e-01,  -6.62134409e-01,
                         -5.96800148e-01,  -6.25176430e-01,  -6.16430819e-01,
                         -5.42056501e-01,  -6.26465619e-01,  -7.00655520e-01,
                         -3.34722012e-01,  -6.97756410e-02,  -4.25714374e-01,
                         -7.29015648e-01,  -6.33196592e-01,  -5.61047792e-01,
                         -5.86230814e-01,  -6.28583431e-01,  -7.04668105e-01,
                         -5.77371597e-01,  -1.45043299e-01,   1.33736774e-01,
                         -1.32128626e-01,  -5.61967015e-01,  -6.44547939e-01,
                         -5.57667077e-01,  -5.80759525e-01,  -6.03009820e-01,
                         -5.89546144e-01,  -6.14008188e-01,  -6.13668382e-01,
                         -5.82725525e-01,  -5.93394756e-01,  -6.16784811e-01,
                         -6.08391941e-01,  -5.96891224e-01,  -6.06222272e-01,
                         -6.27769351e-01,  -6.39377356e-01,  -6.21889889e-01,
                         -5.98495066e-01,  -6.02787435e-01,  -6.15534663e-01,
                         -6.06763899e-01,  -5.98701239e-01,  -6.11655474e-01,
                         -6.05222166e-01,  -5.83497405e-01,  -6.10186279e-01,
                         -6.43710673e-01,  -6.15237236e-01,  -5.71128190e-01,
                         -5.65628529e-01,  -6.04390621e-01,  -6.36741698e-01,
                         -6.10629737e-01,  -5.87950706e-01,  -5.96986234e-01,
                         -5.99588752e-01,  -6.16217494e-01,  -6.22833729e-01,
                         -6.18777514e-01,  -6.24567389e-01,  -5.85956573e-01,
                         -6.11946762e-01,  -6.39626801e-01,  -3.44761699e-01,
                         -1.03438817e-01,  -4.03233916e-01,  -6.92548990e-01,
                         -5.99287331e-01,  -5.70725501e-01,  -6.61340296e-01,
                         -6.19990826e-01,  -5.47112823e-01,  -5.51895261e-01,
                         -6.43223882e-01,  -7.18965113e-01,  -5.96269727e-01,
                         -5.24067879e-01,  -6.56293988e-01,  -4.64490384e-01,
                         -8.13372657e-02,  -3.05023164e-01,  -7.02518523e-01,
                         -5.75768590e-01,  -5.54158866e-01,  -7.81888306e-01,
                         -4.48695451e-01,   6.43046619e-03,  -3.48027736e-01,
                         -7.76456058e-01,  -4.02274013e-01,  -4.91114482e-02,
                         -3.79504353e-01,  -6.78684413e-01,  -6.43523097e-01,
                         -5.57882130e-01,  -2.64962673e-01,  -1.09962314e-01,
                         -5.40311038e-01,  -6.93357289e-01,  -1.77371532e-01,
                         -7.39502236e-02,  -5.72096348e-01,  -7.14020729e-01,
                         -5.37737370e-01,  -6.57894433e-01,  -6.41544580e-01,
                         -1.82255670e-01,  -1.36395171e-01,  -6.13586247e-01,
                         -7.51382113e-01,  -6.10036850e-01,  -5.84772706e-01,
                         -5.64494073e-01,  -6.21919990e-01,  -6.76996887e-01,
                         -5.68235159e-01,  -5.80686927e-01,  -6.58052087e-01,
                         -5.87638378e-01,  -6.13039494e-01,  -6.27791643e-01,
                         -2.90493637e-01,   1.05453119e-01,   3.48142795e-02,
                         -4.66164082e-01,  -7.55577028e-01,  -4.59907740e-01,
                         -4.41343971e-02,   4.77593020e-02,   3.61133280e-04,
                          2.92767212e-02,   4.25512120e-02,  -3.50322668e-03,
                          2.18485110e-02,   8.46902877e-02,   3.41626853e-02,
                         -2.36189067e-02,   1.24650318e-02,   2.26073842e-02,
                         -2.01326981e-03,  -9.02407989e-03,  -1.09790340e-02,
                          1.99941397e-02,   3.05379499e-02,   3.92904282e-02,
                          1.32640928e-01,   6.01214590e-03,  -4.07020688e-01,
                         -4.52669054e-01,  -6.76239282e-02,   7.44520575e-02,
                         -2.99538560e-02,  -8.30159429e-03,   4.14562337e-02,
                         -1.89240812e-03,  -1.18940799e-02,   7.60241598e-02,
                         -8.05874181e-04,  -3.83156180e-01,  -4.57359284e-01,
                         -2.85416581e-02,   1.01906538e-01,  -2.79063936e-02,
                          1.14749201e-01,  -1.27031924e-02,  -4.61370230e-01,
                         -3.48401219e-01,   6.60578981e-02,   4.71101403e-02,
                         -6.83856010e-02,   2.64312718e-02,   5.28452955e-02,
                          1.76745430e-02,   4.31806967e-02,   3.04561090e-02,
                         -1.93188747e-03,  -3.97880748e-03,   4.79375990e-03,
                          2.74264044e-03,  -6.66082054e-02,   1.17222052e-02,
                          2.40709558e-01,  -1.43285533e-02,  -5.30899405e-01,
                         -3.81961584e-01,   5.65955527e-02,   7.40613490e-02,
                         -5.03847143e-03,   3.29978429e-02,   1.72943007e-02,
                         -5.05212555e-03,   3.51403728e-02,   6.91232532e-02,
                          1.15536526e-02,   2.31516846e-02,   9.61371884e-02,
                         -1.88429207e-01,  -4.80890393e-01,  -1.80408552e-01,
                          1.20609201e-01,   2.18984466e-02,  -4.66807187e-03,
                          4.44452167e-02,  -1.23467296e-03,   2.09805593e-02,
                          7.92999342e-02,   3.14740464e-02,  -5.44911325e-02,
                          4.33267243e-02,   1.15586005e-01,  -2.92739898e-01,
                         -5.34156382e-01,  -6.10725582e-03,   1.63799226e-01,
                         -4.13875937e-01,  -4.36652899e-01,  -3.43664140e-02,
                         -2.80208915e-01,  -4.77949739e-01,   2.42552478e-02,
                          1.31306171e-01,  -4.79877621e-01,  -5.53893447e-01,
                          9.96126086e-02,   2.25216195e-01,  -3.77301186e-01,
                         -5.36865234e-01,  -2.17576418e-02,   1.95341319e-01,
                         -2.83100773e-02,  -4.38883249e-03,   1.21178828e-01,
                         -2.73577750e-01,  -7.81030118e-01,  -5.45215726e-01,
                         -3.86829339e-02,  -2.43242890e-01,  -5.29912353e-01,
                         -7.64654428e-02,   2.03677952e-01,  -2.49818221e-01,
                         -5.93098104e-01,  -6.13918722e-01,  -6.56407118e-01,
                         -4.48886156e-01,   2.91182194e-02,   1.43943861e-01,
                         -3.13147873e-01,  -7.33972669e-01,  -5.80991507e-01,
                         -1.53042838e-01,   3.57392393e-02,   6.82753399e-02,
                          5.91359809e-02,  -2.72619396e-01,  -7.19836712e-01,
                         -5.65393448e-01,  -5.17256036e-02,  -1.97213829e-01,
                         -7.61354744e-01,  -5.80738425e-01,  -1.05724044e-04,
                         -2.14106694e-01,  -6.19220972e-01,  -1.42437115e-01,
                          2.25364044e-01,  -3.08365762e-01,  -5.35280168e-01,
                         -1.27009124e-01,  -2.04444051e-01,  -7.00383067e-01,
                         -6.71640635e-01,  -9.59928408e-02,   1.90806031e-01,
                         -2.52933472e-01,  -5.75083375e-01,  -1.68603703e-01,
                         -8.29309300e-02,  -7.01044381e-01,  -7.14516282e-01,
                         -6.20685071e-02,  -1.34257019e-01,  -6.21618152e-01,
                         -2.30644748e-01,   2.55144417e-01,  -2.50406355e-01,
                         -6.14926994e-01,  -1.73922002e-01,  -1.22062147e-01,
                         -6.71358585e-01,  -7.62152553e-01,  -2.01238438e-01,
                          1.95237458e-01,  -1.29554823e-01,  -5.79909623e-01,
                         -3.55357885e-01,   6.96049780e-02,   5.87365255e-02,
                         -1.58159621e-02,   3.80176343e-02,  -3.65378745e-02,
                         -6.19174428e-02,   3.19181308e-02,  -1.74609840e-01,
                         -6.10626042e-01,  -6.82390630e-01,  -3.00242364e-01,
                          6.57134652e-02,  -3.76531156e-03,  -4.82264280e-01,
                         -7.73597002e-01,  -4.87438232e-01,  -1.09383360e-01,
                         -2.16923375e-02,   5.91544285e-02,  -8.34195036e-03,
                         -5.63251078e-01,  -8.49500954e-01,  -3.35796654e-01,
                         -8.21437910e-02,  -5.08853674e-01,  -4.77944702e-01,
                          8.37630406e-02,   1.93562340e-02,  -5.55040598e-01,
                         -4.82822299e-01,   1.06888138e-01,   8.65076482e-03,
                         -5.51663220e-01,  -3.98616195e-01,  -9.55209285e-02,
                         -4.66994792e-01,  -4.94044363e-01,   8.99751410e-02,
                          4.08923253e-03,  -6.11272812e-01,  -4.99817461e-01,
                          8.94859657e-02,   1.00016510e-02,  -5.33123255e-01,
                         -4.93403584e-01,  -3.09565943e-02,   6.77761212e-02,
                         -5.20773754e-02,  -4.24137712e-02,  -3.27244736e-02,
                         -5.09807803e-02,  -3.46170291e-02,  -2.09094472e-02,
                          2.18864437e-03,   2.68082526e-02,  -4.73198667e-03,
                         -7.21596852e-02,  -8.37821066e-02,  -5.69482855e-02,
                         -7.25732669e-02,  -5.47074191e-02,   1.35900108e-02,
                          6.12752326e-03,  -3.58450450e-02,  -3.77178788e-02,
                         -3.44556645e-02,  -2.06391811e-02,  -3.18293422e-02,
                         -7.95531645e-02,  -6.59924671e-02,  -2.31579207e-02,
                         -4.57360223e-02,  -7.34166577e-02,  -3.50244418e-02,
                          1.16285793e-02,  -1.95916574e-02,  -8.70733485e-02,
                         -7.51144886e-02,  -2.14565694e-02,  -3.44313756e-02,
                         -5.03297523e-02,  -1.15453582e-02,  -2.08874866e-02,
                         -7.02058524e-02,  -4.68180515e-02,  -6.93578986e-05,
                         -1.38877723e-02,  -3.55313756e-02,  -9.65857040e-03,
                         -1.41869541e-02,  -8.28869417e-02,  -4.96721119e-02,
                          1.42383119e-02,  -8.13710093e-02,  -2.82506235e-02,
                          9.12348256e-02,  -2.93614686e-01,  -6.21360660e-01,
                         -2.59197295e-01,   4.12620232e-02,  -4.11455408e-02,
                         -2.20676363e-02,  -9.07220971e-03,  -1.01767831e-01,
                         -4.35056947e-02,   3.82084586e-02,  -5.87009341e-02,
                         -9.84465629e-02,   7.88667053e-02,  -1.47421937e-02,
                         -4.85933900e-01,  -4.65758711e-01,  -8.72646049e-02,
                         -3.74525905e-01,  -8.23235929e-01,  -6.70510709e-01,
                         -5.69786727e-01,  -7.11427867e-01,  -4.74460512e-01,
                         -3.88748571e-02,   4.26543318e-02,  -8.37775692e-02,
                         -3.54700722e-02,  -4.95704710e-02,  -4.77592617e-01,
                         -7.94682682e-01,  -5.02116501e-01,  -1.26177952e-01,
                         -9.87990107e-03,   6.59799203e-02,  -1.32515043e-01,
                         -5.20161569e-01,  -3.63751978e-01,   5.18774502e-02,
                          9.83337034e-03,  -1.03439920e-01,  -4.29686764e-03,
                         -2.06360687e-02,  -6.67201206e-02,  -1.44905979e-02,
                          1.67100187e-02,  -1.07732862e-01,  -5.44324160e-01,
                         -8.29475224e-01,  -4.64471966e-01,  -4.30453122e-02,
                          9.23104584e-03,   1.12226075e-02,  -1.62290543e-01,
                         -6.27021432e-01,  -7.76129782e-01,  -3.26798499e-01,
                          5.42099923e-02,  -8.03957507e-02,  -1.18353561e-01,
                          1.34477869e-01,  -1.20267294e-01,  -5.79461396e-01,
                         -3.09107155e-01,  -9.22150761e-02,  -6.71368957e-01,
                         -8.96547973e-01,  -2.74032235e-01,  -5.63179553e-02,
                         -6.41291440e-01,  -8.49602640e-01,  -2.72767514e-01,
                         -7.32613355e-02,  -5.51185310e-01,  -4.35085475e-01,
                          1.49469793e-01,  -1.26145124e-01,  -5.74339271e-01,
                         -2.53047079e-01,  -2.05230594e-01,  -5.23682952e-01,
                         -2.66402990e-01,  -1.67451575e-01,  -7.18104959e-01,
                         -8.18009377e-01,  -2.49390349e-01,   1.09756976e-01,
                         -9.20528695e-02,  -5.36307871e-01,  -7.49088526e-01,
                         -6.77565575e-01,  -6.33853197e-01,  -6.72840893e-01,
                         -6.96761906e-01,  -6.97876692e-01,  -6.60991371e-01,
                         -6.28384113e-01,  -6.39808595e-01,  -6.46897614e-01,
                         -6.56513333e-01,  -6.91467464e-01,  -6.76431537e-01,
                         -6.16005421e-01,  -6.24229252e-01,  -6.54467225e-01,
                         -6.38107240e-01,  -6.73407793e-01,  -7.20583320e-01,
                         -6.83116317e-01,  -6.62647188e-01,  -6.83801055e-01,
                         -6.76635981e-01,  -6.59497023e-01,  -6.47848487e-01,
                         -6.62558019e-01,  -6.96866632e-01,  -6.81467175e-01,
                         -6.29025817e-01,  -6.24928534e-01,  -6.89328015e-01,
                         -7.11851478e-01,  -6.56758606e-01,  -6.62865102e-01,
                         -6.99965358e-01,  -6.79914176e-01,  -6.88744605e-01,
                         -6.89499021e-01,  -6.62291944e-01,  -6.83451712e-01,
                         -6.60555243e-01,  -6.38377726e-01,  -6.96864963e-01,
                         -6.74577117e-01,  -6.38228238e-01,  -7.11071491e-01,
                         -7.19606996e-01,  -6.51305914e-01,  -6.52965605e-01,
                         -7.01875329e-01,  -7.23073542e-01,  -7.06535876e-01,
                         -6.80499911e-01,  -6.67852521e-01,  -6.66359842e-01,
                         -6.27275229e-01,  -6.09038770e-01,  -7.45961607e-01,
                         -7.02513218e-01,  -2.72459209e-01,  -1.92081481e-01,
                         -6.22367442e-01,  -7.34083712e-01,  -6.27791643e-01,
                         -7.97123492e-01,  -7.18215764e-01,  -2.31967047e-01,
                         -2.00329334e-01,  -7.20490932e-01,  -7.67430067e-01,
                         -1.97805092e-01,  -1.34520054e-01,  -7.26903498e-01,
                         -8.10695708e-01,  -2.23660216e-01,  -9.29234996e-02,
                         -6.65911257e-01,  -8.59950662e-01,  -3.37247103e-01,
                         -1.49281070e-01,  -5.95886171e-01,  -7.61979520e-01,
                         -6.03890479e-01,  -7.48513997e-01,  -7.60315657e-01,
                         -2.44052410e-01,  -1.15654863e-01,  -6.89417124e-01,
                         -8.16845655e-01,  -2.60134369e-01,  -1.36537194e-01,
                         -5.85947454e-01,  -7.67694771e-01,  -6.60886645e-01,
                         -6.96879745e-01,  -7.49633849e-01,  -6.89640284e-01,
                         -6.64858282e-01,  -6.78158402e-01,  -7.01492488e-01,
                         -6.89089119e-01,  -6.22109830e-01,  -7.09037423e-01,
                         -7.26480782e-01,  -3.32578331e-01,  -1.61398500e-01,
                         -5.52438974e-01,  -7.83297241e-01,  -6.96409702e-01,
                         -6.83160424e-01,  -7.35704780e-01,  -7.52189636e-01,
                         -5.45646727e-01,  -7.62160346e-02,   9.07062516e-02,
                         -3.44420224e-01,  -7.66944289e-01,  -6.99258924e-01,
                         -6.38974845e-01,  -8.28951776e-01,  -5.97902954e-01,
                         -1.25592977e-01,  -3.01342785e-01,  -7.35809505e-01,
                         -7.22987652e-01,  -5.93834460e-01,  -6.62230551e-01,
                         -7.36134410e-01,  -7.15676308e-01,  -7.09162414e-01,
                         -6.97712183e-01,  -6.31075144e-01,  -7.19235241e-01,
                         -7.73447573e-01,  -4.07300144e-01,  -1.68851897e-01,
                         -4.52958435e-01,  -7.22708762e-01,  -7.95071602e-01,
                         -6.46553576e-01,  -1.92293867e-01,  -1.59650594e-01,
                         -7.57743657e-01,  -8.22405934e-01,  -1.71403840e-01,
                         -1.18548863e-01,  -7.68254995e-01,  -8.14301550e-01,
                         -2.33877748e-01,  -1.82641566e-01,  -6.37569666e-01,
                         -7.75175095e-01,  -6.23496830e-01,  -6.26284122e-01,
                         -7.30529070e-01,  -6.89458549e-01,  -6.34992838e-01,
                         -7.79551327e-01,  -7.43791461e-01,  -2.53497392e-01,
                         -9.25232843e-02,  -6.58844411e-01,  -8.46906126e-01,
                         -2.55077422e-01,  -8.80155861e-02,  -5.97447455e-01,
                         -7.88678885e-01,  -6.31498635e-01,  -6.97291553e-01,
                         -7.34215915e-01,  -3.46848249e-01,   6.31915554e-02,
                         -9.44521427e-02,  -5.69431543e-01,  -7.19273984e-01,
                         -6.26834393e-01,  -6.51286185e-01,  -6.77921653e-01,
                         -6.32523358e-01,  -6.92186594e-01,  -7.02061713e-01,
                         -3.16782415e-01,   1.01644397e-01,  -1.03982039e-01,
                         -5.63038468e-01,  -6.92574859e-01,  -7.55684435e-01,
                         -6.50907218e-01,  -1.64472207e-01,  -1.60712630e-01,
                         -7.60186613e-01,  -7.28219688e-01,  -1.52402148e-01,
                         -2.34739259e-01,  -5.90733528e-01,  -2.14249745e-01,
                          1.70047775e-01,  -2.83708900e-01,  -6.55336380e-01,
                         -2.43393570e-01,   1.15266368e-01,  -1.62022248e-01,
                         -5.80562830e-01,  -6.92745268e-01,  -6.38454795e-01,
                         -6.10008478e-01,  -6.26836121e-01,  -7.16418087e-01,
                         -5.43314934e-01,   3.74012999e-02,   1.01684786e-01,
                         -4.54948992e-01,  -4.36344355e-01,  -1.53812498e-01,
                         -4.26315099e-01,  -4.03201252e-01,  -7.65274689e-02,
                         -4.82351720e-01,  -8.49098086e-01,  -3.39156657e-01,
                         -4.45856042e-02,  -4.77683127e-01,  -7.35889316e-01,
                         -5.97881258e-01,  -5.67105949e-01,  -6.56974614e-01,
                         -6.64430737e-01,  -6.31984949e-01,  -6.08784080e-01,
                         -6.07235610e-01,  -6.35117948e-01,  -6.35639608e-01,
                         -6.14809692e-01,  -6.24285758e-01,  -6.23729825e-01,
                         -5.97780824e-01,  -6.08920157e-01,  -6.27303541e-01,
                         -6.05285406e-01,  -5.98629177e-01,  -5.94081521e-01,
                         -5.97015381e-01,  -6.46669686e-01,  -5.92909217e-01,
                         -5.57517171e-01,  -7.10759223e-01,  -5.31025052e-01,
                         -6.96899891e-02,  -2.01920614e-01,  -6.54656589e-01,
                         -6.68485045e-01,  -5.34769773e-01,  -5.76394916e-01,
                         -6.14284158e-01,  -5.68476558e-01,  -5.83794773e-01,
                         -6.82111263e-01,  -4.64870960e-01,  -6.09325245e-02,
                         -2.20594406e-01,  -6.45770609e-01,  -6.31139696e-01,
                         -5.09395838e-01,  -5.98938584e-01,  -6.26626253e-01,
                         -5.16241491e-01,  -5.42470634e-01,  -7.03805268e-01,
                         -4.82028782e-01,  -2.36266907e-02,  -1.60224542e-01,
                         -6.21249914e-01,  -6.61558509e-01,  -5.34044623e-01,
                         -5.40581226e-01,  -5.51734388e-01,  -5.70686281e-01,
                         -5.79517961e-01,  -5.55444360e-01,  -5.62028229e-01,
                         -5.50577223e-01,  -5.27236104e-01,  -5.69964647e-01,
                         -5.93269587e-01,  -5.34638941e-01,  -5.15167058e-01,
                         -5.66552699e-01,  -5.80448508e-01,  -5.47418118e-01,
                         -5.24839520e-01,  -5.42269409e-01,  -5.77610195e-01,
                         -5.45688272e-01,  -4.99649197e-01,  -5.39428055e-01,
                         -5.60613871e-01,  -5.27143836e-01,  -5.34212947e-01,
                         -5.54537594e-01,  -5.44909298e-01,  -5.26291788e-01,
                         -5.26955187e-01,  -5.49817026e-01,  -5.47938228e-01,
                         -5.31134248e-01,  -5.17664433e-01,  -4.98643905e-01,
                         -5.28774559e-01,  -5.60377300e-01,  -5.24930656e-01,
                         -5.16085029e-01,  -5.37186682e-01,  -5.26772499e-01,
                         -5.22761524e-01,  -5.31032383e-01,  -5.40493488e-01,
                         -5.37322104e-01,  -5.10681689e-01,  -5.09545863e-01,
                         -5.22326231e-01,  -5.25944650e-01,  -5.38853049e-01,
                         -5.25904298e-01,  -5.11473835e-01,  -5.28136313e-01,
                         -5.26166677e-01,  -5.22114038e-01,  -5.27983308e-01,
                         -5.22868156e-01,  -5.27538121e-01,  -5.23465395e-01,
                         -5.23426592e-01,  -5.40344775e-01,  -5.25736392e-01,
                         -5.25312781e-01,  -5.42788386e-01,  -5.21589756e-01,
                         -5.30250072e-01,  -5.44559419e-01,  -5.04730165e-01,
                         -5.07938385e-01,  -5.39721489e-01,  -5.37254691e-01,
                         -5.35079718e-01,  -5.08446336e-01,  -5.03567398e-01,
                         -5.56840360e-01,  -5.45861602e-01,  -5.26592016e-01,
                         -5.55996478e-01,  -4.89182621e-01,  -4.94976550e-01,
                         -6.37331426e-01,  -4.09374028e-01,   8.03750288e-03,
                         -1.88595101e-01,  -6.27355695e-01,  -5.73316574e-01,
                         -4.58582163e-01,  -5.58653295e-01,  -5.28769910e-01,
                         -5.60714841e-01,  -6.23655081e-01,  -2.37727657e-01,
                          4.83621769e-02,  -3.96938145e-01,  -7.17173219e-01,
                         -2.69975305e-01,   2.48052012e-02,  -3.79642546e-01,
                         -6.41608894e-01,  -4.81026173e-01,  -5.61050773e-01,
                         -6.22910678e-01,  -1.80926472e-01,  -1.60946362e-02,
                         -4.50577825e-01,  -6.41366303e-01,  -5.18130243e-01,
                         -5.46300769e-01,  -5.60627162e-01,  -5.34327745e-01,
                         -5.97898781e-01,  -5.40911794e-01,  -5.15706837e-01,
                         -6.30568922e-01,  -3.93994421e-01,  -4.57541384e-02,
                         -2.73817986e-01,  -6.14919603e-01,  -5.62543392e-01,
                         -5.28641939e-01,  -5.93971968e-01,  -5.56387842e-01,
                         -5.62913895e-01,  -5.74678719e-01,  -5.45482814e-01,
                         -6.18529201e-01,  -5.65358102e-01,  -1.75545081e-01,
                          1.93064421e-01,   4.67729755e-02,  -5.49624443e-01,
                         -7.59788036e-01,  -2.43030399e-01,  -1.40517699e-02,
                         -4.20313030e-01,  -3.82452428e-01,   1.02634013e-01,
                          9.92880687e-02,  -7.17996852e-03,   1.74852997e-01,
                         -1.02155574e-01,  -5.54635286e-01,  -2.43864864e-01,
                          1.79202542e-01,   1.49418050e-02,  -2.07284838e-02,
                          1.89894170e-01,  -1.37808889e-01,  -5.97947955e-01,
                         -2.31582537e-01,   2.84962803e-01,  -1.17425345e-01,
                         -5.93429983e-01,  -2.02134922e-01,  -2.54687015e-02,
                         -6.37754798e-01,  -7.06892669e-01,  -1.05060123e-01,
                         -1.63304389e-01,  -5.36028743e-01,  -1.90056846e-01,
                          1.61825091e-01,  -2.17394643e-02,   2.62046866e-02,
                          1.54923543e-01,  -2.93269664e-01,  -5.48376262e-01,
                         -8.19166675e-02,   1.65344074e-01,  -3.50023359e-02,
                          3.45303081e-02,   8.33029300e-02,  -3.53435457e-01,
                         -5.15835106e-01,  -1.20477872e-02,   1.97122678e-01,
                         -3.43166113e-01,  -6.13612235e-01,  -4.79444526e-02,
                          2.57651776e-01,  -2.84937739e-01,  -5.68414092e-01,
                         -1.77545846e-01,   9.35003757e-02,   1.20902397e-01,
                         -3.47863436e-02,  -4.75487620e-01,  -4.45279688e-01,
                          1.42255902e-01,   6.91255629e-02,  -5.23093224e-01,
                         -4.27527636e-01,   4.91917469e-02,   8.63326117e-02,
                         -2.68443059e-02,   2.30802484e-02,   3.51210237e-02,
                          2.66938587e-03,   1.65452696e-02,   3.11622974e-02,
                          4.08089384e-02,   3.60395387e-02,   9.26178135e-03,
                          1.32908495e-02,   3.52171361e-02,   2.14992668e-02,
                          6.62653660e-03,   3.94069850e-02,   5.52036949e-02,
                          1.68761685e-02,   2.12573130e-02,   4.58242372e-02,
                          7.32587185e-03,   1.64145976e-03,   3.81695330e-02,
                          2.63400376e-02,   1.34333363e-02,   1.47796469e-02,
                          1.92220416e-02,   4.53541614e-02,   3.25769298e-02,
                          9.91803315e-03,   3.58283333e-02,   3.49001437e-02,
                          2.30489904e-03,  -2.04220810e-03,   2.17848457e-02,
                          3.96072157e-02,   2.15118229e-02,   2.08067428e-02,
                          4.50343043e-02,   2.56421641e-02,   1.06644630e-02,
                          2.62039341e-02,   2.35058181e-02,   1.66172292e-02,
                          1.48137873e-02,   2.93875337e-02,   3.95015329e-02,
                          7.87327532e-03,   1.13296472e-02,   3.73749025e-02,
                          8.31246935e-03,   4.08680877e-03,   3.93979922e-02,
                          3.38874608e-02,   1.56377559e-03,  -5.94749981e-05,
                          4.16615084e-02,   3.92951518e-02,  -1.13370651e-02,
                          9.39774979e-03,   4.01559882e-02,   1.26889432e-02,
                          2.09526867e-02,   4.22954559e-02,   7.80380284e-03,
                         -6.25611562e-03,   6.93776011e-02,   1.25952959e-02,
                         -4.19917881e-01,  -7.64985323e-01,  -4.93664026e-01,
                         -4.62568365e-02,   6.96560964e-02,   2.01376621e-02,
                         -1.02578441e-03,   1.66463125e-02,   3.07525750e-02,
                          1.15646534e-02,   1.81098487e-02,   2.12839842e-02,
                          3.50911892e-03,   1.96085609e-02,   8.76905676e-03,
                         -9.66779515e-03,   1.60144754e-02,   1.21824080e-02,
                          2.12424882e-02,   5.04425168e-02,   1.10335369e-02,
                         -6.66677859e-03,   1.65907983e-02,  -1.35672363e-02,
                         -1.45229213e-02,   4.18495983e-02,   4.26483564e-02,
                          2.81319977e-03,  -4.06873552e-03,   4.18405002e-03,
                         -2.35851319e-03,  -7.30413152e-03,   6.01811102e-03,
                          2.75861397e-02,   2.87423972e-02,  -2.39170343e-03,
                         -1.24405650e-02,   1.85220484e-02,   1.53565742e-02,
                         -1.60162095e-02,  -6.18214021e-03,   7.66133657e-03,
                         -3.97229893e-03,   8.01303610e-03,   2.17988044e-02,
                         -1.26351928e-02,  -2.44424157e-02,   3.01781017e-02,
                          3.50520238e-02,  -3.34657244e-02,  -4.44447361e-02,
                          1.49577791e-02,   5.02340049e-02,   8.20923131e-03,
                         -5.43449372e-02,  -1.73619147e-02,   3.55946943e-02,
                         -1.69588458e-02,  -3.81183326e-02,   1.28909368e-02,
                          1.86498780e-02,  -9.13985353e-03,  -2.98356693e-02,
                         -1.24038225e-02,   2.03194916e-02,  -4.56560729e-03,
                         -2.43462101e-02,  -1.58220734e-02,  -2.63542775e-02,
                         -4.03021201e-02,  -3.51284742e-02,   5.04749157e-02,
                         -9.02779773e-02,  -6.80138707e-01,  -8.10249388e-01,
                         -2.16401279e-01,  -1.58284962e-01,  -5.48890948e-01,
                         -3.20828795e-01,  -1.37457535e-01,  -6.42433763e-01,
                         -7.94781029e-01,  -2.24035695e-01,  -8.59032795e-02,
                         -6.87051117e-01,  -8.32569718e-01,  -2.50879675e-01,
                         -1.00508735e-01,  -5.48396885e-01,  -7.40574181e-01,
                         -6.73347831e-01,  -6.79718673e-01,  -6.36366308e-01,
                         -6.60673857e-01,  -7.80377746e-01,  -5.35777450e-01,
                         -1.44316003e-01,  -3.11879396e-01,  -7.22182214e-01,
                         -7.33564794e-01,  -5.99752307e-01,  -6.56082392e-01,
                         -7.09776580e-01,  -6.44344687e-01,  -6.94305599e-01,
                         -8.07722211e-01,  -4.99313086e-01,  -1.34273678e-01,
                         -4.10464764e-01,  -5.41939080e-01,  -1.38874009e-01,
                         -3.51458818e-01,  -8.97823274e-01,  -5.54051042e-01,
                         -6.16427474e-02,  -4.00187343e-01,  -7.82278776e-01,
                         -6.49665773e-01,  -6.70058191e-01,  -7.97838271e-01,
                         -3.99298906e-01,  -1.56988412e-01,  -5.10954142e-01,
                         -4.24063444e-01,  -1.12341993e-01,  -5.92698514e-01,
                         -8.97485971e-01,  -3.18920612e-01,  -1.28555581e-01,
                         -5.75626791e-01,  -4.49550062e-01,   9.34141353e-02,
                         -1.11669056e-01,  -6.37562573e-01,  -3.88873756e-01,
                         -1.09907478e-01,  -6.34636760e-01,  -8.55524063e-01,
                         -2.88173914e-01,  -1.37947783e-01,  -5.96513152e-01,
                         -7.78747678e-01,  -6.97551131e-01,  -6.10789239e-01,
                         -2.62832105e-01,   8.27732086e-02,  -1.70491219e-01,
                         -7.62074113e-01,  -8.10467660e-01,  -2.78928280e-01,
                         -1.60405830e-01,  -5.84376454e-01,  -7.89219916e-01,
                         -7.69611955e-01,  -5.64086676e-01,  -1.47673473e-01,
                         -3.35365236e-01,  -9.10344362e-01,  -6.40761316e-01,
                         -1.23025507e-01,  -4.02741164e-01,  -5.72691023e-01,
                         -1.79515302e-01,  -3.75672191e-01,  -9.25173938e-01,
                         -5.65302610e-01,  -1.04837254e-01,  -4.77779031e-01,
                         -5.53273439e-01,  -1.78872898e-01,  -4.38805759e-01,
                         -8.81787896e-01,  -6.51323199e-01,  -4.93882224e-02,
                          4.97976728e-02,  -4.91665483e-01,  -5.72582841e-01,
                         -2.31048062e-01,  -4.46384251e-01,  -5.67142785e-01,
                         -1.75209910e-01,   3.26050222e-02,  -4.52686958e-02,
                         -3.85042936e-01,  -6.11515820e-01,  -2.92959988e-01,
                         -2.65386075e-01,  -7.93746352e-01,  -8.24468017e-01,
                         -2.68343568e-01,  -1.61046442e-02,  -1.66068986e-01,
                         -1.16822734e-01,   6.87489379e-03,  -3.50467205e-01,
                         -6.64151311e-01,  -3.41820151e-01,  -4.63742316e-02,
                         -8.97952244e-02,  -1.36851817e-01,  -4.75292295e-01,
                         -8.95922899e-01,  -6.15808666e-01,  -1.89567640e-01,
                         -4.34371710e-01,  -7.85811186e-01,  -7.99628437e-01,
                         -7.67076075e-01,  -4.99220192e-01,  -1.71261765e-02,
                         -7.81206861e-02,  -6.05997860e-01,  -8.22034836e-01,
                         -7.16115713e-01,  -7.33127177e-01,  -8.35367262e-01,
                         -5.81752419e-01,  -6.79558963e-02,  -2.86665838e-02,
                         -5.05608439e-01,  -7.96139717e-01,  -7.87416518e-01,
                         -7.74739742e-01,  -5.23366213e-01,  -3.08769681e-02,
                         -9.67971161e-02,  -6.39637470e-01,  -5.48926175e-01,
                         -1.56962037e-01,  -5.78463435e-01,  -9.86872315e-01,
                         -4.59370553e-01,  -1.99141428e-01,  -6.03983819e-01,
                         -4.83342141e-01,  -2.17960805e-01,  -6.41004264e-01,
                         -8.91108572e-01,  -6.86753094e-01,  -7.78150082e-01,
                         -8.07887375e-01,  -3.29159677e-01,  -2.14643776e-01,
                         -7.71336138e-01,  -9.02513325e-01,  -3.36795956e-01,
                         -1.80118963e-01,  -7.06227005e-01,  -8.97333503e-01,
                         -4.39885467e-01,  -1.06221944e-01,  -1.06731594e-01,
                         -7.85706937e-02,  -2.66172111e-01,  -7.88479567e-01,
                         -8.49640548e-01,  -3.11150551e-01,  -2.21487194e-01,
                         -6.95065439e-01,  -8.20678711e-01,  -6.79698586e-01,
                         -7.48267949e-01,  -7.45896578e-01,  -7.05833435e-01,
                         -8.36826086e-01,  -6.30297542e-01,  -1.92948490e-01,
                         -3.59500647e-01,  -7.91580975e-01,  -7.76759624e-01,
                         -6.74274504e-01,  -7.42030323e-01,  -7.42290676e-01,
                         -6.90166056e-01,  -6.96337163e-01,  -7.68164814e-01,
                         -6.58073008e-01,  -1.94595873e-01,   6.24022372e-02,
                         -2.94556707e-01,  -7.12720394e-01,  -7.39462376e-01,
                         -6.75032854e-01,  -7.22294688e-01,  -6.80783153e-01,
                         -6.74371481e-01,  -7.94349194e-01,  -5.45675695e-01,
                         -1.38712257e-01,  -3.60813171e-01,  -7.75218427e-01,
                         -7.33949482e-01,  -6.31023526e-01,  -6.86620653e-01,
                         -6.96882546e-01,  -6.69975102e-01,  -6.73494160e-01,
                         -6.84765995e-01,  -6.49452448e-01,  -6.63190365e-01,
                         -7.38922238e-01,  -4.88998890e-01,   4.67942953e-02,
                          5.09149209e-02,  -4.82430667e-01,  -5.16280413e-01,
                         -8.05711523e-02,   5.80005422e-02,   2.58455053e-02,
                         -1.41451374e-01,  -5.75608730e-01,  -7.16732085e-01,
                         -5.71703732e-01,  -6.91088319e-01,  -6.85365856e-01,
                         -2.00307295e-01,  -8.77138898e-02,  -6.50674045e-01,
                         -7.75485098e-01,  -2.00612873e-01,  -5.14437743e-02,
                         -5.73394060e-01,  -7.77983367e-01,  -3.24003249e-01,
                          6.10121340e-02,   3.41931097e-02,   1.58573524e-03,
                          5.33900782e-02,  -1.36276828e-02,   2.26775035e-02,
                          1.35412425e-01,  -1.86019614e-01,  -5.29975832e-01,
                         -2.15207830e-01,   1.25653312e-01,   3.24150324e-02,
                          9.52273794e-03,   5.96279427e-02,   9.04482789e-03,
                          1.14085667e-01,   7.67018721e-02,  -3.72041017e-01,
                         -4.58943188e-01,  -1.07221622e-02,   1.39789343e-01,
                          1.44832637e-02,   4.91430834e-02,   8.38699192e-02,
                          4.99908924e-02,   4.81760427e-02,   5.83950132e-02,
                          6.55647218e-02,   5.64415641e-02,   5.89782186e-02,
                          8.78175348e-02,   4.46691476e-02,   3.31818759e-02,
                          1.75754890e-01,   1.76275615e-02,  -4.24088836e-01,
                         -3.53181154e-01,   3.98224220e-02,   1.71410918e-01,
                          1.12739354e-01,  -2.15335935e-01,  -4.55445051e-01,
                         -1.28398836e-01,   1.75928816e-01,   1.39591247e-01,
                          1.85915101e-02,  -3.26234221e-01,  -6.75459087e-01,
                         -4.78887647e-01,   6.54746145e-02,   2.13353261e-01,
                         -2.38813400e-01,  -4.75199908e-01,  -7.21743107e-02,
                          1.84206054e-01,   5.43544441e-02,   5.66929393e-02,
                          1.17749684e-01,   7.69804120e-02,   7.98613727e-02,
                          9.76174623e-02,   7.55080059e-02,   7.92245790e-02,
                          1.18563205e-01,   7.54978508e-02,   6.04062341e-02,
                          1.94781289e-01,   5.04971249e-03,  -4.51070756e-01,
                         -3.06882173e-01,   1.60773382e-01,   1.18829489e-01,
                          1.59322377e-02,   1.92712620e-01,  -3.55125181e-02,
                         -5.08394718e-01,  -2.53306031e-01,   2.86214501e-01,
                         -2.47648545e-02,  -4.96001214e-01,  -1.72457263e-01,
                         -5.47227114e-02,  -4.80703890e-01,  -2.26303279e-01,
                          2.97991693e-01,  -7.45017976e-02,  -5.12344718e-01,
                         -2.05193907e-01,   1.17607333e-01,   1.61458224e-01,
                          8.32134485e-02,  -3.13531488e-01,  -4.63768899e-01,
                          4.20322344e-02,   2.12559819e-01,  -2.65398115e-01,
                         -5.64241171e-01,  -6.20905578e-01,  -6.22364700e-01,
                         -2.70855546e-01,   4.14515566e-03,  -3.83858919e-01,
                         -7.41145909e-01,  -3.97762686e-01,   1.20257951e-01,
                          1.37487218e-01,  -2.87910730e-01,  -5.85774601e-01,
                         -6.04419768e-01,  -6.07124031e-01,  -3.53941202e-01,
                          1.34909317e-01,   1.11308798e-01,  -3.64242554e-01,
                         -5.89093328e-01,  -6.36834264e-01,  -6.04104400e-01,
                         -1.88784570e-01,  -5.63355582e-03,  -5.74514031e-01,
                         -7.50134110e-01,  -1.50479317e-01,  -1.16967186e-01,
                         -4.75266516e-01,  -1.97264090e-01,  -1.34577915e-01,
                         -5.27179003e-01,  -1.94954380e-01,   2.65132755e-01,
                         -1.86125547e-01,  -5.70892751e-01,  -1.58313870e-01,
                          1.53919592e-01,  -2.32759304e-02,   3.82629633e-02,
                          1.45454064e-01,  -3.05180669e-01,  -4.58973467e-01,
                         -8.83104652e-02,  -2.91541517e-01,  -5.38266897e-01,
                          3.07741798e-02,   1.91724956e-01,  -4.32793319e-01,
                         -4.36211884e-01,  -4.90711965e-02,  -3.55377108e-01,
                         -4.85666424e-01,   1.09302238e-01,   1.29705906e-01,
                         -4.92687821e-01,  -4.15768862e-01,   5.12272678e-03,
                         -3.91565233e-01,  -8.25698555e-01,  -3.47436100e-01,
                         -2.64003072e-02,  -4.16474968e-01,  -4.11085665e-01,
                          2.59358305e-02,   1.13246724e-01,   3.84642780e-02,
                         -1.58228338e-01,  -6.34908915e-01,  -7.04200149e-01,
                         -1.60601765e-01,  -2.35458724e-02,  -6.04281306e-01,
                         -7.49972761e-01,  -1.67212322e-01,  -9.03875232e-02,
                         -5.50413013e-01,  -2.92724907e-01,   2.57346869e-01,
                         -1.14643097e-01,  -5.39151013e-01,  -1.99338049e-01,
                         -1.92837283e-01,  -4.66783017e-01,  -1.78905010e-01,
                         -1.56904146e-01,  -6.17608786e-01,  -6.82978392e-01,
                         -5.47548473e-01,  -5.97297609e-01,  -6.28555596e-01,
                         -5.74220538e-01,  -5.64377069e-01,  -6.63135409e-01,
                         -5.77964187e-01,  -1.07865237e-01,   1.87125370e-01,
                         -1.35815084e-01,  -5.50514340e-01,  -6.30443394e-01,
                         -6.39378905e-01,  -5.03333926e-01,  -4.27048132e-02,
                          1.72379494e-01,  -2.05747008e-01,  -6.16101563e-01,
                         -6.30792558e-01,  -5.44555545e-01,  -6.40235960e-01,
                         -6.07584476e-01,  -1.18925586e-01,   2.24969119e-01,
                         -2.02934816e-01,  -5.01698077e-01,  -1.48340508e-01,
                         -2.10898191e-01,  -4.82124269e-01,  -1.47790357e-01,
                         -1.65986836e-01,  -7.14240730e-01,  -6.16232395e-01,
                         -4.89354581e-02,   1.11597523e-01,  -2.73797382e-02,
                          5.32213375e-02,   1.18287660e-01,  -2.86650062e-01,
                         -5.12394726e-01,  -1.06662542e-01,   1.41990498e-01,
                          1.77064165e-02,   9.69010964e-03,   5.53405806e-02,
                          2.58177482e-02,   3.02890297e-02,   3.86375077e-02,
                          3.35424468e-02,   4.19346169e-02,   3.87894101e-02,
                          3.81417461e-02,   3.99869531e-02,   3.17781605e-02,
                          3.89883295e-02,   3.65620889e-02,   2.50095129e-02,
                          3.82442102e-02,   3.66122685e-02,   3.24572586e-02,
                          4.23795357e-02,   3.76744494e-02,   4.90193591e-02,
                          4.21918333e-02,   3.23409624e-02,   6.77795336e-02,
                          1.43756699e-02,  -3.99891799e-03,   1.39235869e-01,
                         -4.11098935e-02,  -4.87084538e-01,  -3.57376844e-01,
                          1.07782662e-01,   8.00871328e-02,  -2.97788586e-02,
                          1.47519067e-01,  -7.13066533e-02,  -5.44527471e-01,
                         -3.11416566e-01,   2.24040791e-01,  -1.78832747e-02,
                         -5.35512984e-01,  -3.30087662e-01,   9.82382596e-02,
                          8.32128823e-02,  -6.34413213e-03,   4.69638519e-02,
                          5.19707091e-02,   2.13178527e-02,   4.16036434e-02,
                          6.46715313e-02,   9.23322979e-03,   4.59946506e-02,
                          1.37041137e-01,  -1.79666415e-01,  -5.35645485e-01,
                         -2.04884082e-01,   2.09318057e-01,  -7.41326287e-02,
                         -5.75200319e-01,  -6.50608182e-01,  -5.37290990e-01,
                         -6.37284935e-01,  -6.23602867e-01,  -2.22959399e-01,
                          7.09007159e-02,   7.90426508e-02,   4.08799350e-02,
                         -2.43966654e-01,  -6.75853908e-01,  -6.38132751e-01,
                         -1.54502496e-01,   1.60551146e-01,  -3.91573124e-02,
                         -5.33979893e-01,  -7.29199708e-01,  -3.78121614e-01,
                          2.96777617e-02,   6.94336593e-02,  -6.66929595e-03,
                          3.95461731e-02,   3.34977657e-02,   7.88289774e-03,
                          8.97289962e-02,  -5.52978404e-02,  -5.44404328e-01,
                         -7.43429899e-01,  -3.57373059e-01,   9.94593743e-03,
                          5.46521507e-02,   6.27863929e-02,  -1.10629268e-01,
                         -5.92481434e-01,  -7.35145152e-01,  -2.99513817e-01,
                          5.41142672e-02,   5.87513931e-02,  -1.94993168e-02,
                         -2.46096309e-02,   1.08944051e-01,   3.92954759e-02,
                         -4.15843844e-01,  -4.90574151e-01,  -4.37142067e-02,
                          1.08064145e-01,  -2.62161363e-02,  -8.18228908e-03,
                          5.82256578e-02,  -7.76714412e-03,  -4.93914708e-02,
                          1.14470325e-01,  -2.34494248e-04,  -4.62772846e-01,
                         -3.80417913e-01,  -1.21906959e-01,  -4.13660496e-01,
                         -4.07817483e-01,   1.78476293e-02,   9.72080231e-02,
                          2.16558785e-03,  -2.25028291e-01,  -6.58357084e-01,
                         -6.92478061e-01,  -2.11318523e-01,   1.38161883e-01,
                         -6.76558986e-02,  -5.14089108e-01,  -6.86687946e-01,
                         -6.31558716e-01,  -5.72706521e-01,  -6.30818248e-01,
                         -7.26548791e-01,  -4.38082069e-01,  -7.03046769e-02,
                         -3.25504780e-01,  -7.05291331e-01,  -6.41199350e-01,
                         -5.64619601e-01,  -6.39383614e-01,  -6.27961576e-01,
                         -6.01879597e-01,  -6.24781609e-01,  -6.27649486e-01,
                         -6.24269485e-01,  -6.21075273e-01,  -6.13661766e-01,
                         -6.21820927e-01,  -6.25472009e-01,  -6.15422368e-01,
                         -6.13023460e-01,  -6.14948332e-01,  -6.19156539e-01,
                         -6.22681916e-01,  -6.15598738e-01,  -6.18005097e-01,
                         -6.28660262e-01,  -6.23759806e-01,  -6.18216455e-01,
                         -6.17999256e-01,  -6.18864894e-01,  -6.30873024e-01,
                         -6.34523511e-01,  -6.22594953e-01,  -6.17506444e-01,
                         -6.21129334e-01,  -6.27116978e-01,  -6.21712625e-01,
                         -6.11960173e-01,  -6.25834048e-01,  -6.37168944e-01,
                         -6.28769875e-01,  -6.25533700e-01,  -6.23313427e-01,
                         -6.26739562e-01,  -6.32242143e-01,  -6.21333778e-01,
                         -6.25461936e-01,  -6.35785937e-01,  -6.24205887e-01,
                         -6.28798246e-01,  -6.39766157e-01,  -6.37045622e-01,
                         -6.44721508e-01,  -6.35245264e-01,  -6.15961134e-01,
                         -6.32495224e-01,  -6.48715973e-01,  -6.41807675e-01,
                         -6.36801243e-01,  -6.36265099e-01,  -6.42582536e-01,
                         -6.46460176e-01,  -6.34972215e-01,  -6.35881305e-01,
                         -6.54367387e-01,  -6.52116895e-01,  -6.34609044e-01,
                         -6.31399274e-01,  -6.42372727e-01,  -6.55589461e-01,
                         -6.46608174e-01,  -6.47846162e-01,  -6.65312886e-01,
                         -6.13186002e-01,  -6.43134952e-01,  -7.53669262e-01,
                         -4.73488420e-01,  -9.96904895e-02,  -3.64880711e-01,
                         -7.55726159e-01,  -6.87636256e-01,  -6.04160190e-01,
                         -6.61689818e-01,  -6.56048954e-01,  -6.54266238e-01,
                         -6.66652918e-01,  -6.72888875e-01,  -6.73619568e-01,
                         -6.46507919e-01,  -6.60346329e-01,  -6.82450533e-01,
                         -6.58580840e-01,  -6.51315510e-01,  -6.64510846e-01,
                         -6.75510347e-01,  -6.67809725e-01,  -6.47137523e-01,
                         -6.53813422e-01,  -6.74265623e-01,  -6.87903404e-01,
                         -6.61033928e-01,  -6.46561265e-01,  -7.03452528e-01,
                         -6.63262486e-01,  -6.41421199e-01,  -7.75724769e-01,
                         -5.65178514e-01,  -1.47442177e-01,  -3.24075818e-01,
                         -7.28972614e-01,  -7.07975984e-01,  -6.35806084e-01,
                         -6.91960156e-01,  -6.37475789e-01,  -6.84962690e-01,
                         -7.70956457e-01,  -4.03604656e-01,  -7.69105628e-02,
                         -5.26316762e-01,  -8.80885005e-01,  -3.79854947e-01,
                         -9.84680951e-02,  -5.14366210e-01,  -5.19484997e-01,
                          1.25582404e-02,   2.94592734e-02,  -5.06925941e-01,
                         -7.47710526e-01,  -6.23916864e-01,  -6.96683645e-01,
                         -8.15549135e-01,  -4.40659225e-01,  -6.76632300e-02,
                         -4.68233824e-01,  -9.04289126e-01,  -4.83693093e-01,
                         -8.59199837e-02,  -4.44000155e-01,  -7.70957172e-01,
                         -7.32633770e-01,  -6.48772717e-01,  -3.22413445e-01,
                          5.94861843e-02,  -1.05968013e-01,  -6.01058781e-01,
                         -8.09758544e-01,  -5.37792623e-01,  -5.82434796e-02,
                          7.92873874e-02,  -3.37706923e-01,  -7.98970044e-01,
                         -6.98741496e-01,  -2.60936528e-01,  -5.07616550e-02,
                          2.41046436e-02,  -7.35382140e-02,  -5.04670560e-01,
                         -5.10688186e-01,  -1.09670378e-01,  -4.23152715e-01,
                         -9.32873666e-01,  -5.26296377e-01,  -3.31874564e-02,
                         -4.38045949e-01,  -9.23576117e-01,  -5.36770880e-01,
                         -8.20611715e-02,  -4.10649806e-01,  -5.95091701e-01,
                         -1.38884038e-01,   7.61322677e-02,  -8.97419378e-02,
                         -1.36903286e-01,  -1.63669593e-03,   1.20563125e-02,
                         -3.83089900e-01,  -6.14532590e-01,  -2.10517794e-01,
                          5.99857122e-02,  -7.19305128e-02,  -7.48690367e-02,
                         -2.66461149e-02,  -7.87636414e-02,  -7.72249252e-02,
                         -3.96478623e-02,  -3.58039998e-02,  -7.11728483e-02,
                         -3.14826854e-02,  -1.44466264e-02,  -4.20753688e-01,
                         -8.71604204e-01,  -5.71684599e-01,  -1.02642007e-01,
                         -3.78652990e-01,  -5.90150297e-01,  -4.82133292e-02,
                          1.10061571e-01,  -4.79769111e-01,  -5.79995573e-01,
                         -8.06518123e-02,   6.69293255e-02,  -1.02792092e-01,
                         -3.75837795e-02,   3.57658491e-02,  -3.69503528e-01,
                         -8.11503232e-01,  -6.05486274e-01,  -1.55046433e-01,
                          3.43194650e-03,   5.90612106e-02,  -8.15899149e-02,
                         -5.00578105e-01,  -4.72652227e-01,   6.26498386e-02,
                          4.79167700e-02,  -5.10596156e-01,  -5.06834269e-01,
                          9.52018891e-03,   9.63172317e-02,  -3.62376899e-01,
                         -7.45966017e-01,  -6.22007966e-01,  -1.70598865e-01,
                          1.20062470e-01,  -6.68456480e-02,  -6.28132641e-01,
                         -7.80189276e-01,  -2.61315197e-01,  -1.40780166e-01,
                         -4.80724782e-01,  -3.03192884e-01,  -1.37166932e-01,
                         -5.25352538e-01,  -7.46187925e-01,  -6.62341714e-01,
                         -3.95435333e-01,  -4.92223985e-02,  -3.21645707e-01,
                         -8.15703213e-01,  -4.96784151e-01,  -1.73168555e-02,
                         -2.95138359e-01,  -6.95963860e-01,  -5.95746458e-01,
                         -5.67141294e-01,  -7.38495469e-01,  -4.06616718e-01,
                         -3.12068220e-02,  -3.53132933e-01,  -6.97393835e-01,
                         -6.32631540e-01,  -5.36409438e-01,  -5.88300288e-01,
                         -7.14604437e-01,  -5.02898455e-01,  -9.43793282e-02,
                         -2.41366267e-01,  -6.24192178e-01,  -6.31534457e-01,
                         -5.72504461e-01,  -6.30547225e-01,  -6.21342421e-01,
                         -5.74386239e-01,  -5.86409032e-01,  -6.17493570e-01,
                         -5.99810123e-01,  -5.71910679e-01,  -6.05296731e-01,
                         -6.39495671e-01,  -5.63165545e-01,  -5.67770302e-01,
                         -6.93866134e-01,  -4.24728841e-01,  -3.89357731e-02,
                         -3.07557791e-01,  -6.83836877e-01,  -6.16852164e-01,
                         -5.51115453e-01,  -5.87902963e-01,  -5.97852170e-01,
                         -6.12702668e-01,  -5.92430115e-01,  -5.94860256e-01,
                         -6.04232550e-01,  -5.88151753e-01,  -5.84945858e-01,
                         -5.65416694e-01,  -5.93531370e-01,  -6.31319046e-01,
                         -5.95316231e-01,  -5.85154891e-01,  -6.00745320e-01,
                         -6.02555573e-01,  -5.85128367e-01,  -5.65032780e-01,
                         -6.14551008e-01,  -6.29056275e-01,  -5.80268621e-01,
                         -5.87427557e-01,  -5.90211332e-01,  -5.80332994e-01,
                         -5.89427769e-01,  -5.82633913e-01,  -5.96216977e-01,
                         -5.98804235e-01,  -5.84998846e-01,  -5.88762760e-01,
                         -5.73096454e-01,  -5.90004921e-01,  -6.25913560e-01,
                         -6.04614913e-01,  -5.85459054e-01,  -5.84721804e-01,
                         -5.82191229e-01,  -5.90548396e-01,  -5.91606438e-01,
                         -5.97814143e-01,  -6.10193431e-01,  -5.98798633e-01,
                         -5.82877398e-01,  -5.88977754e-01,  -5.96572876e-01,
                         -5.93930900e-01,  -5.91411114e-01,  -5.81203163e-01,
                         -5.93980134e-01,  -6.17706716e-01,  -5.93050599e-01,
                         -5.88554800e-01,  -6.05608702e-01,  -5.86690128e-01,
                         -5.99147677e-01,  -6.12510085e-01,  -5.98128021e-01,
                         -6.01420760e-01,  -5.93506992e-01,  -6.02521300e-01,
                         -6.05059445e-01,  -5.87748349e-01,  -6.14282191e-01,
                         -6.05261683e-01,  -6.10476792e-01,  -6.37060881e-01,
                         -5.47310531e-01,  -5.98191917e-01,  -7.28848338e-01,
                         -4.21592057e-01,  -6.37879074e-02,  -3.07002127e-01,
                         -6.83197379e-01,  -6.53589606e-01,  -5.74916005e-01,
                         -6.43450379e-01,  -6.14751875e-01,  -5.91692150e-01,
                         -6.42719448e-01,  -6.12245917e-01,  -6.00568175e-01,
                         -6.49460256e-01,  -6.32483780e-01,  -5.89120686e-01,
                         -6.65850580e-01,  -6.33970141e-01,  -1.86446145e-01,
                         -9.93355587e-02,  -7.11519539e-01,  -6.96831346e-01,
                         -5.46422377e-02,   4.45112213e-02,  -3.91253978e-02,
                          5.03177606e-02,  -2.02036127e-02,  -3.93431447e-02,
                          2.45571565e-02,   5.09900181e-03,  -1.06804271e-03,
                         -1.98631664e-03,   1.06294872e-02,   2.05390062e-02,
                         -2.50743795e-02,  -2.97936611e-02,   1.78792421e-02,
                          2.07183808e-02,  -2.48358622e-02,  -1.99267361e-02,
                          1.26438532e-02,  -1.87679287e-02,  -1.66430231e-02,
                          2.50566602e-02,   4.64196457e-03,  -2.99857613e-02,
                         -3.32196318e-02,   1.17185069e-02,   3.24443989e-02,
                         -1.75876115e-02,  -7.45721208e-03,   1.30136581e-02,
                         -1.85813233e-02,  -2.45686178e-03,   9.87809431e-03,
                          2.87638337e-04,   3.51460348e-03,  -1.19275004e-02,
                         -1.00692539e-02,  -1.03752371e-02,  -2.43397318e-02,
                         -1.42541602e-02,  -8.66716728e-03,   3.92616447e-03,
                          1.31972227e-02,  -2.27830093e-03,  -4.54641599e-03,
                          1.06129283e-02,   1.04166698e-02,  -4.92372625e-02,
                         -2.74232700e-02,   1.07093908e-01,  -9.39415246e-02,
                         -5.09722173e-01,  -3.72005373e-01,   4.12781984e-02,
                         -1.53361810e-02,  -1.00710936e-01,   7.22047761e-02,
                         -1.96674004e-01,  -6.19281948e-01,  -3.29362929e-01,
                          1.20276675e-01,  -6.48425817e-02,  -5.55219769e-01,
                         -7.07368970e-01,  -5.82398295e-01,  -7.20547855e-01,
                         -7.33572721e-01,  -2.34843224e-01,  -1.81645334e-01,
                         -5.03249764e-01,  -2.73735493e-01,  -1.80031866e-01,
                         -6.15130126e-01,  -7.57987559e-01,  -6.17971420e-01,
                         -6.01863563e-01,  -6.24587059e-01,  -6.42334700e-01,
                         -6.57611370e-01,  -6.19781911e-01,  -6.03529692e-01,
                         -6.51960671e-01,  -6.56548202e-01,  -6.36285365e-01,
                         -6.65973067e-01,  -6.61029875e-01,  -6.23923182e-01,
                         -5.94306886e-01,  -6.45350397e-01,  -7.47052252e-01,
                         -4.60396111e-01,  -6.34009093e-02,  -3.93288672e-01,
                         -8.36610198e-01,  -4.93511289e-01,  -9.60671082e-02,
                         -3.68884057e-01,  -7.27748156e-01,  -6.70147300e-01,
                         -5.91437578e-01,  -6.84164405e-01,  -6.60730064e-01,
                         -6.13099456e-01,  -6.55922413e-01,  -6.47400796e-01,
                         -6.43386185e-01,  -6.52644813e-01,  -6.57647491e-01,
                         -6.53461635e-01,  -5.76740384e-01,  -6.84151828e-01,
                         -7.96393216e-01,  -3.81063670e-01,  -7.03845769e-02,
                         -4.43485945e-01,  -7.60074615e-01,  -6.61789715e-01,
                         -5.73846459e-01,  -6.59461677e-01,  -7.43228674e-01,
                         -4.85383332e-01,  -9.46171060e-02,  -3.08909029e-01,
                         -7.93279827e-01,  -5.94897687e-01,  -1.03735313e-01,
                         -2.86782652e-01,  -7.95995057e-01,  -6.30023539e-01,
                         -9.61458683e-02,  -2.41268367e-01,  -7.00638533e-01,
                         -6.39759243e-01,  -5.77032506e-01,  -7.60914803e-01,
                         -4.75289911e-01,  -1.13654435e-01,  -3.91702086e-01,
                         -4.75725502e-01,  -9.44246724e-02,  -3.75299782e-01,
                         -8.78838837e-01,  -4.42016393e-01,  -6.01587556e-02,
                         -4.48896646e-01,  -4.27284271e-01,  -5.86740337e-02,
                         -4.58685189e-01,  -8.85552347e-01,  -3.78829688e-01,
                         -4.37056608e-02,  -5.02372324e-01,  -4.69446421e-01,
                          1.33981168e-01,  -3.22930738e-02,  -5.85042775e-01,
                         -3.59004378e-01,  -2.54732464e-02,  -5.14330566e-01,
                         -8.55557621e-01,  -2.86254287e-01,  -8.82470533e-02,
                         -5.70754766e-01,  -3.62050265e-01,  -1.05027119e-02,
                         -5.89399993e-01,  -8.59973073e-01,  -2.55959004e-01,
                         -8.02393034e-02,  -5.63178778e-01,  -7.72653043e-01,
                         -5.98938107e-01,  -5.82460284e-01,  -6.85162008e-01,
                         -6.21038437e-01,  -5.77179253e-01,  -6.84901834e-01,
                         -7.11332142e-01,  -3.81892830e-01,   1.09883711e-01,
                          1.27750896e-02,  -5.45429587e-01,  -5.00320077e-01,
                          3.95100266e-02,   8.14379156e-02,  -4.12989616e-01,
                         -7.27510095e-01,  -6.30086303e-01,  -6.24223769e-01,
                         -7.26981223e-01,  -3.84150952e-01,  -1.20494038e-01,
                         -4.56032217e-01,  -4.27578539e-01,  -7.09175766e-02,
                         -5.02491295e-01,  -8.75599325e-01,  -3.09151977e-01,
                         -1.08139545e-01,  -5.09825170e-01,  -3.57665867e-01,
                         -1.38732582e-01,  -5.23715138e-01,  -7.62807071e-01,
                         -6.11590266e-01,  -5.71893871e-01,  -7.26511240e-01,
                         -7.17689037e-01,  -3.19706082e-01,  -9.92929041e-02,
                         -4.50652122e-01,  -7.39780545e-01,  -7.15046227e-01,
                         -5.36340177e-01,  -1.61273122e-01,  -2.05156744e-01,
                         -7.59859681e-01,  -6.83196723e-01,  -1.08986892e-01,
                         -1.96941286e-01,  -6.36727154e-01,  -6.98286653e-01,
                         -6.55736804e-01,  -5.00423253e-01,  -2.35184804e-02,
                          8.76477808e-02,  -3.65098804e-01,  -6.37081563e-01,
                         -7.00887024e-01,  -6.83036923e-01,  -3.02763820e-01,
                         -1.18258722e-01,  -5.13454616e-01,  -7.39816666e-01,
                         -6.16487741e-01,  -6.07943773e-01,  -6.41511440e-01,
                         -6.04814172e-01,  -6.37525737e-01,  -6.66356981e-01,
                         -6.26612902e-01,  -6.35556519e-01,  -6.83229923e-01,
                         -6.59961045e-01,  -5.72609901e-01,  -5.75726271e-01,
                         -7.45857060e-01,  -6.76506758e-01,  -1.90561399e-01,
                         -1.19488619e-01,  -6.34412050e-01,  -7.55101144e-01,
                         -5.72285593e-01,  -6.65052116e-01,  -6.57075644e-01,
                         -6.24207258e-01,  -7.54099607e-01,  -4.67861682e-01,
                         -1.02428578e-01,  -3.55775356e-01,  -7.04197347e-01,
                         -7.00474501e-01,  -5.87031364e-01,  -5.92076182e-01,
                         -7.06613421e-01,  -5.18429935e-01,  -1.70429736e-01,
                         -3.46005648e-01,  -4.98987734e-01,  -1.42914400e-01,
                         -2.27240667e-01,  -7.18411386e-01,  -7.08161712e-01,
                         -5.79154491e-01,  -6.73584700e-01,  -6.36046052e-01,
                         -6.20746076e-01,  -6.51456296e-01,  -6.12755299e-01,
                         -7.37953782e-01,  -6.49074972e-01,  -1.79653943e-01,
                         -1.85100690e-01,  -6.48730218e-01,  -7.30477393e-01,
                         -5.65446317e-01,  -6.01836383e-01,  -6.50960088e-01,
                         -5.86573958e-01,  -6.01840138e-01,  -6.78753972e-01,
                         -6.43920004e-01,  -6.22516692e-01,  -7.07169652e-01,
                         -5.81782758e-01,  -1.76334962e-01,   7.58491009e-02,
                          9.61792096e-03,  -2.56462079e-02,   3.00493222e-02,
                         -3.20105940e-01,  -8.37362349e-01,  -5.88412106e-01,
                         -6.51719049e-02,  -2.78720826e-01,  -4.91884649e-01,
                         -2.07853198e-01,  -3.35729778e-01,  -7.35562205e-01,
                         -6.52219534e-01,  -5.38035274e-01,  -6.75248921e-01,
                         -4.94525582e-01,  -1.08442781e-02,   6.89629391e-02,
                         -3.79145801e-01,  -5.57457924e-01,  -1.50055110e-01,
                          1.04764044e-01,  -1.97476000e-02,  -4.54594791e-02,
                         -5.39229158e-03,  -4.97109443e-02,  -4.50510606e-02,
                         -2.46601012e-02,  -1.83793716e-02,  -3.02883293e-02,
                         -6.17195964e-02,   1.97615148e-03,   5.37581695e-03,
                         -6.47897944e-02,   7.98276290e-02,   2.20446009e-02,
                         -4.72868383e-01,  -5.37807524e-01,  -6.86040074e-02,
                          8.06669816e-02,  -6.20208345e-02,  -3.94803546e-02,
                          4.24039476e-02,   2.31521241e-02,  -4.25036438e-02,
                         -5.22542968e-02,  -6.30573928e-03,  -2.56598722e-02,
                         -5.95011041e-02,  -2.95379607e-04,   4.60424349e-02,
                          1.34652629e-02,  -1.79790724e-02,  -1.66094769e-02,
                         -2.11119726e-02,  -3.06448136e-02,   2.13617925e-03,
                          2.34648660e-02,  -2.66832951e-02,  -4.40835916e-02,
                         -2.90872739e-03,   1.75604291e-04,  -1.33010664e-03,
                          3.30772400e-02,   1.25013245e-02,  -7.78237060e-02,
                         -8.86773840e-02,   1.17025962e-02,   3.91585641e-02,
                         -2.24466342e-02,  -3.66409011e-02,  -3.01260557e-02,
                         -1.65324396e-04,   4.00470756e-02,  -2.74997521e-02,
                         -5.74998483e-02,   2.75639612e-02,   3.27763110e-02,
                         -7.17968633e-03,  -1.53526753e-01,  -4.60086614e-01,
                         -3.65803778e-01,   1.00909941e-01,   5.61030069e-03,
                         -5.28698921e-01,  -5.18482387e-01,  -6.76750764e-02,
                          8.49091858e-02,   1.11175412e-02,   6.42202944e-02,
                         -6.42645285e-02,  -4.82141703e-01,  -4.60451692e-01,
                          5.43870591e-02,   3.81200463e-02,  -4.93036419e-01,
                         -4.35269386e-01,  -5.88586107e-02,  -4.38031077e-01,
                         -8.77676845e-01,  -4.08234119e-01,  -8.81051272e-02,
                         -4.77140009e-01,  -3.88126373e-01,  -5.01482449e-02,
                         -5.33270538e-01,  -8.49190652e-01,  -2.89954782e-01,
                         -1.05761580e-01,  -4.40723538e-01,  -3.11861962e-01,
                         -1.91206992e-01,  -6.34120643e-01,  -7.20266163e-01,
                         -2.13871822e-01,  -1.97228402e-01,  -5.96707523e-01,
                         -3.23939204e-01,   1.76970676e-01,  -1.14293590e-01,
                         -4.78809386e-01,  -2.30682522e-01,  -2.40489334e-01,
                         -5.68135262e-01,  -2.47144714e-01,   1.74507737e-01,
                         -2.19432816e-01,  -5.41747391e-01,  -2.03929886e-01,
                         -2.23899320e-01,  -7.18527675e-01,  -6.28806531e-01,
                         -1.56000853e-01,  -2.56898642e-01,  -6.50533080e-01,
                         -6.91915214e-01,  -6.05256081e-01,  -4.67736959e-01,
                         -4.87932749e-02,   8.18232968e-02,  -3.63760531e-01,
                         -4.51373011e-01,  -1.24393620e-01,  -3.75087082e-01,
                         -7.75077760e-01,  -4.33460832e-01,  -7.47138634e-02,
                         -3.61383915e-01,  -6.67085469e-01,  -6.59715474e-01,
                         -6.68363094e-01,  -6.55155897e-01,  -5.40070772e-01,
                         -6.34714007e-01,  -7.07037985e-01,  -2.96393931e-01,
                         -8.30545798e-02,  -5.27760446e-01,  -7.05260694e-01,
                         -4.90312159e-01,  -6.63316727e-01,  -7.87844002e-01,
                         -2.96862036e-01,   1.67798519e-01,   1.97671670e-02,
                         -5.39312601e-01,  -8.19276333e-01,  -4.62055355e-01,
                         -5.74103892e-02,   2.88339648e-02,   5.54291941e-02,
                         -1.65574417e-01,  -5.55955529e-01,  -3.43145102e-01,
                          1.80612251e-01,  -3.98784094e-02,  -5.52904725e-01,
                         -3.09408545e-01,  -2.54914034e-02,  -5.48501909e-01,
                         -8.37967932e-01,  -3.45146835e-01,  -1.55056007e-02,
                          4.42383029e-02,   9.43071097e-02,  -2.44135708e-01,
                         -5.13920367e-01,  -2.33305469e-01,  -1.92560896e-01,
                         -6.22854710e-01,  -6.97274685e-01,  -2.12609708e-01,
                          1.27582133e-01,  -1.78161979e-01,  -5.69824755e-01,
                         -3.42167825e-01,   5.83497137e-02,   6.64888024e-02,
                         -3.63611914e-02,   1.41171366e-02,   8.65264535e-02,
                         -6.08339384e-02,  -4.44906503e-01,  -6.82292819e-01,
                         -6.87367618e-01,  -6.37449086e-01,  -2.73378640e-01,
                          1.77970454e-01,  -1.08323202e-01,  -6.52711034e-01,
                         -3.67847204e-01,   1.27799749e-01,  -1.51785146e-02,
                         -5.16632535e-02,   1.99755549e-01,  -1.29465133e-01,
                         -5.24518728e-01,  -2.59470046e-01,  -2.07187697e-01,
                         -5.42743683e-01,  -3.30982178e-01,   8.98591429e-02,
                         -1.39515653e-01,  -6.49377584e-01,  -7.04864800e-01,
                         -3.35848451e-01,  -2.13946588e-02,   9.70253348e-02,
                          4.93807420e-02,  -2.95802653e-01,  -5.30153334e-01,
                         -1.89578757e-01,   1.40257999e-01,   3.93103100e-02,
                         -4.99443710e-02,  -2.50679851e-02,  -2.20745318e-02,
                          2.71834582e-02,  -6.53589796e-03,  -9.24416110e-02,
                         -1.55817699e-02,   4.72354740e-02,  -2.13766173e-02,
                         -4.98940190e-03,   6.69135004e-02,   8.31644982e-03,
                         -6.04200251e-02,   2.46917875e-03,   2.30396818e-02,
                         -7.63949528e-02,  -6.28289059e-02,   6.94243684e-02,
                          6.56956211e-02,  -1.93076022e-02,   1.72246918e-02,
                          6.02651797e-02,  -7.47344643e-03,  -2.10325345e-02,
                          3.28376368e-02,   1.30126132e-02,   2.06688624e-02,
                         -3.67152430e-02,  -3.88039827e-01,  -5.42716980e-01,
                         -1.56357586e-01,   1.04719833e-01,  -1.83222070e-02,
                         -4.84199412e-02,   2.99778841e-02,   3.18354294e-02,
                          1.36855589e-02,  -2.42803413e-02,  -1.52721824e-02,
                          5.56615368e-02,   4.70478982e-02,   1.95004754e-02,
                          2.98718065e-02,  -3.08470260e-02,  -1.05073407e-01,
                         -6.78668767e-02,   3.95920761e-02,   8.48625451e-02,
                          2.74938513e-02,  -8.47249664e-03,   1.56594124e-02,
                          4.50302940e-03,  -3.80251147e-02,  -4.94963303e-02,
                          1.10944430e-03,   3.90093289e-02,  -3.17355767e-02,
                         -4.37732115e-02,   6.70378357e-02,   5.45437746e-02,
                         -1.13319037e-02,  -3.01683345e-03,  -2.18565941e-01,
                         -5.97982347e-01,  -6.69801056e-01,  -5.57943404e-01,
                         -6.55661941e-01,  -6.65365756e-01,  -2.47139871e-01,
                          8.43620375e-02,  -4.92971763e-03,  -8.07790179e-03,
                          4.55503054e-02,  -2.93446451e-01,  -4.86537516e-01,
                         -1.37080282e-01,   8.05073529e-02,  -1.49937589e-02,
                         -1.22120045e-02,  -1.31678144e-02,  -7.44092315e-02,
                          2.07043402e-02,   8.27250183e-02,  -4.04593460e-02,
                         -7.02964291e-02,   2.98498143e-02,   2.45772563e-02,
                         -1.48968417e-02,   4.40053232e-02,   4.99103256e-02,
                         -4.22750115e-02,  -6.11684620e-02,   3.63151636e-03,
                          7.54485227e-05,  -8.20453241e-02,  -6.51634336e-02,
                          5.26327826e-02,   4.99694347e-02,   4.11784695e-03,
                          6.29768223e-02,   3.55556421e-02,   5.66925341e-03,
                          6.82305247e-02,  -2.14918137e-01,  -5.84090829e-01,
                         -2.97055066e-01,   1.29495889e-01,   4.39388379e-02,
                         -5.34634367e-02,   5.53851277e-02,   2.99940780e-02,
                         -5.56318536e-02,  -6.01491034e-02,  -3.08682024e-02,
                         -3.70134437e-03,  -1.98497623e-02,   6.56713545e-02,
                          1.55261263e-01,  -1.96961045e-01,  -5.74174464e-01,
                         -2.79230207e-01,   7.03129843e-02,  -4.72715273e-02,
                          1.63911227e-02,   1.66666538e-01,  -2.82912225e-01,
                         -6.53073728e-01,  -2.05752939e-01,   2.08270431e-01,
                         -1.22573040e-01,  -5.94660401e-01,  -6.67232215e-01,
                         -5.82024932e-01,  -6.13395631e-01,  -6.87320888e-01,
                         -6.89032257e-01,  -6.42737210e-01,  -5.99147618e-01,
                         -5.73242009e-01,  -5.77117503e-01,  -6.25622332e-01,
                         -6.98389292e-01,  -7.04645276e-01,  -6.11415029e-01,
                         -5.51986992e-01,  -6.15199268e-01,  -6.95960701e-01,
                         -6.74509943e-01,  -5.89880645e-01,  -5.77251494e-01,
                         -6.44338071e-01,  -6.66971385e-01,  -6.31504297e-01,
                         -6.15420222e-01,  -6.35959089e-01,  -6.67736232e-01,
                         -6.55371368e-01,  -5.98943710e-01,  -5.89036882e-01,
                         -6.25514448e-01,  -6.24334514e-01,  -5.91215193e-01,
                         -6.08739436e-01,  -6.48707867e-01,  -5.93985081e-01,
                         -5.97436011e-01,  -7.57656574e-01,  -6.03662550e-01,
                         -1.37320742e-01,  -1.64245337e-01,  -6.02234006e-01,
                         -6.99475527e-01,  -6.13298774e-01,  -6.66144192e-01,
                         -6.29119873e-01,  -5.44099987e-01,  -5.97687602e-01,
                         -6.57019436e-01,  -6.39052272e-01,  -6.21121705e-01,
                         -6.43020034e-01,  -6.62503362e-01,  -6.45310521e-01,
                         -6.38076425e-01,  -6.31250203e-01,  -6.10751390e-01,
                         -6.28365576e-01,  -6.16127014e-01,  -5.76562583e-01,
                         -6.35361731e-01,  -6.71792805e-01,  -5.86549401e-01,
                         -5.69275379e-01,  -6.63921952e-01,  -6.96349382e-01,
                         -6.16153717e-01,  -5.38200617e-01,  -5.43465257e-01,
                         -5.92348695e-01,  -6.54601753e-01,  -6.91612303e-01,
                         -6.42431498e-01,  -5.98879397e-01,  -6.21278107e-01,
                         -6.26502931e-01,  -6.09166145e-01,  -5.74420035e-01,
                         -5.82309246e-01,  -6.84486687e-01,  -6.66244507e-01,
                         -5.60927749e-01,  -6.18050873e-01,  -6.45696223e-01,
                         -6.00473285e-01,  -6.54597521e-01,  -6.15505278e-01,
                         -5.96350789e-01,  -6.82802320e-01,  -4.21850383e-01,
                         -1.57218814e-01,  -3.62903804e-01,  -3.71386081e-01,
                         -1.42135918e-01,  -3.46125960e-01,  -6.33229494e-01,
                         -6.41681254e-01,  -6.56524599e-01,  -6.18357003e-01,
                         -5.35501420e-01,  -6.41695499e-01,  -7.22194910e-01,
                         -6.24596596e-01,  -5.73192298e-01,  -6.08365297e-01,
                         -6.02975905e-01,  -5.78735352e-01,  -6.17992580e-01,
                         -6.52445793e-01,  -5.88676214e-01,  -5.56545734e-01,
                         -6.39834344e-01,  -6.72182739e-01,  -6.15403652e-01,
                         -6.02504194e-01,  -6.32084668e-01,  -6.49019539e-01,
                         -6.39732122e-01,  -5.74087441e-01,  -5.42125940e-01,
                         -6.45088196e-01,  -6.99919343e-01,  -6.01644993e-01,
                         -5.55748105e-01,  -5.74558079e-01,  -6.25972688e-01,
                         -7.87958503e-01,  -6.48955703e-01,  -1.63826719e-01,
                         -1.81706294e-01,  -4.70826477e-01,  -2.07034796e-01,
                         -1.83122739e-01,  -7.30508506e-01,  -5.99624991e-01,
                         -9.13399532e-02,  -3.34019542e-01,  -4.89811957e-01,
                         -5.67200594e-02,  -2.04814479e-01,  -7.93852389e-01,
                         -5.78098476e-01,  -2.77974214e-02,  -2.40894943e-01,
                         -7.01971531e-01,  -6.35937154e-01,  -5.40238142e-01,
                         -7.17650056e-01,  -5.15165448e-01,  -6.77907541e-02,
                         -2.87752032e-01,  -7.78229058e-01,  -5.07095277e-01,
                         -7.03699002e-03,  -2.49057963e-01,  -7.29201138e-01,
                         -7.32886553e-01,  -5.89518964e-01,  -6.03357673e-01,
                         -5.93085229e-01,  -5.84425926e-01,  -6.64418459e-01,
                         -6.45595908e-01,  -5.30992210e-01,  -6.08699501e-01,
                         -7.55246997e-01,  -4.94175136e-01,   1.32153276e-02,
                          1.03884466e-01,  -2.85816252e-01,  -6.82068467e-01,
                         -6.98603690e-01,  -2.25132495e-01,   2.15591758e-01,
                         -4.07731570e-02,  -6.08907342e-01,  -7.25075185e-01,
                         -5.67327857e-01,  -5.83856225e-01,  -6.32474601e-01,
                         -5.64258814e-01,  -5.64066529e-01,  -6.43558264e-01,
                         -6.25305891e-01,  -5.95244408e-01,  -6.61955953e-01,
                         -6.48411751e-01,  -5.97861826e-01,  -6.94335222e-01,
                         -6.01072729e-01,  -1.05687454e-01,   2.07453057e-01,
                         -9.50192735e-02,  -6.16396666e-01,  -7.27660716e-01,
                         -3.35424900e-01,   2.43098643e-02,   7.22252205e-02,
                          4.97396402e-02,  -2.10102588e-01,  -7.36004829e-01,
                         -6.81038260e-01,  -1.17898770e-01,  -1.67595342e-01,
                         -5.25939941e-01,  -2.66122073e-01,   7.81750381e-02,
                          1.42793693e-02,   2.12425198e-02,   5.15443571e-02,
                         -2.73972869e-01,  -6.58396482e-01,  -6.46366715e-01,
                         -2.26231143e-01,   1.00723930e-01,  -1.10370927e-01,
                         -4.63104159e-01,  -5.58128059e-01,  -6.85656905e-01,
                         -6.48091853e-01,  -1.69284493e-01,  -1.50813863e-01,
                         -7.80668497e-01,  -7.34964967e-01,  -5.30694351e-02,
                         -6.79194331e-02,  -6.06888831e-01,  -7.41343439e-01,
                         -5.68821311e-01,  -5.31754673e-01,  -7.17406094e-01,
                         -7.62925565e-01,  -3.54769677e-01,  -1.07339837e-01,
                         -4.24809486e-01,  -6.52809203e-01,  -6.49621010e-01,
                         -7.24434912e-01,  -6.46134675e-01,  -5.34080923e-01,
                         -6.43937409e-01,  -6.55430317e-01,  -5.67767918e-01,
                         -5.58888853e-01,  -5.63802719e-01,  -7.13396192e-01,
                         -7.24019051e-01,  -2.81688929e-01,  -1.21088959e-01,
                         -5.26149869e-01,  -7.26450980e-01,  -6.17241383e-01,
                         -6.03585422e-01,  -6.38857126e-01,  -6.22919559e-01,
                         -6.11923814e-01,  -6.82186663e-01,  -6.88030064e-01,
                         -3.44066858e-01,  -1.03391215e-01,  -5.08607149e-01,
                         -7.96658993e-01,  -3.48302841e-01,  -3.61530781e-02,
                         -3.84056300e-01,  -7.08194137e-01,  -6.87264800e-01,
                         -6.36449933e-01,  -6.22918725e-01,  -6.10810220e-01,
                         -6.65648639e-01,  -6.99583828e-01,  -6.47962332e-01,
                         -5.75058401e-01,  -5.30518293e-01,  -6.00181401e-01,
                         -7.18962789e-01,  -6.77800715e-01,  -5.84128737e-01,
                         -6.22546196e-01,  -6.66341782e-01,  -6.64593756e-01,
                         -6.99682236e-01,  -6.87756836e-01,  -5.95537782e-01,
                         -5.66144526e-01,  -6.36123955e-01,  -6.60506010e-01,
                         -5.94110966e-01,  -6.11074686e-01,  -7.26792097e-01,
                         -7.02030301e-01,  -5.61802387e-01,  -5.80559075e-01,
                         -7.19335675e-01,  -7.19691694e-01,  -6.01613879e-01,
                         -5.62525094e-01,  -5.99995613e-01,  -6.36212170e-01,
                         -6.91891849e-01,  -7.00825930e-01,  -6.20694339e-01,
                         -5.89558184e-01,  -6.23301208e-01,  -6.27994061e-01,
                         -6.34874880e-01,  -6.51725888e-01,  -6.43181026e-01,
                         -6.31481707e-01,  -6.27267361e-01,  -6.30642056e-01,
                         -6.32862270e-01,  -6.62951529e-01,  -7.30121017e-01,
                         -6.71915472e-01,  -5.26994884e-01,  -5.71253300e-01,
                         -6.85970366e-01,  -6.53315246e-01,  -6.21173561e-01,
                         -6.22038543e-01,  -5.73290765e-01,  -5.90303183e-01,
                         -6.88145697e-01,  -7.11079180e-01,  -6.12275600e-01,
                         -5.62934875e-01,  -6.77727461e-01,  -7.20529675e-01,
                         -6.11685693e-01,  -6.15568161e-01,  -6.59047902e-01,
                         -5.93994796e-01,  -6.15735829e-01,  -6.87915385e-01,
                         -6.49994135e-01,  -6.13410115e-01,  -6.15281641e-01,
                         -6.12551332e-01,  -6.18576169e-01,  -6.24251246e-01,
                         -6.74009740e-01,  -6.83328748e-01,  -5.59035778e-01,
                         -5.43381393e-01,  -6.76706314e-01,  -6.72459960e-01,
                         -5.96984029e-01,  -6.26908064e-01,  -6.48167133e-01,
                         -6.39288783e-01,  -6.75637662e-01,  -6.80420637e-01,
                         -6.27023637e-01,  -6.02328360e-01,  -6.07814848e-01,
                         -6.06926084e-01,  -6.39251113e-01,  -6.88360035e-01,
                         -6.47170365e-01,  -5.53129196e-01,  -5.79319000e-01,
                         -6.87967122e-01,  -6.52690053e-01,  -5.42846799e-01,
                         -6.22284293e-01,  -7.26506531e-01,  -6.20042443e-01,
                         -5.70368886e-01,  -6.66056931e-01,  -6.30384386e-01,
                         -5.64473212e-01,  -6.34966612e-01,  -6.81110740e-01,
                         -6.53654337e-01,  -5.99207878e-01,  -6.03365839e-01,
                         -7.24092901e-01,  -6.12132072e-01,  -2.22498417e-01,
                         -1.98709756e-01,  -5.61007679e-01,  -7.02752948e-01,
                         -6.30516768e-01,  -6.16606534e-01,  -6.05345964e-01,
                         -6.07423127e-01,  -6.67265058e-01,  -6.47584379e-01,
                         -5.52881062e-01,  -5.92990577e-01,  -7.23177016e-01,
                         -5.79143167e-01,  -2.00125709e-01,  -2.09532976e-01,
                         -6.40287519e-01,  -6.44536734e-01,  -1.73624471e-01,
                         -1.78811118e-01,  -6.06178224e-01,  -6.41935647e-01,
                         -5.46212792e-01,  -7.03791797e-01,  -5.71959436e-01,
                         -1.76357061e-01,  -2.16126308e-01,  -5.91893137e-01,
                         -7.47292936e-01,  -6.44828737e-01,  -5.83361924e-01,
                         -6.30994678e-01,  -6.09907150e-01,  -6.01568639e-01,
                         -6.97303891e-01,  -5.62623560e-01,  -1.87328875e-01,
                          3.26380990e-02,   7.61167482e-02,  -1.59732513e-02,
                         -3.38228673e-01,  -6.81261599e-01,  -7.47820556e-01,
                         -5.77710867e-01,  -5.82967222e-01,  -7.85997212e-01,
                         -5.37371874e-01,  -1.02132775e-01,  -3.05196345e-01,
                         -4.54675138e-01,  -8.68337378e-02,  -2.56702483e-01,
                         -7.64846563e-01,  -6.52058899e-01,  -5.71210265e-01,
                         -7.52168953e-01,  -3.88592422e-01,  -8.16796273e-02,
                         -4.72332150e-01,  -4.72434103e-01,   1.25010610e-01,
                          2.07760278e-02,  -5.77006280e-01,  -3.99437994e-01,
                          3.65989050e-03,  -4.17238086e-01,  -7.93858349e-01,
                         -3.45528215e-01,  -7.65421689e-02,  -4.59928244e-01,
                         -6.92545593e-01,  -6.57735407e-01,  -5.81624150e-01,
                         -1.63719922e-01,   1.38060018e-01,  -2.76830256e-01,
                         -5.33603132e-01,  -1.43776566e-01,  -1.30495295e-01,
                         -6.68601096e-01,  -7.50929594e-01,  -2.10953474e-01,
                          1.67246684e-01,  -8.77756849e-02,  -5.00823796e-01,
                         -3.82614553e-01,  -1.19211068e-02,   4.76829410e-02,
                         -1.54707702e-02,   1.23181986e-02,   2.97810212e-02,
                          3.88504006e-02,  -2.32797652e-03,  -6.48302436e-02,
                         -8.53732042e-03,   4.71304618e-02,   8.02845601e-03,
                         -6.85576524e-04,   3.05311605e-02,   3.69461440e-02,
                          1.91391744e-02,   9.60289780e-03,   1.44359283e-02,
                         -1.79270785e-02,  -2.96619777e-02,   2.28850134e-02,
                          1.26206717e-02,  -2.63156742e-03,   7.08003417e-02,
                          3.77054662e-02,  -9.50949118e-02,  -7.08764270e-02,
                          6.48042634e-02,   8.22684094e-02,  -7.51955993e-03,
                          5.68474643e-03,   9.20894668e-02,   1.70919835e-03,
                         -1.05081223e-01,   3.33359726e-02,   1.04875043e-01,
                         -6.48005530e-02,  -1.06751390e-01,   4.76950519e-02,
                          8.13723356e-02,  -4.06513326e-02,  -5.94174452e-02,
                          6.39814138e-02,   6.61462247e-02,  -5.23975343e-02,
                         -3.27564515e-02,   4.87095937e-02,   3.75021361e-02,
                          1.70348492e-02,  -3.36622521e-02,  -9.47578251e-02,
                         -1.56866685e-02,   8.86055753e-02,   6.48348480e-02,
                         -1.05802389e-03,  -2.40378231e-02,   2.58032475e-02,
                          9.18232352e-02,   6.43345192e-02,  -1.78005022e-03,
                         -3.98150273e-02,  -5.89347482e-02,  -3.05961929e-02,
                         -2.16266569e-02,  -2.62355153e-02,   6.55158609e-02,
                          7.71324709e-02,  -1.41485827e-02,   6.70544580e-02,
                          2.76213679e-02,  -3.70370656e-01,  -4.64674413e-01,
                         -8.11101198e-02,   9.12649930e-02,  -1.47493817e-02,
                         -4.02793251e-02,  -3.56744789e-02,  -1.46132251e-02,
                          6.40629008e-02,   5.78152761e-02,   6.06321124e-03,
                          6.77878130e-03,  -4.11903812e-03,  -8.78193788e-03,
                          3.23052774e-03,  -3.29559185e-02,  -6.00116514e-02,
                         -2.37998925e-02,   3.03172786e-02,   5.92519529e-02,
                          3.04085426e-02,  -1.27209323e-02,   1.90510124e-03,
                          3.25274952e-02,   3.93443033e-02,   3.12999152e-02,
                         -1.31122470e-02,  -4.05837521e-02,   2.00488400e-02,
                          6.73748255e-02,   1.66511703e-02,  -2.07267068e-02,
                          5.38595021e-03,   3.88717628e-03,   5.40469261e-03,
                          6.12132587e-02,   4.30150703e-02,  -5.65228499e-02,
                         -5.38284443e-02,   2.57406700e-02,   1.24680093e-02,
                         -5.15767410e-02,  -3.37963179e-02,   2.44722422e-02,
                          2.61205565e-02,   2.62176823e-02,   5.36487997e-02,
                         -3.29560228e-03,  -6.37282059e-02,   1.90594234e-02,
                          5.60647398e-02,  -2.85727270e-02,  -4.27411357e-03,
                          5.36088385e-02,  -3.73200327e-02,  -8.66690725e-02,
                          1.19391484e-02,   6.93742782e-02,   1.88531149e-02,
                         -1.14005934e-02,   1.91700570e-02,  -1.86413117e-02,
                         -8.60897377e-02,   8.87109339e-03,   9.51680616e-02,
                          2.56449752e-03,  -2.10104901e-02,   2.05233134e-03,
                         -5.47678322e-02,   5.88655807e-02,   8.29844475e-02,
                         -3.56209129e-01,  -5.56709588e-01,  -1.14878826e-01,
                          1.65226266e-01,  -3.82963941e-02,  -1.26587763e-01,
                          1.17943101e-01,   1.92544267e-01,  -2.28250846e-01,
                         -6.51063800e-01,  -7.01813638e-01,  -7.04223394e-01,
                         -5.13048768e-01,  -2.03424543e-02,  -1.60046011e-01,
                         -8.08334768e-01,  -6.24705970e-01,  -3.93312126e-02,
                         -2.63860792e-01,  -7.17017353e-01,  -6.79749250e-01,
                         -5.98523498e-01,  -6.16948783e-01,  -5.67356229e-01,
                         -6.89211667e-01,  -7.59966791e-01,  -3.05306852e-01,
                          2.12369934e-02,  -4.26312715e-01,  -8.02834749e-01,
                         -6.24250233e-01,  -6.23935878e-01,  -6.91174448e-01,
                         -2.82154948e-01,  -8.16100612e-02,  -5.30949295e-01,
                         -8.07685971e-01,  -4.01661128e-01,   1.20676160e-01,
                          5.08532114e-02,  -4.31019366e-01,  -6.73428118e-01,
                         -6.83867395e-01,  -5.95617473e-01,  -2.57171839e-01,
                         -1.28232136e-01,  -4.95490313e-01,  -7.10698009e-01,
                         -6.61035538e-01,  -7.33743727e-01,  -5.90578318e-01,
                         -1.40239194e-01,  -1.45034820e-01,  -6.54645801e-01,
                         -7.02373862e-01,  -1.69259027e-01,  -9.07376558e-02,
                         -5.91818810e-01,  -7.52390504e-01,  -6.06094718e-01,
                         -6.99097514e-01,  -6.30175710e-01,  -1.83024451e-01,
                         -1.02681354e-01,  -5.74448347e-01,  -7.34048784e-01,
                         -2.79317498e-01,  -1.11034766e-01,  -5.89756906e-01,
                         -7.42292166e-01,  -2.46646076e-01,  -1.07874312e-01,
                         -6.12706184e-01,  -8.12925458e-01,  -3.07506830e-01,
                          1.37920842e-01,  -2.53540985e-02,  -4.08710271e-01,
                         -6.59327209e-01,  -6.52030826e-01,  -1.55523062e-01,
                          2.15896219e-01,  -2.23117575e-01,  -5.34886122e-01,
                         -2.13242903e-01,  -2.47498974e-01,  -4.83339936e-01,
                         -2.48642728e-01,  -2.51278222e-01,  -6.34280384e-01,
                         -6.84657812e-01,  -6.12442851e-01,  -6.55442357e-01,
                         -6.14378273e-01,  -6.52906895e-01,  -6.82062626e-01,
                         -5.64881146e-01,  -6.29538774e-01,  -6.32032096e-01,
                         -1.80098444e-01,   1.37614354e-01,  -1.35249183e-01,
                         -5.24738669e-01,  -6.33058190e-01,  -6.35402918e-01,
                         -6.64918721e-01,  -5.68176627e-01,  -5.02278149e-01,
                         -7.16365039e-01,  -7.14913011e-01,  -1.75684690e-01,
                          1.75930902e-01,  -1.16101816e-01,  -5.86400807e-01,
                         -7.03238785e-01,  -3.56722832e-01,  -8.36495832e-02,
                         -4.15568709e-01,  -7.51091480e-01,  -4.14038002e-01,
                         -7.98693970e-02,  -3.90862405e-01,  -7.17367291e-01,
                         -6.37485981e-01,  -6.53036773e-01,  -7.13848293e-01,
                         -3.37256879e-01,  -7.09514543e-02,  -4.72906619e-01,
                         -7.74438858e-01,  -3.84313166e-01,  -2.95740645e-02,
                         -3.69284600e-01,  -7.94604242e-01,  -4.97201532e-01,
                         -5.02122752e-02,  -3.20996314e-01,  -7.29416132e-01,
                         -6.54828608e-01,  -5.72584927e-01,  -6.20324373e-01,
                         -5.49148858e-01,  -5.51187515e-01,  -6.55107975e-01,
                         -6.81682050e-01,  -6.39885068e-01,  -5.71759045e-01,
                         -6.20318592e-01,  -7.12752700e-01,  -6.28134251e-01,
                         -6.44928992e-01,  -6.81990921e-01,  -2.85474062e-01,
                         -1.19671412e-01,  -5.17725885e-01,  -3.92735898e-01,
                         -1.45488605e-02,  -5.33683658e-01,  -8.83075655e-01,
                         -2.00974926e-01,  -6.89575681e-03,  -5.32163858e-01,
                         -3.55409741e-01,  -4.46715839e-02,  -5.79436362e-01,
                         -7.87875593e-01,  -2.01637372e-01,  -1.59377798e-01,
                         -6.09709084e-01,  -2.95952320e-01,   2.34408587e-01,
                         -1.76949203e-01,  -6.13900542e-01,  -2.16393635e-01,
                         -1.45597935e-01,  -5.52873552e-01,  -1.95416510e-01,
                          1.98116526e-01,  -3.19897979e-01,  -4.75608408e-01,
                         -6.45136982e-02,  -2.91430205e-01,  -5.16249716e-01,
                         -1.14729576e-01,  -2.54399657e-01,  -8.24471533e-01,
                         -5.30018687e-01,   2.41194991e-03,  -3.52789581e-01,
                         -7.71016181e-01,  -5.50032616e-01,  -5.50395906e-01,
                         -8.15047622e-01,  -4.41795766e-01,  -3.35631743e-02,
                         -4.13239747e-01,  -5.55361331e-01,   6.28381073e-02,
                          1.91791117e-01,  -4.59142923e-01,  -7.55851328e-01,
                         -5.57177246e-01,  -5.67090392e-01,  -6.57495618e-01,
                         -5.86150825e-01,  -7.12357819e-01,  -7.59149432e-01,
                         -2.70831466e-01,  -4.02808599e-02,  -4.97050256e-01,
                         -6.84006453e-01,  -4.82012242e-01,  -6.59575462e-01,
                         -7.61175394e-01,  -2.25119114e-01,  -3.08780428e-02,
                         -6.48601115e-01,  -8.33315790e-01,  -2.12968543e-01,
                         -5.58199137e-02,  -5.71657896e-01,  -7.42464781e-01,
                         -5.78305125e-01,  -6.14692450e-01,  -6.32889628e-01,
                         -5.53747416e-01,  -6.29456282e-01,  -6.82442069e-01,
                         -5.92468321e-01,  -5.93268752e-01,  -6.66885972e-01,
                         -6.30435824e-01,  -5.62918186e-01,  -6.06473088e-01,
                         -6.90653980e-01,  -6.72298253e-01,  -5.74801028e-01,
                         -5.62168777e-01,  -6.80330932e-01,  -6.65198505e-01,
                         -2.73890704e-01,   1.19693778e-01,  -4.27357592e-02,
                         -5.09913504e-01,  -6.82657361e-01,  -6.23339653e-01,
                         -6.39273107e-01,  -6.47382200e-01,  -5.48233747e-01,
                         -5.39408803e-01,  -7.24905610e-01,  -7.54978061e-01,
                         -3.77728820e-01,  -3.87227573e-02,  -2.80946903e-02,
                          4.37674560e-02,   1.63035274e-01,   2.98123099e-02,
                         -2.74998154e-02,   5.69370128e-02,  -6.61857054e-02,
                         -8.47957805e-02,   7.57160038e-02,  -1.79880664e-01,
                         -5.46662867e-01,  -3.18711311e-01,   1.06694728e-01,
                          1.14389308e-01,  -8.33752006e-02,  -5.96534321e-03,
                          1.91456079e-01,  -8.56646523e-02,  -5.25149882e-01,
                         -3.15536380e-01,   1.02589093e-01,   5.17251417e-02,
                         -4.22094129e-02,   9.03611444e-03,  -8.02339017e-02,
                         -7.88773447e-02,   9.93047953e-02,   1.16982251e-01,
                         -5.26366802e-03,  -4.68060374e-02,   2.85988767e-03,
                          5.28261364e-02,   3.57780084e-02,  -1.90773495e-02,
                         -4.21135835e-02,   4.98934928e-03,   6.66525811e-02,
                          1.33168623e-02,  -6.22087382e-02,  -4.50226665e-03,
                          5.19670844e-02,   3.61118838e-02,   2.64703128e-02,
                         -5.72412089e-03,  -1.11294929e-02,   4.37942110e-02,
                          5.63707724e-02,   1.74062513e-02,  -5.41655608e-02,
                         -3.25938649e-02,   1.15808718e-01,  -6.18900582e-02,
                         -4.86625999e-01,  -3.83249432e-01,   2.84257047e-02,
                          4.71814834e-02,  -4.32284698e-02,   3.60667445e-02,
                          2.62298211e-02,  -1.69293024e-02,   4.24251668e-02,
                          3.29658426e-02,  -7.10961670e-02,  -3.55757214e-03,
                          1.63444668e-01,  -1.09850280e-01,  -5.56567371e-01,
                         -3.18304241e-01,   1.12196743e-01,   6.73525874e-03,
                          8.35493673e-03,   1.27654314e-01,  -3.02210927e-01,
                         -5.56877553e-01,  -1.22999892e-01,   1.27120450e-01,
                         -2.58541554e-02,  -6.38371035e-02,   3.64663117e-02,
                          7.92032257e-02,  -1.23850293e-01,  -5.27373672e-01,
                         -6.78502560e-01,  -5.67992628e-01,  -6.01955831e-01,
                         -5.93888938e-01,  -2.58869827e-01,  -1.36383846e-01,
                         -5.64998627e-01,  -7.16205180e-01,  -2.30144754e-01,
                         -1.25931427e-01,  -5.30215800e-01,  -3.53468180e-01,
                          1.26260772e-01,  -7.71314725e-02,  -4.88897979e-01,
                         -5.54462075e-01,  -6.39929593e-01,  -5.85293829e-01,
                         -1.69841051e-01,  -1.82143509e-01,  -7.39026070e-01,
                         -7.00985909e-01,  -8.33657384e-02,  -1.14426509e-01,
                         -6.26125634e-01,  -6.34793937e-01,  -5.19861519e-01,
                         -7.44840026e-01,  -6.20940268e-01,  -1.15679264e-01,
                         -1.67221785e-01,  -6.84417188e-01,  -6.58440769e-01,
                         -1.53494045e-01,  -1.53680295e-01,  -5.75549841e-01,
                         -6.28118515e-01,  -5.99611104e-01,  -7.68852711e-01,
                         -4.64437932e-01,  -5.67288771e-02,  -3.84169996e-01,
                         -5.45495808e-01,  -7.19532371e-02,  -2.06387788e-01,
                         -8.00451100e-01,  -5.61884463e-01,  -3.42557803e-02,
                         -2.49712408e-01,  -6.75144851e-01,  -7.07408905e-01,
                         -6.60668254e-01,  -7.02939451e-01,  -4.93340313e-01,
                         -4.59727226e-03,   1.27348155e-01,  -3.14668208e-01,
                         -5.11166811e-01,  -9.39977691e-02,   1.45268515e-01,
                         -2.18902290e-01,  -6.77748382e-01,  -7.24522114e-01,
                         -2.95355767e-01,   1.37337461e-01,  -2.68802010e-02,
                         -4.78486329e-01,  -3.72513384e-01,   1.03124641e-01,
                          2.19223090e-02,  -4.77557838e-01,  -4.39064384e-01,
                          1.44837024e-02,   5.36542200e-03,  -4.27806705e-01,
                         -7.12236106e-01,  -6.00170076e-01,  -9.80944857e-02,
                          1.87315926e-01,  -2.27333978e-01,  -5.31219780e-01,
                         -2.06105590e-01,   5.33313025e-03,  -6.14316240e-02,
                         -5.52556887e-02,  -2.94556618e-01,  -7.09445596e-01,
                         -7.27949798e-01,  -5.45935690e-01,  -5.47377646e-01,
                         -6.19716585e-01,  -7.04041779e-01,  -6.77782595e-01,
                         -3.17601383e-01,   4.46050242e-02,   1.51445717e-02,
                         -6.78732395e-02,   4.63727377e-02,  -6.86734095e-02,
                         -5.08243084e-01,  -7.48177946e-01,  -6.51983857e-01,
                         -5.95795751e-01,  -7.07118690e-01,  -7.08562613e-01,
                         -5.39192140e-01,  -5.96063197e-01,  -7.59392142e-01,
                         -4.11818802e-01,  -6.32657856e-02,  -3.92404765e-01,
                         -4.39235538e-01,   1.18604466e-01,   3.17217037e-03,
                         -5.68972349e-01,  -3.92156541e-01,   2.97286082e-02,
                          3.50673385e-02,   1.35716870e-02,  -1.96462989e-01,
                         -7.56760001e-01,  -7.77359545e-01,  -1.42663583e-01,
                         -6.69443905e-02,  -6.64203584e-01,  -7.85949290e-01,
                         -5.27153254e-01,  -6.86954856e-01,  -7.00791240e-01,
                         -2.15398863e-01,  -1.89252466e-01,  -6.16830826e-01,
                         -6.31797612e-01,  -5.38401663e-01,  -7.50988126e-01,
                         -6.44469142e-01,  -7.67198205e-02,   1.54575124e-01,
                         -6.07405007e-02,  -2.41342913e-02,   9.49919671e-02,
                         -3.13303411e-01,  -5.97433329e-01,  -1.77549407e-01,
                          1.20921321e-01,  -3.89461778e-02,  -7.29945078e-02,
                          2.28844490e-02,   3.13749351e-02,   1.18871219e-02,
                         -2.17476655e-02,   1.60708893e-02,   1.47167342e-02,
                         -1.06341943e-01,   2.34277989e-03,   9.06285793e-02,
                         -3.00725400e-01,  -5.15975118e-01,  -1.71367437e-01,
                          4.75473516e-02,  -3.63952294e-02,  -2.72932574e-02,
                          1.05201773e-01,   9.94502679e-02,  -2.42937133e-01,
                         -5.62252939e-01,  -3.19077522e-01,   1.03606418e-01,
                          8.89510289e-02,  -8.33596438e-02,  -3.45821343e-02,
                          8.31114221e-03,  -7.65031576e-02,  -2.07035467e-02,
                          6.70606643e-02,  -2.21576050e-01,  -5.18437445e-01,
                         -2.50852257e-01,   9.85605344e-02,   4.02184390e-02,
                         -4.20189425e-02,   2.29641609e-03,  -3.06141414e-02,
                         -4.94338870e-02,  -9.02110245e-03,   1.48754036e-02,
                          2.26329993e-02,  -2.34548151e-02,  -5.22568449e-02,
                         -1.54608870e-02,  -3.93403322e-02,  -4.10828888e-02,
                          6.28877655e-02,   6.00321889e-02,  -4.59257700e-02,
                         -5.37725128e-02,  -3.27495486e-02,  -5.21527715e-02,
                          9.76202718e-04,  -4.55196341e-03,  -3.31280559e-01,
                         -7.01192498e-01,  -6.64518952e-01,  -5.37572086e-01,
                         -6.85217917e-01,  -6.05421901e-01,  -9.03846920e-02,
                          1.47093087e-01,  -2.25101784e-01,  -6.95602655e-01,
                         -6.95392907e-01,  -2.44888052e-01,   1.50729362e-02,
                         -1.26256138e-01,  -6.92321360e-02,   1.44647509e-01,
                         -1.52900353e-01,  -5.48704207e-01,  -2.73061007e-01,
                          9.54573676e-02,  -7.66764730e-02,  -1.56621575e-01,
                          6.19849823e-02,  -1.84296057e-01,  -6.00208461e-01,
                         -2.64912486e-01,   2.09155172e-01,  -9.49050635e-02,
                         -5.25735557e-01,  -3.56864899e-01,  -3.11007537e-02,
                          4.08856086e-02,   5.07036746e-02,   6.38014227e-02,
                         -3.88686098e-02,  -1.10080749e-01,  -1.18186735e-02,
                          6.36084378e-02,   2.45452356e-02,  -3.54833491e-02,
                         -1.09831244e-01,  -7.37890303e-02,   6.09756522e-02,
                          2.16041645e-03,  -5.25447018e-02,   8.03110451e-02,
                         -1.27952158e-01,  -5.32428443e-01,  -3.42968225e-01,
                          8.88586640e-02,   6.31067082e-02,  -8.59912038e-02,
                         -3.74644436e-03,   4.22617346e-02,  -5.26456609e-02,
                         -7.45828776e-03,   1.22993998e-01,  -1.67139143e-01,
                         -6.07741356e-01,  -3.48804295e-01,   1.35460049e-01,
                          4.74189036e-03,  -9.83353332e-02,   9.26231593e-02,
                         -2.24587619e-01,  -5.84052265e-01,  -2.17958182e-01,
                         -9.33941752e-02,  -6.57039881e-01,  -7.11655080e-01,
                         -1.73792630e-01,  -1.93105444e-01,  -6.48863971e-01,
                         -7.08629072e-01,  -5.57931423e-01,  -6.07785344e-01,
                         -6.85784400e-01,  -6.68970942e-01,  -6.35780156e-01,
                         -6.18711829e-01,  -6.36968553e-01,  -6.36124194e-01,
                         -6.08892500e-01,  -6.61720574e-01,  -7.20599294e-01,
                         -6.56144381e-01,  -5.81087470e-01,  -6.14244580e-01,
                         -6.69312477e-01,  -6.46412492e-01,  -6.22831225e-01,
                         -6.67661607e-01,  -6.44746423e-01,  -5.55140913e-01,
                         -5.97054362e-01,  -6.75097048e-01,  -6.32980108e-01,
                         -6.42711580e-01,  -7.30654657e-01,  -6.82532430e-01,
                         -5.51837683e-01,  -5.58571935e-01,  -6.66540146e-01,
                         -6.76480055e-01,  -6.15912437e-01,  -6.48192585e-01,
                         -6.82750344e-01,  -6.29566848e-01,  -6.32416308e-01,
                         -6.54888391e-01,  -5.93444645e-01,  -5.95141888e-01,
                         -6.59412324e-01,  -6.27491355e-01,  -5.78620315e-01,
                         -6.17794693e-01,  -6.59269214e-01,  -6.34119272e-01,
                         -6.16976619e-01,  -6.68601334e-01,  -6.70418620e-01,
                         -5.83363950e-01,  -5.85996270e-01,  -6.69344842e-01,
                         -6.67834342e-01,  -6.24507010e-01,  -6.37324989e-01,
                         -6.68925703e-01,  -6.24932647e-01,  -5.30457556e-01,
                         -5.72420120e-01,  -6.95583642e-01,  -6.48069561e-01,
                         -5.53200006e-01,  -6.14809930e-01,  -6.81888163e-01,
                         -6.35092497e-01,  -5.73344767e-01,  -6.15256965e-01,
                         -7.13506043e-01,  -6.70110941e-01,  -5.54431140e-01,
                         -5.96536994e-01,  -6.85580075e-01,  -6.63697779e-01,
                         -5.89567602e-01,  -5.34758568e-01,  -5.80141485e-01,
                         -6.83355629e-01,  -6.93786204e-01,  -6.27812088e-01,
                         -5.75529814e-01,  -6.21773601e-01,  -6.97810411e-01,
                         -6.23504043e-01,  -6.37561858e-01,  -7.45481968e-01,
                         -3.98804128e-01,  -4.54553626e-02,  -3.55138808e-01,
                         -4.98939574e-01,  -1.75259501e-01,  -3.21506023e-01,
                         -7.18183219e-01,  -6.45299613e-01,  -5.20402253e-01,
                         -6.42947793e-01,  -6.67562485e-01,  -5.86966515e-01,
                         -6.46410227e-01,  -6.84238017e-01,  -3.78472388e-01,
                         -1.04822934e-01,  -3.82792711e-01,  -7.05437720e-01,
                         -6.39228046e-01,  -6.19868934e-01,  -6.49913192e-01,
                         -5.63668549e-01,  -6.75897717e-01,  -6.57509267e-01,
                         -2.04890773e-01,  -1.42668590e-01,  -5.90918660e-01,
                         -6.49947643e-01,  -5.23188472e-01,  -7.29357719e-01,
                         -5.92834055e-01,  -8.66726339e-02,  -2.36948520e-01,
                         -6.08964860e-01,  -1.67870387e-01,   2.02924088e-01,
                         -3.07039380e-01,  -5.79551756e-01,  -1.69075012e-01,
                         -1.96693599e-01,  -7.38466322e-01,  -6.59076631e-01,
                         -4.89083081e-02,  -1.20819300e-01,  -7.46478617e-01,
                         -6.95331335e-01,  -1.57046184e-01,  -1.52930632e-01,
                         -4.87100840e-01,  -6.85714781e-01,  -7.67105222e-01,
                         -4.61206228e-01,  -4.49946150e-02,  -3.40478271e-01,
                         -7.96174049e-01,  -4.53148365e-01,  -3.64526585e-02,
                         -3.77665251e-01,  -7.62848854e-01,  -6.24983430e-01,
                         -5.47306180e-01,  -6.51564419e-01,  -3.60719830e-01,
                         -6.00500442e-02,  -4.53424752e-01,  -8.06827068e-01,
                         -3.95718575e-01,  -6.13805577e-02,  -3.82641256e-01,
                         -7.03309894e-01,  -6.70776844e-01,  -5.82359552e-01,
                         -6.34635508e-01,  -7.18826592e-01,  -4.79298323e-01,
                         -1.12544119e-01,  -3.05063725e-01,  -5.32589912e-01,
                         -1.60961505e-02,   2.15556711e-01,  -3.85101706e-01,
                         -4.98474151e-01,  -7.65087605e-02,  -3.02545279e-01,
                         -7.26742446e-01,  -6.09193802e-01,  -5.76737881e-01,
                         -7.33565986e-01,  -3.98744106e-01,  -1.29682235e-02,
                         -4.10391867e-01,  -8.40373218e-01,  -3.79666358e-01,
                         -2.86846142e-02,  -4.54923987e-01,  -4.22465086e-01,
                          4.01418097e-03,  -4.60698068e-01,  -8.65982711e-01,
                         -2.75132746e-01,  -8.46975148e-02,  -4.74698603e-01,
                         -2.83080220e-01,  -1.21644832e-01,  -4.90994573e-01,
                         -3.54815066e-01,   1.64648026e-01,  -1.16392979e-02,
                         -5.73324740e-01,  -6.88167155e-01,  -5.73316932e-01,
                         -6.68042779e-01,  -6.36632442e-01,  -2.39253074e-01,
                         -9.94060785e-02,  -5.07650137e-01,  -7.39066303e-01,
                         -3.71322185e-01,   8.49419758e-02,   6.17508627e-02,
                         -3.76700699e-01,  -6.86046064e-01,  -6.44964874e-01,
                         -5.80750704e-01,  -6.21735454e-01,  -6.23462796e-01,
                         -6.07589781e-01,  -6.10212266e-01,  -6.10515654e-01,
                         -6.16214573e-01,  -6.13556087e-01,  -6.24909282e-01,
                         -6.05360210e-01,  -5.56432903e-01,  -6.62167370e-01,
                         -6.91883802e-01,  -3.10803115e-01,  -8.23835284e-02,
                         -4.30530697e-01,  -6.92200124e-01,  -5.89629114e-01,
                         -5.97663641e-01,  -6.51124001e-01,  -5.79213560e-01,
                         -6.64669275e-01,  -6.27255797e-01,  -1.75377846e-01,
                         -9.63312164e-02,  -5.85832119e-01,  -7.03587294e-01,
                         -5.44931114e-01,  -6.98462129e-01,  -5.75529099e-01,
                         -9.51098949e-02,  -1.84005886e-01,  -6.39145076e-01,
                         -6.82796597e-01,  -5.68652749e-01,  -6.26395583e-01,
                         -6.40382051e-01,  -5.91095448e-01,  -6.06001318e-01,
                         -6.34001911e-01,  -6.24090552e-01,  -6.06283605e-01,
                         -6.11371219e-01,  -6.14787579e-01,  -6.09489977e-01,
                         -6.37340605e-01,  -6.34175599e-01,  -5.80406964e-01,
                         -5.99520266e-01,  -6.11434877e-01,  -5.79027474e-01,
                         -6.96437478e-01,  -6.64579093e-01,  -2.20396355e-01,
                         -8.20715651e-02,  -5.19899130e-01,  -7.32369602e-01,
                         -5.99110425e-01,  -6.00346148e-01,  -6.34070933e-01,
                         -5.96444964e-01,  -6.26393676e-01,  -6.36930645e-01,
                         -6.07468665e-01,  -6.21404707e-01,  -6.34692967e-01,
                         -6.23842657e-01,  -5.99847198e-01,  -5.99296331e-01,
                         -6.40507698e-01,  -6.41132236e-01,  -6.14444375e-01,
                         -6.23432338e-01,  -6.22529566e-01,  -6.15737557e-01,
                         -6.22014344e-01,  -6.14375591e-01,  -6.26301944e-01,
                         -6.47656679e-01,  -6.18104398e-01,  -5.81912041e-01,
                         -6.09500051e-01,  -6.52197719e-01,  -6.30370259e-01,
                         -6.02994323e-01,  -6.30893886e-01,  -6.33827507e-01,
                         -6.12602234e-01,  -6.28439605e-01,  -6.23584509e-01,
                         -6.06244028e-01,  -6.35224879e-01,  -6.43221736e-01,
                         -6.07400179e-01,  -5.99696279e-01,  -6.22181833e-01,
                         -6.29879415e-01,  -6.19001925e-01,  -6.17276549e-01,
                         -6.35701299e-01,  -6.48523033e-01,  -6.30365252e-01,
                         -6.13396108e-01,  -6.32925034e-01,  -6.29681051e-01,
                         -5.99643707e-01,  -6.37115121e-01,  -6.67714834e-01,
                         -6.02093041e-01,  -5.82746208e-01,  -6.48437500e-01,
                         -6.55291796e-01,  -6.04901433e-01,  -5.97041786e-01,
                         -6.33136392e-01,  -6.46246493e-01,  -6.25637352e-01,
                         -6.20514154e-01,  -6.19343460e-01,  -6.14321411e-01,
                         -6.42572522e-01,  -6.51063979e-01,  -6.17467463e-01,
                         -6.19468689e-01,  -6.34143412e-01,  -6.15615845e-01,
                         -6.11697137e-01,  -6.24546111e-01,  -6.27221048e-01,
                         -6.31013036e-01,  -6.24374807e-01,  -6.15016639e-01,
                         -6.36800408e-01,  -6.57010436e-01,  -6.38813138e-01,
                         -6.11166418e-01,  -6.07863605e-01,  -6.39509141e-01,
                         -6.65595412e-01,  -6.32703662e-01,  -5.91031611e-01,
                         -6.01252317e-01,  -6.37521744e-01,  -6.61555588e-01,
                         -6.34594679e-01,  -5.92577815e-01,  -6.20888650e-01,
                         -6.57046676e-01,  -6.39473557e-01,  -6.29598081e-01,
                         -6.30002797e-01,  -6.25885308e-01,  -6.29095733e-01,
                         -6.24151349e-01,  -6.20955646e-01,  -6.24571264e-01,
                         -6.45449698e-01,  -6.54375255e-01,  -6.02310598e-01,
                         -6.01775885e-01,  -6.37678087e-01,  -6.18438542e-01,
                         -6.98973954e-01,  -6.43764317e-01,  -2.35597461e-01,
                         -1.53599843e-01,  -5.36092639e-01,  -6.84208333e-01,
                         -6.41133726e-01,  -5.49281120e-01,  -1.32159486e-01,
                          1.55070692e-01,  -2.04906568e-01,  -6.68423891e-01,
                         -6.63393617e-01,  -5.78634322e-01,  -7.39617229e-01,
                         -5.68493426e-01,  -7.58474395e-02,  -2.04091981e-01,
                         -7.08613694e-01,  -6.90512657e-01,  -5.66439450e-01,
                         -7.51635730e-01,  -5.80217540e-01,  -6.73982278e-02,
                         -2.06134796e-01,  -8.00843298e-01,  -6.30937874e-01,
                         -5.17683923e-02,  -2.18315795e-01,  -6.65086627e-01,
                         -7.12311745e-01,  -6.46463692e-01,  -4.20610785e-01,
                          2.66201026e-03,   9.41815898e-02,  -3.27595502e-01,
                         -7.85800159e-01,  -6.28602445e-01,  -9.25353765e-02,
                         -1.93435341e-01,  -7.63261199e-01,  -6.86710894e-01,
                         -1.06519386e-01,  -1.52613297e-01,  -7.56747782e-01,
                         -6.92378700e-01,  -1.13731802e-01,  -2.44881451e-01,
                         -5.76097190e-01,  -1.93073586e-01,   1.24091476e-01,
                         -4.36987244e-02,  -5.90048693e-02,   4.52042893e-02,
                         -2.32446358e-01,  -7.19058514e-01,  -6.80594325e-01,
                         -1.53213039e-01,  -1.44316405e-01,  -6.92828536e-01,
                         -7.42238164e-01,  -2.07679331e-01,  -9.69829857e-02,
                         -6.52761161e-01,  -7.83751965e-01,  -1.92332298e-01,
                         -1.34640530e-01,  -6.05566502e-01,  -3.47416520e-01,
                          1.72153845e-01,  -1.26316637e-01,  -6.03165209e-01,
                         -3.46203983e-01,   1.33681506e-01,  -4.18134704e-02,
                         -5.34928620e-01,  -6.62796497e-01,  -6.91015959e-01,
                         -6.63317382e-01,  -2.32372925e-01,   7.84043670e-02,
                         -3.61636505e-02,  -3.06194592e-02,   5.38492650e-02,
                         -2.18757331e-01,  -6.61592126e-01,  -7.61025310e-01,
                         -3.30098957e-01,   1.15412645e-01,  -6.36519566e-02,
                         -5.31052113e-01,  -4.55006927e-01,   4.05577794e-02,
                          8.00368786e-02,  -4.52733576e-01,  -7.95634687e-01,
                         -5.67049325e-01,  -1.38531372e-01,   4.14636843e-02,
                         -2.43328270e-02,  -4.97813337e-02,  -6.39102887e-03,
                         -2.05320586e-02,  -2.89966464e-02,  -2.02639345e-02,
                         -4.70284037e-02,  -4.74851690e-02,  -2.71347761e-02,
                         -2.98672821e-02,  -3.09854597e-02,  -2.71643605e-02,
                         -1.80755835e-02,  -1.52344583e-02,  -3.12419031e-02,
                         -2.63038911e-02,  -5.86280553e-03,  -1.71305966e-02,
                         -4.61899340e-02,  -4.46652435e-02,  -1.67755634e-02,
                         -1.55923739e-02,  -2.96925865e-02,  -2.29108278e-02,
                         -2.61428803e-02,  -3.61178070e-02,  -2.71527972e-02,
                         -2.14418378e-02,  -2.55045872e-02,  -3.17803137e-02,
                         -3.41614224e-02,  -3.77674885e-02,  -4.41032536e-02,
                         -2.12639887e-02,  -8.78070574e-03,  -3.82802188e-02,
                         -3.93106863e-02,  -3.08981966e-02,  -3.86424288e-02,
                         -1.51558863e-02,  -1.18259024e-02,  -3.37030292e-02,
                         -2.83922441e-02,  -3.51755582e-02,  -3.64294872e-02,
                         -2.06493046e-02,  -2.45340466e-02,  -9.66729317e-03,
                         -9.97203402e-03,  -4.37709950e-02,  -3.09813023e-02,
                         -1.84261966e-02,  -2.97149438e-02,  -1.43235913e-02,
                         -2.66988613e-02,  -4.91673201e-02,  -2.58731693e-02,
                         -9.95657220e-03,  -1.42479753e-02,  -2.44133733e-02,
                         -3.12489867e-02,  -1.99164357e-02,  -2.66680643e-02,
                         -3.28437500e-02,  -1.32851135e-02,  -1.79169346e-02,
                         -2.76004616e-02,  -1.97594464e-02,  -1.75519884e-02,
                         -6.48463424e-03,  -1.10983085e-02,  -3.90524976e-02,
                         -4.20047790e-02,  -2.85251923e-02,  -1.00473566e-02,
                          3.59022961e-04,  -2.27711610e-02,  -3.53309363e-02,
                         -2.25070510e-02,  -1.51397772e-02,  -9.73249320e-03,
                         -2.00024769e-02,  -3.28711607e-02,  -1.73865799e-02,
                         -9.17674229e-03,  -1.55639891e-02,  -1.81464348e-02,
                         -3.29219028e-02,  -3.71099971e-02,  -1.52768632e-02,
                         -3.84381064e-03,  -9.04205907e-03,  -1.48264598e-02,
                         -1.68867838e-02,  -1.10704564e-02,  -7.53190834e-03,
                         -2.05846597e-02,  -3.27099860e-02,  -1.96873322e-02,
                         -4.22532624e-03,  -7.03789899e-03,  -1.08832140e-02,
                         -1.98657364e-02,  -2.45202687e-02,  -5.92142390e-03,
                         -7.76679954e-03,  -3.09921261e-02,  -2.40095537e-02,
                         -1.73148187e-03,  -1.02580525e-03,  -2.94820890e-02,
                         -3.94696072e-02,   3.26097035e-03,   7.64309615e-03,
                         -3.94964553e-02,  -3.05755809e-02,   6.28952542e-03,
                          2.66282517e-03,  -2.23076995e-02,  -3.55274566e-02,
                         -5.83678205e-03,   1.28766242e-02,  -2.39382628e-02,
                         -3.70739438e-02,  -2.08564382e-02,  -1.02686984e-02,
                         -4.71759075e-03,  -3.54101248e-02,  -2.63824835e-02,
                          6.20444445e-03,  -4.52123322e-02,   3.02196499e-02,
                          8.13319460e-02,  -3.38541836e-01,  -5.69253504e-01,
                         -1.56503558e-01,  -1.82490513e-01,  -7.57377028e-01,
                         -7.04027593e-01,  -1.51457429e-01,   1.01166114e-01,
                         -8.79399329e-02,  -6.05357647e-01,  -7.88032651e-01,
                         -3.09141040e-01,  -1.08946659e-01,  -4.70549077e-01,
                         -7.06596792e-01,  -7.39868820e-01,  -5.53593814e-01,
                         -1.61934137e-01,  -2.24613965e-01,  -6.55315459e-01,
                         -7.23736703e-01,  -6.10923231e-01,  -6.54461563e-01,
                         -6.52702034e-01,  -6.08458519e-01,  -6.47472918e-01,
                         -6.76753879e-01,  -6.27297163e-01,  -6.17299080e-01,
                         -6.96824670e-01,  -5.37635982e-01,  -5.09805493e-02,
                          1.25952393e-01,  -2.96285957e-01,  -6.81089401e-01,
                         -6.24740481e-01,  -5.76105416e-01,  -7.54166603e-01,
                         -5.91903567e-01,  -1.00352310e-01,  -2.01544285e-01,
                         -7.66092300e-01,  -6.51142657e-01,  -9.65356529e-02,
                         -2.20462650e-01,  -6.80836678e-01,  -6.46649361e-01,
                         -5.61898947e-01,  -7.52068579e-01,  -5.48736453e-01,
                         -8.69652107e-02,  -2.74154544e-01,  -7.29523540e-01,
                         -6.36319101e-01,  -5.51951110e-01,  -7.81518161e-01,
                         -5.14805973e-01,  -1.00627979e-02,  -2.89030969e-01,
                         -8.42274606e-01,  -5.85743546e-01,  -1.84671804e-02,
                         -2.53513604e-01,  -8.19137752e-01,  -5.71977615e-01,
                         -7.43939951e-02,  -3.34357142e-01,  -5.69285333e-01,
                         -7.11413845e-02,   1.83338940e-01,  -2.98405349e-01,
                         -7.01236665e-01,  -6.67423368e-01,  -5.70618570e-01,
                         -6.15602434e-01,  -6.85122907e-01,  -6.44142926e-01,
                         -6.16764367e-01,  -6.46970689e-01,  -5.86977601e-01,
                         -6.41812801e-01,  -7.76670396e-01,  -4.64334965e-01,
                         -6.53854534e-02,  -3.13866377e-01,  -7.18408167e-01,
                         -6.77539647e-01,  -5.78584969e-01,  -6.52739763e-01,
                         -6.59441531e-01,  -6.25729561e-01,  -6.39114439e-01,
                         -6.19506836e-01,  -6.15684271e-01,  -6.64090991e-01,
                         -6.35418177e-01,  -5.95742166e-01,  -7.06850827e-01,
                         -6.35756254e-01,  -2.01471284e-01,  -1.28234178e-01,
                         -5.95165610e-01,  -7.47492969e-01,  -5.69310784e-01,
                         -6.51830733e-01,  -6.68472290e-01,  -2.21011683e-01,
                          1.48515165e-01,  -1.04503557e-01,  -5.67147613e-01,
                         -6.76265895e-01,  -6.53881848e-01,  -5.88216901e-01,
                         -1.68299884e-01,   1.51951939e-01,  -1.46082431e-01,
                         -5.75294018e-01,  -7.02419102e-01,  -6.55125618e-01,
                         -5.77341557e-01,  -6.52247608e-01,  -7.06723928e-01,
                         -3.45658809e-01,  -8.08523968e-02,  -4.27166045e-01,
                         -7.40616858e-01,  -6.36693120e-01,  -5.65424979e-01,
                         -6.58099890e-01,  -6.53083205e-01,  -5.65798044e-01,
                         -6.57228053e-01,  -7.04403460e-01,  -3.17272007e-01,
                         -7.57087991e-02,  -4.48678076e-01,  -7.17654109e-01,
                         -6.06149554e-01,  -6.06617570e-01,  -6.47303522e-01,
                         -5.81724286e-01,  -6.48809910e-01,  -6.31300628e-01,
                         -2.09704429e-01,   1.53566629e-01,  -7.24493936e-02,
                         -5.44388533e-01,  -6.75882101e-01,  -5.82255483e-01,
                         -5.97683489e-01,  -6.27834141e-01,  -6.15958393e-01,
                         -6.44097328e-01,  -6.23154163e-01,  -5.85782290e-01,
                         -6.19101405e-01,  -6.32554352e-01,  -6.10148787e-01,
                         -5.94670177e-01,  -5.99772513e-01,  -6.19493604e-01,
                         -6.10132873e-01,  -6.11858368e-01,  -6.29628062e-01,
                         -6.11473620e-01,  -6.06955767e-01,  -6.18938684e-01,
                         -6.16340637e-01,  -6.14902079e-01,  -6.05397105e-01,
                         -6.07349455e-01,  -6.21822298e-01,  -6.13715589e-01,
                         -5.99753201e-01,  -6.00107491e-01,  -6.06079161e-01,
                         -6.05631948e-01,  -6.05067194e-01,  -6.07992828e-01,
                         -6.04817569e-01,  -6.00720406e-01,  -6.02494121e-01,
                         -6.11794829e-01,  -6.02226913e-01,  -6.02584898e-01,
                         -6.26066208e-01,  -5.74117184e-01,  -6.03812635e-01,
                         -7.01270819e-01,  -3.94383013e-01,  -4.75927107e-02,
                         -3.30676109e-01,  -6.82707965e-01,  -6.27424061e-01,
                         -5.74282706e-01,  -6.18672192e-01,  -6.03691041e-01,
                         -5.95638156e-01,  -5.95970809e-01,  -5.96549153e-01,
                         -6.09255016e-01,  -5.66661954e-01,  -6.02870643e-01,
                         -7.11903811e-01,  -4.31262881e-01,  -3.40643786e-02,
                         -3.02104652e-01,  -7.06820071e-01,  -5.85709453e-01,
                         -5.60965598e-01,  -7.18163431e-01,  -3.79596293e-01,
                          4.68654209e-04,  -3.79159898e-01,  -7.99118400e-01,
                         -3.93608779e-01,  -9.95977968e-03,  -3.37482959e-01,
                         -6.43735707e-01,  -6.73889041e-01,  -5.87329626e-01,
                         -1.76813558e-01,  -5.21318577e-02,  -6.03694320e-01,
                         -7.33043969e-01,  -1.56749323e-01,  -5.33607118e-02,
                         -5.50266325e-01,  -6.80383325e-01,  -5.18630087e-01,
                         -6.61229849e-01,  -6.15857780e-01,  -1.39079764e-01,
                         -1.28342062e-01,  -5.93793690e-01,  -6.84585929e-01,
                         -5.45658171e-01,  -5.90976179e-01,  -6.25436902e-01,
                         -5.95189989e-01,  -5.85854292e-01,  -5.81785083e-01,
                         -6.14100218e-01,  -6.08976960e-01,  -5.71901083e-01,
                         -6.40866816e-01,  -6.20478034e-01,  -2.61539578e-01,
                          1.25122145e-01,   3.86611596e-02,  -4.54546094e-01,
                         -7.45346248e-01,  -4.69385505e-01,  -1.94641519e-02,
                          9.19306725e-02,   9.05408338e-03,   2.79183239e-02,
                          5.22278845e-02,   2.37781107e-02,   1.66039914e-02,
                          1.37302410e-02,   2.41357964e-02,   4.56074513e-02,
                          4.02050763e-02,   3.13492268e-02,   3.81781012e-02,
                          3.47471461e-02,   2.06108708e-02,   4.43241149e-02,
                          3.35239135e-02,  -1.38781397e-02,   9.62330326e-02,
                          5.65569699e-02,  -3.78839612e-01,  -4.73065913e-01,
                         -4.30421680e-02,   1.28349632e-01,   1.33134983e-03,
                          7.60722090e-04,   6.97623417e-02,   3.73187587e-02,
                         -1.22060813e-02,   1.03531480e-01,   5.94409406e-02,
                         -3.96702677e-01,  -4.88997519e-01,  -6.33594161e-03,
                          1.19008139e-01,  -4.32770401e-02,   1.05672926e-01,
                          1.69745386e-02,  -4.54594821e-01,  -4.12807882e-01,
                          3.99733298e-02,   1.15304865e-01,  -1.81113009e-03,
                          3.84907387e-02,   4.33660597e-02,   3.08219017e-03,
                          2.04221234e-02,   3.86855118e-02,   4.62145284e-02,
                          3.00698187e-02,   2.98609305e-02,   6.71254545e-02,
                          1.47125348e-02,   8.32890254e-03,   1.32159069e-01,
                         -7.92038962e-02,  -4.89893019e-01,  -3.25127572e-01,
                          9.59062353e-02,   8.19335654e-02,  -2.57616471e-02,
                          4.82145809e-02,   6.03330843e-02,   1.84935275e-02,
                          4.06525433e-02,   5.51553220e-02,   4.19051648e-04,
                          5.78604080e-02,   1.34363487e-01,  -2.15542570e-01,
                         -5.32812715e-01,  -1.93961710e-01,   1.36671245e-01,
                          3.88793461e-02,  -8.71293538e-04,   6.28837124e-02,
                          2.57758349e-02,   8.89251998e-04,   5.74895367e-02,
                          5.72252907e-02,  -1.19604087e-02,   7.52140582e-02,
                          8.55362043e-02,  -3.51762027e-01,  -5.35069466e-01,
                          2.80000400e-02,   2.18825832e-01,  -3.75546157e-01,
                         -4.67112541e-01,  -6.31178692e-02,  -2.94899166e-01,
                         -5.00023067e-01,   4.53012586e-02,   1.91984668e-01,
                         -4.03057754e-01,  -5.25648177e-01,   3.88178676e-02,
                          1.87664017e-01,  -3.55660945e-01,  -5.37579417e-01,
                         -7.03876689e-02,   1.47553518e-01,  -8.07141420e-03,
                          2.57655438e-02,   9.64752287e-02,  -2.75574803e-01,
                         -7.46805072e-01,  -5.27938306e-01,  -4.64732386e-02,
                         -2.69326448e-01,  -5.39971232e-01,  -6.59175739e-02,
                          2.14134961e-01,  -2.44281828e-01,  -6.07571721e-01,
                         -6.22353852e-01,  -6.36341989e-01,  -4.28180069e-01,
                          3.14478762e-02,   1.38447270e-01,  -2.85394669e-01,
                         -7.01730430e-01,  -5.91301203e-01,  -1.38326451e-01,
                          7.04845786e-02,   5.39025143e-02,   2.28677969e-02,
                         -3.20655137e-01,  -7.52224982e-01,  -5.24837613e-01,
                         -1.82765734e-03,  -2.04006359e-01,  -7.81873584e-01,
                         -5.90418041e-01,  -3.80920693e-02,  -2.57139564e-01,
                         -5.88402331e-01,  -7.68814236e-02,   2.40415484e-01,
                         -3.19994003e-01,  -5.21840930e-01,  -9.28452685e-02,
                         -1.98244318e-01,  -7.23090768e-01,  -6.72712862e-01,
                         -8.81906673e-02,   2.02983767e-01,  -2.17835158e-01,
                         -5.60782194e-01,  -1.84534833e-01,  -9.62053910e-02,
                         -6.95320964e-01,  -7.04568148e-01,  -9.37826559e-02,
                         -1.60066739e-01,  -5.93655467e-01,  -2.27351114e-01,
                          2.39469558e-01,  -2.16987461e-01,  -5.70094287e-01,
                         -1.66628093e-01,  -1.48428768e-01,  -6.79735839e-01,
                         -7.34416306e-01,  -2.06076175e-01,   1.68742225e-01,
                         -1.08433731e-01,  -5.41832387e-01,  -3.45145464e-01,
                          5.60300536e-02,   3.02100182e-02,  -4.26404178e-02,
                          3.30606401e-02,  -3.62616754e-03,  -5.67545881e-03,
                          5.71057536e-02,  -2.07151636e-01,  -6.70320034e-01,
                         -7.19665706e-01,  -2.89841324e-01,   9.76255462e-02,
                          9.31030791e-03,  -4.90889847e-01,  -7.87443697e-01,
                         -4.81820405e-01,  -6.04335964e-02,   2.01618671e-02,
                          2.68442426e-02,  -5.22624739e-02,  -5.46654284e-01,
                         -8.28811705e-01,  -3.41770381e-01,  -7.12224022e-02,
                         -4.90729213e-01,  -4.71709043e-01,   1.02510363e-01,
                          3.42018232e-02,  -5.78545988e-01,  -5.09973764e-01,
                          1.16349421e-01,   3.05045824e-02,  -5.42038381e-01,
                         -3.99767935e-01,  -1.12584457e-01,  -4.82183814e-01,
                         -4.79297727e-01,   1.15604751e-01,   1.89822093e-02,
                         -5.91992080e-01,  -4.73416299e-01,   1.02043800e-01,
                          3.10048298e-03,  -5.40088534e-01,  -4.86460805e-01,
                         -2.68478058e-02,   5.12547977e-02,  -6.90071359e-02,
                         -2.96957102e-02,  -5.19196969e-04,  -3.07118110e-02,
                         -3.05022523e-02,  -2.68093925e-02,  -2.75656320e-02,
                         -2.51562111e-02,  -2.86702402e-02,  -3.33645232e-02,
                         -3.12338173e-02,  -2.74076723e-02,  -3.26110385e-02,
                         -3.33505534e-02,  -2.60048974e-02,  -2.63218600e-02,
                         -3.08823790e-02,  -3.55766527e-02,  -3.68822515e-02,
                         -2.89901271e-02,  -2.33980473e-02,  -2.77397949e-02,
                         -2.85958033e-02,  -2.46280394e-02,  -3.23063321e-02,
                         -3.55088823e-02,  -2.63823159e-02,  -3.15025151e-02,
                         -2.97967549e-02,  -1.61296967e-02,  -3.17419618e-02,
                         -4.62179333e-02,  -2.69504692e-02,  -1.41783357e-02,
                         -2.59180404e-02,  -3.71047296e-02,  -3.60764787e-02,
                         -3.50219049e-02,  -3.26663591e-02,  -2.58268993e-02,
                         -2.45797839e-02,  -1.77145433e-02,  -2.31535230e-02,
                         -5.13715930e-02,  -3.58050987e-02,  -3.11933346e-02,
                         -8.71187225e-02,   1.72329147e-03,   7.47044384e-02,
                         -2.95566887e-01,  -6.00681722e-01,  -2.56234020e-01,
                          7.75070563e-02,  -2.81299595e-02,  -7.82795027e-02,
                          6.65548490e-03,  -1.59286745e-02,  -4.60356548e-02,
                          2.36688138e-04,  -2.66174488e-02,  -8.83008167e-02,
                          4.32217941e-02,  -9.89720132e-03,  -4.68688428e-01,
                         -4.80898470e-01,  -1.16024293e-01,  -3.77713650e-01,
                         -7.74831295e-01,  -6.41206086e-01,  -6.09454930e-01,
                         -7.41184890e-01,  -4.39900786e-01,  -1.24986295e-03,
                          3.18979658e-02,  -7.13256076e-02,   2.64525004e-02,
                         -2.74717454e-02,  -5.02454579e-01,  -8.15378606e-01,
                         -4.90290403e-01,  -8.60407501e-02,   7.08335405e-03,
                          6.02832213e-02,  -1.48500830e-01,  -5.46413064e-01,
                         -3.73140424e-01,   4.75821383e-02,   3.03588044e-02,
                         -7.53910318e-02,  -2.06417944e-02,  -7.11629353e-03,
                         -4.97963466e-02,  -4.26545218e-02,   3.68420072e-02,
                         -9.62089598e-02,  -5.68521738e-01,  -7.87356913e-01,
                         -4.14615691e-01,  -3.33036482e-02,   2.08438821e-02,
                          2.57560369e-02,  -1.47541344e-01,  -6.21635497e-01,
                         -7.84596086e-01,  -3.58588278e-01,   3.46680507e-02,
                         -2.70631816e-02,  -7.68816546e-02,   1.02098711e-01,
                         -1.52145848e-01,  -5.87947547e-01,  -3.13058794e-01,
                         -7.88366869e-02,  -6.17571652e-01,  -8.34987938e-01,
                         -2.59393185e-01,  -5.23257628e-02,  -6.25435293e-01,
                         -8.41266155e-01,  -2.68388212e-01,  -9.47068334e-02,
                         -5.75801730e-01,  -4.24568027e-01,   1.77993596e-01,
                         -1.01938441e-01,  -6.02987230e-01,  -3.02064925e-01,
                         -1.92427874e-01,  -5.10699272e-01,  -2.89408863e-01,
                         -1.59482718e-01,  -6.72085643e-01,  -7.78209627e-01,
                         -2.49562979e-01,   9.62281600e-02,  -8.74782652e-02,
                         -5.35552561e-01,  -7.32913494e-01,  -6.49919927e-01,
                         -6.45117104e-01,  -6.76510036e-01,  -6.53915823e-01,
                         -6.62016809e-01,  -6.59914672e-01,  -6.56019747e-01,
                         -6.76411569e-01,  -6.68250859e-01,  -6.55902445e-01,
                         -6.56462550e-01,  -6.51941538e-01,  -6.54437482e-01,
                         -6.58415496e-01,  -6.66019201e-01,  -6.66767418e-01,
                         -6.49757922e-01,  -6.53220236e-01,  -6.64558411e-01,
                         -6.55942142e-01,  -6.54309154e-01,  -6.62551224e-01,
                         -6.74797535e-01,  -6.81785762e-01,  -6.71956241e-01,
                         -6.65565014e-01,  -6.60149097e-01,  -6.60690367e-01,
                         -6.78688824e-01,  -6.84935689e-01,  -6.76496565e-01,
                         -6.63773000e-01,  -6.64760947e-01,  -6.85957193e-01,
                         -6.82252884e-01,  -6.73411429e-01,  -6.76342666e-01,
                         -6.62000597e-01,  -6.79078937e-01,  -7.01444805e-01,
                         -6.71345353e-01,  -6.62561059e-01,  -6.81215048e-01,
                         -6.80896819e-01,  -6.80223405e-01,  -6.78458095e-01,
                         -6.77434206e-01,  -6.75118208e-01,  -6.64469481e-01,
                         -6.70497179e-01,  -6.79285049e-01,  -6.71434104e-01,
                         -6.90880060e-01,  -7.33519495e-01,  -6.89481139e-01,
                         -6.37361944e-01,  -7.60964036e-01,  -7.02141464e-01,
                         -2.56219298e-01,  -1.98641106e-01,  -6.62626743e-01,
                         -7.51774669e-01,  -5.97154140e-01,  -7.72764087e-01,
                         -7.09709108e-01,  -1.99213415e-01,  -1.80758476e-01,
                         -7.53822923e-01,  -8.05747986e-01,  -2.12041304e-01,
                         -1.40002653e-01,  -7.22484350e-01,  -8.19059134e-01,
                         -2.68277377e-01,  -1.28563046e-01,  -6.65631354e-01,
                         -8.45612824e-01,  -3.13296318e-01,  -1.39046699e-01,
                         -6.15196645e-01,  -7.83325791e-01,  -6.14434540e-01,
                         -7.37946093e-01,  -7.59901702e-01,  -2.89120644e-01,
                         -1.31671742e-01,  -6.71633244e-01,  -8.40946138e-01,
                         -2.85894156e-01,  -1.46948621e-01,  -6.11874223e-01,
                         -7.81146944e-01,  -6.59925222e-01,  -6.74067378e-01,
                         -7.17874527e-01,  -7.01489687e-01,  -6.72151148e-01,
                         -6.66038036e-01,  -7.33735383e-01,  -7.26330876e-01,
                         -6.23988867e-01,  -7.15274930e-01,  -7.64904320e-01,
                         -3.80177438e-01,  -1.67135805e-01,  -5.38385391e-01,
                         -7.89134026e-01,  -6.88985050e-01,  -6.55772686e-01,
                         -7.11857915e-01,  -7.52136946e-01,  -5.57870567e-01,
                         -5.86967357e-02,   8.42149779e-02,  -3.87288272e-01,
                         -7.59020388e-01,  -6.89067125e-01,  -6.57378733e-01,
                         -8.05257320e-01,  -5.74677587e-01,  -1.44699007e-01,
                         -3.30359370e-01,  -7.55959690e-01,  -7.41272569e-01,
                         -6.53495431e-01,  -7.05713391e-01,  -6.83649957e-01,
                         -6.68619514e-01,  -7.37221658e-01,  -7.37892628e-01,
                         -6.22254610e-01,  -6.70960248e-01,  -7.83927977e-01,
                         -4.55872416e-01,  -1.51524797e-01,  -4.37558055e-01,
                         -7.45180309e-01,  -7.78082252e-01,  -6.27611995e-01,
                         -2.51914263e-01,  -2.39584848e-01,  -7.32765198e-01,
                         -7.63829768e-01,  -2.24437058e-01,  -1.74828768e-01,
                         -7.46117711e-01,  -7.99819589e-01,  -2.21162707e-01,
                         -1.76476121e-01,  -6.55321836e-01,  -7.87925243e-01,
                         -6.67763829e-01,  -6.54146791e-01,  -6.98175907e-01,
                         -6.93607688e-01,  -6.59052849e-01,  -7.56950021e-01,
                         -7.09079444e-01,  -2.57630557e-01,  -1.53839678e-01,
                         -6.96240306e-01,  -8.42052639e-01,  -2.90421128e-01,
                         -1.09804951e-01,  -5.83157301e-01,  -8.02645743e-01,
                         -6.39392316e-01,  -6.86805367e-01,  -7.11453676e-01,
                         -3.18960816e-01,   5.62155508e-02,  -8.34554657e-02,
                         -5.58520317e-01,  -7.75024176e-01,  -6.50308013e-01,
                         -6.43214583e-01,  -7.16517985e-01,  -6.46556675e-01,
                         -6.65686309e-01,  -6.86950386e-01,  -3.30944151e-01,
                          6.38756230e-02,  -9.96353626e-02,  -5.33196211e-01,
                         -6.94770396e-01,  -7.41021574e-01,  -6.31406903e-01,
                         -1.78340375e-01,  -1.74073949e-01,  -7.72870660e-01,
                         -7.15382159e-01,  -1.08678259e-01,  -2.39725173e-01,
                         -6.39734268e-01,  -2.40963817e-01,   1.94936961e-01,
                         -2.38162592e-01,  -6.79033995e-01,  -2.78969944e-01,
                          1.82481110e-01,  -1.11866504e-01,  -6.30804062e-01,
                         -7.25913167e-01,  -6.28659725e-01,  -6.11387193e-01,
                         -6.34940505e-01,  -7.03424513e-01,  -5.03666818e-01,
                          3.77942249e-02,   5.04491925e-02,  -4.72226590e-01,
                         -4.24016893e-01,  -1.43665254e-01,  -4.19005096e-01,
                         -4.30335641e-01,  -8.19827393e-02,  -4.36165035e-01,
                         -8.41739774e-01,  -3.54035974e-01,  -3.16468403e-02,
                         -4.68672514e-01,  -7.38879025e-01,  -6.24957681e-01,
                         -5.99889755e-01,  -6.48758829e-01,  -6.33520246e-01,
                         -6.04142129e-01,  -6.17031813e-01,  -6.31473899e-01,
                         -6.05235398e-01,  -6.23027742e-01,  -6.52722061e-01,
                         -6.23919249e-01,  -6.11783147e-01,  -5.93425095e-01,
                         -5.95379114e-01,  -6.52318239e-01,  -6.28530622e-01,
                         -5.96893609e-01,  -6.09004378e-01,  -5.84909081e-01,
                         -6.24504209e-01,  -6.15089118e-01,  -5.71600318e-01,
                         -6.92730486e-01,  -5.15006900e-01,  -7.54910484e-02,
                         -2.21598014e-01,  -6.63461864e-01,  -6.67961001e-01,
                         -5.29013932e-01,  -5.85115314e-01,  -6.44955158e-01,
                         -5.60482502e-01,  -5.58790684e-01,  -7.01015890e-01,
                         -4.73944783e-01,  -4.46980447e-02,  -2.14132905e-01,
                         -6.45140648e-01,  -6.55757010e-01,  -5.35411537e-01,
                         -5.72150528e-01,  -5.85982800e-01,  -5.12582064e-01,
                         -5.53120553e-01,  -6.96790159e-01,  -4.83226538e-01,
                         -4.94880453e-02,  -1.64740920e-01,  -6.08086646e-01,
                         -6.58512652e-01,  -5.23502171e-01,  -5.45768976e-01,
                         -5.70849478e-01,  -5.57881892e-01,  -5.62651038e-01,
                         -5.47156453e-01,  -5.52611470e-01,  -5.79476058e-01,
                         -5.54764986e-01,  -5.31282008e-01,  -5.57799518e-01,
                         -5.63815832e-01,  -5.41259646e-01,  -5.39349675e-01,
                         -5.50746024e-01,  -5.52929401e-01,  -5.42597413e-01,
                         -5.49674511e-01,  -5.70492387e-01,  -5.44212759e-01,
                         -5.12268484e-01,  -5.35783648e-01,  -5.50729096e-01,
                         -5.33164620e-01,  -5.26022971e-01,  -5.40934086e-01,
                         -5.60790420e-01,  -5.45587540e-01,  -5.30492544e-01,
                         -5.52585959e-01,  -5.39375544e-01,  -5.14409542e-01,
                         -5.34315944e-01,  -5.32216251e-01,  -5.21245718e-01,
                         -5.42772293e-01,  -5.47865808e-01,  -5.35009325e-01,
                         -5.24544775e-01,  -5.33302128e-01,  -5.57411313e-01,
                         -5.39963186e-01,  -5.12489200e-01,  -5.12000978e-01,
                         -5.14410496e-01,  -5.50218165e-01,  -5.59659719e-01,
                         -5.05560219e-01,  -5.12284160e-01,  -5.43561757e-01,
                         -5.29919088e-01,  -5.39892137e-01,  -5.32228529e-01,
                         -5.15396237e-01,  -5.42973042e-01,  -5.20504773e-01,
                         -4.91935521e-01,  -5.29790223e-01,  -5.39563656e-01,
                         -5.37312806e-01,  -5.40180504e-01,  -5.08837104e-01,
                         -5.19740045e-01,  -5.49573958e-01,  -5.36250591e-01,
                         -5.32254219e-01,  -5.14411449e-01,  -5.02625108e-01,
                         -5.58124721e-01,  -5.71694374e-01,  -5.10269463e-01,
                         -4.91307229e-01,  -5.34388542e-01,  -5.57898402e-01,
                         -5.23147702e-01,  -5.32288790e-01,  -5.68662763e-01,
                         -4.77211148e-01,  -4.92209822e-01,  -6.68726385e-01,
                         -4.18633282e-01,   3.01198699e-02,  -1.87037691e-01,
                         -6.33883357e-01,  -5.84925413e-01,  -4.85727578e-01,
                         -5.58597386e-01,  -5.16930699e-01,  -5.74081719e-01,
                         -6.25703394e-01,  -2.15883955e-01,   5.99841438e-02,
                         -4.21824872e-01,  -7.54441440e-01,  -2.55987436e-01,
                          6.13530390e-02,  -3.92977774e-01,  -6.71985924e-01,
                         -4.85503435e-01,  -5.58925211e-01,  -6.36952758e-01,
                         -2.02722669e-01,   7.52052106e-03,  -3.96797329e-01,
                         -6.50453925e-01,  -5.58398366e-01,  -5.44589877e-01,
                         -5.62943220e-01,  -5.42703748e-01,  -5.68682790e-01,
                         -5.29378176e-01,  -5.53331077e-01,  -6.59232080e-01,
                         -3.76741141e-01,  -3.65159567e-03,  -2.66645968e-01,
                         -6.52990043e-01,  -5.86523712e-01,  -5.30700028e-01,
                         -5.92024088e-01,  -5.42368412e-01,  -5.61674535e-01,
                         -5.89821577e-01,  -5.47344208e-01,  -6.09127462e-01,
                         -5.41509688e-01,  -1.60432667e-01,   1.61013067e-01,
                          2.37128269e-02,  -5.18080235e-01,  -7.27787912e-01,
                         -2.50544220e-01,  -4.79267053e-02,  -4.33211863e-01,
                         -3.45041245e-01,   1.37621492e-01,   9.33501720e-02,
                         -2.43134573e-02,   1.69499189e-01,  -8.52426961e-02,
                         -5.36486864e-01,  -2.64731795e-01,   1.56564981e-01,
                          4.13004793e-02,   1.35418186e-02,   1.74905866e-01,
                         -1.71822250e-01,  -5.69128633e-01,  -1.74839616e-01,
                          2.55378127e-01,  -1.66396767e-01,  -5.48628092e-01,
                         -1.59629717e-01,  -5.58139458e-02,  -6.60046041e-01,
                         -6.97522223e-01,  -9.18322131e-02,  -1.43617496e-01,
                         -5.17647862e-01,  -1.84446752e-01,   1.64510697e-01,
                         -9.26866569e-03,   2.91945450e-02,   1.39773071e-01,
                         -2.90906429e-01,  -5.47299862e-01,  -1.09859578e-01,
                          1.65672228e-01,   2.38043116e-03,   6.42552078e-02,
                          1.03583880e-01,  -3.62151891e-01,  -5.50919354e-01,
                         -1.81312561e-02,   2.19011858e-01,  -3.20165306e-01,
                         -5.96347034e-01,  -5.52924313e-02,   2.40088344e-01,
                         -2.79845506e-01,  -5.44770420e-01,  -1.45348847e-01,
                          1.05142005e-01,   8.59594867e-02,  -5.66513799e-02,
                         -4.49448198e-01,  -4.39291209e-01,   1.22695036e-01,
                          8.07889849e-02,  -5.03911197e-01,  -4.39111859e-01,
                          3.22973579e-02,   9.38113481e-02,  -1.12500200e-02,
                          2.22727861e-02,   4.01391983e-02,   1.37330722e-02,
                          3.33425635e-03,   2.05045305e-02,   3.41434106e-02,
                          1.31009538e-02,   2.01093182e-02,   4.46280204e-02,
                          2.75060534e-02,   9.26212594e-03,   6.03302941e-03,
                          1.73033793e-02,   3.06797475e-02,   1.65190361e-02,
                          2.24887673e-02,   2.93541439e-02,  -1.03440322e-03,
                          6.58791373e-03,   3.46802324e-02,   2.47179996e-02,
                          8.65892449e-04,  -1.41328909e-02,   1.32989250e-02,
                          4.49737012e-02,   2.90323962e-02,   1.72579866e-02,
                         -4.10223904e-04,  -1.57031640e-02,   3.21880206e-02,
                          4.77269962e-02,  -4.68770182e-03,  -5.51076140e-03,
                          2.77795978e-02,   1.75857004e-02,   9.99431685e-03,
                          2.91111767e-02,   2.46171858e-02,   8.08273908e-03,
                          6.55772164e-03,   1.02080321e-02,   3.29976343e-02,
                          2.97566801e-02,  -1.37293432e-02,  -1.96841033e-03,
                          2.45022252e-02,   1.63315963e-02,   3.06474250e-02,
                          1.25601934e-02,  -1.77814979e-02,   1.94465891e-02,
                          3.45216468e-02,   1.51310330e-02,   1.84278786e-02,
                          2.31248774e-02,   2.33117640e-02,   6.75063673e-03,
                          5.43153100e-03,   2.83244625e-02,   2.05483548e-02,
                          1.43834427e-02,  -9.46116261e-03,  -8.22385773e-03,
                          1.05824791e-01,   6.87812222e-04,  -4.80060667e-01,
                         -7.61888981e-01,  -4.77717221e-01,  -3.19324732e-02,
                          8.73441920e-02,  -1.66212711e-02,  -1.29299983e-02,
                          3.48338783e-02,   1.74353160e-02,   9.17557254e-03,
                         -3.74469953e-03,   4.00524866e-03,   3.30361314e-02,
                          6.09474024e-03,  -7.39603397e-03,   1.12187415e-02,
                          1.00636957e-02,   2.23678015e-02,   2.08515190e-02,
                         -3.16221453e-03,   9.70331486e-04,   1.68751236e-02,
                          2.16884837e-02,   8.86358228e-03,  -7.76555622e-03,
                          3.58521502e-04,   1.94405001e-02,   1.14166709e-02,
                         -1.89922266e-02,  -5.86505188e-03,   2.10370049e-02,
                         -6.90413523e-04,  -1.43542327e-03,   5.54946775e-04,
                         -1.40179945e-02,   1.91670377e-02,   5.79458615e-03,
                         -2.42972448e-02,   1.46662546e-02,  -1.35706319e-02,
                         -4.04747464e-02,   1.77419465e-02,   1.90543458e-02,
                         -4.11110884e-03,  -1.31093524e-02,  -1.90201215e-02,
                          1.22932196e-02,  -1.13907522e-02,  -4.02218960e-02,
                         -2.09425529e-03,  -5.15588559e-03,  -7.42712431e-03,
                         -2.14366987e-03,  -3.36895287e-02,  -1.80058070e-02,
                         -7.59852910e-03,  -1.29777407e-02,   7.53420638e-03,
                         -2.91968323e-02,  -3.72051038e-02,   1.17513631e-02,
                         -6.48319256e-03,  -1.98220573e-02,  -1.45376613e-02,
                         -4.64722663e-02,  -3.43179293e-02,  -2.89580459e-03,
                         -1.61231663e-02,  -3.11359707e-02,  -4.48048860e-02,
                         -3.09769455e-02,   3.76221910e-02,  -1.31927907e-01,
                         -6.57045782e-01,  -7.66546845e-01,  -2.51068652e-01,
                         -2.11517155e-01,  -5.59472084e-01,  -2.70184517e-01,
                         -1.11168914e-01,  -7.23712265e-01,  -8.10374618e-01,
                         -1.44683421e-01,  -1.06784284e-01,  -7.23090589e-01,
                         -7.91985154e-01,  -2.52201915e-01,  -1.28537238e-01,
                         -5.80318809e-01,  -7.83798456e-01,  -6.48479283e-01,
                         -6.58049822e-01,  -6.61890447e-01,  -6.22948050e-01,
                         -7.48704672e-01,  -5.72874427e-01,  -1.52746320e-01,
                         -2.93648601e-01,  -7.01860785e-01,  -7.23628521e-01,
                         -6.36464775e-01,  -6.83160424e-01,  -7.02849388e-01,
                         -6.21242762e-01,  -6.51990414e-01,  -7.98559487e-01,
                         -4.99014497e-01,  -1.06180027e-01,  -4.08724546e-01,
                         -5.30143499e-01,  -1.12330876e-01,  -3.59848708e-01,
                         -8.77302706e-01,  -5.20686924e-01,  -7.27350414e-02,
                         -4.09414440e-01,  -8.03162992e-01,  -6.85955644e-01,
                         -6.69082820e-01,  -7.89671779e-01,  -4.12241071e-01,
                         -1.64088994e-01,  -5.05289018e-01,  -4.32134479e-01,
                         -1.27769440e-01,  -5.77029049e-01,  -8.79995883e-01,
                         -3.03286701e-01,  -1.01017326e-01,  -5.85302591e-01,
                         -4.24589634e-01,   1.63798153e-01,  -1.17941752e-01,
                         -6.38217330e-01,  -3.51978898e-01,  -1.14114948e-01,
                         -5.95722675e-01,  -8.18685412e-01,  -3.41422707e-01,
                         -1.59544319e-01,  -5.73152781e-01,  -8.14507365e-01,
                         -7.88321972e-01,  -6.56395376e-01,  -2.09781617e-01,
                          1.16729736e-01,  -2.05113605e-01,  -7.58621156e-01,
                         -8.04044902e-01,  -3.22925359e-01,  -1.68921649e-01,
                         -5.58798254e-01,  -7.77929544e-01,  -7.55219340e-01,
                         -5.55505097e-01,  -1.41502544e-01,  -3.03961366e-01,
                         -8.91880214e-01,  -6.68916285e-01,  -1.40047789e-01,
                         -3.93815130e-01,  -5.86329639e-01,  -1.73832238e-01,
                         -3.47613454e-01,  -9.17657912e-01,  -5.40618181e-01,
                         -1.25509143e-01,  -5.55474222e-01,  -5.56147218e-01,
                         -1.54566184e-01,  -4.54052299e-01,  -8.78633797e-01,
                         -6.43251061e-01,  -8.49472061e-02,  -1.18432865e-02,
                         -5.05299568e-01,  -5.56238115e-01,  -2.49638632e-01,
                         -4.60221350e-01,  -5.95090151e-01,  -2.38549203e-01,
                         -2.99997191e-04,  -6.67878315e-02,  -4.14974838e-01,
                         -6.12688601e-01,  -2.73234606e-01,  -2.47437716e-01,
                         -7.78360724e-01,  -8.21600735e-01,  -2.96962231e-01,
                         -3.17258313e-02,  -1.50828242e-01,  -1.42215714e-01,
                         -3.29447091e-02,  -3.50839436e-01,  -6.76106930e-01,
                         -3.62838238e-01,  -3.51210982e-02,  -7.17987046e-02,
                         -1.42145425e-01,  -5.27780175e-01,  -9.73156869e-01,
                         -6.39372766e-01,  -1.84745431e-01,  -4.48882580e-01,
                         -7.71366119e-01,  -7.77399480e-01,  -7.69035339e-01,
                         -4.89548922e-01,  -2.37625744e-02,  -1.15332216e-01,
                         -6.29167140e-01,  -8.21846366e-01,  -7.19310105e-01,
                         -7.36652374e-01,  -7.93774784e-01,  -5.44536710e-01,
                         -1.02266021e-01,  -6.34343401e-02,  -5.03675580e-01,
                         -7.95809925e-01,  -8.06189120e-01,  -8.03916097e-01,
                         -5.22871912e-01,  -2.90023405e-02,  -1.36474401e-01,
                         -6.48383796e-01,  -5.03890753e-01,  -1.44160911e-01,
                         -6.06194019e-01,  -9.86223280e-01,  -4.31000561e-01,
                         -2.00659379e-01,  -6.54205203e-01,  -5.31241238e-01,
                         -2.18913794e-01,  -6.41699314e-01,  -9.02506292e-01,
                         -6.69664383e-01,  -7.84590840e-01,  -8.45514596e-01,
                         -3.50582689e-01,  -2.37083152e-01,  -7.54321635e-01,
                         -8.36992860e-01,  -3.32950592e-01,  -2.35550389e-01,
                         -7.45341122e-01,  -9.38628316e-01,  -4.85409260e-01,
                         -1.20940156e-01,  -1.06760144e-01,  -1.02202930e-01,
                         -3.33803356e-01,  -8.43424022e-01,  -8.34435403e-01,
                         -2.86356241e-01,  -2.06113622e-01,  -6.80168986e-01,
                         -8.71236086e-01,  -7.51703382e-01,  -7.54793465e-01,
                         -7.13387668e-01,  -6.86936796e-01,  -8.52507353e-01,
                         -6.38510346e-01,  -1.70575857e-01,  -3.48705441e-01,
                         -8.01046431e-01,  -7.95332968e-01,  -6.76173627e-01,
                         -7.27379084e-01,  -7.47988462e-01,  -6.81543648e-01,
                         -6.87120318e-01,  -8.08415353e-01,  -6.66163445e-01,
                         -1.68412834e-01,   2.89073251e-02,  -3.42744052e-01,
                         -7.20858693e-01,  -7.29262054e-01,  -6.61063969e-01,
                         -7.21144497e-01,  -6.77498043e-01,  -6.46882236e-01,
                         -7.59859502e-01,  -5.33586085e-01,  -1.71295181e-01,
                         -4.09860551e-01,  -8.02456319e-01,  -7.33967066e-01,
                         -6.24168396e-01,  -7.08079398e-01,  -7.22764134e-01,
                         -6.85542643e-01,  -6.99722767e-01,  -7.04930365e-01,
                         -6.70618773e-01,  -6.68399215e-01,  -7.12981939e-01,
                         -4.85621393e-01,   4.13461030e-02,   7.34825358e-02,
                         -4.46684659e-01,  -4.86057371e-01,  -7.54696056e-02,
                          5.23266606e-02,   3.66464704e-02,  -1.21971630e-01,
                         -5.72634399e-01,  -7.17364609e-01,  -5.55349767e-01,
                         -6.96430027e-01,  -7.03406274e-01,  -1.85026601e-01,
                         -6.84580728e-02,  -6.57206655e-01,  -7.72818327e-01,
                         -1.56839326e-01,  -3.49370316e-02,  -6.27259254e-01,
                         -8.06613743e-01,  -2.97448814e-01,   6.69960901e-02,
                          4.66038240e-03,  -2.88906936e-02,   1.75605547e-02,
                         -4.58026007e-02,   3.35917361e-02,   1.52045876e-01,
                         -1.95636064e-01,  -5.37180841e-01,  -2.10159168e-01,
                          1.50053591e-01,   4.12155688e-02,  -1.22909425e-02,
                          5.81839830e-02,   1.72869563e-02,   9.66672823e-02,
                          4.68561836e-02,  -3.72076452e-01,  -4.23279017e-01,
                          2.26186030e-02,   1.49392247e-01,  -1.63043812e-02,
                          2.83582080e-02,   1.09878153e-01,   4.31628339e-02,
                         -6.82160375e-04,   3.81732956e-02,   9.71985906e-02,
                          8.13359991e-02,   2.91056726e-02,   8.00109431e-02,
                          7.33129159e-02,   3.86709496e-02,   1.96291834e-01,
                          5.80994450e-02,  -4.14585501e-01,  -3.58604759e-01,
                          5.06206714e-02,   1.78558797e-01,   9.42301378e-02,
                         -2.38236800e-01,  -4.53681141e-01,  -1.06179647e-01,
                          1.88765913e-01,   1.43153265e-01,   2.21548490e-02,
                         -3.29430103e-01,  -6.76823258e-01,  -4.96547550e-01,
                          5.98212853e-02,   2.67996877e-01,  -2.03310966e-01,
                         -4.92029279e-01,  -7.67946616e-02,   2.14342102e-01,
                          1.02342345e-01,   5.95276095e-02,   7.30421990e-02,
                          5.63205332e-02,   7.42322654e-02,   8.16540197e-02,
                          6.37699440e-02,   6.33964315e-02,   8.76472071e-02,
                          5.55423014e-02,   6.62055984e-02,   1.69334918e-01,
                         -4.72835228e-02,  -4.45279360e-01,  -2.98839122e-01,
                          1.09999083e-01,   8.93337131e-02,   1.23891441e-04,
                          1.67649701e-01,  -1.73016973e-02,  -4.94344801e-01,
                         -2.78695464e-01,   2.76475251e-01,   1.17081543e-02,
                         -4.48587447e-01,  -1.78893790e-01,  -7.08624795e-02,
                         -4.68654364e-01,  -2.41419703e-01,   2.86818504e-01,
                         -7.27259517e-02,  -5.32047451e-01,  -2.11741939e-01,
                          1.18543603e-01,   1.61897883e-01,   6.94434270e-02,
                         -3.70070487e-01,  -4.81258750e-01,   7.01102316e-02,
                          1.86601698e-01,  -2.93057978e-01,  -5.48224509e-01,
                         -6.23958945e-01,  -6.04515791e-01,  -2.38067895e-01,
                         -4.57744971e-02,  -4.40812767e-01,  -7.26866722e-01,
                         -3.97132218e-01,   8.10542256e-02,   1.25618100e-01,
                         -2.72287786e-01,  -5.98311841e-01,  -6.06749713e-01,
                         -5.64945996e-01,  -3.69886965e-01,   5.38737439e-02,
                          7.94518590e-02,  -3.52556109e-01,  -5.85060060e-01,
                         -6.19749129e-01,  -5.94224274e-01,  -2.31934562e-01,
                         -4.55601029e-02,  -5.58467507e-01,  -7.27809310e-01,
                         -1.54972076e-01,  -1.12244375e-01,  -4.41801965e-01,
                         -1.80158034e-01,  -1.37329102e-01,  -4.96060967e-01,
                         -1.57870859e-01,   2.68248707e-01,  -1.75196096e-01,
                         -5.31101942e-01,  -1.47716284e-01,   1.20132245e-01,
                         -2.03996208e-02,   5.65142445e-02,   1.08653672e-01,
                         -3.48059803e-01,  -4.88544106e-01,  -9.39116552e-02,
                         -2.61753500e-01,  -5.54264009e-01,  -1.46539370e-02,
                          1.88233346e-01,  -4.20707226e-01,  -4.28062648e-01,
                         -5.19771054e-02,  -3.55181634e-01,  -4.72466737e-01,
                          8.69880319e-02,   1.00730658e-01,  -4.82238561e-01,
                         -3.96705508e-01,   2.72265729e-02,  -3.84407908e-01,
                         -8.09550941e-01,  -2.77175605e-01,  -1.35189295e-02,
                         -4.70505238e-01,  -3.95117939e-01,   4.03958708e-02,
                          4.95028794e-02,   2.66549643e-02,  -9.37134549e-02,
                         -6.17246270e-01,  -7.34155357e-01,  -1.64390504e-01,
                         -2.56678127e-02,  -6.47444963e-01,  -7.99549401e-01,
                         -1.56980783e-01,  -5.25347032e-02,  -5.80377340e-01,
                         -3.38466942e-01,   2.59749860e-01,  -1.31411090e-01,
                         -5.80847681e-01,  -2.11638674e-01,  -1.86062157e-01,
                         -4.80088234e-01,  -1.87226683e-01,  -1.40087843e-01,
                         -6.33671284e-01,  -7.16086805e-01,  -5.60457408e-01,
                         -5.96658289e-01,  -6.05519950e-01,  -5.80104113e-01,
                         -5.71738362e-01,  -6.27272367e-01,  -5.80755055e-01,
                         -1.28625408e-01,   1.70636728e-01,  -1.75617501e-01,
                         -5.66478729e-01,  -6.43092096e-01,  -6.54050410e-01,
                         -4.96662289e-01,  -5.57411946e-02,   1.52617767e-01,
                         -2.00061932e-01,  -5.94148815e-01,  -6.21697783e-01,
                         -5.36407590e-01,  -6.18857205e-01,  -6.32188082e-01,
                         -1.40568182e-01,   2.41756737e-01,  -2.35984728e-01,
                         -5.28231144e-01,  -1.44961268e-01,  -2.52231270e-01,
                         -5.04067361e-01,  -1.16544440e-01,  -1.30557150e-01,
                         -7.09535956e-01,  -6.40897632e-01,  -5.04301898e-02,
                          9.73464176e-02,  -6.02894388e-02,   9.56478119e-02,
                          1.64674088e-01,  -3.18175912e-01,  -5.44189513e-01,
                         -1.18476965e-01,   1.20808817e-01,  -5.38814440e-03,
                         -3.13326577e-03,   6.87999800e-02,   3.05865705e-02,
                          3.17695527e-03,   4.49579991e-02,   5.82444593e-02,
                          2.26485562e-02,   4.31036726e-02,   9.19677839e-02,
                          8.54101703e-02,   8.02346319e-02,   6.84644431e-02,
                          2.53935363e-02,   3.31088714e-02,   6.71875328e-02,
                          6.91650137e-02,   5.93432821e-02,   2.58200988e-02,
                          1.11851227e-02,   4.48859259e-02,   3.92649174e-02,
                          4.25901376e-02,   8.42548832e-02,   1.12023605e-02,
                         -7.22468179e-03,   1.49442717e-01,  -3.59957144e-02,
                         -4.93193209e-01,  -3.73166382e-01,   8.29621330e-02,
                          7.57890344e-02,  -3.02903564e-03,   1.73729062e-01,
                         -5.71105592e-02,  -5.29575765e-01,  -2.80221850e-01,
                          2.43795455e-01,  -4.22853529e-02,  -5.52366555e-01,
                         -3.22405010e-01,   8.87694806e-02,   6.89545050e-02,
                         -1.46547100e-02,   4.44254503e-02,   5.45540750e-02,
                          5.77740092e-03,   3.37078869e-02,   9.27940458e-02,
                          2.95993779e-02,   2.86250971e-02,   1.27811596e-01,
                         -1.45959318e-01,  -5.01383901e-01,  -1.91880465e-01,
                          1.91999584e-01,  -1.39352202e-01,  -5.96576095e-01,
                         -6.13423049e-01,  -5.58269799e-01,  -6.57534420e-01,
                         -5.72337985e-01,  -1.83307648e-01,   9.10272226e-02,
                          9.59143043e-02,   4.43872996e-02,  -2.35689849e-01,
                         -6.88406408e-01,  -6.57376051e-01,  -1.54100269e-01,
                          1.55190587e-01,  -2.72758305e-02,  -5.24172485e-01,
                         -7.46650100e-01,  -3.68377447e-01,   5.91172688e-02,
                          1.08031832e-01,   3.34901698e-02,   3.90084013e-02,
                          3.44677493e-02,   2.24516187e-02,   1.00082465e-01,
                         -2.01643743e-02,  -5.23735881e-01,  -7.36306787e-01,
                         -3.29879940e-01,   2.01814659e-02,   5.63931316e-02,
                          4.68622558e-02,  -1.57666072e-01,  -6.04160309e-01,
                         -7.21151948e-01,  -2.99764007e-01,   5.41075058e-02,
                          5.15652299e-02,  -3.76759320e-02,  -5.13251461e-02,
                          9.43877622e-02,   5.51244318e-02,  -4.24964130e-01,
                         -5.21660626e-01,  -4.11823019e-02,   1.00394465e-01,
                         -4.24401499e-02,   2.11756062e-02,   6.05753325e-02,
                         -4.98028547e-02,  -4.40764576e-02,   1.31194025e-01,
                         -5.82417240e-03,  -4.30675149e-01,  -3.67600858e-01,
                         -1.68291301e-01,  -4.17666465e-01,  -3.66712332e-01,
                          2.19747517e-02,   6.63834587e-02,  -2.12561525e-02,
                         -2.17860416e-01,  -6.55285895e-01,  -7.22908735e-01,
                         -2.11616695e-01,   1.68920949e-01,  -7.72601813e-02,
                         -5.31143069e-01,  -6.86465979e-01,  -6.46931171e-01,
                         -5.68867147e-01,  -6.22119725e-01,  -7.70507812e-01,
                         -4.80289012e-01,  -7.52568394e-02,  -3.26321065e-01,
                         -7.12818384e-01,  -6.73522353e-01,  -5.89999616e-01,
                         -6.29691660e-01,  -6.50955081e-01,  -6.34955943e-01,
                         -6.05273962e-01,  -6.14925385e-01,  -6.27984524e-01,
                         -6.00112081e-01,  -6.08121991e-01,  -6.48951292e-01,
                         -6.40988171e-01,  -6.09942555e-01,  -6.30243361e-01,
                         -6.68709397e-01,  -6.61068738e-01,  -6.28323138e-01,
                         -6.09450161e-01,  -6.19039237e-01,  -6.29771471e-01,
                         -6.25846267e-01,  -6.41372263e-01,  -6.31258249e-01,
                         -5.90345681e-01,  -6.04397535e-01,  -6.30526721e-01,
                         -6.38213098e-01,  -6.47449911e-01,  -6.21384680e-01,
                         -6.12555683e-01,  -6.24849141e-01,  -6.08386040e-01,
                         -6.29969299e-01,  -6.50265515e-01,  -6.21628881e-01,
                         -6.28783882e-01,  -6.47242069e-01,  -6.39619827e-01,
                         -6.22031212e-01,  -5.95862985e-01,  -6.09750271e-01,
                         -6.32519424e-01,  -6.25501215e-01,  -6.45440519e-01,
                         -6.60208166e-01,  -6.51684463e-01,  -6.48717701e-01,
                         -6.28777027e-01,  -6.20501101e-01,  -6.21113122e-01,
                         -6.24226391e-01,  -6.60516441e-01,  -6.41786993e-01,
                         -5.86401880e-01,  -6.26407564e-01,  -6.57381833e-01,
                         -6.04974806e-01,  -6.05822682e-01,  -6.55637980e-01,
                         -6.49232090e-01,  -6.26010835e-01,  -6.42106593e-01,
                         -6.66066051e-01,  -6.54883385e-01,  -6.14148676e-01,
                         -6.18915617e-01,  -6.54868484e-01,  -6.25051856e-01,
                         -6.72708392e-01,  -7.61349857e-01,  -4.52455342e-01,
                         -9.07020345e-02,  -3.76225650e-01,  -7.72392213e-01,
                         -7.02556908e-01,  -6.16407692e-01,  -6.62513256e-01,
                         -6.30325675e-01,  -6.34258986e-01,  -6.75087392e-01,
                         -6.70496106e-01,  -6.74169421e-01,  -6.57810688e-01,
                         -6.26806855e-01,  -6.57884538e-01,  -6.91211820e-01,
                         -6.53800905e-01,  -6.30356133e-01,  -6.80551529e-01,
                         -6.95174456e-01,  -6.55961156e-01,  -6.53965831e-01,
                         -6.73429728e-01,  -6.85248017e-01,  -6.63630664e-01,
                         -6.31935835e-01,  -6.59112692e-01,  -6.54750764e-01,
                         -6.68258965e-01,  -7.62533545e-01,  -5.46126604e-01,
                         -1.63216695e-01,  -3.08633894e-01,  -6.90539896e-01,
                         -7.21443653e-01,  -6.74831390e-01,  -6.86009586e-01,
                         -6.07792795e-01,  -6.78006530e-01,  -7.95091689e-01,
                         -4.30881977e-01,  -6.13181777e-02,  -5.22977054e-01,
                         -9.27646458e-01,  -3.87233019e-01,  -7.63938278e-02,
                         -5.32522440e-01,  -5.17843604e-01,   2.94332914e-02,
                          2.58780792e-02,  -4.93478835e-01,  -7.54161835e-01,
                         -6.51404798e-01,  -6.72689915e-01,  -7.78664768e-01,
                         -4.36883658e-01,  -9.83215719e-02,  -5.05200148e-01,
                         -8.97103190e-01,  -4.62875277e-01,  -7.99258202e-02,
                         -4.25039828e-01,  -7.51727939e-01,  -7.42445707e-01,
                         -6.68710053e-01,  -3.83669168e-01,  -9.52846278e-03,
                         -8.66644830e-02,  -5.76399267e-01,  -8.48253965e-01,
                         -5.54092288e-01,  -7.19991624e-02,   6.60244152e-02,
                         -3.10201228e-01,  -7.99255610e-01,  -7.17313468e-01,
                         -2.59715796e-01,  -6.78165331e-02,   3.22919451e-02,
                         -4.60983552e-02,  -5.10429084e-01,  -4.87089843e-01,
                         -1.01040594e-01,  -4.52319533e-01,  -9.18634772e-01,
                         -5.12255728e-01,  -3.73086147e-02,  -4.10891801e-01,
                         -9.12953734e-01,  -5.33158123e-01,  -1.05778389e-01,
                         -4.66253966e-01,  -5.75175881e-01,  -1.06913425e-01,
                          6.13468252e-02,  -9.93143246e-02,  -1.44952565e-01,
                          2.08099186e-02,  -7.49413157e-03,  -4.56811696e-01,
                         -6.08729184e-01,  -2.01671228e-01,   3.73284742e-02,
                         -8.94059539e-02,  -1.15037747e-01,  -4.44719084e-02,
                         -6.14297725e-02,  -7.73769170e-02,  -4.49274220e-02,
                         -3.66711877e-02,  -7.32840598e-02,  -2.54390016e-02,
                         -1.11975344e-02,  -4.46765721e-01,  -9.05190527e-01,
                         -5.76217949e-01,  -1.00962132e-01,  -4.13289875e-01,
                         -6.47525251e-01,  -7.45766237e-02,   1.04595333e-01,
                         -4.91584748e-01,  -6.05749011e-01,  -1.09085806e-01,
                          5.07135764e-02,  -7.91659728e-02,   5.89543162e-03,
                          6.17599413e-02,  -3.67156893e-01,  -8.21679711e-01,
                         -6.22802794e-01,  -1.36103496e-01,   3.10004093e-02,
                          4.49627414e-02,  -6.37460500e-02,  -4.92881626e-01,
                         -5.08537889e-01,   7.94276819e-02,   7.12791458e-02,
                         -5.29453874e-01,  -5.27981877e-01,  -7.78958434e-03,
                          1.22129031e-01,  -3.35359186e-01,  -7.45571971e-01,
                         -6.37863457e-01,  -1.74721658e-01,   1.08844690e-01,
                         -1.10714428e-01,  -6.54179573e-01,  -7.79257417e-01,
                         -2.47124940e-01,  -1.20581083e-01,  -4.67251152e-01,
                         -3.21173877e-01,  -1.79773867e-01,  -5.13866961e-01,
                         -7.11006105e-01,  -7.04741359e-01,  -4.15428609e-01,
                         -1.33179908e-03,  -2.72619396e-01,  -8.02181184e-01,
                         -4.88259017e-01,  -1.75288785e-03,  -2.78238177e-01,
                         -7.21170425e-01,  -6.30083680e-01,  -5.37176251e-01,
                         -7.03979731e-01,  -4.11080688e-01,  -2.34870967e-02,
                         -3.19746912e-01,  -6.83472395e-01,  -6.23235226e-01,
                         -5.47120929e-01,  -5.88967383e-01,  -7.06229389e-01,
                         -4.96854901e-01,  -7.44323060e-02,  -2.38969848e-01,
                         -6.43839478e-01,  -6.34280264e-01,  -5.97922623e-01,
                         -6.31063104e-01,  -6.06223464e-01,  -5.89548290e-01,
                         -6.09116793e-01,  -6.18208468e-01,  -5.69138288e-01,
                         -6.14380300e-01,  -6.28158450e-01,  -6.04372382e-01,
                         -5.82571566e-01,  -6.42276824e-01,  -7.09357321e-01,
                         -3.90698463e-01,  -2.95481458e-02,  -3.07292938e-01,
                         -6.84107184e-01,  -6.44678354e-01,  -5.54828346e-01,
                         -6.17716074e-01,  -6.04724109e-01,  -5.80833018e-01,
                         -6.41872287e-01,  -6.06412530e-01,  -5.80914736e-01,
                         -5.94720244e-01,  -5.95903814e-01,  -5.88173509e-01,
                         -6.20357454e-01,  -6.08735681e-01,  -6.12435699e-01,
                         -5.93433499e-01,  -5.90335190e-01,  -6.15048051e-01,
                         -6.04526758e-01,  -6.05646074e-01,  -6.00574374e-01,
                         -5.85426807e-01,  -5.77772260e-01,  -5.96244574e-01,
                         -6.15175843e-01,  -5.86960852e-01,  -5.65339148e-01,
                         -5.90886056e-01,  -5.86654723e-01,  -6.38556421e-01,
                         -5.97842634e-01,  -5.78515530e-01,  -5.80202341e-01,
                         -5.79481781e-01,  -5.80644548e-01,  -5.81678867e-01,
                         -6.32171571e-01,  -6.02709889e-01,  -5.81011653e-01,
                         -6.13318861e-01,  -6.12118959e-01,  -5.89142680e-01,
                         -5.89893281e-01,  -5.87773085e-01,  -6.03679478e-01,
                         -6.01906955e-01,  -6.08199179e-01,  -5.59324622e-01,
                         -5.84199905e-01,  -6.05993867e-01,  -6.13834858e-01,
                         -6.01671100e-01,  -5.87345541e-01,  -6.06369555e-01,
                         -6.05580807e-01,  -6.08491361e-01,  -5.97715437e-01,
                         -6.25838578e-01,  -5.92191219e-01,  -5.85313499e-01,
                         -5.98267019e-01,  -5.89105785e-01,  -5.90836763e-01,
                         -6.09755158e-01,  -5.79638302e-01,  -6.04436934e-01,
                         -6.30947828e-01,  -6.17394447e-01,  -5.54320753e-01,
                         -6.15449548e-01,  -7.10034549e-01,  -4.08321321e-01,
                         -7.07811043e-02,  -3.44109684e-01,  -7.17072785e-01,
                         -6.02489829e-01,  -5.59909284e-01,  -5.94322622e-01,
                         -5.77183008e-01,  -5.83294749e-01,  -6.35000825e-01,
                         -6.18301094e-01,  -5.98159075e-01,  -6.42810941e-01,
                         -5.94677448e-01,  -5.64813912e-01,  -6.97261155e-01,
                         -6.26063883e-01,  -1.85788333e-01,  -8.76521692e-02,
                         -6.56668127e-01,  -6.92361951e-01,  -3.22498530e-02,
                          3.43536474e-02,  -3.83161679e-02,   3.27960588e-02,
                         -1.64923761e-02,  -1.08238431e-02,   1.27079878e-02,
                          4.76097735e-03,   5.01488522e-02,   2.70576440e-02,
                         -3.35933967e-03,   2.19074413e-02,   1.12532480e-02,
                          2.09537111e-02,   2.35596616e-02,   1.98422503e-02,
                          1.18271983e-03,   1.03956712e-02,   1.08177429e-02,
                          7.05604535e-03,  -1.12570617e-02,   2.00656503e-02,
                         -6.76435372e-03,   9.27185174e-03,   1.69084910e-02,
                          2.11946410e-03,  -6.09552395e-03,  -4.65340400e-03,
                          1.55376736e-02,  -2.85653193e-02,  -3.79859586e-03,
                          6.18276699e-03,   6.27940230e-04,   1.07626449e-02,
                          1.01410458e-02,  -1.11385183e-02,   5.80603629e-03,
                          8.56415927e-03,   1.31107839e-02,   1.21803815e-02,
                          2.91032791e-02,   1.44223887e-02,   2.01239958e-02,
                         -1.96380317e-02,  -2.55059991e-02,   2.68941913e-02,
                          8.07917677e-03,   2.39246618e-02,  -9.39836539e-03,
                         -2.00287509e-03,   7.23741669e-03,  -7.60668796e-03,
                         -5.42248366e-03,   1.94323920e-02,   4.61541861e-03,
                         -2.39753304e-03,  -1.17297163e-02,  -9.82510671e-03,
                          1.53548922e-02,   1.88572723e-02,   1.63160823e-03,
                          2.82536112e-02,   1.92014184e-02,  -5.35435835e-03,
                          1.48093160e-02,   1.95833948e-03,   1.71153434e-02,
                         -2.30231341e-02,  -1.49341475e-03,   4.26586065e-03,
                         -1.95586029e-02,   1.59149163e-03,   1.59683730e-02,
                         -2.37795524e-03,  -1.16243167e-03,  -1.22670606e-02,
                         -1.33846849e-02,   3.72528890e-03,  -1.10429386e-03,
                          1.10621303e-02,  -8.17873701e-03,  -1.76184624e-02,
                          2.53205956e-03,   4.32352815e-03,   1.07262367e-02,
                          2.32686605e-02,  -1.85991582e-02,   1.78485475e-02,
                          1.67308711e-02,   1.19141908e-02,  -7.38543051e-04,
                         -1.67032704e-02,   1.11149922e-02,  -1.12273712e-02,
                         -1.46080958e-04,   1.05576422e-02,  -1.34027167e-03,
                          1.60591267e-02,  -1.65530213e-03,  -2.54666433e-02,
                          1.20193195e-02,   1.23309018e-02,   1.97110558e-03,
                         -1.76631436e-02,  -1.90783218e-02,  -1.40906433e-02,
                         -2.36565899e-03,  -8.93865433e-03,  -2.16462668e-05,
                          2.12362199e-03,  -9.13459901e-03,   2.62092194e-03,
                          4.52053850e-04,   1.75688916e-03,   4.90005873e-03,
                          8.35559424e-03,  -6.02037832e-03,   2.26111547e-03,
                         -1.11507520e-03,   5.44992788e-03,   1.17152687e-02,
                          3.82131810e-04,   3.55283963e-03,   3.86573910e-03,
                         -6.31530862e-03,   9.37049277e-03,   1.44752092e-03,
                         -2.69197230e-03,  -1.30840810e-03,  -2.96309381e-03,
                          7.66847190e-03,  -6.16055680e-03],
                          dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri7",
    rate = 41000,
    data = numpy.array([ -4.54902016e-02,  -3.86573561e-02,  -2.28472501e-02,
                         -3.72897722e-02,  -2.58920677e-02,   2.38018297e-03,
                         -2.08662450e-02,  -3.93294170e-02,  -2.87239440e-02,
                         -1.36571508e-02,  -1.26393968e-02,  -4.88746464e-02,
                         -5.24868257e-02,  -1.55656561e-02,  -2.77017187e-02,
                         -5.49596064e-02,  -3.94673832e-02,  -1.52151976e-02,
                         -2.23438609e-02,  -4.68024388e-02,  -3.28892544e-02,
                         -4.88014705e-03,  -3.20575722e-02,  -5.93665019e-02,
                         -2.09933519e-02,   4.54229256e-03,  -3.11645288e-02,
                         -4.84527759e-02,  -4.24732529e-02,  -5.06220758e-02,
                         -3.48328426e-02,  -2.80817430e-02,  -4.44717258e-02,
                         -3.24555598e-02,  -3.70245166e-02,  -3.28553095e-02,
                         -7.70962005e-03,  -4.51821461e-02,  -2.80024018e-02,
                          1.93319586e-03,  -9.91520733e-02,  -1.91377439e-02,
                          1.03902206e-01,  -2.92153984e-01,  -6.40988469e-01,
                         -2.85878479e-01,   8.07978883e-02,  -5.69353346e-03,
                         -7.34175891e-02,   1.83416239e-03,  -8.39130580e-03,
                         -4.18944657e-02,  -2.03102957e-02,  -6.10674396e-02,
                         -8.77678916e-02,   7.36026317e-02,   5.18069603e-03,
                         -4.82660413e-01,  -5.08308411e-01,  -1.09004736e-01,
                         -3.91462743e-01,  -8.58856380e-01,  -6.92293167e-01,
                         -6.60881698e-01,  -8.24968398e-01,  -4.36225682e-01,
                          1.98651161e-02,  -2.84437952e-03,  -9.50862914e-02,
                          4.27046744e-03,  -3.94925699e-02,  -5.20693660e-01,
                         -8.70967507e-01,  -5.16182899e-01,  -8.97782817e-02,
                          7.87873846e-03,   9.07879397e-02,  -1.54468745e-01,
                         -5.97829878e-01,  -3.86896819e-01,   5.98750599e-02,
                          1.60458602e-03,  -1.08231701e-01,  -4.28365543e-03,
                          7.83548970e-03,  -4.27809805e-02,  -1.15310447e-02,
                          5.76686226e-02,  -1.03591554e-01,  -6.12123370e-01,
                         -8.40974152e-01,  -4.18437749e-01,  -1.34560177e-02,
                          2.07304899e-02,   2.06799619e-03,  -1.78926423e-01,
                         -6.52585924e-01,  -8.41791034e-01,  -4.01677698e-01,
                          4.99556214e-02,  -1.97142293e-03,  -7.64249414e-02,
                          8.65511596e-02,  -1.47700816e-01,  -5.72911739e-01,
                         -3.26863885e-01,  -1.01572089e-01,  -6.79353118e-01,
                         -9.09140766e-01,  -2.51100034e-01,  -4.41245139e-02,
                         -6.60622060e-01,  -8.54294300e-01,  -2.92340398e-01,
                         -1.37809694e-01,  -6.12935007e-01,  -4.38266784e-01,
                          2.03359231e-01,  -9.60382596e-02,  -6.08884513e-01,
                         -2.85801977e-01,  -2.29076281e-01,  -5.91075361e-01,
                         -3.10983002e-01,  -1.38269112e-01,  -7.14789152e-01,
                         -8.53790522e-01,  -2.32837453e-01,   1.39771014e-01,
                         -1.13144562e-01,  -5.59236407e-01,  -7.51072764e-01,
                         -7.07846999e-01,  -6.98233843e-01,  -7.16188192e-01,
                         -7.09709287e-01,  -7.16383457e-01,  -6.86648071e-01,
                         -6.77559137e-01,  -7.22321451e-01,  -7.21664429e-01,
                         -7.11676419e-01,  -7.03367233e-01,  -6.72619939e-01,
                         -7.14236617e-01,  -7.49260187e-01,  -6.88895226e-01,
                         -6.74680531e-01,  -7.07057714e-01,  -7.06451297e-01,
                         -7.22562075e-01,  -7.36517191e-01,  -7.27609396e-01,
                         -7.19554424e-01,  -6.92234874e-01,  -6.91896856e-01,
                         -7.32663870e-01,  -7.40406334e-01,  -7.22778440e-01,
                         -7.08477020e-01,  -6.98342383e-01,  -6.99551940e-01,
                         -7.04883158e-01,  -7.31637478e-01,  -7.41229832e-01,
                         -6.96652293e-01,  -7.09237754e-01,  -7.74218321e-01,
                         -7.51484454e-01,  -6.88534081e-01,  -6.86252356e-01,
                         -7.19968140e-01,  -7.41557300e-01,  -7.31687844e-01,
                         -7.18841076e-01,  -7.17165053e-01,  -7.18088627e-01,
                         -7.38812268e-01,  -7.30278492e-01,  -6.88431084e-01,
                         -7.14946032e-01,  -7.70233274e-01,  -7.66135275e-01,
                         -7.37958610e-01,  -7.27430165e-01,  -7.30668008e-01,
                         -6.86868966e-01,  -6.83260500e-01,  -8.50271404e-01,
                         -7.65992641e-01,  -2.58501768e-01,  -1.96301773e-01,
                         -7.23287761e-01,  -8.39818358e-01,  -6.30211115e-01,
                         -7.78392851e-01,  -7.39130795e-01,  -2.32951567e-01,
                         -2.25456193e-01,  -8.02379251e-01,  -8.39611292e-01,
                         -2.51100779e-01,  -1.60125405e-01,  -7.45634794e-01,
                         -8.79272997e-01,  -2.88920820e-01,  -1.40471369e-01,
                         -7.33409107e-01,  -8.84209216e-01,  -3.09755862e-01,
                         -1.38958335e-01,  -6.44862175e-01,  -8.78065407e-01,
                         -6.87848270e-01,  -7.57001996e-01,  -8.05961132e-01,
                         -3.17845017e-01,  -1.49183139e-01,  -7.56070614e-01,
                         -9.07295942e-01,  -2.70260632e-01,  -1.36055365e-01,
                         -6.83881104e-01,  -8.83904099e-01,  -7.00845182e-01,
                         -7.06228018e-01,  -7.84284055e-01,  -7.46977210e-01,
                         -7.29776561e-01,  -7.28882432e-01,  -7.47714043e-01,
                         -7.73249686e-01,  -7.09564328e-01,  -7.46623278e-01,
                         -7.80975461e-01,  -4.22623605e-01,  -1.97412312e-01,
                         -5.73715091e-01,  -8.48572671e-01,  -7.39677727e-01,
                         -7.16198325e-01,  -7.91262329e-01,  -7.87668645e-01,
                         -5.68494260e-01,  -9.39070731e-02,   6.13875091e-02,
                         -4.03009474e-01,  -7.92956173e-01,  -7.36701369e-01,
                         -7.29882717e-01,  -8.54179382e-01,  -5.90217173e-01,
                         -1.87427774e-01,  -3.75254899e-01,  -7.96281338e-01,
                         -7.88542807e-01,  -6.85406685e-01,  -7.75395930e-01,
                         -7.66841352e-01,  -6.90041900e-01,  -7.51678586e-01,
                         -7.72902310e-01,  -6.89345956e-01,  -7.79191315e-01,
                         -8.35237205e-01,  -4.56355006e-01,  -1.95463568e-01,
                         -4.92915303e-01,  -7.75481403e-01,  -8.37855041e-01,
                         -7.15377092e-01,  -2.50470489e-01,  -2.01305389e-01,
                         -8.44536841e-01,  -8.75718713e-01,  -1.77588060e-01,
                         -1.62877724e-01,  -8.15096855e-01,  -8.47589970e-01,
                         -2.52750665e-01,  -1.79027542e-01,  -6.75357640e-01,
                         -8.35616529e-01,  -6.86487973e-01,  -7.19519317e-01,
                         -7.97526956e-01,  -7.29998291e-01,  -6.69385612e-01,
                         -8.02445710e-01,  -8.01585257e-01,  -2.93147504e-01,
                         -1.05842903e-01,  -7.29519427e-01,  -9.07943964e-01,
                         -2.94978797e-01,  -1.54936343e-01,  -6.40205383e-01,
                         -8.24010193e-01,  -6.59655809e-01,  -7.34213352e-01,
                         -8.22563827e-01,  -3.61940742e-01,   9.04279351e-02,
                         -1.19353227e-01,  -5.70995867e-01,  -8.22878778e-01,
                         -6.57633364e-01,  -2.04931378e-01,  -2.79085219e-01,
                         -7.47219145e-01,  -7.55111992e-01,  -6.27268434e-01,
                         -7.07391620e-01,  -6.63822889e-01,  -6.38430297e-01,
                         -6.92808867e-01,  -6.56011045e-01,  -7.27863431e-01,
                         -7.13079095e-01,  -2.42415845e-01,   1.71116650e-01,
                         -7.09639043e-02,  -5.77403545e-01,  -7.11656511e-01,
                         -6.34846687e-01,  -6.94170296e-01,  -6.99318647e-01,
                         -6.35804832e-01,  -7.26403713e-01,  -6.84428096e-01,
                         -2.51010954e-01,   1.54543102e-01,  -2.54795334e-04,
                         -6.12298548e-01,  -8.92541409e-01,  -4.22859013e-01,
                         -2.54004281e-02,  -4.43838537e-01,  -8.64749312e-01,
                         -4.48876858e-01,  -6.40199259e-02,  -4.56271589e-01,
                         -7.65930474e-01,  -5.91052532e-01,  -6.40685737e-01,
                         -7.75801957e-01,  -4.03897673e-01,  -8.50753635e-02,
                         -4.68420982e-01,  -8.63070607e-01,  -4.65844899e-01,
                          4.96235304e-03,  -3.99655133e-01,  -8.97517443e-01,
                         -4.98961300e-01,  -2.88028475e-02,  -3.66335154e-01,
                         -7.83508182e-01,  -6.92854702e-01,  -6.07464433e-01,
                         -7.09302783e-01,  -7.05147922e-01,  -6.72872722e-01,
                         -6.84561908e-01,  -6.64762735e-01,  -6.72726393e-01,
                         -6.67714000e-01,  -6.68355763e-01,  -7.00314820e-01,
                         -6.39321983e-01,  -7.03641117e-01,  -7.77833164e-01,
                         -3.60646456e-01,  -1.32931024e-01,  -5.00533521e-01,
                         -3.74432266e-01,  -5.79408780e-02,  -6.11639977e-01,
                         -8.78807247e-01,  -2.23796412e-01,  -1.41576111e-01,
                         -5.86137772e-01,  -3.03401023e-01,  -7.13012442e-02,
                         -6.95766032e-01,  -8.56968999e-01,  -1.76595137e-01,
                         -1.44537404e-01,  -6.42182052e-01,  -2.99028695e-01,
                          2.17860281e-01,  -2.37796500e-01,  -6.28759265e-01,
                         -2.15490952e-01,  -2.11129516e-01,  -6.36114299e-01,
                         -1.95936754e-01,   2.73241252e-01,  -3.35918486e-01,
                         -6.18903160e-01,  -1.58159673e-01,  -3.18680674e-01,
                         -5.61698079e-01,  -1.40954822e-01,  -2.76009738e-01,
                         -8.99955809e-01,  -6.17646456e-01,  -2.49800868e-02,
                         -3.22151899e-01,  -7.88514733e-01,  -6.62965477e-01,
                         -6.50399864e-01,  -8.35564256e-01,  -4.41936284e-01,
                         -7.82057345e-02,  -4.65943485e-01,  -5.47507524e-01,
                          5.70252314e-02,   1.27035081e-01,  -4.74257320e-01,
                         -7.60787249e-01,  -6.54842675e-01,  -6.64730549e-01,
                         -7.08522975e-01,  -6.40953183e-01,  -7.40612209e-01,
                         -7.74089038e-01,  -3.22768837e-01,  -8.83529410e-02,
                         -5.46537340e-01,  -8.02531004e-01,  -6.15886927e-01,
                         -7.15400815e-01,  -7.73184359e-01,  -2.46596992e-01,
                         -5.56353964e-02,  -6.76400483e-01,  -8.46071184e-01,
                         -2.09244296e-01,  -7.37674534e-02,  -5.92502356e-01,
                         -7.72677004e-01,  -6.57707274e-01,  -6.87669873e-01,
                         -7.02600539e-01,  -6.66031063e-01,  -6.90392017e-01,
                         -6.96278453e-01,  -6.80226862e-01,  -6.86970115e-01,
                         -6.82923138e-01,  -6.67201221e-01,  -6.69090390e-01,
                         -6.76683187e-01,  -6.66037023e-01,  -6.68120265e-01,
                         -6.63320780e-01,  -6.27685547e-01,  -7.04916537e-01,
                         -7.54455149e-01,  -3.60374421e-01,   1.37959629e-01,
                          1.12241488e-02,  -5.07440150e-01,  -7.44610250e-01,
                         -6.88708007e-01,  -6.41274035e-01,  -6.81237757e-01,
                         -7.12021291e-01,  -6.63186371e-01,  -6.66671753e-01,
                         -7.16278911e-01,  -4.67361093e-01,  -2.32255571e-02,
                          7.65263662e-02,  -4.78825495e-02,  -1.11491438e-02,
                          2.77429782e-02,   2.22057924e-02,   4.02681753e-02,
                         -3.62302288e-02,   2.93291640e-02,   1.22583300e-01,
                         -2.78508633e-01,  -5.87245822e-01,  -2.20719576e-01,
                          1.11917958e-01,   3.96668315e-02,  -7.21409470e-02,
                         -1.21340966e-02,   1.15350887e-01,  -1.61488265e-01,
                         -6.03981793e-01,  -3.45031172e-01,   1.29124612e-01,
                          3.65086943e-02,  -8.88498351e-02,   2.97737811e-02,
                          4.39544544e-02,   1.15278885e-02,   1.15647558e-02,
                         -1.85671903e-03,   8.56655743e-03,  -4.55566030e-03,
                         -7.69902719e-03,   3.09130587e-02,   2.06131805e-02,
                          7.38493050e-04,   2.42807087e-03,  -1.15105771e-02,
                          1.28124468e-03,   1.38533078e-02,   8.16725660e-03,
                          1.73120294e-02,  -8.64603370e-03,  -3.06741819e-02,
                         -1.24213230e-02,  -3.64103890e-03,   3.10531501e-02,
                          2.26000827e-02,  -1.73244085e-02,   4.50058505e-02,
                          3.96949146e-03,  -5.93178645e-02,   1.21236756e-01,
                         -1.57967042e-02,  -5.40452778e-01,  -5.06924331e-01,
                         -1.11198137e-02,   1.10964336e-01,  -3.71498391e-02,
                         -3.11973412e-02,   3.86788808e-02,   9.60002840e-03,
                         -6.77465554e-03,   1.83513071e-02,  -4.24534604e-02,
                         -2.19264184e-03,   1.21881150e-01,  -1.93284988e-01,
                         -6.19908333e-01,  -3.40771377e-01,   1.06487967e-01,
                          1.21771097e-02,  -1.74485259e-02,   1.30136088e-01,
                         -2.38301918e-01,  -6.02420628e-01,  -2.52251476e-01,
                          1.26569927e-01,   5.03080934e-02,  -7.40371272e-02,
                         -2.27483865e-02,   9.01103392e-02,  -7.39200190e-02,
                         -5.61329603e-01,  -7.58605480e-01,  -6.14361584e-01,
                         -7.12282300e-01,  -7.57091582e-01,  -2.69943088e-01,
                         -6.11309633e-02,  -6.54601932e-01,  -8.72916639e-01,
                         -2.37771884e-01,  -8.11321288e-02,  -5.68221569e-01,
                         -3.91748428e-01,   1.93102419e-01,   1.55264968e-02,
                         -5.40627182e-01,  -7.28397191e-01,  -7.74561286e-01,
                         -6.34089410e-01,  -1.67766437e-01,  -1.70670539e-01,
                         -7.62761354e-01,  -7.50247777e-01,  -1.07137911e-01,
                         -1.29380152e-01,  -7.20320821e-01,  -7.66263783e-01,
                         -5.84808588e-01,  -8.01653087e-01,  -6.57908678e-01,
                         -6.28651679e-02,  -1.75010413e-01,  -8.11957419e-01,
                         -7.36454785e-01,  -1.33587837e-01,  -1.67017445e-01,
                         -6.92407250e-01,  -6.98624194e-01,  -5.60519278e-01,
                         -8.00712049e-01,  -5.51473379e-01,  -7.02854395e-02,
                         -3.69103730e-01,  -5.14672101e-01,  -8.86141062e-02,
                         -3.58069986e-01,  -9.38089311e-01,  -5.75015903e-01,
                         -3.02451905e-02,  -3.19952577e-01,  -7.56147146e-01,
                         -6.96013272e-01,  -6.38258278e-01,  -7.73103476e-01,
                         -5.56131005e-01,   1.51495496e-02,   1.41744897e-01,
                         -3.98278058e-01,  -6.22936130e-01,  -1.01345666e-01,
                          1.79145232e-01,  -2.39599094e-01,  -7.12641299e-01,
                         -7.76416481e-01,  -3.44198763e-01,   1.61082581e-01,
                         -2.19175778e-02,  -5.89959085e-01,  -4.76088434e-01,
                          1.15679920e-01,   2.38122996e-02,  -5.71982145e-01,
                         -4.98264998e-01,   6.81959093e-02,   9.23463777e-02,
                         -4.05920923e-01,  -7.82081187e-01,  -6.89023077e-01,
                         -1.35327175e-01,   2.10098639e-01,  -2.08140850e-01,
                         -5.96083581e-01,  -2.57983804e-01,   8.27285126e-02,
                          4.34823819e-02,  -4.11027707e-02,  -3.49624187e-01,
                         -7.19554186e-01,  -6.99839950e-01,  -6.53447449e-01,
                         -7.16007590e-01,  -6.47498369e-01,  -6.95175231e-01,
                         -7.53149688e-01,  -4.00797486e-01,   2.82657240e-02,
                          4.32283171e-02,  -6.66065365e-02,   4.71535362e-02,
                         -5.60257211e-02,  -5.53688765e-01,  -7.92428076e-01,
                         -6.69047534e-01,  -6.51589215e-01,  -7.30881393e-01,
                         -6.86332166e-01,  -5.98464608e-01,  -7.33811557e-01,
                         -8.06792259e-01,  -3.33008856e-01,  -8.17129016e-02,
                         -5.27506232e-01,  -4.46776301e-01,   1.80967331e-01,
                         -3.57294343e-02,  -6.31404102e-01,  -4.21150148e-01,
                          1.85357369e-02,   3.62274088e-02,  -1.19891753e-02,
                         -2.43076831e-01,  -7.90954173e-01,  -7.99742162e-01,
                         -1.81786895e-01,  -1.23994119e-01,  -6.69095278e-01,
                         -7.69265711e-01,  -5.98585904e-01,  -7.67075419e-01,
                         -6.73468947e-01,  -1.70660585e-01,  -2.39485458e-01,
                         -7.39441276e-01,  -7.60558009e-01,  -6.23901188e-01,
                         -7.72575140e-01,  -6.42963827e-01,  -1.18141860e-01,
                          6.78854063e-02,  -9.72031280e-02,   3.31217423e-02,
                          1.06132746e-01,  -3.90243918e-01,  -6.01905346e-01,
                         -1.29273579e-01,   1.06209479e-01,  -4.36782911e-02,
                         -4.37007695e-02,   1.40309082e-02,   1.75173525e-02,
                          3.26270908e-02,  -1.34520521e-02,  -7.72526814e-03,
                          1.77676994e-02,  -6.39974251e-02,   2.52219178e-02,
                          6.49191067e-02,  -3.88766259e-01,  -6.12878799e-01,
                         -1.80834353e-01,   1.01050310e-01,   4.45527863e-03,
                         -7.35918954e-02,  -4.40850295e-03,   9.35191289e-02,
                         -2.07931191e-01,  -6.20649517e-01,  -3.50292683e-01,
                          7.71544352e-02,   4.24169842e-03,  -7.50568733e-02,
                          3.88882905e-02,   3.21855061e-02,  -6.91373721e-02,
                         -2.19367519e-02,   3.74373235e-02,  -2.98000515e-01,
                         -5.93596458e-01,  -2.54261762e-01,   8.23091567e-02,
                         -1.40739204e-02,  -4.70552780e-02,   3.25057246e-02,
                         -1.19411864e-03,  -3.35541479e-02,  -3.62765999e-03,
                          9.75229684e-03,  -1.15421880e-02,  -1.25810727e-02,
                         -6.66482653e-03,  -1.80113856e-02,  -4.72764298e-03,
                         -2.99265888e-02,  -6.98840842e-02,  -2.60689035e-02,
                         -1.33766765e-02,  -3.18231545e-02,  -1.32111302e-02,
                         -3.02170161e-02,   2.44313143e-02,   2.96872966e-02,
                         -3.65586489e-01,  -7.71042824e-01,  -7.08908617e-01,
                         -6.22338116e-01,  -7.76194811e-01,  -6.37601972e-01,
                         -1.13151401e-01,   1.27534822e-01,  -2.37537280e-01,
                         -7.58859992e-01,  -8.10797989e-01,  -3.12913239e-01,
                          9.07123834e-02,   1.32733514e-03,  -5.53512461e-02,
                          9.74017456e-02,  -1.87433735e-01,  -6.20287538e-01,
                         -3.26836735e-01,   1.05851397e-01,  -3.49056125e-02,
                         -6.43927753e-02,   1.13371260e-01,  -2.57242769e-01,
                         -6.61651313e-01,  -2.38804221e-01,   2.26701126e-01,
                         -1.92493707e-01,  -6.66506410e-01,  -3.11802804e-01,
                          1.17493391e-01,   1.24826124e-02,  -8.17379281e-02,
                          1.09730605e-02,   3.73562402e-03,  -3.38023715e-02,
                         -1.72626823e-02,   2.13445295e-04,   2.34941463e-03,
                         -1.21615846e-02,  -6.45953696e-03,   1.99800115e-02,
                          1.54926274e-02,  -4.55686077e-02,  -3.07227653e-02,
                          8.25316235e-02,  -1.38294414e-01,  -5.65521121e-01,
                         -4.00675565e-01,   7.59461075e-02,   9.90828946e-02,
                         -4.12733965e-02,   1.02327475e-02,   3.91742364e-02,
                         -4.35469858e-02,  -2.55933274e-02,   1.24369130e-01,
                         -1.08543642e-01,  -6.06325328e-01,  -4.07219023e-01,
                          1.00577034e-01,  -1.04492484e-02,  -8.71535316e-02,
                          1.15250267e-01,  -2.38338068e-01,  -6.22097492e-01,
                         -2.42035642e-01,  -1.17276579e-01,  -7.41155326e-01,
                         -7.92652130e-01,  -1.45543844e-01,  -1.51899725e-01,
                         -6.67066872e-01,  -7.41629422e-01,  -6.33080184e-01,
                         -6.95477247e-01,  -7.21746624e-01,  -6.92483723e-01,
                         -6.87642455e-01,  -6.92327857e-01,  -6.72211766e-01,
                         -6.59909964e-01,  -7.14895248e-01,  -7.14743197e-01,
                         -6.52077913e-01,  -6.74391448e-01,  -7.02678204e-01,
                         -6.81523681e-01,  -6.69462323e-01,  -6.60096347e-01,
                         -6.81619048e-01,  -6.92314506e-01,  -6.56387329e-01,
                         -6.63226545e-01,  -6.95339978e-01,  -6.94723070e-01,
                         -6.74493253e-01,  -6.56858027e-01,  -6.72729850e-01,
                         -6.85105145e-01,  -6.72937036e-01,  -6.79222584e-01,
                         -6.92743957e-01,  -7.01779783e-01,  -6.94837213e-01,
                         -6.81207895e-01,  -7.03180134e-01,  -6.99426591e-01,
                         -6.52524292e-01,  -6.49040461e-01,  -6.71022475e-01,
                         -6.74203336e-01,  -6.85952008e-01,  -7.07687855e-01,
                         -6.86512232e-01,  -6.41776860e-01,  -6.68146312e-01,
                         -7.00534880e-01,  -6.63367987e-01,  -6.61027908e-01,
                         -6.88976049e-01,  -6.95996761e-01,  -7.13016391e-01,
                         -6.81321204e-01,  -6.33832574e-01,  -6.61138892e-01,
                         -6.76735520e-01,  -6.56622589e-01,  -6.66349649e-01,
                         -6.75568461e-01,  -6.75120533e-01,  -6.93471909e-01,
                         -6.97982013e-01,  -6.78264439e-01,  -6.78506672e-01,
                         -6.71213746e-01,  -6.41714275e-01,  -6.67683721e-01,
                         -6.97161257e-01,  -6.63313627e-01,  -6.62223220e-01,
                         -6.87517822e-01,  -6.70744419e-01,  -6.54460192e-01,
                         -6.69543266e-01,  -6.88153803e-01,  -6.65745318e-01,
                         -6.55750513e-01,  -6.86884105e-01,  -6.64462686e-01,
                         -6.48766816e-01,  -6.71228349e-01,  -6.83169007e-01,
                         -7.27392435e-01,  -6.67115271e-01,  -6.46691859e-01,
                         -7.92768598e-01,  -5.08782387e-01,  -1.25756398e-01,
                         -4.02796030e-01,  -4.66662019e-01,  -1.02031052e-01,
                         -3.45720708e-01,  -7.76194274e-01,  -7.07194805e-01,
                         -6.14593685e-01,  -6.93764329e-01,  -7.04114079e-01,
                         -6.24853075e-01,  -6.83945835e-01,  -7.83390880e-01,
                         -4.12853688e-01,  -5.53406999e-02,  -4.34784979e-01,
                         -7.90877044e-01,  -6.60461307e-01,  -6.43660128e-01,
                         -6.79610074e-01,  -6.25135422e-01,  -7.88956702e-01,
                         -7.30083525e-01,  -1.88024491e-01,  -1.04073331e-01,
                         -6.26415670e-01,  -7.43397176e-01,  -6.05973840e-01,
                         -8.02107215e-01,  -6.27616227e-01,  -9.35519412e-02,
                         -2.88743377e-01,  -6.33701265e-01,  -1.12422906e-01,
                          2.15539962e-01,  -3.58073384e-01,  -5.76914728e-01,
                         -1.21815942e-01,  -2.16054797e-01,  -8.10945868e-01,
                         -6.90104663e-01,  -6.51869029e-02,  -1.97799116e-01,
                         -8.39424729e-01,  -7.20866382e-01,  -1.47296980e-01,
                         -2.04716384e-01,  -5.89804232e-01,  -7.39594460e-01,
                         -7.48877227e-01,  -4.25439000e-01,  -3.92334498e-02,
                         -3.92256021e-01,  -8.73191595e-01,  -4.76835191e-01,
                         -2.72264462e-02,  -4.10756230e-01,  -7.97341645e-01,
                         -6.47482276e-01,  -6.45191908e-01,  -7.78599024e-01,
                         -4.00263995e-01,  -2.49290764e-02,  -4.31576729e-01,
                         -8.54296923e-01,  -4.35335964e-01,  -2.50291433e-02,
                         -3.83201659e-01,  -7.71080613e-01,  -6.97241068e-01,
                         -5.62905908e-01,  -6.39712036e-01,  -7.82049060e-01,
                         -5.21866918e-01,  -8.11086595e-02,  -3.14294279e-01,
                         -5.61392009e-01,   3.33275497e-02,   2.29636893e-01,
                         -4.34056610e-01,  -5.11696994e-01,  -6.02275208e-02,
                         -2.87308663e-01,  -7.60712206e-01,  -6.84117377e-01,
                         -6.18043542e-01,  -7.64110565e-01,  -4.11681235e-01,
                          8.35785293e-04,  -4.41935033e-01,  -8.88516665e-01,
                         -4.27207172e-01,  -8.49397331e-02,  -4.48432744e-01,
                         -4.10211146e-01,  -3.77381630e-02,  -4.85411853e-01,
                         -8.85690033e-01,  -3.00519437e-01,  -9.45285931e-02,
                         -4.96407449e-01,  -2.99850017e-01,  -1.47947147e-01,
                         -5.15762329e-01,  -3.03173453e-01,   2.02311963e-01,
                         -6.07452877e-02,  -6.17150307e-01,  -7.05850184e-01,
                         -5.79013884e-01,  -6.86244011e-01,  -7.04672277e-01,
                         -2.66980618e-01,  -8.76314417e-02,  -5.79966128e-01,
                         -8.17396641e-01,  -3.46802205e-01,   1.39457539e-01,
                          7.35527277e-02,  -4.07697797e-01,  -7.19520748e-01,
                         -6.64142728e-01,  -6.21800661e-01,  -6.60113990e-01,
                         -6.40606463e-01,  -6.61432922e-01,  -6.84650600e-01,
                         -6.63287163e-01,  -6.57808602e-01,  -6.14506721e-01,
                         -6.13770187e-01,  -6.69769645e-01,  -6.27502978e-01,
                         -6.74366474e-01,  -7.44890511e-01,  -3.77032757e-01,
                         -5.08823767e-02,  -4.20051336e-01,  -7.84236908e-01,
                         -6.50131941e-01,  -6.08914495e-01,  -6.82044685e-01,
                         -6.13006711e-01,  -7.13608801e-01,  -6.72358096e-01,
                         -1.75973356e-01,  -1.30336210e-01,  -6.68812454e-01,
                         -7.44554043e-01,  -5.43613434e-01,  -7.08663464e-01,
                         -6.12216532e-01,  -1.33674562e-01,  -2.12603465e-01,
                         -6.93262517e-01,  -7.48600066e-01,  -6.13871515e-01,
                         -6.69786036e-01,  -6.67347908e-01,  -6.02327108e-01,
                         -6.31752789e-01,  -6.56395793e-01,  -6.49670243e-01,
                         -6.41331136e-01,  -6.49650395e-01,  -6.89705908e-01,
                         -6.65897071e-01,  -6.27347350e-01,  -6.51623607e-01,
                         -6.47124410e-01,  -6.71163499e-01,  -6.88737571e-01,
                         -6.27516508e-01,  -7.20656753e-01,  -7.04265893e-01,
                         -2.43017778e-01,  -7.45432973e-02,  -5.08729935e-01,
                         -7.38296628e-01,  -6.47594452e-01,  -6.75313175e-01,
                         -6.95488930e-01,  -6.31417215e-01,  -6.52121425e-01,
                         -6.72021866e-01,  -6.29313588e-01,  -6.33640170e-01,
                         -6.63545430e-01,  -6.49919152e-01,  -6.49151325e-01,
                         -6.74915314e-01,  -6.62700117e-01,  -6.51841223e-01,
                         -6.79119766e-01,  -6.70500159e-01,  -6.43935561e-01,
                         -6.62619710e-01,  -6.58441544e-01,  -6.23461127e-01,
                         -6.51369095e-01,  -6.91895902e-01,  -6.67868853e-01,
                         -6.56753778e-01,  -6.73165679e-01,  -6.59801543e-01,
                         -6.71956062e-01,  -7.02483475e-01,  -6.75639510e-01,
                         -6.47340178e-01,  -6.41947389e-01,  -6.34694755e-01,
                         -6.72510803e-01,  -6.97463930e-01,  -6.55771494e-01,
                         -6.54681265e-01,  -6.93768322e-01,  -6.81663334e-01,
                         -6.49631202e-01,  -6.47636652e-01,  -6.63267612e-01,
                         -6.73589528e-01,  -6.81588233e-01,  -6.87196374e-01,
                         -6.63745165e-01,  -6.52116954e-01,  -6.77256286e-01,
                         -6.57129705e-01,  -6.19536817e-01,  -6.48107290e-01,
                         -6.78500652e-01,  -6.76199257e-01,  -6.86253667e-01,
                         -6.93991601e-01,  -6.81906104e-01,  -6.61885142e-01,
                         -6.59672379e-01,  -6.99623704e-01,  -7.24468946e-01,
                         -6.90248072e-01,  -6.77477896e-01,  -7.04655707e-01,
                         -6.76751792e-01,  -6.28885388e-01,  -6.55661821e-01,
                         -6.88692033e-01,  -6.91747785e-01,  -7.17649281e-01,
                         -7.05509424e-01,  -6.62038147e-01,  -6.94040656e-01,
                         -7.23337710e-01,  -6.64867103e-01,  -6.17094696e-01,
                         -6.37212932e-01,  -6.68612957e-01,  -6.77500367e-01,
                         -7.04909861e-01,  -7.46968508e-01,  -7.29776204e-01,
                         -6.83640540e-01,  -6.59496069e-01,  -6.40842557e-01,
                         -6.66383386e-01,  -7.07494020e-01,  -6.87641919e-01,
                         -6.56776130e-01,  -6.59189761e-01,  -6.90329075e-01,
                         -6.95159197e-01,  -6.38161778e-01,  -6.50422812e-01,
                         -6.98846400e-01,  -6.49671376e-01,  -6.48417056e-01,
                         -6.98963761e-01,  -6.74153686e-01,  -6.59586906e-01,
                         -6.44146800e-01,  -6.31065071e-01,  -6.57874644e-01,
                         -6.25008404e-01,  -6.45355105e-01,  -6.73021555e-01,
                         -5.91384590e-01,  -7.36873329e-01,  -7.75991440e-01,
                         -2.48991683e-01,  -7.37423301e-02,  -5.64446390e-01,
                         -7.95383513e-01,  -7.22915888e-01,  -5.73141992e-01,
                         -1.16068341e-01,   1.59108728e-01,  -2.44639605e-01,
                         -7.33068466e-01,  -7.05703378e-01,  -5.82274199e-01,
                         -7.71523416e-01,  -6.56214774e-01,  -1.27380088e-01,
                         -1.89207271e-01,  -7.30406106e-01,  -7.80940413e-01,
                         -6.26973391e-01,  -7.36709297e-01,  -5.57302952e-01,
                         -1.12494484e-01,  -3.15321803e-01,  -8.92496049e-01,
                         -6.73852563e-01,  -8.97528604e-02,  -2.46536449e-01,
                         -6.88075721e-01,  -7.97297418e-01,  -7.63527334e-01,
                         -4.60054368e-01,   3.43024693e-02,   9.36312973e-02,
                         -3.87212604e-01,  -8.41434002e-01,  -6.48996472e-01,
                         -1.00118615e-01,  -2.18996033e-01,  -8.15189838e-01,
                         -7.25224018e-01,  -1.05704769e-01,  -1.31425306e-01,
                         -7.45200634e-01,  -7.41447270e-01,  -2.00154915e-01,
                         -2.77788758e-01,  -5.86500049e-01,  -2.39391506e-01,
                          9.50062647e-02,  -8.40419065e-03,   1.16800778e-02,
                          6.56020120e-02,  -2.84804642e-01,  -7.82886744e-01,
                         -7.63974607e-01,  -2.11422011e-01,  -1.11465342e-01,
                         -7.09789753e-01,  -8.27767730e-01,  -1.96974695e-01,
                         -5.43697551e-02,  -6.93326771e-01,  -8.69079471e-01,
                         -2.67250001e-01,  -1.42450839e-01,  -5.88979244e-01,
                         -3.54414672e-01,   2.09398314e-01,  -1.12549521e-01,
                         -6.65268540e-01,  -3.59731972e-01,   1.40169039e-01,
                         -7.96536729e-02,  -5.52349031e-01,  -7.05011368e-01,
                         -7.88860440e-01,  -7.20107794e-01,  -2.44875729e-01,
                          4.90396544e-02,  -5.77415638e-02,   1.50186801e-03,
                          7.62796029e-02,  -2.90568978e-01,  -7.70950437e-01,
                         -8.26593161e-01,  -3.27679962e-01,   1.81833208e-01,
                         -2.61840448e-02,  -5.48153043e-01,  -4.42109376e-01,
                          5.78874722e-02,   6.87364191e-02,  -4.85205978e-01,
                         -8.98233533e-01,  -6.66758299e-01,  -1.37380823e-01,
                          6.32567331e-02,  -4.29945514e-02,  -9.16822404e-02,
                         -3.37295011e-02,   9.74946562e-03,  -1.87440477e-02,
                         -7.24346116e-02,  -4.90474850e-02,  -2.85405153e-03,
                         -2.32242662e-02,  -4.05447744e-02,  -2.82385163e-02,
                         -1.59425363e-02,  -4.78514656e-03,  -4.09830697e-02,
                         -8.11881050e-02,  -5.08046411e-02,  -2.22944003e-02,
                         -1.62339639e-02,  -4.17779200e-03,  -1.73048396e-02,
                         -1.95722282e-02,  -1.54423360e-02,  -4.76173759e-02,
                         -4.71713543e-02,  -1.84482634e-02,  -1.71439890e-02,
                         -1.32058170e-02,  -1.67634711e-02,  -2.68419273e-02,
                         -2.39492562e-02,  -3.23724635e-02,  -1.23029910e-02,
                          1.17964782e-02,  -2.53979005e-02,  -2.91259196e-02,
                          5.88119775e-03,   7.02467631e-04,   2.01721471e-02,
                          3.89896072e-02,  -5.32079861e-03,  -2.44605877e-02,
                         -2.70400848e-02,  -6.00125454e-02,  -6.25642315e-02,
                         -5.81734627e-02,  -7.60361850e-02,  -5.70479594e-02,
                         -2.10106168e-02,  -1.47926426e-02,  -2.71178987e-02,
                         -4.99216877e-02,  -4.57956344e-02,   7.31723849e-03,
                          2.49065645e-02,  -3.32023539e-02,  -6.09323569e-02,
                         -1.28614577e-02,   5.85258659e-03,  -3.37784998e-02,
                         -3.45232636e-02,  -2.67856382e-03,  -2.63932105e-02,
                         -6.40745983e-02,  -4.45246808e-02,  -1.68294553e-02,
                         -1.57387182e-02,  -2.10065730e-02,  -3.44284400e-02,
                         -2.80881692e-02,   1.44798159e-05,  -9.77644790e-03,
                         -2.95988452e-02,  -1.54767772e-02,  -1.43858595e-02,
                         -3.77753563e-02,  -5.90861626e-02,  -5.94652332e-02,
                         -2.36415174e-02,   9.50500485e-04,  -1.63761657e-02,
                         -3.99212576e-02,  -4.88421954e-02,  -3.24699916e-02,
                         -2.20505353e-02,  -3.84957977e-02,  -2.90543512e-02,
                         -2.36887541e-02,  -4.78717312e-02,  -3.12458929e-02,
                         -6.75699674e-03,  -9.18921269e-03,  -2.32540779e-02,
                         -8.00430328e-02,  -8.04573819e-02,   2.42541963e-03,
                          2.79597496e-03,  -2.01619025e-02,   7.97934458e-03,
                         -3.10478248e-02,  -6.77705407e-02,  -3.60937566e-02,
                         -9.14407708e-03,   4.89050224e-02,   5.53113930e-02,
                         -5.84798642e-02,  -8.63570720e-02,  -3.36716846e-02,
                         -6.27531856e-02,  -5.99927977e-02,   1.95322502e-02,
                          2.00098027e-02,  -4.31314297e-02,  -3.70745398e-02,
                          1.18992971e-02,  -1.02869039e-02,  -5.51115386e-02,
                         -2.45865695e-02,  -3.22565134e-03,  -3.43423709e-02,
                         -2.88216416e-02,  -1.48647502e-02,  -3.58433165e-02,
                         -2.72626393e-02,   8.34976498e-04,   1.34259008e-03,
                          3.70114879e-03,   3.68136680e-03,   1.00263348e-02,
                          7.35263824e-02,   5.00582047e-02,  -8.70547965e-02,
                         -7.99001660e-03,   5.70506416e-02,  -3.61431837e-01,
                         -5.65091550e-01,  -1.48345843e-01,  -1.98096275e-01,
                         -7.89489329e-01,  -7.26060152e-01,  -1.23183094e-01,
                          1.38688311e-01,  -1.04584686e-01,  -6.28518879e-01,
                         -7.99379826e-01,  -3.39487284e-01,  -1.11398213e-01,
                         -4.55325305e-01,  -7.35722005e-01,  -7.63526142e-01,
                         -5.46332598e-01,  -1.72840253e-01,  -2.45962173e-01,
                         -6.84102893e-01,  -7.57214904e-01,  -6.12343609e-01,
                         -6.78345621e-01,  -7.32158959e-01,  -6.50778890e-01,
                         -6.62121654e-01,  -7.49266267e-01,  -7.12684870e-01,
                         -6.64571404e-01,  -7.43591189e-01,  -5.85891247e-01,
                         -6.23542331e-02,   1.41175091e-01,  -3.08712155e-01,
                         -7.38872588e-01,  -6.71978056e-01,  -5.85558355e-01,
                         -7.81848311e-01,  -6.29765749e-01,  -9.01916176e-02,
                         -2.21292764e-01,  -8.71272266e-01,  -7.10377455e-01,
                         -7.48537704e-02,  -2.56211936e-01,  -7.77086914e-01,
                         -6.91994488e-01,  -5.78729987e-01,  -8.09549451e-01,
                         -6.12223089e-01,  -1.18754618e-01,  -2.88647950e-01,
                         -7.57225215e-01,  -7.03164220e-01,  -6.13738954e-01,
                         -7.96608865e-01,  -5.38973749e-01,  -7.78518617e-02,
                         -3.68090183e-01,  -8.90148699e-01,  -5.76642990e-01,
                          5.37192170e-03,  -2.69442797e-01,  -8.59031379e-01,
                         -5.99881828e-01,  -9.09081846e-02,  -3.62051517e-01,
                         -6.01182401e-01,  -9.54660997e-02,   1.41865015e-01,
                         -3.49764228e-01,  -7.36255586e-01,  -7.24587679e-01,
                         -6.73564374e-01,  -6.88515425e-01,  -6.80831850e-01,
                         -6.25590980e-01,  -6.31270051e-01,  -7.05405176e-01,
                         -6.79943144e-01,  -6.90247476e-01,  -7.76868343e-01,
                         -4.94728029e-01,  -1.13192067e-01,  -3.55067790e-01,
                         -7.41951764e-01,  -6.51713073e-01,  -5.63921273e-01,
                         -7.02386200e-01,  -7.13338315e-01,  -6.60791874e-01,
                         -7.07213700e-01,  -7.16396153e-01,  -6.91601276e-01,
                         -7.34876752e-01,  -7.03087568e-01,  -6.13818467e-01,
                         -7.11084604e-01,  -6.52869701e-01,  -2.03987375e-01,
                         -1.62173450e-01,  -6.71199441e-01,  -8.06185126e-01,
                         -6.25212073e-01,  -7.26050138e-01,  -7.07416475e-01,
                         -1.86172396e-01,   2.13288561e-01,  -8.21061954e-02,
                         -5.93375623e-01,  -7.18205869e-01,  -7.12052464e-01,
                         -6.35911882e-01,  -1.50058910e-01,   1.86302349e-01,
                         -1.73924655e-01,  -6.23454213e-01,  -7.21508682e-01,
                         -6.54801071e-01,  -5.86974621e-01,  -7.11699128e-01,
                         -7.59520054e-01,  -3.21598291e-01,  -5.87953888e-02,
                         -4.43125457e-01,  -7.41790056e-01,  -6.67610526e-01,
                         -6.43959463e-01,  -7.08059430e-01,  -6.82207108e-01,
                         -6.07971370e-01,  -6.95276976e-01,  -7.56383061e-01,
                         -3.57791781e-01,  -5.05465418e-02,  -4.32926357e-01,
                         -7.80466616e-01,  -6.83401346e-01,  -6.46226585e-01,
                         -6.80375695e-01,  -6.26204848e-01,  -6.81490123e-01,
                         -6.70291841e-01,  -2.51384914e-01,   1.54587001e-01,
                         -9.33920816e-02,  -6.33472085e-01,  -7.60636091e-01,
                         -6.32774889e-01,  -6.36096179e-01,  -7.01723278e-01,
                         -6.98557913e-01,  -6.45811081e-01,  -6.24295652e-01,
                         -6.43496931e-01,  -6.53240204e-01,  -6.60977900e-01,
                         -6.50453389e-01,  -6.27916217e-01,  -6.36180818e-01,
                         -6.43711686e-01,  -6.46650791e-01,  -6.50329292e-01,
                         -6.33041918e-01,  -6.15765572e-01,  -6.13162100e-01,
                         -6.49611115e-01,  -6.88656926e-01,  -6.57335043e-01,
                         -6.21264637e-01,  -6.20858967e-01,  -6.39834404e-01,
                         -6.82180226e-01,  -6.75595760e-01,  -6.43817246e-01,
                         -6.66491091e-01,  -6.96033835e-01,  -7.05168307e-01,
                         -6.74528062e-01,  -6.31241500e-01,  -6.49367809e-01,
                         -6.57909095e-01,  -6.36264682e-01,  -6.49785459e-01,
                         -6.69011116e-01,  -6.47888720e-01,  -5.86483300e-01,
                         -6.30234838e-01,  -6.95430458e-01,  -3.90073299e-01,
                         -7.52170384e-02,  -3.55157316e-01,  -7.29045510e-01,
                         -7.07185209e-01,  -6.41490221e-01,  -6.71429694e-01,
                         -6.70229256e-01,  -6.78541064e-01,  -6.47469878e-01,
                         -6.10037625e-01,  -6.62645459e-01,  -6.28992617e-01,
                         -5.95466137e-01,  -7.32202053e-01,  -5.33198833e-01,
                         -1.03692509e-01,  -3.59456748e-01,  -8.30009818e-01,
                         -6.71745896e-01,  -5.88734508e-01,  -7.88845003e-01,
                         -4.37525839e-01,  -8.86844378e-03,  -4.49661851e-01,
                         -9.08539712e-01,  -4.03970182e-01,   3.46085802e-02,
                         -3.90795380e-01,  -7.33849883e-01,  -6.72008812e-01,
                         -5.72242022e-01,  -2.16435656e-01,  -1.02026939e-01,
                         -6.56247377e-01,  -7.77025223e-01,  -1.68691576e-01,
                         -4.47794758e-02,  -5.68776131e-01,  -7.49770403e-01,
                         -5.82079530e-01,  -7.19678402e-01,  -6.86056852e-01,
                         -1.46384075e-01,  -9.87092182e-02,  -5.89754283e-01,
                         -6.98259115e-01,  -6.30932808e-01,  -7.03284383e-01,
                         -6.31479144e-01,  -5.59321404e-01,  -6.15766764e-01,
                         -6.57909632e-01,  -7.04658985e-01,  -6.65910900e-01,
                         -5.85070133e-01,  -7.06066310e-01,  -7.28096187e-01,
                         -3.05300832e-01,   1.02526486e-01,  -1.98876616e-02,
                         -5.09342551e-01,  -7.96056211e-01,  -4.81752574e-01,
                          2.97218952e-02,   1.04481198e-01,  -3.26786861e-02,
                          2.04030611e-03,   5.08260727e-02,   2.91896127e-02,
                          2.18154881e-02,   4.44481932e-02,   5.71853630e-02,
                          1.13359885e-02,  -8.25753901e-04,   2.81120073e-02,
                          1.93552114e-03,  -3.77740082e-03,   4.07855734e-02,
                          7.60700777e-02,   3.18030007e-02,  -1.23787597e-02,
                          1.67118043e-01,   1.31806791e-01,  -4.15052682e-01,
                         -5.43624461e-01,  -6.53260574e-02,   8.96864161e-02,
                         -3.90033089e-02,   6.76454557e-03,   6.86907768e-02,
                          3.00996955e-02,   5.67105506e-03,   9.54833329e-02,
                          2.23010164e-02,  -4.08599377e-01,  -4.69271660e-01,
                          2.48786602e-02,   1.11651197e-01,  -8.09797496e-02,
                          1.38191670e-01,   4.29395959e-02,  -5.52231014e-01,
                         -4.65137661e-01,   8.09341595e-02,   7.71780834e-02,
                         -3.09461411e-02,   7.90777430e-02,   6.02528825e-03,
                         -1.61390975e-02,   8.25845674e-02,   1.24266585e-02,
                         -1.79236084e-02,   4.56121489e-02,   6.16876669e-02,
                          6.33814931e-02,  -1.83340535e-02,  -2.99243536e-03,
                          1.30487859e-01,  -1.21731162e-01,  -4.99337077e-01,
                         -3.30831766e-01,   1.05362507e-02,   5.04021607e-02,
                          5.95435426e-02,   9.69838202e-02,  -4.12281603e-03,
                         -2.31183693e-02,   1.02071963e-01,   7.67447576e-02,
                         -2.28122808e-02,   7.02429265e-02,   6.99541345e-02,
                         -3.08720410e-01,  -5.06178260e-01,  -1.34857610e-01,
                          1.17254414e-01,  -4.65026647e-02,  -2.52562258e-02,
                          1.53180912e-01,   8.63107890e-02,   2.85979186e-04,
                          6.49623871e-02,   5.67335933e-02,  -3.98771428e-02,
                          3.32487337e-02,   9.01999623e-02,  -3.53198707e-01,
                         -6.43337965e-01,  -6.55608848e-02,   2.12957382e-01,
                         -3.40064973e-01,  -4.12572920e-01,  -9.13027003e-02,
                         -3.68313491e-01,  -5.16424537e-01,   5.53089660e-03,
                          1.43163800e-01,  -4.07387286e-01,  -5.47426224e-01,
                          6.40001101e-03,   1.79655001e-01,  -3.61580163e-01,
                         -5.74943006e-01,  -8.76444727e-02,   1.91677198e-01,
                         -3.14858146e-02,  -3.72513644e-02,   1.41615123e-01,
                         -2.88079679e-01,  -9.12262619e-01,  -5.92035055e-01,
                          7.45976493e-02,  -1.94673836e-01,  -6.07997596e-01,
                         -1.02867439e-01,   2.46743515e-01,  -2.84884810e-01,
                         -6.90136671e-01,  -6.66477263e-01,  -6.96748435e-01,
                         -5.12276947e-01,   1.74869900e-03,   1.86021864e-01,
                         -2.44423449e-01,  -7.20871568e-01,  -6.31251514e-01,
                         -1.86686441e-01,   5.11202551e-02,   1.06193364e-01,
                          4.43962514e-02,  -3.87159139e-01,  -7.84819245e-01,
                         -4.85085815e-01,  -2.38956623e-02,  -3.16482186e-01,
                         -8.59244525e-01,  -6.35017335e-01,  -1.19736493e-01,
                         -2.83604115e-01,  -5.14356554e-01,  -4.22944203e-02,
                          1.88679799e-01,  -3.53786528e-01,  -5.27445674e-01,
                         -1.08322404e-01,  -1.75076470e-01,  -6.96698844e-01,
                         -7.23204374e-01,  -1.33657664e-01,   2.50262290e-01,
                         -1.46116838e-01,  -5.90369403e-01,  -2.93746382e-01,
                         -1.36315584e-01,  -7.07471907e-01,  -7.84649849e-01,
                         -1.32809833e-01,  -1.23969547e-01,  -5.55272996e-01,
                         -2.07706392e-01,   2.10062921e-01,  -2.53378183e-01,
                         -5.74580491e-01,  -1.93883717e-01,  -1.91156581e-01,
                         -7.27896452e-01,  -7.83995628e-01,  -1.95424005e-01,
                          2.22024143e-01,  -7.72867650e-02,  -5.55474937e-01,
                         -3.84164095e-01,   4.87855896e-02,   6.17669299e-02,
                          7.82086421e-03,   7.98368379e-02,  -1.12009859e-02,
                         -4.46695797e-02,   3.21216248e-02,  -2.28683770e-01,
                         -6.99618697e-01,  -7.60110378e-01,  -2.87021935e-01,
                          1.54567674e-01,   1.91837791e-02,  -5.29682338e-01,
                         -8.49831939e-01,  -5.78433871e-01,  -7.85652325e-02,
                          9.10593048e-02,   4.90490235e-02,  -7.34322593e-02,
                         -5.46102107e-01,  -8.05254817e-01,  -3.46256375e-01,
                         -1.72843903e-01,  -6.03016973e-01,  -4.62708831e-01,
                          1.79988563e-01,   7.52041638e-02,  -5.91857433e-01,
                         -5.22004604e-01,   1.37143880e-01,   1.57504119e-02,
                         -5.79055488e-01,  -3.47526133e-01,  -3.39948796e-02,
                         -5.20022631e-01,  -5.66125274e-01,   1.19595796e-01,
                          4.66701873e-02,  -6.71355963e-01,  -5.61880231e-01,
                          1.50948882e-01,   6.86011240e-02,  -6.07230544e-01,
                         -5.58873177e-01,   8.53891298e-03,   6.89125657e-02,
                         -1.19215854e-01,  -3.76742333e-02,   5.83828315e-02,
                          4.87117171e-02,   3.57368253e-02,   2.58051660e-02,
                          4.01530452e-02,  -9.47370846e-03,  -9.41851810e-02,
                         -6.02639727e-02,  -3.03479414e-02,  -6.34415224e-02,
                         -2.59950105e-02,   8.43500346e-03,  -2.39696112e-02,
                         -2.36867890e-02,   1.08118057e-02,   1.74452681e-02,
                         -6.14248635e-03,  -2.08699759e-02,  -2.94725243e-02,
                         -5.96327782e-02,  -3.89104001e-02,   3.30732353e-02,
                          3.25708240e-02,   6.98962831e-04,   9.32276621e-03,
                         -1.78677440e-02,  -6.12404197e-02,  -2.24624742e-02,
                          4.28005606e-02,   8.34164303e-03,  -6.81966990e-02,
                         -3.13668326e-02,   3.28881443e-02,   3.11122835e-03,
                         -1.57987475e-02,  -3.66233066e-02,  -9.70581472e-02,
                         -4.04440910e-02,   4.91605587e-02,  -1.44480811e-02,
                         -9.66379568e-02,  -5.41332699e-02,   5.58441579e-02,
                          5.52658513e-02,  -6.08749650e-02,   1.67045183e-02,
                          9.00992751e-02,  -3.11666340e-01,  -6.02018058e-01,
                         -2.16507867e-01,   1.20517753e-01,  -3.52130248e-03,
                         -7.95749798e-02,  -2.53724232e-02,  -6.45435974e-02,
                         -3.58470269e-02,   8.03579986e-02,   1.12393927e-02,
                         -9.42654014e-02,   3.26400325e-02,  -5.44565096e-02,
                         -4.79443163e-01,  -4.24484670e-01,  -8.44252780e-02,
                         -4.20201242e-01,  -8.52341831e-01,  -6.74148262e-01,
                         -5.98912179e-01,  -7.43554592e-01,  -4.79406834e-01,
                         -9.30691585e-02,  -3.25629599e-02,  -3.89772393e-02,
                          1.06696449e-01,   5.49751557e-02,  -5.11315346e-01,
                         -9.28320408e-01,  -5.49650609e-01,  -7.07158372e-02,
                          1.46391839e-02,   3.80596407e-02,  -2.26138458e-01,
                         -6.27168179e-01,  -3.44563812e-01,   1.35285139e-01,
                          2.59428527e-02,  -1.21981904e-01,   3.39616835e-02,
                          9.24063176e-02,  -4.89145925e-04,  -4.04561684e-02,
                          2.42319666e-02,  -9.66680571e-02,  -6.09261394e-01,
                         -8.64609063e-01,  -4.54522520e-01,  -7.41616935e-02,
                         -2.26066653e-02,   2.07190663e-02,  -1.66947350e-01,
                         -6.72605217e-01,  -8.03246200e-01,  -3.02530110e-01,
                          6.45590052e-02,  -1.20694645e-01,  -1.44909069e-01,
                          1.68338478e-01,  -9.67968702e-02,  -6.40117407e-01,
                         -3.54930341e-01,  -3.52487713e-02,  -6.27591074e-01,
                         -8.93343747e-01,  -2.03990340e-01,  -2.40300912e-02,
                         -7.59944618e-01,  -9.34929252e-01,  -2.50277728e-01,
                         -1.32823065e-01,  -6.45102918e-01,  -3.70243698e-01,
                          2.29792207e-01,  -1.95728600e-01,  -6.45040154e-01,
                         -2.38999099e-01,  -2.23399684e-01,  -6.01592243e-01,
                         -3.10867995e-01,  -1.50952548e-01,  -6.89215958e-01,
                         -7.86829829e-01,  -2.23830074e-01,   9.40229297e-02,
                         -1.24187857e-01,  -5.56841552e-01,  -7.62747824e-01,
                         -6.92116261e-01,  -7.05185890e-01,  -7.67135561e-01,
                         -7.12865770e-01,  -7.11074114e-01,  -7.43531585e-01,
                         -7.13524699e-01,  -7.05499470e-01,  -6.93504155e-01,
                         -6.95908546e-01,  -7.56644487e-01,  -7.32780755e-01,
                         -6.46887600e-01,  -6.60885155e-01,  -7.40169168e-01,
                         -7.78503895e-01,  -7.22264707e-01,  -6.38417125e-01,
                         -6.60793900e-01,  -7.26451397e-01,  -7.25838482e-01,
                         -7.15628922e-01,  -7.21333623e-01,  -7.02423036e-01,
                         -6.89641953e-01,  -7.30612755e-01,  -7.62847185e-01,
                         -7.06911504e-01,  -6.78602517e-01,  -7.62209415e-01,
                         -7.96119273e-01,  -7.39654779e-01,  -7.09464073e-01,
                         -6.91463947e-01,  -6.75825715e-01,  -6.87136531e-01,
                         -6.98137045e-01,  -7.28168368e-01,  -7.49124587e-01,
                         -7.15204060e-01,  -7.03951716e-01,  -7.33579159e-01,
                         -7.47947872e-01,  -7.56230474e-01,  -7.57793546e-01,
                         -7.46808350e-01,  -7.57628202e-01,  -7.87680507e-01,
                         -7.46788979e-01,  -6.23089135e-01,  -6.26344502e-01,
                         -7.76889384e-01,  -8.04544330e-01,  -7.21031308e-01,
                         -6.64808393e-01,  -6.63092196e-01,  -8.13362062e-01,
                         -7.83592522e-01,  -3.28988522e-01,  -2.32919872e-01,
                         -6.95050836e-01,  -8.15470994e-01,  -6.85297072e-01,
                         -8.29027116e-01,  -7.11289227e-01,  -2.43389547e-01,
                         -2.88337290e-01,  -7.96539068e-01,  -7.77803600e-01,
                         -2.07060114e-01,  -1.72370240e-01,  -8.02308977e-01,
                         -9.05556679e-01,  -2.72607297e-01,  -9.65663642e-02,
                         -6.80206418e-01,  -9.07599807e-01,  -3.83364648e-01,
                         -1.72234908e-01,  -6.54626012e-01,  -8.64334941e-01,
                         -6.70564055e-01,  -7.42683232e-01,  -7.36628354e-01,
                         -3.44692767e-01,  -3.25707287e-01,  -7.75409639e-01,
                         -7.84402668e-01,  -3.04711759e-01,  -2.12252349e-01,
                         -5.81088126e-01,  -7.71882713e-01,  -7.75341690e-01,
                         -7.73049176e-01,  -6.59459591e-01,  -7.12160051e-01,
                         -9.24782991e-01,  -8.00687551e-01,  -6.19560182e-01,
                         -7.28982210e-01,  -7.87181318e-01,  -7.94688344e-01,
                         -7.44740248e-01,  -3.88428599e-01,  -2.26133108e-01,
                         -5.82900941e-01,  -8.21823478e-01,  -6.98802888e-01,
                         -6.62614763e-01,  -8.55706453e-01,  -9.19625819e-01,
                         -5.70479691e-01,  -7.49795064e-02,   2.79125012e-02,
                         -3.85324985e-01,  -7.84619212e-01,  -7.25746989e-01,
                         -6.47561193e-01,  -8.22231770e-01,  -6.34618878e-01,
                         -2.15020344e-01,  -3.71858597e-01,  -8.10071766e-01,
                         -8.82241666e-01,  -7.51582325e-01,  -7.30389655e-01,
                         -8.00033331e-01,  -7.60613024e-01,  -6.31389976e-01,
                         -6.26393378e-01,  -6.98759317e-01,  -8.48612726e-01,
                         -9.25911784e-01,  -4.90313202e-01,  -9.79335010e-02,
                         -4.70973164e-01,  -9.13217366e-01,  -8.89305830e-01,
                         -6.18077159e-01,  -2.03630611e-01,  -2.65448660e-01,
                         -8.83792043e-01,  -8.17273855e-01,  -1.42800331e-01,
                         -2.18418479e-01,  -8.39215994e-01,  -8.60247910e-01,
                         -3.30194741e-01,  -1.57930091e-01,  -5.72422206e-01,
                         -8.68122518e-01,  -7.45360136e-01,  -6.94917083e-01,
                         -8.34827662e-01,  -8.00105155e-01,  -6.50529683e-01,
                         -7.29267716e-01,  -7.80460119e-01,  -3.99752110e-01,
                         -1.92348734e-01,  -6.50699317e-01,  -8.54785085e-01,
                         -3.65024745e-01,  -1.82492286e-01,  -6.10444129e-01,
                         -8.44171226e-01,  -7.04531789e-01,  -6.88736141e-01,
                         -7.43825316e-01,  -4.38741148e-01,  -7.60293659e-03,
                         -1.72727015e-02,  -4.91031885e-01,  -9.51459289e-01,
                         -7.63981164e-01,  -1.29695997e-01,  -1.87244430e-01,
                         -8.03553462e-01,  -8.32552254e-01,  -5.95364451e-01,
                         -7.26939082e-01,  -7.65904367e-01,  -6.32334530e-01,
                         -6.13115370e-01,  -6.24135554e-01,  -7.04593182e-01,
                         -6.94036901e-01,  -3.10230792e-01,   4.25955281e-02,
                         -9.25237983e-02,  -4.82266873e-01,  -6.71254814e-01,
                         -6.52666271e-01,  -7.15044796e-01,  -7.31032968e-01,
                         -6.06496453e-01,  -7.06257999e-01,  -7.68625140e-01,
                         -2.79841512e-01,   1.88238665e-01,  -4.07931246e-02,
                         -6.39570057e-01,  -8.52579534e-01,  -4.00130481e-01,
                         -3.96268293e-02,  -4.61184889e-01,  -8.54181170e-01,
                         -4.29198086e-01,  -3.23160961e-02,  -4.14876282e-01,
                         -8.27978909e-01,  -6.93903089e-01,  -6.18521273e-01,
                         -7.43552327e-01,  -4.44040447e-01,  -9.15271863e-02,
                         -4.42031562e-01,  -8.49898100e-01,  -4.85120654e-01,
                         -5.78823034e-03,  -3.24004322e-01,  -8.71270239e-01,
                         -6.20966136e-01,  -9.88913700e-02,  -2.90039122e-01,
                         -6.87261701e-01,  -6.68879390e-01,  -6.36488914e-01,
                         -7.04212129e-01,  -6.71941102e-01,  -6.80474937e-01,
                         -7.22339392e-01,  -7.12483108e-01,  -6.86216712e-01,
                         -6.22140646e-01,  -6.37502670e-01,  -6.95649445e-01,
                         -6.48883462e-01,  -7.48131692e-01,  -7.87367702e-01,
                         -3.20846885e-01,  -1.27535015e-01,  -5.47401547e-01,
                         -4.24909830e-01,  -4.01247032e-02,  -5.78882217e-01,
                         -9.27222371e-01,  -2.16724083e-01,  -2.36515496e-02,
                         -5.48809707e-01,  -3.60686839e-01,  -7.98540041e-02,
                         -6.44416153e-01,  -8.52328897e-01,  -2.51177102e-01,
                         -1.55552223e-01,  -5.78216076e-01,  -3.15117836e-01,
                          1.83293656e-01,  -1.91032112e-01,  -5.64720750e-01,
                         -1.82285815e-01,  -2.60264695e-01,  -7.14220345e-01,
                         -1.70005739e-01,   3.23774576e-01,  -3.31438929e-01,
                         -6.04646981e-01,  -1.61943838e-01,  -3.27531993e-01,
                         -5.53214788e-01,  -1.55678287e-01,  -2.57000715e-01,
                         -8.49064767e-01,  -6.22288346e-01,  -4.99558486e-02,
                         -3.28500628e-01,  -7.97152281e-01,  -6.79296672e-01,
                         -6.57611907e-01,  -7.98102021e-01,  -4.20753032e-01,
                         -1.28033951e-01,  -4.84231591e-01,  -5.32703459e-01,
                          1.74110178e-02,   1.01111226e-01,  -4.36504722e-01,
                         -7.21172988e-01,  -6.38038039e-01,  -6.55186296e-01,
                         -7.10004866e-01,  -6.98288202e-01,  -8.32124114e-01,
                         -7.73835301e-01,  -2.40701944e-01,  -6.54418170e-02,
                         -5.82799375e-01,  -8.12136114e-01,  -6.07882082e-01,
                         -7.14578032e-01,  -7.55552173e-01,  -2.35848859e-01,
                         -7.16067925e-02,  -6.61569834e-01,  -8.31650376e-01,
                         -2.66614199e-01,  -1.38183594e-01,  -6.50634527e-01,
                         -8.50357413e-01,  -6.38814330e-01,  -5.80355167e-01,
                         -6.77338243e-01,  -7.24166095e-01,  -7.15408564e-01,
                         -6.61814511e-01,  -6.70913160e-01,  -7.36618102e-01,
                         -6.50984287e-01,  -5.60589254e-01,  -7.28004336e-01,
                         -8.76997411e-01,  -7.50528038e-01,  -6.15458727e-01,
                         -6.38272524e-01,  -6.59133554e-01,  -6.66148067e-01,
                         -6.69970095e-01,  -3.99058014e-01,   6.65492415e-02,
                          4.34458852e-02,  -5.36510527e-01,  -8.78991902e-01,
                         -7.58264542e-01,  -6.23709023e-01,  -6.11461699e-01,
                         -6.29861414e-01,  -6.56974077e-01,  -7.22828209e-01,
                         -7.80667901e-01,  -4.98469323e-01,  -1.03549333e-02,
                          3.30941528e-02,  -1.09523185e-01,   4.26289141e-02,
                          6.17532134e-02,  -6.05676658e-02,   9.84193850e-03,
                         -2.18120613e-03,  -2.14887876e-02,   4.73376401e-02,
                         -2.19689339e-01,  -4.80811387e-01,  -2.61836559e-01,
                         -2.82465364e-03,   2.54651550e-02,  -5.13296202e-02,
                         -4.66186479e-02,   9.92707163e-02,  -1.40691549e-01,
                         -6.06351972e-01,  -3.39658856e-01,   1.61958069e-01,
                          1.22341299e-02,  -1.78119943e-01,  -3.54961045e-02,
                          2.19920650e-02,   5.12202410e-03,   1.60051957e-02,
                          1.08705333e-03,  -1.43718068e-02,  -1.92473140e-02,
                          8.20511952e-02,   1.59566298e-01,  -3.31658535e-02,
                         -1.85925886e-01,  -3.56446207e-02,   1.06280819e-01,
                          5.14562316e-02,  -3.64889577e-02,  -1.28843179e-02,
                          3.52633297e-02,  -1.58920418e-02,  -3.55829969e-02,
                          2.28386801e-02,   4.47824858e-02,   5.93113601e-02,
                          5.96918922e-04,  -9.76159200e-02,  -2.61911564e-02,
                          5.79367857e-03,  -3.50905359e-02,   1.16467312e-01,
                         -7.50343176e-03,  -5.19514740e-01,  -5.00469089e-01,
                          1.29319131e-02,   1.40875742e-01,  -5.11305444e-02,
                         -9.30034071e-02,  -2.53500114e-03,   6.59441799e-02,
                          6.15821630e-02,   5.81670739e-03,  -7.42042959e-02,
                         -4.57064100e-02,   1.04263507e-01,  -1.00328252e-01,
                         -5.54039299e-01,  -3.75889242e-01,   1.14267088e-01,
                          5.02227545e-02,  -2.95885988e-02,   1.38540596e-01,
                         -1.79905832e-01,  -5.87036848e-01,  -3.23205054e-01,
                          5.66884354e-02,   4.24418785e-02,  -7.53981397e-02,
                         -3.43062915e-02,   1.19903021e-01,  -2.87532751e-02,
                         -5.50405443e-01,  -7.18476713e-01,  -5.49262643e-01,
                         -7.57182539e-01,  -8.22540522e-01,  -1.87197447e-01,
                          8.08237679e-03,  -7.14647770e-01,  -8.74571621e-01,
                         -1.34867519e-01,  -6.77164942e-02,  -6.97260022e-01,
                         -4.78113681e-01,   2.13315949e-01,   3.38052586e-03,
                         -5.59859872e-01,  -6.85130894e-01,  -7.90196419e-01,
                         -6.78792715e-01,  -9.67629626e-02,  -9.28134322e-02,
                         -8.02815795e-01,  -7.97902763e-01,  -6.30381182e-02,
                         -5.71513399e-02,  -7.16004431e-01,  -8.21583450e-01,
                         -5.95101953e-01,  -7.69239068e-01,  -6.93299532e-01,
                         -1.01988316e-01,  -1.33355334e-01,  -7.74364114e-01,
                         -6.85543656e-01,  -7.07044825e-02,  -2.11638272e-01,
                         -7.72164166e-01,  -7.38864422e-01,  -5.76454997e-01,
                         -7.51890779e-01,  -5.46716928e-01,  -1.33995667e-01,
                         -3.49295497e-01,  -4.98337239e-01,  -1.31599471e-01,
                         -3.35060596e-01,  -8.95916760e-01,  -5.83002269e-01,
                         -3.98491733e-02,  -2.88875848e-01,  -6.91507995e-01,
                         -6.66114151e-01,  -6.48791015e-01,  -7.79104769e-01,
                         -5.62485814e-01,  -1.81615539e-03,   9.18010697e-02,
                         -4.25161541e-01,  -5.55787325e-01,  -5.87270334e-02,
                          1.39111072e-01,  -2.36164182e-01,  -6.30896151e-01,
                         -7.14446902e-01,  -3.77467215e-01,   1.00514032e-01,
                         -2.44079363e-02,  -5.95401227e-01,  -4.76527482e-01,
                          1.98001251e-01,   7.41649866e-02,  -6.45111084e-01,
                         -5.43233871e-01,   1.31693497e-01,   1.18847363e-01,
                         -4.67337519e-01,  -8.00521970e-01,  -6.32507086e-01,
                         -1.11409940e-01,   1.78426117e-01,  -1.87018722e-01,
                         -5.34508169e-01,  -2.97261655e-01,   5.07476553e-03,
                          1.47372736e-02,  -1.04899064e-01,  -3.68864566e-01,
                         -6.32757723e-01,  -6.46957874e-01,  -6.24073088e-01,
                         -6.88427269e-01,  -6.74519897e-01,  -7.03428149e-01,
                         -7.35324383e-01,  -4.11616385e-01,  -1.56429633e-02,
                         -7.33753713e-03,  -2.60839555e-02,   1.19136356e-01,
                         -5.27099222e-02,  -5.01991689e-01,  -7.40066886e-01,
                         -7.30947673e-01,  -6.66164994e-01,  -6.46396756e-01,
                         -6.49189651e-01,  -6.34106815e-01,  -7.58552372e-01,
                         -7.76136100e-01,  -2.97639936e-01,  -7.43314698e-02,
                         -5.20509660e-01,  -4.64821219e-01,   1.23144045e-01,
                         -6.66136891e-02,  -5.79672694e-01,  -3.45585316e-01,
                          1.27659515e-02,  -5.38961450e-03,   2.39755753e-02,
                         -1.45694688e-01,  -7.15200186e-01,  -7.76588380e-01,
                         -1.62080333e-01,  -9.11528468e-02,  -6.67830884e-01,
                         -7.53326595e-01,  -5.40641546e-01,  -7.48948574e-01,
                         -6.96058571e-01,  -1.68224096e-01,  -1.97643086e-01,
                         -7.07642198e-01,  -7.82899916e-01,  -6.22984946e-01,
                         -7.03850150e-01,  -6.02207243e-01,  -1.19962454e-01,
                          8.02225918e-02,  -7.89253339e-02,   6.56951368e-02,
                          1.59706965e-01,  -3.64259481e-01,  -5.93836844e-01,
                         -9.26263630e-02,   1.23455249e-01,  -9.72380638e-02,
                         -1.13262661e-01,  -1.53054353e-02,   5.02458587e-03,
                          2.54197605e-02,   4.76711467e-02,   7.44015202e-02,
                         -2.06482057e-02,  -9.92712006e-02,   1.35600448e-01,
                          1.28549218e-01,  -4.47807252e-01,  -6.51567996e-01,
                         -1.54190958e-01,   1.83687240e-01,   5.15703633e-02,
                         -1.03383154e-01,  -2.75409017e-02,   4.44115624e-02,
                         -1.99241653e-01,  -4.75093931e-01,  -3.32605541e-01,
                         -3.96303907e-02,   4.95810667e-03,  -1.67432502e-02,
                          7.61108696e-02,   7.17186034e-02,  -6.64384142e-02,
                         -2.58045029e-02,   7.81236291e-02,  -2.19700933e-01,
                         -5.82053840e-01,  -3.70645821e-01,   3.15833539e-02,
                          6.23248443e-02,  -3.26174088e-02,   1.10181738e-02,
                          8.11285749e-02,   5.23613393e-02,  -9.74924788e-02,
                         -1.59330294e-01,  -9.26974416e-03,   6.47664964e-02,
                         -1.46644479e-02,   1.56931207e-02,   9.55774784e-02,
                          2.96879355e-02,  -6.58088997e-02,  -5.23781776e-02,
                          2.81258356e-02,   6.79859966e-02,  -3.46883130e-03,
                         -7.61810318e-02,  -2.65746973e-02,  -7.45874941e-02,
                         -4.19569939e-01,  -6.87921584e-01,  -5.94267309e-01,
                         -5.89547873e-01,  -8.03704977e-01,  -5.85125029e-01,
                          4.17231023e-03,   8.90557170e-02,  -3.92226011e-01,
                         -7.64421940e-01,  -6.88372552e-01,  -2.48079464e-01,
                          1.10666558e-01,   4.03642654e-02,  -6.72321767e-02,
                          1.46410596e-02,  -2.04604045e-01,  -5.74436486e-01,
                         -3.67264777e-01,   6.70600235e-02,   1.32550979e-02,
                         -9.47446823e-02,   5.27952500e-02,  -1.85208678e-01,
                         -5.74414611e-01,  -2.39435539e-01,   1.55100390e-01,
                         -2.86870360e-01,  -6.73637211e-01,  -2.80610383e-01,
                          1.09431550e-01,   6.73683807e-02,   2.41868980e-02,
                          7.16468468e-02,   2.24634521e-02,  -5.97571880e-02,
                         -6.26893118e-02,  -1.52849900e-02,   2.59452574e-02,
                          4.28189822e-02,   2.73794774e-02,   4.74927854e-03,
                         -3.59958224e-02,  -1.19502917e-01,  -5.54454401e-02,
                          1.27495751e-01,  -8.32796097e-02,  -5.45225322e-01,
                         -4.71255839e-01,  -3.09935901e-02,   8.32262635e-02,
                         -2.84669362e-03,   1.82162710e-02,   2.44060829e-02,
                         -4.20937575e-02,  -2.68502850e-02,   7.61890188e-02,
                         -9.86737236e-02,  -5.25953174e-01,  -4.41020966e-01,
                          4.48052585e-02,   4.36947607e-02,  -8.25527757e-02,
                          1.01793304e-01,  -1.54845238e-01,  -5.95856488e-01,
                         -3.43825489e-01,  -2.00101659e-01,  -7.00055480e-01,
                         -7.39211619e-01,  -2.10058182e-01,  -1.91450536e-01,
                         -6.26939476e-01,  -7.84909427e-01,  -6.79193795e-01,
                         -6.26189172e-01,  -6.73255205e-01,  -7.08321929e-01,
                         -6.46142244e-01,  -6.12925708e-01,  -7.04087675e-01,
                         -7.28787482e-01,  -6.53323412e-01,  -6.81090355e-01,
                         -7.33632147e-01,  -6.67093635e-01,  -6.64547086e-01,
                         -7.81502068e-01,  -7.59796143e-01,  -5.92898488e-01,
                         -5.86786330e-01,  -7.42997706e-01,  -7.42138505e-01,
                         -6.17929339e-01,  -6.61436260e-01,  -7.51928568e-01,
                         -6.80726171e-01,  -6.24964356e-01,  -6.65517747e-01,
                         -6.84100926e-01,  -7.27653742e-01,  -7.68733680e-01,
                         -6.83244407e-01,  -6.08364522e-01,  -6.66701198e-01,
                         -7.08320439e-01,  -6.69955015e-01,  -6.76484227e-01,
                         -7.34069169e-01,  -7.16788352e-01,  -6.23767614e-01,
                         -5.81485152e-01,  -6.32592022e-01,  -7.07857132e-01,
                         -7.39040852e-01,  -7.19164908e-01,  -6.83025360e-01,
                         -6.49662733e-01,  -6.42303228e-01,  -6.78394616e-01,
                         -7.12627232e-01,  -7.09389091e-01,  -6.54584348e-01,
                         -5.92898488e-01,  -6.75143540e-01,  -8.04109454e-01,
                         -7.13815868e-01,  -5.75582683e-01,  -6.19517386e-01,
                         -6.65166557e-01,  -6.59386635e-01,  -7.08258808e-01,
                         -7.36875355e-01,  -7.07684457e-01,  -6.41215444e-01,
                         -5.89194536e-01,  -6.33692563e-01,  -6.61685169e-01,
                         -6.55240059e-01,  -7.25167751e-01,  -7.02232063e-01,
                         -6.08966470e-01,  -6.87567949e-01,  -7.47185588e-01,
                         -6.69807971e-01,  -6.68762147e-01,  -7.00471699e-01,
                         -6.72473073e-01,  -6.50017440e-01,  -6.44995451e-01,
                         -6.67778075e-01,  -6.91700041e-01,  -7.19237030e-01,
                         -7.07303643e-01,  -5.58760047e-01,  -5.99852800e-01,
                         -8.01420987e-01,  -4.82369602e-01,  -1.26592368e-01,
                         -4.44937766e-01,  -4.91186410e-01,  -7.98993185e-02,
                         -3.31528634e-01,  -8.33336234e-01,  -7.23908424e-01,
                         -5.55931449e-01,  -6.78512871e-01,  -7.36815095e-01,
                         -7.01251805e-01,  -7.29637027e-01,  -6.90600693e-01,
                         -3.34815979e-01,  -5.20435348e-02,  -4.05212015e-01,
                         -8.04285228e-01,  -7.00747788e-01,  -6.48174345e-01,
                         -7.08771586e-01,  -6.02400661e-01,  -6.75746679e-01,
                         -6.82200313e-01,  -2.45480686e-01,  -1.44638136e-01,
                         -5.89084566e-01,  -7.24125683e-01,  -6.53211772e-01,
                         -8.22452664e-01,  -6.08996212e-01,  -5.25425673e-02,
                         -2.32622340e-01,  -6.73704028e-01,  -1.94662198e-01,
                          2.63719290e-01,  -2.65335441e-01,  -5.77177346e-01,
                         -1.74208030e-01,  -2.44668737e-01,  -7.73066580e-01,
                         -6.27599955e-01,  -5.45528233e-02,  -1.95974484e-01,
                         -7.93660522e-01,  -6.85298204e-01,  -1.54287443e-01,
                         -2.20361143e-01,  -5.96773148e-01,  -7.50964820e-01,
                         -7.66795933e-01,  -4.31919098e-01,  -4.39561047e-02,
                         -3.92986059e-01,  -8.23050499e-01,  -4.34456676e-01,
                         -6.35663494e-02,  -4.13349241e-01,  -7.19779670e-01,
                         -5.84135115e-01,  -6.17126346e-01,  -8.03606749e-01,
                         -4.55439717e-01,  -6.24009315e-03,  -3.66843015e-01,
                         -8.36107552e-01,  -4.86077964e-01,  -8.99677128e-02,
                         -3.69685560e-01,  -7.52998292e-01,  -7.45300174e-01,
                         -5.55365920e-01,  -5.98671854e-01,  -8.03954780e-01,
                         -5.37113845e-01,  -6.43316954e-02,  -3.05964917e-01,
                         -5.85282505e-01,  -1.61684267e-02,   2.18230814e-01,
                         -4.37160224e-01,  -5.55929422e-01,  -8.86582583e-02,
                         -2.92069852e-01,  -7.53066361e-01,  -6.59094691e-01,
                         -6.05679393e-01,  -7.79090822e-01,  -4.79183108e-01,
                         -4.68723886e-02,  -3.65431488e-01,  -8.16601932e-01,
                         -4.32560563e-01,  -4.81512733e-02,  -3.98212582e-01,
                         -4.30678397e-01,  -9.81485471e-02,  -5.23625791e-01,
                         -8.59302521e-01,  -2.65512019e-01,  -1.03473715e-01,
                         -5.10889769e-01,  -3.24730903e-01,  -1.91683978e-01,
                         -5.35253763e-01,  -2.63192803e-01,   2.67551154e-01,
                         -9.93378162e-02,  -7.23491967e-01,  -6.96534872e-01,
                         -5.26284516e-01,  -6.86160564e-01,  -6.37201965e-01,
                         -1.79145053e-01,  -1.14417270e-01,  -6.41725242e-01,
                         -8.43065441e-01,  -3.73020470e-01,   1.14291593e-01,
                          7.02380687e-02,  -4.00923520e-01,  -7.33860791e-01,
                         -7.14638591e-01,  -6.95648372e-01,  -7.20542669e-01,
                         -6.29621327e-01,  -5.81418753e-01,  -5.96003711e-01,
                         -5.93396485e-01,  -6.48229003e-01,  -6.92508399e-01,
                         -6.96412802e-01,  -6.88918710e-01,  -6.25249863e-01,
                         -7.02284038e-01,  -7.74787545e-01,  -3.56200129e-01,
                         -2.57474482e-02,  -4.41785663e-01,  -7.91371703e-01,
                         -6.41261816e-01,  -6.43484294e-01,  -6.96621418e-01,
                         -5.51514804e-01,  -6.56570733e-01,  -6.98024452e-01,
                         -2.62878150e-01,  -1.78549647e-01,  -6.07820868e-01,
                         -6.71244025e-01,  -6.04086816e-01,  -8.12779725e-01,
                         -5.86958349e-01,  -8.63823146e-02,  -2.61745244e-01,
                         -6.98333442e-01,  -6.94200993e-01,  -6.27143860e-01,
                         -7.07214355e-01,  -6.91494465e-01,  -6.26171231e-01,
                         -5.98752618e-01,  -6.27897203e-01,  -7.07432866e-01,
                         -6.83666110e-01,  -6.30118668e-01,  -7.13695645e-01,
                         -7.41174996e-01,  -6.41363621e-01,  -6.38112485e-01,
                         -7.34394133e-01,  -7.41003573e-01,  -5.85160434e-01,
                         -5.07637680e-01,  -7.25400448e-01,  -7.30922997e-01,
                         -2.13287532e-01,  -6.06295839e-02,  -6.08625352e-01,
                         -8.61518443e-01,  -6.10024691e-01,  -5.80087602e-01,
                         -7.48582780e-01,  -7.35840499e-01,  -6.37171328e-01,
                         -5.99501550e-01,  -6.36741459e-01,  -6.97744250e-01,
                         -6.97405636e-01,  -6.91889882e-01,  -7.01148748e-01,
                         -6.49169147e-01,  -6.21560216e-01,  -6.78867221e-01,
                         -7.06871748e-01,  -6.66987360e-01,  -6.26156449e-01,
                         -6.18010700e-01,  -6.07055604e-01,  -5.99884152e-01,
                         -6.81369960e-01,  -7.51815736e-01,  -6.75043344e-01,
                         -6.39084101e-01,  -7.26631522e-01,  -7.37283468e-01,
                         -6.94534004e-01,  -6.86332464e-01,  -6.21915758e-01,
                         -5.65170407e-01,  -6.28990769e-01,  -7.32037663e-01,
                         -7.76140034e-01,  -7.28043556e-01,  -6.51897430e-01,
                         -6.50832415e-01,  -6.66038811e-01,  -6.36508942e-01,
                         -6.46735370e-01,  -7.01576114e-01,  -6.99895680e-01,
                         -6.38539732e-01,  -6.29059017e-01,  -6.90901995e-01,
                         -7.07531273e-01,  -6.92446589e-01,  -7.15781152e-01,
                         -6.74652755e-01,  -5.96723735e-01,  -6.54920042e-01,
                         -7.54008889e-01,  -7.25562036e-01,  -6.31341815e-01,
                         -6.09925985e-01,  -7.03111529e-01,  -7.55546153e-01,
                         -6.53316915e-01,  -5.97858071e-01,  -6.96559966e-01,
                         -7.47902751e-01,  -6.67804003e-01,  -5.91254294e-01,
                         -6.28471434e-01,  -7.19408333e-01,  -7.25254595e-01,
                         -6.81248426e-01,  -6.86666965e-01,  -7.19855845e-01,
                         -7.46081471e-01,  -6.88359797e-01,  -5.78563094e-01,
                         -6.29004776e-01,  -7.18042791e-01,  -6.21596456e-01,
                         -5.87501228e-01,  -7.21953332e-01,  -7.53637075e-01,
                         -6.88721180e-01,  -6.85724795e-01,  -7.20995963e-01,
                         -7.27144897e-01,  -6.65113926e-01,  -6.16508663e-01,
                         -6.43753171e-01,  -6.45884871e-01,  -6.72004819e-01,
                         -7.63061106e-01,  -7.14430571e-01,  -5.84757686e-01,
                         -6.29305422e-01,  -7.47635603e-01,  -7.43759334e-01,
                         -6.73445582e-01,  -6.64217412e-01,  -7.04009652e-01,
                         -6.80080533e-01,  -6.19615674e-01,  -6.37025177e-01,
                         -7.06949353e-01,  -7.51662195e-01,  -7.03882933e-01,
                         -6.09432161e-01,  -6.37070298e-01,  -6.93860710e-01,
                         -6.85621440e-01,  -7.76588380e-01,  -6.96222365e-01,
                         -2.50718296e-01,  -1.40877515e-01,  -5.52265882e-01,
                         -7.61299610e-01,  -7.00216234e-01,  -5.80846906e-01,
                         -1.65122256e-01,   1.63905144e-01,  -2.00470820e-01,
                         -7.24160075e-01,  -7.35230803e-01,  -6.09805822e-01,
                         -6.92403197e-01,  -5.53994000e-01,  -1.79108113e-01,
                         -2.59478122e-01,  -6.91444039e-01,  -7.49312878e-01,
                         -6.79012060e-01,  -8.25423121e-01,  -5.56584060e-01,
                         -3.12553607e-02,  -3.02092195e-01,  -8.93716455e-01,
                         -6.36760950e-01,  -8.86712223e-02,  -2.16296598e-01,
                         -6.31021678e-01,  -7.86423743e-01,  -7.38107502e-01,
                         -4.39937592e-01,   2.43485458e-02,   9.33874547e-02,
                         -4.16429430e-01,  -8.38419676e-01,  -5.79838991e-01,
                         -9.10167322e-02,  -2.54302442e-01,  -8.30896795e-01,
                         -7.33195841e-01,  -1.08075246e-01,  -1.87001437e-01,
                         -7.97604144e-01,  -6.92644715e-01,  -1.67483911e-01,
                         -2.86678463e-01,  -5.71294129e-01,  -2.61394680e-01,
                          8.27149451e-02,   4.02949788e-02,   4.13820557e-02,
                          6.38155788e-02,  -3.28431547e-01,  -8.19652200e-01,
                         -7.01435506e-01,  -1.96379647e-01,  -2.06346706e-01,
                         -7.07437396e-01,  -7.42966294e-01,  -1.99785426e-01,
                         -9.60815176e-02,  -6.90815032e-01,  -8.69934022e-01,
                         -2.93750018e-01,  -1.50522947e-01,  -5.86731553e-01,
                         -3.80128622e-01,   1.89025432e-01,  -7.92084113e-02,
                         -5.95324993e-01,  -3.19566250e-01,   1.24640986e-01,
                         -1.13109797e-01,  -6.21796608e-01,  -7.72294283e-01,
                         -7.21777439e-01,  -6.30545437e-01,  -2.63908744e-01,
                          7.79186264e-02,  -7.55563285e-03,  -6.15983829e-02,
                          6.78171813e-02,  -1.97655216e-01,  -7.29731917e-01,
                         -8.25118482e-01,  -3.40707362e-01,   1.61402598e-01,
                         -9.88165964e-04,  -5.35775065e-01,  -4.81254160e-01,
                          2.23991070e-02,   4.92442027e-02,  -4.80339944e-01,
                         -8.68326783e-01,  -6.27619088e-01,  -1.03167348e-01,
                          3.08593754e-02,  -9.69766080e-02,  -3.71000618e-02,
                          4.65775132e-02,  -1.64442174e-02,  -6.08412772e-02,
                         -2.69373320e-02,   2.75779609e-02,   2.01070271e-02,
                         -2.90532056e-02,   1.61046104e-03,   1.66526418e-02,
                         -6.81176037e-02,  -8.63162503e-02,  -6.55657053e-03,
                          4.21598554e-02,   5.77258226e-03,  -6.96792454e-02,
                         -5.13427407e-02,   2.14963481e-02,  -1.93276554e-02,
                         -7.67342150e-02,  -4.21725474e-02,  -2.13728379e-02,
                         -2.17139721e-02,   3.85323749e-03,   2.50190105e-02,
                          2.87152827e-02,  -1.67138856e-02,  -8.70424509e-02,
                         -8.86394531e-02,  -3.02148145e-02,   2.79042572e-02,
                          3.10173947e-02,  -1.80047583e-02,  -1.32673867e-02,
                         -1.20395911e-03,  -7.66834542e-02,  -8.83985311e-02,
                         -3.40368901e-03,   1.97193529e-02,   9.63169523e-03,
                         -7.42191123e-03,  -6.94126859e-02,  -6.11738637e-02,
                          1.20729757e-02,   9.10954550e-03,  -3.49458493e-02,
                         -5.18379100e-02,  -3.72350775e-02,   3.84737365e-03,
                         -1.85532719e-02,  -8.23111236e-02,  -3.10508925e-02,
                          5.30275665e-02,   1.54984351e-02,  -3.75338830e-02,
                         -3.68387401e-02,  -5.65265492e-02,  -2.54956428e-02,
                          7.42881745e-02,   3.25446948e-02,  -1.23444758e-01,
                         -1.11544132e-01,   2.65243482e-02,   4.30688038e-02,
                         -3.82252634e-02,  -6.92371428e-02,  -3.05833369e-02,
                          1.43038342e-02,   7.28402147e-03,  -2.96298042e-02,
                         -4.47126813e-02,  -2.10107975e-02,   3.89336646e-02,
                          4.77163643e-02,  -3.64430472e-02,  -8.21306035e-02,
                         -5.23273796e-02,  -1.45185152e-02,   2.81368885e-02,
                          1.59666652e-03,  -8.54603574e-02,  -6.80872723e-02,
                         -4.80939960e-03,  -7.21765449e-03,   6.09365478e-03,
                          2.36222078e-03,  -5.44034094e-02,  -4.75527607e-02,
                         -9.83647909e-03,  -1.30996052e-02,  -6.99439133e-03,
                         -8.14418308e-03,  -2.33059321e-02,  -2.15816200e-02,
                         -3.34652811e-02,  -6.76507317e-03,   6.95455521e-02,
                          2.96468213e-02,  -9.39029679e-02,  -7.23041221e-02,
                          3.76957916e-02,   2.37488076e-02,  -4.67701182e-02,
                         -3.05729341e-02,  -3.87571543e-03,  -3.63775678e-02,
                         -7.11566582e-02,  -6.15190081e-02,   1.63109787e-02,
                          7.92057365e-02,   1.61951408e-02,  -3.66960764e-02,
                          2.38311477e-02,   2.51697619e-02,  -6.54070154e-02,
                         -8.75272155e-02,  -2.87738424e-02,   2.19842363e-02,
                          2.25386359e-02,  -6.28878968e-03,  -1.06316898e-02,
                          1.71080772e-02,   3.63571420e-02,   6.99645840e-03,
                         -4.60887589e-02,  -7.31864944e-02,  -6.77614585e-02,
                          2.01515332e-02,   8.46660584e-02,  -3.12633812e-02,
                         -1.51385404e-02,   1.04847148e-01,  -2.66430646e-01,
                         -6.15718007e-01,  -2.66777426e-01,  -1.75225690e-01,
                         -6.94621027e-01,  -7.27530658e-01,  -1.96553901e-01,
                          1.25727460e-01,  -6.23238683e-02,  -6.30966008e-01,
                         -8.19450021e-01,  -3.36714596e-01,  -1.04089141e-01,
                         -4.20927644e-01,  -7.70677865e-01,  -9.17412400e-01,
                         -5.82119942e-01,  -6.07305281e-02,  -2.30354756e-01,
                         -7.50647068e-01,  -7.90731192e-01,  -6.36948645e-01,
                         -6.75292015e-01,  -7.24452972e-01,  -7.07113028e-01,
                         -6.81404769e-01,  -6.32636607e-01,  -5.82799554e-01,
                         -6.58542216e-01,  -7.86920130e-01,  -5.57108462e-01,
                         -3.48947272e-02,   7.58244917e-02,  -3.46880287e-01,
                         -6.82117283e-01,  -6.77464306e-01,  -6.73124313e-01,
                         -7.66972542e-01,  -5.40125132e-01,  -9.81169268e-02,
                         -2.58013546e-01,  -8.30371618e-01,  -7.08625972e-01,
                         -1.42797098e-01,  -2.60596186e-01,  -7.44651854e-01,
                         -6.87984645e-01,  -5.10634005e-01,  -7.05274224e-01,
                         -6.14197791e-01,  -1.86932921e-01,  -3.26912671e-01,
                         -7.75192142e-01,  -7.13512063e-01,  -6.05398715e-01,
                         -7.65112817e-01,  -5.13270795e-01,  -9.75131094e-02,
                         -3.92545313e-01,  -8.78760397e-01,  -5.77233016e-01,
                         -2.69716401e-02,  -2.90575743e-01,  -8.48719418e-01,
                         -5.68553746e-01,  -5.55723198e-02,  -3.43947023e-01,
                         -6.15633965e-01,  -1.28418043e-01,   1.39997154e-01,
                         -3.01559567e-01,  -7.00460851e-01,  -7.22202718e-01,
                         -6.30840957e-01,  -6.31419957e-01,  -6.96367502e-01,
                         -6.60496294e-01,  -6.47249281e-01,  -7.48369098e-01,
                         -7.20416129e-01,  -6.96054578e-01,  -7.45418072e-01,
                         -4.17809576e-01,  -4.97895591e-02,  -3.47750008e-01,
                         -7.94696808e-01,  -7.46618688e-01,  -5.73784351e-01,
                         -6.16651177e-01,  -6.91461384e-01,  -6.77302361e-01,
                         -6.80157363e-01,  -7.32863903e-01,  -7.42876172e-01,
                         -7.15392947e-01,  -6.53009474e-01,  -5.89920402e-01,
                         -6.66452408e-01,  -6.17122769e-01,  -2.84058005e-01,
                         -2.89195955e-01,  -6.54301405e-01,  -6.72182858e-01,
                         -5.51463008e-01,  -6.84616327e-01,  -6.25212371e-01,
                         -2.11587399e-01,   6.88246116e-02,  -1.37144387e-01,
                         -5.81895649e-01,  -7.36039340e-01,  -6.50695264e-01,
                         -5.13851285e-01,  -1.25835821e-01,   1.28563911e-01,
                         -1.96710944e-01,  -5.99641979e-01,  -7.45673060e-01,
                         -7.32520819e-01,  -5.96893787e-01,  -6.59256279e-01,
                         -7.65994072e-01,  -3.77363771e-01,  -7.31760710e-02,
                         -4.46129203e-01,  -8.00593019e-01,  -6.90624058e-01,
                         -5.66878676e-01,  -6.45777166e-01,  -6.69838965e-01,
                         -5.97020090e-01,  -6.89825594e-01,  -7.22482741e-01,
                         -3.22793841e-01,  -9.04741883e-02,  -4.68066722e-01,
                         -7.39346862e-01,  -6.41544998e-01,  -6.47841096e-01,
                         -6.75080180e-01,  -6.01360917e-01,  -6.82471693e-01,
                         -6.74173295e-01,  -2.54483372e-01,   1.01886578e-01,
                         -8.71475860e-02,  -5.14891028e-01,  -7.05934703e-01,
                         -6.48603618e-01,  -5.79778671e-01,  -6.09394431e-01,
                         -6.39894903e-01,  -6.21171176e-01,  -6.75218105e-01,
                         -7.41803825e-01,  -6.63718164e-01,  -6.05411291e-01,
                         -6.54975414e-01,  -6.25546038e-01,  -5.92373133e-01,
                         -6.94023490e-01,  -7.30724275e-01,  -6.05680048e-01,
                         -5.39251506e-01,  -6.46977603e-01,  -7.23418474e-01,
                         -6.24213576e-01,  -5.82098484e-01,  -6.93069339e-01,
                         -6.94781661e-01,  -6.02722883e-01,  -6.04896605e-01,
                         -6.15444183e-01,  -6.27235949e-01,  -7.07655668e-01,
                         -7.19468355e-01,  -6.35898173e-01,  -5.81569433e-01,
                         -5.76858759e-01,  -5.94265997e-01,  -6.30082250e-01,
                         -6.96547925e-01,  -7.06815422e-01,  -5.90600312e-01,
                         -5.78765929e-01,  -6.91700935e-01,  -6.32754266e-01,
                         -6.07749939e-01,  -7.04558790e-01,  -4.15756792e-01,
                         -8.23689103e-02,  -3.69979054e-01,  -6.75230920e-01,
                         -5.83392143e-01,  -6.34760380e-01,  -7.44548559e-01,
                         -6.14342272e-01,  -5.86981177e-01,  -6.91192925e-01,
                         -6.76303446e-01,  -6.06891990e-01,  -5.71790636e-01,
                         -6.79599404e-01,  -7.75438905e-01,  -4.17152315e-01,
                         -1.65758058e-02,  -2.79430926e-01,  -6.71475708e-01,
                         -6.12833261e-01,  -6.15930557e-01,  -7.41424382e-01,
                         -3.78187031e-01,  -9.81595553e-03,  -4.33637977e-01,
                         -8.16498756e-01,  -3.57446849e-01,  -4.82103266e-02,
                         -4.34657305e-01,  -6.91893280e-01,  -6.74141049e-01,
                         -5.98159492e-01,  -2.25474104e-01,  -1.13410436e-01,
                         -6.56957269e-01,  -7.60244727e-01,  -1.49563894e-01,
                         -6.00585006e-02,  -5.53436100e-01,  -6.53238773e-01,
                         -5.68583727e-01,  -7.85056949e-01,  -6.52922750e-01,
                         -9.58855301e-02,  -1.48832873e-01,  -6.73925519e-01,
                         -7.00364947e-01,  -5.17234206e-01,  -6.32271349e-01,
                         -6.74548388e-01,  -5.77491760e-01,  -6.07636094e-01,
                         -6.77706122e-01,  -7.02672482e-01,  -6.70249641e-01,
                         -5.94376385e-01,  -6.14591241e-01,  -6.04617774e-01,
                         -3.04757416e-01,   6.85883239e-02,   4.32708338e-02,
                         -4.09328967e-01,  -7.33621001e-01,  -5.00834525e-01,
                         -2.75647398e-02,   1.43982098e-01,   2.61122193e-02,
                         -1.81689002e-02,   5.52644134e-02,   4.14384566e-02,
                         -4.19681007e-03,   2.58014705e-02,   5.18792942e-02,
                          1.03782155e-01,   1.38575494e-01,   3.06277201e-02,
                         -3.91820669e-02,   6.45357184e-04,   4.23876345e-02,
                          1.23665906e-01,   5.68461269e-02,  -9.44790095e-02,
                          8.31702650e-02,   8.97401273e-02,  -4.29196566e-01,
                         -5.01845181e-01,   1.22075072e-02,   1.47716269e-01,
                         -1.85124166e-02,   3.77899483e-02,   1.09669261e-01,
                          2.43557580e-02,  -6.71994872e-03,   1.03823490e-01,
                          1.99266747e-02,  -3.90657514e-01,  -4.45799530e-01,
                          1.84465554e-02,   1.55611098e-01,  -4.05188836e-03,
                          9.85431150e-02,  -2.64013894e-02,  -4.87528414e-01,
                         -4.38327938e-01,  -6.79533603e-03,   9.18980092e-02,
                          1.71700623e-02,   3.92706878e-02,   6.75430298e-02,
                          1.13683686e-01,   6.81157410e-02,  -8.36777687e-02,
                         -3.91352363e-02,   1.22646734e-01,   1.16703644e-01,
                          2.68652253e-02,  -1.22830737e-02,   8.45266134e-02,
                          1.76011786e-01,  -1.55530125e-01,  -5.81221759e-01,
                         -3.73997450e-01,   1.02364376e-01,   1.79075509e-01,
                          4.93284762e-02,   1.94369908e-03,  -2.08852533e-02,
                          6.43956382e-03,   1.03002004e-01,   7.08941594e-02,
                         -6.73303455e-02,   5.46486117e-02,   1.98108509e-01,
                         -2.00339332e-01,  -5.39839566e-01,  -1.78906187e-01,
                          1.33052692e-01,   3.70322703e-03,  -1.98208578e-02,
                          6.65365532e-02,   4.46703658e-02,   4.14962322e-02,
                          3.39688621e-02,  -4.16405015e-02,  -7.70505965e-02,
                          4.98346053e-02,   9.86635461e-02,  -3.04574341e-01,
                         -5.09378314e-01,   5.76607287e-02,   2.22253203e-01,
                         -4.41437364e-01,  -5.20912707e-01,  -6.58510923e-02,
                         -2.75647759e-01,  -5.55289209e-01,  -8.12283754e-02,
                          1.81105509e-01,  -3.72497469e-01,  -6.10187948e-01,
                         -1.09495157e-02,   2.17588142e-01,  -3.51167679e-01,
                         -5.58328450e-01,  -1.15799405e-01,   1.05877422e-01,
                          2.11699633e-03,   8.66450965e-02,   1.72376543e-01,
                         -3.08828056e-01,  -9.04481351e-01,  -5.94654799e-01,
                          3.30345258e-02,  -2.64914185e-01,  -6.51005864e-01,
                         -8.87972489e-02,   2.62632906e-01,  -3.03741157e-01,
                         -7.24240303e-01,  -6.68693841e-01,  -6.22100770e-01,
                         -3.87954295e-01,   6.21615909e-02,   8.86263102e-02,
                         -4.18951541e-01,  -7.95594096e-01,  -5.85284650e-01,
                         -1.41730100e-01,   1.12426057e-02,   2.66483650e-02,
                          4.31161635e-02,  -3.28984380e-01,  -8.07226658e-01,
                         -6.04522586e-01,  -1.18648648e-01,  -2.88676292e-01,
                         -7.47964323e-01,  -5.34734905e-01,  -3.63449790e-02,
                         -2.45946556e-01,  -5.50100386e-01,  -4.28427532e-02,
                          2.10561007e-01,  -4.32945102e-01,  -6.42694950e-01,
                         -1.97914124e-01,  -2.38213301e-01,  -6.38853908e-01,
                         -6.10440433e-01,  -1.38763070e-01,   1.56071946e-01,
                         -2.56306350e-01,  -6.63760960e-01,  -2.69060582e-01,
                         -9.49750766e-02,  -6.90817535e-01,  -7.14609563e-01,
                         -8.17921460e-02,  -1.84283197e-01,  -6.55572832e-01,
                         -2.78872073e-01,   1.91329613e-01,  -2.43032083e-01,
                         -5.99079192e-01,  -2.06830472e-01,  -1.22029923e-01,
                         -6.53633177e-01,  -7.95838892e-01,  -2.68195063e-01,
                          1.69866249e-01,  -7.72706121e-02,  -5.58261812e-01,
                         -4.23867732e-01,   2.51746252e-02,   8.13946426e-02,
                          2.13999092e-03,   2.61187111e-03,  -8.37145969e-02,
                         -4.28989865e-02,   5.62145449e-02,  -2.26110563e-01,
                         -6.93629205e-01,  -7.58956671e-01,  -3.14048141e-01,
                          1.15432598e-01,  -2.24997588e-02,  -5.58517456e-01,
                         -7.99271286e-01,  -4.47729290e-01,  -2.10926663e-02,
                          1.50312623e-03,  -3.59115265e-02,  -6.06192611e-02,
                         -5.36405325e-01,  -8.62903178e-01,  -3.97190630e-01,
                         -1.39442474e-01,  -5.58166385e-01,  -5.31218946e-01,
                          8.30576420e-02,   8.65840763e-02,  -5.74071348e-01,
                         -6.05494201e-01,   7.32826367e-02,   8.00559670e-02,
                         -5.28935134e-01,  -4.78637159e-01,  -1.85103804e-01,
                         -4.95797843e-01,  -5.49748242e-01,   1.56053212e-02,
                          7.22858831e-02,  -4.67695326e-01,  -4.74083871e-01,
                          1.01967901e-02,  -8.03076103e-02,  -5.98201990e-01,
                         -5.11011064e-01,   1.19018583e-02,   1.27722979e-01,
                         -5.14148138e-02,  -7.14143068e-02,  -1.88068766e-02,
                         -3.74655165e-02,  -4.28515710e-02,  -1.09678144e-02,
                         -2.76705232e-02,  -6.34403676e-02,  -3.31009030e-02,
                         -3.51326168e-02,  -1.02943927e-01,  -7.36715868e-02,
                          2.54596397e-02,   4.26740944e-02,  -1.21634165e-02,
                         -7.31504932e-02,  -8.08659941e-02,  -3.54688764e-02,
                         -5.79558825e-03,   4.95803962e-03,  -2.99005732e-02,
                         -9.78204161e-02,  -4.62400280e-02,   5.20610586e-02,
                         -9.25250165e-03,  -1.02403313e-01,  -5.94350174e-02,
                         -7.31490180e-03,  -4.38732468e-02,  -5.61290681e-02,
                         -2.68751662e-03,  -1.72989424e-02,  -8.30596611e-02,
                         -4.80245277e-02,   8.75649136e-03,  -1.87748503e-02,
                         -4.04477082e-02,  -2.37809680e-02,  -8.29376653e-03,
                         -3.98546420e-02,  -9.83724967e-02,  -3.53151262e-02,
                          2.34586280e-02,  -9.09330994e-02,  -8.66693258e-02,
                          2.60649826e-02,  -3.76966223e-02,  -1.82822440e-02,
                         -1.56495464e-03,  -4.09181535e-01,  -6.28862500e-01,
                         -1.86462209e-01,   1.37182876e-01,  -7.55040953e-03,
                         -9.80625600e-02,  -3.38068865e-02,  -3.27040404e-02,
                         -2.60779690e-02,   8.74683075e-03,  -7.67266676e-02,
                         -1.03120811e-01,   1.02547124e-01,   3.45313856e-05,
                         -5.11389136e-01,  -5.07974982e-01,  -1.41346037e-01,
                         -4.27023768e-01,  -8.49949598e-01,  -7.11511612e-01,
                         -6.89552128e-01,  -8.09857249e-01,  -3.83938581e-01,
                          9.29537639e-02,  -1.83418263e-02,  -1.77968994e-01,
                          5.21782115e-02,   7.11919665e-02,  -5.37941158e-01,
                         -9.64833021e-01,  -5.70028245e-01,  -5.98759577e-02,
                          5.70890717e-02,   4.98827398e-02,  -2.17225179e-01,
                         -6.29792750e-01,  -4.70712721e-01,   3.03536933e-02,
                          1.21898882e-01,  -3.95325944e-02,  -7.10406974e-02,
                         -4.71916199e-02,  -5.60587570e-02,  -4.02206033e-02,
                          1.31146247e-02,  -1.13444932e-01,  -5.16059935e-01,
                         -7.16872931e-01,  -4.46339309e-01,  -1.45043477e-01,
                         -2.21292470e-02,   5.14155217e-02,  -1.46770135e-01,
                         -6.56720221e-01,  -8.45020652e-01,  -3.90575469e-01,
                          4.95582409e-02,  -1.23189306e-02,  -3.50269563e-02,
                          1.41250208e-01,  -1.97112441e-01,  -6.67534947e-01,
                         -3.47875476e-01,  -8.97744894e-02,  -6.65667832e-01,
                         -8.60468626e-01,  -2.12571070e-01,  -7.10165128e-02,
                         -7.30569541e-01,  -8.89413178e-01,  -2.53137559e-01,
                         -1.16014823e-01,  -6.53425694e-01,  -4.30918872e-01,
                          2.83771396e-01,  -3.61721739e-02,  -6.10443890e-01,
                         -3.20580035e-01,  -2.28349015e-01,  -5.52986920e-01,
                         -3.23991269e-01,  -2.02141508e-01,  -7.82585323e-01,
                         -9.05378580e-01,  -1.81725815e-01,   2.69629210e-01,
                         -1.06177054e-01,  -7.01379895e-01,  -8.55267107e-01,
                         -6.96824610e-01,  -6.50441766e-01,  -6.72226846e-01,
                         -6.57184422e-01,  -7.05242217e-01,  -7.20137417e-01,
                         -6.48512065e-01,  -6.56946123e-01,  -7.41876006e-01,
                         -7.77121127e-01,  -7.22391367e-01,  -6.35881960e-01,
                         -6.57079458e-01,  -7.46784627e-01,  -7.37704694e-01,
                         -6.97982013e-01,  -7.29364157e-01,  -7.53986120e-01,
                         -7.39018202e-01,  -7.31232703e-01,  -7.50014544e-01,
                         -7.37967551e-01,  -6.44964099e-01,  -6.07661307e-01,
                         -6.96639776e-01,  -7.36392140e-01,  -7.08088458e-01,
                         -7.33024120e-01,  -7.47031808e-01,  -7.03601062e-01,
                         -6.78964853e-01,  -6.90773070e-01,  -7.28448570e-01,
                         -7.64103174e-01,  -7.52290249e-01,  -7.42521882e-01,
                         -7.63334036e-01,  -7.20195055e-01,  -6.41619682e-01,
                         -6.76618934e-01,  -7.55941033e-01,  -7.34962344e-01,
                         -6.95338309e-01,  -7.08379209e-01,  -7.23488867e-01,
                         -7.30738163e-01,  -7.11257398e-01,  -7.01618552e-01,
                         -7.68931985e-01,  -7.91745484e-01,  -6.94625378e-01,
                         -6.23962581e-01,  -7.03789949e-01,  -8.47962916e-01,
                         -7.83833683e-01,  -6.23776019e-01,  -7.72082806e-01,
                         -7.75766194e-01,  -2.41016701e-01,  -1.40763789e-01,
                         -7.16796100e-01,  -8.24330926e-01,  -5.69914758e-01,
                         -7.63485432e-01,  -8.01963687e-01,  -2.96444803e-01,
                         -2.15261281e-01,  -7.54932523e-01,  -8.21648896e-01,
                         -2.38098875e-01,  -1.51728481e-01,  -7.71406651e-01,
                         -8.88049781e-01,  -2.78696477e-01,  -1.70685545e-01,
                         -7.61855185e-01,  -8.40766788e-01,  -2.33473718e-01,
                         -1.18896924e-01,  -6.64352179e-01,  -8.60558569e-01,
                         -6.87735736e-01,  -8.02254617e-01,  -7.78310597e-01,
                         -2.51698703e-01,  -1.64736211e-01,  -7.80071378e-01,
                         -8.78460050e-01,  -2.57307112e-01,  -1.68088824e-01,
                         -7.26919770e-01,  -8.82999003e-01,  -6.46417916e-01,
                         -6.56833053e-01,  -7.81567574e-01,  -7.83737421e-01,
                         -7.37887621e-01,  -6.93434179e-01,  -7.68962920e-01,
                         -8.11152399e-01,  -6.76041603e-01,  -7.55416811e-01,
                         -8.36823165e-01,  -4.08870369e-01,  -1.93391919e-01,
                         -6.16760194e-01,  -8.39888811e-01,  -6.94030285e-01,
                         -6.77541971e-01,  -7.65151203e-01,  -8.00540805e-01,
                         -6.09326720e-01,  -1.20443195e-01,   8.64228308e-02,
                         -3.59237105e-01,  -8.01431835e-01,  -7.36689508e-01,
                         -6.84866965e-01,  -8.66058230e-01,  -6.45482719e-01,
                         -2.06472352e-01,  -3.68888021e-01,  -7.76526213e-01,
                         -7.82527685e-01,  -6.88656271e-01,  -7.45429516e-01,
                         -7.71832526e-01,  -7.44179964e-01,  -7.53416181e-01,
                         -7.40271270e-01,  -6.76042080e-01,  -7.77149439e-01,
                         -8.44569325e-01,  -4.31149006e-01,  -1.39292821e-01,
                         -5.00761867e-01,  -8.23983192e-01,  -8.34188640e-01,
                         -6.86503112e-01,  -2.73690552e-01,  -2.37149686e-01,
                         -8.02249908e-01,  -8.33663523e-01,  -2.16916159e-01,
                         -1.62093684e-01,  -7.67544270e-01,  -8.76565576e-01,
                         -2.99844444e-01,  -1.74970135e-01,  -6.45531833e-01,
                         -7.93632388e-01,  -6.94924116e-01,  -7.50961602e-01,
                         -7.63528109e-01,  -7.24132180e-01,  -7.19345689e-01,
                         -8.00659120e-01,  -7.89602220e-01,  -3.03775132e-01,
                         -9.07044634e-02,  -7.35208154e-01,  -9.43182111e-01,
                         -2.98174858e-01,  -1.26290247e-01,  -6.16449535e-01,
                         -8.46475244e-01,  -6.97522998e-01,  -7.17747808e-01,
                         -8.00600111e-01,  -3.75084668e-01,   9.74197090e-02,
                         -9.11706612e-02,  -5.60837328e-01,  -8.45993817e-01,
                         -6.90235436e-01,  -1.93416595e-01,  -2.59121537e-01,
                         -7.68877268e-01,  -7.52424240e-01,  -5.86732328e-01,
                         -7.08762646e-01,  -7.08025992e-01,  -6.61504507e-01,
                         -6.83160424e-01,  -6.52877629e-01,  -7.23470092e-01,
                         -6.90088272e-01,  -2.57979989e-01,   1.36418074e-01,
                         -5.69822751e-02,  -5.91614962e-01,  -7.75137961e-01,
                         -6.45332813e-01,  -6.70898199e-01,  -6.89404309e-01,
                         -6.19804502e-01,  -7.28795528e-01,  -7.05264926e-01,
                         -2.63976038e-01,   1.34153128e-01,  -2.25415565e-02,
                         -6.27455533e-01,  -9.01558340e-01,  -4.11633879e-01,
                         -6.66436600e-03,  -4.43700343e-01,  -8.99180710e-01,
                         -4.77349013e-01,  -1.99066456e-02,  -4.29266632e-01,
                         -8.36612821e-01,  -6.34054959e-01,  -6.33270741e-01,
                         -7.97262192e-01,  -3.81289244e-01,  -2.84857526e-02,
                         -4.95251030e-01,  -9.19530332e-01,  -4.71938699e-01,
                          1.29996398e-02,  -4.09287125e-01,  -9.17797387e-01,
                         -5.04990458e-01,  -2.45292131e-02,  -3.77097040e-01,
                         -8.01519394e-01,  -7.26563752e-01,  -6.30101979e-01,
                         -6.58954680e-01,  -6.61596298e-01,  -7.07040012e-01,
                         -7.01133549e-01,  -6.45480096e-01,  -6.82798803e-01,
                         -6.81764483e-01,  -6.69525862e-01,  -7.10710406e-01,
                         -6.53090179e-01,  -7.12401986e-01,  -7.61507452e-01,
                         -3.27152133e-01,  -1.39648154e-01,  -5.43821812e-01,
                         -3.93938243e-01,  -3.49113978e-02,  -5.87864280e-01,
                         -9.04517114e-01,  -2.59898126e-01,  -1.15813255e-01,
                         -5.43317378e-01,  -3.10661376e-01,  -9.93309543e-02,
                         -7.10107803e-01,  -8.52116227e-01,  -1.46748781e-01,
                         -1.16606034e-01,  -6.43371940e-01,  -3.10486346e-01,
                          2.16411278e-01,  -2.24574417e-01,  -5.99206626e-01,
                         -1.93597361e-01,  -2.15861991e-01,  -6.48402631e-01,
                         -2.13159025e-01,   2.54425257e-01,  -3.18222553e-01,
                         -5.96550286e-01,  -1.88384786e-01,  -3.27249378e-01,
                         -4.99522328e-01,  -1.09819211e-01,  -3.00311297e-01,
                         -8.91939700e-01,  -5.83136022e-01,  -2.15328559e-02,
                         -3.36671293e-01,  -7.79724956e-01,  -6.18953407e-01,
                         -6.08251989e-01,  -8.38053465e-01,  -4.69353050e-01,
                         -8.53959098e-02,  -4.40212011e-01,  -5.24183512e-01,
                          2.79458761e-02,   8.42985660e-02,  -4.61858541e-01,
                         -7.36518502e-01,  -6.56990409e-01,  -6.51742697e-01,
                         -6.88959479e-01,  -6.39564633e-01,  -7.27187097e-01,
                         -7.38825202e-01,  -2.96267182e-01,  -9.73558873e-02,
                         -5.59167445e-01,  -7.66731620e-01,  -5.78219533e-01,
                         -7.18801141e-01,  -7.73202658e-01,  -2.50961214e-01,
                         -6.67441115e-02,  -6.50073946e-01,  -8.42690170e-01,
                         -2.56363958e-01,  -8.80044997e-02,  -5.93699038e-01,
                         -7.92384028e-01,  -6.30201578e-01,  -6.41523302e-01,
                         -7.05651164e-01,  -6.74665630e-01,  -6.72012806e-01,
                         -6.77644849e-01,  -6.69127524e-01,  -6.86858296e-01,
                         -6.98990166e-01,  -6.79882944e-01,  -6.61607921e-01,
                         -6.54645145e-01,  -6.46477401e-01,  -6.79213881e-01,
                         -7.04609752e-01,  -6.43305302e-01,  -6.84710264e-01,
                         -7.55950212e-01,  -3.71679336e-01,   1.59839422e-01,
                          2.50594504e-02,  -5.21546304e-01,  -7.47527182e-01,
                         -6.88878596e-01,  -6.49144113e-01,  -6.70923352e-01,
                         -6.87932909e-01,  -6.47078991e-01,  -6.79074764e-01,
                         -7.55695343e-01,  -4.91143972e-01,  -2.51621790e-02,
                          8.73635113e-02,  -1.55010642e-02,  -2.23468826e-03,
                          8.67226347e-03,   2.03449056e-02,   1.70169733e-02,
                         -8.33122805e-02,   1.78804267e-02,   1.34145036e-01,
                         -2.77263016e-01,  -6.12501144e-01,  -2.40161896e-01,
                          1.25277877e-01,   1.89010128e-02,  -8.14767778e-02,
                          4.94685546e-02,   1.23380981e-01,  -1.72992617e-01,
                         -5.58931649e-01,  -3.80040407e-01,   7.63482973e-02,
                          9.58195776e-02,  -5.73445857e-02,  -1.28393164e-02,
                          2.58517284e-02,   2.72638202e-02,   2.36996282e-02,
                         -3.74830328e-02,  -2.76816785e-02,   2.84113865e-02,
                          1.20543847e-02,  -3.81748145e-03,  -2.12562340e-03,
                          2.58725882e-03,   2.21681260e-02,   2.28405907e-03,
                         -1.81726292e-02,  -5.04243595e-04,   5.46051934e-03,
                          1.09207472e-02,   1.22339614e-02,   6.13898132e-03,
                          8.16474017e-03,  -9.01856646e-03,   4.49328125e-03,
                          3.16668302e-02,   6.93940418e-03,   9.32939351e-03,
                         -1.26420809e-02,  -2.04251334e-02,   1.16041966e-01,
                         -4.29736003e-02,  -5.20967901e-01,  -4.63053912e-01,
                          4.71964478e-03,   7.94421360e-02,  -3.73844020e-02,
                         -4.36742231e-03,  -4.93033789e-03,  -1.96313169e-02,
                          3.76964770e-02,   4.55561616e-02,  -3.43886316e-02,
                         -7.24319927e-03,   1.12454295e-01,  -1.67176500e-01,
                         -6.17212474e-01,  -3.48948389e-01,   1.35688871e-01,
                          1.12441890e-02,  -2.42015682e-02,   1.41984046e-01,
                         -2.81202644e-01,  -6.44271493e-01,  -2.42885664e-01,
                          1.11227781e-01,   2.37329919e-02,  -5.22581041e-02,
                          1.60457473e-03,   8.90102834e-02,  -5.48228733e-02,
                         -5.49788713e-01,  -7.93481171e-01,  -6.28869593e-01,
                         -6.92947984e-01,  -7.55684555e-01,  -2.69081175e-01,
                         -3.86388674e-02,  -6.31183267e-01,  -8.80802214e-01,
                         -2.70121187e-01,  -9.83364955e-02,  -5.91213286e-01,
                         -4.23105657e-01,   1.86838031e-01,   3.63878114e-03,
                         -5.46121240e-01,  -7.08183527e-01,  -7.69423246e-01,
                         -6.02233529e-01,  -1.09136514e-01,  -1.86364636e-01,
                         -8.13536584e-01,  -7.51715124e-01,  -1.18258327e-01,
                         -1.73926905e-01,  -7.11997390e-01,  -7.13307738e-01,
                         -5.67631543e-01,  -8.00966859e-01,  -6.50506616e-01,
                         -8.13581571e-02,  -2.17154354e-01,  -8.38024139e-01,
                         -6.95643902e-01,  -7.48869926e-02,  -1.83041990e-01,
                         -7.29216933e-01,  -7.28528082e-01,  -6.12434208e-01,
                         -8.21254790e-01,  -5.55280447e-01,  -7.24225044e-02,
                         -3.58639896e-01,  -5.65729916e-01,  -1.25994742e-01,
                         -2.97730803e-01,  -9.03809011e-01,  -5.68803728e-01,
                          8.39582179e-04,  -3.48012775e-01,  -8.15792501e-01,
                         -6.83891475e-01,  -5.83408713e-01,  -7.49752939e-01,
                         -5.59288383e-01,   1.42366132e-02,   1.32516935e-01,
                         -4.09150481e-01,  -6.37810528e-01,  -1.22676514e-01,
                          1.96031481e-01,  -2.23748401e-01,  -7.33262181e-01,
                         -7.62346268e-01,  -3.27490658e-01,   1.26723439e-01,
                         -2.89961621e-02,  -5.47771513e-01,  -4.56498742e-01,
                          1.10485636e-01,   4.86867800e-02,  -5.57816327e-01,
                         -5.39087713e-01,   5.29833548e-02,   1.05949372e-01,
                         -4.10868287e-01,  -7.68410981e-01,  -6.83074474e-01,
                         -1.48395315e-01,   2.07346469e-01,  -2.27522060e-01,
                         -5.97357512e-01,  -2.63736129e-01,   3.27506028e-02,
                          4.89210747e-02,  -3.35153490e-02,  -4.20971632e-01,
                         -7.53050566e-01,  -6.81039512e-01,  -6.33726895e-01,
                         -6.97149396e-01,  -6.49376690e-01,  -6.82381690e-01,
                         -7.36476719e-01,  -4.12419498e-01,   2.83794273e-02,
                          3.11528239e-02,  -7.51346871e-02,   8.44841301e-02,
                         -4.93179262e-02,  -5.61572850e-01,  -7.44925857e-01,
                         -6.30704939e-01,  -6.53899312e-01,  -7.33671725e-01,
                         -6.90945327e-01,  -6.00861669e-01,  -7.10873246e-01,
                         -7.86289454e-01,  -3.52671415e-01,  -1.11168683e-01,
                         -5.34970820e-01,  -4.50014621e-01,   1.68203309e-01,
                         -4.22027335e-02,  -6.09011650e-01,  -3.94760162e-01,
                          2.96350606e-02,   6.35741055e-02,   1.09388772e-02,
                         -2.31388986e-01,  -7.48281717e-01,  -7.62797892e-01,
                         -1.78554028e-01,  -1.42784879e-01,  -7.07648277e-01,
                         -7.76748121e-01,  -5.77972412e-01,  -7.58581042e-01,
                         -6.48740888e-01,  -1.37609422e-01,  -2.15986013e-01,
                         -7.16460764e-01,  -7.52944410e-01,  -6.17573977e-01,
                         -7.60579586e-01,  -6.30107701e-01,  -8.52202177e-02,
                          1.00063041e-01,  -9.72389653e-02,  -4.61965660e-03,
                          7.01443702e-02,  -3.75297874e-01,  -5.94302595e-01,
                         -1.57038331e-01,   1.16332866e-01,  -1.67815341e-03,
                         -8.45988560e-03,   1.88028216e-02,  -4.24392968e-02,
                         -2.13750172e-02,   1.39820427e-02,   3.22858989e-02,
                          2.90791551e-03,  -9.88441110e-02,   1.98934022e-02,
                          9.34295207e-02,  -3.51898730e-01,  -6.09175682e-01,
                         -2.06829593e-01,   1.04925409e-01,   2.48456448e-02,
                         -6.13327138e-02,   3.07735521e-02,   9.72773433e-02,
                         -2.35772744e-01,  -5.83449781e-01,  -2.99521744e-01,
                          9.46558118e-02,   2.43753605e-02,  -9.79366452e-02,
                         -6.37807231e-03,   4.11172956e-02,  -3.80394422e-02,
                         -1.82509713e-03,   6.66535497e-02,  -2.67283291e-01,
                         -5.98269165e-01,  -2.69091964e-01,   1.03713103e-01,
                          9.50156711e-03,  -3.49703841e-02,   3.40612791e-02,
                         -3.00933030e-02,  -5.10585606e-02,   1.05693669e-03,
                          2.16223858e-02,  -1.65806815e-03,  -4.76652049e-02,
                         -1.90173797e-02,   2.99497526e-02,  -1.02817931e-03,
                         -3.38780060e-02,  -1.96037721e-02,  -1.11457508e-03,
                         -1.37084089e-02,  -1.76856406e-02,  -1.13158245e-02,
                         -3.17986086e-02,   3.07286847e-02,   3.57496552e-02,
                         -3.37429076e-01,  -7.39064991e-01,  -7.16898143e-01,
                         -6.40895545e-01,  -7.61977196e-01,  -6.12831533e-01,
                         -1.01729222e-01,   1.50713146e-01,  -2.09719270e-01,
                         -7.47543216e-01,  -7.77956963e-01,  -2.84528315e-01,
                          5.43522313e-02,  -4.36224043e-02,  -5.75907417e-02,
                          1.04506552e-01,  -1.91097975e-01,  -6.14883661e-01,
                         -3.17651987e-01,   1.01601541e-01,  -2.97629517e-02,
                         -6.98078349e-02,   9.80640277e-02,  -2.35191882e-01,
                         -6.58104300e-01,  -2.51184851e-01,   2.38059029e-01,
                         -2.15630189e-01,  -6.75528407e-01,  -2.96063632e-01,
                          8.86809081e-02,   1.59194842e-02,  -4.67256345e-02,
                          5.74530801e-03,   6.08510617e-03,  -9.47331544e-03,
                         -9.84032080e-03,  -1.99477933e-02,  -9.00489558e-03,
                          7.35444343e-03,  -2.18380112e-02,  -1.37062073e-02,
                          4.11686338e-02,  -2.96516083e-02,  -5.20342477e-02,
                          1.04222074e-01,  -1.23802662e-01,  -5.96310198e-01,
                         -4.08509016e-01,   6.14813976e-02,   5.57171516e-02,
                         -7.18654171e-02,  -1.41223250e-02,   3.67041305e-02,
                         -3.07134762e-02,  -3.74324024e-02,   9.59594026e-02,
                         -1.29341111e-01,  -5.87098479e-01,  -3.89266819e-01,
                          7.33104572e-02,  -6.46365946e-03,  -4.45027761e-02,
                          1.39638141e-01,  -2.27787182e-01,  -6.19860232e-01,
                         -2.46175289e-01,  -1.33787841e-01,  -7.63837278e-01,
                         -8.05523336e-01,  -1.52632207e-01,  -1.34791523e-01,
                         -6.60045743e-01,  -7.87479758e-01,  -6.59456074e-01,
                         -6.69269085e-01,  -6.94515884e-01,  -6.76333904e-01,
                         -6.70506358e-01,  -6.82028770e-01,  -6.91187382e-01,
                         -6.80372596e-01,  -6.80505574e-01,  -6.87522173e-01,
                         -6.94873214e-01,  -7.01676846e-01,  -6.81579888e-01,
                         -6.70985281e-01,  -6.79182410e-01,  -6.83515906e-01,
                         -6.91638052e-01,  -6.83592141e-01,  -6.70220852e-01,
                         -6.77083015e-01,  -6.92287028e-01,  -6.96074069e-01,
                         -6.80743992e-01,  -6.72731221e-01,  -6.78360462e-01,
                         -6.86260283e-01,  -6.90128803e-01,  -6.79239452e-01,
                         -6.79140866e-01,  -6.87573910e-01,  -6.80658042e-01,
                         -6.76423371e-01,  -6.78229570e-01,  -6.79922819e-01,
                         -6.78910077e-01,  -6.81456208e-01,  -6.92301989e-01,
                         -6.87900662e-01,  -6.83002293e-01,  -6.87239408e-01,
                         -6.75797939e-01,  -6.71839535e-01,  -6.79220438e-01,
                         -6.78528011e-01,  -6.82542861e-01,  -6.81568980e-01,
                         -6.80323422e-01,  -6.86601281e-01,  -6.75898194e-01,
                         -6.75664485e-01,  -6.88082099e-01,  -6.76016212e-01,
                         -6.75133109e-01,  -6.80968404e-01,  -6.70939684e-01,
                         -6.81531250e-01,  -6.87439799e-01,  -6.77912652e-01,
                         -6.79656267e-01,  -6.75796747e-01,  -6.80338442e-01,
                         -6.84177101e-01,  -6.69732332e-01,  -6.74275637e-01,
                         -6.81463659e-01,  -6.76325083e-01,  -6.80041552e-01,
                         -6.73618257e-01,  -6.68911219e-01,  -6.85627878e-01,
                         -6.87839270e-01,  -6.76899016e-01,  -6.76818311e-01,
                         -6.77288473e-01,  -6.79617882e-01,  -6.80311739e-01,
                         -6.75553024e-01,  -6.63551092e-01,  -6.70832992e-01,
                         -7.10034728e-01,  -6.49519086e-01,  -6.45612359e-01,
                         -8.08552802e-01,  -5.34043550e-01,  -1.11921065e-01,
                         -3.81819367e-01,  -4.94995356e-01,  -1.28739148e-01,
                         -3.53844941e-01,  -7.81810403e-01,  -7.04386711e-01,
                         -6.19211793e-01,  -6.99854314e-01,  -6.98063016e-01,
                         -6.21789694e-01,  -6.87326610e-01,  -7.82363772e-01,
                         -4.17978257e-01,  -6.24131635e-02,  -4.23418224e-01,
                         -7.88681149e-01,  -6.73753083e-01,  -6.53734207e-01,
                         -6.99953198e-01,  -6.22376859e-01,  -7.40863562e-01,
                         -6.95733309e-01,  -2.00554907e-01,  -1.35220170e-01,
                         -6.52815998e-01,  -7.60623693e-01,  -5.85949838e-01,
                         -7.71140873e-01,  -6.49781346e-01,  -1.08659692e-01,
                         -2.62024403e-01,  -6.42956138e-01,  -1.33777902e-01,
                          2.44718954e-01,  -3.43355298e-01,  -6.12238884e-01,
                         -1.27223298e-01,  -1.94893599e-01,  -8.20781291e-01,
                         -7.02310860e-01,  -6.74602240e-02,  -1.82539776e-01,
                         -8.07026982e-01,  -7.06168354e-01,  -1.17945224e-01,
                         -1.92908660e-01,  -6.36620164e-01,  -7.50173271e-01,
                         -7.25619614e-01,  -4.28028077e-01,  -4.86343764e-02,
                         -4.09649432e-01,  -8.88616502e-01,  -4.75210071e-01,
                         -1.35804834e-02,  -3.91819000e-01,  -7.93140113e-01,
                         -6.41057551e-01,  -6.30870283e-01,  -7.90645242e-01,
                         -4.12800074e-01,  -9.08933673e-03,  -4.42524195e-01,
                         -8.95758092e-01,  -4.40304816e-01,  -2.42090169e-02,
                         -3.96984369e-01,  -7.53575504e-01,  -6.98707104e-01,
                         -6.00748241e-01,  -6.62384391e-01,  -7.93832362e-01,
                         -5.19099653e-01,  -7.90783986e-02,  -3.33490133e-01,
                         -5.96863508e-01,  -2.32160427e-02,   1.96249947e-01,
                         -4.44419891e-01,  -5.32506645e-01,  -7.34770447e-02,
                         -3.20055068e-01,  -7.88578987e-01,  -6.59306943e-01,
                         -6.01889610e-01,  -7.86638737e-01,  -4.39272642e-01,
                          1.17287859e-02,  -4.18639272e-01,  -9.08196986e-01,
                         -4.11678851e-01,  -4.04035486e-02,  -4.72314775e-01,
                         -4.37332511e-01,  -2.81260703e-02,  -4.89809513e-01,
                         -9.08917427e-01,  -3.09675395e-01,  -7.35785142e-02,
                         -5.09511948e-01,  -3.35070580e-01,  -1.40322119e-01,
                         -5.33330739e-01,  -3.43967587e-01,   2.08764046e-01,
                         -4.75163758e-02,  -6.32992506e-01,  -7.29769289e-01,
                         -5.90840220e-01,  -7.06199110e-01,  -7.20381021e-01,
                         -2.35147089e-01,  -7.19498098e-02,  -6.01408362e-01,
                         -8.24923456e-01,  -3.60677272e-01,   1.23216316e-01,
                          5.20563088e-02,  -4.43336010e-01,  -7.30300725e-01,
                         -6.66510701e-01,  -6.28984213e-01,  -6.72566593e-01,
                         -6.64552212e-01,  -6.56904995e-01,  -6.62410855e-01,
                         -6.51773274e-01,  -6.61948502e-01,  -6.59656763e-01,
                         -6.66371346e-01,  -6.73932016e-01,  -6.01511300e-01,
                         -6.79845333e-01,  -7.73271143e-01,  -3.72527122e-01,
                         -5.83304167e-02,  -4.48339134e-01,  -7.69913971e-01,
                         -6.42210126e-01,  -6.29098535e-01,  -6.84571385e-01,
                         -6.20562911e-01,  -7.27104306e-01,  -6.73203528e-01,
                         -1.80154935e-01,  -1.30622387e-01,  -6.58719540e-01,
                         -7.41607487e-01,  -5.68688691e-01,  -7.55437791e-01,
                         -6.28411055e-01,  -1.14840083e-01,  -2.05145881e-01,
                         -6.85182869e-01,  -7.35336006e-01,  -6.16466999e-01,
                         -6.64132059e-01,  -6.75029576e-01,  -6.50558412e-01,
                         -6.69395566e-01,  -6.66019559e-01,  -6.54938996e-01,
                         -6.60878062e-01,  -6.67353511e-01,  -6.64089620e-01,
                         -6.50655568e-01,  -6.62656128e-01,  -6.71845496e-01,
                         -6.47051334e-01,  -6.73376381e-01,  -6.72978401e-01,
                         -6.10073924e-01,  -7.29221165e-01,  -7.20845163e-01,
                         -2.44931892e-01,  -9.76181105e-02,  -5.67755699e-01,
                         -7.69993901e-01,  -6.33515358e-01,  -6.49905384e-01,
                         -6.88963234e-01,  -6.52175367e-01,  -6.55802369e-01,
                         -6.67206645e-01,  -6.65825129e-01,  -6.68789387e-01,
                         -6.72481656e-01,  -6.67974532e-01,  -6.57803833e-01,
                         -6.63073480e-01,  -6.66805744e-01,  -6.65690243e-01,
                         -6.77300513e-01,  -6.70306563e-01,  -6.52062953e-01,
                         -6.64394200e-01,  -6.76795483e-01,  -6.68215692e-01,
                         -6.67229891e-01,  -6.68695748e-01,  -6.66735232e-01,
                         -6.71494067e-01,  -6.71600223e-01,  -6.64466381e-01,
                         -6.58679843e-01,  -6.63629353e-01,  -6.74628854e-01,
                         -6.72362685e-01,  -6.68722510e-01,  -6.70158207e-01,
                         -6.69351697e-01,  -6.73486829e-01,  -6.71203554e-01,
                         -6.67407811e-01,  -6.72372639e-01,  -6.68223500e-01,
                         -6.65472627e-01,  -6.73677385e-01,  -6.76909149e-01,
                         -6.72760248e-01,  -6.66855454e-01,  -6.68670058e-01,
                         -6.75158799e-01,  -6.72212422e-01,  -6.64353430e-01,
                         -6.66579366e-01,  -6.76006496e-01,  -6.76557422e-01,
                         -6.76135838e-01,  -6.78178430e-01,  -6.70172274e-01,
                         -6.68011606e-01,  -6.72328413e-01,  -6.69375598e-01,
                         -6.70594454e-01,  -6.74487948e-01,  -6.75317287e-01,
                         -6.75506115e-01,  -6.76426649e-01,  -6.78244889e-01,
                         -6.73668206e-01,  -6.71083093e-01,  -6.71760559e-01,
                         -6.68773115e-01,  -6.75094247e-01,  -6.78584397e-01,
                         -6.73453271e-01,  -6.75990045e-01,  -6.75835550e-01,
                         -6.75091505e-01,  -6.75566733e-01,  -6.69911444e-01,
                         -6.73009336e-01,  -6.78726494e-01,  -6.78440630e-01,
                         -6.74896300e-01,  -6.67367578e-01,  -6.74063087e-01,
                         -6.82700992e-01,  -6.77980006e-01,  -6.80327058e-01,
                         -6.76330745e-01,  -6.65165603e-01,  -6.71511471e-01,
                         -6.81134582e-01,  -6.82998836e-01,  -6.80002630e-01,
                         -6.78388059e-01,  -6.80527031e-01,  -6.72268033e-01,
                         -6.64155006e-01,  -6.70368552e-01,  -6.83918834e-01,
                         -6.86537504e-01,  -6.71597660e-01,  -6.73074484e-01,
                         -6.85962498e-01,  -6.86079800e-01,  -6.74820483e-01,
                         -6.58334434e-01,  -6.91803455e-01,  -6.87450588e-01,
                         -6.22726798e-01,  -7.42575705e-01,  -7.28088737e-01,
                         -2.61608362e-01,  -1.28765002e-01,  -5.65211892e-01,
                         -7.71786988e-01,  -7.09217548e-01,  -5.71898222e-01,
                         -1.31373286e-01,   1.57908812e-01,  -2.24063143e-01,
                         -7.15372801e-01,  -7.12956011e-01,  -6.16126597e-01,
                         -7.81344891e-01,  -6.31418943e-01,  -1.26584664e-01,
                         -2.15879962e-01,  -7.32949793e-01,  -7.37652719e-01,
                         -5.99485338e-01,  -7.86786973e-01,  -6.02662623e-01,
                         -7.25647360e-02,  -2.51434654e-01,  -8.58152092e-01,
                         -6.60547554e-01,  -8.90100226e-02,  -2.57812381e-01,
                         -6.95222318e-01,  -7.54834116e-01,  -6.99353576e-01,
                         -4.54320371e-01,   1.79831330e-02,   1.02790259e-01,
                         -3.92260134e-01,  -8.46864283e-01,  -6.30441904e-01,
                         -9.75591093e-02,  -2.30871484e-01,  -8.16026866e-01,
                         -7.20250130e-01,  -1.03404500e-01,  -1.67445868e-01,
                         -8.18117976e-01,  -7.53671110e-01,  -1.27290800e-01,
                         -2.32222125e-01,  -6.11629128e-01,  -2.46425569e-01,
                          1.25812262e-01,  -3.26796286e-02,  -4.76191044e-02,
                          7.88143352e-02,  -2.54699796e-01,  -8.00780058e-01,
                         -7.39816844e-01,  -1.71455592e-01,  -1.47829056e-01,
                         -7.38709748e-01,  -8.13816071e-01,  -2.09855825e-01,
                         -8.26508552e-02,  -7.11941600e-01,  -8.56132627e-01,
                         -2.22916916e-01,  -1.32540569e-01,  -6.11980259e-01,
                         -3.80998939e-01,   1.83118507e-01,  -1.08467169e-01,
                         -6.69797063e-01,  -3.94811004e-01,   1.45581409e-01,
                         -5.67304231e-02,  -5.73328614e-01,  -7.17655957e-01,
                         -7.44120419e-01,  -6.81661606e-01,  -2.47099936e-01,
                          8.42743516e-02,  -2.55868454e-02,  -5.61043210e-02,
                          6.07568696e-02,  -2.07754999e-01,  -7.17416525e-01,
                         -8.23510528e-01,  -3.59495014e-01,   1.34848148e-01,
                         -4.05607708e-02,  -5.87832630e-01,  -5.09145200e-01,
                          4.01032493e-02,   6.75527006e-02,  -4.74913210e-01,
                         -8.45141649e-01,  -6.25346720e-01,  -1.34904295e-01,
                          5.13227023e-02,  -3.47272716e-02,  -4.60808836e-02,
                         -1.91366095e-02,  -3.16559114e-02,  -2.12771297e-02,
                         -2.07846351e-02,  -3.06604318e-02,  -2.13686023e-02,
                         -2.51396447e-02,  -4.10321131e-02,  -4.55092750e-02,
                         -2.95624137e-02,  -1.55214081e-02,  -2.64886487e-02,
                         -2.64049042e-02,  -2.18208916e-02,  -4.23135720e-02,
                         -4.41963635e-02,  -2.50524972e-02,  -1.61713939e-02,
                         -2.09459346e-02,  -4.61869389e-02,  -4.82590459e-02,
                         -1.94356199e-02,  -2.06274688e-02,  -3.12686637e-02,
                         -3.19840610e-02,  -3.82141098e-02,  -2.68035326e-02,
                         -1.95460208e-02,  -2.85659693e-02,  -3.01524140e-02,
                         -4.01843190e-02,  -4.32180837e-02,  -2.82940548e-02,
                         -1.88448448e-02,  -1.65311750e-02,  -3.35967578e-02,
                         -4.39641476e-02,  -3.01394165e-02,  -3.37035954e-02,
                         -3.46429199e-02,  -3.12573723e-02,  -3.89818437e-02,
                         -1.24346567e-02,   6.36449142e-04,  -3.07425018e-02,
                         -3.74791212e-02,  -3.19074802e-02,  -2.51735579e-02,
                         -1.15889302e-02,  -2.52069663e-02,  -3.46231833e-02,
                         -3.01009864e-02,  -3.22512016e-02,  -2.12060884e-02,
                         -2.20329557e-02,  -3.44623998e-02,  -2.58000884e-02,
                         -1.25734564e-02,  -2.22600484e-03,  -2.05346476e-02,
                         -5.65218888e-02,  -3.39619517e-02,   2.15430232e-03,
                         -1.68435089e-02,  -3.52107994e-02,  -2.80324854e-02,
                         -2.42011975e-02,  -2.31781527e-02,  -1.88160650e-02,
                         -1.06913047e-02,  -9.01627447e-03,  -1.97664090e-02,
                         -1.91601105e-02,  -6.48619374e-03,  -1.62233021e-02,
                         -3.45670953e-02,  -2.27622595e-02,  -6.61116466e-03,
                         -1.16854133e-02,  -1.07694557e-02,  -7.30970083e-03,
                         -2.91631464e-02,  -4.69287671e-02,  -1.85507890e-02,
                          9.26445331e-03,  -1.57386046e-02,  -3.30796614e-02,
                         -1.05941817e-02,  -5.16252068e-04,  -3.78073729e-03,
                         -1.62170678e-02,  -3.79031599e-02,  -2.59911790e-02,
                          2.62849673e-04,   6.18774537e-03,  -3.83369136e-03,
                         -3.65318693e-02,  -4.21983749e-02,  -7.56852888e-03,
                         -6.39286684e-03,  -1.33142527e-02,   3.06321681e-03,
                         -4.14245157e-03,  -1.51858106e-02,  -1.66978892e-02,
                         -2.76987310e-02,  -1.99555568e-02,  -7.77585199e-03,
                         -1.10866521e-02,  -7.98043422e-03,  -1.71734206e-02,
                         -3.04430313e-02,  -2.11414527e-02,  -1.59801897e-02,
                         -5.62963774e-03,   1.05237709e-02,  -6.41446840e-03,
                         -1.65235698e-02,   3.74361081e-03,   3.55103728e-03,
                         -1.47456201e-02,  -2.34280732e-02,  -1.07589979e-02,
                          1.95812378e-02,   6.17422024e-03,  -3.48845609e-02,
                         -1.83512853e-03,   1.36527810e-02,  -5.62667996e-02,
                          1.36423232e-02,   5.31355776e-02,  -3.40003103e-01,
                         -5.65994799e-01,  -1.83344379e-01,  -1.97588742e-01,
                         -7.77472615e-01,  -7.52954006e-01,  -1.78826213e-01,
                          1.12403832e-01,  -6.81460425e-02,  -6.34265900e-01,
                         -8.71382535e-01,  -3.44587773e-01,  -7.49782398e-02,
                         -4.61033911e-01,  -7.53004789e-01,  -7.96165287e-01,
                         -5.69198608e-01,  -1.47219270e-01,  -2.39496022e-01,
                         -7.08573461e-01,  -7.67526388e-01,  -6.13574505e-01,
                         -6.66860461e-01,  -7.38515854e-01,  -6.98280036e-01,
                         -6.66371167e-01,  -6.83331847e-01,  -6.64585292e-01,
                         -6.64990604e-01,  -7.48662412e-01,  -5.73461115e-01,
                         -4.74400781e-02,   1.54709965e-01,  -2.81850129e-01,
                         -7.29073763e-01,  -7.13881493e-01,  -6.20528877e-01,
                         -7.59568751e-01,  -6.11328423e-01,  -1.15170330e-01,
                         -2.24804088e-01,  -8.29345286e-01,  -7.03051090e-01,
                         -1.04806349e-01,  -2.29930669e-01,  -7.37740099e-01,
                         -7.27774441e-01,  -6.03959799e-01,  -7.68265724e-01,
                         -5.81826448e-01,  -1.26547843e-01,  -3.09985161e-01,
                         -7.55057633e-01,  -6.70719564e-01,  -6.24116540e-01,
                         -8.35446060e-01,  -5.10819972e-01,  -8.65554903e-03,
                         -3.31629664e-01,  -9.00349081e-01,  -6.16417170e-01,
                         -3.05791926e-02,  -3.00577343e-01,  -8.95785093e-01,
                         -6.02560043e-01,  -4.79284711e-02,  -3.48343015e-01,
                         -6.55576229e-01,  -1.26693338e-01,   2.00666517e-01,
                         -2.70210922e-01,  -7.02500939e-01,  -7.40747869e-01,
                         -7.07071781e-01,  -6.79430723e-01,  -6.61095560e-01,
                         -6.81478620e-01,  -7.14434624e-01,  -7.07481444e-01,
                         -6.17836475e-01,  -6.70393229e-01,  -8.17363203e-01,
                         -5.16021430e-01,  -1.05518892e-01,  -3.59676749e-01,
                         -7.64154613e-01,  -7.12645054e-01,  -6.35640562e-01,
                         -7.05270410e-01,  -6.85838938e-01,  -6.64936543e-01,
                         -7.00312912e-01,  -6.95022345e-01,  -6.82141364e-01,
                         -7.10532129e-01,  -6.91810548e-01,  -6.41612351e-01,
                         -7.32035577e-01,  -6.85641408e-01,  -2.48286694e-01,
                         -1.43107891e-01,  -6.30824924e-01,  -8.08130741e-01,
                         -6.25144839e-01,  -7.06513882e-01,  -7.07381010e-01,
                         -2.52512455e-01,   1.20737806e-01,  -9.41523015e-02,
                         -5.75374007e-01,  -7.39347875e-01,  -7.12914467e-01,
                         -6.45199597e-01,  -1.91668004e-01,   1.76294953e-01,
                         -1.83025360e-01,  -6.51217818e-01,  -7.34954536e-01,
                         -6.71364784e-01,  -6.02579772e-01,  -7.27117777e-01,
                         -7.86652148e-01,  -3.33435684e-01,  -7.46811703e-02,
                         -4.95793790e-01,  -7.97066092e-01,  -6.79039299e-01,
                         -6.23432636e-01,  -7.11916089e-01,  -7.01225221e-01,
                         -6.06513023e-01,  -7.04215288e-01,  -7.64888883e-01,
                         -3.33583236e-01,  -4.76072095e-02,  -4.74276006e-01,
                         -7.95130193e-01,  -6.45326972e-01,  -6.21825278e-01,
                         -6.94089353e-01,  -6.45829380e-01,  -7.05846131e-01,
                         -6.64514244e-01,  -2.03501955e-01,   1.63756832e-01,
                         -9.90924910e-02,  -5.79199433e-01,  -7.10326076e-01,
                         -6.44910693e-01,  -6.63360715e-01,  -6.87522829e-01,
                         -6.63063526e-01,  -6.46185279e-01,  -6.47565961e-01,
                         -6.59532070e-01,  -6.49066746e-01,  -6.32871985e-01,
                         -6.57430172e-01,  -6.68145001e-01,  -6.41580522e-01,
                         -6.30665541e-01,  -6.34766757e-01,  -6.42823577e-01,
                         -6.55426502e-01,  -6.60938263e-01,  -6.62578702e-01,
                         -6.57629967e-01,  -6.52313650e-01,  -6.50977671e-01,
                         -6.36334062e-01,  -6.34223104e-01,  -6.54949546e-01,
                         -6.55830562e-01,  -6.45978630e-01,  -6.51620984e-01,
                         -6.62286699e-01,  -6.57869756e-01,  -6.24808133e-01,
                         -6.11353040e-01,  -6.42194688e-01,  -6.58539176e-01,
                         -6.61217391e-01,  -6.44765854e-01,  -6.01872981e-01,
                         -6.42397523e-01,  -6.78276777e-01,  -5.91464460e-01,
                         -6.64220452e-01,  -7.74784744e-01,  -3.91087681e-01,
                         -1.43982954e-02,  -3.49966854e-01,  -7.36776590e-01,
                         -6.41369283e-01,  -5.90647638e-01,  -6.84150934e-01,
                         -6.37194753e-01,  -6.05661750e-01,  -6.40879571e-01,
                         -6.53758466e-01,  -6.56970322e-01,  -5.81885755e-01,
                         -6.15586519e-01,  -7.64559686e-01,  -4.65978503e-01,
                         -1.86423752e-02,  -2.90167391e-01,  -7.47702837e-01,
                         -6.44472718e-01,  -5.84582686e-01,  -7.40512013e-01,
                         -3.91572535e-01,   1.20500037e-02,  -4.22535092e-01,
                         -8.67770195e-01,  -4.08719718e-01,  -6.63959654e-04,
                         -3.54425102e-01,  -7.05550611e-01,  -7.22436368e-01,
                         -5.93848348e-01,  -2.10531890e-01,  -9.61915180e-02,
                         -6.30172372e-01,  -7.83141613e-01,  -1.96770027e-01,
                         -6.25526235e-02,  -5.74619293e-01,  -7.34194279e-01,
                         -5.89107811e-01,  -7.09193051e-01,  -6.23302400e-01,
                         -1.30967721e-01,  -1.27287418e-01,  -6.43136561e-01,
                         -7.62358785e-01,  -5.72343946e-01,  -5.96959889e-01,
                         -6.51505649e-01,  -6.30530238e-01,  -6.49446905e-01,
                         -6.38315380e-01,  -6.41273916e-01,  -6.57224119e-01,
                         -6.15649581e-01,  -6.58878505e-01,  -6.57207787e-01,
                         -2.98456699e-01,   1.26382634e-01,   5.70532046e-02,
                         -4.71810013e-01,  -8.01180243e-01,  -5.00695705e-01,
                         -2.24205405e-02,   7.93958977e-02,   1.23705261e-03,
                          4.17457595e-02,   7.24091455e-02,   2.97777131e-02,
                          3.49447727e-02,   5.71765229e-02,   2.87507027e-02,
                          2.14989875e-02,   3.67101319e-02,   2.68679559e-02,
                          4.25136834e-02,   4.06347215e-02,   1.45345563e-02,
                          6.91156313e-02,   4.13268097e-02,  -4.94608283e-02,
                          1.03120506e-01,   8.41929391e-02,  -4.09224451e-01,
                         -5.30149102e-01,  -5.70889600e-02,   1.47165567e-01,
                          1.89506973e-03,   2.11008778e-03,   8.14326108e-02,
                          3.35781425e-02,  -7.18305586e-03,   1.09151505e-01,
                          4.46505509e-02,  -4.17307168e-01,  -5.10570645e-01,
                          1.70638058e-02,   1.72177419e-01,  -4.87444401e-02,
                          7.89707005e-02,   1.70750506e-02,  -4.65128660e-01,
                         -4.30608481e-01,   3.03674769e-02,   1.16213679e-01,
                          8.23553279e-03,   2.87553649e-02,   2.87992302e-02,
                          2.15093903e-02,   3.85651849e-02,   3.14231664e-02,
                          5.31129427e-02,   5.76970465e-02,   4.57013212e-02,
                          5.38048744e-02,  -2.04253476e-02,   1.12567591e-02,
                          1.77018300e-01,  -9.27579701e-02,  -5.55097461e-01,
                         -3.44579995e-01,   1.22234508e-01,   1.04269885e-01,
                         -1.98240820e-02,   4.32609059e-02,   4.20244262e-02,
                          1.49199730e-02,   7.60262683e-02,   7.41938353e-02,
                         -1.61476899e-02,   3.87581326e-02,   1.27444685e-01,
                         -1.92302465e-01,  -5.33006608e-01,  -2.19128951e-01,
                          1.67847708e-01,   5.49553148e-02,  -2.09246259e-02,
                          8.78307745e-02,   4.86191325e-02,   1.74112655e-02,
                          9.13237184e-02,   7.51037821e-02,   4.81046678e-04,
                          6.74643815e-02,   9.60429683e-02,  -3.13378006e-01,
                         -5.69523275e-01,  -1.39856595e-03,   2.43786633e-01,
                         -4.04502213e-01,  -4.93372738e-01,  -6.17499761e-02,
                         -3.44367236e-01,  -5.41513920e-01,   5.41040190e-02,
                          2.05080211e-01,  -4.09412771e-01,  -5.44904947e-01,
                          2.32231077e-02,   1.72217190e-01,  -3.61808479e-01,
                         -5.31611204e-01,  -7.64707848e-02,   1.49153903e-01,
                          1.63965430e-02,   4.07103002e-02,   8.39707330e-02,
                         -3.03882450e-01,  -7.81563103e-01,  -5.60195923e-01,
                         -4.70310263e-02,  -2.59328395e-01,  -5.54157734e-01,
                         -6.15225583e-02,   2.19674870e-01,  -2.80189991e-01,
                         -6.40495658e-01,  -6.56050920e-01,  -6.86656654e-01,
                         -4.66491371e-01,   1.98791809e-02,   1.64745167e-01,
                         -2.99194515e-01,  -7.95549512e-01,  -6.36103809e-01,
                         -1.18523806e-01,   7.16905221e-02,   6.93123937e-02,
                          5.67154177e-02,  -3.42210323e-01,  -8.38930726e-01,
                         -6.01384282e-01,  -1.95450895e-02,  -2.22376361e-01,
                         -8.34798217e-01,  -6.08961582e-01,  -2.31119320e-02,
                         -2.90345669e-01,  -6.41977489e-01,  -7.11205900e-02,
                          2.63064325e-01,  -3.41523439e-01,  -5.49980819e-01,
                         -8.89904127e-02,  -2.07282484e-01,  -8.00345182e-01,
                         -7.54098773e-01,  -1.05105996e-01,   1.93703473e-01,
                         -2.39520505e-01,  -5.77833593e-01,  -1.93336368e-01,
                         -6.49307072e-02,  -7.03760386e-01,  -7.89627135e-01,
                         -1.42464504e-01,  -1.92757517e-01,  -6.25802040e-01,
                         -2.05756500e-01,   2.38886490e-01,  -2.40873814e-01,
                         -5.85539699e-01,  -2.11448848e-01,  -1.60345465e-01,
                         -6.85839534e-01,  -7.98802555e-01,  -2.16524199e-01,
                          2.06539914e-01,  -1.34012729e-01,  -5.94321132e-01,
                         -3.57267380e-01,   7.29984045e-02,   3.17013040e-02,
                         -4.67066951e-02,   4.87681329e-02,  -1.03581343e-02,
                         -1.89514048e-02,   7.76530281e-02,  -2.15311229e-01,
                         -7.38549709e-01,  -7.82339096e-01,  -2.93046445e-01,
                          1.08497314e-01,  -2.55833864e-02,  -5.26283026e-01,
                         -8.14846098e-01,  -5.26155591e-01,  -5.75279370e-02,
                          4.52671275e-02,   3.25329672e-03,  -8.41366276e-02,
                         -5.79335034e-01,  -8.56612623e-01,  -3.41851741e-01,
                         -1.17561348e-01,  -5.75106204e-01,  -4.86579359e-01,
                          1.33158445e-01,   1.70389470e-02,  -6.38882518e-01,
                         -5.29881835e-01,   1.53542727e-01,   4.22481820e-02,
                         -5.72889924e-01,  -4.26477462e-01,  -1.46710366e-01,
                         -5.27747929e-01,  -4.85086501e-01,   1.54902235e-01,
                          1.00500146e-02,  -6.99286997e-01,  -5.45982003e-01,
                          1.66949868e-01,   5.11967205e-02,  -6.35315299e-01,
                         -5.48009872e-01,   7.73849785e-02,   1.31578431e-01,
                         -1.16440244e-01,  -4.36288528e-02,   3.88592407e-02,
                         -5.96993603e-02,  -8.18099454e-02,   2.33811399e-04,
                          3.51626985e-02,  -1.31964032e-02,  -3.64475064e-02,
                         -1.57358199e-02,  -6.73771203e-02,  -1.10848144e-01,
                         -3.89676318e-02,   9.28076450e-03,  -1.85790751e-02,
                         -1.58161484e-02,   8.90615396e-03,  -3.56107093e-02,
                         -1.12892017e-01,  -6.89123720e-02,   4.69663553e-02,
                          2.52732877e-02,  -6.54496700e-02,  -5.42975329e-02,
                         -7.29495147e-03,  -1.14198122e-02,  -4.84008566e-02,
                         -6.37052581e-02,  -1.91506520e-02,   1.69155020e-02,
                         -1.72581542e-02,  -7.09587932e-02,  -7.38705173e-02,
                         -1.97515916e-02,   4.54993127e-03,  -2.86992416e-02,
                         -4.76216525e-02,  -5.69012947e-02,  -5.32919131e-02,
                         -4.03677151e-02,  -6.98801279e-02,  -1.97486375e-02,
                          8.92495438e-02,   2.80123558e-02,  -5.62206991e-02,
                         -3.79679427e-02,  -6.70869946e-02,  -7.19235698e-03,
                          3.57211679e-02,  -2.86875367e-01,  -5.16091168e-01,
                         -2.49787539e-01,  -1.49902711e-02,  -6.63494170e-02,
                         -8.62215608e-02,  -1.91270281e-02,   1.06222765e-03,
                         -4.13559936e-03,   9.90594644e-03,  -3.19711529e-02,
                         -6.63324445e-02,   3.08745839e-02,  -9.83993486e-02,
                         -4.98012155e-01,  -4.16668743e-01,  -9.95462164e-02,
                         -4.49536264e-01,  -8.30564559e-01,  -5.99095821e-01,
                         -5.84679902e-01,  -8.47884119e-01,  -5.47819018e-01,
                         -2.68211570e-02,   6.42139977e-03,  -9.98565406e-02,
                          4.57571745e-02,  -3.66442911e-02,  -6.37665629e-01,
                         -9.46229458e-01,  -4.62102443e-01,  -7.49261398e-03,
                          7.95423810e-04,   1.60350651e-02,  -1.39913917e-01,
                         -5.41380107e-01,  -4.53498274e-01,  -5.56895509e-03,
                          4.40685265e-02,  -9.12832767e-02,  -2.08586864e-02,
                          3.22557725e-02,  -2.21507587e-02,  -1.66611336e-02,
                          4.51948196e-02,  -1.21579468e-01,  -6.22934937e-01,
                         -8.53252411e-01,  -4.41198170e-01,  -1.96345635e-02,
                          4.47979905e-02,   1.80516243e-02,  -2.15934113e-01,
                         -6.95428729e-01,  -8.20646524e-01,  -3.74547690e-01,
                          1.57589484e-02,  -5.55305108e-02,  -1.24869049e-01,
                          4.64232899e-02,  -1.18508652e-01,  -5.14427722e-01,
                         -3.72205585e-01,  -1.58524737e-01,  -6.06719494e-01,
                         -8.89363289e-01,  -3.54093313e-01,  -2.59739924e-02,
                         -6.01993978e-01,  -9.77856159e-01,  -3.60637158e-01,
                         -3.62765999e-03,  -5.57751775e-01,  -5.07405639e-01,
                          2.29140088e-01,  -6.38307109e-02,  -7.74319351e-01,
                         -4.44177479e-01,  -1.03569686e-01,  -4.27481830e-01,
                         -3.98840398e-01,  -2.29379654e-01,  -6.42592728e-01,
                         -8.68003130e-01,  -3.31648856e-01,   1.82445064e-01,
                         -5.57686239e-02,  -6.53888047e-01,  -7.85209954e-01,
                         -5.84402323e-01,  -6.98335052e-01,  -8.58374655e-01,
                         -6.80345953e-01,  -5.97098649e-01,  -7.68099904e-01,
                         -8.08272421e-01,  -6.84006453e-01,  -6.37979269e-01,
                         -7.17192888e-01,  -7.77028561e-01,  -7.12455511e-01,
                         -6.27863228e-01,  -6.50897801e-01,  -7.46739984e-01,
                         -7.93253601e-01,  -7.37334669e-01,  -7.25595653e-01,
                         -7.89692521e-01,  -7.01779246e-01,  -5.81932783e-01,
                         -7.12636530e-01,  -8.22235227e-01,  -6.94760144e-01,
                         -6.56470120e-01,  -7.87184179e-01,  -7.77035654e-01,
                         -6.16801679e-01,  -5.84858775e-01,  -7.20350921e-01,
                         -7.95526266e-01,  -7.28986859e-01,  -6.64048374e-01,
                         -6.86898112e-01,  -7.39788651e-01,  -7.26959705e-01,
                         -6.68822944e-01,  -7.05282032e-01,  -8.12018931e-01,
                         -8.15717638e-01,  -7.21907020e-01,  -6.64592385e-01,
                         -6.73201501e-01,  -6.88615799e-01,  -7.02815592e-01,
                         -7.47905016e-01,  -7.53147840e-01,  -6.82700038e-01,
                         -6.77993953e-01,  -7.59232819e-01,  -7.53796637e-01,
                         -6.46821856e-01,  -6.58939779e-01,  -8.30749989e-01,
                         -8.19750428e-01,  -6.51544034e-01,  -7.74002910e-01,
                         -7.96540499e-01,  -2.86766171e-01,  -1.69275373e-01,
                         -7.11838365e-01,  -8.07848692e-01,  -5.65906465e-01,
                         -7.37075806e-01,  -7.07903862e-01,  -2.23922476e-01,
                         -2.70381182e-01,  -8.55701089e-01,  -8.46116424e-01,
                         -2.16056734e-01,  -1.48440331e-01,  -7.55628824e-01,
                         -8.45894098e-01,  -2.72934228e-01,  -1.67570546e-01,
                         -7.01014102e-01,  -8.36340964e-01,  -3.26394469e-01,
                         -1.54638141e-01,  -6.18264616e-01,  -8.23547304e-01,
                         -6.50865078e-01,  -7.57543683e-01,  -7.72811770e-01,
                         -2.79983968e-01,  -1.59785792e-01,  -7.31120467e-01,
                         -8.95960152e-01,  -3.69864196e-01,  -1.98877096e-01,
                         -5.95201015e-01,  -7.78733075e-01,  -7.09718287e-01,
                         -7.46168971e-01,  -7.56809115e-01,  -7.39264607e-01,
                         -7.47963309e-01,  -6.89443111e-01,  -7.45845377e-01,
                         -7.99827993e-01,  -6.52825654e-01,  -7.39926875e-01,
                         -8.54278862e-01,  -3.99767846e-01,  -1.21785678e-01,
                         -5.75590968e-01,  -8.86971116e-01,  -7.18271554e-01,
                         -6.52924955e-01,  -7.81524360e-01,  -7.69389629e-01,
                         -4.86419827e-01,  -8.82272050e-02,   1.44283110e-02,
                         -3.96695942e-01,  -8.20583522e-01,  -7.65657604e-01,
                         -6.65551484e-01,  -8.19052696e-01,  -6.69615448e-01,
                         -2.82288790e-01,  -3.78679484e-01,  -7.62734175e-01,
                         -7.94963837e-01,  -5.81532955e-01,  -5.69985807e-01,
                         -7.60162950e-01,  -8.10863733e-01,  -7.21996367e-01,
                         -7.01954901e-01,  -7.04525948e-01,  -7.77092457e-01,
                         -8.13173354e-01,  -4.82036829e-01,  -2.07615286e-01,
                         -4.28783983e-01,  -7.14391291e-01,  -8.44075203e-01,
                         -7.29769170e-01,  -2.49564290e-01,  -1.92560032e-01,
                         -8.03146005e-01,  -8.52426350e-01,  -2.08540663e-01,
                         -1.89962894e-01,  -8.19466114e-01,  -8.39366138e-01,
                         -2.35363975e-01,  -1.52086288e-01,  -5.96454084e-01,
                         -7.41425514e-01,  -6.84681118e-01,  -7.56915331e-01,
                         -7.69033194e-01,  -7.25608468e-01,  -7.58039117e-01,
                         -8.30254614e-01,  -7.27724612e-01,  -2.90438294e-01,
                         -1.49630710e-01,  -6.82306707e-01,  -8.68395984e-01,
                         -3.42281848e-01,  -1.71749339e-01,  -5.90054989e-01,
                         -7.84699142e-01,  -6.24178231e-01,  -6.59504652e-01,
                         -8.08108807e-01,  -4.59814191e-01,   7.46485516e-02,
                         -2.32218951e-02,  -5.83397985e-01,  -8.89960527e-01,
                         -6.12866044e-01,  -1.70851707e-01,  -3.40631187e-01,
                         -7.48178065e-01,  -6.34492159e-01,  -5.71617901e-01,
                         -7.89873958e-01,  -6.65053904e-01,  -5.24358571e-01,
                         -6.79746389e-01,  -7.07284987e-01,  -6.97546005e-01,
                         -6.68406665e-01,  -2.77874380e-01,   8.01995769e-02,
                         -1.06335647e-01,  -5.36322653e-01,  -7.04807639e-01,
                         -6.62499964e-01,  -7.03500807e-01,  -6.73006058e-01,
                         -5.44941127e-01,  -6.79965079e-01,  -7.14713752e-01,
                         -2.33128443e-01,   1.00652389e-01,  -1.55698702e-01,
                         -5.85603058e-01,  -7.26635516e-01,  -3.83464843e-01,
                         -7.37082958e-02,  -4.35644120e-01,  -8.27374220e-01,
                         -4.88648415e-01,  -1.18466958e-01,  -4.03659344e-01,
                         -7.38901258e-01,  -6.82819426e-01,  -7.05006480e-01,
                         -7.30256140e-01,  -2.67675459e-01,   3.51301220e-04,
                         -5.72121203e-01,  -9.67338681e-01,  -4.26665425e-01,
                          3.58889922e-02,  -4.09872890e-01,  -8.81756186e-01,
                         -4.90799308e-01,  -4.81826477e-02,  -3.67659926e-01,
                         -7.31863797e-01,  -6.92343891e-01,  -7.05426991e-01,
                         -7.08847880e-01,  -5.88917613e-01,  -6.38113201e-01,
                         -7.27449417e-01,  -7.04113722e-01,  -6.79123223e-01,
                         -6.17755175e-01,  -6.17589831e-01,  -6.68751299e-01,
                         -6.20253921e-01,  -7.38462865e-01,  -8.30150485e-01,
                         -3.91759157e-01,  -1.33753166e-01,  -4.53976989e-01,
                         -3.41809660e-01,  -2.30712891e-02,  -5.60925424e-01,
                         -9.86375213e-01,  -4.10667002e-01,  -8.61822814e-02,
                         -3.56932372e-01,  -2.22868294e-01,  -1.59779847e-01,
                         -7.22531259e-01,  -7.82357752e-01,  -1.71442136e-01,
                         -1.89414755e-01,  -6.20656669e-01,  -2.64208704e-01,
                          2.57044554e-01,  -1.73881158e-01,  -6.28895342e-01,
                         -2.50436813e-01,  -1.59603387e-01,  -5.40467680e-01,
                         -2.00520247e-01,   1.98357075e-01,  -2.96770900e-01,
                         -5.29436409e-01,  -1.97353661e-01,  -3.29426974e-01,
                         -4.54146504e-01,  -1.38191909e-01,  -3.42572361e-01,
                         -8.26919198e-01,  -5.37326396e-01,  -1.04370095e-01,
                         -3.74315619e-01,  -6.64203048e-01,  -5.54136813e-01,
                         -6.51858866e-01,  -7.99559772e-01,  -4.03773487e-01,
                         -1.08901292e-01,  -4.06520337e-01,  -4.17213976e-01,
                          1.50168380e-02,  -5.57389669e-02,  -5.12677073e-01,
                         -6.06325805e-01,  -5.57396233e-01,  -6.97538197e-01,
                         -7.13533401e-01,  -6.20888531e-01,  -7.32369006e-01,
                         -6.83461189e-01,  -2.18839124e-01,  -1.23378150e-01,
                         -6.34738564e-01,  -7.63308823e-01,  -4.76182312e-01,
                         -6.58212781e-01,  -8.29162359e-01,  -3.01733762e-01,
                         -7.17877373e-02,  -6.40275419e-01,  -7.86041617e-01,
                         -2.10681722e-01,  -7.76001513e-02,  -5.32462597e-01,
                         -7.20810711e-01,  -6.41087353e-01,  -7.04619765e-01,
                         -7.03502715e-01,  -5.46670437e-01,  -5.62957823e-01,
                         -7.07346737e-01,  -7.11382806e-01,  -6.49742007e-01,
                         -6.61374867e-01,  -7.00280547e-01,  -6.84415460e-01,
                         -6.14262700e-01,  -6.18960679e-01,  -7.03748345e-01,
                         -6.63790286e-01,  -5.76427579e-01,  -6.97462857e-01,
                         -7.59511054e-01,  -3.45607162e-01,   1.62896425e-01,
                          5.82506470e-02,  -4.71541882e-01,  -7.06862450e-01,
                         -6.35287941e-01,  -6.50146365e-01,  -7.05190718e-01,
                         -6.64237738e-01,  -6.22299552e-01,  -6.46266282e-01,
                         -6.63855314e-01,  -4.74351585e-01,  -1.21344753e-01,
                          4.36493531e-02,   4.73710261e-02,   8.24511051e-02,
                          4.14153859e-02,  -9.66809131e-03,  -1.54069848e-02,
                         -5.91061711e-02,   9.38633680e-02,   1.90708280e-01,
                         -3.02891493e-01,  -6.56777561e-01,  -2.01043263e-01,
                          2.13685885e-01,   3.96811552e-02,  -1.36793017e-01,
                          5.39848432e-02,   2.18779653e-01,  -1.33108854e-01,
                         -5.86412251e-01,  -3.79304260e-01,   6.57165125e-02,
                          7.09926412e-02,  -2.79605910e-02,   2.23126765e-02,
                          3.25599946e-02,   4.39007357e-02,   3.27371433e-02,
                         -4.36597131e-02,  -9.35470220e-04,   9.19023380e-02,
                          5.13902381e-02,   6.60757022e-03,   2.80241277e-02,
                         -1.19502516e-02,  -5.07193804e-02,   2.91591920e-02,
                          6.52139559e-02,  -9.50120762e-03,   8.32652301e-03,
                          6.15408793e-02,   6.37982506e-03,   5.81963919e-03,
                          4.55487147e-02,   1.50535046e-03,   1.45380273e-02,
                          3.87396067e-02,  -2.90663373e-02,  -2.79801823e-02,
                          1.27519323e-02,   6.11793771e-02,   1.46671906e-01,
                         -9.27056149e-02,  -5.20970583e-01,  -3.78345490e-01,
                          9.03561935e-02,   1.11411974e-01,  -7.79778734e-02,
                         -5.34576252e-02,  -7.78629910e-03,  -3.29029956e-03,
                          7.61282519e-02,   5.52133583e-02,  -8.56332853e-02,
                          1.17238089e-02,   1.83015734e-01,  -1.69543639e-01,
                         -5.88141084e-01,  -2.56321758e-01,   1.33555368e-01,
                         -6.76547512e-02,  -5.74583262e-02,   1.72851667e-01,
                         -2.10714325e-01,  -5.77716589e-01,  -1.99357480e-01,
                          1.45397410e-01,   1.09544471e-02,  -1.15932874e-01,
                         -2.84283385e-02,   1.19648091e-01,  -8.44759680e-03,
                         -5.13717651e-01,  -7.94729829e-01,  -6.62230790e-01,
                         -6.88525498e-01,  -7.12854624e-01,  -2.42266029e-01,
                          1.32731497e-02,  -5.32687604e-01,  -8.21368754e-01,
                         -2.62356818e-01,  -7.27356672e-02,  -5.28361022e-01,
                         -3.51564676e-01,   1.80895507e-01,  -1.41602531e-01,
                         -6.85045838e-01,  -6.68113172e-01,  -6.55860782e-01,
                         -5.82660079e-01,  -1.14351474e-01,  -1.27825603e-01,
                         -7.61540353e-01,  -7.32453525e-01,  -8.44230354e-02,
                         -1.54701099e-01,  -7.48170197e-01,  -7.49542236e-01,
                         -5.12624741e-01,  -6.92357838e-01,  -6.53715253e-01,
                         -1.80319294e-01,  -2.14079082e-01,  -7.62377441e-01,
                         -6.99251235e-01,  -8.21118206e-02,  -1.32702991e-01,
                         -7.33403027e-01,  -7.61929274e-01,  -5.50519943e-01,
                         -7.37491846e-01,  -5.72165847e-01,  -1.10296845e-01,
                         -3.07601124e-01,  -4.99322861e-01,  -1.43145084e-01,
                         -3.16538721e-01,  -8.39053035e-01,  -5.69913805e-01,
                         -1.52430072e-01,  -3.91116291e-01,  -6.26999259e-01,
                         -5.51799715e-01,  -6.19015753e-01,  -7.57466316e-01,
                         -5.25170445e-01,  -1.62670668e-02,   1.08853415e-01,
                         -3.28742981e-01,  -5.34392774e-01,  -1.33515611e-01,
                          1.07966430e-01,  -2.59723008e-01,  -7.24775255e-01,
                         -7.63764858e-01,  -3.17448229e-01,   1.58823505e-01,
                          5.10660093e-03,  -5.29841542e-01,  -4.67837989e-01,
                          7.23504946e-02,   3.26758437e-02,  -4.78174508e-01,
                         -4.38035309e-01,   5.38009740e-02,   1.03297390e-01,
                         -3.73023570e-01,  -7.87186682e-01,  -6.57344639e-01,
                         -6.26108721e-02,   1.41632870e-01,  -3.69368374e-01,
                         -5.84621251e-01,  -1.48888662e-01,   7.36195520e-02,
                          7.33686332e-03,   7.79345492e-03,  -3.25583726e-01,
                         -8.33514392e-01,  -8.02614212e-01,  -5.49859822e-01,
                         -5.75412810e-01,  -6.39602661e-01,  -7.12038636e-01,
                         -7.69937813e-01,  -4.01277184e-01,   9.44834799e-02,
                          7.80665204e-02,  -8.38726237e-02,   5.21343127e-02,
                          5.30480221e-03,  -4.83089268e-01,  -8.45548570e-01,
                         -7.32107460e-01,  -5.60829937e-01,  -6.87179387e-01,
                         -7.45327115e-01,  -5.70904315e-01,  -6.71403944e-01,
                         -8.04586172e-01,  -3.29573154e-01,  -5.36825061e-02,
                         -5.36751151e-01,  -5.28830171e-01,   1.09984100e-01,
                         -5.70533937e-03,  -5.18021286e-01,  -3.30220640e-01,
                         -2.98161767e-02,  -4.06746119e-02,   7.84236118e-02,
                         -1.32866696e-01,  -8.47123742e-01,  -8.40463221e-01,
                         -7.04220533e-02,  -5.02259433e-02,  -7.28399694e-01,
                         -8.13801348e-01,  -5.92611730e-01,  -7.80491352e-01,
                         -6.53073490e-01,  -8.78393948e-02,  -2.02397749e-01,
                         -7.92874455e-01,  -7.81970382e-01,  -5.30631840e-01,
                         -6.86522305e-01,  -6.65655375e-01,  -1.64741129e-01,
                          6.52636439e-02,  -1.16814211e-01,  -4.35473882e-02,
                          6.42156675e-02,  -3.26852947e-01,  -5.19231975e-01,
                         -9.69737321e-02,   1.14303276e-01,  -3.54728736e-02,
                         -2.92022508e-02,   1.05418675e-02,   2.90254597e-03,
                          4.89509329e-02,  -9.28144995e-03,  -6.22933246e-02,
                         -4.70280722e-02,  -8.30766335e-02,   2.69814022e-02,
                          6.59257025e-02,  -3.05636257e-01,  -4.99605805e-01,
                         -2.01236948e-01,   4.74265628e-02,   2.33929455e-02,
                         -7.74293169e-02,  -3.26238014e-02,   5.00483774e-02,
                         -2.71079034e-01,  -6.21428788e-01,  -3.05382937e-01,
                          1.38149872e-01,   9.52644497e-02,  -2.95316018e-02,
                         -5.01598138e-03,  -7.10868388e-02,  -1.55301794e-01,
                         -1.38966357e-02,   9.39139873e-02,  -2.46628001e-01,
                         -5.57193339e-01,  -2.61350930e-01,   6.13948219e-02,
                         -8.40470754e-03,  -2.94195823e-02,   2.03077905e-02,
                         -3.48799564e-02,  -1.79747641e-02,   8.42999388e-03,
                         -1.31457858e-02,   4.27094810e-02,   3.18773873e-02,
                         -8.37273598e-02,  -8.52642879e-02,   1.35450419e-02,
                          4.50689048e-02,  -2.01392900e-02,  -5.24414666e-02,
                          2.62750685e-02,   5.13491668e-02,  -6.18006736e-02,
                         -9.61749926e-02,   4.61937934e-02,   4.18943428e-02,
                         -3.75401795e-01,  -7.85867333e-01,  -7.35318124e-01,
                         -6.22410893e-01,  -7.22417057e-01,  -5.41907072e-01,
                         -6.82483613e-02,   7.06053376e-02,  -2.79496163e-01,
                         -7.11748838e-01,  -7.14777172e-01,  -2.30314940e-01,
                          5.81103861e-02,  -1.31008446e-01,  -1.31001413e-01,
                          1.27726838e-01,  -9.75851864e-02,  -5.63849807e-01,
                         -3.96561414e-01,   3.93338650e-02,   2.32402496e-02,
                         -2.03177314e-02,   9.78268832e-02,  -2.55715042e-01,
                         -6.67365193e-01,  -2.22260073e-01,   3.05129796e-01,
                         -1.37150809e-01,  -7.07365751e-01,  -4.11956549e-01,
                          9.40349922e-02,   8.28471631e-02,  -5.93125708e-02,
                          2.28026207e-03,   1.35483900e-02,  -9.24994871e-02,
                         -9.41701308e-02,   1.35478275e-02,   4.59309518e-02,
                         -3.32452320e-02,  -6.01926409e-02,   3.82379703e-02,
                          4.39860970e-02,  -1.04263335e-01,  -2.89191920e-02,
                          1.90486640e-01,  -9.88710448e-02,  -5.99423766e-01,
                         -4.28957850e-01,   1.65948682e-02,   1.41570251e-02,
                         -4.24942933e-02,   7.60964528e-02,  -3.06439176e-02,
                         -2.05092743e-01,  -3.82703878e-02,   1.70188278e-01,
                         -1.31945387e-01,  -6.20913684e-01,  -4.50130284e-01,
                          7.40801170e-02,   1.14438139e-01,   5.72643802e-02,
                          1.25751242e-01,  -3.16219956e-01,  -6.89614534e-01,
                         -2.58454680e-01,  -1.13023162e-01,  -7.05175996e-01,
                         -7.61255383e-01,  -2.25331232e-01,  -2.67878264e-01,
                         -6.90419078e-01,  -6.92098379e-01,  -6.15481734e-01,
                         -7.63681412e-01,  -7.29665995e-01,  -6.03417695e-01,
                         -6.88692987e-01,  -7.55655766e-01,  -7.16510475e-01,
                         -7.00623214e-01,  -6.85466945e-01,  -7.06960797e-01,
                         -7.05088258e-01,  -6.30760372e-01,  -6.65359497e-01,
                         -7.21328139e-01,  -6.71595633e-01,  -7.03643680e-01,
                         -7.38326371e-01,  -6.41262650e-01,  -6.28992260e-01,
                         -7.24233508e-01,  -7.40875542e-01,  -6.69849575e-01,
                         -6.31246984e-01,  -7.08707094e-01,  -7.49496460e-01,
                         -6.58006549e-01,  -6.65025175e-01,  -7.54453003e-01,
                         -6.96823359e-01,  -6.34388328e-01,  -7.20916986e-01,
                         -7.72648394e-01,  -6.67800069e-01,  -5.77844977e-01,
                         -6.64608240e-01,  -7.65561700e-01,  -7.20337331e-01,
                         -6.70703709e-01,  -6.84308708e-01,  -6.83530867e-01,
                         -6.66891992e-01,  -6.51523054e-01,  -6.92050040e-01,
                         -7.52941310e-01,  -7.07571805e-01,  -6.60321295e-01,
                         -6.86523795e-01,  -6.90333366e-01,  -7.16063142e-01,
                         -7.19677269e-01,  -6.46342874e-01,  -6.84744775e-01,
                         -7.56495118e-01,  -6.71038270e-01,  -6.20903552e-01,
                         -6.86432481e-01,  -6.92264557e-01,  -6.22326434e-01,
                         -6.19161487e-01,  -7.63949871e-01,  -8.32021654e-01,
                         -6.51790202e-01,  -5.61410546e-01,  -6.99558139e-01,
                         -7.45623946e-01,  -6.89710975e-01,  -7.03176141e-01,
                         -7.18154192e-01,  -6.98997438e-01,  -7.00579166e-01,
                         -7.04837978e-01,  -6.56021416e-01,  -6.09990895e-01,
                         -6.80377841e-01,  -7.65259862e-01,  -7.50103414e-01,
                         -6.98496282e-01,  -6.25043094e-01,  -6.45323634e-01,
                         -7.71816730e-01,  -7.23650396e-01,  -6.90105617e-01,
                         -8.07320952e-01,  -5.36208510e-01,  -1.66632816e-01,
                         -3.43378961e-01,  -4.28689271e-01,  -2.08240286e-01,
                         -4.17459130e-01,  -7.38668084e-01,  -6.68222547e-01,
                         -6.65255666e-01,  -7.90883005e-01,  -7.14706123e-01,
                         -6.30734384e-01,  -7.28335321e-01,  -7.41218626e-01,
                         -4.23606068e-01,  -1.63104519e-01,  -4.17974085e-01,
                         -7.18651295e-01,  -6.76911533e-01,  -7.05686331e-01,
                         -7.70713270e-01,  -6.86615586e-01,  -7.50849307e-01,
                         -6.28500223e-01,  -1.23576656e-01,  -1.61690071e-01,
                         -7.22396731e-01,  -7.69631505e-01,  -5.93909085e-01,
                         -7.74147809e-01,  -6.21888340e-01,  -1.40906930e-01,
                         -3.31464171e-01,  -6.65972650e-01,  -1.24778055e-01,
                          2.23320365e-01,  -4.28693056e-01,  -6.54268861e-01,
                         -8.24597776e-02,  -1.88229099e-01,  -8.38736713e-01,
                         -6.69390261e-01,  -5.66358268e-02,  -2.39494205e-01,
                         -8.48580301e-01,  -7.06850469e-01,  -1.66486070e-01,
                         -2.87381262e-01,  -6.84990168e-01,  -7.28833377e-01,
                         -7.01956749e-01,  -4.63995814e-01,  -6.46735281e-02,
                         -3.46942186e-01,  -8.48903656e-01,  -5.35452127e-01,
                         -1.40699834e-01,  -4.61198747e-01,  -7.79262602e-01,
                         -6.54132187e-01,  -6.37689650e-01,  -7.70513773e-01,
                         -4.44036752e-01,  -4.46502827e-02,  -4.58299279e-01,
                         -9.48107719e-01,  -5.15547872e-01,  -2.67389398e-02,
                         -3.02659929e-01,  -7.50578642e-01,  -8.41916740e-01,
                         -6.82809651e-01,  -6.51232123e-01,  -7.80974209e-01,
                         -4.90259022e-01,  -8.85244459e-02,  -4.46847916e-01,
                         -6.90321565e-01,   2.97966297e-03,   2.33074844e-01,
                         -4.68705952e-01,  -5.32086074e-01,  -6.71964558e-03,
                         -2.80225426e-01,  -8.45863700e-01,  -7.25000262e-01,
                         -6.16000116e-01,  -8.16346824e-01,  -4.82057035e-01,
                          1.24733115e-03,  -3.99779528e-01,  -8.98252368e-01,
                         -4.48455095e-01,  -5.48184700e-02,  -4.52783674e-01,
                         -4.88333046e-01,  -9.94624197e-02,  -4.85700250e-01,
                         -9.06585097e-01,  -4.07755941e-01,  -1.72840074e-01,
                         -4.66756642e-01,  -2.69597322e-01,  -1.71996310e-01,
                         -5.76970339e-01,  -3.53085518e-01,   2.31397003e-01,
                         -6.23446517e-02,  -7.04362512e-01,  -7.12793171e-01,
                         -5.42527020e-01,  -7.28549540e-01,  -7.03874767e-01,
                         -1.98477000e-01,  -9.70602706e-02,  -6.63657904e-01,
                         -8.80801260e-01,  -3.85101169e-01,   7.73247108e-02,
                          1.61194392e-02,  -3.93884242e-01,  -6.93312109e-01,
                         -6.86818242e-01,  -6.33046508e-01,  -6.52319968e-01,
                         -6.59353495e-01,  -6.85016632e-01,  -6.86908364e-01,
                         -6.46089315e-01,  -6.48275018e-01,  -6.57746971e-01,
                         -6.78299487e-01,  -6.71192527e-01,  -5.81064939e-01,
                         -6.84764743e-01,  -8.26646209e-01,  -4.37191188e-01,
                         -5.98612875e-02,  -4.09444481e-01,  -7.79472053e-01,
                         -7.09792197e-01,  -7.02657878e-01,  -6.70809925e-01,
                         -5.07806957e-01,  -6.60133362e-01,  -7.22289681e-01,
                         -2.42944285e-01,  -9.62415040e-02,  -5.73918939e-01,
                         -7.46461511e-01,  -6.34320378e-01,  -7.67363846e-01,
                         -6.41754270e-01,  -1.71275675e-01,  -1.95245743e-01,
                         -6.11959279e-01,  -7.33291805e-01,  -6.88841581e-01,
                         -7.02408671e-01,  -6.35841370e-01,  -5.63137829e-01,
                         -5.85698128e-01,  -6.72951639e-01,  -7.78202295e-01,
                         -7.31814623e-01,  -5.74602902e-01,  -5.78180552e-01,
                         -6.92288399e-01,  -7.12703884e-01,  -6.49506152e-01,
                         -6.28138840e-01,  -6.98324502e-01,  -6.98685229e-01,
                         -6.61322594e-01,  -8.00330162e-01,  -7.07843900e-01,
                         -1.92360073e-01,  -1.22955911e-01,  -6.25922680e-01,
                         -7.74760783e-01,  -5.83489180e-01,  -5.89093089e-01,
                         -6.47366226e-01,  -6.48264527e-01,  -6.76203787e-01,
                         -6.41543150e-01,  -6.33934855e-01,  -7.20826566e-01,
                         -7.25809097e-01,  -6.80560589e-01,  -7.01044440e-01,
                         -6.92165911e-01,  -6.34895682e-01,  -6.32552028e-01,
                         -6.75585985e-01,  -6.83559120e-01,  -6.56001508e-01,
                         -6.79950416e-01,  -7.55262673e-01,  -7.39310622e-01,
                         -6.29996359e-01,  -5.96322477e-01,  -6.41961575e-01,
                         -6.67378366e-01,  -7.00322330e-01,  -7.38267183e-01,
                         -7.18894958e-01,  -6.70766771e-01,  -6.44999862e-01,
                         -6.74945831e-01,  -7.13124871e-01,  -6.44546866e-01,
                         -5.93333840e-01,  -7.07243562e-01,  -7.75506377e-01,
                         -6.98408604e-01,  -6.53124154e-01,  -6.50011599e-01,
                         -6.52034283e-01,  -6.87918663e-01,  -6.99677169e-01,
                         -6.94209039e-01,  -6.87516689e-01,  -6.45841599e-01,
                         -6.48130417e-01,  -6.83733344e-01,  -6.76850855e-01,
                         -7.12111115e-01,  -7.58805275e-01,  -7.21045673e-01,
                         -6.93296075e-01,  -6.87191546e-01,  -6.49573267e-01,
                         -6.51560187e-01,  -6.68086529e-01,  -6.38557494e-01,
                         -6.46563172e-01,  -7.06437349e-01,  -7.08915830e-01,
                         -6.55759335e-01,  -6.61860526e-01,  -7.02622771e-01,
                         -6.65623367e-01,  -6.32433891e-01,  -6.95527852e-01,
                         -7.38706052e-01,  -6.94125772e-01,  -6.39143765e-01,
                         -6.51973128e-01,  -7.18904674e-01,  -7.31569588e-01,
                         -7.06622422e-01,  -7.20994294e-01,  -6.80315793e-01,
                         -6.10018671e-01,  -6.48088515e-01,  -7.00227797e-01,
                         -6.94020629e-01,  -6.80365205e-01,  -6.46785915e-01,
                         -6.54689968e-01,  -7.09339440e-01,  -6.88716531e-01,
                         -6.52412176e-01,  -6.69370294e-01,  -6.68620706e-01,
                         -6.90358281e-01,  -7.46325016e-01,  -7.16504455e-01,
                         -6.27354324e-01,  -6.16003335e-01,  -6.72718465e-01,
                         -6.90871775e-01,  -6.81025863e-01,  -6.98283672e-01,
                         -6.84568822e-01,  -6.34204268e-01,  -6.37487471e-01,
                         -7.02756763e-01,  -7.53572583e-01,  -7.03253865e-01,
                         -6.48170352e-01,  -7.32323527e-01,  -7.42546558e-01,
                         -6.52182221e-01,  -7.38645315e-01,  -6.39451325e-01,
                         -1.82800695e-01,  -1.69848606e-01,  -6.12976551e-01,
                         -7.29660392e-01,  -6.62395000e-01,  -5.88651776e-01,
                         -1.37222692e-01,   1.81666285e-01,  -2.84129769e-01,
                         -8.04789007e-01,  -6.78294361e-01,  -5.45899868e-01,
                         -8.10750067e-01,  -6.89302981e-01,  -1.06074929e-01,
                         -1.75091088e-01,  -7.95590878e-01,  -8.06433499e-01,
                         -5.28340876e-01,  -7.12318659e-01,  -6.07866287e-01,
                         -5.91449142e-02,  -2.73308963e-01,  -9.22270954e-01,
                         -6.28857970e-01,   4.33645211e-03,  -2.19715640e-01,
                         -7.42548525e-01,  -8.24381530e-01,  -6.80838406e-01,
                         -4.00929987e-01,   7.30546610e-03,   9.12568346e-02,
                         -3.81264180e-01,  -8.65373492e-01,  -6.75915480e-01,
                         -1.28240928e-01,  -1.86880350e-01,  -7.44086325e-01,
                         -7.41575420e-01,  -1.71855599e-01,  -1.69376791e-01,
                         -7.87591994e-01,  -7.55036950e-01,  -1.18437998e-01,
                         -1.96229115e-01,  -6.05573118e-01,  -2.26364613e-01,
                          1.73514515e-01,  -9.29380432e-02,  -1.49618566e-01,
                          1.21964827e-01,  -1.43034786e-01,  -7.74593890e-01,
                         -8.22031438e-01,  -2.51656681e-01,  -1.02040149e-01,
                         -6.88787639e-01,  -8.71310711e-01,  -2.45306730e-01,
                         -6.07338287e-02,  -6.85230374e-01,  -8.26088011e-01,
                         -2.35700786e-01,  -1.84454098e-01,  -6.25203848e-01,
                         -3.12979013e-01,   2.58945078e-01,  -1.38243794e-01,
                         -7.04522014e-01,  -3.41698229e-01,   1.45075172e-01,
                         -1.21414863e-01,  -6.03605092e-01,  -7.36385584e-01,
                         -7.38040030e-01,  -6.36935711e-01,  -2.12152421e-01,
                          8.41602534e-02,  -9.36112329e-02,  -1.42576471e-01,
                          7.51895383e-02,  -1.17635138e-01,  -6.74932837e-01,
                         -8.86252701e-01,  -4.71940726e-01,   1.00224301e-01,
                          3.50455120e-02,  -5.18528879e-01,  -5.21794081e-01,
                          3.98214022e-03,   6.65739253e-02,  -4.43651170e-01,
                         -8.11793625e-01,  -6.60898089e-01,  -2.23632932e-01,
                          4.66733910e-02,   1.69994384e-02,  -7.15992600e-02,
                         -6.26615882e-02,  -2.69345585e-02,  -3.55342105e-02,
                         -5.07782102e-02,  -4.18855138e-02,  -4.89607044e-02,
                         -6.56391829e-02,  -4.71254662e-02,  -1.40331993e-02,
                         -7.45900348e-03,  -3.23861800e-02,  -4.90397997e-02,
                         -2.28316132e-02,   1.56448297e-02,   4.14875373e-02,
                          3.09757739e-02,  -5.04386686e-02,  -1.21379972e-01,
                         -1.04595296e-01,  -6.22426718e-02,  -3.44716124e-02,
                         -3.47693637e-02,  -6.84066638e-02,  -5.25777154e-02,
                         -6.07467024e-04,  -1.64150558e-02,  -5.47360517e-02,
                         -5.28344437e-02,  -3.33393998e-02,  -3.21705779e-03,
                         -9.83044691e-03,  -5.27347811e-02,  -2.14443039e-02,
                          4.60863337e-02,   1.90650206e-02,  -6.58578277e-02,
                         -1.13850914e-01,  -7.80040622e-02,   1.80754270e-02,
                          9.06057935e-03,  -1.30314603e-01,  -1.42899707e-01,
                          3.23188584e-03,   3.27021740e-02,  -6.53432533e-02,
                         -7.48335496e-02,  -1.82112716e-02,  -2.32334323e-02,
                         -4.32760902e-02,  -4.52219471e-02,  -9.20156017e-02,
                         -9.24109519e-02,   4.18784916e-02,   7.22023696e-02,
                         -1.03242651e-01,  -1.55841187e-01,  -3.67933251e-02,
                         -2.53556743e-02,  -4.70374972e-02,   2.38440335e-02,
                          1.48934731e-02,  -7.72435516e-02,  -9.60804969e-02,
                         -3.68009508e-02,   2.38404274e-02,  -1.06688160e-02,
                         -9.25127715e-02,  -6.79848269e-02,  -1.89811513e-02,
                         -2.15963703e-02,   1.53411236e-02,  -8.72734096e-03,
                         -1.14899904e-01,  -6.58279285e-02,   5.58034256e-02,
                          5.12008090e-03,  -8.31905529e-02,  -5.43845817e-02,
                         -2.58635469e-02,  -6.11345693e-02,  -8.17439854e-02,
                         -4.76040840e-02,   3.96153843e-03,   1.37317292e-02,
                         -2.34501120e-02,  -4.52625118e-02,  -2.47015990e-02,
                          5.79119613e-03,   1.99106000e-02,  -1.77604649e-02,
                         -9.36557055e-02,  -9.08519477e-02,   4.15650476e-03,
                          6.57508895e-02,   3.83053683e-02,  -6.90840334e-02,
                         -1.48524344e-01,  -4.98914234e-02,   7.27333724e-02,
                          1.60944108e-02,  -4.99151722e-02,  -5.34980325e-03,
                          1.33704646e-02,  -3.36493962e-02,  -1.02144994e-01,
                         -1.14986546e-01,   5.11910347e-03,   8.89781192e-02,
                         -2.12409683e-02,  -1.26145408e-01,  -5.39844930e-02,
                          5.70504963e-02,   6.01036921e-02,  -3.39001813e-03,
                         -4.97619025e-02,  -7.46676326e-02,  -7.04352260e-02,
                         -1.50071215e-02,   1.92636028e-02,  -1.27160642e-02,
                         -2.01310776e-02,   1.16235623e-02,  -3.83136590e-04,
                         -2.84534562e-02,  -4.09292839e-02,  -5.72355650e-02,
                         -5.53145818e-03,   3.36446762e-02,  -6.05801232e-02,
                         -2.57658269e-02,   4.55121845e-02,  -3.12218040e-01,
                         -5.44727564e-01,  -1.81149527e-01,  -2.06183568e-01,
                         -7.72306502e-01,  -7.51535952e-01,  -2.11690634e-01,
                          8.08697492e-02,  -9.35640857e-02,  -6.88539326e-01,
                         -9.14603829e-01,  -3.43592286e-01,  -7.52247423e-02,
                         -4.68043417e-01,  -7.23420441e-01,  -7.48642087e-01,
                         -5.53562284e-01,  -1.73105478e-01,  -2.93711275e-01,
                         -7.59090602e-01,  -8.12864721e-01,  -6.92092717e-01,
                         -7.07313836e-01,  -6.56352758e-01,  -6.13291204e-01,
                         -6.87619805e-01,  -7.36164272e-01,  -6.91634834e-01,
                         -6.85502529e-01,  -7.84578919e-01,  -6.19928777e-01,
                         -5.53845316e-02,   1.70041189e-01,  -2.91465878e-01,
                         -7.00742483e-01,  -6.46712899e-01,  -6.27727389e-01,
                         -8.25852871e-01,  -6.60554588e-01,  -1.56749055e-01,
                         -2.49508142e-01,  -8.13991666e-01,  -6.77761793e-01,
                         -1.06232785e-01,  -2.63745904e-01,  -7.64545619e-01,
                         -7.21203923e-01,  -6.08508706e-01,  -8.07778537e-01,
                         -6.05397761e-01,  -9.19575617e-02,  -2.56090313e-01,
                         -7.46770561e-01,  -6.84285104e-01,  -6.20648026e-01,
                         -8.52768838e-01,  -5.42104900e-01,  -1.63396131e-02,
                         -3.37684929e-01,  -9.13022637e-01,  -6.63266897e-01,
                         -1.08596206e-01,  -2.66274095e-01,  -7.63424158e-01,
                         -5.87673128e-01,  -1.21138982e-01,  -3.29153389e-01,
                         -5.97374797e-01,  -1.56072676e-01,   1.20234437e-01,
                         -3.22237670e-01,  -7.20987558e-01,  -7.13467062e-01,
                         -6.26304030e-01,  -6.61867499e-01,  -7.60557652e-01,
                         -7.34091103e-01,  -6.49520218e-01,  -6.44882619e-01,
                         -5.97533882e-01,  -6.53088331e-01,  -8.23983610e-01,
                         -5.86523950e-01,  -1.92063466e-01,  -3.61250848e-01,
                         -7.16018438e-01,  -7.11484671e-01,  -6.27719700e-01,
                         -6.48187935e-01,  -6.55306995e-01,  -6.92368448e-01,
                         -7.52313554e-01,  -7.06552446e-01,  -6.22625768e-01,
                         -6.49618328e-01,  -6.71656072e-01,  -6.69252872e-01,
                         -7.93221176e-01,  -6.62970304e-01,  -1.66133031e-01,
                         -1.69311076e-01,  -6.83567524e-01,  -7.71799564e-01,
                         -6.21248782e-01,  -7.45153308e-01,  -6.68375254e-01,
                         -1.80721477e-01,   1.37712434e-01,  -9.08185095e-02,
                         -5.48219502e-01,  -7.40900338e-01,  -7.26209879e-01,
                         -5.98376811e-01,  -1.63420692e-01,   1.56351268e-01,
                         -1.28431156e-01,  -5.95293462e-01,  -7.87301958e-01,
                         -7.07889020e-01,  -5.86335063e-01,  -7.26867735e-01,
                         -7.98689544e-01,  -3.77729207e-01,  -8.59558135e-02,
                         -4.05851275e-01,  -7.43679762e-01,  -7.00466692e-01,
                         -6.13889456e-01,  -6.84757352e-01,  -6.79604232e-01,
                         -6.07024431e-01,  -7.52765656e-01,  -7.89119363e-01,
                         -3.33884448e-01,  -5.48791438e-02,  -4.16542232e-01,
                         -7.52048135e-01,  -7.01741993e-01,  -6.19569659e-01,
                         -6.11770928e-01,  -6.45924032e-01,  -7.74898350e-01,
                         -6.99877739e-01,  -1.92478850e-01,   1.68755308e-01,
                         -1.56105593e-01,  -6.44766390e-01,  -6.90681159e-01,
                         -5.75016141e-01,  -6.16647661e-01,  -6.63439393e-01,
                         -6.54735804e-01,  -6.53228343e-01,  -6.31863594e-01,
                         -6.21430874e-01,  -6.60696030e-01,  -6.89363897e-01,
                         -6.72916830e-01,  -6.49391472e-01,  -6.43186569e-01,
                         -6.42859340e-01,  -6.52354658e-01,  -6.66411996e-01,
                         -6.43060446e-01,  -6.19509041e-01,  -6.76505923e-01,
                         -7.35114634e-01,  -6.86876833e-01,  -6.17895365e-01,
                         -6.10109866e-01,  -6.08564496e-01,  -6.35467708e-01,
                         -7.21677601e-01,  -7.31029868e-01,  -6.45267069e-01,
                         -6.31598115e-01,  -6.65060103e-01,  -6.21585190e-01,
                         -5.75678885e-01,  -6.03753209e-01,  -6.62866175e-01,
                         -7.21681952e-01,  -7.16593087e-01,  -6.42850697e-01,
                         -6.44292533e-01,  -6.71647429e-01,  -5.96576869e-01,
                         -6.38467968e-01,  -7.22752094e-01,  -3.73111814e-01,
                         -3.04484349e-02,  -3.91717285e-01,  -7.91815042e-01,
                         -6.68875635e-01,  -6.11046672e-01,  -6.94220364e-01,
                         -6.00824773e-01,  -6.08555555e-01,  -7.05228388e-01,
                         -6.43991590e-01,  -6.01359069e-01,  -6.41079485e-01,
                         -7.36550987e-01,  -7.78250158e-01,  -4.10053074e-01,
                         -1.95180848e-02,  -2.98579127e-01,  -7.35763013e-01,
                         -7.09953606e-01,  -6.47209227e-01,  -7.06389248e-01,
                         -4.22409981e-01,  -9.54013392e-02,  -4.10372138e-01,
                         -7.85514712e-01,  -4.10368979e-01,  -3.74417827e-02,
                         -3.45876962e-01,  -6.85404956e-01,  -7.43636727e-01,
                         -6.33102059e-01,  -2.32057258e-01,  -1.35961771e-01,
                         -6.79627240e-01,  -7.63330340e-01,  -1.18528828e-01,
                         -1.72149725e-02,  -6.02652252e-01,  -7.69589126e-01,
                         -5.59072793e-01,  -6.78677619e-01,  -6.74580395e-01,
                         -2.29780436e-01,  -2.11086512e-01,  -6.38509035e-01,
                         -6.60658300e-01,  -5.13934672e-01,  -6.45844638e-01,
                         -7.22607791e-01,  -6.72702789e-01,  -6.54895425e-01,
                         -6.29787087e-01,  -6.52123809e-01,  -6.54859841e-01,
                         -6.03126109e-01,  -7.10427463e-01,  -7.51372874e-01,
                         -2.98333645e-01,   2.51734108e-01,   1.05092898e-01,
                         -6.05214000e-01,  -8.95821452e-01,  -4.49909210e-01,
                          2.04642043e-02,   7.20055774e-02,  -2.49552038e-02,
                         -6.70012180e-03,   6.59378916e-02,   7.17066079e-02,
                          7.03480467e-02,   8.28660652e-02,   1.09530203e-02,
                         -2.97987424e-02,   3.78477462e-02,   6.37181550e-02,
                          5.18692508e-02,   1.50578627e-02,  -2.60890108e-02,
                          8.19589272e-02,   1.32142231e-01,   1.37408506e-02,
                          5.90954535e-02,   7.58049265e-03,  -4.12580222e-01,
                         -4.90345299e-01,  -3.15238945e-02,   1.83593392e-01,
                          4.25421260e-03,  -5.90652376e-02,   7.27524683e-02,
                          7.37136528e-02,  -1.41352657e-02,   9.70384777e-02,
                          4.03397232e-02,  -4.29624826e-01,  -4.68393296e-01,
                          5.67075312e-02,   1.24130100e-01,  -9.73706543e-02,
                          8.51468220e-02,   1.99267771e-02,  -4.75284427e-01,
                         -3.93158376e-01,   1.31705269e-01,   1.71317756e-01,
                         -5.61873242e-02,  -3.57794799e-02,   5.56980669e-02,
                          7.13622421e-02,   6.24912456e-02,   3.80948558e-02,
                          4.05804664e-02,   3.16605940e-02,   1.07587166e-02,
                          3.87590639e-02,   3.72637548e-02,   7.71830678e-02,
                          1.55056074e-01,  -9.78335813e-02,  -4.74490345e-01,
                         -3.47251326e-01,   2.44723484e-02,   1.03846036e-01,
                          5.84396385e-02,   8.64151046e-02,   6.82097748e-02,
                          1.30215781e-02,   2.10760068e-02,   2.93358937e-02,
                          1.42755816e-02,   1.24485470e-01,   1.50156796e-01,
                         -2.57962286e-01,  -5.51757812e-01,  -1.75163150e-01,
                          1.86473265e-01,   4.90199402e-02,  -2.85263490e-02,
                          1.14058934e-01,   1.04044601e-01,   3.01417187e-02,
                          8.46776515e-02,   3.97185609e-02,  -1.02294728e-01,
                          5.26081920e-02,   1.86486959e-01,  -2.92035341e-01,
                         -5.73717535e-01,   2.32657157e-02,   2.52497882e-01,
                         -3.69350970e-01,  -4.97564763e-01,  -1.26156539e-01,
                         -3.16170931e-01,  -4.75832313e-01,   9.64282602e-02,
                          3.15479755e-01,  -3.61988842e-01,  -6.26087189e-01,
                          3.31912423e-03,   1.91581562e-01,  -4.00754452e-01,
                         -5.24688542e-01,  -1.42518012e-02,   1.50389403e-01,
                         -2.45483760e-02,   6.20528422e-02,   1.42665505e-01,
                         -3.01790804e-01,  -7.68463433e-01,  -4.50524598e-01,
                          3.19004841e-02,  -3.30323905e-01,  -6.67901278e-01,
                         -4.02293876e-02,   3.37379515e-01,  -2.71641880e-01,
                         -6.95113778e-01,  -5.96330285e-01,  -6.38023317e-01,
                         -5.28645635e-01,   3.44666792e-03,   2.07080841e-01,
                         -2.86509603e-01,  -7.68222332e-01,  -5.62120497e-01,
                         -4.11793254e-02,   8.44023973e-02,   6.78646145e-03,
                          6.44727005e-03,  -3.55898857e-01,  -8.31303120e-01,
                         -5.30852973e-01,   7.21530020e-02,  -1.82009816e-01,
                         -8.29804361e-01,  -6.24879897e-01,  -3.25184315e-02,
                         -2.56208837e-01,  -5.94894886e-01,  -3.96409631e-02,
                          2.82782525e-01,  -3.37391585e-01,  -5.72376728e-01,
                         -1.16170451e-01,  -1.60245046e-01,  -6.99505270e-01,
                         -7.07138062e-01,  -6.50674254e-02,   2.58010179e-01,
                         -2.55266905e-01,  -6.19599223e-01,  -1.65018439e-01,
                         -3.49183865e-02,  -7.00228333e-01,  -7.89546251e-01,
                         -1.29774034e-01,  -1.35467589e-01,  -5.99270523e-01,
                         -2.41956621e-01,   2.62268722e-01,  -1.68992117e-01,
                         -5.54474533e-01,  -2.02864081e-01,  -1.89005300e-01,
                         -7.37661958e-01,  -7.75098681e-01,  -1.27393574e-01,
                          2.96577364e-01,  -7.33737126e-02,  -6.13512993e-01,
                         -4.14642960e-01,   8.54371339e-02,   6.07159249e-02,
                         -1.14791498e-01,  -2.90024430e-02,   5.72305359e-02,
                          1.19013861e-01,   1.17054693e-01,  -2.35790268e-01,
                         -7.19814479e-01,  -7.61509895e-01,  -2.69998699e-01,
                          1.81866020e-01,   2.14290824e-02,  -5.57804942e-01,
                         -8.35981488e-01,  -5.02263069e-01,  -2.63431203e-02,
                          7.71422908e-02,  -6.09624945e-03,  -1.25203595e-01,
                         -5.34834683e-01,  -7.75374413e-01,  -3.48142803e-01,
                         -8.85353088e-02,  -4.62653548e-01,  -5.01822472e-01,
                          1.92070995e-02,   4.41736169e-02,  -5.36419928e-01,
                         -5.50619364e-01,   1.00786783e-01,   1.21557243e-01,
                         -4.74524617e-01,  -4.55714256e-01,  -1.70601919e-01,
                         -4.62304294e-01,  -4.99545664e-01,   8.34994018e-02,
                          8.98402706e-02,  -5.74438691e-01,  -6.00389123e-01,
                          5.00767194e-02,   9.84920561e-02,  -4.91920978e-01,
                         -5.47203064e-01,  -5.97359911e-02,   1.06807828e-01,
                          1.96036929e-03,  -1.87059343e-02,  -4.84366901e-02,
                         -4.89159860e-02,   2.04724818e-02,   2.31890269e-02,
                         -9.01369099e-03,  -3.79247256e-02,  -6.99179769e-02,
                         -4.02833633e-02,  -1.16906816e-03,  -1.32591417e-02,
                         -3.50090489e-02,  -4.52989191e-02,  -1.60147548e-02,
                          4.03597066e-03,  -4.15350311e-02,  -2.56272629e-02,
                          5.26904650e-02,   3.04648355e-02,  -2.81107370e-02,
                         -1.46551467e-02,  -1.11941108e-02,  -4.69116606e-02,
                         -4.68901359e-02,   3.94984428e-03,   2.98016295e-02,
                         -2.69134957e-02,  -7.21075758e-02,  -9.37715825e-03,
                          4.38095294e-02,  -1.77403353e-02,  -8.50042701e-02,
                         -8.24574754e-02,  -5.17635904e-02,  -8.69165268e-03,
                         -2.42835041e-02,  -1.04770601e-01,  -5.84458262e-02,
                          6.42670169e-02,   3.24152522e-02,  -2.91087776e-02,
                         -1.40954321e-02,  -4.97826301e-02,  -5.36677800e-02,
                         -1.27108404e-02,  -3.71296629e-02,   2.74394415e-02,
                          3.81967649e-02,  -3.17495108e-01,  -5.58746099e-01,
                         -2.40208149e-01,   8.02812427e-02,  -3.89288329e-02,
                         -1.67539746e-01,   6.97423879e-04,   9.40661207e-02,
                         -4.66372855e-02,  -7.29626790e-02,   2.64603179e-03,
                          1.84638780e-02,   1.11920394e-01,  -3.97158079e-02,
                         -5.37475467e-01,  -5.14559507e-01,  -1.24013267e-01,
                         -4.13740903e-01,  -8.55319500e-01,  -6.75276697e-01,
                         -5.74696004e-01,  -7.47934163e-01,  -5.07003903e-01,
                         -5.58225773e-02,   1.36366952e-02,  -9.78216156e-02,
                         -1.48847224e-02,  -3.25007513e-02,  -5.01012564e-01,
                         -8.47061157e-01,  -5.15697300e-01,  -5.59933707e-02,
                          9.39039066e-02,   9.97717977e-02,  -1.82970047e-01,
                         -5.70116162e-01,  -4.26817238e-01,  -2.24702936e-02,
                          5.92880957e-02,  -3.07427044e-03,  -4.68341727e-03,
                         -3.20790261e-02,  -8.22665095e-02,  -6.09312691e-02,
                          8.64779204e-02,  -1.53505141e-02,  -6.27042055e-01,
                         -9.34577048e-01,  -4.29989636e-01,   3.16521935e-02,
                          1.45489015e-02,  -2.35884171e-02,  -1.52795792e-01,
                         -6.05783939e-01,  -8.47692668e-01,  -4.37184364e-01,
                          5.03225625e-02,   8.99014622e-03,  -8.10155123e-02,
                          7.81470016e-02,  -1.76918477e-01,  -5.88734627e-01,
                         -2.92670786e-01,  -7.32012540e-02,  -6.85424566e-01,
                         -9.19141233e-01,  -2.25011021e-01,   5.23396477e-04,
                         -6.97272658e-01,  -9.14541125e-01,  -2.43290514e-01,
                         -1.02373526e-01,  -6.73245251e-01,  -4.61510628e-01,
                          2.21817210e-01,  -1.11702077e-01,  -6.74369931e-01,
                         -3.64861518e-01,  -1.81754887e-01,  -4.71849591e-01,
                         -3.49407315e-01,  -2.38777012e-01,  -7.12219119e-01,
                         -8.53025198e-01,  -2.56188720e-01,   1.66740894e-01,
                         -8.69378000e-02,  -5.86807549e-01,  -7.96351314e-01,
                         -6.92164838e-01,  -6.48426235e-01,  -7.42305994e-01,
                         -7.37863123e-01,  -6.67506635e-01,  -6.80571258e-01,
                         -7.00578451e-01,  -6.65391445e-01,  -6.83236718e-01,
                         -7.86449969e-01,  -8.02119851e-01,  -6.86963618e-01,
                         -6.65226400e-01,  -7.51152873e-01,  -7.45140374e-01,
                         -6.96226120e-01,  -7.16983974e-01,  -7.58751452e-01,
                         -7.72649288e-01,  -7.11598694e-01,  -6.41058922e-01,
                         -6.82343423e-01,  -7.11962879e-01,  -6.66910529e-01,
                         -6.94779277e-01,  -7.55094767e-01,  -7.51958430e-01,
                         -7.21717536e-01,  -6.95107877e-01,  -7.31189191e-01,
                         -7.54594803e-01,  -6.55003667e-01,  -6.37029588e-01,
                         -7.41315961e-01,  -7.32207298e-01,  -7.13474214e-01,
                         -7.91366756e-01,  -7.72699118e-01,  -6.83022082e-01,
                         -6.71515286e-01,  -7.14829803e-01,  -7.48941481e-01,
                         -7.15326607e-01,  -6.94689929e-01,  -7.69600272e-01,
                         -7.70974576e-01,  -7.00275540e-01,  -7.16676056e-01,
                         -7.09669352e-01,  -6.88568056e-01,  -7.62196898e-01,
                         -7.39737272e-01,  -6.86578751e-01,  -8.03033710e-01,
                         -7.68192232e-01,  -5.91268420e-01,  -7.16892064e-01,
                         -7.35527039e-01,  -2.87502021e-01,  -2.30334803e-01,
                         -7.55713999e-01,  -8.57895434e-01,  -6.21681988e-01,
                         -7.74935484e-01,  -7.54318655e-01,  -2.14286536e-01,
                         -1.98464200e-01,  -8.58193278e-01,  -9.13644910e-01,
                         -2.08729342e-01,  -4.98267300e-02,  -7.10091412e-01,
                         -9.16664064e-01,  -2.78164119e-01,  -6.18954040e-02,
                         -6.98695064e-01,  -9.20000076e-01,  -3.49559218e-01,
                         -1.83802977e-01,  -6.71966553e-01,  -8.37140679e-01,
                         -6.63297296e-01,  -7.91146755e-01,  -8.02622259e-01,
                         -2.74520010e-01,  -1.19563267e-01,  -7.40255475e-01,
                         -9.26069438e-01,  -3.12144160e-01,  -1.40628308e-01,
                         -6.22622430e-01,  -8.04504693e-01,  -7.23035097e-01,
                         -8.01796794e-01,  -7.82389760e-01,  -6.89822674e-01,
                         -7.57219374e-01,  -7.93858230e-01,  -7.52756655e-01,
                         -6.96650445e-01,  -6.42414093e-01,  -7.75263846e-01,
                         -7.90114462e-01,  -3.72260123e-01,  -2.48500466e-01,
                         -6.81408167e-01,  -8.23603272e-01,  -6.43880963e-01,
                         -7.31517255e-01,  -8.68261993e-01,  -7.68022180e-01,
                         -5.46511054e-01,  -1.77384019e-01,   5.65583855e-02,
                         -3.02443266e-01,  -7.90859103e-01,  -7.81431258e-01,
                         -6.98923051e-01,  -8.15970182e-01,  -5.60539305e-01,
                         -1.25083968e-01,  -3.33828390e-01,  -8.48806858e-01,
                         -8.91630054e-01,  -7.07740724e-01,  -7.09462762e-01,
                         -7.27887154e-01,  -7.13257432e-01,  -7.69912541e-01,
                         -7.25022852e-01,  -6.49990916e-01,  -8.51959944e-01,
                         -9.15310562e-01,  -4.35492098e-01,  -1.43433496e-01,
                         -4.54607934e-01,  -7.48522043e-01,  -8.34944844e-01,
                         -7.44875789e-01,  -2.99313098e-01,  -1.70397997e-01,
                         -7.49846458e-01,  -9.02403355e-01,  -2.72939891e-01,
                         -1.33869678e-01,  -7.17974365e-01,  -8.19860041e-01,
                         -2.94790626e-01,  -2.26290569e-01,  -7.11636126e-01,
                         -8.60347569e-01,  -6.42345607e-01,  -6.67019427e-01,
                         -8.38746667e-01,  -7.35496342e-01,  -5.89689732e-01,
                         -8.01160276e-01,  -8.58731210e-01,  -2.73531795e-01,
                         -4.32911105e-02,  -7.47475386e-01,  -9.99983251e-01,
                         -2.95631319e-01,  -3.85069624e-02,  -5.59957981e-01,
                         -8.39016378e-01,  -7.42536068e-01,  -7.73323894e-01,
                         -7.30641484e-01,  -3.12757313e-01,   8.61992780e-03,
                         -1.52923092e-01,  -5.08991182e-01,  -7.71848202e-01,
                         -6.70809031e-01,  -2.23039761e-01,  -2.32595474e-01,
                         -7.47910440e-01,  -8.37485492e-01,  -6.50091946e-01,
                         -7.08063960e-01,  -6.58806622e-01,  -5.27871370e-01,
                         -6.06375039e-01,  -6.86084569e-01,  -7.39188135e-01,
                         -6.99959934e-01,  -3.23254734e-01,   5.89046329e-02,
                          4.44093347e-03,  -3.97261322e-01,  -7.66343296e-01,
                         -7.95206249e-01,  -6.34337962e-01,  -6.00030601e-01,
                         -6.87627316e-01,  -7.76621759e-01,  -6.58097208e-01,
                         -2.39725769e-01,   8.72638524e-02,  -4.51654680e-02,
                         -5.48412859e-01,  -8.59524906e-01,  -4.44564283e-01,
                          2.22853348e-02,  -3.96884769e-01,  -8.80054772e-01,
                         -4.51648027e-01,  -2.87986808e-02,  -4.11066800e-01,
                         -7.55078673e-01,  -6.10863447e-01,  -7.00893879e-01,
                         -8.93429577e-01,  -4.19585109e-01,  -2.99175014e-03,
                         -5.07461846e-01,  -9.01555598e-01,  -3.82555783e-01,
                          5.88228740e-03,  -4.55299914e-01,  -8.62388372e-01,
                         -4.85002309e-01,  -1.11699931e-01,  -4.28479612e-01,
                         -7.28524268e-01,  -6.28446937e-01,  -6.45212352e-01,
                         -7.11206794e-01,  -6.26294374e-01,  -6.63127303e-01,
                         -7.31579065e-01,  -6.92596316e-01,  -6.65341556e-01,
                         -6.22921228e-01,  -6.50267899e-01,  -7.04651952e-01,
                         -6.56698346e-01,  -7.92274594e-01,  -8.32033336e-01,
                         -3.32340240e-01,  -1.48100078e-01,  -5.17567635e-01,
                         -3.51364374e-01,  -6.37443513e-02,  -5.90457618e-01,
                         -8.19044530e-01,  -2.00717524e-01,  -1.45655558e-01,
                         -6.22073352e-01,  -3.47971886e-01,  -3.06017138e-02,
                         -6.02732599e-01,  -8.26118946e-01,  -1.91368863e-01,
                         -1.19496688e-01,  -6.36898518e-01,  -3.97978485e-01,
                          1.65081516e-01,  -1.16191916e-01,  -5.19249439e-01,
                         -2.96983063e-01,  -3.45557511e-01,  -6.12545431e-01,
                         -8.54835063e-02,   2.91608721e-01,  -3.48419935e-01,
                         -5.90147257e-01,  -1.61549658e-01,  -3.04813534e-01,
                         -5.14521420e-01,  -1.79896757e-01,  -3.00096869e-01,
                         -7.91256607e-01,  -5.63882232e-01,  -1.01409651e-01,
                         -3.31902146e-01,  -7.13395596e-01,  -6.74713492e-01,
                         -7.25090206e-01,  -8.31227541e-01,  -3.85262907e-01,
                         -6.61855638e-02,  -5.05747318e-01,  -5.85164547e-01,
                          7.99104273e-02,   1.86441585e-01,  -4.54578876e-01,
                         -7.82208860e-01,  -6.76522851e-01,  -6.55672491e-01,
                         -6.43038571e-01,  -5.37915349e-01,  -6.81227028e-01,
                         -8.30287337e-01,  -4.01602566e-01,  -4.20218296e-02,
                         -4.77080286e-01,  -8.45453441e-01,  -6.42952323e-01,
                         -6.27133965e-01,  -6.98323011e-01,  -2.99825728e-01,
                         -1.12883464e-01,  -5.77533484e-01,  -7.67725110e-01,
                         -3.12408566e-01,  -1.19686455e-01,  -5.07940948e-01,
                         -7.84315169e-01,  -7.47727394e-01,  -7.14961648e-01,
                         -6.72143698e-01,  -6.28188133e-01,  -6.85071349e-01,
                         -6.72645628e-01,  -6.08533680e-01,  -6.68522716e-01,
                         -7.04729199e-01,  -6.44489348e-01,  -6.29207790e-01,
                         -6.63124442e-01,  -7.33752668e-01,  -7.74036527e-01,
                         -6.46412253e-01,  -5.49291134e-01,  -6.94607079e-01,
                         -7.24607408e-01,  -3.14673752e-01,   8.38249549e-02,
                         -9.57449675e-02,  -5.53267300e-01,  -6.81071162e-01,
                         -6.02250397e-01,  -6.75007761e-01,  -7.48718798e-01,
                         -6.51710927e-01,  -5.63549578e-01,  -6.40467823e-01,
                         -6.96023643e-01,  -4.24626648e-01,  -4.98226099e-02,
                         -2.24471968e-02,  -9.41401720e-02,   4.19367477e-02,
                          9.19260904e-02,   1.14038493e-02,  -2.17544455e-02,
                         -6.63692057e-02,   1.23447673e-02,   1.05483525e-01,
                         -2.06307337e-01,  -5.18100142e-01,  -2.92453229e-01,
                          5.25769405e-02,   9.52551812e-02,  -3.69982533e-02,
                         -7.40959123e-02,   4.41451184e-02,  -9.89031196e-02,
                         -4.88284677e-01,  -3.85389239e-01,   5.55039868e-02,
                          8.84390771e-02,  -6.16030805e-02,  -1.62709989e-02,
                          3.75968143e-02,   6.41078055e-02,   8.59328434e-02,
                          1.32391015e-02,  -5.35565130e-02,  -2.60042883e-02,
                          4.14791331e-02,   7.60295168e-02,   1.72825530e-02,
                         -6.55862987e-02,  -4.36166525e-02,   5.15655354e-02,
                          6.21492229e-02,  -3.67166549e-02,  -6.09067231e-02,
                          1.35517148e-02,   2.45902762e-02,   1.30606927e-02,
                          3.42313983e-02,   2.23140586e-02,   1.57326851e-02,
                          1.18207640e-03,  -1.24518331e-02,   5.03953211e-02,
                          3.81022580e-02,  -3.32653843e-04,   8.86030346e-02,
                         -8.83406177e-02,  -5.04882336e-01,  -4.62070256e-01,
                         -8.16350877e-02,   7.03120902e-02,   7.20117539e-02,
                          4.02326025e-02,  -3.68328206e-02,   7.15503981e-03,
                          8.37758034e-02,  -3.31320204e-02,  -1.42116815e-01,
                          6.58322647e-02,   2.20464483e-01,  -2.26402804e-01,
                         -6.27007663e-01,  -2.11784661e-01,   1.45779461e-01,
                         -1.05301835e-01,  -3.32665071e-02,   1.93919644e-01,
                         -2.92903721e-01,  -6.55451953e-01,  -2.10600466e-01,
                          1.02603838e-01,  -3.04137245e-02,  -9.91535955e-04,
                          1.37299940e-01,   4.99849655e-02,  -2.31258929e-01,
                         -5.36074162e-01,  -6.15941703e-01,  -5.67974746e-01,
                         -7.62601435e-01,  -8.20733190e-01,  -2.78896362e-01,
                          6.98513491e-03,  -6.00627184e-01,  -9.24533367e-01,
                         -3.10241967e-01,  -7.61191770e-02,  -5.81895053e-01,
                         -4.44333225e-01,   2.11917818e-01,   2.41899863e-02,
                         -5.89071035e-01,  -6.73937380e-01,  -6.60928965e-01,
                         -6.37790740e-01,  -2.10174084e-01,  -1.31554142e-01,
                         -7.34812558e-01,  -8.16960394e-01,  -1.89457506e-01,
                         -1.26788571e-01,  -6.52360022e-01,  -7.42401302e-01,
                         -6.16044819e-01,  -8.10845673e-01,  -6.44172668e-01,
                         -1.51979094e-02,  -1.17923141e-01,  -8.35558236e-01,
                         -7.38952994e-01,  -7.73331150e-02,  -2.20150068e-01,
                         -7.85547614e-01,  -7.11879790e-01,  -5.54063678e-01,
                         -7.91318417e-01,  -5.94650984e-01,  -1.32388651e-01,
                         -3.06808323e-01,  -4.32970166e-01,  -7.98194632e-02,
                         -3.37931633e-01,  -9.18284059e-01,  -5.77601969e-01,
                         -5.07288165e-02,  -3.50124508e-01,  -7.39100933e-01,
                         -6.54390633e-01,  -6.05360985e-01,  -7.22746551e-01,
                         -5.12649655e-01,   1.19953312e-03,   6.24635108e-02,
                         -4.49905068e-01,  -5.82349002e-01,  -6.05760776e-02,
                          1.81266978e-01,  -2.43736610e-01,  -7.19462872e-01,
                         -7.54426301e-01,  -3.27718973e-01,   1.34990647e-01,
                         -1.55320233e-02,  -5.29713809e-01,  -4.13289905e-01,
                          1.32497534e-01,  -1.87453851e-02,  -6.07766271e-01,
                         -4.98795271e-01,   7.38233700e-02,   1.08871177e-01,
                         -3.88161302e-01,  -7.56742716e-01,  -6.30208194e-01,
                         -1.26933172e-01,   1.10881992e-01,  -2.79308856e-01,
                         -5.75643003e-01,  -2.41191804e-01,   1.11541986e-01,
                          6.68615103e-02,  -1.45473853e-01,  -4.72589791e-01,
                         -7.10837185e-01,  -6.45684958e-01,  -6.62097096e-01,
                         -7.65226185e-01,  -5.89438617e-01,  -5.45425355e-01,
                         -7.46071219e-01,  -4.82730448e-01,   3.13938372e-02,
                          7.35746324e-02,  -2.38742400e-02,   7.95323476e-02,
                         -7.31172636e-02,  -5.28045416e-01,  -7.47937620e-01,
                         -6.58366919e-01,  -6.54549062e-01,  -7.74833739e-01,
                         -6.82888567e-01,  -5.32271087e-01,  -7.65354753e-01,
                         -8.94281864e-01,  -3.58983159e-01,  -6.34039268e-02,
                         -4.97039348e-01,  -4.49451178e-01,   1.51484698e-01,
                         -2.54478995e-02,  -5.81053197e-01,  -3.79484087e-01,
                          5.17406166e-02,   1.22517191e-01,   6.57096431e-02,
                         -2.88550079e-01,  -8.30456078e-01,  -7.38055170e-01,
                         -1.72070563e-01,  -1.91723496e-01,  -6.84069932e-01,
                         -7.19327033e-01,  -5.57244599e-01,  -7.59743035e-01,
                         -6.81624949e-01,  -1.99568972e-01,  -2.58480966e-01,
                         -6.90192699e-01,  -7.31514096e-01,  -6.65488958e-01,
                         -7.04417765e-01,  -4.70251024e-01,  -1.03389077e-01,
                         -4.22520563e-02,  -1.22578003e-01,   2.33549327e-02,
                          4.83960137e-02,  -3.71299773e-01,  -5.10269403e-01,
                         -9.91745815e-02,   3.58661450e-02,  -9.23235044e-02,
                          2.11149640e-02,   6.79724589e-02,  -4.26782761e-03,
                          3.57645154e-02,  -5.60612651e-03,  -3.78817357e-02,
                          1.17782690e-02,  -6.72188550e-02,  -2.78780032e-02,
                          5.80724403e-02,  -2.99134970e-01,  -6.05666339e-01,
                         -2.44000643e-01,   1.96788490e-01,   8.10890496e-02,
                         -1.98011845e-01,  -6.10083267e-02,   1.32765323e-01,
                         -2.32231110e-01,  -6.30048871e-01,  -3.43332201e-01,
                          9.10421386e-02,   5.25785461e-02,  -8.09953064e-02,
                          2.88610030e-02,   6.94258660e-02,  -8.12984109e-02,
                         -5.21432869e-02,   6.94750473e-02,  -2.16928914e-01,
                         -5.38289249e-01,  -2.74434805e-01,   6.27712235e-02,
                         -1.30336881e-02,  -5.58553115e-02,   7.17033744e-02,
                          3.63296010e-02,  -1.00418553e-01,  -1.24864541e-01,
                         -4.44989577e-02,   2.81954594e-02,   9.61790036e-04,
                         -1.92727353e-02,   5.93093708e-02,   5.95158190e-02,
                         -4.18307632e-02,  -3.62985730e-02,   4.68007550e-02,
                          5.88589013e-02,   1.09243980e-02,  -4.92800698e-02,
                         -3.47680822e-02,   7.49556273e-02,   4.62043192e-03,
                         -3.90797764e-01,  -7.33628511e-01,  -7.42652953e-01,
                         -6.98742568e-01,  -7.56087482e-01,  -5.46592832e-01,
                         -4.79672141e-02,   1.08248800e-01,  -2.97035635e-01,
                         -7.30269194e-01,  -7.29916155e-01,  -3.26648235e-01,
                          2.83232275e-02,   2.65550171e-03,  -3.50894146e-02,
                          9.50665995e-02,  -1.33999079e-01,  -5.08918881e-01,
                         -2.92472929e-01,   4.38123159e-02,  -8.55726078e-02,
                         -8.39720815e-02,   1.19818568e-01,  -2.12834850e-01,
                         -6.32010698e-01,  -2.55584687e-01,   1.78381607e-01,
                         -2.29039863e-01,  -6.41107738e-01,  -2.54777044e-01,
                          1.84956431e-01,   7.38703609e-02,  -1.07744142e-01,
                         -5.90845346e-02,  -1.29818460e-02,  -2.20296420e-02,
                          2.72854092e-03,   1.77156106e-02,   1.05230408e-02,
                          1.47840159e-03,  -3.22012343e-02,  -1.54035361e-02,
                          3.59117985e-02,  -4.74552996e-02,  -7.75868893e-02,
                          6.86052740e-02,  -1.14939317e-01,  -5.43204606e-01,
                         -4.07656431e-01,   5.18929064e-02,   7.78438300e-02,
                         -6.09249100e-02,   2.26450618e-02,   5.65465353e-02,
                         -7.54299685e-02,  -8.93187821e-02,   3.70215401e-02,
                         -1.30511075e-01,  -4.91853565e-01,  -3.41419995e-01,
                          2.47379392e-02,  -4.48816791e-02,  -6.63272152e-03,
                          1.64996013e-01,  -3.12982112e-01,  -7.04819679e-01,
                         -2.36267194e-01,  -7.44209513e-02,  -6.76555395e-01,
                         -7.62675583e-01,  -1.77242383e-01,  -1.17590755e-01,
                         -6.35950804e-01,  -7.92370498e-01,  -5.99540472e-01,
                         -6.25033200e-01,  -7.34911323e-01,  -7.21980095e-01,
                         -7.58221924e-01,  -7.77632117e-01,  -6.77530527e-01,
                         -6.30335212e-01,  -6.68675184e-01,  -6.70282781e-01,
                         -6.45013332e-01,  -6.83253706e-01,  -7.51953542e-01,
                         -7.18196690e-01,  -6.40155613e-01,  -6.57675385e-01,
                         -6.85732603e-01,  -6.54602051e-01,  -6.48668647e-01,
                         -6.89742327e-01,  -7.10459948e-01,  -6.51550770e-01,
                         -6.09673798e-01,  -6.92247689e-01,  -7.31979489e-01,
                         -6.56404972e-01,  -6.42263830e-01,  -6.72098398e-01,
                         -6.68974102e-01,  -6.99858248e-01,  -7.46847332e-01,
                         -7.48612523e-01,  -6.78656518e-01,  -5.94540298e-01,
                         -6.32729232e-01,  -6.97832882e-01,  -6.53506756e-01,
                         -6.42520308e-01,  -6.96511984e-01,  -6.94424987e-01,
                         -6.72141075e-01,  -6.72660351e-01,  -6.72130525e-01,
                         -6.54635966e-01,  -6.39844239e-01,  -6.89816594e-01,
                         -7.28494644e-01,  -6.73766375e-01,  -6.43655479e-01,
                         -6.59621179e-01,  -6.56808138e-01,  -6.81701124e-01,
                         -7.07163274e-01,  -6.89011216e-01,  -6.91423953e-01,
                         -7.44725823e-01,  -7.73588181e-01,  -6.67699337e-01,
                         -5.60944200e-01,  -6.63577616e-01,  -7.58728504e-01,
                         -6.80292666e-01,  -6.32807434e-01,  -6.16091490e-01,
                         -5.97427547e-01,  -6.95113301e-01,  -7.58686244e-01,
                         -6.77432656e-01,  -6.12108290e-01,  -6.54044569e-01,
                         -7.45945752e-01,  -7.16268778e-01,  -6.26880765e-01,
                         -7.28396535e-01,  -7.91284978e-01,  -6.39468908e-01,
                         -5.91713011e-01,  -6.59931600e-01,  -7.07590699e-01,
                         -7.32909739e-01,  -6.30293727e-01,  -6.46502912e-01,
                         -7.70986557e-01,  -4.37800825e-01,  -1.22661531e-01,
                         -4.22529876e-01,  -5.02892852e-01,  -1.95871353e-01,
                         -3.66914093e-01,  -7.31941760e-01,  -6.88020468e-01,
                         -6.06024325e-01,  -7.29826331e-01,  -7.70908296e-01,
                         -6.54536188e-01,  -6.42632544e-01,  -6.96058333e-01,
                         -4.24760550e-01,  -1.26659408e-01,  -3.94266129e-01,
                         -7.62758851e-01,  -7.25694597e-01,  -6.49417400e-01,
                         -6.31421804e-01,  -5.98097920e-01,  -7.52162218e-01,
                         -7.00772643e-01,  -2.05839112e-01,  -1.16449669e-01,
                         -6.11845911e-01,  -7.92202532e-01,  -6.83811724e-01,
                         -7.66193390e-01,  -5.45630455e-01,  -9.56613496e-02,
                         -3.45378071e-01,  -6.82871640e-01,  -9.51013193e-02,
                          2.81209290e-01,  -3.52637053e-01,  -6.01613522e-01,
                         -1.04060277e-01,  -2.20418021e-01,  -8.55227292e-01,
                         -7.09251821e-01,  -4.84285019e-02,  -1.61885470e-01,
                         -8.15275073e-01,  -7.31601775e-01,  -1.52282998e-01,
                         -2.09861889e-01,  -6.35846257e-01,  -7.42919326e-01,
                         -6.73846126e-01,  -4.15144265e-01,  -1.16412982e-01,
                         -3.94712001e-01,  -8.08680058e-01,  -5.27007282e-01,
                         -1.27223387e-01,  -3.75508338e-01,  -7.72949755e-01,
                         -7.12949038e-01,  -5.72477579e-01,  -6.58085525e-01,
                         -4.49968249e-01,  -8.53147954e-02,  -4.19835567e-01,
                         -8.86115849e-01,  -5.06395817e-01,  -6.56209216e-02,
                         -3.29779446e-01,  -7.01425314e-01,  -7.39388347e-01,
                         -6.13068998e-01,  -6.53358877e-01,  -8.63836765e-01,
                         -5.90560019e-01,  -4.71428894e-02,  -2.86442697e-01,
                         -6.36002362e-01,  -7.55616426e-02,   1.83734581e-01,
                         -4.70192045e-01,  -5.65032125e-01,  -4.36213613e-02,
                         -2.38184899e-01,  -7.67018855e-01,  -7.16864944e-01,
                         -6.07198894e-01,  -7.21927643e-01,  -4.71824348e-01,
                         -1.36065274e-01,  -4.50542122e-01,  -8.00594032e-01,
                         -3.77207994e-01,  -7.65022561e-02,  -5.20967782e-01,
                         -5.13896644e-01,  -3.69972326e-02,  -4.51336145e-01,
                         -9.29701746e-01,  -3.54800522e-01,  -8.62005651e-02,
                         -4.70158428e-01,  -2.98095465e-01,  -1.43867582e-01,
                         -5.20521462e-01,  -3.47771525e-01,   1.42992973e-01,
                         -1.24581687e-01,  -6.50399148e-01,  -6.71215177e-01,
                         -5.82086861e-01,  -7.85964072e-01,  -7.79575229e-01,
                         -2.62392282e-01,  -8.12732950e-02,  -6.07169747e-01,
                         -8.20417345e-01,  -2.94609129e-01,   1.60083875e-01,
                         -4.40730108e-03,  -5.06178677e-01,  -7.33746588e-01,
                         -6.00109220e-01,  -5.83539069e-01,  -6.97963238e-01,
                         -6.89634740e-01,  -6.99439287e-01,  -7.36174405e-01,
                         -6.84389949e-01,  -6.58014059e-01,  -6.85043454e-01,
                         -7.14559197e-01,  -6.71904385e-01,  -5.80743492e-01,
                         -7.22487926e-01,  -8.14643443e-01,  -3.39880407e-01,
                         -1.09249260e-02,  -4.55220610e-01,  -8.21040750e-01,
                         -6.95267081e-01,  -6.46325350e-01,  -6.56925976e-01,
                         -6.27006173e-01,  -7.91725397e-01,  -6.74985290e-01,
                         -1.14038512e-01,  -1.22587353e-01,  -7.24629283e-01,
                         -8.07348609e-01,  -5.84582329e-01,  -7.47492015e-01,
                         -6.67541862e-01,  -1.80653304e-01,  -2.30083019e-01,
                         -7.17692494e-01,  -8.13285232e-01,  -6.33933067e-01,
                         -5.92695951e-01,  -6.45707965e-01,  -7.04844892e-01,
                         -7.09315002e-01,  -6.69069290e-01,  -6.81356609e-01,
                         -6.67585075e-01,  -6.19249284e-01,  -6.74452960e-01,
                         -7.43626177e-01,  -7.32017457e-01,  -7.04145670e-01,
                         -6.68256998e-01,  -6.66385770e-01,  -6.70965731e-01,
                         -6.41976893e-01,  -7.43698001e-01,  -7.23787785e-01,
                         -2.71401614e-01,  -8.84783715e-02,  -5.37215054e-01,
                         -7.77508974e-01,  -6.47192478e-01,  -7.00328946e-01,
                         -7.62907803e-01,  -6.45568132e-01,  -6.44620836e-01,
                         -7.43055820e-01,  -7.37975299e-01,  -6.54793382e-01,
                         -6.12678230e-01,  -6.63233817e-01,  -7.01993346e-01,
                         -6.88459992e-01,  -7.07148850e-01,  -6.90801740e-01,
                         -6.07236147e-01,  -6.08107090e-01,  -7.13812411e-01,
                         -7.58221865e-01,  -6.63250268e-01,  -6.20447516e-01,
                         -7.41470575e-01,  -7.59236097e-01,  -6.34460986e-01,
                         -6.51910007e-01,  -7.26364613e-01,  -6.92055464e-01,
                         -6.73616886e-01,  -6.83363557e-01,  -6.76244497e-01,
                         -6.69493377e-01,  -6.34662509e-01,  -6.41524792e-01,
                         -6.91175520e-01,  -6.93400145e-01,  -7.24374771e-01,
                         -7.43438482e-01,  -6.61375165e-01,  -6.40721560e-01,
                         -6.79337442e-01,  -6.62395716e-01,  -6.92774117e-01,
                         -7.28990674e-01,  -6.66306794e-01,  -6.40145898e-01,
                         -6.94536746e-01,  -7.33168483e-01,  -7.23352313e-01,
                         -6.59064710e-01,  -6.16381645e-01,  -6.61940098e-01,
                         -7.05412567e-01,  -6.91974938e-01,  -6.81894481e-01,
                         -7.00905442e-01,  -6.99359000e-01,  -6.51480079e-01,
                         -6.41938269e-01,  -7.03196645e-01,  -7.12928236e-01,
                         -6.62083209e-01,  -6.70841813e-01,  -6.91779912e-01,
                         -6.39500201e-01,  -6.26954138e-01,  -7.01575339e-01,
                         -7.15550244e-01,  -6.67158484e-01,  -6.80629551e-01,
                         -6.95460260e-01,  -6.50956810e-01,  -6.46973908e-01,
                         -6.94304109e-01,  -7.10892797e-01,  -6.80624068e-01,
                         -6.49468422e-01,  -6.76683962e-01,  -7.14900315e-01,
                         -7.07004964e-01,  -7.28349626e-01,  -7.26903498e-01,
                         -6.17329597e-01,  -5.85760713e-01,  -6.76022708e-01,
                         -6.83878601e-01,  -6.51153386e-01,  -6.83705211e-01,
                         -6.82955801e-01,  -6.50472164e-01,  -6.67620540e-01,
                         -6.88424289e-01,  -6.79172158e-01,  -6.74930036e-01,
                         -6.85496449e-01,  -6.98858678e-01,  -7.09380865e-01,
                         -7.06307113e-01,  -6.64184511e-01,  -6.18944287e-01,
                         -6.54186010e-01,  -6.99294090e-01,  -6.54009700e-01,
                         -6.59353495e-01,  -7.36664176e-01,  -6.53097510e-01,
                         -5.83312809e-01,  -7.96000659e-01,  -7.81857729e-01,
                         -2.70230263e-01,  -7.42262080e-02,  -4.96448338e-01,
                         -8.04454446e-01,  -7.50082970e-01,  -5.29777646e-01,
                         -1.06080510e-01,   1.40184686e-01,  -2.14388445e-01,
                         -6.53376579e-01,  -7.00205743e-01,  -7.12564409e-01,
                         -8.00009787e-01,  -5.50289929e-01,  -1.44901469e-01,
                         -2.35902771e-01,  -6.67700887e-01,  -7.65535116e-01,
                         -6.83245182e-01,  -7.88092375e-01,  -5.73754966e-01,
                         -5.45498356e-02,  -2.32194200e-01,  -8.12399745e-01,
                         -6.05677664e-01,  -1.05353817e-01,  -2.71504670e-01,
                         -6.24119222e-01,  -7.25201309e-01,  -7.46956229e-01,
                         -4.78733122e-01,   8.34303629e-03,   8.01089332e-02,
                         -3.78567040e-01,  -8.16420853e-01,  -6.61774874e-01,
                         -1.13774493e-01,  -1.33658201e-01,  -7.44994700e-01,
                         -7.74280727e-01,  -1.53644651e-01,  -1.29612342e-01,
                         -7.52205491e-01,  -7.75794148e-01,  -2.35432684e-01,
                         -2.72260278e-01,  -5.57923079e-01,  -1.57798752e-01,
                          2.10725158e-01,  -8.30429941e-02,  -1.59108996e-01,
                          1.31146193e-01,  -1.49306744e-01,  -7.94360399e-01,
                         -7.46463239e-01,  -1.54155523e-01,  -1.41683206e-01,
                         -7.53501415e-01,  -8.23211193e-01,  -2.02522904e-01,
                         -1.00133911e-01,  -6.89392388e-01,  -7.65226901e-01,
                         -2.14983314e-01,  -2.05550432e-01,  -6.27051353e-01,
                         -3.35004658e-01,   2.07005873e-01,  -1.52861848e-01,
                         -7.12356091e-01,  -3.67447048e-01,   2.04591066e-01,
                          4.66503948e-03,  -5.61778843e-01,  -7.64357269e-01,
                         -7.49423444e-01,  -6.74125433e-01,  -2.77657926e-01,
                          9.62876305e-02,   7.84728490e-03,  -7.70407170e-02,
                          2.39398200e-02,  -1.96401477e-01,  -6.41276002e-01,
                         -7.50346065e-01,  -3.79561335e-01,   3.98536772e-02,
                         -1.06698997e-01,  -5.70230246e-01,  -4.98483777e-01,
                         -2.05195732e-02,   6.16001263e-02,  -3.83516192e-01,
                         -7.98257828e-01,  -6.51867270e-01,  -1.41336575e-01,
                          8.95602107e-02,  -5.80422673e-03,  -6.87285736e-02,
                         -4.27750051e-02,  -1.02715585e-02,  -1.03331963e-02,
                         -2.50831414e-02,  -3.77590675e-03,  -8.00736062e-03,
                         -3.66115123e-02,  -1.81220118e-02,  -3.42134573e-02,
                         -8.38516504e-02,  -5.38155660e-02,  -1.30752623e-02,
                         -4.49510105e-02,  -6.35160580e-02,  -1.15322915e-03,
                          5.41074760e-02,   1.91889575e-03,  -6.39250502e-02,
                         -4.61072177e-02,  -4.05503251e-02,  -6.05986603e-02,
                         -2.17592660e-02,   8.59206892e-04,  -4.75345403e-02,
                         -6.86531067e-02,  -4.22031693e-02,  -2.71933079e-02,
                          4.81720688e-03,   4.64972146e-02,  -3.74186970e-03,
                         -6.27303123e-02,   6.15794351e-03,   1.91528648e-02,
                         -1.02320239e-01,  -8.60841423e-02,   4.07237671e-02,
                          2.25768741e-02,  -5.01067005e-02,  -4.30748798e-02,
                         -1.77217554e-02,  -3.94723844e-03,  -4.34967950e-02,
                         -1.18084706e-01,  -8.98090154e-02,  -2.32251082e-03,
                          1.25900256e-02,  -5.28888451e-03,  -3.06426380e-02,
                         -5.79090193e-02,   7.33439159e-03,   8.14817324e-02,
                         -8.60257167e-03,  -1.18463576e-01,  -6.67809919e-02,
                          9.74427559e-04,  -2.87468825e-02,  -4.82962169e-02,
                         -2.31836569e-02,  -2.06335131e-02,  -4.84513529e-02,
                         -6.71456903e-02,  -5.94230853e-02,  -4.31956723e-02,
                         -1.99635103e-02,   1.04831960e-02,   7.30637601e-03,
                         -3.11271660e-02,  -5.80211282e-02,  -4.11804281e-02,
                          1.00873429e-02,   1.44379158e-02,  -4.22249846e-02,
                         -5.82400002e-02,  -2.31210981e-02,   2.22391654e-02,
                          4.53532003e-02,  -1.92369018e-02,  -8.04055184e-02,
                         -4.25931364e-02,  -1.61846597e-02,  -1.83549020e-02,
                         -3.09441537e-02,  -9.05519575e-02,  -6.14717826e-02,
                          2.27230322e-02,  -6.84143789e-03,   3.67796305e-03,
                          5.36864288e-02,  -3.09774037e-02,  -6.86366186e-02,
                         -3.73644531e-02,  -1.08210430e-01,  -8.56012329e-02,
                          7.01164454e-02,   8.73148069e-02,   2.68921303e-03,
                          5.53176156e-04,   4.62371074e-02,   8.45338125e-03,
                         -8.76265317e-02,  -6.54326826e-02,  -2.97252974e-03,
                         -9.21831354e-02,  -1.36553317e-01,   2.64323037e-02,
                          1.43005699e-01,   3.68163735e-02,  -1.14501618e-01,
                         -9.03527066e-02,   1.65610109e-02,   3.45513783e-03,
                         -2.41225753e-02,   1.86694134e-02,  -2.76683550e-03,
                         -3.22991461e-02,  -9.83241294e-03,  -3.88848335e-02,
                         -3.52146886e-02,   3.37998122e-02,   1.20745711e-02,
                         -3.77627984e-02,  -2.44452544e-02,  -1.82550829e-02,
                          3.56722460e-03,  -3.19994939e-03,  -8.80473703e-02,
                         -4.42801863e-02,   4.66965064e-02,  -6.27748519e-02,
                         -3.82462814e-02,   1.00474551e-01,  -2.48803541e-01,
                         -5.45966506e-01,  -1.67742416e-01,  -1.76034510e-01,
                         -8.47465217e-01,  -8.44713330e-01,  -1.70214221e-01,
                          1.21007442e-01,  -1.37402818e-01,  -6.45120680e-01,
                         -8.00952494e-01,  -3.16370845e-01,  -8.24638307e-02,
                         -4.64509875e-01,  -7.75187194e-01,  -8.11716497e-01,
                         -5.55655599e-01,  -1.38316259e-01,  -2.64590114e-01,
                         -7.44110942e-01,  -7.61804461e-01,  -5.90373158e-01,
                         -6.53469265e-01,  -6.78317845e-01,  -6.33258700e-01,
                         -6.98576987e-01,  -7.55310714e-01,  -6.97025061e-01,
                         -6.82735264e-01,  -7.66911685e-01,  -5.79223037e-01,
                         -4.08027731e-02,   1.49977207e-01,  -3.06498647e-01,
                         -7.25274563e-01,  -6.89423621e-01,  -6.35095000e-01,
                         -7.65711606e-01,  -5.61029911e-01,  -7.37658888e-02,
                         -2.34934106e-01,  -8.73024464e-01,  -7.49007463e-01,
                         -1.15449883e-01,  -2.05002382e-01,  -7.20853508e-01,
                         -7.68999755e-01,  -6.77531123e-01,  -7.80259132e-01,
                         -5.57003975e-01,  -1.16409555e-01,  -2.36754328e-01,
                         -6.77853763e-01,  -7.15394378e-01,  -6.61990702e-01,
                         -8.00586104e-01,  -5.41223645e-01,  -7.07906857e-02,
                         -3.12905550e-01,  -8.59318256e-01,  -6.39445364e-01,
                         -7.73751810e-02,  -2.59991139e-01,  -8.15221846e-01,
                         -6.30659103e-01,  -9.76002291e-02,  -3.05600852e-01,
                         -6.33735478e-01,  -1.56002656e-01,   1.77592725e-01,
                         -3.17214429e-01,  -7.11583912e-01,  -6.57119453e-01,
                         -6.55611634e-01,  -7.19280601e-01,  -7.12985396e-01,
                         -6.95532143e-01,  -6.86617792e-01,  -6.60691917e-01,
                         -5.99320948e-01,  -7.05264509e-01,  -8.71111214e-01,
                         -5.30071318e-01,  -7.72775859e-02,  -3.17301214e-01,
                         -7.27955639e-01,  -7.22913504e-01,  -6.71069503e-01,
                         -6.71037495e-01,  -6.01737440e-01,  -6.54824853e-01,
                         -7.54359543e-01,  -6.76823914e-01,  -5.92256069e-01,
                         -6.97560489e-01,  -7.77469754e-01,  -6.93178773e-01,
                         -6.89262867e-01,  -6.23134971e-01,  -2.48955905e-01,
                         -1.81551307e-01,  -6.24168694e-01,  -7.52587795e-01,
                         -5.92071891e-01,  -7.40202487e-01,  -7.36345768e-01,
                         -1.96822196e-01,   1.51741371e-01,  -1.51787087e-01,
                         -5.75609565e-01,  -6.83690786e-01,  -7.03256845e-01,
                         -6.26196504e-01,  -1.72276273e-01,   1.60837412e-01,
                         -1.42189398e-01,  -5.79180062e-01,  -7.24106908e-01,
                         -6.96057677e-01,  -6.36695087e-01,  -7.68185735e-01,
                         -8.22453022e-01,  -3.41960281e-01,  -1.65285133e-02,
                         -4.13958758e-01,  -7.71701872e-01,  -7.02742457e-01,
                         -6.52126670e-01,  -6.97460532e-01,  -6.36160254e-01,
                         -5.56729317e-01,  -6.94834054e-01,  -7.77736902e-01,
                         -3.73772591e-01,  -8.86096433e-02,  -4.71490473e-01,
                         -7.75003254e-01,  -6.60630465e-01,  -6.41265810e-01,
                         -6.75055504e-01,  -6.31105959e-01,  -7.10509598e-01,
                         -6.68515921e-01,  -2.25961223e-01,   1.47285759e-01,
                         -9.55851823e-02,  -5.95486581e-01,  -7.17713118e-01,
                         -6.29550815e-01,  -6.61583006e-01,  -6.72640920e-01,
                         -6.32946372e-01,  -6.41523898e-01,  -6.64367199e-01,
                         -6.83062792e-01,  -6.62679851e-01,  -6.42761111e-01,
                         -6.89164579e-01,  -6.91790462e-01,  -6.25564098e-01,
                         -5.86480677e-01,  -6.05137587e-01,  -6.78063035e-01,
                         -7.04291880e-01,  -6.51437700e-01,  -6.43457711e-01,
                         -6.60732687e-01,  -6.35961056e-01,  -6.23483658e-01,
                         -6.64560378e-01,  -7.25762010e-01,  -6.98004842e-01,
                         -6.07127130e-01,  -6.11651003e-01,  -6.47746921e-01,
                         -6.29106939e-01,  -6.44281447e-01,  -6.77719891e-01,
                         -6.67968988e-01,  -6.31157279e-01,  -6.15781069e-01,
                         -6.69728756e-01,  -6.90900087e-01,  -6.38231874e-01,
                         -6.59391463e-01,  -6.69566572e-01,  -5.92427790e-01,
                         -6.81527138e-01,  -7.63277590e-01,  -3.88282657e-01,
                         -5.32696582e-02,  -3.85757297e-01,  -7.44855940e-01,
                         -6.27676070e-01,  -6.10607922e-01,  -7.61087060e-01,
                         -6.81703091e-01,  -5.88189065e-01,  -6.06858730e-01,
                         -6.31229877e-01,  -6.84212983e-01,  -6.18184030e-01,
                         -5.92714310e-01,  -7.38853157e-01,  -4.92975742e-01,
                         -6.45446479e-02,  -3.07920843e-01,  -7.44758844e-01,
                         -6.67727709e-01,  -6.18285298e-01,  -7.67726719e-01,
                         -4.20504451e-01,   4.41993736e-02,  -3.63488257e-01,
                         -8.90932798e-01,  -4.54108179e-01,  -1.28044151e-02,
                         -3.68181020e-01,  -6.96877778e-01,  -7.10984886e-01,
                         -6.23647034e-01,  -2.32515916e-01,  -9.36595723e-02,
                         -6.42634153e-01,  -7.92940855e-01,  -1.72527477e-01,
                         -5.51381372e-02,  -6.07403398e-01,  -7.18328834e-01,
                         -5.40560424e-01,  -7.33557701e-01,  -6.71990097e-01,
                         -1.50687575e-01,  -1.49021789e-01,  -6.36884093e-01,
                         -7.37146795e-01,  -5.85943878e-01,  -6.31066322e-01,
                         -6.66325152e-01,  -6.11142397e-01,  -6.26790166e-01,
                         -6.44647658e-01,  -6.45058334e-01,  -6.59050286e-01,
                         -6.34077966e-01,  -6.77502096e-01,  -6.75701380e-01,
                         -2.86815256e-01,   1.56553581e-01,   3.22481580e-02,
                         -4.99292821e-01,  -7.75994480e-01,  -4.84637111e-01,
                         -1.79824494e-02,   9.89221334e-02,   8.66408646e-03,
                          2.41473000e-02,   4.92415056e-02,   3.28997038e-02,
                          4.26780172e-02,   3.09234615e-02,   8.82293750e-03,
                          3.60398479e-02,   6.59558326e-02,   4.70324643e-02,
                          3.41937989e-02,   3.75754014e-02,   1.88974962e-02,
                          5.22455014e-02,   6.14996552e-02,  -1.13850441e-02,
                          7.87506402e-02,   6.82688579e-02,  -3.75293761e-01,
                         -5.12628496e-01,  -4.85655926e-02,   1.64149702e-01,
                         -7.28494255e-03,  -2.17286423e-02,   8.88697281e-02,
                          5.56796901e-02,  -1.30120190e-02,   1.06833652e-01,
                          6.30722940e-02,  -4.08116668e-01,  -5.06967008e-01,
                         -2.33526174e-02,   1.05006605e-01,  -1.73919220e-02,
                          1.51717231e-01,   1.12988055e-02,  -4.91689086e-01,
                         -4.37290251e-01,   3.91378626e-02,   1.23768941e-01,
                         -2.80931126e-02,   2.61387080e-02,   8.76518413e-02,
                          2.43814941e-02,  -5.16709266e-03,   1.45028327e-02,
                          5.75638153e-02,   6.10330403e-02,   3.79313305e-02,
                          8.47331062e-02,   2.75665931e-02,  -2.48717293e-02,
                          1.29880965e-01,  -6.84711933e-02,  -5.31974435e-01,
                         -3.49695385e-01,   1.09258860e-01,   1.04091816e-01,
                         -5.88644389e-03,   2.45783478e-02,   3.13509814e-02,
                          4.43918705e-02,   6.88357279e-02,   4.49058749e-02,
                          8.04062292e-04,   9.27554891e-02,   1.44893989e-01,
                         -2.73695737e-01,  -5.94341993e-01,  -1.68148905e-01,
                          1.89496234e-01,   2.58837547e-02,  -2.15445948e-03,
                          9.44936052e-02,   1.59458828e-03,  -2.22421084e-02,
                          9.14897323e-02,   8.89848471e-02,  -1.09441457e-02,
                          7.12567344e-02,   1.17967039e-01,  -3.45605463e-01,
                         -6.03895724e-01,  -2.16747914e-03,   2.24576801e-01,
                         -4.02606636e-01,  -4.79745299e-01,  -7.77446777e-02,
                         -3.32992435e-01,  -5.36819220e-01,   2.52876114e-02,
                          2.17358366e-01,  -4.07887816e-01,  -5.80433905e-01,
                          4.73187566e-02,   2.12690383e-01,  -3.82950217e-01,
                         -5.47345102e-01,  -4.69340496e-02,   1.47715986e-01,
                         -5.03114611e-02,   1.84759870e-02,   1.46749586e-01,
                         -2.98074067e-01,  -8.42891455e-01,  -5.54444075e-01,
                         -9.54440050e-03,  -2.79731631e-01,  -5.96979856e-01,
                         -7.67870918e-02,   2.47311816e-01,  -2.53432006e-01,
                         -6.65705740e-01,  -6.71182275e-01,  -6.61430597e-01,
                         -4.68041837e-01,   1.73558958e-03,   1.65175781e-01,
                         -2.90806234e-01,  -7.65646040e-01,  -6.15427732e-01,
                         -1.49517000e-01,   3.69887054e-02,   5.61796091e-02,
                          4.32428531e-02,  -3.42426717e-01,  -8.14173758e-01,
                         -5.73135138e-01,  -2.30012052e-02,  -2.39545196e-01,
                         -8.15062344e-01,  -6.03635490e-01,  -6.45358190e-02,
                         -2.90339202e-01,  -6.02733731e-01,  -6.87269047e-02,
                          2.33947277e-01,  -3.72348219e-01,  -5.59238553e-01,
                         -8.99117813e-02,  -2.28688031e-01,  -7.95173049e-01,
                         -7.14112997e-01,  -8.43754709e-02,   2.01320887e-01,
                         -2.33782545e-01,  -5.73524535e-01,  -1.95739657e-01,
                         -9.51093286e-02,  -7.17934072e-01,  -7.81917632e-01,
                         -1.54362097e-01,  -1.74999252e-01,  -5.96741557e-01,
                         -2.18751267e-01,   2.41794273e-01,  -2.52025306e-01,
                         -6.31029725e-01,  -1.90886095e-01,  -1.20929107e-01,
                         -6.99174464e-01,  -8.22962821e-01,  -2.58383274e-01,
                          2.06253424e-01,  -5.02612367e-02,  -5.80659807e-01,
                         -4.27492589e-01,   7.37061501e-02,   6.74515665e-02,
                         -8.05223361e-02,  -1.69567749e-04,  -1.32297666e-03,
                          1.11460993e-02,   8.16965848e-02,  -2.09361717e-01,
                         -7.20015883e-01,  -7.87398517e-01,  -3.06672215e-01,
                          1.26165032e-01,   6.79689739e-03,  -5.21476567e-01,
                         -8.33897531e-01,  -5.34012556e-01,  -6.55955076e-02,
                          2.94544958e-02,   2.38577481e-02,  -4.97226082e-02,
                         -5.96672833e-01,  -9.06010330e-01,  -3.63887042e-01,
                         -8.40736181e-02,  -5.31568348e-01,  -5.08018911e-01,
                          9.96582285e-02,   5.28070442e-02,  -6.01909876e-01,
                         -5.49017489e-01,   1.34563595e-01,   5.03528118e-02,
                         -5.70700347e-01,  -4.33256447e-01,  -1.30970031e-01,
                         -5.09165108e-01,  -5.11909723e-01,   1.12571314e-01,
                          2.89622159e-03,  -6.70451403e-01,  -5.14065146e-01,
                          1.51076779e-01,   4.79976460e-02,  -5.45179844e-01,
                         -5.17912686e-01,  -3.98658328e-02,   6.18015826e-02,
                         -8.04876760e-02,  -3.35054509e-02,   8.57361220e-03,
                         -6.48549795e-02,  -4.84080240e-02,   3.03496490e-03,
                         -1.99886616e-02,  -3.19531783e-02,  -3.74245606e-02,
                         -5.83762825e-02,  -2.77335998e-02,   2.81594787e-03,
                         -2.11645588e-02,  -2.76241973e-02,  -2.17203535e-02,
                         -4.50437516e-02,  -4.29708920e-02,  -1.98437274e-02,
                         -3.66864391e-02,  -4.53322381e-02,  -1.97693869e-03,
                          6.03844272e-03,  -5.41632287e-02,  -7.30855092e-02,
                         -2.68235281e-02,  -1.58099141e-02,  -4.04574126e-02,
                         -3.38974856e-02,  -2.24446245e-02,  -3.36186960e-02,
                         -4.08382490e-02,  -4.75547947e-02,  -4.11755741e-02,
                         -5.29629877e-03,  -6.90486142e-03,  -4.91902046e-02,
                         -4.99852896e-02,  -3.97808962e-02,  -4.44166511e-02,
                         -1.65838823e-02,  -7.43872719e-03,  -3.32348719e-02,
                         -4.67892066e-02,  -6.30187988e-02,  -2.74554938e-02,
                         -2.67556432e-04,  -8.15482438e-02,  -1.34780239e-02,
                          7.46535361e-02,  -3.20083231e-01,  -6.52841151e-01,
                         -2.69093305e-01,   1.17514253e-01,  -4.58997814e-03,
                         -1.19046710e-01,  -4.83658202e-02,  -2.53007878e-02,
                         -1.72404386e-02,   1.02848364e-02,  -4.96708676e-02,
                         -7.53446817e-02,   7.52800032e-02,  -3.65587361e-02,
                         -5.16781509e-01,  -4.89668876e-01,  -1.02912486e-01,
                         -4.24036503e-01,  -8.71219695e-01,  -6.69794619e-01,
                         -6.29110575e-01,  -8.29861879e-01,  -5.02186120e-01,
                         -2.26822104e-02,   3.02020423e-02,  -5.80511093e-02,
                          1.63902529e-02,  -3.00908554e-02,  -5.28415024e-01,
                         -8.96539152e-01,  -5.37549436e-01,  -8.83903801e-02,
                          1.60072502e-02,   5.39846048e-02,  -1.91703558e-01,
                         -5.71370780e-01,  -3.91714841e-01,   6.90077245e-03,
                          2.89355479e-02,  -5.16451113e-02,  -1.94714200e-02,
                         -1.08339349e-02,  -5.21201715e-02,  -5.40620163e-02,
                          3.28509957e-02,  -9.57760140e-02,  -6.06514812e-01,
                         -8.34261358e-01,  -4.27557796e-01,  -6.16424195e-02,
                         -2.21468844e-02,   1.49345761e-02,  -1.48814619e-01,
                         -6.65393651e-01,  -8.63313079e-01,  -3.90357733e-01,
                          5.03290109e-02,  -2.43295506e-02,  -7.40909055e-02,
                          9.86985341e-02,  -1.70013726e-01,  -6.12826824e-01,
                         -3.54929328e-01,  -1.10912770e-01,  -6.71729386e-01,
                         -9.16767418e-01,  -2.79500872e-01,  -3.70513983e-02,
                         -6.41200662e-01,  -8.96434546e-01,  -3.37468952e-01,
                         -1.29160032e-01,  -6.14196062e-01,  -4.47023988e-01,
                          2.20749408e-01,  -1.11725554e-01,  -6.58271968e-01,
                         -3.02883983e-01,  -2.17592567e-01,  -5.89929879e-01,
                         -3.35902780e-01,  -1.52748510e-01,  -6.89551413e-01,
                         -8.61377537e-01,  -2.97185361e-01,   1.17786430e-01,
                         -8.86825398e-02,  -5.80940068e-01,  -7.92296588e-01,
                         -6.87320828e-01,  -6.75992489e-01,  -7.54559159e-01,
                         -7.22036004e-01,  -6.97441638e-01,  -7.26351440e-01,
                         -7.10672736e-01,  -6.92824543e-01,  -7.05036938e-01,
                         -7.19282925e-01,  -7.36766398e-01,  -7.32101321e-01,
                         -7.07189381e-01,  -7.01072574e-01,  -7.06346929e-01,
                         -7.11724818e-01,  -7.18143344e-01,  -7.28986323e-01,
                         -7.47086406e-01,  -7.25954771e-01,  -6.78057671e-01,
                         -6.99946880e-01,  -7.56183028e-01,  -7.54574597e-01,
                         -7.21550286e-01,  -6.96600974e-01,  -7.07966983e-01,
                         -7.48429060e-01,  -7.37411499e-01,  -6.98339880e-01,
                         -7.05086708e-01,  -7.29100466e-01,  -7.44928837e-01,
                         -7.36969948e-01,  -7.10228682e-01,  -7.17299104e-01,
                         -7.33905613e-01,  -7.31824577e-01,  -7.37401187e-01,
                         -7.33432770e-01,  -7.19443679e-01,  -7.18591571e-01,
                         -7.23167002e-01,  -7.24755466e-01,  -7.26373911e-01,
                         -7.45371521e-01,  -7.55602300e-01,  -7.23879039e-01,
                         -7.00912774e-01,  -7.16451705e-01,  -7.41837204e-01,
                         -7.43707240e-01,  -7.37128019e-01,  -7.58516788e-01,
                         -7.13092148e-01,  -6.68795347e-01,  -8.19409013e-01,
                         -7.61164069e-01,  -2.77590156e-01,  -2.02691361e-01,
                         -6.97268605e-01,  -8.12838316e-01,  -6.43166780e-01,
                         -8.25691998e-01,  -7.57308960e-01,  -1.94421574e-01,
                         -2.04990044e-01,  -8.23368013e-01,  -8.29266012e-01,
                         -2.17227250e-01,  -1.71547115e-01,  -7.81635225e-01,
                         -8.82216632e-01,  -2.78277844e-01,  -1.36488244e-01,
                         -7.14233637e-01,  -8.76538634e-01,  -3.17076266e-01,
                         -1.33318782e-01,  -6.52421653e-01,  -8.66633952e-01,
                         -6.50024056e-01,  -7.62456656e-01,  -8.02168489e-01,
                         -2.89857030e-01,  -1.55641451e-01,  -7.43221223e-01,
                         -8.97315860e-01,  -3.02189112e-01,  -1.27613366e-01,
                         -6.46394730e-01,  -8.65401208e-01,  -6.95615292e-01,
                         -7.11773038e-01,  -7.76906013e-01,  -7.47116864e-01,
                         -7.34821320e-01,  -7.06240654e-01,  -7.48129070e-01,
                         -7.74302125e-01,  -6.81944549e-01,  -7.64023006e-01,
                         -7.99097836e-01,  -3.88831288e-01,  -1.82550088e-01,
                         -5.82045615e-01,  -8.47930849e-01,  -7.34579921e-01,
                         -6.97534800e-01,  -7.73953855e-01,  -7.94974029e-01,
                         -5.84404230e-01,  -9.87931639e-02,   7.95738697e-02,
                         -3.72896910e-01,  -8.00804436e-01,  -7.60973454e-01,
                         -7.09469259e-01,  -8.48101318e-01,  -6.14674926e-01,
                         -1.62846386e-01,  -3.45562279e-01,  -8.07048798e-01,
                         -7.94952631e-01,  -6.77648365e-01,  -7.49926925e-01,
                         -7.51463592e-01,  -7.11764753e-01,  -7.74873674e-01,
                         -7.83294559e-01,  -6.66289628e-01,  -7.52195835e-01,
                         -8.64066541e-01,  -4.59212333e-01,  -1.43383905e-01,
                         -4.76865381e-01,  -8.02313030e-01,  -8.59651566e-01,
                         -6.94121480e-01,  -2.21730739e-01,  -1.94811583e-01,
                         -7.94646204e-01,  -8.48192692e-01,  -2.39831582e-01,
                         -1.83506608e-01,  -7.73493648e-01,  -8.47647011e-01,
                         -2.82909572e-01,  -1.71242297e-01,  -6.37727022e-01,
                         -8.32960606e-01,  -7.13479698e-01,  -7.31606841e-01,
                         -7.78262436e-01,  -6.96091592e-01,  -6.94708049e-01,
                         -8.32636118e-01,  -7.46974289e-01,  -2.77859092e-01,
                         -1.52780712e-01,  -7.32064486e-01,  -9.00680244e-01,
                         -2.91105777e-01,  -1.39212921e-01,  -6.40686393e-01,
                         -8.28919351e-01,  -6.69234157e-01,  -7.34950542e-01,
                         -8.09520781e-01,  -3.69728953e-01,   8.95940363e-02,
                         -9.85416621e-02,  -5.66679358e-01,  -8.47858369e-01,
                         -6.81945622e-01,  -1.86312079e-01,  -2.60804147e-01,
                         -7.62682319e-01,  -7.45862961e-01,  -5.98901927e-01,
                         -7.01071858e-01,  -6.81154251e-01,  -6.62122011e-01,
                         -6.94535255e-01,  -6.52462959e-01,  -7.18409777e-01,
                         -6.96488857e-01,  -2.79190481e-01,   1.18957795e-01,
                         -6.64057359e-02,  -5.67478418e-01,  -7.39088237e-01,
                         -6.58737242e-01,  -6.86317325e-01,  -6.95155203e-01,
                         -6.38597727e-01,  -7.11381078e-01,  -6.78984404e-01,
                         -2.46466503e-01,   1.37634575e-01,  -5.88527359e-02,
                         -5.88485062e-01,  -8.11430454e-01,  -4.21617776e-01,
                         -4.69312184e-02,  -4.51174766e-01,  -8.89194310e-01,
                         -4.64455843e-01,  -4.52147909e-02,  -4.14340675e-01,
                         -7.96868205e-01,  -6.72314346e-01,  -6.44689858e-01,
                         -7.64312327e-01,  -3.87260497e-01,  -2.14329809e-02,
                         -4.75496918e-01,  -9.06602919e-01,  -4.53096747e-01,
                         -1.33349106e-03,  -4.23501700e-01,  -8.91134024e-01,
                         -4.99696940e-01,  -5.00560142e-02,  -3.63867968e-01,
                         -7.58669496e-01,  -6.98133707e-01,  -6.04918420e-01,
                         -6.79403007e-01,  -7.12892592e-01,  -6.77532315e-01,
                         -6.68388486e-01,  -6.80215359e-01,  -6.83254004e-01,
                         -6.75230384e-01,  -6.90086842e-01,  -6.81643665e-01,
                         -5.97429037e-01,  -7.02388406e-01,  -8.02371800e-01,
                         -3.44978541e-01,  -9.46182758e-02,  -5.03111959e-01,
                         -3.82141054e-01,  -5.77812493e-02,  -6.31891370e-01,
                         -8.76662314e-01,  -2.02291593e-01,  -1.39971793e-01,
                         -5.89896142e-01,  -2.94386983e-01,  -5.96180297e-02,
                         -6.99601710e-01,  -8.42835367e-01,  -1.49717197e-01,
                         -1.60493463e-01,  -6.44106269e-01,  -2.58707434e-01,
                          2.47127607e-01,  -2.15991229e-01,  -6.23978674e-01,
                         -2.12480754e-01,  -1.90387353e-01,  -6.46566570e-01,
                         -2.23077551e-01,   2.56319612e-01,  -3.31515223e-01,
                         -5.77089131e-01,  -1.31009549e-01,  -3.00154418e-01,
                         -5.50253332e-01,  -1.73334390e-01,  -2.52025187e-01,
                         -8.30107331e-01,  -6.23094916e-01,  -3.63757014e-02,
                         -2.94887692e-01,  -7.85942376e-01,  -6.65117979e-01,
                         -6.19779408e-01,  -8.09419572e-01,  -4.59945321e-01,
                         -7.68028945e-02,  -4.15416181e-01,  -5.42831719e-01,
                          2.57421471e-02,   1.35485500e-01,  -4.50905025e-01,
                         -7.42271781e-01,  -6.38539076e-01,  -6.73576653e-01,
                         -7.37637341e-01,  -6.40174627e-01,  -6.95194542e-01,
                         -7.29084432e-01,  -2.91764140e-01,  -8.87545794e-02,
                         -5.73548496e-01,  -7.80210197e-01,  -5.88903844e-01,
                         -7.31812537e-01,  -7.44700193e-01,  -2.05035716e-01,
                         -6.47049248e-02,  -6.96652055e-01,  -8.82376015e-01,
                         -2.40299702e-01,  -6.08483106e-02,  -5.74279904e-01,
                         -7.74159014e-01,  -6.50456190e-01,  -6.37664914e-01,
                         -6.62842095e-01,  -6.94642901e-01,  -7.15329766e-01,
                         -6.76659286e-01,  -6.43561542e-01,  -6.48803830e-01,
                         -6.82977378e-01,  -6.86615288e-01,  -6.64937019e-01,
                         -6.70713902e-01,  -6.62962079e-01,  -6.69747233e-01,
                         -6.80461347e-01,  -6.50138676e-01,  -7.17911541e-01,
                         -7.43421078e-01,  -3.52802992e-01,   1.37125120e-01,
                          3.56761105e-02,  -4.88736987e-01,  -7.38385975e-01,
                         -6.85797513e-01,  -6.76520228e-01,  -6.95772648e-01,
                         -6.58701420e-01,  -6.24970257e-01,  -6.86443090e-01,
                         -7.66735315e-01,  -5.13849258e-01,  -2.97305435e-02,
                          9.75535288e-02,  -3.72598693e-02,   2.70098564e-03,
                          5.28474748e-02,  -6.72485773e-03,  -2.59298570e-02,
                         -2.89979260e-02,   6.43471032e-02,   9.74187329e-02,
                         -3.12138468e-01,  -6.11873388e-01,  -2.34171852e-01,
                          1.29042655e-01,   2.03078240e-02,  -1.00158125e-01,
                          2.71546654e-02,   1.36480123e-01,  -1.63204774e-01,
                         -5.55397630e-01,  -3.38873625e-01,   7.83037245e-02,
                          4.74259704e-02,  -5.60650937e-02,   8.61077197e-03,
                          1.05288597e-02,  -2.16866983e-03,   1.65283792e-02,
                         -7.42015848e-03,  -1.99153963e-02,   5.84235275e-03,
                          2.39830911e-02,   9.08821356e-03,  -1.14947604e-02,
                          1.67026755e-03,   1.00340517e-02,  -2.36028852e-03,
                          8.18583649e-03,   1.67371724e-02,   1.86140335e-03,
                         -5.57508878e-03,  -8.54589976e-04,   1.69916544e-02,
                          1.88163128e-02,  -4.59232600e-03,   3.20756575e-03,
                          5.55186905e-03,   4.96870000e-03,   4.02870253e-02,
                         -2.57694107e-02,  -5.33409901e-02,   1.11524887e-01,
                         -5.33746555e-02,  -5.27210057e-01,  -4.44322795e-01,
                          2.03842446e-02,   7.54030645e-02,  -5.08132018e-02,
                          1.95975825e-02,   3.32364216e-02,  -4.90096286e-02,
                          4.95125446e-03,   5.89586981e-02,  -4.98693176e-02,
                         -2.16324627e-02,   1.30546540e-01,  -1.65827572e-01,
                         -6.07297540e-01,  -3.37027341e-01,   1.20650828e-01,
                          1.20899389e-02,  -2.62732953e-02,   1.26136675e-01,
                         -2.57184952e-01,  -6.12776458e-01,  -2.46836960e-01,
                          1.08737983e-01,   4.01106738e-02,  -4.09612656e-02,
                         -5.02704585e-04,   7.74874389e-02,  -8.16565678e-02,
                         -5.60020328e-01,  -7.60238171e-01,  -6.18149400e-01,
                         -7.23910451e-01,  -7.57420123e-01,  -2.43565425e-01,
                         -2.41364483e-02,  -6.28285408e-01,  -8.91935289e-01,
                         -2.73808300e-01,  -6.63368329e-02,  -5.58626115e-01,
                         -4.34567153e-01,   1.59943625e-01,  -1.50646027e-02,
                         -5.72821498e-01,  -6.97643816e-01,  -7.31313705e-01,
                         -6.41379476e-01,  -1.68399900e-01,  -1.53597310e-01,
                         -7.54036009e-01,  -7.39711642e-01,  -1.29526868e-01,
                         -1.66633844e-01,  -7.00980008e-01,  -7.32801616e-01,
                         -5.57589412e-01,  -7.72670269e-01,  -7.07999110e-01,
                         -1.24650128e-01,  -1.48274824e-01,  -7.86142886e-01,
                         -7.04170108e-01,  -9.06579792e-02,  -2.23256648e-01,
                         -7.57999718e-01,  -7.09356964e-01,  -5.86624205e-01,
                         -8.03754032e-01,  -5.70893228e-01,  -1.18278407e-01,
                         -3.47770900e-01,  -5.15261531e-01,  -1.14391312e-01,
                         -2.97046751e-01,  -8.97712469e-01,  -5.73025048e-01,
                         -9.96332616e-04,  -3.43869895e-01,  -7.97015727e-01,
                         -6.82532668e-01,  -6.14230812e-01,  -7.54292428e-01,
                         -5.68800390e-01,  -1.13787316e-02,   1.62593544e-01,
                         -3.72172415e-01,  -6.24530673e-01,  -1.14555262e-01,
                          1.65057108e-01,  -2.29866907e-01,  -7.05500603e-01,
                         -7.78100491e-01,  -3.18586469e-01,   1.67041093e-01,
                         -4.34288867e-02,  -5.83681226e-01,  -4.66822118e-01,
                          1.28406629e-01,   6.80487528e-02,  -5.58974147e-01,
                         -5.26731849e-01,   6.75409287e-02,   9.41337347e-02,
                         -4.37151641e-01,  -7.83595502e-01,  -6.54319525e-01,
                         -1.40149429e-01,   1.70907125e-01,  -2.13068664e-01,
                         -5.89706063e-01,  -3.13170940e-01,   2.51301751e-02,
                          7.02369437e-02,  -2.82859663e-03,  -3.60602677e-01,
                         -7.40820110e-01,  -7.08531499e-01,  -6.23247683e-01,
                         -6.82621658e-01,  -6.72475159e-01,  -7.06452250e-01,
                         -7.22230315e-01,  -3.90644729e-01,   1.87864546e-02,
                          2.22312249e-02,  -6.18594028e-02,   9.24038067e-02,
                         -5.04950173e-02,  -5.59085906e-01,  -7.53667295e-01,
                         -6.43471956e-01,  -6.41673386e-01,  -7.30476737e-01,
                         -7.13627338e-01,  -6.07618392e-01,  -7.05050349e-01,
                         -7.60585964e-01,  -3.03558350e-01,  -9.05967504e-02,
                         -5.34803867e-01,  -4.52843636e-01,   1.57754138e-01,
                         -3.68340351e-02,  -6.05656922e-01,  -3.89536202e-01,
                          3.65745984e-02,   3.35044637e-02,   8.48465506e-03,
                         -2.00650349e-01,  -7.71327138e-01,  -7.97757089e-01,
                         -1.81354344e-01,  -1.25370204e-01,  -6.71972156e-01,
                         -7.55778551e-01,  -5.73828638e-01,  -7.69318998e-01,
                         -6.74344480e-01,  -1.49343804e-01,  -2.24329397e-01,
                         -7.07571924e-01,  -7.32839406e-01,  -6.19563282e-01,
                         -7.40204573e-01,  -6.26586199e-01,  -1.31270364e-01,
                          9.04946849e-02,  -9.53356773e-02,  -3.21091316e-03,
                          1.12475939e-01,  -3.54658663e-01,  -5.85260332e-01,
                         -1.37167305e-01,   8.70665386e-02,  -4.72992100e-02,
                         -2.28695050e-02,   1.90330837e-02,  -3.93618681e-02,
                         -1.76135451e-02,   1.05250515e-02,   1.74827210e-03,
                         -1.26210414e-02,  -5.98087162e-02,   5.05602919e-02,
                          8.61634165e-02,  -3.78462940e-01,  -6.27969384e-01,
                         -1.82777196e-01,   1.26680911e-01,   1.37048364e-02,
                         -7.75800645e-02,   2.20933575e-02,   1.15877032e-01,
                         -2.38909528e-01,  -6.25201225e-01,  -2.94431865e-01,
                          1.12760775e-01,   2.70838607e-02,  -5.23390509e-02,
                          2.27832664e-02,   8.32729856e-05,  -9.62088034e-02,
                         -8.57070275e-03,   1.15627766e-01,  -2.45561004e-01,
                         -6.02107823e-01,  -2.49173656e-01,   1.07196018e-01,
                         -1.92157160e-02,  -7.11834356e-02,   3.26456502e-02,
                          1.43035194e-02,  -2.53957883e-02,  -3.56027111e-03,
                          7.25569064e-03,  -2.91630672e-03,  -2.26753913e-02,
                         -3.49184982e-02,  -9.71409213e-03,   1.11134779e-02,
                          1.00774914e-02,   1.86795797e-02,  -1.87125839e-02,
                         -5.86459376e-02,   3.46258562e-03,   1.94994584e-02,
                         -5.23565747e-02,   9.75591317e-03,   3.25828083e-02,
                         -3.40714365e-01,  -7.38834500e-01,  -6.89186692e-01,
                         -6.05553329e-01,  -7.65594900e-01,  -6.27367020e-01,
                         -1.00111187e-01,   1.48295566e-01,  -2.10472181e-01,
                         -7.43435383e-01,  -7.74799049e-01,  -2.84312904e-01,
                          4.58790325e-02,  -3.59657519e-02,  -3.51021625e-02,
                          1.14216425e-01,  -1.88363165e-01,  -6.22653961e-01,
                         -3.08504969e-01,   1.24634676e-01,  -4.47172336e-02,
                         -5.57946749e-02,   1.37388289e-01,  -2.49573022e-01,
                         -6.64968729e-01,  -2.58293688e-01,   2.18562633e-01,
                         -2.01496258e-01,  -6.82514608e-01,  -2.88261920e-01,
                          1.20725878e-01,  -6.60127960e-03,  -6.38073683e-02,
                          5.62612200e-03,  -6.83186715e-03,  -9.79910605e-03,
                         -7.02310412e-04,   7.02067744e-03,  -1.51203992e-02,
                         -1.25768827e-02,   2.70917471e-02,   1.13222271e-03,
                         -9.04107839e-03,  -5.31761087e-02,  -6.35684803e-02,
                          9.96182486e-02,  -1.01589039e-01,  -5.60908377e-01,
                         -3.93365979e-01,   3.16634029e-02,   3.78641561e-02,
                         -3.78313772e-02,   1.89116728e-02,   2.53750850e-02,
                         -6.09158762e-02,  -4.53192629e-02,   9.83680487e-02,
                         -1.33366928e-01,  -5.87370455e-01,  -3.93712282e-01,
                          6.61404952e-02,   4.62444220e-03,  -2.57911924e-02,
                          1.34068161e-01,  -2.51494974e-01,  -6.21450245e-01,
                         -2.16325819e-01,  -1.11183755e-01,  -7.71612287e-01,
                         -8.13755155e-01,  -1.41515762e-01,  -1.33775011e-01,
                         -6.83855414e-01,  -7.90941119e-01,  -6.28574014e-01,
                         -6.66447461e-01,  -7.15561152e-01,  -6.81896627e-01,
                         -6.86966121e-01,  -6.92521572e-01,  -6.74172878e-01,
                         -6.58992112e-01,  -6.71173453e-01,  -7.06719160e-01,
                         -6.90168798e-01,  -6.61847413e-01,  -6.81290209e-01,
                         -6.91582143e-01,  -6.96135700e-01,  -6.94235623e-01,
                         -6.82019293e-01,  -6.87834859e-01,  -6.68163836e-01,
                         -6.56483173e-01,  -6.87055945e-01,  -6.90068841e-01,
                         -6.83321238e-01,  -6.84601128e-01,  -6.80153489e-01,
                         -6.88633442e-01,  -6.85858071e-01,  -6.84167325e-01,
                         -6.83603406e-01,  -6.64645314e-01,  -6.81702554e-01,
                         -7.01073825e-01,  -6.80318296e-01,  -6.76240206e-01,
                         -6.81159079e-01,  -6.83072984e-01,  -6.82944477e-01,
                         -6.67418718e-01,  -6.84049606e-01,  -7.00300157e-01,
                         -6.68639898e-01,  -6.67103648e-01,  -6.92463517e-01,
                         -6.89483702e-01,  -6.78718805e-01,  -6.74140513e-01,
                         -6.90088451e-01,  -6.97552383e-01,  -6.71387732e-01,
                         -6.75633848e-01,  -6.91544950e-01,  -6.73681438e-01,
                         -6.69589818e-01,  -6.83460355e-01,  -6.90016329e-01,
                         -6.80296779e-01,  -6.67641521e-01,  -6.82575881e-01,
                         -6.91379488e-01,  -6.80868506e-01,  -6.79819405e-01,
                         -6.82088256e-01,  -6.86220467e-01,  -6.78864717e-01,
                         -6.72458291e-01,  -6.88345850e-01,  -6.82131410e-01,
                         -6.66458428e-01,  -6.77293122e-01,  -6.83667243e-01,
                         -6.84612811e-01,  -6.85355604e-01,  -6.73987269e-01,
                         -6.75451875e-01,  -6.85061812e-01,  -6.76437199e-01,
                         -6.75889611e-01,  -6.73285663e-01,  -6.79234624e-01,
                         -7.11227059e-01,  -6.39896870e-01,  -6.41071379e-01,
                         -8.07309508e-01,  -5.28410494e-01,  -1.17751814e-01,
                         -3.85918647e-01,  -4.90258396e-01,  -1.30729496e-01,
                         -3.59538436e-01,  -7.88875461e-01,  -7.05348313e-01,
                         -6.17196262e-01,  -7.02950716e-01,  -6.95918322e-01,
                         -6.25074923e-01,  -6.97954416e-01,  -7.81989872e-01,
                         -4.11762834e-01,  -6.45385161e-02,  -4.31169599e-01,
                         -7.83831120e-01,  -6.64302588e-01,  -6.53103888e-01,
                         -6.98334694e-01,  -6.27314091e-01,  -7.46781230e-01,
                         -6.94446027e-01,  -2.08095670e-01,  -1.40281349e-01,
                         -6.46618724e-01,  -7.62039006e-01,  -5.95956266e-01,
                         -7.67141759e-01,  -6.41330600e-01,  -1.18876107e-01,
                         -2.57395774e-01,  -6.27122223e-01,  -1.39864132e-01,
                          2.50701666e-01,  -3.33436161e-01,  -6.21082067e-01,
                         -1.26495317e-01,  -1.96217164e-01,  -8.30672801e-01,
                         -7.05819368e-01,  -7.14277104e-02,  -1.82614625e-01,
                         -8.06873560e-01,  -7.11080968e-01,  -1.18095651e-01,
                         -1.92051947e-01,  -6.36767864e-01,  -7.49263823e-01,
                         -7.28796303e-01,  -4.29679960e-01,  -4.50682528e-02,
                         -4.10652578e-01,  -8.92126143e-01,  -4.74090517e-01,
                         -8.81651137e-03,  -3.86465460e-01,  -7.96971738e-01,
                         -6.45621240e-01,  -6.24216437e-01,  -7.89187908e-01,
                         -4.19399142e-01,  -1.43392868e-02,  -4.41579640e-01,
                         -8.88128579e-01,  -4.40570176e-01,  -2.80620400e-02,
                         -4.00997877e-01,  -7.69659996e-01,  -7.08600640e-01,
                         -5.91908634e-01,  -6.52909517e-01,  -7.98708439e-01,
                         -5.31382620e-01,  -8.17376748e-02,  -3.32641751e-01,
                         -5.97100675e-01,  -1.66279394e-02,   2.01542184e-01,
                         -4.44769710e-01,  -5.35194993e-01,  -7.55825043e-02,
                         -3.17170054e-01,  -7.86096513e-01,  -6.61118805e-01,
                         -6.02246881e-01,  -7.85702705e-01,  -4.47459877e-01,
                          1.49873400e-03,  -4.13455874e-01,  -9.04617846e-01,
                         -4.22129422e-01,  -4.25923951e-02,  -4.65952337e-01,
                         -4.39109981e-01,  -3.34324352e-02,  -4.89028484e-01,
                         -9.01256919e-01,  -3.07439625e-01,  -8.73609334e-02,
                         -5.20780802e-01,  -3.29931319e-01,  -1.31297305e-01,
                         -5.27830601e-01,  -3.45198393e-01,   2.03257337e-01,
                         -5.21529503e-02,  -6.34903789e-01,  -7.17543542e-01,
                         -5.83958507e-01,  -7.21653521e-01,  -7.21349835e-01,
                         -2.20120162e-01,  -7.25202188e-02,  -6.12017512e-01,
                         -8.25952411e-01,  -3.52232993e-01,   1.19167730e-01,
                          4.10688818e-02,  -4.38172877e-01,  -7.20694184e-01,
                         -6.66827381e-01,  -6.36329174e-01,  -6.71146035e-01,
                         -6.51066005e-01,  -6.52066350e-01,  -6.68284237e-01,
                         -6.60356164e-01,  -6.64729655e-01,  -6.51712477e-01,
                         -6.60037041e-01,  -6.79195523e-01,  -6.16766572e-01,
                         -6.80079877e-01,  -7.61190712e-01,  -3.75734121e-01,
                         -5.41104972e-02,  -4.35958117e-01,  -7.69439816e-01,
                         -6.47676408e-01,  -6.40135467e-01,  -6.79148138e-01,
                         -6.12830222e-01,  -7.37598240e-01,  -6.68203175e-01,
                         -1.78666651e-01,  -1.37989730e-01,  -6.50161564e-01,
                         -7.40846694e-01,  -5.69506764e-01,  -7.55475521e-01,
                         -6.31762385e-01,  -1.04452200e-01,  -2.05216214e-01,
                         -6.91288114e-01,  -7.27141321e-01,  -6.09058261e-01,
                         -6.62921309e-01,  -6.87799811e-01,  -6.55336082e-01,
                         -6.53343141e-01,  -6.65653825e-01,  -6.63757980e-01,
                         -6.61876202e-01,  -6.65675461e-01,  -6.62639260e-01,
                         -6.60575330e-01,  -6.65804565e-01,  -6.63046062e-01,
                         -6.49070203e-01,  -6.73346281e-01,  -6.69611931e-01,
                         -6.14709795e-01,  -7.27698505e-01,  -7.13804305e-01,
                         -2.42586136e-01,  -1.00798503e-01,  -5.77426553e-01,
                         -7.78729379e-01,  -6.30051613e-01,  -6.42400503e-01,
                         -6.91873372e-01,  -6.57543421e-01,  -6.59194529e-01,
                         -6.73882186e-01,  -6.65945470e-01,  -6.60877228e-01,
                         -6.64625645e-01,  -6.66584849e-01,  -6.67048097e-01,
                         -6.68008685e-01,  -6.66939437e-01,  -6.71188116e-01,
                         -6.71646714e-01,  -6.65248990e-01,  -6.67606771e-01,
                         -6.71160042e-01,  -6.68573678e-01,  -6.65291131e-01,
                         -6.64774776e-01,  -6.70243263e-01,  -6.74307764e-01,
                         -6.70615196e-01,  -6.66143537e-01,  -6.66346192e-01,
                         -6.69902623e-01,  -6.74145162e-01,  -6.73517883e-01,
                         -6.69506073e-01,  -6.69464707e-01,  -6.68220937e-01,
                         -6.70905411e-01,  -6.78051293e-01,  -6.70665085e-01,
                         -6.65462315e-01,  -6.73545837e-01,  -6.73452020e-01,
                         -6.69722557e-01,  -6.69728458e-01,  -6.73052490e-01,
                         -6.77278280e-01,  -6.75055742e-01,  -6.71347082e-01,
                         -6.66491926e-01,  -6.71957135e-01,  -6.81653261e-01,
                         -6.72378242e-01,  -6.71104610e-01,  -6.76093698e-01,
                         -6.69965625e-01,  -6.75203502e-01,  -6.76401496e-01,
                         -6.71722293e-01,  -6.74015224e-01,  -6.69539511e-01,
                         -6.73208892e-01,  -6.77652895e-01,  -6.73081040e-01,
                         -6.76781952e-01,  -6.75510049e-01,  -6.73088312e-01,
                         -6.76060677e-01,  -6.73892856e-01,  -6.76978052e-01,
                         -6.79424703e-01,  -6.75139725e-01,  -6.72224522e-01,
                         -6.73734903e-01,  -6.77999139e-01,  -6.70484066e-01,
                         -6.67615056e-01,  -6.83205962e-01,  -6.83450222e-01,
                         -6.71023309e-01,  -6.71616971e-01,  -6.75227940e-01,
                         -6.75771415e-01,  -6.78063095e-01,  -6.79915845e-01,
                         -6.79224432e-01,  -6.75597310e-01,  -6.72414839e-01,
                         -6.76046968e-01,  -6.80171788e-01,  -6.75470293e-01,
                         -6.72877908e-01,  -6.76116824e-01,  -6.75440907e-01,
                         -6.73928261e-01,  -6.74221456e-01,  -6.78350925e-01,
                         -6.80499554e-01,  -6.71927691e-01,  -6.75034523e-01,
                         -6.85821891e-01,  -6.77365005e-01,  -6.69403553e-01,
                         -6.72280073e-01,  -6.84239447e-01,  -6.85315490e-01,
                         -6.62411392e-01,  -6.90614402e-01,  -6.90430045e-01,
                         -6.24481082e-01,  -7.39504635e-01,  -7.26187527e-01,
                         -2.59266227e-01,  -1.28925979e-01,  -5.66353321e-01,
                         -7.66566694e-01,  -7.16057956e-01,  -5.83038211e-01,
                         -1.23498857e-01,   1.63721189e-01,  -2.24331170e-01,
                         -7.13136554e-01,  -7.13274717e-01,  -6.09937370e-01,
                         -7.78438926e-01,  -6.38045549e-01,  -1.30343094e-01,
                         -2.17473090e-01,  -7.25596130e-01,  -7.28635192e-01,
                         -6.05846703e-01,  -7.95645773e-01,  -6.02628410e-01,
                         -6.89625964e-02,  -2.54996806e-01,  -8.66996706e-01,
                         -6.54565632e-01,  -7.28893057e-02,  -2.58304775e-01,
                         -7.07973778e-01,  -7.53045619e-01,  -6.87018692e-01,
                         -4.54508632e-01,   6.55217841e-03,   9.52702537e-02,
                         -3.92462909e-01,  -8.48392844e-01,  -6.26874506e-01,
                         -8.29785764e-02,  -2.28161365e-01,  -8.27062666e-01,
                         -7.28048384e-01,  -1.03828751e-01,  -1.58820391e-01,
                         -8.14037919e-01,  -7.53576100e-01,  -1.24810226e-01,
                         -2.41461769e-01,  -6.17573678e-01,  -2.40726516e-01,
                          1.26769364e-01,  -3.31805833e-02,  -5.01372218e-02,
                          7.46240392e-02,  -2.58086562e-01,  -8.06943774e-01,
                         -7.36930668e-01,  -1.55461267e-01,  -1.36807203e-01,
                         -7.46217489e-01,  -8.22074056e-01,  -2.04179868e-01,
                         -8.09779465e-02,  -7.16209292e-01,  -8.59486818e-01,
                         -2.25108474e-01,  -1.37037024e-01,  -6.26896322e-01,
                         -3.77863258e-01,   2.06629828e-01,  -1.01655103e-01,
                         -6.71739101e-01,  -3.98585349e-01,   1.43249393e-01,
                         -5.09937443e-02,  -5.78145146e-01,  -7.19848037e-01,
                         -7.35617399e-01,  -6.80876970e-01,  -2.51386613e-01,
                          7.57621229e-02,  -2.97827460e-02,  -5.45071475e-02,
                          5.60610741e-02,  -2.05947354e-01,  -7.04159200e-01,
                         -8.11695755e-01,  -3.60468894e-01,   1.25264332e-01,
                         -3.99716832e-02,  -5.81032991e-01,  -5.05986989e-01,
                          4.15987819e-02,   7.17923343e-02,  -4.66733903e-01,
                         -8.44120920e-01,  -6.29041970e-01,  -1.41090229e-01,
                          3.83545496e-02,  -3.82554494e-02,  -3.74024101e-02,
                         -6.05862914e-03,  -2.31651999e-02,  -2.91494075e-02,
                         -2.83347089e-02,  -2.82335635e-02,  -1.66115388e-02,
                         -1.54165551e-02,  -2.94069219e-02,  -3.69773395e-02,
                         -2.91355345e-02,  -1.87121574e-02,  -2.57240832e-02,
                         -3.43430340e-02,  -3.17704566e-02,  -3.46094221e-02,
                         -3.15504633e-02,  -2.72574611e-02,  -2.74950359e-02,
                         -1.61125306e-02,  -2.02718657e-02,  -3.30778547e-02,
                         -3.30611616e-02,  -3.71564664e-02,  -2.95391958e-02,
                         -2.10757256e-02,  -2.12344527e-02,  -1.64300855e-02,
                         -3.33056562e-02,  -4.23860252e-02,  -2.81200390e-02,
                         -3.17238942e-02,  -2.88532637e-02,  -2.27612928e-02,
                         -3.42406854e-02,  -3.23815756e-02,  -3.24019752e-02,
                         -4.26596142e-02,  -3.80465984e-02,  -3.36632803e-02,
                         -2.81463917e-02,  -1.27780950e-02,  -1.63584054e-02,
                         -3.41861807e-02,  -4.45925295e-02,  -4.60909158e-02,
                         -2.75516063e-02,  -1.81010850e-02,  -3.58345434e-02,
                         -3.38351279e-02,  -2.12183334e-02,  -2.83887740e-02,
                         -4.12869975e-02,  -4.15899754e-02,  -1.72149725e-02,
                         -1.44179314e-02,  -3.95317860e-02,  -2.77989320e-02,
                         -1.01763895e-02,  -2.29585953e-02,  -3.72068249e-02,
                         -4.26331162e-02,  -3.62977087e-02,  -2.61699818e-02,
                         -1.44784674e-02,  -1.30108390e-02,  -2.76397001e-02,
                         -2.99957972e-02,  -4.28203419e-02,  -5.20843007e-02,
                         -1.94894616e-02,  -8.17140192e-03,  -1.84224490e-02,
                         -7.23405555e-03,  -1.21831978e-02,  -3.21238935e-02,
                         -3.16486992e-02,  -2.19044797e-02,  -2.05677077e-02,
                         -1.36804599e-02,  -1.45337926e-02,  -4.16782908e-02,
                         -4.09866534e-02,  -2.01512538e-02,  -2.61345170e-02,
                         -2.00040061e-02,  -9.08331573e-03,  -2.13401262e-02,
                         -3.06256413e-02,  -2.67307181e-02,  -1.19501501e-02,
                         -1.09726228e-02,  -1.60014201e-02,  -1.70591101e-03,
                         -1.02448687e-02,  -3.54387164e-02,  -3.24662849e-02,
                         -1.46115832e-02,  -8.39453004e-03,  -2.31772419e-02,
                         -2.89555322e-02,  -1.68967433e-02,  -2.01837290e-02,
                         -2.43055336e-02,  -1.22279739e-02,  -2.91795819e-03,
                         -1.85223464e-02,  -4.83160354e-02,  -3.54039371e-02,
                          7.53938977e-04,  -3.52367270e-03,  -1.34375272e-02,
                         -2.28623813e-03,  -4.79187537e-03,  -2.85914801e-02,
                         -4.11693975e-02,  -6.37035491e-03,   2.24418491e-02,
                         -1.15649810e-03,  -5.87518793e-03,  -1.04553029e-02,
                         -4.41256613e-02,  -2.48695612e-02,  -5.89835132e-03,
                         -1.61896925e-02,   2.25581834e-03,  -2.05831882e-02,
                         -3.23490873e-02,  -1.80238206e-02,  -6.64442331e-02,
                          4.23230864e-02,   1.22012481e-01,  -2.99957633e-01,
                         -5.66732764e-01,  -1.92103192e-01,  -2.14376986e-01,
                         -8.13856840e-01,  -7.80581355e-01,  -1.54439479e-01,
                          1.33168489e-01,  -9.08357576e-02,  -6.42490029e-01,
                         -8.64875078e-01,  -3.49549145e-01,  -9.04453471e-02,
                         -4.90153611e-01,  -7.74798691e-01,  -7.97360420e-01,
                         -5.40930331e-01,  -1.11703947e-01,  -2.54327089e-01,
                         -7.37311065e-01,  -7.66390562e-01,  -6.31816149e-01,
                         -6.96838439e-01,  -7.14344859e-01,  -6.47396922e-01,
                         -6.69394791e-01,  -7.29339242e-01,  -7.11875439e-01,
                         -7.13173509e-01,  -7.55301058e-01,  -5.36723077e-01,
                         -3.57883088e-02,   1.32451504e-01,  -3.25999945e-01,
                         -7.53921270e-01,  -7.03529954e-01,  -6.63682461e-01,
                         -8.19706678e-01,  -6.01434886e-01,  -1.04923725e-01,
                         -2.45062962e-01,  -8.54954660e-01,  -7.10395992e-01,
                         -7.56280571e-02,  -2.41718873e-01,  -7.63269782e-01,
                         -6.88371181e-01,  -6.01166964e-01,  -8.13088298e-01,
                         -5.95394135e-01,  -1.20715067e-01,  -2.82751501e-01,
                         -7.57165015e-01,  -7.07182050e-01,  -5.98203719e-01,
                         -7.88291335e-01,  -5.03818214e-01,  -5.31431139e-02,
                         -4.20500219e-01,  -9.10007596e-01,  -5.64132154e-01,
                         -4.81052063e-02,  -3.21612984e-01,  -8.61669898e-01,
                         -5.68901420e-01,  -4.02923524e-02,  -3.57344776e-01,
                         -6.40676916e-01,  -9.77582037e-02,   1.98965430e-01,
                         -2.92482436e-01,  -7.21291661e-01,  -7.19243288e-01,
                         -6.70105159e-01,  -6.91254079e-01,  -6.79030895e-01,
                         -6.81264102e-01,  -7.18428016e-01,  -7.00242102e-01,
                         -6.28804684e-01,  -6.89231157e-01,  -7.83765972e-01,
                         -4.73339140e-01,  -9.66685340e-02,  -3.53424877e-01,
                         -7.63409674e-01,  -7.26806939e-01,  -6.14710867e-01,
                         -6.50299668e-01,  -6.77260876e-01,  -6.90348446e-01,
                         -6.91561878e-01,  -6.54672027e-01,  -6.36718214e-01,
                         -6.96400464e-01,  -6.85176790e-01,  -6.10521495e-01,
                         -7.44087994e-01,  -7.03835785e-01,  -2.30718762e-01,
                         -1.64888650e-01,  -6.24204338e-01,  -7.64535964e-01,
                         -6.44768357e-01,  -7.10255444e-01,  -6.78723514e-01,
                         -2.31868580e-01,   1.58268854e-01,  -1.14956558e-01,
                         -6.11732721e-01,  -7.15235710e-01,  -7.08629012e-01,
                         -6.21827662e-01,  -1.49328455e-01,   1.67570919e-01,
                         -1.55833840e-01,  -6.08003438e-01,  -7.44275808e-01,
                         -6.79969013e-01,  -5.94879448e-01,  -6.77818656e-01,
                         -7.29131162e-01,  -3.36045355e-01,  -7.53561407e-02,
                         -4.91873533e-01,  -8.06869626e-01,  -6.74112082e-01,
                         -6.69758916e-01,  -7.63756096e-01,  -6.50178015e-01,
                         -5.41236937e-01,  -6.95645392e-01,  -7.64465868e-01,
                         -3.42250735e-01,  -8.25580657e-02,  -4.73050714e-01,
                         -7.38268197e-01,  -6.26463354e-01,  -6.39983892e-01,
                         -6.86642289e-01,  -6.38014376e-01,  -6.79300368e-01,
                         -6.30971849e-01,  -2.22513199e-01,   1.61729708e-01,
                         -6.83019459e-02,  -5.80418169e-01,  -7.18129516e-01,
                         -6.45087123e-01,  -6.58353746e-01,  -6.73329115e-01,
                         -6.63917065e-01,  -6.56157732e-01,  -6.50998533e-01,
                         -6.39763176e-01,  -6.29128695e-01,  -6.56437635e-01,
                         -6.73447251e-01,  -6.81964099e-01,  -6.92316353e-01,
                         -6.49377227e-01,  -6.49812818e-01,  -6.85345054e-01,
                         -6.30780041e-01,  -5.96915126e-01,  -6.48312807e-01,
                         -6.98373318e-01,  -6.95423186e-01,  -6.29060745e-01,
                         -6.16648138e-01,  -6.74332798e-01,  -6.55618966e-01,
                         -6.15830779e-01,  -6.43864036e-01,  -6.54935181e-01,
                         -6.40441477e-01,  -6.70743346e-01,  -6.96723461e-01,
                         -6.58997118e-01,  -6.26199782e-01,  -6.13906980e-01,
                         -6.02101862e-01,  -6.34032130e-01,  -6.58276379e-01,
                         -6.73793912e-01,  -6.68372333e-01,  -5.71727812e-01,
                         -6.58338845e-01,  -8.04736555e-01,  -4.20500010e-01,
                         -4.21023741e-02,  -3.67031306e-01,  -7.18484282e-01,
                         -6.64413512e-01,  -6.27423644e-01,  -6.64934456e-01,
                         -6.42232239e-01,  -6.15475416e-01,  -6.02471232e-01,
                         -6.23029530e-01,  -6.30002618e-01,  -5.77155292e-01,
                         -6.50322020e-01,  -7.70311356e-01,  -4.64400172e-01,
                         -4.29260470e-02,  -2.99740821e-01,  -7.43300796e-01,
                         -6.34625077e-01,  -5.77889085e-01,  -7.49816120e-01,
                         -3.89055341e-01,   3.95479165e-02,  -3.95816565e-01,
                         -8.66870046e-01,  -4.16515768e-01,   2.22728886e-02,
                         -3.05907667e-01,  -6.68214560e-01,  -7.32766509e-01,
                         -6.21479213e-01,  -1.79258347e-01,  -5.22966571e-02,
                         -6.37203693e-01,  -7.86961317e-01,  -1.87769875e-01,
                         -6.71322569e-02,  -5.61547339e-01,  -6.93431914e-01,
                         -5.51736116e-01,  -7.07940280e-01,  -6.39478564e-01,
                         -1.14025846e-01,  -9.10803750e-02,  -6.21050775e-01,
                         -7.59126067e-01,  -5.81567705e-01,  -5.96683025e-01,
                         -6.54992998e-01,  -6.44991994e-01,  -6.42254055e-01,
                         -6.47755921e-01,  -6.89837992e-01,  -6.63424671e-01,
                         -5.82021534e-01,  -6.65849805e-01,  -6.65943682e-01,
                         -2.46134847e-01,   1.62508130e-01,   1.39923329e-02,
                         -5.06606162e-01,  -7.67165780e-01,  -4.59699303e-01,
                         -4.19719191e-03,   1.02717839e-01,   1.52343055e-02,
                          4.91622537e-02,   1.19795501e-01,   6.82939440e-02,
                          2.37743068e-03,   3.93376052e-02,   6.35757372e-02,
                          5.16030863e-02,   1.12709329e-01,   1.33536294e-01,
                          5.24541624e-02,   2.16685217e-02,   6.35920838e-02,
                          9.66858193e-02,   2.83676218e-02,  -4.00126725e-02,
                          1.08193822e-01,   6.67935461e-02,  -4.18045461e-01,
                         -5.12913764e-01,  -1.76055357e-02,   1.64410740e-01,
                         -2.38275193e-02,  -1.11150844e-02,   9.33884084e-02,
                          1.61941294e-02,  -3.82641330e-02,   1.21035919e-01,
                          7.42482916e-02,  -4.11592036e-01,  -5.31631231e-01,
                         -3.55539806e-02,   1.33056596e-01,  -3.11629679e-02,
                          9.64492559e-02,  -1.29986962e-03,  -5.04492640e-01,
                         -4.85983521e-01,  -1.38123287e-03,   1.06841482e-01,
                         -1.07199056e-02,   4.12160717e-02,   6.81832731e-02,
                          4.71446067e-02,   5.45017347e-02,   1.61596760e-02,
                          3.40012684e-02,   6.00079745e-02,   1.38260452e-02,
                          4.78787757e-02,   3.10202707e-02,  -1.22761652e-02,
                          1.20700724e-01,  -5.20932786e-02,  -5.04969954e-01,
                         -3.69763285e-01,   9.11595076e-02,   9.73121449e-02,
                         -4.29566018e-02,   3.44761387e-02,   6.49445951e-02,
                         -9.48677305e-03,   3.17088664e-02,   8.03447440e-02,
                         -2.38740607e-03,   7.43958205e-02,   1.45859122e-01,
                         -2.79291838e-01,  -5.69765925e-01,  -1.58851415e-01,
                          1.63687050e-01,   6.30382076e-02,   3.65532115e-02,
                          4.72384952e-02,  -1.48078976e-02,   3.92289311e-02,
                          1.10500284e-01,   4.80641723e-02,  -1.26038091e-02,
                          9.61909890e-02,   1.14211529e-01,  -3.22311312e-01,
                         -5.71682155e-01,  -3.96015309e-02,   1.85542449e-01,
                         -3.84670824e-01,  -4.34318185e-01,  -3.84361371e-02,
                         -3.52961600e-01,  -5.65370679e-01,   5.75041324e-02,
                          2.22770900e-01,  -4.40886557e-01,  -5.91006935e-01,
                          1.41789857e-02,   1.87180266e-01,  -3.48116577e-01,
                         -5.55678248e-01,  -1.22502208e-01,   1.35296404e-01,
                          2.96605955e-04,   8.57072510e-03,   9.57805142e-02,
                         -2.96421677e-01,  -8.25707078e-01,  -5.84210992e-01,
                         -5.98745458e-02,  -2.88355887e-01,  -5.57090104e-01,
                         -6.81913868e-02,   2.22582117e-01,  -2.46733502e-01,
                         -6.68700874e-01,  -6.88266218e-01,  -6.44608259e-01,
                         -4.60593402e-01,  -1.92984603e-02,   1.19399190e-01,
                         -3.54731798e-01,  -7.86275804e-01,  -6.13277674e-01,
                         -1.60747290e-01,   4.42915224e-02,   7.29735643e-02,
                          9.15138647e-02,  -2.77055055e-01,  -8.21278811e-01,
                         -6.01936102e-01,  -2.14746799e-02,  -2.57788181e-01,
                         -8.29727888e-01,  -5.84070146e-01,  -1.85140111e-02,
                         -2.50234544e-01,  -6.17216766e-01,  -7.24150389e-02,
                          2.85596430e-01,  -3.42387497e-01,  -5.69900095e-01,
                         -1.15252562e-01,  -2.27926657e-01,  -7.52167583e-01,
                         -7.13495135e-01,  -1.18544489e-01,   2.10800827e-01,
                         -2.14363620e-01,  -5.69796801e-01,  -2.05229804e-01,
                         -1.23305798e-01,  -7.36115932e-01,  -7.85368145e-01,
                         -1.23890169e-01,  -1.18812531e-01,  -5.96335649e-01,
                         -2.44788215e-01,   2.48002157e-01,  -2.49609828e-01,
                         -6.27131760e-01,  -1.86027020e-01,  -1.39034480e-01,
                         -7.03590214e-01,  -8.03609610e-01,  -2.42750958e-01,
                          1.97432160e-01,  -7.58077204e-02,  -5.82424879e-01,
                         -4.28330153e-01,   5.75482696e-02,   9.24379975e-02,
                         -2.61291936e-02,   3.23476046e-02,   1.66212337e-03,
                          7.51144113e-03,   9.43399668e-02,  -2.16690436e-01,
                         -7.32411981e-01,  -7.56934702e-01,  -3.02060634e-01,
                          1.05168678e-01,   7.05322064e-03,  -5.54908156e-01,
                         -8.46857369e-01,  -4.74384695e-01,  -3.94452997e-02,
                         -4.39719093e-04,  -3.90992081e-03,  -3.21060196e-02,
                         -5.37715435e-01,  -8.72974038e-01,  -3.29827547e-01,
                         -5.84716201e-02,  -5.92909217e-01,  -5.37977219e-01,
                          1.48114085e-01,   5.78694530e-02,  -6.19376361e-01,
                         -5.73929846e-01,   9.38675478e-02,   6.12570569e-02,
                         -5.54601312e-01,  -4.40129966e-01,  -1.10902630e-01,
                         -5.11462390e-01,  -5.57019234e-01,   8.51918757e-02,
                          3.24193984e-02,  -6.21847808e-01,  -5.32057464e-01,
                          1.14107937e-01,   5.28172813e-02,  -5.64779580e-01,
                         -5.40603340e-01,  -3.09647769e-02,   5.34464493e-02,
                         -8.63165334e-02,  -2.58735325e-02,   3.23519520e-02,
                          9.14437976e-03,   5.33817662e-03,  -4.32555564e-03,
                         -1.52375521e-02,  -2.13478766e-02,  -5.86246289e-02,
                         -5.91625944e-02,   5.66500053e-03,   4.84330161e-03,
                         -3.85638513e-02,  -6.49368623e-03,   1.25106843e-02,
                         -2.29420606e-02,  -4.19416800e-02,  -4.59250882e-02,
                         -2.95443404e-02,  -2.79882587e-02,  -4.05607596e-02,
                         -1.02171674e-02,  -2.56937202e-02,  -6.44827783e-02,
                         -1.73047502e-02,   8.57118610e-03,  -1.33188693e-02,
                         -5.27033862e-03,   2.78249499e-03,  -9.11018532e-03,
                         -4.28772829e-02,  -4.04683910e-02,   1.17048696e-02,
                         -5.91702107e-03,  -5.48397005e-02,  -5.64970523e-02,
                         -4.71028760e-02,  -2.42244508e-02,  -3.09972763e-02,
                         -4.97946814e-02,  -8.65869410e-03,   1.98386852e-02,
                          7.36323930e-03,  -1.82974767e-02,  -7.79106189e-03,
                          2.21469738e-02,  -5.99346869e-02,  -2.32353080e-02,
                          9.54027548e-02,  -2.96281219e-01,  -6.92675173e-01,
                         -3.15087646e-01,   9.89295989e-02,   2.70124171e-02,
                         -4.60387580e-02,  -1.66892298e-02,  -1.49099641e-02,
                         -1.12485476e-02,  -2.34817229e-02,  -5.36400676e-02,
                         -3.47653627e-02,   1.03541724e-01,  -6.84763887e-04,
                         -4.83127266e-01,  -5.04219115e-01,  -1.44078195e-01,
                         -4.25584555e-01,  -8.30775917e-01,  -6.66064918e-01,
                         -6.48801386e-01,  -8.09915006e-01,  -4.77505505e-01,
                         -3.64170177e-03,   5.61129935e-02,  -3.94189693e-02,
                          4.62592840e-02,  -2.66876034e-02,  -5.62607765e-01,
                         -8.90603185e-01,  -5.32498300e-01,  -1.31322280e-01,
                         -1.18017801e-04,   6.84083924e-02,  -2.00433895e-01,
                         -6.04414880e-01,  -4.02153581e-01,   5.43091260e-02,
                          6.17814325e-02,  -7.10048825e-02,  -1.22039011e-02,
                          1.68814436e-02,  -5.07568195e-02,  -5.57666682e-02,
                          2.85045113e-02,  -1.09481461e-01,  -6.27656162e-01,
                         -8.65146935e-01,  -4.26870912e-01,  -2.11095829e-02,
                          1.09199267e-02,   2.26264931e-02,  -1.66732743e-01,
                         -6.82087839e-01,  -8.50011349e-01,  -3.86386186e-01,
                          3.09813358e-02,  -2.84338426e-02,  -6.97618127e-02,
                          1.06530085e-01,  -1.41086593e-01,  -5.90750635e-01,
                         -3.53345484e-01,  -1.09298244e-01,  -6.82261407e-01,
                         -9.26038861e-01,  -2.50857085e-01,  -2.30619200e-02,
                         -6.84305966e-01,  -9.20124114e-01,  -3.04475129e-01,
                         -9.63289142e-02,  -6.04222178e-01,  -4.50009048e-01,
                          2.21624762e-01,  -7.56500959e-02,  -6.14471972e-01,
                         -3.05698603e-01,  -2.38064304e-01,  -5.73285818e-01,
                         -2.92894900e-01,  -1.32732883e-01,  -7.20129669e-01,
                         -8.92588496e-01,  -2.53708482e-01,   1.73748389e-01,
                         -1.25599906e-01,  -6.26974523e-01,  -7.66781569e-01,
                         -6.86197639e-01,  -7.03358054e-01,  -7.28481710e-01,
                         -6.76946759e-01,  -6.63089633e-01,  -7.21979201e-01,
                         -7.63981402e-01,  -7.14847267e-01,  -6.76610529e-01,
                         -7.29086876e-01,  -7.35768378e-01,  -6.86390102e-01,
                         -7.00922728e-01,  -7.21190810e-01,  -7.05023408e-01,
                         -7.11483300e-01,  -7.15684593e-01,  -7.14681089e-01,
                         -7.35913575e-01,  -7.21029162e-01,  -6.83592975e-01,
                         -6.91435158e-01,  -6.97784007e-01,  -6.91124618e-01,
                         -7.07984090e-01,  -7.06668198e-01,  -7.10417330e-01,
                         -7.37617254e-01,  -7.14239717e-01,  -6.93859279e-01,
                         -7.15889573e-01,  -7.03090608e-01,  -6.99635744e-01,
                         -7.20830858e-01,  -7.03080714e-01,  -6.92427874e-01,
                         -6.98034763e-01,  -7.12211847e-01,  -7.51022398e-01,
                         -7.27727950e-01,  -6.72822714e-01,  -6.90397739e-01,
                         -7.14314878e-01,  -7.25566626e-01,  -7.56358027e-01,
                         -7.48776913e-01,  -7.12202668e-01,  -6.96012616e-01,
                         -7.01692283e-01,  -7.22599447e-01,  -7.24224329e-01,
                         -6.92522049e-01,  -6.88197136e-01,  -7.38489747e-01,
                         -7.30702221e-01,  -6.89998150e-01,  -8.13629925e-01,
                         -7.71674991e-01,  -2.75261045e-01,  -1.40154064e-01,
                         -6.61147892e-01,  -8.31750095e-01,  -6.52436197e-01,
                         -8.23340952e-01,  -7.55439758e-01,  -1.72225326e-01,
                         -1.58868313e-01,  -7.97977090e-01,  -8.40571880e-01,
                         -2.05017209e-01,  -1.29848197e-01,  -7.55685866e-01,
                         -8.70680451e-01,  -2.62614965e-01,  -1.03708252e-01,
                         -6.99068427e-01,  -9.10723567e-01,  -3.37898880e-01,
                         -1.21111266e-01,  -6.53612733e-01,  -8.57128084e-01,
                         -6.09064043e-01,  -7.52969444e-01,  -8.49846601e-01,
                         -3.13232690e-01,  -1.22682750e-01,  -7.26830065e-01,
                         -9.06958163e-01,  -3.05133015e-01,  -1.35078132e-01,
                         -6.47272050e-01,  -8.54437470e-01,  -6.95980310e-01,
                         -7.15588570e-01,  -7.59485126e-01,  -7.18676269e-01,
                         -7.34177709e-01,  -7.23943710e-01,  -7.46404231e-01,
                         -7.45995700e-01,  -6.38243437e-01,  -7.52039611e-01,
                         -8.10327411e-01,  -3.63735378e-01,  -1.53952420e-01,
                         -5.51299870e-01,  -7.97380924e-01,  -7.24784791e-01,
                         -7.01010525e-01,  -7.70410120e-01,  -8.21727872e-01,
                         -5.87061584e-01,  -7.51825273e-02,   8.56888965e-02,
                         -3.80919039e-01,  -8.19739401e-01,  -7.25188017e-01,
                         -6.39712036e-01,  -8.60755026e-01,  -6.56351030e-01,
                         -1.65839911e-01,  -3.47666115e-01,  -8.09009969e-01,
                         -8.08874190e-01,  -7.06188619e-01,  -7.33658075e-01,
                         -6.95783854e-01,  -6.95072651e-01,  -8.05499315e-01,
                         -7.99154520e-01,  -6.59111977e-01,  -7.60369599e-01,
                         -9.08599913e-01,  -5.04115105e-01,  -1.20942026e-01,
                         -4.24378097e-01,  -7.70393252e-01,  -8.35228920e-01,
                         -7.27562964e-01,  -2.71340817e-01,  -1.80425510e-01,
                         -8.18057895e-01,  -9.03451264e-01,  -2.18142956e-01,
                         -1.53112128e-01,  -7.94561088e-01,  -8.68281007e-01,
                         -2.78257489e-01,  -1.85836807e-01,  -6.85438931e-01,
                         -8.42298329e-01,  -6.75177276e-01,  -6.75623536e-01,
                         -7.24534094e-01,  -7.01026797e-01,  -6.97944343e-01,
                         -7.91960597e-01,  -7.58353949e-01,  -3.04395914e-01,
                         -1.42279461e-01,  -7.34840214e-01,  -8.85436296e-01,
                         -2.44256541e-01,  -1.13693595e-01,  -6.46730244e-01,
                         -8.37881267e-01,  -6.70360863e-01,  -7.64964044e-01,
                         -8.45021307e-01,  -3.65501791e-01,   9.87856537e-02,
                         -8.85945484e-02,  -5.51149011e-01,  -8.36139917e-01,
                         -6.72141969e-01,  -2.12496966e-01,  -2.76872993e-01,
                         -7.35387444e-01,  -7.73630500e-01,  -6.55141354e-01,
                         -6.87216580e-01,  -6.53775096e-01,  -6.84894860e-01,
                         -7.05834985e-01,  -6.10251427e-01,  -7.04535246e-01,
                         -7.23641932e-01,  -2.74985969e-01,   1.11756884e-01,
                         -1.06286444e-01,  -5.92643023e-01,  -7.56705403e-01,
                         -6.65035248e-01,  -7.02750087e-01,  -7.43559659e-01,
                         -6.73259616e-01,  -7.23237813e-01,  -6.88325107e-01,
                         -2.78170139e-01,   9.88011509e-02,  -5.98305091e-02,
                         -5.97979128e-01,  -8.21202874e-01,  -3.94027352e-01,
                         -6.60941675e-02,  -5.05492210e-01,  -8.98649752e-01,
                         -4.40980196e-01,  -2.21768767e-02,  -4.19890881e-01,
                         -8.11627448e-01,  -7.18388557e-01,  -7.38373220e-01,
                         -7.69376874e-01,  -3.36623222e-01,  -5.43818846e-02,
                         -4.95745391e-01,  -8.84187996e-01,  -4.74194407e-01,
                         -1.73015259e-02,  -4.11154062e-01,  -9.06393766e-01,
                         -5.21770358e-01,  -2.31969226e-02,  -3.30300629e-01,
                         -7.74724364e-01,  -7.33668685e-01,  -6.48564637e-01,
                         -7.01573908e-01,  -6.84318662e-01,  -6.70167148e-01,
                         -6.69219136e-01,  -6.46933556e-01,  -6.71708226e-01,
                         -6.67782128e-01,  -6.78826332e-01,  -7.11477458e-01,
                         -6.25402927e-01,  -6.85410440e-01,  -7.81030059e-01,
                         -3.92996579e-01,  -1.70287266e-01,  -5.15074730e-01,
                         -3.90171468e-01,  -5.95193319e-02,  -5.72809160e-01,
                         -8.66761267e-01,  -2.51342297e-01,  -1.58635587e-01,
                         -6.10054791e-01,  -3.17673385e-01,  -3.94193269e-02,
                         -6.66422606e-01,  -8.51037681e-01,  -1.65096194e-01,
                         -1.44415647e-01,  -6.67790353e-01,  -3.02577138e-01,
                          2.59840161e-01,  -2.15283334e-01,  -6.41326785e-01,
                         -1.87767267e-01,  -1.61155298e-01,  -6.44004941e-01,
                         -2.53644675e-01,   2.22331658e-01,  -3.30839366e-01,
                         -5.88819921e-01,  -1.73025548e-01,  -3.21335405e-01,
                         -5.15751064e-01,  -1.21730871e-01,  -2.64305502e-01,
                         -8.74888659e-01,  -6.37396097e-01,  -4.62942198e-02,
                         -3.06500643e-01,  -7.91245997e-01,  -6.81732833e-01,
                         -6.57209396e-01,  -8.28596473e-01,  -4.15177315e-01,
                         -5.19995578e-02,  -4.58293468e-01,  -5.58320582e-01,
                          3.75358388e-02,   1.30023792e-01,  -4.54596519e-01,
                         -7.54699588e-01,  -6.80467248e-01,  -7.28379548e-01,
                         -7.33601689e-01,  -5.88089347e-01,  -7.08752573e-01,
                         -7.78326333e-01,  -3.18214685e-01,  -1.10369056e-01,
                         -5.66613495e-01,  -7.89605975e-01,  -6.15748644e-01,
                         -7.09219038e-01,  -7.68594980e-01,  -2.79653728e-01,
                         -5.80441318e-02,  -6.52591646e-01,  -8.71527672e-01,
                         -2.50937939e-01,  -1.03780009e-01,  -6.15037680e-01,
                         -7.57848084e-01,  -6.25789404e-01,  -6.75748646e-01,
                         -7.01516032e-01,  -6.65526509e-01,  -6.88864470e-01,
                         -6.93453074e-01,  -6.70092523e-01,  -6.85193956e-01,
                         -7.11013436e-01,  -6.71705842e-01,  -6.32549167e-01,
                         -6.79825842e-01,  -7.10501730e-01,  -6.93828225e-01,
                         -6.81756794e-01,  -6.65608287e-01,  -7.27161109e-01,
                         -7.20106006e-01,  -3.28053236e-01,   1.24306187e-01,
                          2.29238737e-02,  -4.91182417e-01,  -7.76620567e-01,
                         -6.94434822e-01,  -6.37838125e-01,  -7.05664277e-01,
                         -6.83369637e-01,  -6.29852533e-01,  -7.02993393e-01,
                         -7.62173474e-01,  -5.15258849e-01,  -6.37714565e-02,
                          8.95445198e-02,  -1.42856361e-02,   2.49385219e-02,
                          5.34294434e-02,   5.67570608e-03,   3.28749344e-02,
                         -2.07660440e-02,   1.72105469e-02,   1.27215579e-01,
                         -2.39831239e-01,  -5.94441116e-01,  -2.53987432e-01,
                          1.15970373e-01,   5.13925627e-02,  -4.90443371e-02,
                          2.95108091e-02,   1.13305032e-01,  -1.65879160e-01,
                         -5.62974930e-01,  -3.52361083e-01,   8.49461704e-02,
                          5.40247113e-02,  -5.53199500e-02,   2.32193787e-02,
                          2.25020498e-02,  -1.01917014e-02,   3.53510841e-03,
                          1.77821908e-02,   5.34515828e-02,   3.89574319e-02,
                         -1.52640399e-02,  -1.29112331e-02,   2.99534481e-03,
                          2.14440227e-02,   4.92425859e-02,   2.14819126e-02,
                         -1.83162708e-02,  -1.27830375e-02,  -1.86719298e-02,
                         -3.84490788e-02,  -1.07463375e-02,   3.70893478e-02,
                          3.76890637e-02,   2.05516666e-02,   1.82772912e-02,
                         -3.51350661e-03,   8.30822438e-03,   4.15519811e-02,
                         -4.43042256e-02,  -6.08710460e-02,   1.15846843e-01,
                         -3.01492903e-02,  -5.04403174e-01,  -4.70490396e-01,
                          1.25639641e-03,   8.90640095e-02,  -8.28565732e-02,
                         -3.69792916e-02,   2.68855579e-02,  -2.64596790e-02,
                         -3.11442977e-03,   2.38154102e-02,  -5.21898605e-02,
                         -1.64949819e-02,   7.07146004e-02,  -2.26145133e-01,
                         -5.97435594e-01,  -3.19101393e-01,   1.03797093e-01,
                         -1.02170771e-02,  -3.04155331e-02,   1.53204769e-01,
                         -2.10300803e-01,  -5.96520305e-01,  -2.78501540e-01,
                          7.93447495e-02,   3.89581732e-02,  -4.46445197e-02,
                         -3.31098004e-03,   1.16987117e-01,  -3.71440761e-02,
                         -5.98046839e-01,  -8.28765094e-01,  -5.98298669e-01,
                         -6.66655481e-01,  -7.58824110e-01,  -2.67173111e-01,
                         -2.11158395e-02,  -6.04373634e-01,  -8.63273263e-01,
                         -2.57910132e-01,  -7.62040913e-02,  -5.79348385e-01,
                         -4.17179376e-01,   1.89635709e-01,  -4.75555584e-02,
                         -6.10602915e-01,  -6.81388140e-01,  -7.16299772e-01,
                         -6.40699685e-01,  -1.63398042e-01,  -1.61551207e-01,
                         -7.87643492e-01,  -7.73904502e-01,  -1.11429475e-01,
                         -1.39843792e-01,  -7.34929621e-01,  -7.64090896e-01,
                         -5.50392687e-01,  -7.39475727e-01,  -6.35786712e-01,
                         -9.82563794e-02,  -2.10735932e-01,  -8.45862925e-01,
                         -7.21352696e-01,  -4.79137786e-02,  -1.57049373e-01,
                         -7.91509390e-01,  -7.81099081e-01,  -5.67002535e-01,
                         -7.63963282e-01,  -5.55718124e-01,  -1.21758759e-01,
                         -4.24679488e-01,  -5.63050926e-01,  -4.86166626e-02,
                         -2.64881074e-01,  -9.35490489e-01,  -6.04263604e-01,
                         -1.67701878e-02,  -3.04428726e-01,  -7.62373984e-01,
                         -7.34656692e-01,  -6.44688785e-01,  -7.37322569e-01,
                         -5.80331028e-01,  -2.48615295e-02,   1.57775059e-01,
                         -3.84465545e-01,  -6.31845713e-01,  -1.03603445e-01,
                          1.72653601e-01,  -2.75586516e-01,  -7.03446507e-01,
                         -6.64858520e-01,  -2.97163755e-01,   6.84585571e-02,
                         -9.35658962e-02,  -6.21671379e-01,  -5.31292915e-01,
                          1.09836236e-01,   7.77205601e-02,  -5.80657125e-01,
                         -5.83919883e-01,   5.41682392e-02,   1.74891740e-01,
                         -3.85500818e-01,  -8.58652115e-01,  -7.40397871e-01,
                         -1.26001284e-01,   2.00956568e-01,  -2.51736224e-01,
                         -6.14421129e-01,  -2.64720201e-01,   5.53440675e-02,
                          3.20092663e-02,  -7.74117466e-03,  -3.13012302e-01,
                         -7.67215550e-01,  -7.72936642e-01,  -6.32396281e-01,
                         -7.06355393e-01,  -6.95055485e-01,  -6.97505176e-01,
                         -7.48017788e-01,  -3.97993892e-01,   2.87751015e-02,
                          6.86656684e-03,  -3.80282998e-02,   6.30145296e-02,
                         -1.51661620e-01,  -5.51529288e-01,  -7.22114503e-01,
                         -7.12545991e-01,  -6.54187799e-01,  -6.01542950e-01,
                         -6.13309801e-01,  -6.89965010e-01,  -8.05150807e-01,
                         -6.82313383e-01,  -2.19329819e-01,  -1.30190954e-01,
                         -5.54681659e-01,  -4.20382410e-01,   1.69577837e-01,
                         -3.83604132e-02,  -6.16564691e-01,  -4.40393358e-01,
                         -4.07563336e-02,  -9.28531401e-03,   2.81240493e-02,
                         -1.39553040e-01,  -6.96162164e-01,  -7.32803047e-01,
                         -1.37074754e-01,  -8.84867981e-02,  -6.40125334e-01,
                         -7.82351673e-01,  -6.48459375e-01,  -7.76057720e-01,
                         -6.41018748e-01,  -1.73417956e-01,  -2.59992868e-01,
                         -7.32558310e-01,  -7.40903258e-01,  -5.82576096e-01,
                         -7.18683004e-01,  -6.25956237e-01,  -1.21155977e-01,
                          1.05232947e-01,  -5.21183722e-02,  -1.07779931e-02,
                          1.23663247e-02,  -4.21122193e-01,  -5.62455177e-01,
                         -4.06529754e-02,   1.62489995e-01,  -1.04676396e-01,
                         -7.11914375e-02,   1.06980808e-01,   2.93523055e-02,
                         -7.18849599e-02,  -2.27440167e-02,   6.19589649e-02,
                         -3.26380655e-02,  -1.35174885e-01,   1.30016521e-01,
                          1.79288849e-01,  -4.15783018e-01,  -6.20385468e-01,
                         -9.67897698e-02,   1.42615765e-01,  -5.79643771e-02,
                         -1.02945045e-01,   4.60726954e-02,   4.95546944e-02,
                         -2.56415397e-01,  -4.85243559e-01,  -2.61539042e-01,
                          1.08570987e-02,  -9.07186884e-03,  -6.14532493e-02,
                         -2.98443045e-02,  -4.17145193e-02,  -7.09637702e-02,
                          2.91037224e-02,   9.97988805e-02,  -2.38081917e-01,
                         -5.88594317e-01,  -2.90588856e-01,   1.37026384e-01,
                          1.01136945e-01,  -5.13002230e-03,  -1.85483638e-02,
                         -8.08657184e-02,  -3.24783176e-02,   1.91277023e-02,
                         -7.38377497e-02,  -7.50016496e-02,   3.93717214e-02,
                          9.87140238e-02,   8.17649215e-02,  -8.28804914e-03,
                         -6.50386363e-02,  -1.45253446e-02,   1.11925940e-03,
                         -1.86743904e-02,   2.59726774e-03,  -5.47407679e-02,
                         -1.19898111e-01,   6.48391340e-03,   4.09595110e-02,
                         -3.29824835e-01,  -7.10142851e-01,  -7.27223039e-01,
                         -6.99514389e-01,  -7.41391361e-01,  -4.56126183e-01,
                          1.57964230e-02,   5.59900105e-02,  -3.68705392e-01,
                         -7.46452212e-01,  -6.83615446e-01,  -2.44701177e-01,
                          1.85883995e-02,  -1.10260829e-01,  -6.06555119e-02,
                          1.82990447e-01,  -1.29070848e-01,  -6.33636951e-01,
                         -3.76995862e-01,   9.09910426e-02,   4.38712584e-03,
                         -4.95924018e-02,   7.53613785e-02,  -2.90793061e-01,
                         -6.42030776e-01,  -1.99198574e-01,   1.80235267e-01,
                         -2.54266709e-01,  -5.67546666e-01,  -1.69631973e-01,
                          1.24502547e-01,  -3.28229889e-02,  -8.91801864e-02,
                          1.09441793e-02,  -1.94402598e-02,  -3.79663371e-02,
                          2.87057348e-02,  -4.71925159e-04,  -5.02910726e-02,
                         -2.10388680e-03,   2.41328534e-02,   1.31520871e-02,
                          4.71778028e-03,  -6.57097399e-02,  -3.76929045e-02,
                          9.46411565e-02,  -1.53402567e-01,  -5.96769750e-01,
                         -4.23641026e-01,   7.38958046e-02,   9.62793529e-02,
                         -7.38052726e-02,  -1.17216865e-03,   4.35013883e-02,
                         -5.59656098e-02,  -2.05647424e-02,   1.15258232e-01,
                         -1.17752582e-01,  -5.81829488e-01,  -4.34473544e-01,
                          6.39156625e-02,   1.31009640e-02,  -7.49358535e-02,
                          1.44414186e-01,  -1.61578014e-01,  -5.73746204e-01,
                         -2.78169543e-01,  -2.12467268e-01,  -7.29430497e-01,
                         -7.09498584e-01,  -2.42823139e-01,  -3.06511879e-01,
                         -6.67352140e-01,  -6.89706862e-01,  -5.93378246e-01,
                         -6.76960886e-01,  -7.14101493e-01,  -6.21529996e-01,
                         -6.15868032e-01,  -6.85569346e-01,  -7.05543816e-01,
                         -6.78065956e-01,  -6.41011775e-01,  -7.01930583e-01,
                         -7.98835874e-01,  -6.91284895e-01,  -5.50425947e-01,
                         -6.65763855e-01,  -7.89559722e-01,  -6.85334384e-01,
                         -5.92577338e-01,  -6.60313964e-01,  -7.02980459e-01,
                         -6.77930951e-01,  -7.34157324e-01,  -7.67000198e-01,
                         -6.46561384e-01,  -6.10188007e-01,  -7.32822001e-01,
                         -7.48286307e-01,  -6.57069862e-01,  -6.28159642e-01,
                         -6.32606030e-01,  -6.49302423e-01,  -6.95043445e-01,
                         -6.95709527e-01,  -6.29517615e-01,  -6.06702030e-01,
                         -6.93849385e-01,  -7.58768320e-01,  -7.01048672e-01,
                         -6.50889754e-01,  -6.68294013e-01,  -6.63524210e-01,
                         -6.48354948e-01,  -6.69634283e-01,  -7.09862292e-01,
                         -7.35348821e-01,  -7.17405796e-01,  -6.81938112e-01,
                         -6.48687303e-01,  -6.31556749e-01,  -6.77726448e-01,
                         -6.96118295e-01,  -6.25369966e-01,  -6.37749195e-01,
                         -7.35503912e-01,  -7.10044324e-01,  -5.88939428e-01,
                         -5.82636595e-01,  -7.19638646e-01,  -7.55628347e-01,
                         -6.05277002e-01,  -5.95023155e-01,  -7.74482191e-01,
                         -7.70560026e-01,  -6.27205491e-01,  -6.59183562e-01,
                         -7.57689178e-01,  -6.89343333e-01,  -5.64685881e-01,
                         -6.07012868e-01,  -7.14879692e-01,  -6.63985789e-01,
                         -5.99986255e-01,  -6.85431182e-01,  -7.39758611e-01,
                         -6.77546501e-01,  -6.22375071e-01,  -6.55354559e-01,
                         -7.04858243e-01,  -6.33958459e-01,  -5.96312404e-01,
                         -6.86166763e-01,  -6.54134572e-01,  -6.76498353e-01,
                         -8.18652153e-01,  -5.05551934e-01,  -1.31823286e-01,
                         -4.11661685e-01,  -5.43178141e-01,  -1.78918839e-01,
                         -2.66205639e-01,  -6.98110700e-01,  -7.48804629e-01,
                         -6.37085915e-01,  -6.29670143e-01,  -5.86163342e-01,
                         -5.69480598e-01,  -7.35715568e-01,  -8.36378694e-01,
                         -4.64509428e-01,  -6.77214041e-02,  -3.52529973e-01,
                         -7.74510682e-01,  -7.31938422e-01,  -6.51226401e-01,
                         -6.35609210e-01,  -5.83831370e-01,  -7.40103781e-01,
                         -6.87269449e-01,  -2.17145070e-01,  -2.04120204e-01,
                         -6.46377265e-01,  -6.52896821e-01,  -5.21102786e-01,
                         -7.47683406e-01,  -6.15883410e-01,  -8.96591991e-02,
                         -2.42922693e-01,  -6.54966235e-01,  -1.76208273e-01,
                          2.35881791e-01,  -3.74081314e-01,  -6.80570245e-01,
                         -1.59997955e-01,  -1.65344968e-01,  -7.38533318e-01,
                         -6.59419060e-01,  -1.10467255e-01,  -2.23721609e-01,
                         -8.01246524e-01,  -6.70203865e-01,  -7.06230924e-02,
                         -1.84057236e-01,  -6.96581662e-01,  -7.63092518e-01,
                         -6.33001983e-01,  -4.40113157e-01,  -1.96145535e-01,
                         -4.28200722e-01,  -7.48861969e-01,  -3.79992962e-01,
                         -2.98110098e-02,  -4.15272862e-01,  -7.77548015e-01,
                         -6.36133552e-01,  -6.15738034e-01,  -7.52182245e-01,
                         -3.84542286e-01,  -4.62375674e-03,  -4.66454059e-01,
                         -8.79782081e-01,  -3.89698833e-01,  -4.86484505e-02,
                         -4.55996215e-01,  -7.46239185e-01,  -6.37844682e-01,
                         -5.80723763e-01,  -7.08776951e-01,  -7.90043354e-01,
                         -4.50352609e-01,  -4.66051586e-02,  -3.51444513e-01,
                         -6.45856261e-01,  -6.23121746e-02,   2.30121553e-01,
                         -3.45531940e-01,  -4.58417028e-01,  -1.23000175e-01,
                         -4.24288213e-01,  -7.70169199e-01,  -5.60573816e-01,
                         -5.78109086e-01,  -7.77445197e-01,  -3.84947926e-01,
                          1.16401548e-02,  -4.21687722e-01,  -8.44754398e-01,
                         -4.15892035e-01,  -1.17241755e-01,  -4.80045319e-01,
                         -3.54604334e-01,   4.70137149e-02,  -4.84520286e-01,
                         -8.84083331e-01,  -2.77343005e-01,  -1.30251989e-01,
                         -5.25943100e-01,  -2.85506427e-01,  -1.48331746e-01,
                         -5.37089169e-01,  -3.12754780e-01,   2.05088601e-01,
                         -9.62375849e-02,  -6.34573340e-01,  -6.14053667e-01,
                         -5.29354751e-01,  -7.50270605e-01,  -7.06731677e-01,
                         -2.29837745e-01,  -1.14080369e-01,  -5.84146619e-01,
                         -7.93999076e-01,  -3.56192738e-01,   1.36929527e-01,
                          8.53762329e-02,  -4.22294110e-01,  -7.71936536e-01,
                         -7.16237605e-01,  -6.23832643e-01,  -6.42473519e-01,
                         -6.12769961e-01,  -5.65350056e-01,  -5.73534548e-01,
                         -6.31163716e-01,  -6.98381245e-01,  -7.02879846e-01,
                         -6.79493248e-01,  -6.10244274e-01,  -5.12168348e-01,
                         -6.70705140e-01,  -8.38654757e-01,  -4.17256176e-01,
                          1.29410345e-02,  -3.17512900e-01,  -7.18915045e-01,
                         -6.57486558e-01,  -6.57433093e-01,  -7.32906103e-01,
                         -6.43750310e-01,  -6.83939219e-01,  -6.40154541e-01,
                         -2.24932760e-01,  -1.38037428e-01,  -5.47435641e-01,
                         -6.63291991e-01,  -5.98050475e-01,  -7.65604675e-01,
                         -5.85617363e-01,  -1.14450261e-01,  -2.56879121e-01,
                         -6.79301679e-01,  -6.35031641e-01,  -5.71505725e-01,
                         -7.44954944e-01,  -6.88535154e-01,  -5.13764083e-01,
                         -5.83357453e-01,  -7.17643082e-01,  -6.75037920e-01,
                         -5.46522915e-01,  -5.72712004e-01,  -7.20478415e-01,
                         -7.22616613e-01,  -6.57429516e-01,  -6.76770806e-01,
                         -6.40603006e-01,  -5.84729910e-01,  -5.86960673e-01,
                         -6.19699657e-01,  -7.71851957e-01,  -7.09787786e-01,
                         -2.10105523e-01,  -7.69688934e-02,  -5.64174831e-01,
                         -7.88392007e-01,  -6.21496439e-01,  -5.84069550e-01,
                         -6.42980278e-01,  -6.52638912e-01,  -6.19681001e-01,
                         -5.62562466e-01,  -6.25760972e-01,  -7.45736957e-01,
                         -7.26817667e-01,  -6.54555678e-01,  -6.20472312e-01,
                         -6.14004314e-01,  -6.62800550e-01,  -6.76463366e-01,
                         -5.99021018e-01,  -5.90627015e-01,  -7.19625056e-01,
                         -7.81210423e-01,  -6.19123876e-01,  -4.78851765e-01,
                         -6.21461928e-01,  -7.62504518e-01,  -6.30420268e-01,
                         -5.31710207e-01,  -6.64332271e-01,  -7.50265181e-01,
                         -6.67438686e-01,  -6.01045489e-01,  -6.13047659e-01,
                         -6.28895998e-01,  -6.51923060e-01,  -6.83873296e-01,
                         -6.82810962e-01,  -6.83878481e-01,  -6.88251793e-01,
                         -6.21340990e-01,  -5.75297892e-01,  -6.64146423e-01,
                         -7.30048656e-01,  -6.50241494e-01,  -5.85408986e-01,
                         -6.45579994e-01,  -7.06794739e-01,  -6.63705766e-01,
                         -6.03027284e-01,  -6.40116751e-01,  -7.12145448e-01,
                         -6.93709612e-01,  -6.15627587e-01,  -5.91317952e-01,
                         -6.35011375e-01,  -6.65890753e-01,  -6.50664270e-01,
                         -6.55821145e-01,  -6.76672697e-01,  -6.27929509e-01,
                         -6.03632569e-01,  -7.03529477e-01,  -7.38347590e-01,
                         -6.36639357e-01,  -6.14035249e-01,  -6.74018741e-01,
                         -6.78455710e-01,  -6.85231090e-01,  -7.13907242e-01,
                         -6.88657343e-01,  -6.39535069e-01,  -6.27316594e-01,
                         -6.50719345e-01,  -6.38848841e-01,  -5.89151144e-01,
                         -6.37817919e-01,  -7.20779896e-01,  -6.74409628e-01,
                         -6.40812814e-01,  -6.91308737e-01,  -6.78474545e-01,
                         -6.58685088e-01,  -6.85844362e-01,  -6.66419566e-01,
                         -6.56986713e-01,  -7.01311350e-01,  -7.00869381e-01,
                         -6.36475980e-01,  -6.10641062e-01,  -6.99008763e-01,
                         -7.53202140e-01,  -6.39026046e-01,  -5.78580558e-01,
                         -6.86191440e-01,  -7.42795706e-01,  -6.77447557e-01,
                         -5.88828504e-01,  -5.82741022e-01,  -7.04638183e-01,
                         -7.67988741e-01,  -6.68557584e-01,  -5.89209020e-01,
                         -6.23523355e-01,  -6.88812912e-01,  -6.95814490e-01,
                         -6.94922805e-01,  -7.42571354e-01,  -6.37221694e-01,
                         -5.07972121e-01,  -7.30234861e-01,  -7.76838958e-01,
                         -2.66777813e-01,  -1.04594998e-01,  -5.48000455e-01,
                         -7.73217738e-01,  -7.12992191e-01,  -5.81301928e-01,
                         -1.25491217e-01,   2.36535355e-01,  -1.65296450e-01,
                         -7.79332340e-01,  -7.67926335e-01,  -5.30766368e-01,
                         -6.43695891e-01,  -6.05756104e-01,  -2.12802768e-01,
                         -2.40069509e-01,  -6.57328486e-01,  -7.07170665e-01,
                         -6.48069561e-01,  -8.30128729e-01,  -5.89519858e-01,
                         -3.08854915e-02,  -2.66005516e-01,  -9.05146599e-01,
                         -6.32744789e-01,  -2.68581714e-02,  -2.76263744e-01,
                         -7.64401793e-01,  -7.46786714e-01,  -6.19686365e-01,
                         -4.27056581e-01,  -2.20106682e-04,   1.01605497e-01,
                         -3.85758638e-01,  -8.05576503e-01,  -5.93126178e-01,
                         -1.34513289e-01,  -2.41682306e-01,  -7.54179776e-01,
                         -6.96782291e-01,  -1.57372206e-01,  -2.37068042e-01,
                         -8.34151804e-01,  -7.37111926e-01,  -1.25405431e-01,
                         -2.02061579e-01,  -5.89185834e-01,  -2.86321104e-01,
                          1.23169631e-01,   6.35052798e-03,  -6.01524897e-02,
                          5.66022731e-02,  -2.23802373e-01,  -7.61524975e-01,
                         -7.75999665e-01,  -2.23445639e-01,  -6.53716922e-02,
                         -5.95607877e-01,  -7.56782413e-01,  -2.14646161e-01,
                         -1.16124660e-01,  -7.61947095e-01,  -9.03288424e-01,
                         -2.31301278e-01,  -6.14108406e-02,  -5.76216578e-01,
                         -4.34072971e-01,   1.75020024e-01,  -7.65250400e-02,
                         -6.37658060e-01,  -3.39473873e-01,   1.38688982e-01,
                         -1.21643268e-01,  -5.87571204e-01,  -6.82322741e-01,
                         -7.27339268e-01,  -7.32865632e-01,  -2.83270538e-01,
                          1.52677223e-01,   3.53371203e-02,  -4.58383225e-02,
                          9.71746072e-02,  -2.03175828e-01,  -7.70253956e-01,
                         -8.31947625e-01,  -2.99086034e-01,   1.96228981e-01,
                         -3.29999737e-02,  -6.19958580e-01,  -5.46432972e-01,
                         -4.44775214e-03,   5.64940423e-02,  -4.15151089e-01,
                         -7.99737155e-01,  -6.50187433e-01,  -1.38471276e-01,
                          1.19724073e-01,   1.57175194e-02,  -6.14524633e-02,
                         -2.51273215e-02,   3.34516331e-03,  -5.48774889e-03,
                         -4.90619764e-02,  -8.37146714e-02,  -6.19167276e-02,
                          3.21249254e-02,   1.09845951e-01,   2.28123143e-02,
                         -1.05229408e-01,  -5.84112406e-02,   2.88357958e-02,
                         -2.00085100e-02,  -8.53328258e-02,  -4.17918935e-02,
                          1.96507610e-02,  -5.06108301e-03,  -4.09174226e-02,
                         -2.49531716e-02,  -3.09954900e-02,  -5.04327044e-02,
                         -3.08720786e-02,  -1.82503648e-02,  -1.14602186e-02,
                          1.15516577e-02,   1.44900158e-02,  -6.17515296e-03,
                         -4.74888757e-02,  -7.56693408e-02,  -4.39902097e-02,
                         -1.43597648e-02,   1.43453525e-03,   3.21495272e-02,
                         -1.42304460e-02,  -8.41713622e-02,  -3.97263356e-02,
                          1.76904257e-03,  -2.27924436e-02,  -2.48584407e-03,
                          3.14126629e-03,  -6.83021247e-02,  -9.56498757e-02,
                         -2.91411746e-02,   3.69072184e-02,   7.97143672e-03,
                         -6.37683794e-02,  -3.87371033e-02,   1.71003025e-02,
                         -3.10078114e-02,  -7.46753961e-02,  -2.23657656e-02,
                          2.29397584e-02,   2.86597002e-04,  -5.32976538e-02,
                         -6.54221997e-02,  -1.44998003e-02,   2.14760727e-03,
                         -2.79776547e-02,  -1.73082780e-02,   4.73913475e-04,
                         -3.41428211e-03,   1.23040807e-02,   8.84092133e-03,
                         -1.68467890e-02,  -2.57587396e-02,  -5.78110628e-02,
                         -8.89005885e-02,  -7.08324090e-02,  -5.01599684e-02,
                         -1.36788432e-02,   4.69135344e-02,   3.25364061e-02,
                         -4.83466797e-02,  -8.27467442e-02,  -4.38332334e-02,
                          1.49073359e-02,   2.54872739e-02,  -1.48532689e-02,
                         -4.63143587e-02,  -5.18884808e-02,  -2.80084126e-02,
                          2.09281426e-02,   2.79845856e-02,  -2.45628897e-02,
                         -6.98610321e-02,  -6.36029914e-02,  -1.19797727e-02,
                          2.48432867e-02,   7.76086655e-03,  -6.65141409e-03,
                         -2.95694917e-03,  -2.46321093e-02,  -2.85215750e-02,
                          4.36354708e-03,  -1.16595207e-02,  -6.16023056e-02,
                         -4.93202172e-02,  -1.00621013e-02,  -1.42241223e-02,
                         -2.91550029e-02,  -3.27993892e-02,  -4.20652926e-02,
                         -2.37151422e-02,   4.37958166e-02,   7.40797818e-02,
                         -7.55838538e-03,  -7.43289515e-02,   4.46050242e-03,
                          6.70049712e-02,  -1.08933710e-02,  -5.45964763e-02,
                         -9.79455654e-03,  -3.47124669e-03,  -2.08690539e-02,
                         -2.45995112e-02,  -3.62965278e-02,  -2.00656317e-02,
                          3.56106311e-02,   6.75604865e-02,   6.57096086e-03,
                         -7.48281032e-02,  -3.70012783e-02,   5.13451593e-03,
                         -4.47394289e-02,  -4.13747542e-02,  -1.60915013e-02,
                         -1.18234940e-02,   3.25279459e-02,   7.74852140e-03,
                          3.11475322e-02,   5.94697595e-02,  -3.31186354e-01,
                         -5.70350468e-01,  -1.66554138e-01,  -2.25251347e-01,
                         -8.48623276e-01,  -7.41151094e-01,  -1.12080976e-01,
                          1.29260927e-01,  -1.03317708e-01,  -6.64028525e-01,
                         -8.61761272e-01,  -3.66545171e-01,  -1.38308808e-01,
                         -4.18474734e-01,  -6.33214235e-01,  -7.96907306e-01,
                         -6.76759958e-01,  -2.04485983e-01,  -2.08814263e-01,
                         -6.56069517e-01,  -7.58697569e-01,  -6.43726051e-01,
                         -6.74482763e-01,  -7.05902934e-01,  -6.63551033e-01,
                         -6.48536921e-01,  -6.86493456e-01,  -7.08092630e-01,
                         -7.12064862e-01,  -7.25552917e-01,  -5.29877126e-01,
                         -7.37357065e-02,   1.14074752e-01,  -2.70296544e-01,
                         -6.97535872e-01,  -6.95306659e-01,  -6.51562572e-01,
                         -8.27217042e-01,  -6.08333528e-01,  -6.54387251e-02,
                         -2.66832560e-01,  -9.10342991e-01,  -6.69570327e-01,
                          8.98042880e-03,  -1.91251546e-01,  -8.07951450e-01,
                         -7.84469187e-01,  -5.92524052e-01,  -7.78647184e-01,
                         -6.06255770e-01,  -5.90712018e-02,  -2.08903998e-01,
                         -7.42734909e-01,  -7.10791588e-01,  -6.38523102e-01,
                         -8.27408373e-01,  -5.23654640e-01,  -6.95794150e-02,
                         -3.82141650e-01,  -8.72553051e-01,  -5.63564122e-01,
                         -1.33858994e-02,  -3.04910600e-01,  -9.09756362e-01,
                         -6.06662333e-01,  -3.64599973e-02,  -3.41233641e-01,
                         -6.30235672e-01,  -1.01881593e-01,   1.79639250e-01,
                         -2.87117392e-01,  -7.04259574e-01,  -7.47163713e-01,
                         -6.66292787e-01,  -6.53350055e-01,  -7.02828586e-01,
                         -6.42223001e-01,  -6.08421445e-01,  -7.33141661e-01,
                         -7.36821175e-01,  -7.17557013e-01,  -7.76556969e-01,
                         -4.53534156e-01,  -6.57748729e-02,  -3.29433709e-01,
                         -7.28248000e-01,  -7.05664456e-01,  -6.50576591e-01,
                         -6.91559076e-01,  -6.50841713e-01,  -6.52733743e-01,
                         -7.06751287e-01,  -6.80311322e-01,  -6.55744910e-01,
                         -6.93562448e-01,  -6.63283288e-01,  -6.36603594e-01,
                         -7.78050363e-01,  -7.01364756e-01,  -2.22124621e-01,
                         -1.21715918e-01,  -5.75094700e-01,  -7.55672336e-01,
                         -6.60340130e-01,  -7.33058393e-01,  -6.29633009e-01,
                         -1.80060714e-01,   7.99175277e-02,  -1.56011671e-01,
                         -5.36003828e-01,  -6.78858638e-01,  -7.31505096e-01,
                         -6.53669238e-01,  -1.47555992e-01,   1.83699682e-01,
                         -2.00739220e-01,  -6.23290598e-01,  -6.84951961e-01,
                         -6.67607486e-01,  -6.54564857e-01,  -7.31700182e-01,
                         -6.82431281e-01,  -2.55488217e-01,  -1.17209569e-01,
                         -5.40546596e-01,  -7.60747671e-01,  -6.33649707e-01,
                         -6.15871012e-01,  -7.06437588e-01,  -6.89997673e-01,
                         -6.24741197e-01,  -7.44277298e-01,  -7.73801804e-01,
                         -3.12683672e-01,  -5.96397109e-02,  -5.04806936e-01,
                         -7.68401682e-01,  -6.07325673e-01,  -6.33712590e-01,
                         -6.68662012e-01,  -5.84632814e-01,  -7.33356118e-01,
                         -7.28913188e-01,  -2.06422374e-01,   1.54668823e-01,
                         -1.43402442e-01,  -5.89508355e-01,  -6.67103648e-01,
                         -5.74076533e-01,  -6.08524680e-01,  -6.89346492e-01,
                         -7.12103307e-01,  -6.90202177e-01,  -6.33729160e-01,
                         -5.99407732e-01,  -6.06310785e-01,  -6.50670588e-01,
                         -7.46892750e-01,  -7.49061406e-01,  -6.03024840e-01,
                         -5.60338974e-01,  -6.84778810e-01,  -7.31982112e-01,
                         -6.25216246e-01,  -5.56922495e-01,  -6.61818326e-01,
                         -7.67937362e-01,  -6.74399257e-01,  -5.58288634e-01,
                         -6.22708082e-01,  -6.99227214e-01,  -6.51296437e-01,
                         -6.15031958e-01,  -6.50399745e-01,  -6.65805161e-01,
                         -6.50988996e-01,  -6.42923176e-01,  -6.31218612e-01,
                         -6.50017440e-01,  -6.99605763e-01,  -6.89029336e-01,
                         -6.49003744e-01,  -6.37653708e-01,  -6.24296725e-01,
                         -6.82466745e-01,  -7.27811933e-01,  -5.86879790e-01,
                         -5.68480432e-01,  -6.89645588e-01,  -3.97535980e-01,
                         -9.37734991e-02,  -4.48929101e-01,  -7.46294856e-01,
                         -5.44048369e-01,  -5.56660712e-01,  -7.79933691e-01,
                         -7.23501444e-01,  -6.05471790e-01,  -6.24636114e-01,
                         -6.82425618e-01,  -6.96824193e-01,  -5.95716476e-01,
                         -6.31819129e-01,  -7.77812839e-01,  -4.44347769e-01,
                         -2.37469766e-02,  -3.65800530e-01,  -8.02995205e-01,
                         -6.16607249e-01,  -5.44569552e-01,  -7.62907863e-01,
                         -4.55424249e-01,  -2.44424231e-02,  -3.93847674e-01,
                         -8.20879281e-01,  -4.36553925e-01,  -8.67170244e-02,
                         -3.90425444e-01,  -6.90215349e-01,  -7.06569910e-01,
                         -5.68562806e-01,  -2.22701117e-01,  -1.62182331e-01,
                         -6.31594241e-01,  -7.32213557e-01,  -2.21786514e-01,
                         -1.09347515e-01,  -5.62160850e-01,  -7.43334234e-01,
                         -6.48199439e-01,  -7.29577303e-01,  -5.89118898e-01,
                         -1.24840185e-01,  -1.50957704e-01,  -5.96567988e-01,
                         -7.09694445e-01,  -6.76825821e-01,  -7.17374325e-01,
                         -5.76908469e-01,  -5.24936855e-01,  -6.95653141e-01,
                         -7.22545564e-01,  -6.74986243e-01,  -6.90673947e-01,
                         -6.46353602e-01,  -6.34601355e-01,  -5.91100812e-01,
                         -2.76442319e-01,   7.50332028e-02,   1.64151005e-03,
                         -4.84168559e-01,  -7.62332559e-01,  -4.33134913e-01,
                          3.83184897e-03,   7.27620274e-02,   1.56060290e-02,
                          2.42029168e-02,   1.68498326e-03,  -2.23985557e-02,
                         -9.70922760e-04,   1.63266491e-02,   2.11247485e-02,
                          4.40908484e-02,   6.82147518e-02,   6.15603365e-02,
                          4.53734174e-02,   2.02867165e-02,  -3.96987343e-05,
                          2.41100285e-02,   1.20728305e-02,   2.19873581e-02,
                          1.55564785e-01,   2.37535480e-02,  -4.27506804e-01,
                         -4.59596097e-01,  -6.14713132e-02,   6.94300085e-02,
                          3.04413144e-04,   4.58773263e-02,   3.47506590e-02,
                         -6.62415549e-02,  -3.03818993e-02,   1.61136344e-01,
                          9.06841531e-02,  -4.08223063e-01,  -5.29416740e-01,
                         -7.98192807e-03,   1.71362966e-01,  -2.25992966e-02,
                          7.08671957e-02,  -5.16658910e-02,  -4.84830976e-01,
                         -3.59714776e-01,   6.61641508e-02,   1.09326035e-01,
                          3.30009162e-02,   2.19612411e-05,  -7.16299042e-02,
                         -2.45323237e-02,   3.08923218e-02,   2.13431809e-02,
                          1.01292029e-01,   8.49567726e-02,  -2.26895344e-02,
                          3.89934480e-02,   4.98389751e-02,  -6.32184930e-03,
                          6.89083189e-02,  -1.31466925e-01,  -5.01794875e-01,
                         -3.27540636e-01,   7.67869726e-02,   1.09684378e-01,
                          2.17963587e-02,   3.54650579e-02,   4.61757965e-02,
                          5.09106852e-02,   6.57288358e-02,   2.89734378e-02,
                         -3.19861509e-02,   7.94367641e-02,   1.46416679e-01,
                         -2.64073342e-01,  -5.65454602e-01,  -1.66715905e-01,
                          1.65815666e-01,   1.21668084e-02,  -2.27089226e-02,
                          1.17012776e-01,   7.24512711e-02,  -3.64611074e-02,
                         -1.82641707e-02,   3.31022753e-03,  -2.56076716e-02,
                          1.05843559e-01,   1.64991841e-01,  -3.12548220e-01,
                         -6.14484012e-01,  -5.59678935e-02,   2.10691810e-01,
                         -3.54759902e-01,  -4.34822559e-01,  -6.42413348e-02,
                         -3.67701858e-01,  -5.76782763e-01,   4.14381772e-02,
                          2.31361762e-01,  -4.21349019e-01,  -5.83882511e-01,
                          4.04876433e-02,   2.10319713e-01,  -3.97118270e-01,
                         -5.97964525e-01,  -7.55466893e-02,   1.50008619e-01,
                         -4.01341729e-02,   3.86572555e-02,   1.41159624e-01,
                         -3.11993897e-01,  -8.48237693e-01,  -5.86559772e-01,
                         -1.96470097e-02,  -2.56752342e-01,  -5.96975803e-01,
                         -6.14552833e-02,   2.79696405e-01,  -2.72036165e-01,
                         -7.19375372e-01,  -7.04917312e-01,  -6.45855665e-01,
                         -4.14892495e-01,   2.98979543e-02,   1.42753869e-01,
                         -3.13028246e-01,  -7.67141759e-01,  -6.39638424e-01,
                         -1.74217463e-01,   6.67973757e-02,   9.09252912e-02,
                          4.30476964e-02,  -3.59075755e-01,  -8.57259750e-01,
                         -6.07885718e-01,  -1.17154401e-02,  -2.23466769e-01,
                         -8.09071600e-01,  -5.85905850e-01,  -2.51867808e-02,
                         -2.59906024e-01,  -6.38525069e-01,  -1.17139429e-01,
                          2.63566166e-01,  -3.15166473e-01,  -5.58564365e-01,
                         -1.27071902e-01,  -2.20693693e-01,  -7.44585931e-01,
                         -7.15466976e-01,  -1.15428068e-01,   2.07089067e-01,
                         -2.38307938e-01,  -5.95759749e-01,  -2.08346173e-01,
                         -1.33119226e-01,  -7.59274900e-01,  -7.57613957e-01,
                         -9.12910625e-02,  -1.66554525e-01,  -6.35974646e-01,
                         -2.19522551e-01,   2.59471416e-01,  -2.57706136e-01,
                         -6.31124258e-01,  -2.01739177e-01,  -1.40701726e-01,
                         -6.97505891e-01,  -8.18520069e-01,  -2.35389814e-01,
                          2.28787228e-01,  -7.23683238e-02,  -5.91802299e-01,
                         -4.34654742e-01,   3.59353870e-02,   7.23838210e-02,
                         -3.50999944e-02,   2.22893786e-02,  -1.76889766e-02,
                         -4.37827185e-02,   4.99153510e-02,  -1.95688024e-01,
                         -7.18589723e-01,  -7.75485098e-01,  -2.50539690e-01,
                          1.64525673e-01,  -3.62884291e-02,  -5.88064432e-01,
                         -8.29808176e-01,  -5.38878322e-01,  -1.14637814e-01,
                          7.45790303e-02,   1.00510240e-01,  -6.25995323e-02,
                         -6.06510043e-01,  -8.88944566e-01,  -3.62389326e-01,
                         -8.83231685e-02,  -5.47104836e-01,  -4.95309532e-01,
                          1.20634235e-01,   3.86893265e-02,  -5.89386582e-01,
                         -5.48919618e-01,   9.26620066e-02,   4.43939008e-02,
                         -5.81601799e-01,  -4.46885049e-01,  -9.58906338e-02,
                         -4.97616827e-01,  -5.24563968e-01,   1.10586531e-01,
                          1.82366595e-02,  -6.15713239e-01,  -5.16441882e-01,
                          8.36921483e-02,   3.44195329e-02,  -5.41593671e-01,
                         -5.24827778e-01,  -4.19839732e-02,   4.67370935e-02,
                         -4.97981086e-02,  -1.19478023e-02,  -3.23549509e-02,
                         -4.58755493e-02,  -1.72703210e-02,  -2.77589858e-02,
                         -1.10481670e-02,  -1.08859912e-02,  -4.78885472e-02,
                         -4.35961634e-02,  -2.26479154e-02,  -2.46106312e-02,
                         -4.64752987e-02,  -5.08583039e-02,  -2.26496551e-02,
                         -5.24670351e-03,  -5.61848329e-03,  -2.92074960e-02,
                         -5.88765144e-02,  -4.75483686e-02,  -2.91509815e-02,
                         -2.48688869e-02,  -3.13263126e-02,  -5.54890372e-02,
                         -4.16321456e-02,  -1.99572081e-04,  -3.78918462e-03,
                         -4.31431122e-02,  -7.53806084e-02,  -5.71921840e-02,
                         -5.27728070e-03,   1.90733664e-03,  -3.86728793e-02,
                         -6.37230277e-02,  -3.88527960e-02,  -1.42791541e-02,
                         -3.26997042e-02,  -4.00361419e-02,  -2.18781140e-02,
                         -1.67004280e-02,  -4.26035710e-02,  -7.05612525e-02,
                         -3.75729427e-02,  -1.13863247e-02,  -2.39869673e-02,
                         -1.67704578e-02,  -5.78133091e-02,  -2.49607190e-02,
                          3.68107371e-02,  -2.99324006e-01,  -5.96221983e-01,
                         -2.60161787e-01,   5.47550358e-02,  -2.70094965e-02,
                         -5.38839214e-02,  -1.93449110e-02,  -5.31595610e-02,
                         -3.70540842e-02,   7.30494910e-04,  -4.61969376e-02,
                         -7.56077766e-02,   8.06207955e-02,  -1.83497119e-04,
                         -5.11464119e-01,  -5.22690892e-01,  -1.06462635e-01,
                         -3.99803519e-01,  -8.63537550e-01,  -6.96511805e-01,
                         -6.42567515e-01,  -8.07968259e-01,  -4.91163582e-01,
                         -5.01356600e-03,   5.45847267e-02,  -7.59605095e-02,
                         -1.44312093e-02,  -4.59566787e-02,  -5.08126080e-01,
                         -8.44147503e-01,  -5.43996751e-01,  -1.26808524e-01,
                          2.84806974e-02,   7.02371746e-02,  -1.93504527e-01,
                         -5.74639201e-01,  -3.84226739e-01,   3.02597936e-02,
                          2.35833391e-03,  -8.67445245e-02,   2.21386496e-02,
                          1.77487712e-02,  -6.30469844e-02,  -4.99833003e-02,
                          2.35860925e-02,  -1.00246102e-01,  -6.07263505e-01,
                         -8.68073046e-01,  -4.29757804e-01,  -2.04238091e-02,
                         -4.53824829e-03,   9.21416190e-03,  -1.47294745e-01,
                         -6.52532578e-01,  -8.65104973e-01,  -3.97707671e-01,
                          6.54347017e-02,  -2.84671262e-02,  -8.35795626e-02,
                          1.26445249e-01,  -1.71880260e-01,  -6.38455153e-01,
                         -3.31494451e-01,  -7.42748082e-02,  -6.56830430e-01,
                         -9.14862216e-01,  -2.83711523e-01,  -3.32907140e-02,
                         -6.47083580e-01,  -9.06178117e-01,  -3.20880771e-01,
                         -1.01947792e-01,  -5.94043911e-01,  -4.60489869e-01,
                          1.88503161e-01,  -9.57592204e-02,  -6.40749872e-01,
                         -3.18770826e-01,  -1.92124754e-01,  -5.56700706e-01,
                         -3.52835894e-01,  -1.73088908e-01,  -6.91740751e-01,
                         -8.44018817e-01,  -2.70126551e-01,   1.25957906e-01,
                         -8.51424932e-02,  -5.79387605e-01,  -7.96832025e-01,
                         -6.83977902e-01,  -6.75430477e-01,  -7.39455342e-01,
                         -6.93412662e-01,  -6.98944390e-01,  -7.27279365e-01,
                         -6.99177563e-01,  -7.08495378e-01,  -7.07711577e-01,
                         -6.93767965e-01,  -7.22374678e-01,  -7.09462821e-01,
                         -6.98039353e-01,  -7.49014139e-01,  -7.33109593e-01,
                         -6.71106517e-01,  -6.87968493e-01,  -7.20654190e-01,
                         -7.17617452e-01,  -7.17477620e-01,  -7.08130598e-01,
                         -7.06787646e-01,  -7.26855397e-01,  -7.12472916e-01,
                         -6.92535400e-01,  -7.19454825e-01,  -7.37680972e-01,
                         -7.20227361e-01,  -7.02353537e-01,  -7.01157331e-01,
                         -7.19814599e-01,  -7.32274055e-01,  -7.16161728e-01,
                         -6.99539721e-01,  -7.13528454e-01,  -7.40197897e-01,
                         -7.30282903e-01,  -7.07909167e-01,  -7.28457093e-01,
                         -7.35145390e-01,  -6.99577093e-01,  -6.98572934e-01,
                         -7.29829431e-01,  -7.37792850e-01,  -7.19813883e-01,
                         -7.03023016e-01,  -7.25269079e-01,  -7.53878474e-01,
                         -7.27015197e-01,  -7.05130458e-01,  -7.29336143e-01,
                         -7.19623148e-01,  -7.06693172e-01,  -7.55947471e-01,
                         -7.32584953e-01,  -6.80453420e-01,  -7.98059583e-01,
                         -7.25147247e-01,  -2.65499175e-01,  -2.09184408e-01,
                         -7.03732908e-01,  -8.19209158e-01,  -6.36313736e-01,
                         -7.93301940e-01,  -7.40088403e-01,  -2.09627703e-01,
                         -1.98000580e-01,  -8.03854287e-01,  -8.35730195e-01,
                         -2.11084664e-01,  -1.49208978e-01,  -7.79260159e-01,
                         -8.88484657e-01,  -2.63010979e-01,  -1.11861028e-01,
                         -7.37752318e-01,  -9.23748791e-01,  -3.18958730e-01,
                         -1.17275968e-01,  -6.27773643e-01,  -8.32274020e-01,
                         -6.56695127e-01,  -7.90216625e-01,  -8.17501485e-01,
                         -2.86188960e-01,  -1.25845179e-01,  -7.27382541e-01,
                         -8.91651630e-01,  -2.98406661e-01,  -1.56243622e-01,
                         -6.50857627e-01,  -8.37216258e-01,  -7.04098046e-01,
                         -7.26634860e-01,  -7.61440217e-01,  -7.36278594e-01,
                         -7.62020409e-01,  -7.44463503e-01,  -7.36698627e-01,
                         -7.41475224e-01,  -6.81559682e-01,  -7.87037075e-01,
                         -8.35473478e-01,  -3.96766335e-01,  -1.35490090e-01,
                         -5.50679624e-01,  -8.72130990e-01,  -7.58147418e-01,
                         -6.80457234e-01,  -7.51932561e-01,  -7.98602045e-01,
                         -5.97638667e-01,  -1.09656058e-01,   7.53340349e-02,
                         -3.75940442e-01,  -7.97363222e-01,  -7.35391378e-01,
                         -6.96921885e-01,  -8.60542119e-01,  -6.19752944e-01,
                         -1.63654298e-01,  -3.51767391e-01,  -8.27085733e-01,
                         -8.03412795e-01,  -6.54246330e-01,  -7.58653581e-01,
                         -7.84170747e-01,  -7.09226549e-01,  -7.49580383e-01,
                         -7.54936457e-01,  -6.85739815e-01,  -7.93172538e-01,
                         -8.44202161e-01,  -4.59155470e-01,  -1.84020355e-01,
                         -4.73279387e-01,  -7.78393984e-01,  -8.39756727e-01,
                         -7.04376996e-01,  -2.59029448e-01,  -1.96425244e-01,
                         -8.11007738e-01,  -8.67046177e-01,  -1.80362865e-01,
                         -1.49207845e-01,  -8.24233651e-01,  -8.80862117e-01,
                         -2.52287716e-01,  -1.43701822e-01,  -6.80764437e-01,
                         -8.79907310e-01,  -6.83896601e-01,  -6.95808053e-01,
                         -8.16222429e-01,  -7.44933248e-01,  -6.55187309e-01,
                         -7.87378490e-01,  -8.01783323e-01,  -3.17596078e-01,
                         -1.18161730e-01,  -7.26047695e-01,  -9.35958147e-01,
                         -3.05889547e-01,  -1.17590711e-01,  -6.38065994e-01,
                         -8.69787931e-01,  -6.78305030e-01,  -7.00749815e-01,
                         -7.90907919e-01,  -3.69228929e-01,   9.75200534e-02,
                         -8.89472812e-02,  -5.75868368e-01,  -8.42028201e-01,
                         -6.62964702e-01,  -1.98274136e-01,  -2.48950481e-01,
                         -7.44037390e-01,  -7.78668582e-01,  -6.07159078e-01,
                         -6.95368767e-01,  -6.95335031e-01,  -6.53668284e-01,
                         -7.11022198e-01,  -6.78119361e-01,  -6.98560119e-01,
                         -6.79302931e-01,  -2.63062268e-01,   1.39594048e-01,
                         -6.88508973e-02,  -5.84049881e-01,  -7.53935456e-01,
                         -6.34994805e-01,  -6.53753459e-01,  -7.16163754e-01,
                         -6.61534667e-01,  -6.93820894e-01,  -6.62292004e-01,
                         -2.60979086e-01,   1.28762752e-01,  -4.53114100e-02,
                         -6.15407765e-01,  -8.45715702e-01,  -4.05240595e-01,
                         -3.79779637e-02,  -4.53591496e-01,  -8.89086187e-01,
                         -4.61317003e-01,  -1.01901954e-02,  -4.09123898e-01,
                         -8.15743268e-01,  -6.36016667e-01,  -6.23225629e-01,
                         -8.08004558e-01,  -4.20824111e-01,   1.21079236e-02,
                         -4.38039750e-01,  -9.60802495e-01,  -5.14368355e-01,
                          2.19917968e-02,  -3.92500162e-01,  -8.97170007e-01,
                         -5.03128171e-01,  -1.57184638e-02,  -3.51217031e-01,
                         -8.21538627e-01,  -7.30870605e-01,  -5.91788113e-01,
                         -6.78961396e-01,  -6.75389409e-01,  -6.55329525e-01,
                         -7.03641295e-01,  -6.96544468e-01,  -6.87660575e-01,
                         -6.61397099e-01,  -6.60960615e-01,  -7.03949869e-01,
                         -6.22139275e-01,  -6.94146514e-01,  -8.25899601e-01,
                         -3.78291905e-01,  -7.19109103e-02,  -4.71176088e-01,
                         -4.10718292e-01,  -9.37061906e-02,  -6.24578834e-01,
                         -8.65662098e-01,  -2.02014118e-01,  -1.43522605e-01,
                         -6.03865325e-01,  -3.31951797e-01,  -8.46084431e-02,
                         -6.48916662e-01,  -8.19161415e-01,  -2.07393602e-01,
                         -1.56040385e-01,  -6.17153645e-01,  -3.06455106e-01,
                          2.22160101e-01,  -1.84990630e-01,  -5.98112941e-01,
                         -2.28784040e-01,  -2.09283054e-01,  -5.96400023e-01,
                         -1.93065524e-01,   1.96388289e-01,  -3.64060640e-01,
                         -5.33133566e-01,  -1.20235920e-01,  -3.77532810e-01,
                         -5.58181942e-01,  -5.51782101e-02,  -2.33736664e-01,
                         -9.11437809e-01,  -6.05728507e-01,   9.97860357e-03,
                         -3.25479656e-01,  -8.28498363e-01,  -6.73086822e-01,
                         -6.21138573e-01,  -8.19962800e-01,  -4.41090494e-01,
                         -5.17255962e-02,  -4.33280319e-01,  -5.52899003e-01,
                          2.42849644e-02,   8.61554742e-02,  -5.00404537e-01,
                         -7.21144021e-01,  -5.99977672e-01,  -6.95902824e-01,
                         -7.42665708e-01,  -5.84105670e-01,  -6.94926977e-01,
                         -7.73843348e-01,  -2.93731958e-01,  -8.07911605e-02,
                         -5.91003656e-01,  -8.14183056e-01,  -5.89038551e-01,
                         -6.88635230e-01,  -7.46192515e-01,  -2.46005490e-01,
                         -7.01047629e-02,  -6.56325519e-01,  -8.28294694e-01,
                         -2.35093296e-01,  -1.01529934e-01,  -6.03366137e-01,
                         -7.73967087e-01,  -6.22346699e-01,  -6.56715631e-01,
                         -7.55664587e-01,  -7.21654952e-01,  -6.47309899e-01,
                         -6.51762962e-01,  -6.93636239e-01,  -6.57073498e-01,
                         -6.06585503e-01,  -6.43689692e-01,  -7.04951406e-01,
                         -7.02531755e-01,  -6.52916193e-01,  -6.67190254e-01,
                         -7.07710743e-01,  -6.60615027e-01,  -6.87062562e-01,
                         -7.30098426e-01,  -3.86268198e-01,   8.31244364e-02,
                         -5.15947631e-03,  -5.10076284e-01,  -7.72850752e-01,
                         -6.80265546e-01,  -5.81543446e-01,  -6.26552761e-01,
                         -6.91395402e-01,  -6.99354768e-01,  -7.18838513e-01,
                         -7.20727801e-01,  -4.59179282e-01,  -1.70784537e-02,
                          1.20964035e-01,   9.84168053e-03,   1.23025635e-02,
                          6.59548305e-03,  -2.32275911e-02,   6.87401462e-03,
                         -6.57576844e-02,  -2.12229956e-02,   9.02985036e-02,
                         -2.70367563e-01,  -5.98899901e-01,  -2.74862587e-01,
                          5.65889962e-02,   2.56433953e-02,  -3.97389522e-03,
                          6.51271418e-02,   1.01954542e-01,  -1.37850896e-01,
                         -4.81503189e-01,  -3.20687234e-01,   2.49697510e-02,
                         -3.74534763e-02,  -8.34654868e-02,   6.27622157e-02,
                          8.77177995e-03,  -8.11378434e-02,  -6.37736451e-03,
                          3.36881503e-02,   2.28328374e-03,  -3.15930583e-02,
                         -2.18975600e-02,   4.65926453e-02,   4.25134823e-02,
                         -2.11263765e-02,  -9.63387452e-03,   1.61997117e-02,
                          6.93449518e-03,  -2.36136708e-04,  -2.21194071e-03,
                          5.41123413e-02,   1.11315839e-01,   8.84497724e-03,
                         -1.36689067e-01,  -7.65146241e-02,   8.54899809e-02,
                          5.66776507e-02,  -5.33727147e-02,  -9.80848540e-03,
                         -3.55518237e-02,  -1.06261313e-01,   9.35703367e-02,
                          4.50205654e-02,  -4.79228735e-01,  -4.92284477e-01,
                          2.07840968e-02,   7.53193423e-02,  -1.30812570e-01,
                         -4.79977801e-02,   4.95411567e-02,   1.87775912e-03,
                         -3.70444008e-03,   6.00076914e-02,   3.38239074e-02,
                         -7.17169568e-02,  -5.75719737e-02,  -1.65774226e-01,
                         -4.53678280e-01,  -2.81344593e-01,   7.31680170e-02,
                         -5.68103492e-02,  -6.35288283e-02,   1.19035803e-01,
                         -2.40359142e-01,  -5.34397840e-01,  -2.23596245e-01,
                          2.26757955e-03,  -9.09197610e-03,   2.64837960e-04,
                         -2.44051404e-02,   3.74187753e-02,  -2.43334603e-02,
                         -4.80903774e-01,  -7.50595212e-01,  -6.24527335e-01,
                         -7.00951517e-01,  -7.66417086e-01,  -2.99599856e-01,
                         -6.33991808e-02,  -6.14608288e-01,  -8.25963557e-01,
                         -2.17039406e-01,  -8.09529647e-02,  -5.79133987e-01,
                         -4.28098172e-01,   1.10986769e-01,  -8.15596655e-02,
                         -5.87779582e-01,  -7.29502082e-01,  -7.61879265e-01,
                         -6.23269260e-01,  -1.79047495e-01,  -1.52645096e-01,
                         -6.79535508e-01,  -6.97555840e-01,  -1.30814075e-01,
                         -1.45146236e-01,  -7.09387124e-01,  -8.17298770e-01,
                         -6.34598732e-01,  -6.95057869e-01,  -5.46243727e-01,
                         -1.38788640e-01,  -2.84275115e-01,  -8.12953949e-01,
                         -6.86134040e-01,  -1.13171712e-01,  -1.97273508e-01,
                         -7.02679932e-01,  -7.08935440e-01,  -6.25431001e-01,
                         -8.40833426e-01,  -5.64789414e-01,  -7.10799918e-02,
                         -3.57004732e-01,  -5.93836486e-01,  -1.50494039e-01,
                         -2.73060739e-01,  -8.92215371e-01,  -6.02747560e-01,
                          9.60109476e-03,  -2.72785485e-01,  -7.83543110e-01,
                         -7.18894124e-01,  -5.78216493e-01,  -7.37180889e-01,
                         -6.45572960e-01,  -7.44851604e-02,   1.12868376e-01,
                         -4.38748091e-01,  -6.45581782e-01,  -7.38954619e-02,
                          2.11297676e-01,  -2.51687676e-01,  -7.39902556e-01,
                         -7.40067899e-01,  -3.31918597e-01,   6.81537837e-02,
                         -5.09055294e-02,  -5.04203856e-01,  -4.51429486e-01,
                          7.92818889e-02,   6.21115118e-02,  -4.93858367e-01,
                         -4.85683441e-01,   2.22281013e-02,   4.94909212e-02,
                         -3.88088375e-01,  -7.19129086e-01,  -6.90104723e-01,
                         -2.41980284e-01,   8.18189606e-02,  -2.42252916e-01,
                         -5.62609792e-01,  -3.13106626e-01,   3.91658256e-03,
                          6.91080615e-02,  -3.06264162e-02,  -3.55794847e-01,
                         -6.64402425e-01,  -7.00091541e-01,  -7.14925706e-01,
                         -7.58786142e-01,  -6.77269399e-01,  -6.89788640e-01,
                         -7.29125142e-01,  -3.86464030e-01,   1.46793546e-02,
                         -2.60007735e-02,  -1.03604540e-01,   8.31577405e-02,
                          2.30708742e-03,  -4.78965253e-01,  -7.75221169e-01,
                         -7.14358449e-01,  -6.48887634e-01,  -7.01818824e-01,
                         -6.88398778e-01,  -6.26036108e-01,  -7.54036009e-01,
                         -8.03990364e-01,  -3.74488890e-01,  -1.30748615e-01,
                         -5.11571348e-01,  -4.58667904e-01,   1.37589961e-01,
                         -4.27753069e-02,  -6.18842363e-01,  -3.56292129e-01,
                          8.56563821e-02,  -1.38173839e-02,  -9.67126116e-02,
                         -2.28144929e-01,  -7.03531623e-01,  -7.45700300e-01,
                         -1.81887329e-01,  -9.55181867e-02,  -6.34215117e-01,
                         -8.38990211e-01,  -6.97065175e-01,  -7.45827496e-01,
                         -6.10099196e-01,  -1.77895665e-01,  -2.22492650e-01,
                         -6.54421270e-01,  -7.25578725e-01,  -6.43723607e-01,
                         -7.68899918e-01,  -6.42841220e-01,  -1.39127254e-01,
                          8.02763253e-02,  -8.38777423e-02,  -2.38583330e-02,
                          5.71241193e-02,  -3.68159860e-01,  -5.93991399e-01,
                         -1.35093838e-01,   1.47684962e-01,  -8.17825366e-03,
                         -5.93181998e-02,  -2.06351411e-02,   1.31275989e-02,
                          6.34560436e-02,   4.41426557e-04,  -2.85772923e-02,
                         -2.09205039e-02,  -8.77162889e-02,   3.22922245e-02,
                          4.95409667e-02,  -4.22061771e-01,  -6.34266496e-01,
                         -2.00578496e-01,   1.30795583e-01,   4.86839041e-02,
                         -6.97739869e-02,   1.06920470e-02,   7.37846270e-02,
                         -2.19710454e-01,  -5.16274393e-01,  -2.98869431e-01,
                          2.24277414e-02,  -3.15770085e-05,  -4.30341922e-02,
                          8.17652196e-02,   5.81634417e-02,  -1.34624243e-01,
                         -6.65067807e-02,   1.16169572e-01,  -2.06733763e-01,
                         -6.04686975e-01,  -3.19265842e-01,   7.60523155e-02,
                          1.99692603e-02,  -3.78819518e-02,   2.26526782e-02,
                         -2.21072743e-03,   1.99660822e-03,  -6.20175339e-03,
                         -6.00794181e-02,  -1.34223059e-03,   4.92565036e-02,
                         -1.93664450e-02,  -5.27329072e-02,  -9.90623888e-03,
                          4.69011925e-02,   6.14740737e-02,  -2.16601864e-02,
                         -9.51281115e-02,  -3.79103720e-02,   4.93487194e-02,
                          6.53649345e-02,   5.19703627e-02,  -5.98199405e-02,
                         -3.88224721e-01,  -6.81947947e-01,  -6.85286999e-01,
                         -6.96640491e-01,  -8.04405093e-01,  -5.36480606e-01,
                         -2.70918701e-02,   5.19640706e-02,  -3.07915330e-01,
                         -6.76619351e-01,  -7.31224358e-01,  -3.22368681e-01,
                          7.55385906e-02,  -4.11065016e-03,  -5.08083366e-02,
                          1.45429730e-01,  -1.10144086e-01,  -5.80479920e-01,
                         -3.71076286e-01,   5.92495874e-02,  -1.56155322e-02,
                         -6.03086688e-02,   8.86409730e-02,  -2.61222810e-01,
                         -6.60968244e-01,  -2.26350680e-01,   2.09723637e-01,
                         -2.60829896e-01,  -6.64091170e-01,  -2.46045753e-01,
                          1.27683908e-01,  -1.40015325e-02,  -8.55390355e-02,
                          4.63984981e-02,   4.76421006e-02,  -1.18771112e-02,
                         -7.69924023e-04,  -2.25459374e-02,  -1.08575812e-02,
                          8.64509940e-02,   5.79454824e-02,  -5.80710359e-02,
                         -4.47278023e-02,  -1.24480249e-02,  -2.62341904e-03,
                          3.04450206e-02,  -1.82546556e-01,  -4.74049807e-01,
                         -2.96345741e-01,   3.40062007e-02,  -8.13656673e-03,
                         -1.05513982e-01,   6.04711473e-03,   6.65991083e-02,
                         -3.29030827e-02,  -6.90523311e-02,   3.64658050e-02,
                         -1.03333235e-01,  -4.73465860e-01,  -3.45108569e-01,
                          7.41325319e-02,   9.63760354e-03,  -4.77026254e-02,
                          1.37431607e-01,  -2.19875768e-01,  -6.15043521e-01,
                         -2.61997670e-01,  -1.50794774e-01,  -6.94392025e-01,
                         -7.46874511e-01,  -2.54810035e-01,  -2.03168347e-01,
                         -5.36792934e-01,  -6.77900195e-01,  -6.92254066e-01,
                         -7.26687491e-01,  -6.65969610e-01,  -6.08259022e-01,
                         -6.67472482e-01,  -6.93417668e-01,  -6.63563728e-01,
                         -6.72728002e-01,  -6.79300964e-01,  -6.77654445e-01,
                         -6.67209744e-01,  -6.25101626e-01,  -6.65864110e-01,
                         -7.68248141e-01,  -7.39401519e-01,  -6.22734249e-01,
                         -5.89535713e-01,  -6.47179127e-01,  -6.91975951e-01,
                         -6.68254137e-01,  -6.67752385e-01,  -7.23122478e-01,
                         -7.11939037e-01,  -6.60164297e-01,  -6.57975912e-01,
                         -6.51483357e-01,  -6.49895966e-01,  -6.81126595e-01,
                         -6.79224908e-01,  -6.72955871e-01,  -7.06486344e-01,
                         -7.17549324e-01,  -6.78645253e-01,  -6.26616657e-01,
                         -6.25772774e-01,  -6.87994480e-01,  -7.07620561e-01,
                         -6.57193482e-01,  -6.36628568e-01,  -6.66900873e-01,
                         -6.87896013e-01,  -6.63447917e-01,  -6.30583048e-01,
                         -6.60017908e-01,  -6.91178322e-01,  -6.42141640e-01,
                         -6.31788313e-01,  -7.16567397e-01,  -7.25998044e-01,
                         -6.39721990e-01,  -6.33658230e-01,  -7.01818109e-01,
                         -7.15214670e-01,  -6.93361402e-01,  -6.95897758e-01,
                         -6.87665761e-01,  -6.35952771e-01,  -6.00191653e-01,
                         -6.53148770e-01,  -7.00262249e-01,  -6.41744852e-01,
                         -6.43081605e-01,  -7.57385552e-01,  -7.49787927e-01,
                         -6.36283219e-01,  -6.13829851e-01,  -6.52080834e-01,
                         -6.89401507e-01,  -6.94032311e-01,  -6.34321272e-01,
                         -6.10175550e-01,  -6.46048844e-01,  -6.83508635e-01,
                         -7.13760078e-01,  -6.78907573e-01,  -6.78688109e-01,
                         -7.68381119e-01,  -7.04361320e-01,  -6.17147744e-01,
                         -6.99976802e-01,  -6.51976943e-01,  -6.16563618e-01,
                         -7.35848486e-01,  -4.76358861e-01,  -1.74021825e-01,
                         -4.01610106e-01,  -4.17141199e-01,  -1.37575641e-01,
                         -4.07536775e-01,  -7.82146335e-01,  -6.64341211e-01,
                         -5.84816694e-01,  -7.18682826e-01,  -7.37231374e-01,
                         -6.94135249e-01,  -7.29444742e-01,  -6.74362123e-01,
                         -3.24223846e-01,  -8.94417763e-02,  -4.51383233e-01,
                         -8.04357231e-01,  -6.56826377e-01,  -5.88829160e-01,
                         -7.01774478e-01,  -6.70105636e-01,  -7.06912279e-01,
                         -6.11812174e-01,  -1.87725186e-01,  -2.07280502e-01,
                         -6.82360530e-01,  -7.05732703e-01,  -5.79961836e-01,
                         -8.19151103e-01,  -6.42914951e-01,  -5.79906516e-02,
                         -1.95178077e-01,  -6.10336781e-01,  -2.27786809e-01,
                          1.07430868e-01,  -3.33289802e-01,  -4.78916645e-01,
                         -8.29710439e-02,  -2.60793895e-01,  -8.56735528e-01,
                         -7.07659602e-01,  -6.50965795e-02,  -1.49098039e-01,
                         -7.71217525e-01,  -7.11362302e-01,  -1.57132834e-01,
                         -1.81712046e-01,  -6.23374641e-01,  -8.47206295e-01,
                         -7.93237269e-01,  -3.92164737e-01,  -3.81274670e-02,
                         -4.11084414e-01,  -8.53820503e-01,  -4.73592907e-01,
                         -3.78741771e-02,  -3.41659993e-01,  -7.12172925e-01,
                         -6.45007432e-01,  -6.47145927e-01,  -7.39505947e-01,
                         -3.82605493e-01,  -8.00196081e-02,  -5.44817746e-01,
                         -8.99120867e-01,  -3.96233737e-01,  -4.71195690e-02,
                         -4.36357349e-01,  -7.50042796e-01,  -6.51809812e-01,
                         -5.69254160e-01,  -7.09184885e-01,  -8.49423349e-01,
                         -5.54874837e-01,  -1.15887754e-01,  -3.04272741e-01,
                         -5.05393088e-01,   3.70900072e-02,   1.56422317e-01,
                         -5.54571867e-01,  -5.95221639e-01,  -8.16994011e-02,
                         -3.21593106e-01,  -7.38571823e-01,  -6.12963140e-01,
                         -6.65171802e-01,  -8.41962934e-01,  -3.88513148e-01,
                          3.68398875e-02,  -4.57018405e-01,  -9.38729703e-01,
                         -4.38766420e-01,  -2.23961975e-02,  -3.97509575e-01,
                         -4.03702915e-01,  -8.57116431e-02,  -5.71053803e-01,
                         -8.99752438e-01,  -2.82919616e-01,  -1.24772772e-01,
                         -5.09355724e-01,  -3.15877795e-01,  -1.94230661e-01,
                         -4.99792606e-01,  -2.10585520e-01,   2.60757387e-01,
                         -1.45526931e-01,  -7.50943065e-01,  -7.01300442e-01,
                         -5.11363089e-01,  -6.77666068e-01,  -7.12347031e-01,
                         -3.00019056e-01,  -1.19021155e-01,  -5.49619019e-01,
                         -8.20069432e-01,  -4.17057514e-01,   8.24441090e-02,
                          5.27872629e-02,  -4.00502414e-01,  -7.28082478e-01,
                         -6.94446862e-01,  -6.30669832e-01,  -7.10291803e-01,
                         -7.05598652e-01,  -5.97152531e-01,  -5.88919222e-01,
                         -6.89374328e-01,  -7.16262698e-01,  -6.21204257e-01,
                         -6.15312397e-01,  -7.07328856e-01,  -6.87658489e-01,
                         -6.97772086e-01,  -7.02994585e-01,  -3.27265531e-01,
                         -5.93323335e-02,  -4.75176334e-01,  -8.29039097e-01,
                         -6.69285953e-01,  -6.08963490e-01,  -6.75496757e-01,
                         -6.40546918e-01,  -7.45480120e-01,  -6.48952007e-01,
                         -1.54962942e-01,  -1.49550363e-01,  -6.66769326e-01,
                         -7.34659195e-01,  -5.97405434e-01,  -8.00116122e-01,
                         -6.61777079e-01,  -1.42164350e-01,  -2.16146961e-01,
                         -6.55224979e-01,  -6.61634982e-01,  -5.79106212e-01,
                         -7.32896090e-01,  -7.34434247e-01,  -5.97329795e-01,
                         -6.26115501e-01,  -7.25897253e-01,  -7.20016181e-01,
                         -6.52480900e-01,  -6.49819195e-01,  -7.02539027e-01,
                         -6.91066980e-01,  -6.52725220e-01,  -6.57514751e-01,
                         -6.69701815e-01,  -6.89378619e-01,  -6.50323033e-01,
                         -6.08059764e-01,  -7.49231935e-01,  -7.08914459e-01,
                         -2.41146207e-01,  -1.12627782e-01,  -5.72932303e-01,
                         -7.68057764e-01,  -5.92978477e-01,  -6.46921694e-01,
                         -8.08651924e-01,  -7.53849387e-01,  -6.33263409e-01,
                         -5.82272172e-01,  -6.06582940e-01,  -6.87506020e-01,
                         -6.99960113e-01,  -6.48095369e-01,  -6.65373683e-01,
                         -7.08012402e-01,  -6.97880507e-01,  -6.87632322e-01,
                         -6.80776238e-01,  -6.42209888e-01,  -6.14935577e-01,
                         -6.47781968e-01,  -7.11835921e-01,  -7.16296256e-01,
                         -6.63635254e-01,  -6.57174051e-01,  -6.66049719e-01,
                         -6.35793686e-01,  -6.46136940e-01,  -6.77595973e-01,
                         -6.93345726e-01,  -7.45892167e-01,  -7.18851030e-01,
                         -5.96794426e-01,  -6.18950844e-01,  -7.23759413e-01,
                         -7.05438018e-01,  -6.70519114e-01,  -6.72289968e-01,
                         -6.27111852e-01,  -6.24748886e-01,  -7.12069869e-01,
                         -7.40921199e-01,  -6.60552502e-01,  -6.14355147e-01,
                         -6.60408497e-01,  -6.81957483e-01,  -6.80292130e-01,
                         -7.24395573e-01,  -7.10700512e-01,  -6.35435402e-01,
                         -6.40810490e-01,  -6.89418495e-01,  -6.96175456e-01,
                         -6.81970716e-01,  -6.75784945e-01,  -6.97280586e-01,
                         -6.94094658e-01,  -6.47058606e-01,  -6.49292648e-01,
                         -6.78496778e-01,  -6.84237659e-01,  -6.94985330e-01,
                         -6.65759087e-01,  -6.52626753e-01,  -7.34945476e-01,
                         -7.37558603e-01,  -6.17537200e-01,  -5.80646753e-01,
                         -6.49618149e-01,  -6.98761642e-01,  -6.82611585e-01,
                         -6.68694854e-01,  -7.33012378e-01,  -7.75063276e-01,
                         -6.89200699e-01,  -5.77673733e-01,  -5.79936028e-01,
                         -7.03731596e-01,  -7.78230727e-01,  -6.96741402e-01,
                         -6.53705180e-01,  -7.30736136e-01,  -7.31014073e-01,
                         -6.24170184e-01,  -5.70001245e-01,  -6.55598700e-01,
                         -7.75290072e-01,  -7.43479967e-01,  -6.40369773e-01,
                         -6.30703270e-01,  -6.45663798e-01,  -6.57376945e-01,
                         -6.90113664e-01,  -6.98226929e-01,  -7.09433615e-01,
                         -6.94112122e-01,  -6.58315122e-01,  -7.21795976e-01,
                         -7.46268809e-01,  -6.34594798e-01,  -6.05976641e-01,
                         -6.81066632e-01,  -7.13456511e-01,  -6.80713117e-01,
                         -6.38349831e-01,  -6.75824165e-01,  -6.74352229e-01,
                         -6.05360866e-01,  -7.23188996e-01,  -7.10246563e-01,
                         -2.88633138e-01,  -1.97658449e-01,  -6.05511785e-01,
                         -7.58633614e-01,  -6.68622315e-01,  -5.45796692e-01,
                         -1.30233601e-01,   1.57213107e-01,  -2.18998715e-01,
                         -6.89284921e-01,  -7.05178022e-01,  -6.83107078e-01,
                         -8.21615338e-01,  -5.75477421e-01,  -9.01680812e-02,
                         -2.50685185e-01,  -7.70390928e-01,  -7.29914308e-01,
                         -5.59978247e-01,  -7.68318415e-01,  -6.16467834e-01,
                         -1.21131003e-01,  -3.22280169e-01,  -8.43503952e-01,
                         -5.80277026e-01,  -8.16968381e-02,  -2.82675326e-01,
                         -7.02763379e-01,  -7.77619183e-01,  -6.94030941e-01,
                         -4.53208745e-01,  -3.86018306e-02,   7.23998994e-02,
                         -3.60095799e-01,  -8.03801537e-01,  -6.22581184e-01,
                         -1.10081591e-01,  -2.04964146e-01,  -8.29441309e-01,
                         -8.24363053e-01,  -1.23735026e-01,  -7.02715814e-02,
                         -7.92726636e-01,  -8.22569907e-01,  -1.52786881e-01,
                         -2.01276898e-01,  -6.16335094e-01,  -2.78251410e-01,
                          1.10758908e-01,  -5.61549738e-02,  -4.83453423e-02,
                          9.37358215e-02,  -2.91333497e-01,  -7.92657137e-01,
                         -6.48481667e-01,  -1.30660474e-01,  -1.70476362e-01,
                         -7.72683442e-01,  -8.39557588e-01,  -2.26164609e-01,
                         -1.26655951e-01,  -7.21824169e-01,  -8.12916219e-01,
                         -2.34565914e-01,  -1.72283292e-01,  -6.42037690e-01,
                         -4.11629409e-01,   2.30496868e-01,  -3.11017241e-02,
                         -6.78692818e-01,  -4.53514934e-01,   9.95685831e-02,
                         -6.78585693e-02,  -5.50335467e-01,  -6.62190199e-01,
                         -6.97642505e-01,  -7.50083148e-01,  -3.43520761e-01,
                          1.17633730e-01,   1.20617086e-02,  -1.04837537e-01,
                          5.30252755e-02,  -1.54303923e-01,  -6.92730546e-01,
                         -8.52026582e-01,  -3.77399355e-01,   1.65077388e-01,
                         -5.11052459e-02,  -6.48650289e-01,  -5.15264511e-01,
                          5.51599897e-02,   5.70442863e-02,  -4.52782750e-01,
                         -8.26341450e-01,  -6.52139485e-01,  -1.42882094e-01,
                          5.54373972e-02,  -3.23852710e-02,   3.42113003e-02,
                          8.57076943e-02,  -5.69093488e-02,  -1.43446371e-01,
                         -1.05149649e-01,  -4.64219078e-02,   1.84380859e-02,
                          5.58139607e-02,   1.59265511e-02,  -7.17513412e-02,
                         -9.21610147e-02,  -5.06576756e-03,   4.49802950e-02,
                         -3.48316282e-02,  -1.19592294e-01,  -6.86684623e-02,
                          4.03717160e-02,   1.97721384e-02,  -8.32253322e-02,
                         -6.17461801e-02,   3.94868515e-02,   1.19705275e-02,
                         -1.08705513e-01,  -9.68521386e-02,   2.80106701e-02,
                          1.59394685e-02,  -9.11316574e-02,  -5.36375754e-02,
                          4.51233536e-02,   3.66417989e-02,  -3.18562686e-02,
                         -1.09557353e-01,  -1.19636878e-01,  -9.05212015e-03,
                          5.96085377e-02,   5.20500494e-03,  -5.31092584e-02,
                         -6.38064370e-02,  -3.58619764e-02,  -1.20316148e-02,
                         -3.96818742e-02,  -3.42743322e-02,   1.50957638e-02,
                         -1.22954417e-02,  -4.08072993e-02,   2.73309946e-02,
                          1.82064977e-02,  -1.19967625e-01,  -1.30998686e-01,
                          3.60959917e-02,   1.07554220e-01,  -2.00716755e-03,
                         -8.60952362e-02,  -6.36751875e-02,  -5.75848557e-02,
                         -8.41902420e-02,  -3.58738378e-02,   4.19390164e-02,
                          1.91603806e-02,  -3.64069641e-02,  -2.31848247e-02,
                         -1.33339781e-02,  -3.95308174e-02,  -5.48136756e-02,
                         -6.20351583e-02,  -3.68298441e-02,   1.09801935e-02,
                          5.24105318e-03,  -3.05354483e-02,  -5.73494397e-02,
                         -6.87701181e-02,  -1.78680923e-02,   2.12716702e-02,
                         -2.52157617e-02,  -2.29242556e-02,   3.61506194e-02,
                         -9.02600307e-03,  -9.72080454e-02,  -7.22417459e-02,
                          5.84746432e-03,   1.20793562e-03,  -5.67131601e-02,
                         -4.78161946e-02,  -1.51976288e-04,  -9.26106144e-03,
                         -2.28435099e-02,   8.29749648e-03,   4.91397083e-03,
                         -6.23542555e-02,  -9.48069692e-02,  -1.64376236e-02,
                          6.06370084e-02,   5.52863861e-03,  -5.64348958e-02,
                         -2.54977196e-02,  -3.69690247e-02,  -7.73270503e-02,
                         -1.77600943e-02,   3.84014696e-02,   2.67615984e-03,
                         -1.68387685e-02,   1.98670034e-03,  -2.39355396e-02,
                         -6.60488084e-02,  -3.23239043e-02,   3.14391740e-02,
                         -2.73334887e-03,  -8.36551860e-02,  -5.12393713e-02,
                          4.76786420e-02,   4.27634455e-02,  -4.32149023e-02,
                         -5.94188161e-02,  -2.08146069e-02,  -4.06515822e-02,
                         -4.98410538e-02,   3.48444469e-02,   5.49002402e-02,
                         -5.78140281e-02,  -9.35853496e-02,   1.73626915e-02,
                          8.80519971e-02,   2.42630038e-02,  -5.25938943e-02,
                         -3.98706160e-02,  -2.87393797e-02,  -4.94277105e-02,
                          1.13553321e-02,   3.12915677e-03,  -1.44606799e-01,
                         -5.18356748e-02,   8.73394608e-02,  -2.72600710e-01,
                         -5.21081328e-01,  -1.92965895e-01,  -2.32961699e-01,
                         -7.64792621e-01,  -7.48122573e-01,  -2.17539400e-01,
                          1.19605348e-01,  -1.66203901e-02,  -6.10892236e-01,
                         -9.12018538e-01,  -4.33592141e-01,  -1.30200878e-01,
                         -4.71235365e-01,  -7.46594667e-01,  -7.33231246e-01,
                         -5.15098989e-01,  -2.05083594e-01,  -3.42373788e-01,
                         -7.57305980e-01,  -7.54156709e-01,  -6.05442941e-01,
                         -7.00174510e-01,  -7.32743204e-01,  -6.61006093e-01,
                         -6.92256153e-01,  -7.31919110e-01,  -6.91023707e-01,
                         -6.61490500e-01,  -6.85047150e-01,  -5.59849858e-01,
                         -1.59820348e-01,   5.49249984e-02,  -2.83946812e-01,
                         -6.68096483e-01,  -6.68624759e-01,  -6.73668981e-01,
                         -8.25922310e-01,  -6.02001607e-01,  -1.34705275e-01,
                         -2.95277357e-01,  -8.34495068e-01,  -6.29899561e-01,
                         -6.01016060e-02,  -3.03447604e-01,  -8.49816442e-01,
                         -7.37007141e-01,  -5.79505861e-01,  -8.26250613e-01,
                         -6.34250939e-01,  -7.36963749e-02,  -2.33735815e-01,
                         -7.71377385e-01,  -7.32261300e-01,  -6.29935205e-01,
                         -8.22838902e-01,  -5.38500667e-01,  -6.27542660e-02,
                         -3.96214277e-01,  -9.28738475e-01,  -5.96936226e-01,
                         -1.94487628e-02,  -2.86159754e-01,  -9.03411269e-01,
                         -6.90522373e-01,  -7.80802891e-02,  -2.54759163e-01,
                         -6.42258644e-01,  -2.28345275e-01,   1.65527776e-01,
                         -2.48798504e-01,  -7.33621359e-01,  -7.55578220e-01,
                         -6.32092118e-01,  -6.35690451e-01,  -7.28329003e-01,
                         -7.23394275e-01,  -6.86089218e-01,  -7.54538357e-01,
                         -7.22359061e-01,  -6.84491396e-01,  -7.82364964e-01,
                         -5.30038774e-01,  -1.15637876e-01,  -3.29854965e-01,
                         -7.72865236e-01,  -7.54289508e-01,  -5.99212170e-01,
                         -6.32717788e-01,  -7.15160370e-01,  -7.30058491e-01,
                         -6.61920249e-01,  -6.10443115e-01,  -6.64557099e-01,
                         -7.52702832e-01,  -7.62206018e-01,  -7.32387543e-01,
                         -7.78166473e-01,  -6.65548742e-01,  -2.66702324e-01,
                         -1.97068140e-01,  -6.14183307e-01,  -7.76172042e-01,
                         -6.47930264e-01,  -7.33569384e-01,  -7.33438969e-01,
                         -2.64600217e-01,   1.57738715e-01,  -7.89446533e-02,
                         -6.17588937e-01,  -7.44928956e-01,  -6.32891953e-01,
                         -5.78530788e-01,  -2.26936385e-01,   1.24122836e-01,
                         -1.77200705e-01,  -6.45312905e-01,  -7.38837063e-01,
                         -6.68946803e-01,  -6.15148067e-01,  -7.46978939e-01,
                         -8.43038380e-01,  -4.17447954e-01,  -9.03781950e-02,
                         -4.81302172e-01,  -8.44017029e-01,  -7.15465724e-01,
                         -5.74976504e-01,  -6.47563398e-01,  -6.97838783e-01,
                         -6.41503513e-01,  -7.28126228e-01,  -7.55596220e-01,
                         -2.90958464e-01,  -2.78946180e-02,  -5.10040522e-01,
                         -8.33038270e-01,  -6.65677130e-01,  -6.42470062e-01,
                         -7.14150965e-01,  -6.53819859e-01,  -6.80264771e-01,
                         -6.75708234e-01,  -3.23158294e-01,   7.36193135e-02,
                         -5.92659861e-02,  -5.36745965e-01,  -7.40066350e-01,
                         -6.85324073e-01,  -6.81405425e-01,  -6.78208530e-01,
                         -6.37563765e-01,  -6.60544455e-01,  -6.81909680e-01,
                         -6.45271361e-01,  -6.67885780e-01,  -7.18917847e-01,
                         -6.68688297e-01,  -6.40147924e-01,  -6.91535354e-01,
                         -6.76576793e-01,  -6.60230756e-01,  -7.00060785e-01,
                         -6.57467604e-01,  -5.95716715e-01,  -6.58645928e-01,
                         -7.35356629e-01,  -6.78885818e-01,  -5.96097946e-01,
                         -6.43242896e-01,  -6.97324693e-01,  -6.57519221e-01,
                         -6.67667508e-01,  -7.01154888e-01,  -6.32060230e-01,
                         -5.93064070e-01,  -6.71832681e-01,  -7.00861156e-01,
                         -6.24634743e-01,  -6.11639082e-01,  -6.89191222e-01,
                         -7.23459303e-01,  -6.84704065e-01,  -6.29097164e-01,
                         -6.54067099e-01,  -6.93646371e-01,  -6.04151666e-01,
                         -6.49934232e-01,  -7.69930780e-01,  -4.17109549e-01,
                         -7.16779158e-02,  -3.95993769e-01,  -7.32416213e-01,
                         -6.65565550e-01,  -6.17654622e-01,  -6.31915271e-01,
                         -6.29759431e-01,  -6.82962060e-01,  -6.89990222e-01,
                         -6.74914062e-01,  -6.79576159e-01,  -5.91102958e-01,
                         -5.84593415e-01,  -7.22832859e-01,  -5.05484164e-01,
                         -8.37180242e-02,  -3.01997930e-01,  -7.64213204e-01,
                         -6.58527315e-01,  -5.89517951e-01,  -7.72089422e-01,
                         -4.00522858e-01,   2.87708435e-02,  -4.20569330e-01,
                         -8.91557992e-01,  -4.56863731e-01,  -1.03433512e-03,
                         -3.12639862e-01,  -7.24409223e-01,  -7.70527661e-01,
                         -6.02951407e-01,  -2.18942448e-01,  -1.36107236e-01,
                         -6.46291375e-01,  -7.36838996e-01,  -1.70935601e-01,
                         -9.71487835e-02,  -6.09911680e-01,  -7.56745160e-01,
                         -5.78719199e-01,  -6.71107590e-01,  -6.26548946e-01,
                         -1.65513769e-01,  -1.63521528e-01,  -6.56680942e-01,
                         -7.28212953e-01,  -5.75207174e-01,  -6.58731043e-01,
                         -6.76866174e-01,  -6.10514104e-01,  -6.22860491e-01,
                         -6.32907569e-01,  -6.54885054e-01,  -6.54483914e-01,
                         -6.26195312e-01,  -6.97419107e-01,  -6.75950289e-01,
                         -2.82296121e-01,   1.65952906e-01,   7.50116035e-02,
                         -4.97730643e-01,  -8.32062006e-01,  -5.13681591e-01,
                          1.19951060e-02,   1.31515533e-01,  -1.80566218e-02,
                         -1.20824687e-02,   5.38288914e-02,   3.06121279e-02,
                          2.86790673e-02,   3.97713594e-02,   2.97719501e-02,
                          2.46796720e-02,   2.28640903e-02,   4.82674837e-02,
                          5.41319773e-02,   1.12359775e-02,   1.91942491e-02,
                          7.19184801e-02,   3.15072723e-02,  -2.95073148e-02,
                          9.17865187e-02,   7.60690421e-02,  -3.69137853e-01,
                         -5.21698952e-01,  -6.54184148e-02,   1.49992153e-01,
                         -5.51227154e-03,   2.35899556e-02,   1.08988263e-01,
                          1.59369968e-02,  -3.76323685e-02,   9.98239592e-02,
                          6.00353964e-02,  -4.03334260e-01,  -5.24353445e-01,
                         -1.47056291e-02,   1.44982278e-01,  -3.84714901e-02,
                          1.11369349e-01,   9.92321223e-03,  -5.03523946e-01,
                         -4.42559242e-01,   5.62280342e-02,   1.37839541e-01,
                          1.05003268e-02,   3.20274085e-02,   1.24065736e-02,
                          4.80625406e-03,   7.05730170e-02,   5.05860634e-02,
                          1.22764353e-02,   2.97830382e-04,   2.70954426e-02,
                          1.10757641e-01,   2.68680118e-02,  -3.15895341e-02,
                          1.40862957e-01,  -7.21645281e-02,  -5.44078887e-01,
                         -3.61520886e-01,   1.04957864e-01,   9.90421176e-02,
                         -2.89897267e-02,   5.87498359e-02,   8.88383240e-02,
                         -8.05123802e-03,   1.60944331e-02,   8.56462792e-02,
                          6.52801525e-03,   4.05103564e-02,   1.22447386e-01,
                         -2.23042011e-01,  -5.35094857e-01,  -2.17089877e-01,
                          1.31647125e-01,   6.90416843e-02,   1.14150597e-02,
                          6.05217442e-02,   1.85663477e-02,   8.70896317e-03,
                          8.80588293e-02,   6.68024346e-02,  -2.43178895e-03,
                          9.11473483e-02,   6.73161373e-02,  -3.85452300e-01,
                         -5.72152317e-01,   7.10976915e-03,   2.43866429e-01,
                         -3.53875697e-01,  -4.91549611e-01,  -1.08598866e-01,
                         -3.40394050e-01,  -5.42119801e-01,   3.71793695e-02,
                          2.15328276e-01,  -4.16695386e-01,  -5.62164187e-01,
                          3.56408134e-02,   1.83696687e-01,  -3.78475100e-01,
                         -5.51609933e-01,  -6.38395324e-02,   1.58658579e-01,
                         -2.18168478e-02,   2.03533750e-02,   1.15102872e-01,
                         -2.97772676e-01,  -8.14027965e-01,  -5.79711080e-01,
                         -5.83361238e-02,  -2.77899861e-01,  -5.63217998e-01,
                         -5.95458895e-02,   2.27534994e-01,  -2.75994003e-01,
                         -6.59169316e-01,  -6.72478557e-01,  -6.82958066e-01,
                         -4.74727094e-01,   7.69995945e-03,   1.64495319e-01,
                         -2.89809704e-01,  -7.60350168e-01,  -6.25005186e-01,
                         -1.59208357e-01,   5.58872260e-02,   7.45782405e-02,
                          4.24002931e-02,  -3.47742766e-01,  -8.33749473e-01,
                         -5.78359067e-01,   1.49812736e-02,  -2.25958005e-01,
                         -8.54937136e-01,  -6.17405176e-01,  -2.79220268e-02,
                         -2.79874593e-01,  -6.30026400e-01,  -5.63472211e-02,
                          2.78719813e-01],
                          dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri8",
    rate = 41000,
    data = numpy.array([ -2.32272316e-02,  -5.36326366e-03,   2.04394478e-02,
                          6.56702090e-03,   3.42980353e-03,  -5.27426740e-03,
                          3.49948206e-03,   2.29048841e-02,   3.16685089e-03,
                          5.06082689e-03,   7.19126081e-03,  -1.98456589e-02,
                          1.63424283e-03,   1.34453047e-02,  -1.79223213e-02,
                         -9.73435305e-03,   6.91217836e-03,   7.60733010e-03,
                          1.28714899e-02,   4.31606692e-04,  -5.89636061e-03,
                          3.10156145e-03,   5.31685958e-03,   4.37445287e-03,
                         -4.56697401e-03,   3.81285953e-03,   2.26947758e-02,
                          3.97252757e-03,  -1.17507065e-02,  -3.21511342e-03,
                         -6.24198234e-03,  -1.80980074e-03,   9.56927054e-03,
                          2.95281759e-03,  -4.25715232e-03,   3.19565157e-03,
                          1.29527980e-02,   4.14239895e-03,  -4.84908372e-03,
                          6.35058479e-03,   8.54139123e-03,   6.73125405e-03,
                          1.02663925e-02,  -3.63100646e-03,  -9.01663117e-03,
                          5.73219173e-03,   1.75965782e-02,   1.87143181e-02,
                         -4.21883725e-03,  -1.76692531e-02,   1.22567010e-03,
                          1.07395025e-02,   1.25450259e-02,   6.19102921e-03,
                         -1.09485695e-02,  -5.07314457e-03,  -2.06926139e-03,
                         -3.33672244e-04,   1.75538100e-02,   2.67303013e-03,
                         -4.49099997e-03,   1.21997884e-02,  -9.46752355e-03,
                         -6.86832098e-03,   2.71929037e-02,   1.64590869e-02,
                         -2.85043009e-03,  -1.22271152e-02,  -1.11562600e-02,
                          6.81605376e-03,  -3.71522945e-03,  -5.75046847e-03,
                          2.05454398e-02,   1.41630908e-02,  -4.37523751e-03,
                         -9.52176098e-03,   2.22524512e-03,   2.61259396e-02,
                          1.17340311e-02,  -2.16643643e-02,  -1.27952285e-02,
                          1.86502300e-02,  -1.49878323e-01,  -6.12339079e-01,
                         -7.72258580e-01,  -3.18033695e-01,   6.37939349e-02,
                          6.73965737e-02,  -1.22153265e-02,  -4.15136293e-02,
                          8.47325251e-02,   2.46978179e-02,  -4.37956870e-01,
                         -4.98582512e-01,  -3.33935581e-02,   1.19082436e-01,
                         -2.24739332e-02,  -1.46117248e-02,   5.95441014e-02,
                         -5.36303967e-03,  -5.93690090e-02,   1.11932583e-01,
                          8.57756007e-03,  -4.64332521e-01,  -4.01962131e-01,
                         -1.41663700e-01,  -4.23673451e-01,  -4.18396592e-01,
                          1.25882104e-02,   8.25324282e-02,  -8.14044289e-03,
                         -2.17360631e-01,  -6.97585940e-01,  -7.54105210e-01,
                         -2.21861169e-01,   1.44271418e-01,  -7.05161244e-02,
                         -5.43537140e-01,  -7.42481887e-01,  -6.63318098e-01,
                         -6.07306361e-01,  -6.82110846e-01,  -7.72552788e-01,
                         -4.92817611e-01,  -8.34411904e-02,  -3.15681607e-01,
                         -7.52057374e-01,  -6.89908206e-01,  -5.92136562e-01,
                         -6.77867532e-01,  -6.71169996e-01,  -6.59946322e-01,
                         -6.55935168e-01,  -6.31398201e-01,  -6.75876200e-01,
                         -6.84451818e-01,  -6.52470410e-01,  -6.64255381e-01,
                         -6.61623240e-01,  -6.53513312e-01,  -6.50498748e-01,
                         -6.36577249e-01,  -6.53208435e-01,  -6.66893899e-01,
                         -6.67660475e-01,  -6.82387948e-01,  -6.63072288e-01,
                         -6.44862711e-01,  -6.69641435e-01,  -6.59408867e-01,
                         -6.29630685e-01,  -6.53301001e-01,  -6.75454736e-01,
                         -6.55694246e-01,  -6.45240188e-01,  -6.53478444e-01,
                         -6.61403477e-01,  -6.67205989e-01,  -6.62186086e-01,
                         -6.68997943e-01,  -6.77395880e-01,  -6.50808096e-01,
                         -6.53103828e-01,  -6.73075020e-01,  -6.37118578e-01,
                         -6.42355204e-01,  -6.89405203e-01,  -6.65301800e-01,
                         -6.51435494e-01,  -6.77443206e-01,  -6.69559002e-01,
                         -6.64226890e-01,  -6.52264655e-01,  -6.36285484e-01,
                         -6.78957462e-01,  -7.02511966e-01,  -6.56270027e-01,
                         -6.33784175e-01,  -6.72394454e-01,  -6.99706197e-01,
                         -6.77239001e-01,  -6.77342236e-01,  -6.89757705e-01,
                         -6.62797451e-01,  -6.88744009e-01,  -7.14552999e-01,
                         -6.48794293e-01,  -6.44390941e-01,  -6.95493281e-01,
                         -7.02669442e-01,  -7.09338367e-01,  -6.77117050e-01,
                         -6.75448477e-01,  -7.15313852e-01,  -6.35895193e-01,
                         -6.85062528e-01,  -8.23530316e-01,  -4.85123426e-01,
                         -1.03487156e-01,  -4.01530713e-01,  -7.91709483e-01,
                         -7.17299998e-01,  -6.12006128e-01,  -6.96454346e-01,
                         -7.20161855e-01,  -6.76580727e-01,  -6.98307097e-01,
                         -7.22405374e-01,  -7.09619761e-01,  -7.12646306e-01,
                         -6.94434524e-01,  -6.80946767e-01,  -7.25587249e-01,
                         -7.32425272e-01,  -7.01215863e-01,  -6.93963349e-01,
                         -6.86311662e-01,  -7.15103686e-01,  -7.34789252e-01,
                         -6.89930677e-01,  -6.90420508e-01,  -7.11918831e-01,
                         -7.18905389e-01,  -7.36194134e-01,  -6.61114037e-01,
                         -6.85926259e-01,  -8.53040040e-01,  -5.85946083e-01,
                         -1.21863768e-01,  -3.27942699e-01,  -7.86332130e-01,
                         -7.67180562e-01,  -6.62205040e-01,  -7.17874408e-01,
                         -6.81696296e-01,  -7.39056051e-01,  -8.07624280e-01,
                         -3.92242670e-01,  -7.39979073e-02,  -5.95780432e-01,
                         -9.54409301e-01,  -3.80056977e-01,  -9.22100544e-02,
                         -5.84380686e-01,  -5.84046721e-01,   4.40732799e-02,
                          6.11264780e-02,  -5.65738976e-01,  -8.27651501e-01,
                         -6.56525552e-01,  -7.03749776e-01,  -8.35682929e-01,
                         -4.65617865e-01,  -7.91818649e-02,  -5.00596702e-01,
                         -9.53692734e-01,  -5.00279844e-01,  -1.09428115e-01,
                         -5.03555596e-01,  -8.13376784e-01,  -7.62368441e-01,
                         -6.84746802e-01,  -3.49303961e-01,   4.75482419e-02,
                         -8.03661570e-02,  -5.91721237e-01,  -8.74866366e-01,
                         -5.81255138e-01,  -5.59720583e-02,   6.04816899e-02,
                         -3.51872802e-01,  -8.22546303e-01,  -7.50777960e-01,
                         -2.91230679e-01,  -6.93027228e-02,   1.27881961e-02,
                         -7.16155395e-02,  -5.14424741e-01,  -5.14296889e-01,
                         -1.22213893e-01,  -4.61329609e-01,  -9.68464315e-01,
                         -5.66388905e-01,  -4.83664423e-02,  -4.32533294e-01,
                         -9.57035482e-01,  -5.63022852e-01,  -1.08553655e-01,
                         -4.88826782e-01,  -6.32459521e-01,  -1.04242444e-01,
                          1.00241177e-01,  -1.15230270e-01,  -1.77237809e-01,
                          1.40134823e-02,   2.59898826e-02,  -4.45122540e-01,
                         -6.58982813e-01,  -2.06726328e-01,   6.83881864e-02,
                         -6.27430081e-02,  -1.02433152e-01,  -5.34288064e-02,
                         -6.35400191e-02,  -7.78937861e-02,  -3.28722820e-02,
                         -2.20017862e-02,  -1.02132544e-01,  -3.28871012e-02,
                          9.09457542e-03,  -4.70756710e-01,  -9.41561818e-01,
                         -5.82400441e-01,  -8.63346159e-02,  -3.99825811e-01,
                         -6.51214719e-01,  -6.17355518e-02,   1.55503273e-01,
                         -4.87175524e-01,  -6.55383527e-01,  -1.27362341e-01,
                          7.67398477e-02,  -8.67239162e-02,  -3.84861007e-02,
                          3.26787382e-02,  -3.86041969e-01,  -8.64499867e-01,
                         -6.60201907e-01,  -1.61692396e-01,   2.19838452e-02,
                          6.34778365e-02,  -8.65969956e-02,  -5.37282586e-01,
                         -5.30980706e-01,   8.01127329e-02,   1.02392241e-01,
                         -5.45302033e-01,  -5.67354262e-01,   7.65102729e-03,
                          1.10140868e-01,  -3.68342280e-01,  -7.97620535e-01,
                         -6.88078463e-01,  -1.75435990e-01,   1.45147309e-01,
                         -7.55655095e-02,  -6.77661955e-01,  -8.20341647e-01,
                         -2.50521094e-01,  -1.55959085e-01,  -5.33264816e-01,
                         -3.03375155e-01,  -1.20403014e-01,  -5.34625232e-01,
                         -7.74446547e-01,  -7.40153313e-01,  -4.71678227e-01,
                         -5.79608940e-02,  -3.20300370e-01,  -8.56073618e-01,
                         -5.22536993e-01,  -2.73934496e-03,  -3.22308958e-01,
                         -7.63733923e-01,  -6.35842383e-01,  -5.94218493e-01,
                         -7.54392028e-01,  -4.14594531e-01,  -4.72490080e-02,
                         -3.60187203e-01,  -7.30168045e-01,  -6.88565016e-01,
                         -5.81732154e-01,  -6.44274712e-01,  -7.60478497e-01,
                         -5.27581513e-01,  -9.16681215e-02,  -2.25166857e-01,
                         -6.78510904e-01,  -6.99906528e-01,  -5.91093242e-01,
                         -6.59474671e-01,  -6.47444427e-01,  -6.12748623e-01,
                         -6.37795985e-01,  -6.38857841e-01,  -6.62929177e-01,
                         -6.35074258e-01,  -5.91933250e-01,  -6.39016628e-01,
                         -6.06612623e-01,  -6.44622862e-01,  -7.69517839e-01,
                         -4.26350474e-01,  -1.85634773e-02,  -3.28511178e-01,
                         -7.31803119e-01,  -6.64339840e-01,  -5.90248823e-01,
                         -6.38948798e-01,  -6.25514567e-01,  -6.24130547e-01,
                         -6.37914479e-01,  -6.19339943e-01,  -6.04720533e-01,
                         -6.17504299e-01,  -6.44438922e-01,  -6.41853750e-01,
                         -6.23647511e-01,  -6.27850235e-01,  -6.36019409e-01,
                         -6.45912230e-01,  -6.52666330e-01,  -6.36031270e-01,
                         -6.15055859e-01,  -6.07756138e-01,  -6.19189322e-01,
                         -6.44835472e-01,  -6.44961238e-01,  -6.09877348e-01,
                         -6.05201066e-01,  -6.48283064e-01,  -6.57525122e-01,
                         -6.18705094e-01,  -6.11391842e-01,  -6.49593055e-01,
                         -6.64658487e-01,  -6.25417650e-01,  -6.02620542e-01,
                         -6.31087542e-01,  -6.37424588e-01,  -6.18192315e-01,
                         -6.12568140e-01,  -6.08081162e-01,  -6.22310996e-01,
                         -6.41801298e-01,  -6.44418776e-01,  -6.45633280e-01,
                         -6.15019917e-01,  -5.97568572e-01,  -6.32378042e-01,
                         -6.34069085e-01,  -6.31985962e-01,  -6.59335673e-01,
                         -6.40802622e-01,  -6.07445121e-01,  -6.06678367e-01,
                         -6.35690868e-01,  -6.64943695e-01,  -6.40411973e-01,
                         -6.30367517e-01,  -6.51480258e-01,  -6.30001962e-01,
                         -6.34917557e-01,  -6.62113726e-01,  -6.37861907e-01,
                         -6.24075890e-01,  -6.34047270e-01,  -6.40380800e-01,
                         -6.43790483e-01,  -6.25262201e-01,  -6.21075690e-01,
                         -6.56786561e-01,  -6.60170078e-01,  -5.91016889e-01,
                         -6.34061933e-01,  -7.60337174e-01,  -4.57616746e-01,
                         -2.77818553e-02,  -3.26654792e-01,  -7.83325672e-01,
                         -6.85287476e-01,  -5.94687641e-01,  -6.63078964e-01,
                         -6.25189185e-01,  -6.56633019e-01,  -6.95339084e-01,
                         -6.51594102e-01,  -6.42816842e-01,  -6.52823031e-01,
                         -6.60092294e-01,  -6.42283857e-01,  -7.12504745e-01,
                         -6.78461790e-01,  -1.83491811e-01,  -8.47847760e-02,
                         -7.43775368e-01,  -7.52714217e-01,  -8.51130784e-02,
                          7.31954947e-02,  -1.32191461e-02,   3.22408676e-02,
                         -2.61108037e-02,  -2.29308177e-02,   3.56727540e-02,
                          1.11645898e-02,   1.94572210e-02,   6.11249264e-03,
                         -3.63252498e-02,  -1.14152078e-02,   1.78642720e-02,
                          1.98749546e-02,   8.87970906e-03,  -3.17500415e-03,
                         -2.26445752e-03,  -3.74308485e-03,   1.55773256e-02,
                          2.53880359e-02,  -6.05948875e-03,  -1.12604415e-02,
                          3.93759226e-03,   4.26812470e-03,  -5.55730658e-03,
                         -1.79029554e-02,   8.19623377e-03,   2.50887536e-02,
                         -4.99859627e-04,   8.18966702e-03,   8.59188009e-03,
                         -1.80692878e-02,   4.91145824e-04,   9.48674511e-03,
                         -2.28508865e-03,   7.94694480e-03,   3.04782088e-03,
                          7.74473301e-05,   3.73648526e-03,  -8.76710191e-03,
                         -4.01271693e-03,   5.92163717e-03,   1.08370520e-02,
                          4.89255693e-03,  -2.48679128e-02,  -1.09511325e-02,
                          1.99187491e-02,   3.02749383e-03,   1.82476162e-03,
                          2.11315090e-03,  -1.10256644e-02,   8.80636182e-03,
                          1.51473202e-03,  -1.35558937e-02,   9.52498056e-03,
                          4.02143085e-03,   2.93327565e-03,   6.80865347e-03,
                         -2.64862347e-02,  -5.07107843e-03,   2.80667208e-02,
                         -4.76888148e-03,  -9.57530923e-03,   2.56553292e-03,
                         -6.78377738e-03,   3.01781902e-03,   8.23267549e-03,
                          1.63373016e-02,   1.49708651e-02,  -2.31802016e-02,
                         -1.44314896e-02,   1.72325522e-02,   1.92008505e-04,
                         -4.46335273e-03,   1.62344659e-03,  -1.29411521e-03,
                          9.31785069e-03,  -3.85112665e-03,  -1.39799081e-02,
                          1.06609333e-02,   1.18638743e-02,  -2.97618797e-03,
                         -1.83140917e-03,   2.03209952e-03,   3.14373686e-03,
                         -2.25210749e-03,   5.27634984e-05,   4.77607362e-03,
                          6.76442796e-05,   1.51171740e-02,   1.81653313e-02,
                         -1.34713985e-02,  -1.82876606e-02,  -4.67206817e-03,
                         -2.92517035e-03,   5.28381392e-03,   2.86061759e-03,
                         -5.68911899e-03,   3.56795918e-03,   7.08699925e-03,
                         -3.10032791e-03,  -9.56513826e-03,  -2.18404667e-03,
                          9.36841965e-03,   1.45706697e-03,  -9.84662306e-03,
                         -7.33346911e-03,  -1.18817817e-02,  -1.44224390e-02,
                          3.17383488e-03,   1.47909028e-02,   4.77711484e-03,
                         -3.29720601e-03,   1.35621731e-03,   5.02680428e-03,
                          3.78365861e-03,  -1.06106850e-03,  -4.35817847e-03,
                         -5.64476522e-03,  -1.71108302e-02,  -1.21378144e-02,
                          1.07395500e-02,  -4.43059602e-04,  -7.18981912e-03,
                          2.05829386e-02,   2.12508589e-02,   4.38617775e-03,
                         -1.20633468e-02,  -2.62848400e-02,   4.20698372e-04,
                          7.18371663e-03,  -2.40748599e-02,  -1.11359488e-02,
                          3.90893593e-03,   3.23664164e-03,   2.03576274e-02,
                          3.12331389e-03,  -1.32682892e-02,  -1.10064913e-03,
                         -1.71114560e-02,  -1.59763191e-02,   6.39466662e-03,
                          2.13259668e-03,   2.21715611e-03,  -6.55443082e-03,
                         -1.51330801e-02,   8.83002114e-03,   1.02205006e-02,
                          2.32457323e-03,   1.57347824e-02,   2.79338984e-03,
                         -1.66144948e-02,  -8.66218377e-03,   5.27045503e-03,
                          6.69793691e-03,  -7.08134519e-03,  -1.11077249e-03,
                          2.11307872e-02,   1.22936545e-02,  -6.67195534e-03,
                         -1.36616295e-02,  -1.58233792e-02,  -2.15934683e-03,
                          1.24431513e-02,   1.41863003e-02,   7.56164640e-03,
                         -7.93765485e-03,  -1.56321079e-02,  -1.23216705e-02,
                         -3.44108022e-03,   9.20258462e-03,   1.34239369e-03,
                         -9.17663611e-03,   5.00279339e-03,   3.92030878e-03,
                         -1.01350928e-02,   2.37573497e-03,   9.62778460e-03,
                         -5.42981876e-03,  -1.43494764e-02,  -1.46916863e-02,
                          6.65620947e-03,   2.93014720e-02,  -8.13703146e-03,
                         -4.27972823e-02,  -7.18038483e-03,   1.47973578e-02,
                          7.10208854e-03,   1.58694461e-02,   5.64396440e-04,
                         -1.70225073e-02,  -2.47237179e-03,  -6.08462095e-03,
                         -2.69761798e-03,   1.63041763e-02,  -3.59326787e-03,
                         -7.53870886e-03,   3.50323040e-03,  -1.06183570e-02,
                          1.95980519e-02,  -1.33772522e-01,  -6.29165351e-01,
                         -7.99382865e-01,  -3.21134150e-01,   6.60492778e-02,
                          5.10840043e-02,  -3.48769762e-02,  -3.45501415e-02,
                          1.15843199e-01,   4.23010588e-02,  -4.55111980e-01,
                         -5.29730737e-01,  -3.76444645e-02,   1.28859267e-01,
                         -2.10321005e-02,  -1.37084983e-02,   4.52497452e-02,
                         -2.49214787e-02,  -5.39151803e-02,   1.16464414e-01,
                         -2.12744214e-02,  -4.99959052e-01,  -3.92935157e-01,
                         -1.21225946e-01,  -4.45093066e-01,  -4.33952957e-01,
                          2.44503226e-02,   8.57104063e-02,  -3.03414138e-03,
                         -2.08384365e-01,  -6.91130698e-01,  -7.52563179e-01,
                         -2.36499935e-01,   1.42602280e-01,  -6.52274266e-02,
                         -5.54852128e-01,  -7.45444596e-01,  -6.66718006e-01,
                         -6.00287139e-01,  -6.63460195e-01,  -7.91286767e-01,
                         -4.93168324e-01,  -5.26847690e-02,  -3.37578058e-01,
                         -7.84086823e-01,  -6.94761336e-01,  -6.00489140e-01,
                         -6.79101944e-01,  -6.74306393e-01,  -6.61590159e-01,
                         -6.58363104e-01,  -6.52752161e-01,  -6.78876281e-01,
                         -6.84187710e-01,  -6.63093030e-01,  -6.51455879e-01,
                         -6.57826841e-01,  -6.46173120e-01,  -6.31125391e-01,
                         -6.59862816e-01,  -6.65961683e-01,  -6.47988141e-01,
                         -6.54644072e-01,  -6.51456952e-01,  -6.68878436e-01,
                         -6.89995527e-01,  -6.62300706e-01,  -6.47257745e-01,
                         -6.44573867e-01,  -6.45535707e-01,  -6.77876294e-01,
                         -6.92874134e-01,  -6.71609998e-01,  -6.28490567e-01,
                         -6.20313644e-01,  -6.77751124e-01,  -6.81925595e-01,
                         -6.39807880e-01,  -6.51896119e-01,  -6.66591167e-01,
                         -6.59615219e-01,  -6.49202824e-01,  -6.43038809e-01,
                         -6.59557581e-01,  -6.63183808e-01,  -6.76724792e-01,
                         -6.90386057e-01,  -6.37288749e-01,  -6.28176987e-01,
                         -6.93137825e-01,  -7.01529443e-01,  -6.67795777e-01,
                         -6.45031512e-01,  -6.48646295e-01,  -6.76603675e-01,
                         -6.76953197e-01,  -6.66195095e-01,  -6.61358237e-01,
                         -6.61031663e-01,  -6.98269248e-01,  -7.03638375e-01,
                         -6.54786587e-01,  -6.49057150e-01,  -6.75809145e-01,
                         -6.91084802e-01,  -6.92020714e-01,  -6.74715400e-01,
                         -6.82872355e-01,  -6.93349719e-01,  -6.55065954e-01,
                         -6.64116561e-01,  -7.11272180e-01,  -6.58170760e-01,
                         -6.68307364e-01,  -7.70921648e-01,  -5.10443926e-01,
                         -1.24327265e-01,  -3.57458383e-01,  -7.82506645e-01,
                         -7.39084184e-01,  -6.33805573e-01,  -6.98634803e-01,
                         -6.96608245e-01,  -6.76708817e-01,  -6.68052256e-01,
                         -6.67918324e-01,  -7.25677669e-01,  -7.28219330e-01,
                         -6.96561396e-01,  -7.08879232e-01,  -6.86374366e-01,
                         -6.67138577e-01,  -6.95477188e-01,  -7.01491833e-01,
                         -7.03668356e-01,  -7.17066884e-01,  -7.01592088e-01,
                         -6.99137032e-01,  -7.15172827e-01,  -6.79873824e-01,
                         -6.76936388e-01,  -7.38174438e-01,  -6.94784999e-01,
                         -6.94931090e-01,  -8.18171859e-01,  -5.65792859e-01,
                         -1.32826865e-01,  -3.37005317e-01,  -7.87806988e-01,
                         -7.50954866e-01,  -6.39663398e-01,  -7.29805470e-01,
                         -7.06409037e-01,  -7.39451826e-01,  -8.04584563e-01,
                         -3.99398565e-01,  -8.28431249e-02,  -5.87762237e-01,
                         -9.13792133e-01,  -3.59352916e-01,  -1.13782801e-01,
                         -5.76639593e-01,  -5.55099308e-01,   3.50031815e-02,
                          4.04963829e-02,  -5.61852992e-01,  -7.95309067e-01,
                         -6.25747383e-01,  -7.18671262e-01,  -8.65360618e-01,
                         -4.74222749e-01,  -8.47056881e-02,  -4.94317561e-01,
                         -9.25272167e-01,  -4.68572259e-01,  -8.76884311e-02,
                         -4.93179083e-01,  -8.06344688e-01,  -7.71858275e-01,
                         -7.11401820e-01,  -3.42738569e-01,   7.66247883e-02,
                         -9.03415009e-02,  -6.04805648e-01,  -8.48845899e-01,
                         -5.84026515e-01,  -9.58922580e-02,   7.07114339e-02,
                         -3.07980925e-01,  -8.07234347e-01,  -7.51247942e-01,
                         -3.06372672e-01,  -8.24570432e-02,   3.53910290e-02,
                         -5.36721684e-02,  -5.20806670e-01,  -5.22984505e-01,
                         -1.37324214e-01,  -4.69875574e-01,  -9.55736995e-01,
                         -5.35010099e-01,  -2.73509379e-02,  -4.57539439e-01,
                         -9.80963707e-01,  -5.63946664e-01,  -1.18233547e-01,
                         -4.61388320e-01,  -5.94364643e-01,  -1.41397372e-01,
                          6.45797476e-02,  -7.56848305e-02,  -1.37262136e-01,
                         -7.66095880e-04,   9.23689548e-03,  -4.12729144e-01,
                         -6.21428430e-01,  -2.02768937e-01,   4.94224653e-02,
                         -9.30697024e-02,  -9.26889181e-02,  -7.95607548e-03,
                         -5.36242612e-02,  -8.81913975e-02,  -4.41977754e-02,
                         -3.52129713e-02,  -8.80256742e-02,  -2.67988909e-02,
                         -3.42275552e-03,  -4.51710761e-01,  -9.10537779e-01,
                         -5.73275805e-01,  -9.23632234e-02,  -4.02851135e-01,
                         -6.50907874e-01,  -8.11279938e-02,   1.35333315e-01,
                         -4.85737771e-01,  -6.38180435e-01,  -1.05385743e-01,
                          6.05987161e-02,  -1.17816336e-01,  -3.95558365e-02,
                          1.09091969e-02,  -4.13110703e-01,  -8.44943941e-01,
                         -6.32129848e-01,  -1.60266444e-01,  -1.85677689e-02,
                          1.68008171e-02,  -9.77816656e-02,  -5.45388222e-01,
                         -5.20111084e-01,   9.46617648e-02,   5.83428591e-02,
                         -5.79698384e-01,  -5.51814556e-01,   2.57167742e-02,
                          1.06909975e-01,  -4.01703507e-01,  -8.03406000e-01,
                         -6.71095192e-01,  -2.01554745e-01,   1.33354411e-01,
                         -7.46804997e-02,  -7.08181202e-01,  -8.39965761e-01,
                         -2.65155584e-01,  -1.36653155e-01,  -5.04456937e-01,
                         -3.73121917e-01,  -1.80471614e-01,  -5.26985109e-01,
                         -8.06317329e-01,  -7.51086950e-01,  -4.34902042e-01,
                         -4.82919738e-02,  -3.27070385e-01,  -8.81134629e-01,
                         -5.44427395e-01,  -9.17753298e-03,  -3.56051356e-01,
                         -7.83507347e-01,  -6.29929245e-01,  -5.98897159e-01,
                         -7.65878379e-01,  -4.57381189e-01,  -7.69444108e-02,
                         -3.39586049e-01,  -7.39729464e-01,  -7.07732260e-01,
                         -5.61054170e-01,  -6.42845333e-01,  -7.85766721e-01,
                         -5.41391015e-01,  -9.08769891e-02,  -2.42094472e-01,
                         -7.32186258e-01,  -7.20974922e-01,  -5.54455101e-01,
                         -6.41152918e-01,  -6.56861782e-01,  -6.16915762e-01,
                         -6.48607969e-01,  -6.41269565e-01,  -6.21648312e-01,
                         -6.03864789e-01,  -6.51783884e-01,  -7.24502385e-01,
                         -5.99001348e-01,  -5.74289143e-01,  -7.38256156e-01,
                         -4.46737021e-01,  -3.86927016e-02,  -3.38799417e-01,
                         -7.40604937e-01,  -6.42433286e-01,  -5.61425507e-01,
                         -6.50069714e-01,  -6.41221464e-01,  -6.13048792e-01,
                         -6.16605163e-01,  -6.31927490e-01,  -6.63810313e-01,
                         -6.27361000e-01,  -5.92875242e-01,  -6.31640673e-01,
                         -6.33296967e-01,  -6.13199592e-01,  -6.13647223e-01,
                         -6.05505168e-01,  -6.41783118e-01,  -6.69807434e-01,
                         -6.27387941e-01,  -6.31507516e-01,  -6.61288261e-01,
                         -6.22919500e-01,  -6.04641557e-01,  -6.26740396e-01,
                         -6.18423760e-01,  -6.22992098e-01,  -6.65768504e-01,
                         -6.68450475e-01,  -6.13935292e-01,  -5.97144783e-01,
                         -6.36885941e-01,  -6.45727873e-01,  -6.41230106e-01,
                         -6.54551625e-01,  -6.23761237e-01,  -6.02169633e-01,
                         -6.34091616e-01,  -6.30410790e-01,  -6.13805056e-01,
                         -6.23115957e-01,  -6.22771680e-01,  -6.44069970e-01,
                         -6.42376840e-01,  -5.92420042e-01,  -6.11678064e-01,
                         -6.53074026e-01,  -6.33812785e-01,  -6.28747523e-01,
                         -6.33770525e-01,  -6.44883156e-01,  -6.66868091e-01,
                         -6.22049391e-01,  -6.09640658e-01,  -6.88183248e-01,
                         -6.80004060e-01,  -6.24682367e-01,  -6.54015779e-01,
                         -6.70120955e-01,  -6.46797776e-01,  -6.35841608e-01,
                         -6.18190825e-01,  -6.26931310e-01,  -6.61503792e-01,
                         -6.78525865e-01,  -6.71969295e-01,  -6.19842470e-01,
                         -6.12304568e-01,  -6.75499260e-01,  -6.44495189e-01,
                         -6.66136563e-01,  -7.67532647e-01,  -4.55575973e-01,
                         -5.14969155e-02,  -3.40033412e-01,  -7.77259827e-01,
                         -7.06615984e-01,  -5.96451759e-01,  -6.59760892e-01,
                         -6.76621795e-01,  -6.89993560e-01,  -6.78399205e-01,
                         -6.39314175e-01,  -6.63852453e-01,  -6.88829362e-01,
                         -6.55749559e-01,  -6.22811079e-01,  -7.19028890e-01,
                         -6.79526865e-01,  -2.10577592e-01,  -1.34504437e-01,
                         -7.51285732e-01,  -7.57444799e-01,  -9.64900702e-02,
                          7.62136057e-02,  -5.94296232e-02,  -3.81759927e-02,
                         -4.43650670e-02,  -2.84612775e-02,   7.20276218e-03,
                         -6.62571145e-03,   1.93917695e-02,   1.03672901e-02,
                         -2.06959769e-02,  -1.65481791e-02,  -3.31888162e-02,
                         -1.36423437e-02,  -4.70892573e-03,  -3.45151424e-02,
                          1.22326734e-02,   3.87795046e-02,   4.68980009e-03,
                          3.36553901e-03,  -1.22437105e-02,  -2.19547413e-02,
                         -7.91553408e-03,  -7.88814295e-03,   2.11448353e-02,
                          2.62975413e-02,   1.04223122e-03,   1.47639122e-02,
                          6.94511132e-03,   5.81695931e-03,   3.28634083e-02,
                          7.61447428e-03,  -2.62263743e-03,   1.18487692e-02,
                         -7.87090696e-03,  -5.94430277e-03,  -1.83712761e-03,
                         -5.55548025e-03,   1.25544770e-02,   9.93760550e-05,
                         -9.93139111e-03,   5.68399346e-03,   3.79160349e-03,
                          1.75413322e-02,   2.32006256e-02,   7.33947600e-05,
                         -4.75822948e-03,  -7.53007503e-03,   2.69926782e-03,
                          1.42719168e-02,  -1.06195267e-02,  -4.97389678e-03,
                          1.32460725e-02,  -4.18279646e-03,   1.09739741e-03,
                          3.56528419e-03,  -1.37094595e-02,  -4.41795774e-03,
                          1.43704447e-03,   3.44100012e-03,   1.30778188e-02,
                         -2.22758390e-03,  -2.98693292e-02,  -3.71587016e-02,
                         -3.14040529e-03,   2.61226241e-02,   4.34478745e-03,
                         -6.08575856e-03,  -8.74645449e-03,  -2.32730918e-02,
                          3.36259161e-03,   1.01632364e-02,  -1.58443935e-02,
                         -6.10823184e-03,  -1.66641511e-02,  -2.70721596e-02,
                          9.23635066e-03,   1.39864590e-02,   1.37378750e-02,
                          3.72428112e-02,   1.53332418e-02,  -2.16104165e-02,
                         -2.01678611e-02,   1.84047536e-03,   6.91980267e-06,
                         -3.35749462e-02,  -2.93094013e-02,   5.15480479e-03,
                          3.78192845e-03,  -6.56583579e-03,  -2.37570284e-03,
                          4.82752360e-03,   1.70680461e-03,  -1.39176454e-02,
                         -3.10010370e-03,   1.55384010e-02,   1.09956786e-02,
                          2.97460216e-03,  -1.55608747e-02,  -1.74997328e-03,
                          4.01629061e-02,   1.99969169e-02,   1.05334772e-03,
                          1.65623073e-02,  -1.15954913e-02,  -2.70091444e-02,
                          6.20158482e-03,   4.17936854e-02,   4.15942930e-02,
                         -2.04256084e-02,  -2.40643360e-02,   4.05459590e-02,
                          8.72723293e-03,  -3.08331996e-02,  -2.02566013e-03,
                         -9.49392188e-03,   1.17438030e-03,   2.63746846e-02,
                         -1.59190712e-03,   5.47023211e-03,   3.05133834e-02,
                          2.12127361e-02,   1.37754856e-02,  -1.51561946e-02,
                         -2.45136898e-02,   1.70107652e-02,   3.25574316e-02,
                          2.09255312e-02,  -6.54156832e-03,  -2.74531804e-02,
                          1.60681992e-03,   3.75705259e-03,  -2.18544360e-02,
                         -5.83225675e-03,  -1.01739680e-02,  -2.07283664e-02,
                          9.56545770e-03,   4.23982099e-04,  -3.45362574e-02,
                         -2.62868088e-02,  -6.17899932e-03,   7.78718095e-04,
                         -3.41143087e-03,  -9.60135460e-03,  -5.92594640e-03,
                         -1.18765766e-02,  -1.76764447e-02,   3.28514434e-04,
                          1.33846607e-02,   1.09597184e-02,   1.10174315e-02,
                         -3.34788719e-03,  -2.63151620e-02,  -2.04908345e-02,
                         -8.27091001e-03,  -8.17507412e-03,   3.10902577e-03,
                         -1.49486959e-03,  -1.18463822e-02,   1.23164002e-02,
                          1.87304011e-03,  -3.98458280e-02,  -2.11224742e-02,
                          1.46671152e-02,   1.77231524e-02,   3.06212483e-03,
                         -2.17601042e-02,  -1.14524979e-02,   1.18311010e-02,
                         -7.85958255e-04,  -9.71245579e-03,  -2.03099418e-02,
                         -2.46499870e-02,  -8.70966120e-04,  -1.69800911e-02,
                         -3.97722721e-02,  -1.21691460e-02,   9.46508907e-03,
                          2.69454718e-02,   3.34426723e-02,   7.42254592e-03,
                         -1.00745605e-02,  -2.99876072e-02,  -3.18739265e-02,
                         -3.64318001e-03,  -8.53362307e-03,  -7.34373694e-03,
                          8.91555753e-03,  -1.32149016e-03,  -2.07358622e-03,
                         -1.29151391e-02,  -6.23064162e-03,   2.06788052e-02,
                         -2.49927901e-02,  -2.50188038e-02,   3.52190398e-02,
                         -2.86173890e-03,  -3.69111896e-02,  -7.75384717e-03,
                          1.96063165e-02,  -1.26533464e-01,  -6.16179407e-01,
                         -8.01513851e-01,  -2.67671049e-01,   1.10018045e-01,
                          2.80949436e-02,  -1.51833612e-02,   7.28067383e-03,
                          9.93081108e-02,   1.65138859e-02,  -4.55964535e-01,
                         -5.35533309e-01,  -6.05520085e-02,   1.18827112e-01,
                         -9.46725160e-03,  -4.12716577e-03,   5.86890765e-02,
                         -8.83636437e-03,  -3.52633633e-02,   1.47852570e-01,
                         -9.79472417e-04,  -4.80840445e-01,  -3.74812186e-01,
                         -1.41232342e-01,  -4.61272627e-01,  -4.23247010e-01,
                          2.53666677e-02,   8.47960040e-02,  -9.19153262e-03,
                         -2.21536949e-01,  -6.88637972e-01,  -7.43256092e-01,
                         -2.19463170e-01,   1.66890159e-01,  -5.05119003e-02,
                         -5.54027021e-01,  -7.55229354e-01,  -6.55848920e-01,
                         -5.73863924e-01,  -6.59181952e-01,  -7.83614993e-01,
                         -4.76802379e-01,  -5.69930486e-02,  -3.50527644e-01,
                         -7.72818565e-01,  -6.34605110e-01,  -5.55861175e-01,
                         -7.10819125e-01,  -7.00557530e-01,  -6.54300928e-01,
                         -6.72540486e-01,  -6.57588840e-01,  -6.42018914e-01,
                         -6.43370092e-01,  -6.57724440e-01,  -6.61463737e-01,
                         -6.54015541e-01,  -6.57487929e-01,  -6.35011196e-01,
                         -6.25167131e-01,  -6.53628409e-01,  -6.69003606e-01,
                         -6.81747973e-01,  -6.56806231e-01,  -5.99704623e-01,
                         -6.23065114e-01,  -6.85048044e-01,  -6.78743839e-01,
                         -6.40748799e-01,  -6.45514786e-01,  -6.56263828e-01,
                         -6.21528566e-01,  -6.25190794e-01,  -6.62159264e-01,
                         -6.50195718e-01,  -6.71141326e-01,  -6.94121063e-01,
                         -6.36646211e-01,  -6.27507806e-01,  -6.69286072e-01,
                         -6.74765289e-01,  -6.72582924e-01,  -6.41769171e-01,
                         -6.21964633e-01,  -6.63220763e-01,  -6.67239070e-01,
                         -6.36827767e-01,  -6.33564651e-01,  -6.30988717e-01,
                         -6.52371347e-01,  -6.93775475e-01,  -6.94092393e-01,
                         -6.64122045e-01,  -6.37684286e-01,  -6.47723794e-01,
                         -6.82315528e-01,  -6.75252676e-01,  -6.57354355e-01,
                         -6.69637859e-01,  -6.71615958e-01,  -6.67548895e-01,
                         -6.67904913e-01,  -6.50442064e-01,  -6.34059489e-01,
                         -6.65462732e-01,  -7.18357801e-01,  -7.10167348e-01,
                         -6.90604448e-01,  -6.94806397e-01,  -6.56096041e-01,
                         -6.67133093e-01,  -7.00748622e-01,  -6.35599554e-01,
                         -7.03042805e-01,  -8.18447888e-01,  -5.04654229e-01,
                         -1.23970032e-01,  -3.47441763e-01,  -7.36078978e-01,
                         -7.23154008e-01,  -6.78785443e-01,  -7.61225820e-01,
                         -6.98138118e-01,  -6.40535355e-01,  -6.81434274e-01,
                         -6.87146425e-01,  -6.99178398e-01,  -6.97701633e-01,
                         -6.93636835e-01,  -7.34016418e-01,  -7.10173845e-01,
                         -6.66170180e-01,  -6.95335209e-01,  -7.06098437e-01,
                         -6.87097490e-01,  -7.05128491e-01,  -7.27411032e-01,
                         -7.44771540e-01,  -7.56171525e-01,  -6.99470341e-01,
                         -6.85225427e-01,  -7.55778193e-01,  -7.00911880e-01,
                         -6.86047912e-01,  -8.31394494e-01,  -6.12618983e-01,
                         -1.68556631e-01,  -3.22744280e-01,  -7.54215479e-01,
                         -7.38610208e-01,  -6.53391659e-01,  -7.26590753e-01,
                         -6.67069256e-01,  -7.30801582e-01,  -8.17489266e-01,
                         -3.91906947e-01,  -7.20275864e-02,  -5.62853038e-01,
                         -9.32699919e-01,  -4.20915157e-01,  -1.09902084e-01,
                         -5.54025531e-01,  -5.48324585e-01,   5.52667193e-02,
                          4.02569287e-02,  -5.60772121e-01,  -8.04403126e-01,
                         -6.57137096e-01,  -7.01608181e-01,  -8.34271312e-01,
                         -4.86051887e-01,  -9.13369581e-02,  -4.89005566e-01,
                         -9.66925442e-01,  -5.21475255e-01,  -8.59776512e-02,
                         -4.88314271e-01,  -7.93107569e-01,  -7.23835409e-01,
                         -7.27280021e-01,  -4.06115979e-01,   6.54891282e-02,
                         -8.53556916e-02,  -6.55342102e-01,  -9.22816396e-01,
                         -5.74915826e-01,  -3.57332863e-02,   5.11826277e-02,
                         -3.71478915e-01,  -8.37831020e-01,  -7.58289695e-01,
                         -2.71831572e-01,  -3.37600373e-02,   2.76480243e-02,
                         -7.23909438e-02,  -5.25428891e-01,  -5.60090065e-01,
                         -1.43207416e-01,  -4.26540315e-01,  -9.49790180e-01,
                         -5.69397986e-01,  -6.15766495e-02,  -4.46292311e-01,
                         -9.62537825e-01,  -5.96956909e-01,  -1.30837485e-01,
                         -4.63104159e-01,  -5.87360442e-01,  -9.07654017e-02,
                          5.40471189e-02,  -1.10603645e-01,  -1.44341812e-01,
                         -3.72800045e-02,   5.36931865e-03,  -4.01573896e-01,
                         -6.25919342e-01,  -2.06270725e-01,   1.65936872e-02,
                         -6.60504922e-02,  -4.61260751e-02,  -5.48847690e-02,
                         -9.27011743e-02,  -8.53783563e-02,  -3.94562520e-02,
                         -3.27291153e-02,  -9.24433470e-02,  -2.05846671e-02,
                         -3.33523285e-03,  -4.32558149e-01,  -8.86911273e-01,
                         -6.36275291e-01,  -1.78374797e-01,  -4.13415968e-01,
                         -6.21995449e-01,  -8.06606486e-02,   9.83380228e-02,
                         -5.31171620e-01,  -6.81363463e-01,  -1.35005146e-01,
                          6.40887320e-02,  -6.62239715e-02,   1.35876574e-02,
                          8.60173162e-03,  -4.25553918e-01,  -8.53508592e-01,
                         -6.42970443e-01,  -1.45733789e-01,   1.74249290e-03,
                          3.75390984e-02,  -1.07852593e-01,  -5.77467918e-01,
                         -5.20346284e-01,   7.50698969e-02,   4.43689264e-02,
                         -5.62713742e-01,  -5.62692165e-01,   2.58079823e-02,
                          1.13573447e-01,  -4.12423044e-01,  -8.19510698e-01,
                         -6.99621260e-01,  -2.05506742e-01,   1.20031208e-01,
                         -9.14504156e-02,  -6.87105775e-01,  -8.51952791e-01,
                         -2.75612265e-01,  -1.47295117e-01,  -5.52011132e-01,
                         -3.50108266e-01,  -1.42490432e-01,  -5.40287495e-01,
                         -7.93360829e-01,  -7.37350941e-01,  -4.50409323e-01,
                         -7.81795681e-02,  -3.25068384e-01,  -8.43820214e-01,
                         -5.71380198e-01,  -4.55261357e-02,  -3.18193167e-01,
                         -7.50690997e-01,  -6.32989109e-01,  -6.04284823e-01,
                         -7.55501926e-01,  -4.24989998e-01,  -5.66799454e-02,
                         -3.82166237e-01,  -7.82094002e-01,  -6.63800716e-01,
                         -5.34275889e-01,  -6.75765038e-01,  -7.90590644e-01,
                         -5.17447889e-01,  -4.66533266e-02,  -2.06129223e-01,
                         -7.14348137e-01,  -7.24213421e-01,  -6.11291349e-01,
                         -6.58676922e-01,  -6.34308338e-01,  -6.24269009e-01,
                         -6.44188941e-01,  -6.41414881e-01,  -6.30363345e-01,
                         -6.20148122e-01,  -6.40833616e-01,  -6.52944684e-01,
                         -6.12763226e-01,  -6.45728946e-01,  -7.33380556e-01,
                         -4.24501270e-01,  -2.57344265e-02,  -3.29085439e-01,
                         -7.54085481e-01,  -6.75788105e-01,  -5.76287091e-01,
                         -6.41137064e-01,  -6.58892334e-01,  -6.20653391e-01,
                         -6.18782282e-01,  -6.45499527e-01,  -6.50438070e-01,
                         -6.35708570e-01,  -5.95581174e-01,  -6.17712736e-01,
                         -6.55633152e-01,  -6.18124723e-01,  -6.08466983e-01,
                         -6.10692322e-01,  -6.17655993e-01,  -6.33644402e-01,
                         -6.43317223e-01,  -6.72538817e-01,  -6.13464892e-01,
                         -5.75153112e-01,  -6.41399145e-01,  -6.37273371e-01,
                         -6.14013314e-01,  -6.13674402e-01,  -6.00566387e-01,
                         -6.13078892e-01,  -6.30864084e-01,  -6.63254440e-01,
                         -6.76553845e-01,  -6.30665600e-01,  -6.02137685e-01,
                         -6.27691746e-01,  -6.47579610e-01,  -6.36296749e-01,
                         -6.17726624e-01,  -6.03278160e-01,  -6.33554399e-01,
                         -6.56189322e-01,  -6.07834041e-01,  -5.93781054e-01,
                         -6.35250568e-01,  -6.54257238e-01,  -6.33638740e-01,
                         -6.18290365e-01,  -6.38301075e-01,  -6.39173269e-01,
                         -6.27993226e-01,  -6.39754891e-01,  -6.47530675e-01,
                         -6.45586848e-01,  -6.45975053e-01,  -6.40960991e-01,
                         -6.36970401e-01,  -6.54022992e-01,  -6.31965280e-01,
                         -6.13487065e-01,  -6.59306169e-01,  -6.45655096e-01,
                         -6.19620442e-01,  -6.43359303e-01,  -6.55547678e-01,
                         -6.62011564e-01,  -6.38021290e-01,  -6.33309186e-01,
                         -6.56664491e-01,  -6.55860484e-01,  -6.23246551e-01,
                         -6.57618582e-01,  -7.68131554e-01,  -4.72507089e-01,
                         -7.12410063e-02,  -3.69376719e-01,  -7.44728386e-01,
                         -6.72429919e-01,  -6.22070134e-01,  -6.66235149e-01,
                         -6.60944283e-01,  -6.64964080e-01,  -6.96533263e-01,
                         -6.59488142e-01,  -6.24662101e-01,  -6.77046835e-01,
                         -6.39350057e-01,  -6.03815317e-01,  -7.35279441e-01,
                         -6.72040105e-01,  -1.81136772e-01,  -9.73356739e-02,
                         -7.39302576e-01,  -7.42221892e-01,  -7.16963187e-02,
                          6.74017146e-02,  -2.99435891e-02,   4.03664773e-03,
                         -2.18208935e-02,  -1.47238988e-02,  -1.22872312e-02,
                         -1.85780842e-02,  -1.73105602e-03,   1.91840325e-02,
                          1.66583359e-02,  -2.24983934e-02,  -3.41655663e-03,
                          2.29748189e-02,   1.84850842e-02,   1.98193565e-02,
                          1.51741188e-02,   2.95848795e-03,  -7.26236496e-03,
                          1.72677748e-02,   9.08720680e-03,   1.39380367e-02,
                          4.38776687e-02,  -6.21510437e-03,  -8.30126461e-03,
                         -8.00911151e-03,  -2.62394119e-02,   3.67541313e-02,
                          2.62194220e-02,  -1.72581803e-03,   1.67478137e-02,
                         -3.69632803e-03,  -9.38597601e-03,  -1.55673141e-03,
                          1.03799924e-02,   1.86674986e-02,   1.21282842e-02,
                          1.60537823e-03,  -7.31343077e-03,  -6.80213422e-03,
                         -1.88986231e-02,  -8.10803846e-03,  -1.11897057e-02,
                         -2.07597762e-02,   1.96208768e-02,   8.42433143e-03,
                         -2.07190588e-02,  -1.56910215e-02,   4.71472461e-03,
                          1.97369121e-02,  -8.99854675e-03,   7.87082687e-03,
                          1.16685973e-02,  -1.09042320e-02,   2.00366583e-02,
                         -4.47357260e-03,  -1.99673306e-02,  -2.67804391e-03,
                         -2.88408250e-02,  -2.95045823e-02,  -9.67156142e-03,
                         -4.64442093e-03,  -2.29453929e-02,   1.16701191e-03,
                          3.95317748e-02,   5.91293955e-03,  -2.18460732e-03,
                          1.39538141e-03,  -4.78381012e-03,   1.58098270e-03,
                         -7.53331091e-03,   3.75823793e-03,  -2.42638402e-03,
                          1.31056262e-02,   4.62068394e-02,   1.64021440e-02,
                         -1.48859061e-03,  -6.87248539e-03,   9.35390766e-04,
                          6.98425947e-03,  -1.32919000e-02,  -2.40482367e-03,
                         -2.53549893e-04,   1.01784058e-02,   1.31028546e-02,
                         -1.34988697e-02,   4.38555330e-03,   1.73067320e-02,
                          1.68652255e-02,   2.74099479e-03,  -1.54716698e-02,
                          5.09013981e-03,   7.16603268e-03,   1.66328363e-02,
                          1.90428179e-02,  -6.48028310e-03,  -1.34135736e-02,
                         -2.84230094e-02,  -5.23827458e-03,   2.97765695e-02,
                          8.36794823e-03,  -8.63006711e-03,   7.15855230e-03,
                          1.30101424e-02,  -1.33663677e-02,   2.71168165e-03,
                          1.48293301e-02,  -3.25897895e-02,  -2.46711634e-02,
                         -3.92963132e-03,  -1.75185222e-02,  -1.71319265e-02,
                         -6.65250933e-03,  -1.26458919e-02,  -5.02785519e-02,
                         -1.10585978e-02,   3.96229997e-02,  -1.53786214e-02,
                         -2.12919936e-02,   1.25378342e-02,  -1.76358863e-03,
                         -7.01700058e-03,   6.29112590e-03,   1.81887653e-02,
                          1.10410741e-02,   6.07353682e-03,   1.46552455e-02,
                          2.02088207e-02,   1.30070671e-02,  -9.67249088e-03,
                         -1.50505388e-02,  -1.36142476e-02,  -4.28672181e-03,
                          6.91783288e-03,   9.54032596e-03,   3.14316340e-02,
                          4.44914494e-03,  -2.61124056e-02,   6.67004939e-03,
                          4.58736485e-03,  -7.74353184e-03,  -7.06388522e-03,
                         -1.72888711e-02,  -7.97481649e-03,   2.88416422e-03,
                          1.19470078e-02,  -2.30331719e-03,  -1.49917370e-02,
                          1.19314222e-02,   2.62544048e-03,  -1.73175596e-02,
                          6.85244706e-03,   1.11490358e-02,  -1.97091531e-02,
                         -3.63455936e-02,  -2.31472366e-02,   3.13289277e-03,
                          1.50060887e-02,  -1.02457928e-03,   4.69119381e-03,
                          3.27585861e-02,   2.79059149e-02,   1.12484274e-02,
                          9.85014718e-04,   1.39788026e-02,   1.71205048e-02,
                         -1.84164140e-02,   3.53435334e-03,   1.26462923e-02,
                         -2.84622703e-02,   6.85960706e-03,   1.63773801e-02,
                         -1.58788655e-02,   2.77075637e-03,  -1.58014502e-02,
                         -2.47575175e-02,   4.35391767e-03,  -1.60695445e-02,
                         -1.04863690e-02,   1.51518211e-02,   1.09448214e-03,
                          1.68189649e-02,   1.69797875e-02,  -1.53327771e-02,
                          5.82014676e-03,   7.69248232e-03,  -1.98805463e-02,
                         -9.68227815e-03,  -1.18960384e-02,   3.74229974e-04,
                          1.74671840e-02,  -1.32535044e-02,  -1.54488767e-02,
                         -7.05198385e-03,  -1.07072573e-02,   1.06367301e-02,
                          4.74982010e-03,  -2.58796308e-02,  -1.69715863e-02,
                          4.41005751e-02,  -1.16063930e-01,  -6.30403578e-01,
                         -7.95548260e-01,  -3.37634295e-01,   1.07617667e-02,
                          4.29755971e-02,  -1.49539821e-02,  -4.35659103e-02,
                          1.30669042e-01,   4.42610942e-02,  -4.84753758e-01,
                         -5.14862835e-01,  -1.16149215e-02,   1.20797880e-01,
                         -4.91395369e-02,  -3.25326845e-02,   8.10836554e-02,
                          8.50506220e-03,  -6.32834584e-02,   1.26993626e-01,
                         -6.12996845e-03,  -4.81134385e-01,  -3.61522973e-01,
                         -1.35286093e-01,  -4.58949149e-01,  -4.39412922e-01,
                          6.01942767e-04,   1.24549694e-01,   2.34919935e-02,
                         -2.56222934e-01,  -6.99895799e-01,  -7.48301804e-01,
                         -2.53700167e-01,   1.31039962e-01,  -1.06453896e-01,
                         -5.67353666e-01,  -6.90835893e-01,  -6.15376413e-01,
                         -5.87583244e-01,  -6.91657543e-01,  -7.93742120e-01,
                         -4.46278572e-01,  -5.84312640e-02,  -3.62769067e-01,
                         -7.34868467e-01,  -6.56727612e-01,  -6.21970236e-01,
                         -6.72836483e-01,  -6.24172747e-01,  -6.30937934e-01,
                         -6.72718048e-01,  -6.61946416e-01,  -6.39788449e-01,
                         -6.45895123e-01,  -6.49212062e-01,  -6.22810721e-01,
                         -6.44576430e-01,  -6.79537416e-01,  -6.51024044e-01,
                         -6.44369602e-01,  -6.63538158e-01,  -6.62786365e-01,
                         -6.62984729e-01,  -6.41398191e-01,  -6.30678773e-01,
                         -6.52617693e-01,  -6.52657390e-01,  -6.59534097e-01,
                         -6.72129869e-01,  -6.71094656e-01,  -6.89726472e-01,
                         -6.68396056e-01,  -6.32548392e-01,  -6.55879021e-01,
                         -6.57637835e-01,  -6.59218729e-01,  -6.91975832e-01,
                         -6.77139938e-01,  -6.64054096e-01,  -6.71287835e-01,
                         -6.52564347e-01,  -6.42527521e-01,  -6.46378160e-01,
                         -6.75146997e-01,  -7.05271184e-01,  -6.80634975e-01,
                         -6.62604809e-01,  -6.60121620e-01,  -6.51169240e-01,
                         -6.83187902e-01,  -6.84103072e-01,  -6.48881376e-01,
                         -6.77721798e-01,  -6.82763219e-01,  -6.40608668e-01,
                         -6.50600195e-01,  -6.70483053e-01,  -6.83431923e-01,
                         -6.82739913e-01,  -6.42677605e-01,  -6.63486838e-01,
                         -7.12435007e-01,  -6.88759446e-01,  -6.69523597e-01,
                         -6.77148879e-01,  -6.93331599e-01,  -7.18562186e-01,
                         -6.96659029e-01,  -6.65156424e-01,  -6.60805166e-01,
                         -6.81929171e-01,  -7.20589638e-01,  -6.64042532e-01,
                         -6.64728820e-01,  -7.84719944e-01,  -5.19750476e-01,
                         -1.09515458e-01,  -3.49850565e-01,  -7.78621197e-01,
                         -7.45243073e-01,  -6.53753161e-01,  -7.13362992e-01,
                         -7.08291411e-01,  -6.67341650e-01,  -6.50647521e-01,
                         -6.66766822e-01,  -7.16774523e-01,  -7.32929707e-01,
                         -6.93282485e-01,  -6.60834610e-01,  -6.95690393e-01,
                         -7.29149461e-01,  -6.97933853e-01,  -6.89037323e-01,
                         -7.06064641e-01,  -7.00973570e-01,  -7.16390312e-01,
                         -7.28884816e-01,  -6.97513461e-01,  -6.70510709e-01,
                         -7.18320608e-01,  -7.67321825e-01,  -6.74617469e-01,
                         -6.61741078e-01,  -8.03649962e-01,  -5.73534071e-01,
                         -1.44931808e-01,  -3.20053130e-01,  -7.65966654e-01,
                         -7.75692105e-01,  -6.84285522e-01,  -7.51112938e-01,
                         -6.88705027e-01,  -6.93347692e-01,  -8.01673412e-01,
                         -4.37770754e-01,  -7.03720897e-02,  -5.40873170e-01,
                         -8.99776697e-01,  -3.71304572e-01,  -1.26015261e-01,
                         -5.71458340e-01,  -5.50598979e-01,   1.20425718e-02,
                          2.75384281e-02,  -5.48471749e-01,  -7.98484504e-01,
                         -6.57921553e-01,  -7.43318439e-01,  -8.36563051e-01,
                         -4.23002422e-01,  -9.31579620e-02,  -5.38124025e-01,
                         -9.46062565e-01,  -4.86552030e-01,  -9.77400243e-02,
                         -4.80388999e-01,  -8.07254970e-01,  -7.84399271e-01,
                         -7.14723051e-01,  -3.53816509e-01,   6.97028711e-02,
                         -7.48373941e-02,  -6.02542281e-01,  -8.65742803e-01,
                         -5.69652200e-01,  -5.98893389e-02,   6.58589825e-02,
                         -3.55682999e-01,  -8.55182230e-01,  -7.62807667e-01,
                         -2.61581212e-01,  -2.00491846e-02,   5.67777827e-02,
                         -7.69915059e-02,  -5.62322259e-01,  -5.47354639e-01,
                         -1.23489395e-01,  -4.48452979e-01,  -9.68009889e-01,
                         -5.86876571e-01,  -7.72951469e-02,  -4.56226200e-01,
                         -9.48261738e-01,  -5.49231172e-01,  -1.35573879e-01,
                         -4.90303993e-01,  -5.85034490e-01,  -1.08043514e-01,
                          5.44292480e-02,  -9.43769962e-02,  -1.16921410e-01,
                          1.24368882e-02,   1.24056684e-03,  -4.18215454e-01,
                         -6.27747118e-01,  -2.09433511e-01,   4.51207981e-02,
                         -9.32460129e-02,  -9.62152630e-02,  -2.46926751e-02,
                         -4.72297519e-02,  -4.65768874e-02,  -2.40446497e-02,
                         -4.61467542e-02,  -9.42580774e-02,  -3.91177572e-02,
                         -2.87017878e-02,  -4.56368446e-01,  -8.94675612e-01,
                         -5.64618587e-01,  -9.93935317e-02,  -4.29270297e-01,
                         -6.67724133e-01,  -6.28083721e-02,   1.42487407e-01,
                         -4.94324714e-01,  -6.23414338e-01,  -9.32166651e-02,
                          6.97674379e-02,  -8.91080797e-02,  -1.39047354e-02,
                          3.18600871e-02,  -4.10588294e-01,  -8.61595690e-01,
                         -6.19109452e-01,  -1.38029590e-01,  -5.96576696e-03,
                          4.82451394e-02,  -7.14680627e-02,  -5.29048920e-01,
                         -5.13900399e-01,   7.39744082e-02,   6.54213578e-02,
                         -5.42372048e-01,  -5.45860708e-01,   1.87438875e-02,
                          1.23855405e-01,  -3.70565206e-01,  -7.88935900e-01,
                         -6.65249348e-01,  -1.80539638e-01,   1.24615721e-01,
                         -8.80365819e-02,  -6.54859602e-01,  -7.93007493e-01,
                         -2.82177716e-01,  -1.74223974e-01,  -5.04578829e-01,
                         -3.08942467e-01,  -1.48851067e-01,  -5.52698791e-01,
                         -7.80119479e-01,  -7.11746752e-01,  -4.42735642e-01,
                         -6.36016876e-02,  -3.31235319e-01,  -8.56357813e-01,
                         -5.38631558e-01,  -3.09823286e-02,  -3.22709620e-01,
                         -7.58594394e-01,  -6.42844975e-01,  -5.79484165e-01,
                         -7.52720952e-01,  -4.35453862e-01,  -4.07615155e-02,
                         -3.41881841e-01,  -7.11639047e-01,  -6.73420072e-01,
                         -5.78601122e-01,  -6.35953426e-01,  -7.66349196e-01,
                         -5.25385857e-01,  -7.64739290e-02,  -2.68055826e-01,
                         -7.13768542e-01,  -6.80162430e-01,  -5.95535815e-01,
                         -6.65842235e-01,  -6.46823645e-01,  -6.34392917e-01,
                         -6.42649293e-01,  -6.32963479e-01,  -6.48988128e-01,
                         -6.35990262e-01,  -6.45039737e-01,  -6.51845694e-01,
                         -5.61201274e-01,  -6.19709671e-01,  -7.58032024e-01,
                         -4.28999841e-01,  -2.75795944e-02,  -3.34268630e-01,
                         -7.47722328e-01,  -6.45467579e-01,  -5.66794276e-01,
                         -6.50159180e-01,  -6.22011304e-01,  -6.32734060e-01,
                         -6.54045999e-01,  -6.22154891e-01,  -6.54478133e-01,
                         -6.49981439e-01,  -6.02720380e-01,  -6.09548450e-01,
                         -6.44859970e-01,  -6.87040091e-01,  -6.50511563e-01,
                         -5.90456247e-01,  -6.23467982e-01,  -6.34291768e-01,
                         -6.32062852e-01,  -6.51250243e-01,  -6.10985100e-01,
                         -6.12664521e-01,  -6.39072120e-01,  -6.08191013e-01,
                         -6.33557677e-01,  -6.54338479e-01,  -6.08486474e-01,
                         -6.08024597e-01,  -6.31318986e-01,  -6.42201483e-01,
                         -6.34939134e-01,  -6.08541965e-01,  -6.29469335e-01,
                         -6.38625681e-01,  -6.10314667e-01,  -6.34342551e-01,
                         -6.45815551e-01,  -6.19919658e-01,  -6.29181802e-01,
                         -6.38055921e-01,  -6.38182819e-01,  -6.38588667e-01,
                         -6.17480993e-01,  -6.19808912e-01,  -6.44936383e-01,
                         -6.46953344e-01,  -6.39263570e-01,  -6.28818631e-01,
                         -6.19796634e-01,  -6.32746816e-01,  -6.36238337e-01,
                         -6.12311065e-01,  -6.26462340e-01,  -6.63586617e-01,
                         -6.41768217e-01,  -6.25939071e-01,  -6.41995072e-01,
                         -6.21387601e-01,  -6.40456080e-01,  -6.77164793e-01,
                         -6.34863913e-01,  -6.29874170e-01,  -6.55456603e-01,
                         -6.35813296e-01,  -6.41691446e-01,  -6.22148812e-01,
                         -6.20500863e-01,  -6.72377646e-01,  -6.11276329e-01,
                         -6.53085232e-01,  -7.73256063e-01,  -4.22887862e-01,
                         -5.28236777e-02,  -3.65606457e-01,  -7.45133281e-01,
                         -6.90069675e-01,  -6.07364893e-01,  -6.61470354e-01,
                         -6.81538284e-01,  -6.47649825e-01,  -6.48063421e-01,
                         -6.68011010e-01,  -6.43895090e-01,  -6.67892456e-01,
                         -6.77941144e-01,  -6.15216434e-01,  -7.31156766e-01,
                         -6.91237450e-01,  -1.68217480e-01,  -1.22141540e-01,
                         -7.54419863e-01,  -7.32186913e-01,  -8.70368630e-02,
                          6.48074448e-02,  -6.02807738e-02,   2.01273840e-02,
                          2.10961718e-02,  -3.75662968e-02,   5.26396791e-03,
                          5.11085102e-03,  -6.36730809e-03,   6.56376919e-03,
                         -2.35763453e-02,  -1.26359928e-02,   9.11253132e-03,
                         -1.63323358e-02,  -3.85714928e-04,   3.23239691e-03,
                         -2.99673118e-02,  -1.58976223e-02,  -6.27739867e-03,
                          3.58046941e-03,   2.81833317e-02,  -1.28834881e-02,
                         -4.05852199e-02,  -1.51484255e-02,  -1.77598335e-02,
                          1.64098642e-03,   2.76193842e-02,  -7.13242684e-03,
                         -2.56809257e-02,  -1.43382642e-02,  -8.14664271e-03,
                          6.65611355e-03,  -3.24948807e-03,  -1.74287893e-02,
                          6.77911611e-03,   9.40500479e-03,  -1.71742458e-02,
                         -1.29509233e-02,   4.96527879e-03,   2.04254314e-03,
                         -4.61565284e-03,  -4.82143695e-03,  -5.58295147e-03,
                         -6.48954185e-03,  -1.08735571e-02,  -1.04393074e-02,
                         -4.49945778e-03,  -1.24666654e-02,  -9.85128433e-03,
                          5.61916828e-03,  -6.30559027e-03,  -1.22364219e-02,
                         -7.83265661e-03,  -2.13034134e-02,   6.03336317e-04,
                          2.10181959e-02,  -1.36277992e-02,  -1.60573553e-02,
                          4.01755422e-03,  -1.25932721e-02,  -1.71818379e-02,
                         -2.91475863e-03,   1.69258378e-02,   2.41767820e-02,
                         -9.70830768e-03,  -1.61869247e-02,   6.42391574e-03,
                         -4.21294244e-03,  -2.56321044e-04,   1.10971369e-02,
                         -2.30797846e-03,   2.41171150e-03,  -2.52806675e-03,
                         -1.83611531e-02,  -9.52912960e-03,  -9.75424703e-03,
                          5.53002767e-03,   2.62997206e-02,  -7.82964472e-03,
                         -2.06207559e-02,   8.41614604e-03,   7.90896639e-03,
                          3.88101628e-03,   4.57096240e-03,   8.23536655e-04,
                          1.53282927e-02,   1.60062574e-02,   2.73641362e-03,
                          8.29527387e-04,   4.77495231e-03,   2.49263961e-02,
                          2.31470615e-02,  -5.02714049e-03,   4.56739013e-04,
                          4.21150075e-03,   3.46531556e-03,   2.72002555e-02,
                          8.23285151e-03,  -1.23883532e-02,   1.69358011e-02,
                          9.29175783e-03,  -9.90994275e-03,   3.97267146e-03,
                          1.00100075e-03,   9.89232305e-03,   2.55952775e-02,
                          7.20116030e-03,  -2.70612352e-03,  -5.81245823e-03,
                         -4.94679390e-03,   1.45905484e-02,   5.22653339e-03,
                         -3.92947113e-03,   2.03081481e-02,   1.27472216e-02,
                         -1.37737552e-02,  -1.28623601e-02,  -1.98175461e-04,
                          1.69293452e-02,   1.82300117e-02,  -1.69269275e-03,
                         -5.10322629e-03,   1.07667167e-02,   1.59651376e-02,
                         -9.38354118e-04,  -1.01051386e-02,   9.88026150e-04,
                         -5.68609161e-04,  -8.18891393e-04,   7.07956683e-03,
                         -8.34842212e-03,  -1.18207689e-02,   2.13161972e-03,
                         -1.43534655e-03,   8.24616291e-03,   1.57286953e-02,
                         -7.54809519e-03,  -1.84134990e-02,  -2.22997051e-02,
                         -2.86991131e-02,  -5.01290057e-03,   2.45722998e-02,
                          2.05663424e-02,  -7.62749696e-03,  -1.87330283e-02,
                         -5.18312445e-03,  -7.33753806e-03,  -1.60722192e-02,
                         -1.59361940e-02,  -1.85154062e-02,   1.45858875e-03,
                          1.22529529e-02,  -1.57668833e-02,  -2.27890890e-02,
                         -1.65203884e-02,  -1.37890046e-02,   1.90568483e-03,
                         -1.30674234e-02,  -3.09832729e-02,  -1.76164079e-02,
                         -1.34993661e-02,   1.84821209e-03,  -6.28210790e-03,
                         -5.07904887e-02,  -2.25073956e-02,   1.02236243e-02,
                         -1.97581518e-02,  -2.64810608e-03,   1.45886745e-02,
                         -1.50812622e-02,  -5.42400405e-03,   4.13850648e-03,
                         -1.89478137e-02,  -3.21060121e-02,  -2.91388258e-02,
                          8.52236152e-03,   3.07630245e-02,  -8.34632386e-03,
                         -3.25241946e-02,  -1.63668394e-02,  -2.64855451e-03,
                         -1.88485496e-02,  -3.77072729e-02,  -6.60315761e-03,
                          7.79108936e-03,  -1.31759616e-02,   2.50411965e-03,
                         -1.15289846e-02,  -4.35567945e-02,  -1.97112821e-02,
                         -1.87244266e-02,  -1.36014167e-02,   2.08258200e-02,
                          7.51256710e-03,   6.64850511e-03,   6.17835904e-03,
                         -2.24302039e-02,  -1.15499515e-02,  -2.10200232e-02,
                         -2.26743203e-02,  -1.48194164e-01,  -6.03243470e-01,
                         -7.70839632e-01,  -3.08464378e-01,   3.71393822e-02,
                          3.05223223e-02,  -2.17182655e-02,  -3.88875790e-02,
                          9.79777426e-02,   2.48242170e-02,  -4.58005220e-01,
                         -5.16036570e-01,  -4.51680683e-02,   1.22093707e-01,
                         -2.91603692e-02,  -4.85065691e-02,   4.78319377e-02,
                          1.33822579e-02,  -4.56023812e-02,   9.38870534e-02,
                         -3.83082852e-02,  -4.81705993e-01,  -3.88150781e-01,
                         -1.43159166e-01,  -4.36931670e-01,  -4.46917534e-01,
                         -4.82944585e-03,   1.02482267e-01,  -1.27632720e-02,
                         -2.46876404e-01,  -7.05981851e-01,  -7.49889672e-01,
                         -2.07199425e-01,   1.28350526e-01,  -1.17900290e-01,
                         -5.40509164e-01,  -7.23383546e-01,  -6.71189606e-01,
                         -5.98473489e-01,  -6.72177374e-01,  -7.63120294e-01,
                         -4.79579002e-01,  -1.10462286e-01,  -3.50906670e-01,
                         -7.60358036e-01,  -6.92187369e-01,  -5.99572480e-01,
                         -6.98136330e-01,  -6.64784729e-01,  -6.37126267e-01,
                         -6.99730575e-01,  -6.86940551e-01,  -6.72177970e-01,
                         -6.70901179e-01,  -6.50677502e-01,  -6.77327871e-01,
                         -6.77551448e-01,  -6.48337483e-01,  -6.74397469e-01,
                         -6.86197937e-01,  -6.63481057e-01,  -6.51831985e-01,
                         -6.53088927e-01,  -6.82604194e-01,  -6.91892624e-01,
                         -6.64915502e-01,  -6.62370205e-01,  -6.54984832e-01,
                         -6.45427704e-01,  -6.73075020e-01,  -6.76978946e-01,
                         -6.62551582e-01,  -6.78933859e-01,  -6.79396749e-01,
                         -6.62354946e-01,  -6.67778254e-01,  -6.69189811e-01,
                         -6.63568020e-01,  -6.71763062e-01,  -6.69944227e-01,
                         -6.66944325e-01,  -6.76928639e-01,  -6.69073820e-01,
                         -6.74274564e-01,  -6.90950513e-01,  -6.67117059e-01,
                         -6.77943289e-01,  -7.03847110e-01,  -6.45777285e-01,
                         -6.23190343e-01,  -6.64601684e-01,  -6.76917791e-01,
                         -6.95974290e-01,  -6.77158892e-01,  -6.45268857e-01,
                         -6.92434907e-01,  -6.92007363e-01,  -6.64361954e-01,
                         -6.93799436e-01,  -6.76535547e-01,  -6.67516470e-01,
                         -6.85679674e-01,  -6.71953857e-01,  -7.03678668e-01,
                         -6.97185695e-01,  -6.50347888e-01,  -6.87030375e-01,
                         -6.93206608e-01,  -6.75963402e-01,  -6.92277014e-01,
                         -6.88256025e-01,  -7.09136784e-01,  -6.68052256e-01,
                         -6.73361123e-01,  -7.94790089e-01,  -5.07556915e-01,
                         -9.89370197e-02,  -3.73454034e-01,  -7.71179557e-01,
                         -7.20493257e-01,  -6.63990915e-01,  -7.03566670e-01,
                         -6.86894417e-01,  -6.92781985e-01,  -6.97697341e-01,
                         -6.91613257e-01,  -7.00939715e-01,  -7.12305069e-01,
                         -7.18066156e-01,  -6.90411627e-01,  -6.76839292e-01,
                         -7.02761769e-01,  -7.25838423e-01,  -7.34352291e-01,
                         -6.96503997e-01,  -6.73413575e-01,  -7.16649890e-01,
                         -7.24138677e-01,  -6.98580801e-01,  -6.92710221e-01,
                         -7.13458896e-01,  -7.43913233e-01,  -6.85764372e-01,
                         -6.90231025e-01,  -8.13882053e-01,  -5.84182739e-01,
                         -1.68253392e-01,  -3.31376493e-01,  -7.60717332e-01,
                         -7.71431983e-01,  -6.80598199e-01,  -7.40404785e-01,
                         -6.91108108e-01,  -7.19031334e-01,  -8.09305429e-01,
                         -4.21886593e-01,  -7.01946542e-02,  -5.61137736e-01,
                         -9.50433135e-01,  -4.23819363e-01,  -1.16917692e-01,
                         -5.51163554e-01,  -5.57281911e-01,   2.47272756e-02,
                          3.07770409e-02,  -5.80907524e-01,  -8.33946168e-01,
                         -6.59635723e-01,  -6.86081946e-01,  -8.17744732e-01,
                         -4.96804059e-01,  -1.25274241e-01,  -5.04759610e-01,
                         -9.23162997e-01,  -4.65245396e-01,  -9.56462175e-02,
                         -5.04820704e-01,  -8.15808475e-01,  -7.67839432e-01,
                         -6.83521569e-01,  -3.51836711e-01,   3.80478948e-02,
                         -9.00845081e-02,  -6.17378771e-01,  -8.71508062e-01,
                         -5.41333079e-01,  -6.39948025e-02,   1.95425320e-02,
                         -3.81983876e-01,  -8.40172231e-01,  -7.22853124e-01,
                         -2.56564081e-01,  -6.33185506e-02,   2.88883671e-02,
                         -7.20439553e-02,  -5.39775610e-01,  -5.22607267e-01,
                         -1.19821467e-01,  -4.59497988e-01,  -9.72068906e-01,
                         -5.56517184e-01,  -3.17714438e-02,  -4.68576252e-01,
                         -9.89662886e-01,  -5.38699627e-01,  -9.63826329e-02,
                         -4.75645542e-01,  -6.02699637e-01,  -1.20998971e-01,
                          7.29425848e-02,  -8.92764479e-02,  -1.34045556e-01,
                          1.78258121e-02,   1.68957077e-02,  -4.19602722e-01,
                         -6.45342529e-01,  -2.21205816e-01,   6.37125298e-02,
                         -6.78104311e-02,  -8.50936323e-02,  -3.08741108e-02,
                         -6.94900379e-02,  -4.67372313e-02,  -1.98190678e-02,
                         -6.25247955e-02,  -7.05620274e-02,  -1.56848866e-04,
                         -3.40506211e-02,  -4.77783293e-01,  -9.21989024e-01,
                         -5.66324234e-01,  -6.93094060e-02,  -4.23964918e-01,
                         -6.56633079e-01,  -5.81544861e-02,   1.10324226e-01,
                         -4.78591442e-01,  -5.97640693e-01,  -1.09741151e-01,
                          7.74102658e-02,  -9.72450823e-02,  -3.91762070e-02,
                          4.44144197e-02,  -4.09760624e-01,  -8.56811404e-01,
                         -6.09838843e-01,  -1.69310614e-01,  -1.25759728e-02,
                          7.09240735e-02,  -6.20941781e-02,  -5.36012590e-01,
                         -5.42366087e-01,   9.26873833e-02,   9.81990322e-02,
                         -5.79882741e-01,  -5.52324772e-01,   4.14344035e-02,
                          9.87602621e-02,  -3.77173752e-01,  -7.85446167e-01,
                         -6.74129248e-01,  -1.69854954e-01,   1.33228451e-01,
                         -7.41309673e-02,  -6.67681277e-01,  -8.37444425e-01,
                         -2.62815714e-01,  -1.32126272e-01,  -4.95724678e-01,
                         -3.01215887e-01,  -1.64829656e-01,  -5.52909732e-01,
                         -7.42036760e-01,  -7.12610006e-01,  -4.65075582e-01,
                         -7.21839070e-02,  -3.38616699e-01,  -8.46714616e-01,
                         -5.17580211e-01,  -1.78246759e-02,  -3.29065591e-01,
                         -7.63094783e-01,  -6.19283438e-01,  -5.79718530e-01,
                         -7.81372249e-01,  -4.42686945e-01,  -4.87082526e-02,
                         -3.54910463e-01,  -7.12201595e-01,  -6.81064129e-01,
                         -5.94298959e-01,  -6.36472404e-01,  -7.41985321e-01,
                         -5.16411245e-01,  -8.37003663e-02,  -2.34950900e-01,
                         -6.83038473e-01,  -6.80754960e-01,  -5.82249105e-01,
                         -6.62731349e-01,  -6.50285244e-01,  -6.30121529e-01,
                         -6.58161521e-01,  -6.21686339e-01,  -6.11241162e-01,
                         -6.23971999e-01,  -6.45648599e-01,  -6.69853449e-01,
                         -5.77043831e-01,  -6.06741846e-01,  -7.46207058e-01,
                         -4.17601228e-01,  -2.96864677e-02,  -3.41663808e-01,
                         -7.24651754e-01,  -6.41081631e-01,  -5.74206769e-01,
                         -6.45504653e-01,  -6.43074811e-01,  -6.22979224e-01,
                         -6.26452327e-01,  -6.40638530e-01,  -6.37233555e-01,
                         -6.21984780e-01,  -6.45694554e-01,  -6.40734196e-01,
                         -6.11238658e-01,  -6.24493778e-01,  -6.17335200e-01,
                         -6.08447254e-01,  -6.38712645e-01,  -6.42750561e-01,
                         -6.23351455e-01,  -6.05744720e-01,  -6.07595980e-01,
                         -6.39919460e-01,  -6.40792608e-01,  -6.12596095e-01,
                         -6.05072856e-01,  -6.20208502e-01,  -6.48942769e-01,
                         -6.40460670e-01,  -6.08546972e-01,  -6.17240429e-01,
                         -6.21778369e-01,  -6.15950644e-01,  -6.36773765e-01,
                         -6.52033746e-01,  -6.55601621e-01,  -6.36593461e-01,
                         -6.10355675e-01,  -6.29069686e-01,  -6.40322149e-01,
                         -6.29366815e-01,  -6.34639442e-01,  -6.20479226e-01,
                         -6.20701849e-01,  -6.51974380e-01,  -6.44607663e-01,
                         -6.27921820e-01,  -6.29722178e-01,  -6.26079619e-01,
                         -6.28024280e-01,  -6.30122900e-01,  -6.36819780e-01,
                         -6.31672680e-01,  -6.09223187e-01,  -6.39421940e-01,
                         -6.70851350e-01,  -6.32040083e-01,  -6.06202722e-01,
                         -6.19937062e-01,  -6.43267870e-01,  -6.51315153e-01,
                         -6.26613200e-01,  -6.40825927e-01,  -6.68142319e-01,
                         -6.44656658e-01,  -6.37713790e-01,  -6.34353518e-01,
                         -6.47679090e-01,  -6.71474993e-01,  -5.94464839e-01,
                         -6.46839321e-01,  -7.85450876e-01,  -4.42832917e-01,
                         -3.88637111e-02,  -3.39113146e-01,  -7.39114642e-01,
                         -6.71881914e-01,  -6.03679657e-01,  -6.75669611e-01,
                         -6.49858534e-01,  -6.28108859e-01,  -6.75110340e-01,
                         -6.67573154e-01,  -6.30753636e-01,  -6.57420337e-01,
                         -6.60623968e-01,  -6.32130027e-01,  -7.40431070e-01,
                         -6.71439052e-01,  -1.71806082e-01,  -1.06818564e-01,
                         -7.28041947e-01,  -7.63271630e-01,  -1.14773855e-01,
                          8.47302601e-02,  -3.61213386e-02,   2.57054493e-02,
                          1.49817253e-02,  -2.83952355e-02,   6.52404455e-03,
                         -2.89792046e-02,  -1.78490542e-02,   2.39805449e-02,
                         -1.46233374e-02,  -3.90568399e-04,   1.08854426e-02,
                         -2.83407569e-02,  -5.27263340e-03,   3.41497082e-03,
                         -6.81196945e-03,   8.46727565e-03,  -1.91732850e-02,
                         -8.93578772e-03,   3.13486941e-02,  -4.63083759e-03,
                         -2.27747858e-02,  -9.06676799e-03,  -1.06943632e-02,
                          1.01667279e-02,   9.37489152e-04,  -1.96515992e-02,
                          3.42422910e-03,   4.75419313e-03,  -1.50287861e-03,
                         -7.37513229e-03,  -2.83707753e-02,   2.14004517e-03,
                          1.37654580e-02,  -3.19925249e-02,  -1.32474983e-02,
                          2.08831485e-02,  -1.17643061e-03,  -1.13369599e-02,
                         -1.11093111e-02,  -7.36822840e-03,   7.13545410e-03,
                          2.32526194e-03,   2.46375427e-03,   2.76151404e-04,
                         -2.01492645e-02,  -1.12583591e-02,  -1.11399218e-03,
                         -9.82006546e-03,   5.73382573e-03,   7.12406542e-03,
                         -1.33991251e-02,   2.31150258e-03,   2.24649310e-02,
                          5.20194601e-03,  -1.69769675e-02,  -1.28404154e-02,
                          9.02057160e-03,   2.01589074e-02,   1.33703724e-02,
                         -2.95975339e-03,  -1.65545549e-02,  -9.69715882e-03,
                         -7.56997615e-04,  -4.43954999e-03,   2.61687092e-04,
                          4.67743445e-03,   1.60279940e-03,   4.52588731e-03,
                         -1.19622891e-04,  -1.15056783e-02,  -1.06874909e-02,
                         -1.56522100e-03,   1.35033869e-03,  -5.30976336e-03,
                          6.50109083e-04,   1.15343183e-02,   5.27154443e-05,
                          2.49729608e-03,   1.82529502e-02,   3.86656797e-03,
                         -9.33548668e-04,   1.33376000e-02,   1.67267013e-03,
                         -1.30872373e-02,  -6.37648627e-03,   1.62163824e-02,
                          2.87331361e-02,  -1.17952202e-03,  -1.76341888e-02,
                          4.79451055e-03,   1.32144208e-03,  -3.97387287e-03,
                          1.34989498e-02,   5.76003129e-03,  -2.36988836e-03,
                          2.72572949e-03,  -1.23005584e-02,  -1.13471635e-02,
                          1.10328412e-02,   2.78216111e-03,  -1.46053331e-02,
                         -5.65450406e-03,  -3.03886668e-03,  -1.24755558e-02,
                          2.17301026e-03,   1.32021988e-02,  -4.01745830e-03,
                         -4.54520527e-03,  -3.10372375e-03,  -1.97195485e-02,
                         -2.84310989e-03,   1.25840781e-02,  -1.45156160e-02,
                         -2.29362641e-02,  -1.41640995e-02,  -1.13409963e-02,
                         -2.91352539e-04,  -1.06047904e-02,  -1.60896629e-02,
                          1.21931573e-02,   2.80165509e-03,  -3.29831280e-02,
                         -2.31348388e-02,   5.05052693e-03,   7.72182737e-03,
                         -5.78029407e-03,  -5.53287892e-03,   5.22534829e-03,
                         -3.08700092e-03,  -1.36695905e-02,  -1.49509069e-02,
                         -1.63824726e-02,  -4.34981706e-03,  -4.97280760e-03,
                         -2.52039395e-02,  -1.80256870e-02,  -3.03063332e-03,
                         -1.18233319e-02,  -1.82477441e-02,  -4.08957159e-04,
                          2.16012858e-02,   3.98116140e-03,  -2.26281229e-02,
                         -1.94840021e-02,  -2.79186815e-02,  -1.99247394e-02,
                          1.15485266e-02,  -3.99884535e-03,  -7.77310086e-03,
                          1.20640993e-02,  -1.73192732e-02,  -2.32450590e-02,
                          4.10571788e-03,   3.12376232e-03,   6.96777692e-03,
                         -9.45999566e-03,  -3.37929539e-02,  -8.10115132e-03,
                          3.47460597e-03,  -2.07308959e-03,   5.51790232e-04,
                         -1.94890164e-02,  -1.11551546e-02,   1.11207636e-02,
                         -3.94263770e-03,  -8.00215919e-03,  -8.39093421e-03,
                         -6.71863183e-03,   3.95130366e-03,  -1.77626368e-02,
                         -7.18640769e-03,   2.37025041e-02,  -1.06149772e-02,
                         -1.64952893e-02,   1.23456810e-02,   6.80190977e-04,
                          6.29364094e-03,   4.54661483e-03,  -1.46588655e-02,
                          1.30742630e-02,   1.03217671e-02,  -2.21262295e-02,
                         -2.53517879e-04,   1.26580335e-02,  -5.07465005e-03,
                         -1.29721472e-02,  -1.76868401e-02,  -2.77485698e-03,
                          1.47675481e-02,   7.17376918e-03,   4.33708262e-03,
                          1.43967783e-02,   7.59506039e-03,  -2.13619769e-02,
                         -1.11021027e-02,   1.73444375e-02,  -5.83398668e-03,
                          9.70486365e-03,  -1.21122018e-01,  -6.09560847e-01,
                         -7.93964684e-01,  -3.19090128e-01,   4.91195656e-02,
                          3.69040444e-02,  -1.27254697e-02,  -2.58613215e-03,
                          1.34062424e-01,   4.53177877e-02,  -4.53461200e-01,
                         -5.24403572e-01,  -4.80552427e-02,   1.17585152e-01,
                         -2.60454491e-02,  -2.56762970e-02,   5.52754328e-02,
                          2.32564635e-03,  -4.72911820e-02,   1.11416131e-01,
                         -1.99893732e-02,  -4.91231591e-01,  -3.90114009e-01,
                         -1.29278839e-01,  -4.54118878e-01,  -4.51456040e-01,
                          2.47988272e-02,   1.18805259e-01,  -4.77964571e-03,
                         -2.53901690e-01,  -7.16118217e-01,  -7.37605155e-01,
                         -2.07105935e-01,   1.47744507e-01,  -6.76030442e-02,
                         -5.29878438e-01,  -7.30675638e-01,  -6.73281312e-01,
                         -6.07841432e-01,  -6.74881816e-01,  -7.82053173e-01,
                         -4.82926369e-01,  -7.81303570e-02,  -3.45511138e-01,
                         -7.55001247e-01,  -6.73895419e-01,  -5.95943272e-01,
                         -6.85930073e-01,  -6.91334784e-01,  -6.72385275e-01,
                         -6.53451920e-01,  -6.44930840e-01,  -6.67925239e-01,
                         -6.59685850e-01,  -6.51703835e-01,  -6.45681798e-01,
                         -6.40594244e-01,  -6.80707335e-01,  -6.81681693e-01,
                         -6.33063257e-01,  -6.34018481e-01,  -6.61689997e-01,
                         -6.72379911e-01,  -6.65863514e-01,  -6.47115231e-01,
                         -6.53863072e-01,  -6.73215091e-01,  -6.59328818e-01,
                         -6.45364344e-01,  -6.56342149e-01,  -6.54130876e-01,
                         -6.47682965e-01,  -6.56460941e-01,  -6.51999354e-01,
                         -6.52859628e-01,  -6.70337796e-01,  -6.61305189e-01,
                         -6.52312398e-01,  -6.79977655e-01,  -6.96168184e-01,
                         -6.60472929e-01,  -6.18905246e-01,  -6.41450584e-01,
                         -6.82527304e-01,  -6.73043013e-01,  -6.60482764e-01,
                         -6.61752045e-01,  -6.55661941e-01,  -6.65121675e-01,
                         -6.72374427e-01,  -6.64432108e-01,  -6.62604511e-01,
                         -6.68252707e-01,  -6.79007888e-01,  -6.79209828e-01,
                         -6.74377084e-01,  -6.68761909e-01,  -6.49219275e-01,
                         -6.63267672e-01,  -6.95464909e-01,  -6.76585019e-01,
                         -6.56534612e-01,  -6.75394297e-01,  -6.91127539e-01,
                         -6.82101846e-01,  -6.78863823e-01,  -7.04248071e-01,
                         -7.01227069e-01,  -6.74999535e-01,  -6.90784276e-01,
                         -7.17946291e-01,  -7.03110516e-01,  -6.35398626e-01,
                         -6.73906505e-01,  -7.82392979e-01,  -4.87933695e-01,
                         -1.06924988e-01,  -3.92460823e-01,  -7.89748907e-01,
                         -7.17625678e-01,  -6.47142887e-01,  -6.95201933e-01,
                         -6.90240204e-01,  -7.10752368e-01,  -7.09759355e-01,
                         -7.06331611e-01,  -7.20581472e-01,  -7.01098680e-01,
                         -7.10477710e-01,  -7.12001204e-01,  -7.00094938e-01,
                         -7.02186286e-01,  -6.70469046e-01,  -6.88597918e-01,
                         -7.26100206e-01,  -7.10946083e-01,  -7.18844116e-01,
                         -7.17081726e-01,  -7.22803771e-01,  -7.14738607e-01,
                         -6.63950741e-01,  -7.24693120e-01,  -7.29406059e-01,
                         -6.78613067e-01,  -7.96361566e-01,  -5.83296835e-01,
                         -1.45073816e-01,  -3.55619311e-01,  -7.73063660e-01,
                         -7.30597913e-01,  -6.80047691e-01,  -7.51564264e-01,
                         -6.90761328e-01,  -7.23230362e-01,  -7.96244264e-01,
                         -4.28296983e-01,  -9.34717208e-02,  -5.85023999e-01,
                         -9.71413970e-01,  -3.98997396e-01,  -1.01510063e-01,
                         -5.57253003e-01,  -5.24751782e-01,   2.03531105e-02,
                         -5.09468885e-03,  -5.56577504e-01,  -8.07024062e-01,
                         -6.92203462e-01,  -7.34261692e-01,  -8.08568716e-01,
                         -4.52715933e-01,  -1.17230527e-01,  -4.88576472e-01,
                         -9.10033762e-01,  -5.13533890e-01,  -1.19318433e-01,
                         -4.68846947e-01,  -7.74306417e-01,  -7.63733208e-01,
                         -7.37245679e-01,  -3.69710654e-01,   7.30588958e-02,
                         -9.94595885e-02,  -6.40747786e-01,  -8.83037090e-01,
                         -5.60122311e-01,  -6.15059957e-02,   2.99795661e-02,
                         -3.71588171e-01,  -8.51645052e-01,  -7.70756721e-01,
                         -2.57856309e-01,  -2.94064879e-02,   1.78000554e-02,
                         -1.15305491e-01,  -5.74452460e-01,  -5.01491606e-01,
                         -7.79827535e-02,  -4.55077946e-01,  -9.65787768e-01,
                         -5.80849171e-01,  -7.41668791e-02,  -4.36931223e-01,
                         -9.78766978e-01,  -5.90195954e-01,  -1.06456488e-01,
                         -4.55681086e-01,  -5.90999484e-01,  -1.43096715e-01,
                          2.73398850e-02,  -8.85222182e-02,  -1.38701960e-01,
                         -3.00798062e-02,  -1.65031850e-02,  -4.34180409e-01,
                         -6.29306853e-01,  -2.25626573e-01,   3.17461975e-03,
                         -8.46644938e-02,  -1.02934755e-01,  -7.41425455e-02,
                         -3.31129879e-02,  -3.63214836e-02,  -6.86376691e-02,
                         -5.96078858e-02,  -8.46560001e-02,  -2.90816892e-02,
                         -4.55423631e-02,  -5.22076726e-01,  -9.17239845e-01,
                         -5.53101540e-01,  -1.24624722e-01,  -4.33705628e-01,
                         -6.60553634e-01,  -8.19675624e-02,   1.51443481e-01,
                         -4.62850988e-01,  -6.05136514e-01,  -1.07345752e-01,
                          2.07720958e-02,  -1.11967549e-01,  -2.32990235e-02,
                          4.43187729e-03,  -4.00713801e-01,  -8.64320695e-01,
                         -6.70748353e-01,  -1.41481563e-01,   1.32417157e-02,
                          3.89051028e-02,  -6.43392056e-02,  -5.34628868e-01,
                         -5.33976257e-01,   8.14600661e-02,   5.64719029e-02,
                         -5.63661814e-01,  -5.52163541e-01,  -7.63068441e-03,
                          9.15447921e-02,  -3.93518239e-01,  -8.08891654e-01,
                         -6.61021531e-01,  -1.77999839e-01,   1.19692907e-01,
                         -6.87025711e-02,  -6.55383766e-01,  -8.23637724e-01,
                         -2.88305044e-01,  -1.66772842e-01,  -5.07615507e-01,
                         -3.08672786e-01,  -1.33475780e-01,  -5.24707496e-01,
                         -7.73096979e-01,  -7.40845263e-01,  -4.64455366e-01,
                         -4.72129323e-02,  -3.05122703e-01,  -8.60048354e-01,
                         -5.45299172e-01,  -5.00476360e-03,  -3.15395057e-01,
                         -7.87833512e-01,  -6.57822490e-01,  -5.93964159e-01,
                         -7.69216299e-01,  -4.14807051e-01,  -3.65382582e-02,
                         -4.03322518e-01,  -7.81797409e-01,  -6.97095215e-01,
                         -5.48265398e-01,  -5.91776073e-01,  -7.66281068e-01,
                         -5.50213397e-01,  -7.34284818e-02,  -2.49195144e-01,
                         -7.03963995e-01,  -6.59327924e-01,  -5.60895264e-01,
                         -6.61309302e-01,  -6.64184570e-01,  -6.18178248e-01,
                         -6.19582772e-01,  -6.39844120e-01,  -6.42443359e-01,
                         -6.23585999e-01,  -6.68808043e-01,  -6.70285642e-01,
                         -5.53760171e-01,  -6.15474641e-01,  -7.40195036e-01,
                         -4.07340676e-01,  -3.28235887e-02,  -3.26251388e-01,
                         -7.33072639e-01,  -6.71685100e-01,  -5.84330082e-01,
                         -6.34307444e-01,  -6.08304620e-01,  -6.12354994e-01,
                         -6.43513680e-01,  -6.19623482e-01,  -6.21695220e-01,
                         -6.47504389e-01,  -6.51719928e-01,  -6.22275531e-01,
                         -5.93336463e-01,  -6.15559280e-01,  -6.38763011e-01,
                         -6.32306576e-01,  -6.16709113e-01,  -6.05125606e-01,
                         -6.20836198e-01,  -6.38704836e-01,  -6.43772662e-01,
                         -6.29986644e-01,  -5.98263383e-01,  -6.12416923e-01,
                         -6.39319181e-01,  -6.27679765e-01,  -6.08862460e-01,
                         -5.95627367e-01,  -6.38430238e-01,  -6.62301004e-01,
                         -5.89176059e-01,  -5.90101123e-01,  -6.44462287e-01,
                         -6.32808328e-01,  -6.31381929e-01,  -6.22536778e-01,
                         -6.28598809e-01,  -6.44205928e-01,  -5.82424879e-01,
                         -6.06655777e-01,  -6.75000012e-01,  -6.21986270e-01,
                         -6.19466186e-01,  -6.41789019e-01,  -6.09525442e-01,
                         -6.27071083e-01,  -6.14843249e-01,  -6.14745736e-01,
                         -6.68598294e-01,  -6.38024449e-01,  -6.18286729e-01,
                         -6.35125637e-01,  -6.18416429e-01,  -6.37955248e-01,
                         -6.32914960e-01,  -6.23043716e-01,  -6.57330453e-01,
                         -6.37767255e-01,  -6.36233628e-01,  -6.51014566e-01,
                         -6.24309421e-01,  -6.44002259e-01,  -6.32271349e-01,
                         -6.17963791e-01,  -6.81305707e-01,  -6.60393417e-01,
                         -6.38643742e-01,  -6.62164509e-01,  -5.92180610e-01,
                         -6.62753761e-01,  -7.65083432e-01,  -4.22063828e-01,
                         -7.63790533e-02,  -3.45924973e-01,  -7.31453896e-01,
                         -6.98246181e-01,  -5.97188532e-01,  -6.70507133e-01,
                         -6.77993178e-01,  -6.21871293e-01,  -6.43370092e-01,
                         -6.67398393e-01,  -6.67300165e-01,  -6.80660307e-01,
                         -6.41863823e-01,  -6.19357049e-01,  -7.66224384e-01,
                         -6.99033260e-01,  -1.68171883e-01,  -1.21143416e-01,
                         -7.76408911e-01,  -7.55099177e-01,  -8.44847709e-02,
                          5.67085370e-02,  -4.62947451e-02,   3.68142016e-02,
                         -1.05762458e-03,  -3.17625366e-02,   2.87774089e-03,
                         -3.45057249e-02,   1.28317496e-03,   3.62709314e-02,
                         -2.57536639e-02,  -4.44394052e-02,  -2.02503223e-02,
                          2.59141810e-03,   1.35313226e-02,  -1.23808244e-02,
                         -2.81977635e-02,  -5.33087505e-03,   1.53802391e-02,
                         -1.26338145e-02,  -4.37285565e-02,  -1.90078020e-02,
                         -3.10176960e-03,  -5.32639027e-03,   9.22279991e-03,
                          7.71088712e-03,  -4.70018014e-04,  -2.11962853e-02,
                         -2.76611745e-02,   1.55238248e-02,   3.47503857e-03,
                         -2.35939492e-02,   2.54892707e-02,   2.10385714e-02,
                         -2.55995709e-02,  -1.10490834e-02,  -1.72775623e-03,
                         -1.22258822e-02,  -6.82710623e-03,   6.27233693e-03,
                          1.51491463e-02,   1.40571315e-03,  -1.12318974e-02,
                         -1.35999117e-02,  -4.17147204e-03,   2.28050109e-02,
                          4.79603186e-03,  -1.58173721e-02,   1.29379174e-02,
                         -3.79046611e-03,  -1.54151106e-02,   2.91131809e-02,
                          1.41548412e-02,  -4.82588960e-03,   3.20753530e-02,
                          1.12063484e-02,  -3.33489962e-02,  -3.02634062e-03,
                          2.78590936e-02,  -7.31697073e-03,  -2.69447677e-02,
                          8.20658170e-03,   1.67064704e-02,   1.00305108e-02,
                          3.28555442e-02,   2.53262538e-02,   6.48186915e-03,
                          1.44208688e-02,   5.51679684e-03,   6.65702671e-03,
                          2.18999740e-02,   9.37827118e-03,   6.07169466e-03,
                          1.95593666e-02,   2.93941684e-02,   2.72232573e-02,
                         -6.46629930e-03,  -1.47759896e-02,   1.65782627e-02,
                          7.90332817e-03,  -1.81754380e-02,  -1.46904849e-02,
                          1.07953732e-03,   2.15505883e-02,   1.31855560e-02,
                         -1.58477575e-02,  -7.45941931e-03,   4.77621751e-03,
                         -8.62173829e-03,  -8.25152826e-03,   1.18950127e-04,
                         -2.70545075e-04,   2.74559204e-03,   6.44552428e-03,
                          6.52984297e-03,   9.21358936e-04,  -1.33219017e-02,
                         -2.34294105e-02,  -8.87722615e-03,   1.75423417e-02,
                          3.37780896e-03,  -2.44622566e-02,   9.53867566e-03,
                          2.97849942e-02,  -2.20879316e-02,  -2.31560636e-02,
                          2.68731508e-02,   1.47840949e-02,  -1.26744844e-02,
                         -6.22751843e-03,   3.73031828e-03,   1.31146125e-02,
                         -2.17003096e-03,  -1.08548161e-02,   1.35738505e-02,
                         -1.10549293e-02,  -2.39640139e-02,   3.53535302e-02,
                          2.13868842e-02,  -2.24410966e-02,   1.42488517e-02,
                          1.29106380e-02,  -7.19233416e-03,   1.98738817e-02,
                         -5.67869144e-03,  -2.77613997e-02,   1.43245365e-02,
                          2.04302538e-02,   2.05985876e-03,  -3.47095396e-04,
                          1.05938017e-02,   3.90660688e-02,   2.06595846e-02,
                         -1.25805857e-02,   1.17561528e-02,   2.24598702e-02,
                          1.11346198e-02,   7.13135349e-03,  -1.17480634e-02,
                         -3.19281616e-03,   1.65056996e-02,   1.24451369e-02,
                          2.27006208e-02,   1.26814516e-02,  -1.03649199e-02,
                          7.23925093e-03,   1.66440327e-02,   7.63574615e-03,
                          3.06132389e-03,   5.88439545e-03,   2.21766550e-02,
                         -3.98434885e-03,  -2.96286736e-02,   9.98492353e-03,
                          4.62122681e-03,  -1.95856206e-02,   2.21051667e-02,
                          1.54135246e-02,  -3.00330650e-02,  -2.08597779e-02,
                         -4.20877803e-03,   7.03742355e-03,   1.45062292e-02,
                          6.01953967e-03,   7.67361280e-03,  -3.73124750e-03,
                         -1.63882077e-02,   9.68812406e-03,   3.07897422e-02,
                          1.61894709e-02,  -2.01878194e-02,  -2.56403852e-02,
                          1.50862439e-02,   6.32405933e-03,  -2.61938889e-02,
                          1.20861083e-03,   9.43824276e-03,  -4.84125130e-03,
                          7.55264470e-03,  -1.06868027e-02,  -2.51672901e-02,
                         -3.06489598e-03,  -7.09632179e-04,   2.50293431e-03,
                          3.59253096e-03,  -1.00253532e-02,   7.00405799e-04,
                         -2.16974271e-03,  -1.13289831e-02,   4.57064202e-03,
                         -9.71903931e-03,  -1.57868098e-02,   3.25917918e-03,
                         -5.85226296e-03,   6.14060415e-03,   8.49223230e-03,
                         -2.44949330e-02,  -1.69015229e-02,  -6.98087970e-03,
                          1.75718148e-03,  -1.49775103e-01,  -6.19941652e-01,
                         -7.90190220e-01,  -3.28570366e-01,   4.95675243e-02,
                          7.52514973e-02,   1.40692247e-02,  -3.16161141e-02,
                          7.94304609e-02,   9.29705985e-03,  -4.42358524e-01,
                         -4.99576986e-01,  -6.50808588e-02,   9.66628194e-02,
                         -1.70643143e-02,  -1.63117368e-02,   5.57041392e-02,
                         -9.72906686e-03,  -4.94228974e-02,   1.36039197e-01,
                         -2.26363242e-02,  -5.23142517e-01,  -4.00391400e-01,
                         -1.17384650e-01,  -4.43021536e-01,  -4.67301369e-01,
                          4.71619796e-03,   1.32887155e-01,   6.97330339e-03,
                         -2.60038048e-01,  -7.29001462e-01,  -7.65063465e-01,
                         -2.25135580e-01,   1.33770689e-01,  -9.23797041e-02,
                         -5.43784380e-01,  -7.32960403e-01,  -6.54043674e-01,
                         -5.95070422e-01,  -7.00822294e-01,  -7.83733726e-01,
                         -4.64059085e-01,  -7.23697841e-02,  -3.27893138e-01,
                         -7.81491637e-01,  -7.45072067e-01,  -6.39033437e-01,
                         -7.08229542e-01,  -6.67572677e-01,  -6.34452701e-01,
                         -6.86354101e-01,  -6.71721697e-01,  -6.51262105e-01,
                         -6.63433254e-01,  -6.75058067e-01,  -6.84074581e-01,
                         -6.58171535e-01,  -6.55390143e-01,  -6.73847020e-01,
                         -6.44913197e-01,  -6.51626945e-01,  -6.83715761e-01,
                         -6.61630392e-01,  -6.53051734e-01,  -6.63937926e-01,
                         -6.62249804e-01,  -6.57116592e-01,  -6.35308862e-01,
                         -6.55300617e-01,  -7.01900482e-01,  -6.83499694e-01,
                         -6.55280232e-01,  -6.51346028e-01,  -6.53647006e-01,
                         -6.83154821e-01,  -6.93248272e-01,  -6.76412582e-01,
                         -6.66840971e-01,  -6.59557998e-01,  -6.81234419e-01,
                         -6.88722491e-01,  -6.60390317e-01,  -6.78052664e-01,
                         -7.02807724e-01,  -7.00636685e-01,  -7.02138305e-01,
                         -6.63438916e-01,  -6.47542059e-01,  -6.97999954e-01,
                         -6.96838677e-01,  -6.63670123e-01,  -6.61660254e-01,
                         -6.47264063e-01,  -6.55291259e-01,  -7.06460357e-01,
                         -7.26325631e-01,  -6.96461618e-01,  -6.63749278e-01,
                         -6.76919103e-01,  -7.13509858e-01,  -6.91607654e-01,
                         -6.49975181e-01,  -6.82457030e-01,  -7.07950056e-01,
                         -6.68627560e-01,  -6.78367317e-01,  -7.09022105e-01,
                         -6.74817502e-01,  -6.67588532e-01,  -6.97323442e-01,
                         -7.24897683e-01,  -7.33859003e-01,  -6.55606210e-01,
                         -6.94770098e-01,  -8.22708547e-01,  -5.03543794e-01,
                         -9.29539651e-02,  -3.64032447e-01,  -7.79010713e-01,
                         -7.24625766e-01,  -6.35172427e-01,  -7.31668532e-01,
                         -7.60673165e-01,  -6.95205629e-01,  -6.73811734e-01,
                         -7.36839294e-01,  -7.60904491e-01,  -6.91752434e-01,
                         -6.58468008e-01,  -6.98838830e-01,  -7.37454414e-01,
                         -7.28545189e-01,  -6.88993454e-01,  -6.70251191e-01,
                         -6.72766149e-01,  -6.95918322e-01,  -7.19128489e-01,
                         -7.15161324e-01,  -7.36870706e-01,  -7.29408562e-01,
                         -6.91082835e-01,  -7.35362470e-01,  -7.10850000e-01,
                         -6.78493679e-01,  -8.04638147e-01,  -5.96378684e-01,
                         -1.34124473e-01,  -2.95740843e-01,  -7.75266647e-01,
                         -7.99197376e-01,  -6.93772495e-01,  -7.11685658e-01,
                         -6.58375204e-01,  -7.43294835e-01,  -8.37838531e-01,
                         -4.15862083e-01,  -6.06195889e-02,  -5.67237854e-01,
                         -9.75105762e-01,  -4.42756891e-01,  -1.16482243e-01,
                         -5.33089817e-01,  -5.23534477e-01,   4.53422815e-02,
                          3.85688357e-02,  -5.76908112e-01,  -8.37974846e-01,
                         -6.64895177e-01,  -7.17747867e-01,  -8.24070215e-01,
                         -4.24641997e-01,  -9.22258198e-02,  -5.38988590e-01,
                         -9.53086197e-01,  -4.92257118e-01,  -7.52639547e-02,
                         -4.70891118e-01,  -8.45887542e-01,  -7.87303567e-01,
                         -6.81981504e-01,  -3.52266043e-01,   7.07417056e-02,
                         -7.64661282e-02,  -6.30022466e-01,  -8.83702874e-01,
                         -5.62359631e-01,  -4.40843031e-02,   5.59179485e-02,
                         -3.67766559e-01,  -8.22197020e-01,  -7.45155871e-01,
                         -2.93041557e-01,  -4.88995872e-02,   6.33871555e-02,
                         -3.15515138e-02,  -5.29359341e-01,  -5.46636522e-01,
                         -1.24230422e-01,  -4.66094017e-01,  -9.69022810e-01,
                         -5.34620404e-01,  -1.74413957e-02,  -4.32660103e-01,
                         -9.99832571e-01,  -6.01686835e-01,  -9.66270566e-02,
                         -4.66103464e-01,  -6.09485328e-01,  -1.10535614e-01,
                          4.83891405e-02,  -8.99735987e-02,  -1.09620139e-01,
                         -1.96202844e-02,  -2.51631737e-02,  -4.36476052e-01,
                         -6.20034099e-01,  -1.57957181e-01,   4.83789705e-02,
                         -1.17366508e-01,  -8.52537304e-02,  -3.09825372e-02,
                         -6.52475730e-02,  -4.38674167e-02,  -7.89371692e-03,
                         -3.37404944e-02,  -1.11765616e-01,  -5.32752723e-02,
                         -2.47056186e-02,  -4.60255235e-01,  -8.90522897e-01,
                         -5.79595089e-01,  -1.43448249e-01,  -4.27645892e-01,
                         -6.09264255e-01,  -1.00884316e-02,   1.57819554e-01,
                         -4.89296436e-01,  -6.30648017e-01,  -1.38369367e-01,
                          5.26280813e-02,  -7.04814419e-02,  -2.80983075e-02,
                          2.93388274e-02,  -3.94737333e-01,  -8.75511646e-01,
                         -6.23813689e-01,  -1.28286406e-01,   8.67296383e-03,
                          7.65623301e-02,  -6.61699548e-02,  -5.38726389e-01,
                         -5.18044233e-01,   7.21906871e-02,   8.19988772e-02,
                         -5.41953087e-01,  -5.78344107e-01,  -6.30695198e-04,
                          1.15294456e-01,  -3.83093476e-01,  -7.89321542e-01,
                         -6.60550654e-01,  -1.95056021e-01,   1.10036001e-01,
                         -7.68720284e-02,  -6.73469663e-01,  -8.41259003e-01,
                         -2.60335952e-01,  -1.16543591e-01,  -5.13249338e-01,
                         -3.44190359e-01,  -1.35612950e-01,  -5.21926343e-01,
                         -7.94469833e-01,  -7.40214944e-01,  -4.48420465e-01,
                         -7.51272291e-02,  -3.34122807e-01,  -8.54493737e-01,
                         -5.55313647e-01,  -1.52457673e-02,  -2.88367599e-01,
                         -7.54556060e-01,  -6.54641271e-01,  -6.06863320e-01,
                         -7.63523519e-01,  -4.10267502e-01,  -2.71945205e-02,
                         -3.54106545e-01,  -7.45034695e-01,  -6.91239119e-01,
                         -5.67311525e-01,  -6.41227365e-01,  -7.48266101e-01,
                         -4.90252078e-01,  -7.92214125e-02,  -2.50062019e-01,
                         -7.07027137e-01,  -7.15100765e-01,  -5.83802879e-01,
                         -6.50789380e-01,  -6.57864571e-01,  -6.28520548e-01,
                         -6.63295209e-01,  -6.57495499e-01,  -6.47805870e-01,
                         -6.38508201e-01,  -6.38447344e-01,  -6.75384760e-01,
                         -6.22362733e-01,  -6.40648663e-01,  -7.41909444e-01,
                         -4.22606200e-01,  -2.56525576e-02,  -3.05116415e-01,
                         -7.36994863e-01,  -6.86806619e-01,  -5.60898662e-01,
                         -6.28114760e-01,  -6.51400089e-01,  -6.05484009e-01,
                         -6.11983180e-01,  -6.36474848e-01,  -6.47322297e-01,
                         -6.49232507e-01,  -6.24116600e-01,  -6.42004490e-01,
                         -6.69539094e-01,  -6.14449620e-01,  -6.26955926e-01,
                         -6.87770605e-01,  -6.37522221e-01,  -6.18337989e-01,
                         -6.40014648e-01,  -6.20834053e-01,  -6.58465147e-01,
                         -6.62167907e-01,  -6.20213985e-01,  -6.48532271e-01,
                         -6.37296200e-01,  -6.17345810e-01,  -6.49898171e-01,
                         -6.29502773e-01,  -6.16519690e-01,  -6.25691295e-01,
                         -6.13201678e-01,  -6.28788590e-01,  -6.26147389e-01,
                         -6.32261515e-01,  -6.53125167e-01,  -6.08618319e-01,
                         -6.14498436e-01,  -6.44869089e-01,  -5.99971116e-01,
                         -6.22901917e-01,  -6.73099875e-01,  -6.56328678e-01,
                         -6.42036498e-01,  -5.93266368e-01,  -5.70464730e-01,
                         -6.30782664e-01,  -6.40773356e-01,  -6.39291406e-01,
                         -6.69426024e-01,  -6.35407805e-01,  -6.00176394e-01,
                         -6.19701922e-01,  -6.42484725e-01,  -6.51249051e-01,
                         -6.24566793e-01,  -6.12842798e-01,  -6.63138151e-01,
                         -6.69342637e-01,  -6.14789605e-01,  -6.08039916e-01,
                         -6.43321157e-01,  -6.66484118e-01,  -6.57331526e-01,
                         -6.25915945e-01,  -6.35392845e-01,  -6.58718526e-01,
                         -6.50938630e-01,  -6.43923283e-01,  -6.03185892e-01,
                         -6.50582075e-01,  -7.63705075e-01,  -4.52631712e-01,
                         -2.53102519e-02,  -2.97566980e-01,  -7.45149851e-01,
                         -6.99099600e-01,  -6.05051935e-01,  -6.49181843e-01,
                         -6.47419512e-01,  -6.60446465e-01,  -6.65196836e-01,
                         -6.58085823e-01,  -6.61687315e-01,  -6.60767317e-01,
                         -6.56803191e-01,  -6.09154224e-01,  -6.96765006e-01,
                         -7.01159298e-01,  -2.09265321e-01,  -1.06035694e-01,
                         -7.43429780e-01,  -7.27165461e-01,  -5.10706119e-02,
                          9.90240127e-02,  -3.06729544e-02,   1.22818490e-02,
                          2.81922705e-03,  -3.56685393e-03,   3.07482891e-02,
                          1.16499690e-02,  -2.44281860e-03,  -1.46382982e-02,
                         -1.12312725e-02,   1.65672414e-02,   4.10552556e-03,
                         -7.47522898e-03,   3.04525788e-03,  -4.38502477e-03,
                         -2.04994367e-03,   4.78582876e-03,  -1.10516781e-02,
                         -6.30379608e-03,   2.44886372e-02,   1.23632848e-02,
                         -2.53397729e-02,  -8.19272641e-03,   1.90540142e-02,
                          5.00402646e-03,   3.40181985e-03,   3.53089347e-03,
                         -1.40649481e-02,   6.91619888e-03,   3.63738462e-02,
                          1.34851420e-02,  -1.12931821e-02,   6.02372037e-03,
                          1.68293454e-02,  -6.94825081e-03,  -1.90144647e-02,
                         -9.66030080e-03,  -7.85948616e-03,  -3.24425031e-03,
                         -7.43696187e-03,  -2.22671889e-02,  -2.70895869e-03,
                          1.08621363e-02,  -1.66622605e-02,  -1.48228584e-02,
                          8.81892070e-03,   5.73517103e-03,   9.00543481e-03,
                          1.00700594e-02,  -8.69506877e-03,  -7.30085652e-03,
                         -3.72977369e-03,  -1.44533059e-02,  -4.95381001e-03,
                          6.30589481e-03,   9.56416037e-03,   1.65922139e-02,
                          6.46681234e-04,  -1.26832938e-02,  -6.74600713e-03,
                         -2.12410875e-02,  -2.15271544e-02,   1.58010179e-03,
                          1.02954498e-03,  -2.29791924e-03,  -2.11101249e-02,
                         -4.50891964e-02,   2.54041655e-03,   4.19304334e-02,
                          2.05952232e-03,  -1.92925390e-02,  -6.14608219e-03,
                         -6.20164908e-03,  -9.84947477e-03,   5.77771498e-05,
                          2.57651005e-02,   1.06218336e-02,  -2.72318106e-02,
                         -2.34152030e-04,   2.25430191e-03,  -4.05362546e-02,
                         -2.03594379e-03,   2.33146250e-02,  -2.86075696e-02,
                         -1.99032910e-02,   2.13646032e-02,   7.48818787e-03,
                         -2.26360839e-02,  -3.16544138e-02,   4.91674407e-04,
                          2.34014913e-02,  -6.77391049e-03,  -1.27489679e-02,
                          4.59769648e-03,  -2.17100815e-03,   5.09393588e-03,
                          5.14322380e-03,  -2.07973067e-02,  -2.70777326e-02,
                         -2.78315600e-02,  -2.12932751e-02,   7.78937526e-03,
                          1.24901477e-02,   2.19812663e-03,   1.12848049e-02,
                          1.14409812e-02,  -2.88930605e-03,  -1.87995993e-02,
                         -3.36705931e-02,  -1.65830199e-02,   2.79300064e-02,
                          3.44060771e-02,  -1.46887230e-03,  -1.05364090e-02,
                          8.33994802e-03,   5.45964437e-03,   3.91864264e-03,
                          2.05893777e-02,   1.21907061e-02,  -1.55801279e-03,
                          2.11600680e-02,   3.80854085e-02,   1.65420938e-02,
                         -8.68203025e-03,  -7.36914156e-03,   1.99255720e-02,
                          4.09531891e-02,   1.30998595e-02,  -2.32807472e-02,
                          1.52692175e-03,   2.64647696e-02,   3.45719443e-03,
                          7.00681284e-03,   1.02960737e-02,  -2.56114230e-02,
                         -1.07714580e-02,   1.12742651e-02,  -2.01196801e-02,
                         -5.39284898e-03,   2.17902511e-02,   3.08078597e-03,
                          1.82488654e-02,   3.43150310e-02,   1.29043590e-02,
                          5.43382345e-03,   3.38839670e-03,   1.51596544e-02,
                          2.26149727e-02,  -3.29296128e-03,  -1.24993746e-03,
                          1.77275098e-03,  -7.91087281e-03,   2.07681861e-02,
                          3.98774445e-03,  -2.61422619e-02,   1.97296720e-02,
                          2.02781949e-02,  -1.20986663e-02,   8.43794644e-03,
                          2.88517331e-04,  -9.95025970e-03,   2.45910734e-02,
                          3.69587801e-02,   2.55185664e-02,   1.23963784e-03,
                         -1.78203993e-02,  -8.29567388e-03,  -1.09281950e-02,
                         -1.47384917e-02,  -4.64748067e-04,   5.65522490e-03,
                          3.87829333e-03,  -1.41144432e-02,  -1.78607479e-02,
                          6.90790126e-03,   1.42507895e-03,  -1.42168312e-03,
                          1.29957581e-02,  -1.33408830e-02,  -2.27739532e-02,
                          7.48934131e-03,   1.06502818e-02,  -9.49935173e-04,
                         -7.92934094e-03,  -5.17277699e-03,   1.77740902e-02,
                          1.31336097e-02,  -2.27663442e-02,  -2.20729057e-02,
                          8.18579085e-03,   7.69784814e-03,  -7.09305424e-03,
                          3.84765072e-03,   2.69069802e-03,  -1.46917831e-02,
                          7.80968647e-03,   1.15007283e-02,  -3.01566292e-02,
                         -1.23725599e-02,  -1.39135242e-01,  -5.97436190e-01,
                         -7.81825960e-01,  -3.32855761e-01,   5.30823059e-02,
                          5.50514534e-02,   4.80365660e-03,   3.50265368e-03,
                          1.12917535e-01,   3.91566642e-02,  -4.51215208e-01,
                         -5.32835007e-01,  -3.47390138e-02,   1.14567347e-01,
                         -3.70051041e-02,   2.49285903e-03,   6.01388365e-02,
                         -2.10149605e-02,  -5.18457890e-02,   1.22492045e-01,
                          6.24444941e-03,  -4.86199439e-01,  -3.99628729e-01,
                         -1.17242172e-01,  -4.53878254e-01,  -4.42859620e-01,
                          3.28358747e-02,   8.69284198e-02,  -3.98529373e-05,
                         -2.31696606e-01,  -7.32540429e-01,  -7.32757270e-01,
                         -2.09139496e-01,   1.22663535e-01,  -7.24799037e-02,
                         -5.48916996e-01,  -7.42616236e-01,  -6.68880165e-01,
                         -6.24212623e-01,  -6.66939199e-01,  -7.66663671e-01,
                         -4.79274780e-01,  -4.31258790e-02,  -3.43597800e-01,
                         -7.98939943e-01,  -6.83873117e-01,  -5.87368369e-01,
                         -6.75397873e-01,  -6.69183910e-01,  -6.68631971e-01,
                         -6.66733682e-01,  -6.35310709e-01,  -6.34866178e-01,
                         -6.60437942e-01,  -6.86954200e-01,  -6.61416352e-01,
                         -6.46019638e-01,  -6.74984634e-01,  -6.57859206e-01,
                         -6.28193259e-01,  -6.44132555e-01,  -6.91857517e-01,
                         -7.03574419e-01,  -6.53579533e-01,  -6.58511996e-01,
                         -6.71396613e-01,  -6.27062023e-01,  -6.50965929e-01,
                         -6.72995448e-01,  -6.50667906e-01,  -6.90689743e-01,
                         -6.97234392e-01,  -6.50823057e-01,  -6.37682319e-01,
                         -6.48052156e-01,  -6.96141183e-01,  -6.94398463e-01,
                         -6.18864000e-01,  -6.24082983e-01,  -6.81975186e-01,
                         -6.98804736e-01,  -6.76469922e-01,  -6.40973806e-01,
                         -6.66600585e-01,  -6.98269069e-01,  -6.58670664e-01,
                         -6.47716880e-01,  -6.88449919e-01,  -6.98189318e-01,
                         -6.62863672e-01,  -6.46399796e-01,  -6.85761750e-01,
                         -6.86168790e-01,  -6.40254438e-01,  -6.61077321e-01,
                         -7.00251937e-01,  -6.88916206e-01,  -6.75676286e-01,
                         -6.87340438e-01,  -7.11010456e-01,  -6.96243763e-01,
                         -6.54281437e-01,  -6.65063560e-01,  -6.81003690e-01,
                         -6.61264360e-01,  -6.77556932e-01,  -7.04867959e-01,
                         -6.95211947e-01,  -6.84599936e-01,  -6.81410611e-01,
                         -7.01777339e-01,  -7.01203763e-01,  -6.26769006e-01,
                         -6.88416064e-01,  -8.05179656e-01,  -4.88441020e-01,
                         -1.11852542e-01,  -3.89165401e-01,  -8.00601423e-01,
                         -7.54132509e-01,  -6.50226891e-01,  -7.06853151e-01,
                         -7.22392559e-01,  -6.87556088e-01,  -6.71781719e-01,
                         -6.92450821e-01,  -7.06151783e-01,  -6.98465407e-01,
                         -7.15113282e-01,  -7.09866166e-01,  -6.88236952e-01,
                         -7.12939560e-01,  -7.38850176e-01,  -7.27822542e-01,
                         -6.93891406e-01,  -6.81361377e-01,  -6.91692352e-01,
                         -6.94414377e-01,  -7.27889240e-01,  -7.24057674e-01,
                         -6.84314072e-01,  -7.15477049e-01,  -6.71622097e-01,
                         -6.68792069e-01,  -8.33889246e-01,  -6.17894828e-01,
                         -1.76993385e-01,  -3.40806365e-01,  -7.31949508e-01,
                         -7.19547570e-01,  -6.70503378e-01,  -7.43337452e-01,
                         -6.95238054e-01,  -7.23538518e-01,  -8.02019238e-01,
                         -4.22215581e-01,  -6.44769594e-02,  -5.71103275e-01,
                         -9.73458529e-01,  -3.89218062e-01,  -8.86775628e-02,
                         -5.69103956e-01,  -5.47895730e-01,   3.29496041e-02,
                          3.57917175e-02,  -5.36443651e-01,  -7.98919857e-01,
                         -6.69549644e-01,  -7.42812932e-01,  -8.49360526e-01,
                         -4.28261220e-01,  -5.89274056e-02,  -5.06861329e-01,
                         -9.49053764e-01,  -5.02381206e-01,  -9.02207568e-02,
                         -4.61718470e-01,  -8.12890947e-01,  -7.77743816e-01,
                         -6.80180848e-01,  -3.41901124e-01,   6.62117526e-02,
                         -7.74538666e-02,  -6.25108600e-01,  -8.80925953e-01,
                         -5.51796079e-01,  -4.14709076e-02,   6.24664389e-02,
                         -3.59684229e-01,  -8.37375224e-01,  -7.42550313e-01,
                         -2.64981151e-01,  -4.02739719e-02,   3.27715762e-02,
                         -8.11504796e-02,  -5.28328538e-01,  -5.13168812e-01,
                         -1.26840800e-01,  -4.63516772e-01,  -9.53280091e-01,
                         -5.50922811e-01,  -5.91285788e-02,  -4.45225507e-01,
                         -9.20656443e-01,  -5.27801871e-01,  -1.17650181e-01,
                         -4.77302343e-01,  -6.06388688e-01,  -1.20820031e-01,
                          6.22978322e-02,  -1.17053464e-01,  -1.31163448e-01,
                          1.76038817e-02,  -2.32537724e-02,  -4.25123543e-01,
                         -5.97555935e-01,  -1.87966883e-01,   6.24916181e-02,
                         -8.65793899e-02,  -1.03359170e-01,  -2.41899658e-02,
                         -5.93683533e-02,  -7.84281343e-02,  -4.57169749e-02,
                         -2.62421351e-02,  -4.50921096e-02,  -2.85758059e-02,
                         -4.46070023e-02,  -4.36465353e-01,  -8.65498006e-01,
                         -5.66244543e-01,  -1.27989471e-01,  -4.32014287e-01,
                         -6.11395061e-01,  -3.00800633e-02,   1.30453721e-01,
                         -4.90164369e-01,  -6.31168008e-01,  -1.18434697e-01,
                          6.04783893e-02,  -9.14084464e-02,  -1.07786981e-02,
                          2.71938480e-02,  -3.99501801e-01,  -8.31941068e-01,
                         -6.48231268e-01,  -1.70462087e-01,   1.77265014e-02,
                          5.04079759e-02,  -8.07501450e-02,  -5.41259050e-01,
                         -5.48706472e-01,   8.02228898e-02,   8.23078528e-02,
                         -5.44613361e-01,  -5.22907376e-01,   1.70339923e-02,
                          9.08514708e-02,  -3.78901273e-01,  -7.70468712e-01,
                         -6.45804286e-01,  -2.15697780e-01,   9.02145728e-02,
                         -5.24162911e-02,  -6.45157099e-01,  -7.95810521e-01,
                         -2.51948208e-01,  -2.09469587e-01,  -5.61993301e-01,
                         -3.01375985e-01,  -1.16955094e-01,  -5.20153165e-01,
                         -7.81641364e-01,  -7.44007468e-01,  -4.47251797e-01,
                         -6.04361817e-02,  -3.41171145e-01,  -8.69197488e-01,
                         -5.42659044e-01,  -6.55495934e-03,  -3.00655752e-01,
                         -7.54996479e-01,  -6.49091303e-01,  -6.08373106e-01,
                         -7.71903038e-01,  -4.30916429e-01,  -4.88374867e-02,
                         -3.77519727e-01,  -7.51885056e-01,  -6.65512264e-01,
                         -5.55753887e-01,  -6.46912217e-01,  -7.57230163e-01,
                         -5.26165366e-01,  -1.07714772e-01,  -2.47722268e-01,
                         -6.93454802e-01,  -6.95075095e-01,  -5.75743735e-01,
                         -6.41760588e-01,  -6.44049227e-01,  -6.36461437e-01,
                         -6.48231864e-01,  -6.16994858e-01,  -6.43542051e-01,
                         -6.52510047e-01,  -6.32161081e-01,  -6.39212310e-01,
                         -5.79653203e-01,  -6.28221869e-01,  -7.32510805e-01,
                         -4.21502292e-01,  -6.80657476e-02,  -3.22458535e-01,
                         -7.01740682e-01,  -6.81214333e-01,  -5.79864383e-01,
                         -6.03784323e-01,  -6.27088666e-01,  -6.37141168e-01,
                         -6.48327351e-01,  -6.41200125e-01,  -6.25276029e-01,
                         -6.15615129e-01,  -6.11664295e-01,  -6.03289843e-01,
                         -6.22056425e-01,  -6.58298194e-01,  -6.39924765e-01,
                         -6.04545891e-01,  -6.12899840e-01,  -6.29876196e-01,
                         -6.38443172e-01,  -6.31561935e-01,  -6.04653180e-01,
                         -6.00745559e-01,  -6.29767418e-01,  -6.54807746e-01,
                         -6.43218219e-01,  -6.10140800e-01,  -6.08809650e-01,
                         -6.28985643e-01,  -6.39864743e-01,  -6.40362144e-01,
                         -6.14534616e-01,  -6.00571632e-01,  -6.22171640e-01,
                         -6.21191144e-01,  -6.18751705e-01,  -6.43838704e-01,
                         -6.43564045e-01,  -6.32538676e-01,  -6.39370441e-01,
                         -6.23082995e-01,  -5.87761283e-01,  -5.94370604e-01,
                         -6.39272511e-01,  -6.47589386e-01,  -6.30595386e-01,
                         -6.41902149e-01,  -6.40183628e-01,  -6.30274892e-01,
                         -6.31334722e-01,  -5.98283410e-01,  -5.99330962e-01,
                         -6.47285163e-01,  -6.39908552e-01,  -6.32385135e-01,
                         -6.48322523e-01,  -6.35691106e-01,  -6.43267870e-01,
                         -6.37056112e-01,  -6.14843309e-01,  -6.43156588e-01,
                         -6.40219271e-01,  -6.31468892e-01,  -6.66895747e-01,
                         -6.41704738e-01,  -6.18803680e-01,  -6.42028451e-01,
                         -6.47540390e-01,  -6.56987131e-01,  -6.06340170e-01,
                         -6.35269880e-01,  -7.68390954e-01,  -4.72861469e-01,
                         -5.97238429e-02,  -3.45089763e-01,  -7.49620080e-01,
                         -6.68369114e-01,  -6.03840172e-01,  -6.77648842e-01,
                         -6.74727678e-01,  -6.71955407e-01,  -6.55522406e-01,
                         -6.47021294e-01,  -6.71818852e-01,  -6.66738510e-01,
                         -6.50025666e-01,  -6.33565962e-01,  -7.21810699e-01,
                         -6.73880637e-01,  -1.80567652e-01,  -1.03159875e-01,
                         -7.42742956e-01,  -7.43703425e-01,  -8.58622938e-02,
                          6.76716343e-02,  -3.98844294e-02,   2.71089040e-02,
                          1.17641455e-02,  -1.18036624e-02,  -6.05354609e-04,
                         -2.26286370e-02,   2.19816677e-02,   2.73467079e-02,
                         -2.20360644e-02,  -3.44437989e-03,   1.40854828e-02,
                          2.28631720e-02,   2.05432121e-02,  -1.76254585e-02,
                          6.31768373e-04,   1.76222399e-02,  -9.10735782e-03,
                          1.61536708e-02,   2.13037338e-02,  -1.42610250e-02,
                          3.57862725e-03,   2.38555558e-02,   1.72717962e-02,
                          1.11249285e-02,   2.42971582e-03,   9.57635045e-03,
                          2.76423711e-03,  -1.38215693e-02,   6.88539585e-03,
                          1.39991781e-02,   6.71344204e-03,   2.52050292e-02,
                          1.73024703e-02,  -8.95464141e-03,  -2.54860194e-03,
                          1.20816715e-02,   9.45615117e-03,  -9.53814760e-03,
                         -1.57362092e-02,   1.10449828e-02,   2.49937996e-02,
                          1.18236206e-02,   7.30241043e-03,   2.66284263e-03,
                         -1.41478255e-02,  -9.55871493e-03,   1.56944022e-02,
                          7.33599998e-03,  -2.04744637e-02,  -6.52625505e-03,
                          2.18607951e-02,   2.62146797e-02,   1.52643807e-02,
                         -1.17098438e-02,  -2.10008323e-02,  -9.44713247e-04,
                          4.04383987e-03,   2.77593004e-04,  -4.19527479e-03,
                         -5.16166026e-03,   1.63237993e-02,   1.29405120e-02,
                         -7.24529009e-03,   2.37533450e-03,  -7.77885143e-04,
                         -4.91786574e-04,   1.34810414e-02,  -5.44229662e-03,
                         -2.18289346e-03,   5.70782833e-03,  -2.45811269e-02,
                         -7.24873366e-03,   5.78093482e-03,  -2.49491092e-02,
                          3.90952831e-04,   1.44228712e-02,  -1.10560991e-02,
                          4.17723833e-03,   2.47560744e-03,  -7.57284323e-03,
                          6.39014971e-03,  -6.59889681e-03,  -2.82323151e-03,
                          4.32929769e-03,  -1.02382647e-02,   8.92761908e-03,
                         -8.78211111e-03,  -3.48301083e-02,   1.97964665e-02,
                          2.84829009e-02,  -2.27916194e-03,   7.98287336e-03,
                         -1.48609336e-02,  -2.63793785e-02,  -1.12934383e-02,
                         -2.46584937e-02,   8.04363005e-03,   3.22748087e-02,
                         -2.87154200e-03,   9.54199210e-03,   1.70909520e-02,
                         -1.77523699e-02,  -2.01030038e-02,  -1.87717117e-02,
                         -7.67093804e-03,   1.39424894e-02,   4.13695304e-03,
                          1.19299805e-02,   1.00165270e-02,  -2.12418083e-02,
                         -7.76917674e-03,  -4.40376578e-03,  -1.82077643e-02,
                          1.33198034e-02,   1.10552022e-02,  -1.66785996e-02,
                         -7.65030645e-03,  -1.35344621e-02,  -1.06574418e-02,
                          1.41332010e-02,   8.34215898e-03,   7.21285352e-03,
                          5.20750415e-03,  -1.88679807e-02,  -1.16415592e-02,
                         -1.33888575e-03,  -1.22439982e-02,  -3.15661542e-03,
                         -6.20711129e-03,  -2.20651850e-02,  -1.48620387e-03,
                          1.64671931e-02,   6.13927469e-03,   1.45509676e-03,
                         -4.40882752e-03,  -1.85277089e-02,  -1.61629133e-02,
                         -3.56421107e-03,  -5.90593973e-03,  -1.32454317e-02,
                         -6.61595631e-03,   2.93322746e-03,   7.80167710e-03,
                          1.02748340e-02,   9.08816815e-04,  -9.65317339e-03,
                         -1.17875002e-02,  -1.65763404e-02,  -5.54598169e-03,
                          1.07664447e-02,  -4.38122824e-03,  -2.47826660e-03,
                          2.32539810e-02,   4.35960386e-03,  -1.19859800e-02,
                          7.92741869e-03,   5.25709614e-03,   8.95617902e-03,
                          2.21360326e-02,  -1.08125119e-03,  -5.00692567e-03,
                          2.36184732e-03,  -2.40734182e-02,  -2.49573104e-02,
                         -1.00912033e-02,  -8.32111109e-03,   1.39168128e-02,
                          1.82191208e-02,  -2.60354369e-03,  -2.88829696e-03,
                          7.48107559e-04,  -1.87979965e-03,  -1.27798347e-02,
                         -1.57007445e-02,   6.50488678e-03,  -4.22405917e-03,
                         -2.09562555e-02,   1.97140221e-02,   3.71232368e-02,
                          2.23458372e-03,  -2.04627533e-02,  -8.23647156e-03,
                          2.48381197e-02,   1.86341647e-02,  -1.13985334e-02,
                          4.42953873e-03,   9.17219836e-03,  -1.95485707e-02,
                         -1.39107741e-02,   1.78239383e-02,   3.48805487e-02,
                          2.36899126e-02,   1.77728408e-03,  -5.09038009e-03,
                          3.65963066e-03,   8.82912427e-03,  -9.00727697e-04,
                          4.46151104e-03,  -1.60670593e-01,  -6.24184251e-01,
                         -7.67732918e-01,  -2.92777956e-01,   6.44143820e-02,
                          6.07245527e-02,   1.51005797e-02,  -1.35218715e-02,
                          9.09037814e-02,   1.34493895e-02,  -4.71029639e-01,
                         -5.19649267e-01,  -2.34209690e-02,   1.30132869e-01,
                         -1.65317617e-02,  -5.84026566e-03,   6.37313351e-02,
                         -1.54252658e-02,  -7.41580501e-02,   1.17930643e-01,
                          1.76962912e-02,  -4.69783217e-01,  -3.99411172e-01,
                         -1.53752506e-01,  -4.57637489e-01,  -4.29897577e-01,
                          2.32813247e-02,   1.15176149e-01,   1.59790590e-02,
                         -2.58453041e-01,  -7.21082151e-01,  -7.09042549e-01,
                         -2.08070859e-01,   1.14711687e-01,  -9.03870240e-02,
                         -5.37489176e-01,  -7.14054823e-01,  -6.75966024e-01,
                         -6.53502882e-01,  -6.80416286e-01,  -7.34635770e-01,
                         -4.48110610e-01,  -7.38235489e-02,  -3.71842414e-01,
                         -7.81404972e-01,  -6.68393493e-01,  -5.77908516e-01,
                         -6.58294678e-01,  -6.70631409e-01,  -6.81275904e-01,
                         -6.51799858e-01,  -6.29374504e-01,  -6.63726926e-01,
                         -6.50624335e-01,  -6.52492821e-01,  -6.72192812e-01,
                         -6.62029862e-01,  -6.71944022e-01,  -6.65037155e-01,
                         -6.56619430e-01,  -6.65452063e-01,  -6.55124605e-01,
                         -6.67515814e-01,  -6.65591478e-01,  -6.47268236e-01,
                         -6.65285170e-01,  -6.54305339e-01,  -6.47340000e-01,
                         -6.61840320e-01,  -6.45588994e-01,  -6.73663020e-01,
                         -6.88640356e-01,  -6.40833855e-01,  -6.52876973e-01,
                         -6.79005027e-01,  -6.77863598e-01,  -6.89101338e-01,
                         -6.67979360e-01,  -6.51921213e-01,  -6.46722078e-01,
                         -6.35944188e-01,  -6.76277816e-01,  -6.84181809e-01,
                         -6.54420137e-01,  -6.76823378e-01,  -6.72569096e-01,
                         -6.55441999e-01,  -6.77908659e-01,  -6.74310982e-01,
                         -6.75435543e-01,  -6.85052514e-01,  -6.63538694e-01,
                         -6.60957396e-01,  -6.74972296e-01,  -6.78878665e-01,
                         -6.71003401e-01,  -6.63392901e-01,  -6.81622386e-01,
                         -6.75659657e-01,  -6.56741917e-01,  -6.80321217e-01,
                         -6.84193850e-01,  -6.77107453e-01,  -6.89343989e-01,
                         -6.75904334e-01,  -6.75477684e-01,  -6.87904894e-01,
                         -6.85960829e-01,  -6.89424574e-01,  -6.61954761e-01,
                         -6.70494854e-01,  -7.09880233e-01,  -6.50295317e-01,
                         -7.03696012e-01,  -8.22650373e-01,  -4.89134341e-01,
                         -8.86063129e-02,  -3.69520605e-01,  -7.97006190e-01,
                         -7.30411351e-01,  -6.12520933e-01,  -7.09077477e-01,
                         -7.26431012e-01,  -6.72222674e-01,  -6.95384085e-01,
                         -7.36097574e-01,  -7.24530578e-01,  -6.70369744e-01,
                         -6.53900862e-01,  -6.93665743e-01,  -7.06024647e-01,
                         -7.13181615e-01,  -7.37541437e-01,  -7.03805745e-01,
                         -6.74661279e-01,  -7.19417453e-01,  -7.20299363e-01,
                         -6.81644619e-01,  -7.18328655e-01,  -7.37017035e-01,
                         -7.04307020e-01,  -7.12175369e-01,  -6.75654590e-01,
                         -6.97722197e-01,  -8.33249927e-01,  -5.82869947e-01,
                         -1.35122120e-01,  -3.31672490e-01,  -7.75676250e-01,
                         -7.47173846e-01,  -6.63767874e-01,  -7.37737417e-01,
                         -6.84963048e-01,  -7.19472587e-01,  -8.04503441e-01,
                         -4.40018803e-01,  -9.67230499e-02,  -5.46870947e-01,
                         -9.26362038e-01,  -4.03820992e-01,  -1.18164778e-01,
                         -5.68592787e-01,  -5.32310486e-01,   4.40149456e-02,
                          3.45218405e-02,  -5.49442589e-01,  -8.35997283e-01,
                         -6.73037052e-01,  -6.88104153e-01,  -8.37921858e-01,
                         -4.57193553e-01,  -7.56119639e-02,  -5.23480594e-01,
                         -9.29723322e-01,  -4.76595849e-01,  -1.13419317e-01,
                         -4.82869148e-01,  -8.18691850e-01,  -7.81933963e-01,
                         -6.84287488e-01,  -3.62891406e-01,   5.46819158e-02,
                         -6.86689839e-02,  -5.96949875e-01,  -8.45250845e-01,
                         -5.68372071e-01,  -7.25249946e-02,   6.49798289e-02,
                         -3.73641878e-01,  -8.42523038e-01,  -7.17119217e-01,
                         -2.72829652e-01,  -7.91447982e-02,   2.18323469e-02,
                         -4.68345396e-02,  -5.17622709e-01,  -5.67491889e-01,
                         -1.50624186e-01,  -4.22757536e-01,  -9.39211309e-01,
                         -5.69387853e-01,  -3.92407589e-02,  -4.15991902e-01,
                         -9.69013035e-01,  -6.12649083e-01,  -1.40621766e-01,
                         -4.42199886e-01,  -5.71157336e-01,  -1.35475338e-01,
                          3.66520993e-02,  -9.37815756e-02,  -1.23868972e-01,
                          1.15000075e-02,   2.46099895e-03,  -4.32409525e-01,
                         -6.03955269e-01,  -1.65971741e-01,   4.93966118e-02,
                         -8.36433917e-02,  -8.51498693e-02,  -3.61898951e-02,
                         -6.39709830e-02,  -9.48675945e-02,  -5.08195944e-02,
                         -5.75783662e-03,  -6.51416928e-02,  -3.17751095e-02,
                         -2.32295692e-02,  -4.65002745e-01,  -9.02053475e-01,
                         -5.76823473e-01,  -9.98187363e-02,  -4.08145458e-01,
                         -6.52953863e-01,  -4.33737561e-02,   1.44364521e-01,
                         -5.16507387e-01,  -6.32774770e-01,  -1.09592363e-01,
                          7.09979758e-02,  -7.57552311e-02,  -4.95653301e-02,
                          2.74790823e-02,  -3.70518804e-01,  -8.80168557e-01,
                         -6.51625514e-01,  -1.31496400e-01,   2.98519013e-03,
                          4.70568202e-02,  -7.67482072e-02,  -5.22149563e-01,
                         -5.09577930e-01,   6.17570765e-02,   6.75890967e-02,
                         -5.39990842e-01,  -5.58676004e-01,   1.18237324e-02,
                          1.17562696e-01,  -3.77533525e-01,  -7.93481529e-01,
                         -6.65397942e-01,  -1.70443699e-01,   1.34174138e-01,
                         -8.37146565e-02,  -6.74717247e-01,  -8.25785160e-01,
                         -2.66993254e-01,  -1.43480510e-01,  -5.12830496e-01,
                         -3.11727643e-01,  -1.21300079e-01,  -5.26569188e-01,
                         -7.85076678e-01,  -7.39836037e-01,  -4.51913178e-01,
                         -5.23817688e-02,  -3.29202056e-01,  -8.65629256e-01,
                         -5.35981894e-01,  -1.38567770e-02,  -3.15463871e-01,
                         -7.39652395e-01,  -6.22424722e-01,  -6.20141268e-01,
                         -7.95793474e-01,  -4.26475257e-01,  -3.24614197e-02,
                         -3.36730301e-01,  -7.18018830e-01,  -7.05460489e-01,
                         -5.92500508e-01,  -6.33072674e-01,  -7.48531103e-01,
                         -5.01077533e-01,  -8.18122700e-02,  -2.51922995e-01,
                         -6.71862602e-01,  -6.82836711e-01,  -6.16734564e-01,
                         -6.70348942e-01,  -6.31804705e-01,  -5.98716021e-01,
                         -6.26622736e-01,  -6.44203424e-01,  -6.65767372e-01,
                         -6.48932159e-01,  -6.35170400e-01,  -6.38377666e-01,
                         -5.68277359e-01,  -6.23956859e-01,  -7.47617602e-01,
                         -4.30693924e-01,  -4.72507365e-02,  -3.25118065e-01,
                         -7.23907471e-01,  -6.58027232e-01,  -5.70063770e-01,
                         -6.40777349e-01,  -6.32161438e-01,  -6.13802493e-01,
                         -6.37432694e-01,  -6.35619521e-01,  -6.27890289e-01,
                         -6.17700458e-01,  -6.17584407e-01,  -6.32567763e-01,
                         -6.34336472e-01,  -6.38457060e-01,  -6.42121136e-01,
                         -6.27684295e-01,  -6.17163897e-01,  -6.25884056e-01,
                         -6.36767805e-01,  -6.29530370e-01,  -6.26145542e-01,
                         -6.27647221e-01,  -6.18155479e-01,  -6.35217309e-01,
                         -6.38053060e-01,  -6.04968131e-01,  -6.28342688e-01,
                         -6.43051386e-01,  -6.06763482e-01,  -6.34215951e-01,
                         -6.51956379e-01,  -6.08864784e-01,  -6.09899402e-01,
                         -6.23321354e-01,  -6.31365359e-01,  -6.40007675e-01,
                         -6.07431114e-01,  -6.16661847e-01,  -6.53145611e-01,
                         -6.30029380e-01,  -6.20995522e-01,  -6.24269366e-01,
                         -6.17740929e-01,  -6.39270723e-01,  -6.34258151e-01,
                         -6.25678182e-01,  -6.37463450e-01,  -6.21533871e-01,
                         -6.35151863e-01,  -6.48490012e-01,  -6.21992648e-01,
                         -6.37196004e-01,  -6.41001999e-01,  -6.23879731e-01,
                         -6.44882739e-01,  -6.38191223e-01,  -6.41058266e-01,
                         -6.59551203e-01,  -6.18925512e-01,  -6.21008873e-01,
                         -6.61518872e-01,  -6.44879103e-01,  -6.31308079e-01,
                         -6.40752792e-01,  -6.53920531e-01,  -6.47955656e-01,
                         -6.34550214e-01,  -6.54318810e-01,  -6.12098575e-01,
                         -6.40131652e-01,  -7.59893298e-01,  -4.50837135e-01,
                         -4.75376360e-02,  -3.50531965e-01,  -7.56859422e-01,
                         -6.81096613e-01,  -6.18863344e-01,  -6.66104972e-01,
                         -6.52213991e-01,  -6.77254617e-01,  -6.65558159e-01,
                         -6.25951648e-01,  -6.51698053e-01,  -6.86777711e-01,
                         -6.77725732e-01,  -6.36547744e-01,  -7.27783501e-01,
                         -6.89070463e-01,  -1.79081574e-01,  -9.46486443e-02,
                         -7.44316161e-01,  -7.50151396e-01,  -8.57236683e-02,
                          8.72645602e-02,  -2.39211973e-02,  -5.77005837e-03,
                         -3.61112468e-02,   1.79778726e-03,   4.67009805e-02,
                         -2.00068317e-02,  -2.45178863e-03,   2.68842354e-02,
                         -9.19922162e-03,  -6.08180184e-03,  -1.47378827e-02,
                         -9.31128394e-03,   2.19598189e-02,   1.52701791e-03,
                          2.68265698e-03,   4.19724500e-03,  -2.99594793e-02,
                         -6.23139460e-03,   8.55657645e-03,  -1.19669819e-02,
                          4.65497700e-03,   2.00309069e-03,  -2.16972665e-03,
                          8.06395710e-03,  -1.90361049e-02,  -6.37325039e-03,
                          2.03432273e-02,  -1.39905764e-02,  -1.69211775e-02,
                          6.03014370e-03,   4.78321780e-03,   1.02675296e-02,
                         -5.63696446e-03,  -1.81911848e-02,   4.47326805e-03,
                          6.70596166e-03,  -2.01667397e-04,  -1.72285468e-03,
                         -6.86406018e-03,   2.98328395e-03,   2.18656170e-03,
                         -9.81763005e-04,   4.93295444e-03,  -4.17930447e-03,
                          1.05832294e-02,   2.16454156e-02,  -4.31992719e-03,
                          1.60552247e-03,   5.10691060e-03,  -1.37174521e-02,
                          3.48138157e-03,   4.72471956e-03,  -7.26954127e-03,
                          4.45553614e-03,  -8.57355539e-03,  -1.18701048e-02,
                          8.62925022e-04,  -9.56888590e-03,   4.87950211e-03,
                          1.27868503e-02,  -1.05452025e-02,  -4.90439450e-03,
                         -1.42604008e-03,  -7.89900310e-03,   1.41639716e-03,
                          6.86646265e-04,   7.47780828e-03,   2.35757045e-03,
                         -2.00965814e-02,   2.81501422e-03,   1.60726029e-02,
                         -7.62977125e-03,   6.16855541e-05,   1.10378545e-02,
                          3.56646953e-03,  -8.22279230e-03,  -2.13596374e-02,
                         -5.05161646e-04,   1.19677829e-02,  -9.93140694e-03,
                         -2.67133233e-03,   7.62373256e-03,   5.50300535e-03,
                          1.20347869e-02,  -1.54062845e-02,  -2.71745622e-02,
                          1.37375062e-02,   2.13562418e-02,   3.76711180e-03,
                          1.00896170e-03,  -6.99225254e-03,  -5.51665248e-03,
                         -5.31998277e-03,  -1.25421584e-02,   7.15147192e-03,
                          2.22668517e-02,   6.29785378e-03,  -1.26033798e-02,
                         -2.06593126e-02,  -5.86201809e-03,   1.42343072e-02,
                          7.54719833e-03,  -5.25265886e-03,  -1.00688580e-02,
                         -8.28167424e-03,   7.88883120e-03,   1.17693990e-02,
                         -2.43290327e-03,  -1.98181882e-03,   3.57109890e-03,
                         -2.26911879e-03,  -6.81462837e-03,  -6.11724984e-03,
                         -5.12417813e-04,   3.04850959e-03,  -8.54595681e-04,
                         -4.22348239e-04,  -3.87893384e-03,  -1.45989582e-02,
                         -2.29759887e-03,   2.39960495e-02,   2.18271893e-02,
                         -1.64153098e-04,  -2.13291706e-03,   9.45714395e-03,
                          8.10161524e-04,  -1.08122882e-02,  -6.41864585e-03,
                         -1.54513912e-02,  -1.71883740e-02,   1.69044696e-02,
                          2.99343616e-02,   5.27292164e-03,  -1.24653364e-02,
                         -1.13785584e-02,   2.43500178e-03,  -6.27940055e-04,
                         -1.48864025e-02,   9.07701906e-03,   2.42739953e-02,
                         -2.20307615e-03,  -7.09641818e-03,  -4.31746058e-03,
                         -1.55651197e-02,  -9.58541688e-03,  -1.28456205e-02,
                         -1.95454005e-02,  -6.91538211e-03,  -9.28347651e-03,
                          1.37683249e-03,   2.57417783e-02,  -8.52390006e-03,
                         -4.47797589e-02,  -5.72685758e-03,   3.46099399e-02,
                          1.24614434e-02,  -2.21526437e-02,  -1.74352918e-02,
                         -4.26929415e-04,  -1.01934141e-03,  -2.00031954e-03,
                         -7.57718412e-03,  -1.37007777e-02,   3.21162152e-05,
                          2.02328945e-03,  -8.77245213e-04,   2.70524248e-02,
                          3.82917561e-02,   1.43540902e-02,  -2.13405443e-03,
                         -9.97545663e-03,  -9.96781606e-03,  -3.61905689e-03,
                         -1.21822972e-02,  -1.65239442e-02,   2.75939959e-03,
                          2.30051577e-02,   2.67605763e-02,   1.15705989e-02,
                         -8.71791039e-03,  -6.09200541e-03,   1.08651957e-02,
                          5.74606331e-03,  -1.44029446e-02,  -1.58203673e-02,
                          8.88201525e-04,   8.22381768e-03,  -6.85581053e-03,
                         -8.27382598e-03,   1.61431320e-02,   1.18012428e-02,
                          5.65181300e-03,   2.64592282e-02,   4.26722784e-03,
                         -9.76022147e-03,   6.32660603e-03,  -9.00464971e-03,
                          2.79528480e-02,  -1.26974314e-01,  -6.52781248e-01,
                         -7.89870977e-01,  -2.73110211e-01,   6.64934292e-02,
                          4.40262519e-02,  -6.73980778e-03,  -1.68489665e-02,
                          1.10693350e-01,   2.40725204e-02,  -4.42564458e-01,
                         -4.86808389e-01,  -3.86298150e-02,   1.05028369e-01,
                         -3.53072360e-02,  -3.39457020e-02,   5.04938178e-02,
                         -1.77973486e-03,  -3.84851396e-02,   1.21044494e-01,
                         -3.42356935e-02,  -4.92238283e-01,  -3.84405196e-01,
                         -1.43143564e-01,  -4.41301197e-01,  -4.27936554e-01,
                          2.40066536e-02,   1.26481131e-01,   1.21219887e-03,
                         -2.66727328e-01,  -7.43429303e-01,  -7.86080599e-01,
                         -2.33475104e-01,   1.63051471e-01,  -6.32128641e-02,
                         -5.58374643e-01,  -7.57322550e-01,  -6.51342750e-01,
                         -5.59297562e-01,  -6.55966282e-01,  -7.77070940e-01,
                         -4.87003148e-01,  -9.99388397e-02,  -3.28858018e-01,
                         -7.08931923e-01,  -6.77261114e-01,  -6.27327979e-01,
                         -6.66610599e-01,  -6.43389761e-01,  -6.78819060e-01,
                         -6.94713712e-01,  -6.43544257e-01,  -6.34167194e-01,
                         -6.39611900e-01,  -6.57472730e-01,  -6.70768917e-01,
                         -6.53691173e-01,  -6.56325758e-01,  -6.50652766e-01,
                         -6.48537219e-01,  -6.74302220e-01,  -6.68343663e-01,
                         -6.62160754e-01,  -6.71116173e-01,  -6.74024701e-01,
                         -6.73930287e-01,  -6.22220874e-01,  -6.10576808e-01,
                         -6.79407537e-01,  -6.65595233e-01,  -6.47703826e-01,
                         -7.00510204e-01,  -6.66233540e-01,  -6.07046485e-01,
                         -6.23524964e-01,  -6.56155050e-01,  -6.81728959e-01,
                         -6.55718625e-01,  -6.37314796e-01,  -6.85544193e-01,
                         -6.71425164e-01,  -6.42176569e-01,  -6.71152711e-01,
                         -6.46205962e-01,  -6.28974736e-01,  -6.64838195e-01,
                         -6.64572299e-01,  -6.71550035e-01,  -6.72668755e-01,
                         -6.31378472e-01,  -6.25507474e-01,  -6.47996366e-01,
                         -6.73843622e-01,  -6.83298469e-01,  -6.50075495e-01,
                         -6.57949150e-01,  -6.94891870e-01,  -6.82327926e-01,
                         -6.65448248e-01,  -6.49713218e-01,  -6.39106452e-01,
                         -6.62932575e-01,  -6.70028806e-01,  -6.62362456e-01,
                         -6.66622043e-01,  -6.71017528e-01,  -6.73809469e-01,
                         -6.60472453e-01,  -6.64293647e-01,  -6.84546232e-01,
                         -6.87268078e-01,  -6.85722470e-01,  -6.41753554e-01,
                         -6.99937284e-01,  -8.28318596e-01,  -5.00047088e-01,
                         -5.56225441e-02,  -3.34031284e-01,  -7.72577405e-01,
                         -7.05597162e-01,  -6.19248271e-01,  -7.02822506e-01,
                         -7.08400190e-01,  -6.87594056e-01,  -6.92665577e-01,
                         -7.00186610e-01,  -6.88571751e-01,  -6.69231653e-01,
                         -6.99429989e-01,  -7.07265198e-01,  -6.78714991e-01,
                         -6.94816530e-01,  -7.11085856e-01,  -6.95321858e-01,
                         -6.76563680e-01,  -6.90022111e-01,  -7.24560142e-01,
                         -7.07372487e-01,  -6.79580331e-01,  -6.76320195e-01,
                         -6.91966712e-01,  -7.36429870e-01,  -6.81867659e-01,
                         -6.70276701e-01,  -8.19962144e-01,  -5.99376917e-01,
                         -1.47070587e-01,  -3.10607344e-01,  -7.39931166e-01,
                         -7.50138283e-01,  -6.97845101e-01,  -7.52392113e-01,
                         -6.66932821e-01,  -6.86477780e-01,  -7.86040127e-01,
                         -4.39609706e-01,  -1.10463619e-01,  -5.81078589e-01,
                         -9.53488350e-01,  -4.06111777e-01,  -1.00657597e-01,
                         -5.46677172e-01,  -5.41282117e-01,   1.53198345e-02,
                          1.58638731e-02,  -5.39139926e-01,  -7.99249768e-01,
                         -6.82579756e-01,  -7.19566703e-01,  -8.17823946e-01,
                         -4.50163096e-01,  -6.89045638e-02,  -4.91967171e-01,
                         -9.64346349e-01,  -5.11999488e-01,  -8.78165886e-02,
                         -4.68348712e-01,  -7.91207194e-01,  -7.60590434e-01,
                         -7.22032070e-01,  -3.88965398e-01,   5.89147359e-02,
                         -6.57716542e-02,  -6.01139843e-01,  -8.64067972e-01,
                         -5.81414163e-01,  -8.71411711e-02,   5.15726805e-02,
                         -3.56605828e-01,  -8.36817682e-01,  -7.39993811e-01,
                         -2.88264692e-01,  -7.04984516e-02,   4.73100841e-02,
                         -5.18347360e-02,  -5.31478882e-01,  -5.37941873e-01,
                         -1.49277076e-01,  -4.66930091e-01,  -9.42154706e-01,
                         -5.42139053e-01,  -5.23455553e-02,  -4.61477220e-01,
                         -9.68277752e-01,  -5.54676294e-01,  -1.15516655e-01,
                         -4.76220965e-01,  -6.04186237e-01,  -1.30664796e-01,
                          6.50431365e-02,  -7.74886087e-02,  -1.31881729e-01,
                         -8.87966063e-03,   4.84594435e-04,  -4.18938011e-01,
                         -6.35619223e-01,  -2.18297407e-01,   3.86774689e-02,
                         -8.47757086e-02,  -9.07023102e-02,  -3.13384086e-02,
                         -5.80812357e-02,  -9.62938145e-02,  -7.76664913e-02,
                         -2.84847766e-02,  -5.42875826e-02,  -1.96171775e-02,
                         -1.86128113e-02,  -4.75891083e-01,  -9.14165854e-01,
                         -5.71391344e-01,  -1.19991660e-01,  -4.15053636e-01,
                         -6.31674707e-01,  -7.00163096e-02,   1.28596559e-01,
                         -4.89891171e-01,  -6.16769612e-01,  -9.58884433e-02,
                          4.24954370e-02,  -1.02705732e-01,  -1.34022646e-02,
                          9.10466630e-03,  -4.08196211e-01,  -8.39291513e-01,
                         -6.31449699e-01,  -1.56211644e-01,  -2.44505145e-02,
                          2.36436054e-02,  -7.95736834e-02,  -5.36770225e-01,
                         -5.16128480e-01,   8.28697458e-02,   6.98232800e-02,
                         -5.25133252e-01,  -5.47038615e-01,  -2.96859071e-02,
                          8.03659186e-02,  -3.89415950e-01,  -7.85547018e-01,
                         -6.49526834e-01,  -1.90575570e-01,   1.15083352e-01,
                         -8.15403461e-02,  -6.77876711e-01,  -8.16290498e-01,
                         -2.65203983e-01,  -1.60786107e-01,  -5.20504296e-01,
                         -3.23220223e-01,  -1.47475123e-01,  -5.48544824e-01,
                         -7.64175951e-01,  -7.01408446e-01,  -4.81129974e-01,
                         -9.71752554e-02,  -3.15989912e-01,  -8.53870571e-01,
                         -5.45309305e-01,  -1.31643005e-02,  -3.11940759e-01,
                         -7.55590320e-01,  -6.52920187e-01,  -6.13074183e-01,
                         -7.64121354e-01,  -4.29366052e-01,  -6.02565371e-02,
                         -3.77325505e-01,  -7.35614002e-01,  -6.77562773e-01,
                         -5.95130086e-01,  -6.61230981e-01,  -7.48674870e-01,
                         -5.13229609e-01,  -1.02396876e-01,  -2.56033391e-01,
                         -6.90589011e-01,  -6.97376370e-01,  -5.88882267e-01,
                         -6.39772296e-01,  -6.58735156e-01,  -6.49524987e-01,
                         -6.26636326e-01,  -6.13710582e-01,  -6.51048839e-01,
                         -6.45498812e-01,  -6.44231200e-01,  -6.63673580e-01,
                         -6.01298392e-01,  -6.50280595e-01,  -7.54546821e-01,
                         -4.22200054e-01,  -3.33083607e-02,  -3.32416296e-01,
                         -7.48611033e-01,  -6.49768472e-01,  -5.45730710e-01,
                         -6.37336671e-01,  -6.31116033e-01,  -6.24331713e-01,
                         -6.60550416e-01,  -6.33065522e-01,  -6.10481441e-01,
                         -6.23917341e-01,  -6.42058730e-01,  -6.34645224e-01,
                         -6.08337283e-01,  -6.22735500e-01,  -6.42524719e-01,
                         -6.32949114e-01,  -6.31467819e-01,  -6.39335752e-01,
                         -6.44159198e-01,  -6.31320834e-01,  -6.25657141e-01,
                         -6.49814665e-01,  -6.48387194e-01,  -6.27248764e-01,
                         -6.21618152e-01,  -6.17782712e-01,  -6.18113101e-01,
                         -6.12388611e-01,  -6.20565355e-01,  -6.45373821e-01,
                         -6.29837632e-01,  -6.15168989e-01,  -6.39538586e-01,
                         -6.56348705e-01,  -6.44689322e-01,  -6.21477365e-01,
                         -6.47756815e-01,  -6.72624469e-01,  -6.20228410e-01,
                         -6.18106782e-01,  -6.59679890e-01,  -6.37785852e-01,
                         -6.30889833e-01,  -6.35365129e-01,  -6.32180572e-01,
                         -6.54942155e-01,  -6.29619300e-01,  -6.15777671e-01,
                         -6.58166170e-01,  -6.46766961e-01,  -6.33087277e-01,
                         -6.47603333e-01,  -6.20600283e-01,  -5.99394083e-01,
                         -6.14899814e-01,  -6.40201747e-01,  -6.41428113e-01,
                         -6.34721160e-01,  -6.67638838e-01,  -6.55728459e-01,
                         -6.14031136e-01,  -6.49215400e-01,  -6.61448777e-01,
                         -6.40633047e-01,  -6.52406216e-01,  -6.29663467e-01,
                         -6.47251725e-01,  -6.88645780e-01,  -6.20284200e-01,
                         -6.63377225e-01,  -7.63379395e-01,  -4.37077105e-01,
                         -6.87894598e-02,  -3.60199541e-01,  -7.61532545e-01,
                         -6.79600298e-01,  -5.97897351e-01,  -6.88180745e-01,
                         -6.63917243e-01,  -6.51455760e-01,  -6.85067475e-01,
                         -6.53760791e-01,  -6.48082733e-01,  -6.65059745e-01,
                         -6.46297216e-01,  -6.35020435e-01,  -7.28256583e-01,
                         -6.82360530e-01,  -1.98609233e-01,  -8.81282836e-02,
                         -7.19901204e-01,  -7.48261750e-01,  -9.08981115e-02,
                          5.22796549e-02,  -3.70775387e-02,   5.74960187e-02,
                          4.66641411e-03,  -2.86805015e-02,   1.92916731e-03,
                         -4.02996987e-02,   5.37349936e-03,   3.63738649e-02,
                         -1.66910123e-02,  -2.45666783e-02,  -2.23346725e-02,
                         -7.49560399e-03,   3.73850367e-03,  -1.55977802e-02,
                         -8.08048807e-03,  -1.12544345e-02,  -3.03869043e-03,
                          2.52663307e-02,  -7.60087464e-03,  -1.30365882e-02,
                          2.17315294e-02,  -9.29284655e-03,  -3.22301835e-02,
                          3.23210866e-03,   2.13243011e-02,  -2.61631026e-03,
                         -1.41416900e-02,   1.75732877e-02,   2.89016142e-02,
                          1.72799651e-03,  -1.94642041e-02,  -2.30659619e-02,
                          3.79197183e-03,   1.18697044e-02,  -1.81101337e-02,
                         -1.26662827e-03,   2.80149188e-02,   3.33779585e-03,
                         -2.32407507e-02,  -1.91836469e-02,  -1.73459601e-04,
                         -2.60003586e-03,  -1.90353524e-02,   3.39275366e-03,
                          3.10758892e-02,   2.46105511e-02,   3.09472159e-03,
                         -1.50257116e-02,  -1.96589669e-03,   1.37991123e-02,
                         -3.71426833e-03,  -1.29326954e-02,   4.30565524e-05,
                          1.93479769e-02,   2.76580192e-02,   1.41453906e-03,
                         -2.56481208e-02,  -1.53435580e-02,   7.90238287e-03,
                          6.34100614e-03,  -3.82924592e-03,   1.30107673e-02,
                          2.85518114e-02,   2.56178156e-02,   7.30494130e-03,
                         -3.17372121e-02,  -2.52312031e-02,   1.37096029e-02,
                          6.99114753e-03,   2.54631136e-03,   2.41182372e-03,
                         -1.09006921e-02,   3.56565276e-03,   1.79796340e-03,
                          8.55175499e-03,   3.61537747e-02,  -2.50053173e-03,
                         -2.02507395e-02,   1.31191136e-02,   4.17856779e-03,
                          2.09242338e-03,  -5.14932675e-04,  -7.36391963e-03,
                          2.55676936e-02,   8.82543996e-03,  -1.49661237e-02,
                          8.07406474e-03,  -1.26921358e-02,  -8.82508699e-03,
                          2.19202545e-02,  -5.99443971e-04,   5.80630731e-03,
                          7.95269571e-03,  -2.11978704e-02,   2.17301026e-03,
                          3.41863884e-03,  -2.02907529e-02,   7.41059612e-03,
                          2.21906547e-02,   1.14321867e-02,   4.39226488e-03,
                          3.13603226e-03,   1.56967230e-02,   2.18683388e-03,
                         -1.28852660e-02,   1.82448933e-03,  -2.08439841e-03,
                         -1.01138046e-03,   8.92641768e-03,  -2.49143341e-03,
                          4.18748986e-03,  -1.06568169e-03,  -3.11504062e-02,
                         -1.32447751e-02,   1.11813443e-02,  -1.06786173e-02,
                         -2.06369180e-02,   2.81978771e-03,   1.68973580e-02,
                         -2.94069201e-03,  -2.32674200e-02,  -6.37357077e-03,
                          7.06556719e-03,  -1.44238481e-02,  -2.42880918e-02,
                         -9.21642501e-03,  -3.24681308e-03,  -5.14921453e-03,
                         -3.21580213e-03,   7.82580022e-03,   2.46088374e-02,
                          6.51901495e-03,  -2.54299063e-02,  -4.64659976e-03,
                          2.13021170e-02,   1.01903230e-02,   1.15583139e-03,
                         -9.14325379e-03,  -3.71676707e-03,   2.07320340e-02,
                          2.34538061e-03,  -1.71949249e-02,  -2.06802785e-03,
                         -9.27902292e-03,  -5.20777656e-03,   2.34674867e-02,
                          7.21813925e-03,  -2.03947257e-02,  -3.65373609e-03,
                          2.04633307e-02,   1.64833870e-02,   5.61063085e-03,
                          8.23743269e-03,  -5.27848024e-03,  -3.35965864e-02,
                         -2.71684267e-02,  -5.04264608e-04,   1.29413127e-03,
                         -5.39411465e-03,   1.32018141e-02,   2.60593537e-02,
                         -1.25762611e-03,  -1.55956820e-02,  -6.28180336e-03,
                         -8.36269371e-03,   1.44243129e-02,   2.04021893e-02,
                         -2.33378354e-02,  -1.05039245e-02,   2.42848564e-02,
                          6.88041467e-03,   1.94928609e-03,  -1.05757173e-02,
                         -2.84414794e-02,  -2.79141963e-03,  -1.23842210e-02,
                         -3.58963162e-02,  -7.40322808e-04,   2.39582639e-02,
                          2.57220455e-02,   2.84224339e-02,   1.20206103e-02,
                         -6.72380580e-03,  -1.84974503e-02,  -8.98235291e-03,
                          8.87967646e-03,   1.17940996e-04,   9.54002142e-03,
                          1.69565435e-02,  -2.09977422e-02,  -1.26955798e-02,
                          4.19896841e-02,   3.30082774e-02,  -1.39663089e-02,
                          5.98066370e-04,   2.98899449e-02,   2.87304772e-03,
                          1.48169314e-02,  -1.08414315e-01,  -5.87261140e-01,
                         -7.93439329e-01,  -3.41317922e-01,   3.21569480e-02,
                          3.13040353e-02,  -1.24379769e-02,  -1.90655459e-02,
                          1.03027649e-01,   5.54784462e-02,  -4.08868611e-01,
                         -5.11662662e-01,  -5.79950288e-02,   1.30305931e-01,
                          2.96995696e-03,  -1.26637835e-02,   2.98823044e-02,
                         -3.08219716e-02,  -3.49952690e-02,   1.43524975e-01,
                         -1.96134765e-02,  -5.13953090e-01,  -4.04509425e-01,
                         -1.11744434e-01,  -4.22711492e-01,  -4.48388070e-01,
                          1.76751781e-02,   1.30163938e-01,   1.42681366e-02,
                         -2.34406546e-01,  -7.13059545e-01,  -7.54146159e-01,
                         -2.13564396e-01,   1.48041055e-01,  -7.66598061e-02,
                         -5.31785786e-01,  -7.17054188e-01,  -6.64595723e-01,
                         -6.13505960e-01,  -6.80683017e-01,  -7.85867274e-01,
                         -4.67355102e-01,  -3.32385674e-02,  -3.33940804e-01,
                         -7.72663355e-01,  -6.53492749e-01,  -5.82183897e-01,
                         -6.97190523e-01,  -6.73752069e-01,  -6.56815171e-01,
                         -6.59862220e-01,  -6.42174006e-01,  -6.51270211e-01,
                         -6.30864322e-01,  -6.32942200e-01,  -6.48650289e-01,
                         -6.51919782e-01,  -6.81960940e-01,  -6.47911727e-01,
                         -6.16683602e-01,  -6.52390122e-01,  -6.38474584e-01,
                         -6.54848516e-01,  -6.89137042e-01,  -6.40053868e-01,
                         -6.36031806e-01,  -6.47254527e-01,  -6.25776768e-01,
                         -6.62013352e-01,  -6.57762825e-01,  -6.26531065e-01,
                         -6.69585407e-01,  -6.78016663e-01,  -6.48473203e-01,
                         -6.46549881e-01,  -6.46570325e-01,  -6.61652386e-01,
                         -6.73322558e-01,  -6.72603130e-01,  -6.72405183e-01,
                         -6.45447493e-01,  -6.37294173e-01,  -6.56413972e-01,
                         -6.57602191e-01,  -6.74718082e-01,  -6.81869030e-01,
                         -6.56664550e-01,  -6.65426075e-01,  -6.69413030e-01,
                         -6.23425305e-01,  -6.08463764e-01,  -6.49877310e-01,
                         -6.77057207e-01,  -6.64316535e-01,  -6.46081150e-01,
                         -6.41047180e-01,  -6.57040358e-01,  -6.89692080e-01,
                         -6.82195663e-01,  -6.37927830e-01,  -6.49133623e-01,
                         -6.89518511e-01,  -6.58748209e-01,  -6.22394323e-01,
                         -6.69116080e-01,  -7.02683985e-01,  -6.80603683e-01,
                         -6.93899095e-01,  -6.98801816e-01,  -6.58504903e-01,
                         -6.72020257e-01,  -6.67640388e-01,  -6.02576494e-01,
                         -6.96125507e-01,  -7.98841655e-01,  -4.83977884e-01,
                         -1.17807448e-01,  -3.42407495e-01,  -7.38882720e-01,
                         -7.07743406e-01,  -6.05042219e-01,  -7.00524747e-01,
                         -7.12037742e-01,  -6.64672971e-01,  -7.03940630e-01,
                         -7.08415091e-01,  -6.65183723e-01,  -6.65019333e-01,
                         -6.96094275e-01,  -7.10417747e-01,  -6.95663154e-01,
                         -6.94842398e-01,  -7.13979900e-01,  -7.06044555e-01,
                         -6.77241087e-01,  -6.65379345e-01,  -6.83183551e-01,
                         -7.13930309e-01,  -7.20219254e-01,  -6.85476840e-01,
                         -6.77988768e-01,  -7.16265619e-01,  -6.74297333e-01,
                         -6.74419940e-01,  -8.10672760e-01,  -6.00396097e-01,
                         -1.48132235e-01,  -2.97026783e-01,  -7.63304472e-01,
                         -7.86583483e-01,  -6.81267917e-01,  -7.10580051e-01,
                         -6.64756358e-01,  -7.25162983e-01,  -8.07969511e-01,
                         -4.20790911e-01,  -6.16532974e-02,  -5.31504631e-01,
                         -9.63727593e-01,  -4.61471498e-01,  -1.34827197e-01,
                         -5.42133212e-01,  -5.01576066e-01,   4.14291322e-02,
                         -1.29169337e-02,  -5.90008616e-01,  -8.22063208e-01,
                         -6.35840893e-01,  -6.61999881e-01,  -8.32598746e-01,
                         -4.87201989e-01,  -1.01309739e-01,  -5.07670581e-01,
                         -9.17337418e-01,  -4.77537036e-01,  -1.02226473e-01,
                         -4.72481221e-01,  -8.04318845e-01,  -7.85833895e-01,
                         -7.10807860e-01,  -3.27602237e-01,   9.44205672e-02,
                         -1.31668419e-01,  -6.47699237e-01,  -8.21767807e-01,
                         -5.64920187e-01,  -1.04760565e-01,   1.66916531e-02,
                         -3.95265937e-01,  -8.14250469e-01,  -7.31410921e-01,
                         -3.13340843e-01,  -6.03760816e-02,   2.82706469e-02,
                         -8.20678398e-02,  -5.22230029e-01,  -5.32052875e-01,
                         -1.21123426e-01,  -4.57010567e-01,  -9.98217106e-01,
                         -5.69070816e-01,  -3.02438643e-02,  -4.32478100e-01,
                         -9.55934703e-01,  -5.73700428e-01,  -1.12987854e-01,
                         -4.59760219e-01,  -6.22063458e-01,  -1.52050048e-01,
                          6.15399852e-02,  -5.42140603e-02,  -1.04710169e-01,
                         -7.40662403e-03,   1.61481760e-02,  -4.16521251e-01,
                         -6.68514192e-01,  -2.12435782e-01,   5.39509803e-02,
                         -1.08797163e-01,  -1.01151258e-01,  -1.23420451e-02,
                         -2.92412769e-02,  -6.89923391e-02,  -6.08688593e-02,
                         -2.67444607e-02,  -8.48248824e-02,  -5.39452769e-02,
                         -9.89568699e-03,  -4.48631912e-01,  -9.00370061e-01,
                         -5.72496235e-01,  -1.33721828e-01,  -4.12844718e-01,
                         -6.02645278e-01,  -6.43557683e-02,   1.14628844e-01,
                         -4.67266083e-01,  -6.05473518e-01,  -1.19849846e-01,
                          6.66335225e-02,  -6.78426474e-02,  -3.22751626e-02,
                         -6.29290380e-03,  -4.08642292e-01,  -8.36554885e-01,
                         -6.26787007e-01,  -1.68325067e-01,  -5.71168866e-03,
                          5.81607334e-02,  -8.56777504e-02,  -5.26582420e-01,
                         -5.01392365e-01,   5.54631166e-02,   5.70641048e-02,
                         -5.23354530e-01,  -5.53611219e-01,  -1.58089306e-02,
                          1.03574537e-01,  -3.70712668e-01,  -7.59064317e-01,
                         -6.24675453e-01,  -2.03103989e-01,   7.84839392e-02,
                         -7.13427663e-02,  -6.37226462e-01,  -7.88304806e-01,
                         -2.25242376e-01,  -1.36429846e-01,  -5.28087556e-01,
                         -3.19264203e-01,  -1.26754463e-01,  -5.20567238e-01,
                         -7.77129769e-01,  -7.52253771e-01,  -4.59153682e-01,
                         -3.93231250e-02,  -3.09482336e-01,  -8.38556826e-01,
                         -5.32451808e-01,  -3.95911559e-02,  -3.05078804e-01,
                         -7.23949492e-01,  -6.49538100e-01,  -6.03276908e-01,
                         -7.41663814e-01,  -4.29840207e-01,  -6.29310235e-02,
                         -3.58980387e-01,  -7.29648590e-01,  -6.88210011e-01,
                         -5.78502178e-01,  -6.38766408e-01,  -7.67004013e-01,
                         -5.07152319e-01,  -2.75715385e-02,  -2.28190824e-01,
                         -7.40915716e-01,  -7.04083145e-01,  -5.64669669e-01,
                         -6.49570405e-01,  -6.48549676e-01,  -6.25988424e-01,
                         -6.45691037e-01,  -6.60980046e-01,  -6.80285156e-01,
                         -6.09243453e-01,  -5.90577781e-01,  -6.56882405e-01,
                         -5.90612352e-01,  -6.35626435e-01,  -7.59830832e-01,
                         -4.12427634e-01,  -3.84931341e-02,  -3.56047302e-01,
                         -7.53453195e-01,  -6.56692863e-01,  -5.47804356e-01,
                         -6.46789253e-01,  -6.74316585e-01,  -6.37094498e-01,
                         -6.14612043e-01,  -5.94299555e-01,  -6.34407997e-01,
                         -6.67602420e-01,  -6.26327097e-01,  -6.11818552e-01,
                         -6.32365882e-01,  -6.33299530e-01,  -6.32346392e-01,
                         -6.30598843e-01,  -6.29097462e-01,  -6.23769999e-01,
                         -6.17900431e-01,  -6.36889279e-01,  -6.38796628e-01,
                         -6.24770701e-01,  -6.36939287e-01,  -6.24829412e-01,
                         -6.08552992e-01,  -6.28579021e-01,  -6.18580997e-01,
                         -6.04955435e-01,  -6.26131713e-01,  -6.22968793e-01,
                         -6.08083725e-01,  -6.11093283e-01,  -6.19900286e-01,
                         -6.29255295e-01,  -6.21690333e-01,  -6.24446332e-01,
                         -6.51225865e-01,  -6.46915853e-01,  -6.16221905e-01,
                         -6.08961284e-01,  -6.31237864e-01,  -6.40198648e-01,
                         -6.23512506e-01,  -6.36280894e-01,  -6.42018557e-01,
                         -6.02684379e-01,  -6.10152721e-01,  -6.35870278e-01,
                         -6.23591006e-01,  -6.44228339e-01,  -6.46759868e-01,
                         -6.05324686e-01,  -6.20703459e-01,  -6.40205801e-01,
                         -6.23595119e-01,  -6.37177348e-01,  -6.37795568e-01,
                         -6.16583884e-01,  -6.34555578e-01,  -6.51887417e-01,
                         -6.48432314e-01,  -6.56267941e-01,  -6.54616058e-01,
                         -6.58682823e-01,  -6.76499844e-01,  -6.47147894e-01,
                         -6.40908659e-01,  -6.75698102e-01,  -6.14323556e-01,
                         -6.48378134e-01,  -7.72529662e-01,  -4.49601680e-01,
                         -5.80096841e-02,  -3.62606436e-01,  -7.38071322e-01,
                         -6.42876327e-01,  -5.99850953e-01,  -6.80289447e-01,
                         -6.64907753e-01,  -6.53940797e-01,  -6.28426373e-01,
                         -6.29546165e-01,  -6.85536385e-01,  -6.85650289e-01,
                         -6.46243989e-01,  -6.12850904e-01,  -7.13487208e-01,
                         -6.90157712e-01,  -1.87750071e-01,  -1.04591012e-01,
                         -7.58934498e-01,  -7.43252039e-01,  -8.54080319e-02,
                          4.14862521e-02,  -6.25691786e-02,  -5.22892037e-03,
                         -1.49079785e-02,   1.44789824e-02,   2.50478927e-02,
                         -2.79938709e-02,   1.19771054e-02,   1.10384468e-02,
                         -3.67773115e-03,   4.34816554e-02,   5.99069102e-03,
                         -1.45554049e-02,   1.86074618e-02,  -6.78199949e-03,
                         -2.82531395e-03,   1.21186888e-02,  -3.41628422e-03,
                          1.52042964e-02,   1.54962260e-02,   4.91241924e-03,
                          7.25453254e-03,  -1.48894619e-02,  -3.80922342e-03,
                          1.85440145e-02,   6.52375631e-03,   6.55262079e-03,
                         -2.61445204e-03,  -8.93000606e-03,   6.55805087e-03,
                          1.26363290e-03,   4.57762601e-03,   5.84350107e-03,
                         -8.88347346e-03,   6.20850502e-03,   1.38902233e-03,
                         -1.66587681e-02,   1.00824414e-02,   3.05948351e-02,
                          2.71572303e-02,  -3.48088518e-03,  -2.97798682e-02,
                          2.10456997e-02,   4.35274020e-02,  -6.77096285e-03,
                         -1.26023707e-03,   2.83885226e-02,   1.13201244e-02,
                         -2.04349943e-02,  -3.22328582e-02,   4.38366318e-03,
                          2.09161770e-02,  -5.87350316e-03,   1.63200665e-02,
                          3.08776665e-02,  -4.99496050e-03,  -5.68649219e-03,
                          3.85779003e-03,  -1.66677544e-03,   9.43782646e-03,
                          9.12728440e-03,  -2.23235716e-03,  -9.85142891e-04,
                          7.30015198e-03,   6.32348238e-03,  -4.59617469e-03,
                          5.00642927e-03,   3.36622773e-03,  -1.93392467e-02,
                          2.10331567e-03,   1.34003907e-02,  -1.35677950e-02,
                         -7.38900388e-03,  -7.14424811e-03,  -9.54218395e-03,
                          1.67835969e-02,  -4.09679580e-03,  -2.85886042e-02,
                         -1.85021432e-03,   7.43266940e-03,   7.72149069e-03,
                          4.98699956e-03,  -1.83462556e-02,  -1.61420908e-02,
                         -1.04629982e-03,   4.76729561e-04,  -9.66111757e-03,
                         -2.88744625e-02,  -1.10077243e-02,   1.42695149e-02,
                         -6.64312299e-03,  -2.15640124e-02,  -2.00209916e-02,
                         -1.85356215e-02,  -1.01410353e-03,   9.19757131e-03,
                          6.18883455e-03,  -4.11677035e-03,  -1.81940999e-02,
                         -1.77895166e-02,  -1.74548030e-02,  -1.44450890e-03,
                          1.85056664e-02,  -1.23677058e-02,  -1.78684536e-02,
                          2.56684478e-02,   1.96159910e-02,  -3.13617638e-03,
                          3.12296161e-03,   6.80099707e-03,   5.65171707e-03,
                         -4.37264284e-03,   2.99954228e-03,   2.25441419e-02,
                          1.28972791e-02,   1.60549842e-02,   1.14748590e-02,
                         -1.76363830e-02,   7.46412855e-03,   2.05159187e-02,
                         -1.43443989e-02,  -2.65235081e-03,   1.04404129e-02,
                         -7.14613823e-04,   5.65681094e-03,  -9.22714081e-03,
                         -2.12393105e-02,  -8.58180504e-03,  -3.11102805e-04,
                          1.48441950e-02,  -2.20176275e-03,  -3.36379781e-02,
                         -1.04983021e-02,   9.08440351e-03,   3.98886576e-03,
                          5.94334165e-03,   2.06890889e-03,   5.94220450e-03,
                         -7.80281471e-03,  -2.92964596e-02,   3.46055813e-03,
                          2.36784611e-02,  -2.68126343e-04,  -1.39478883e-02,
                         -1.93584524e-02,   2.76611117e-03,   2.11368911e-02,
                         -5.12723764e-03,   3.10325925e-03,   2.92454902e-02,
                          1.41786598e-02,   2.42747320e-03,  -9.87278111e-03,
                         -1.76095683e-02,  -3.26110120e-03,  -5.47152990e-03,
                          3.18054634e-04,   1.00384559e-02,  -5.33479964e-03,
                          5.07272827e-03,   1.35582965e-02,  -5.07559534e-03,
                         -9.01320367e-04,  -2.17129639e-03,  -4.31244681e-03,
                          9.82826669e-03,  -9.10671707e-03,  -1.60108376e-02,
                          8.28047283e-03,   6.66189613e-03,   1.82275940e-03,
                         -8.03473964e-03,  -1.76299121e-02,   9.56776459e-03,
                          8.99431854e-03,  -1.01957209e-02,   9.43843462e-03,
                         -2.77288666e-04,  -2.70910766e-02,  -1.35012241e-02,
                         -2.76374049e-03,   5.26315067e-03,   8.92822724e-03,
                         -1.05598597e-02,  -7.93483574e-03,  -1.89671479e-03,
                         -1.30381584e-02,  -2.81213108e-03,  -6.99620927e-03,
                         -2.19090246e-02,  -9.82925948e-03,  -1.85775720e-02,
                         -1.19910575e-02,   2.70744972e-02,   5.75839728e-03,
                         -1.04327081e-02,   2.20309221e-03,  -2.79187616e-02,
                         -4.53439308e-03,  -1.44014567e-01,  -6.38045013e-01,
                         -7.88277924e-01,  -3.00891608e-01,   5.40222935e-02,
                          3.64714935e-02,  -3.04681640e-02,  -2.03347057e-02,
                          1.25551596e-01,   1.93273611e-02,  -4.59659874e-01,
                         -4.88950044e-01,  -3.07511557e-02,   1.00360349e-01,
                         -4.81231138e-02,  -3.18654515e-02,   6.49918765e-02,
                         -5.70882158e-03,  -5.82406819e-02,   1.34700626e-01,
                         -8.49247258e-03,  -5.14198720e-01,  -4.03072566e-01,
                         -1.17423035e-01,  -4.26993966e-01,  -4.40269262e-01,
                          7.30716763e-03,   1.19213529e-01,   1.29837766e-02,
                         -2.46436626e-01,  -7.01212227e-01,  -7.33189404e-01,
                         -2.25706384e-01,   1.40558437e-01,  -7.18548670e-02,
                         -5.36795557e-01,  -7.23618805e-01,  -6.72022343e-01,
                         -6.06321573e-01,  -6.58821642e-01,  -7.79670298e-01,
                         -4.87555742e-01,  -6.75554052e-02,  -3.29710454e-01,
                         -7.33264208e-01,  -6.56585217e-01,  -6.00106239e-01,
                         -6.81563854e-01,  -6.58194602e-01,  -6.45297229e-01,
                         -6.56745017e-01,  -6.51488066e-01,  -6.49850428e-01,
                         -6.33437753e-01,  -6.45406187e-01,  -6.66123867e-01,
                         -6.57628953e-01,  -6.52700126e-01,  -6.51835024e-01,
                         -6.55861259e-01,  -6.49611235e-01,  -6.46629930e-01,
                         -6.72444105e-01,  -6.57199442e-01,  -6.33479655e-01,
                         -6.64621711e-01,  -6.59809053e-01,  -6.32869124e-01,
                         -6.56029642e-01,  -6.66522324e-01,  -6.43498361e-01,
                         -6.40803218e-01,  -6.63819790e-01,  -6.65816069e-01,
                         -6.44476056e-01,  -6.51894152e-01,  -6.58311129e-01,
                         -6.42160416e-01,  -6.60054386e-01,  -6.77676499e-01,
                         -6.59786284e-01,  -6.52425468e-01,  -6.52542531e-01,
                         -6.51572526e-01,  -6.55542612e-01,  -6.54806197e-01,
                         -6.63404047e-01,  -6.68659508e-01,  -6.61135674e-01,
                         -6.64055407e-01,  -6.63996994e-01,  -6.75104797e-01,
                         -7.01552153e-01,  -6.75921261e-01,  -6.33891702e-01,
                         -6.50586784e-01,  -6.72587335e-01,  -6.69907212e-01,
                         -6.72051668e-01,  -6.78934336e-01,  -6.88552618e-01,
                         -6.80456102e-01,  -6.63354874e-01,  -6.66020274e-01,
                         -6.61705256e-01,  -6.67930365e-01,  -6.83830440e-01,
                         -6.75614059e-01,  -6.95136011e-01,  -7.01706290e-01,
                         -6.83558643e-01,  -6.98307693e-01,  -6.39294386e-01,
                         -6.77808702e-01,  -8.35110247e-01,  -5.15049756e-01,
                         -7.54896328e-02,  -3.70480210e-01,  -7.91508138e-01,
                         -7.36325800e-01,  -6.63606346e-01,  -7.04048872e-01,
                         -7.07080543e-01,  -6.91288233e-01,  -6.61617398e-01,
                         -6.94646537e-01,  -7.22276568e-01,  -6.87880158e-01,
                         -6.91269517e-01,  -6.90756381e-01,  -7.07716644e-01,
                         -7.38907158e-01,  -6.98874652e-01,  -6.95183873e-01,
                         -7.03319430e-01,  -6.77922964e-01,  -7.08108068e-01,
                         -7.15795577e-01,  -7.21748829e-01,  -7.33240664e-01,
                         -6.90355301e-01,  -7.16431558e-01,  -6.88673675e-01,
                         -6.66994035e-01,  -8.34890187e-01,  -6.18273139e-01,
                         -1.37296274e-01,  -3.28743875e-01,  -7.71865189e-01,
                         -7.52173364e-01,  -6.83959246e-01,  -7.38836706e-01,
                         -6.88726425e-01,  -7.25654662e-01,  -7.90214479e-01,
                         -4.19259191e-01,  -7.44025037e-02,  -5.47130048e-01,
                         -9.44850266e-01,  -4.12386805e-01,  -1.30564258e-01,
                         -5.66061974e-01,  -5.06496012e-01,   4.17765006e-02,
                         -1.44131007e-02,  -5.85631251e-01,  -8.06509674e-01,
                         -6.54471517e-01,  -7.19543159e-01,  -8.42668951e-01,
                         -4.58769798e-01,  -8.44613016e-02,  -5.06425083e-01,
                         -9.35250878e-01,  -4.76722330e-01,  -1.10324994e-01,
                         -5.11823714e-01,  -7.92014718e-01,  -7.54949689e-01,
                         -7.14935780e-01,  -3.51654321e-01,   4.96757105e-02,
                         -1.16669752e-01,  -6.04400575e-01,  -8.46698999e-01,
                         -5.63203096e-01,  -6.56101406e-02,   5.24607711e-02,
                         -3.49461824e-01,  -8.38959217e-01,  -7.57676661e-01,
                         -2.69553632e-01,  -5.74250557e-02,   2.58519184e-02,
                         -6.87645152e-02,  -5.45373261e-01,  -5.41859925e-01,
                         -1.43171713e-01,  -4.53626513e-01,  -9.19891000e-01,
                         -5.58058560e-01,  -8.18441138e-02,  -4.52444196e-01,
                         -9.60256159e-01,  -5.56014180e-01,  -1.17947862e-01,
                         -4.78600562e-01,  -5.77893853e-01,  -1.21617749e-01,
                          2.83835419e-02,  -9.37329605e-02,  -1.13055035e-01,
                          8.41438398e-03,  -4.94922884e-03,  -4.36084539e-01,
                         -6.30034328e-01,  -1.96012110e-01,   4.59583513e-02,
                         -9.15646404e-02,  -7.91412443e-02,  -1.14127733e-02,
                         -6.84317723e-02,  -9.05335397e-02,  -4.50568721e-02,
                         -2.64379550e-02,  -5.82034886e-02,  -4.06469367e-02,
                         -4.96109016e-02,  -4.37870532e-01,  -8.93153667e-01,
                         -5.97371459e-01,  -9.90119651e-02,  -4.17096883e-01,
                         -6.52354360e-01,  -4.60341796e-02,   1.20020568e-01,
                         -5.02846539e-01,  -6.14893615e-01,  -1.20649248e-01,
                          6.24779053e-02,  -8.28045532e-02,  -3.99771594e-02,
                          2.70855669e-02,  -3.82411748e-01,  -8.44702363e-01,
                         -6.42237008e-01,  -1.73053041e-01,   6.81214547e-03,
                          5.42965047e-02,  -1.12809129e-01,  -5.43006003e-01,
                         -5.01095772e-01,   7.93767869e-02,   7.06091374e-02,
                         -5.50521731e-01,  -5.56862414e-01,   3.28293396e-03,
                          9.29320082e-02,  -3.78992170e-01,  -7.75914490e-01,
                         -6.62320018e-01,  -1.96407810e-01,   1.04841150e-01,
                         -7.83965737e-02,  -6.60148799e-01,  -8.32310915e-01,
                         -2.60454357e-01,  -1.31662920e-01,  -5.41323185e-01,
                         -3.46797049e-01,  -1.37530640e-01,  -5.45008302e-01,
                         -7.70516276e-01,  -6.93805575e-01,  -4.46916252e-01,
                         -8.31666142e-02,  -3.35160702e-01,  -8.38167846e-01,
                         -5.28075814e-01,  -4.38714549e-02,  -3.28288257e-01,
                         -7.45540857e-01,  -6.47490084e-01,  -6.13665879e-01,
                         -7.77978122e-01,  -4.34423000e-01,  -4.81438078e-02,
                         -3.79052639e-01,  -7.51844406e-01,  -6.92920744e-01,
                         -5.82511604e-01,  -6.19296968e-01,  -7.33756185e-01,
                         -5.23776531e-01,  -1.02016650e-01,  -2.62182385e-01,
                         -6.94392025e-01,  -6.86493695e-01,  -5.96803725e-01,
                         -6.45746112e-01,  -6.26130223e-01,  -6.29585564e-01,
                         -6.61349952e-01,  -6.54358387e-01,  -6.49590492e-01,
                         -6.15375578e-01,  -6.22094750e-01,  -6.69756532e-01,
                         -6.15268171e-01,  -6.42509520e-01,  -7.35034347e-01,
                         -4.09416676e-01,  -3.51627208e-02,  -3.44750851e-01,
                         -7.48551965e-01,  -6.54348433e-01,  -5.71799636e-01,
                         -6.46814287e-01,  -6.31714642e-01,  -6.24850154e-01,
                         -6.29342020e-01,  -6.28509760e-01,  -6.56532884e-01,
                         -6.28527462e-01,  -6.13232315e-01,  -6.42697453e-01,
                         -6.37885034e-01,  -6.32372677e-01,  -6.24307632e-01,
                         -6.29185259e-01,  -6.47201598e-01,  -6.18420184e-01,
                         -6.21715546e-01,  -6.49212956e-01,  -6.25306427e-01,
                         -6.16183400e-01,  -6.12478852e-01,  -6.11716092e-01,
                         -6.41262531e-01,  -6.38804555e-01,  -6.36421740e-01,
                         -6.39014900e-01,  -6.12464070e-01,  -6.24986410e-01,
                         -6.36381388e-01,  -6.17425263e-01,  -6.29546285e-01,
                         -6.28861129e-01,  -6.19427562e-01,  -6.34877861e-01,
                         -6.33217216e-01,  -6.29553020e-01,  -6.33528709e-01,
                         -6.32304847e-01,  -6.35900021e-01,  -6.30217135e-01,
                         -6.24384344e-01,  -6.27412796e-01,  -6.34458959e-01,
                         -6.43271029e-01,  -6.28780365e-01,  -6.15818083e-01,
                         -6.27835035e-01,  -6.32563889e-01,  -6.29838586e-01,
                         -6.25630736e-01,  -6.29871428e-01,  -6.43093944e-01,
                         -6.31325901e-01,  -6.17499709e-01,  -6.27525330e-01,
                         -6.43247962e-01,  -6.46999300e-01,  -6.28801405e-01,
                         -6.33179188e-01,  -6.43647790e-01,  -6.18027091e-01,
                         -6.48552358e-01,  -6.89241648e-01,  -6.36780143e-01,
                         -6.33450806e-01,  -6.62482440e-01,  -5.91666639e-01,
                         -6.36399448e-01,  -7.49531627e-01,  -4.55721051e-01,
                         -7.75617138e-02,  -3.30123544e-01,  -7.31262207e-01,
                         -6.70393109e-01,  -5.99511027e-01,  -6.78044558e-01,
                         -6.44464672e-01,  -6.43238842e-01,  -6.68959141e-01,
                         -6.42732680e-01,  -6.59741700e-01,  -6.52807057e-01,
                         -6.27786934e-01,  -6.40919983e-01,  -7.32357085e-01,
                         -7.04238057e-01,  -2.05554843e-01,  -4.50966768e-02,
                         -7.15826929e-01,  -7.65970528e-01,  -5.90299070e-02,
                          6.36227801e-02,  -7.07476959e-02,   2.68798620e-02,
                          6.87006675e-03,   1.67176183e-02,   2.71879062e-02,
                         -3.48680876e-02,   3.65633592e-02,   2.24083234e-02,
                         -5.05394526e-02,   4.45534382e-03,   4.02176706e-03,
                          1.17360018e-02,   4.00147066e-02,  -2.31136475e-02,
                         -1.38369948e-02,   2.82388180e-02,   1.33487163e-02,
                          1.36075839e-02,  -7.38996500e-03,  -1.69604050e-03,
                          2.89984439e-02,   9.54080652e-03,   9.88561101e-03,
                          5.02180681e-03,  -3.98269901e-03,   2.24011634e-02,
                         -4.85805422e-03,  -9.36734676e-03,   3.79480384e-02,
                          1.53976027e-02,   3.47880268e-04,   1.13575272e-02,
                         -1.97390583e-03,   1.80566963e-02,   4.82069980e-03,
                         -3.44383195e-02,   4.57957992e-03,   3.16414088e-02,
                          8.06914736e-03,  -7.23199511e-04,  -5.38817188e-03,
                          4.36245510e-03,   2.26944219e-02,   1.75353251e-02,
                          1.35271894e-02,   1.80929936e-02,   1.41323041e-02,
                         -2.60038814e-03,  -5.73432213e-03,   2.47766748e-02,
                          1.86688267e-02,  -2.25456469e-02,   5.55797946e-03,
                          4.64010425e-02,   2.02549361e-02,   4.48754011e-03,
                          7.58056389e-03,  -1.58122298e-03,   1.37277357e-02,
                          1.57405660e-02,  -4.53790091e-03,   1.17473425e-02,
                          1.98058691e-02,   6.11979701e-03,   1.41823599e-02,
                          2.84418324e-03,  -1.63180325e-02,   2.07980117e-03,
                          1.94389764e-02,   2.01506428e-02,   9.59694944e-03,
                         -3.94837232e-03,  -9.91197652e-04,  -3.51204025e-03,
                          3.64217092e-03,   2.36140843e-02,   5.05557284e-03,
                         -6.52784074e-04,   2.78480425e-02,   1.45528903e-02,
                         -6.07345672e-03,   8.22176691e-03,   1.52030149e-02,
                          3.16758780e-03,  -1.31093580e-02,  -5.00224857e-03,
                          1.35720884e-02,   2.86066579e-03,   4.10369923e-03,
                          1.51340570e-02,  -4.07257630e-03,  -7.73637183e-03,
                         -2.92970362e-04,  -1.38441548e-02,  -1.51487142e-02,
                         -1.28370989e-02,  -1.43627394e-02,   2.57913233e-03,
                          1.01367906e-02,  -3.20157805e-03,  -1.09441644e-02,
                         -1.06678372e-02,  -1.93576030e-02,  -2.90544257e-02,
                         -6.97314320e-03,   1.33292060e-02,  -9.12720431e-03,
                         -1.79990157e-02,  -5.32192132e-03,  -1.40841538e-02,
                         -1.12466021e-02,   1.88859366e-03,  -1.22639891e-02,
                         -2.40398925e-02,  -1.45064052e-02,  -1.05818524e-03,
                          9.74522904e-04,  -1.41906254e-02,  -1.55166965e-02,
                          4.21513710e-03,  -1.27774477e-03,  -2.88544092e-02,
                         -2.35544331e-02,   7.66360154e-03,   6.62418967e-03,
                         -1.12280846e-02,  -2.75379326e-03,  -5.07114222e-03,
                         -2.34823357e-02,  -1.45305293e-02,  -4.72633727e-03,
                         -1.06953559e-02,  -1.16278157e-02,  -1.23061966e-02,
                         -3.75620346e-03,   1.06870907e-03,  -1.03015844e-02,
                         -3.24883149e-03,  -9.26468696e-04,  -1.96434464e-02,
                         -1.90700628e-02,  -1.35449376e-02,  -2.83170515e-03,
                          1.20348670e-02,  -1.12519842e-02,  -1.92535501e-02,
                          6.20985031e-03,  -1.96600892e-03,  -1.01307677e-02,
                         -7.34884664e-03,  -2.02843137e-02,  -3.95686179e-03,
                          1.22429095e-02,   6.05034234e-04,   2.29979330e-03,
                         -7.59786367e-03,  -1.27317002e-02,   6.28837105e-03,
                         -7.58038787e-03,  -1.15772467e-02,   5.11544803e-03,
                         -2.29629651e-02,  -2.13398226e-02,   2.23067533e-02,
                          1.05385715e-02,  -1.37588428e-02,  -4.81011206e-03,
                          3.39986570e-03,   6.98847231e-03,  -4.71427571e-03,
                         -1.38268238e-02,   5.33968490e-03,   1.59304272e-02,
                          9.47104767e-03,  -4.08575917e-03,  -1.80602539e-02,
                         -4.96161077e-03,   5.91977919e-03,  -4.78882389e-03,
                         -5.61593240e-03,  -1.26145920e-02,  -1.74586941e-02,
                          6.12514699e-03,   1.89684927e-02,   8.50254763e-03,
                         -4.27912921e-03,  -6.12514699e-03,   2.80631636e-03,
                         -5.84607990e-03,  -1.66738573e-02,  -1.33116348e-02,
                         -9.59435478e-03,   1.19854668e-02,   1.40093016e-02,
                         -1.14553329e-02,  -1.31975058e-02,  -7.43313367e-03,
                          1.80890691e-02,  -1.40342519e-01,  -6.30988955e-01,
                         -7.88265288e-01,  -2.98404127e-01,   6.73959032e-02,
                          4.60942313e-02,  -2.57390887e-02,  -3.86348628e-02,
                          8.98586065e-02,   1.53813921e-02,  -4.44857121e-01,
                         -5.04971683e-01,  -5.05840629e-02,   1.23876452e-01,
                         -6.52571069e-03,  -1.54283252e-02,   5.54708876e-02,
                         -1.16574327e-02,  -4.63008173e-02,   1.29852161e-01,
                         -2.05041450e-02,  -4.82367128e-01,  -3.85863215e-01,
                         -1.57486349e-01,  -4.50558275e-01,  -4.36796129e-01,
                          9.02601797e-03,   1.22813687e-01,   8.25516507e-03,
                         -2.46605501e-01,  -7.09080994e-01,  -7.59893239e-01,
                         -2.25049198e-01,   1.44301578e-01,  -8.47718939e-02,
                         -5.36062539e-01,  -7.35845804e-01,  -6.72940671e-01,
                         -5.82118571e-01,  -6.53941274e-01,  -7.49483228e-01,
                         -4.60601181e-01,  -1.03024974e-01,  -3.46833408e-01,
                         -7.40290344e-01,  -6.90172434e-01,  -6.07590914e-01,
                         -6.83802605e-01,  -6.60973907e-01,  -6.40157759e-01,
                         -6.71832263e-01,  -6.59851372e-01,  -6.79105401e-01,
                         -6.77933097e-01,  -6.24386251e-01,  -6.49484694e-01,
                         -6.75909102e-01,  -6.40661955e-01,  -6.58785343e-01,
                         -6.82739317e-01,  -6.59124315e-01,  -6.62512362e-01,
                         -6.66049659e-01,  -6.48068070e-01,  -6.56518579e-01,
                         -6.65690780e-01,  -6.52038038e-01,  -6.43952847e-01,
                         -6.53700948e-01,  -6.66665077e-01,  -6.59132183e-01,
                         -6.48279727e-01,  -6.59049749e-01,  -6.60400987e-01,
                         -6.53572440e-01,  -6.76088393e-01,  -6.87766731e-01,
                         -6.53772295e-01,  -6.31358862e-01,  -6.46908283e-01,
                         -6.72009230e-01,  -6.88840985e-01,  -6.77657008e-01,
                         -6.59830868e-01,  -6.61120117e-01,  -6.56840324e-01,
                         -6.67769015e-01,  -6.84667408e-01,  -6.58660650e-01,
                         -6.58031344e-01,  -6.95454538e-01,  -6.94450259e-01,
                         -6.78004801e-01,  -6.62087739e-01,  -6.58700883e-01,
                         -6.81659639e-01,  -6.67397022e-01,  -6.54784918e-01,
                         -6.74462020e-01,  -6.59455657e-01,  -6.68706894e-01,
                         -7.00023115e-01,  -6.87070429e-01,  -6.91468775e-01,
                         -6.86151564e-01,  -6.61796868e-01,  -6.92511201e-01,
                         -7.11157620e-01,  -6.87309682e-01,  -6.67590559e-01,
                         -6.89344108e-01,  -7.29696095e-01,  -6.72443092e-01,
                         -6.95410430e-01,  -8.02898586e-01,  -4.82903630e-01,
                         -9.88242999e-02,  -3.99221301e-01,  -7.99620688e-01,
                         -7.25993276e-01,  -6.29299939e-01,  -6.94344461e-01,
                         -7.29184091e-01,  -7.10660815e-01,  -6.71371341e-01,
                         -6.75979793e-01,  -7.05512822e-01,  -7.04428315e-01,
                         -7.14941740e-01,  -7.25650728e-01,  -7.20866084e-01,
                         -7.06950009e-01,  -6.74660683e-01,  -6.83288634e-01,
                         -7.25010276e-01,  -7.26465106e-01,  -7.10242808e-01,
                         -7.18824446e-01,  -7.23453403e-01,  -6.80894315e-01,
                         -6.87993765e-01,  -7.64289677e-01,  -7.07049608e-01,
                         -6.78450882e-01,  -8.18505764e-01,  -5.92750549e-01,
                         -1.33566901e-01,  -3.11027706e-01,  -7.88689256e-01,
                         -7.88514853e-01,  -6.73220575e-01,  -7.27090478e-01,
                         -6.79956555e-01,  -7.28218257e-01,  -8.18061173e-01,
                         -4.11799639e-01,  -7.90543780e-02,  -5.85529625e-01,
                         -9.34628248e-01,  -3.92613739e-01,  -1.37707531e-01,
                         -5.73338270e-01,  -5.25231183e-01,   3.70183997e-02,
                          6.96532615e-03,  -5.70766091e-01,  -8.11194062e-01,
                         -6.79190636e-01,  -7.33447611e-01,  -8.36627662e-01,
                         -4.64593142e-01,  -9.76305678e-02,  -5.06893218e-01,
                         -9.21802044e-01,  -4.70619947e-01,  -1.09448068e-01,
                         -4.92325664e-01,  -7.97927976e-01,  -7.88222432e-01,
                         -7.09071696e-01,  -3.30011368e-01,   6.25130981e-02,
                         -1.05477661e-01,  -6.25495017e-01,  -8.72028470e-01,
                         -5.65536380e-01,  -7.92688280e-02,   4.21852469e-02,
                         -3.39409679e-01,  -8.43315899e-01,  -7.78604567e-01,
                         -2.70384818e-01,  -3.62955183e-02,   4.01383340e-02,
                         -7.56160691e-02,  -5.77554822e-01,  -5.55457473e-01,
                         -1.09340928e-01,  -4.57119018e-01,  -9.54924464e-01,
                         -5.27647793e-01,  -4.46829125e-02,  -4.66947109e-01,
                         -9.78549898e-01,  -5.57383955e-01,  -9.48720351e-02,
                         -4.72538710e-01,  -6.15384579e-01,  -1.23500027e-01,
                          6.41141385e-02,  -8.77322108e-02,  -1.34827554e-01,
                         -1.59976557e-02,  -7.55453482e-03,  -4.24886435e-01,
                         -6.35106862e-01,  -1.98207960e-01,   6.96532801e-02,
                         -7.53114820e-02,  -1.22975789e-01,  -6.28997758e-02,
                         -4.10709195e-02,  -5.80838323e-02,  -7.17243850e-02,
                         -6.47988245e-02,  -7.98372105e-02,  -1.13798557e-02,
                         -2.65311655e-02,  -4.88869727e-01,  -9.01169538e-01,
                         -5.60009658e-01,  -1.09590009e-01,  -4.15735483e-01,
                         -6.48033798e-01,  -6.01693355e-02,   1.33586749e-01,
                         -5.18152654e-01,  -6.30769372e-01,  -8.39992985e-02,
                          5.83568104e-02,  -1.16051979e-01,  -4.59086634e-02,
                          2.27288287e-02,  -3.66706431e-01,  -8.20149004e-01,
                         -6.46225274e-01,  -2.07645789e-01,  -3.76537405e-02,
                          7.90107548e-02,  -5.25027066e-02,  -5.60668588e-01,
                         -5.42045057e-01,   6.00869879e-02,   4.12867144e-02,
                         -5.46898365e-01,  -5.25835991e-01,   2.31139995e-02,
                          1.07670948e-01,  -3.95337939e-01,  -8.09791803e-01,
                         -6.77498281e-01,  -2.01312229e-01,   1.20540865e-01,
                         -6.66584596e-02,  -6.69359982e-01,  -8.20893168e-01,
                         -2.61892885e-01,  -1.50708795e-01,  -5.14350832e-01,
                         -3.20161849e-01,  -1.35897160e-01,  -5.23779213e-01,
                         -7.73007512e-01,  -7.28325784e-01,  -4.49599385e-01,
                         -6.45936877e-02,  -3.42239857e-01,  -8.67809951e-01,
                         -5.26915193e-01,   6.29702059e-04,  -3.03421110e-01,
                         -7.55747437e-01,  -6.60486519e-01,  -6.16964638e-01,
                         -7.64012218e-01,  -4.27827060e-01,  -6.31377995e-02,
                         -3.68591577e-01,  -7.04291582e-01,  -6.68225765e-01,
                         -6.07873678e-01,  -6.38738692e-01,  -7.29671776e-01,
                         -5.38215995e-01,  -9.55271870e-02,  -2.13860556e-01,
                         -6.72280371e-01,  -6.83067143e-01,  -5.86557150e-01,
                         -6.49036109e-01,  -6.28942311e-01,  -6.23785555e-01,
                         -6.37588680e-01,  -6.15773976e-01,  -6.44522250e-01,
                         -6.36669159e-01,  -6.27080858e-01,  -6.39642000e-01,
                         -5.69508612e-01,  -6.37015760e-01,  -7.52104700e-01,
                         -4.19826180e-01,  -4.63447385e-02,  -3.14649522e-01,
                         -7.14073181e-01,  -6.65541589e-01,  -5.78329980e-01,
                         -6.67488158e-01,  -6.56123281e-01,  -6.02840424e-01,
                         -6.11921668e-01,  -6.06949627e-01,  -6.37688935e-01,
                         -6.62231803e-01,  -6.19014084e-01,  -6.15120113e-01,
                         -6.30667865e-01,  -6.12747371e-01,  -6.15226328e-01,
                         -6.25063717e-01,  -6.29099667e-01,  -6.32543385e-01,
                         -6.30207717e-01,  -6.41342044e-01,  -6.32460117e-01,
                         -6.06795609e-01,  -6.09187365e-01,  -6.13711894e-01,
                         -6.33102655e-01,  -6.56167448e-01,  -6.22535646e-01,
                         -5.99380016e-01,  -6.27697408e-01,  -6.39706075e-01,
                         -6.29442692e-01,  -6.22882426e-01,  -6.26284778e-01,
                         -6.33402407e-01,  -6.36265993e-01,  -6.47389591e-01,
                         -6.42119944e-01,  -6.16641164e-01,  -6.15757406e-01,
                         -6.17041230e-01,  -6.16261542e-01,  -6.43123269e-01,
                         -6.44926846e-01,  -6.17845297e-01,  -6.22184277e-01,
                         -6.37471020e-01,  -6.38138652e-01,  -6.28364623e-01,
                         -6.11592948e-01,  -6.33401036e-01,  -6.72099292e-01,
                         -6.46805704e-01,  -6.15733564e-01,  -6.35389566e-01,
                         -6.37569726e-01,  -6.31580532e-01,  -6.43706381e-01,
                         -6.39731705e-01,  -6.46448910e-01,  -6.37861192e-01,
                         -6.02950752e-01,  -6.30209386e-01,  -6.53600693e-01,
                         -6.39595628e-01,  -6.63634360e-01,  -6.39630973e-01,
                         -6.26156509e-01,  -6.76725447e-01,  -6.07492149e-01,
                         -6.33104324e-01,  -7.74407387e-01,  -4.58314359e-01,
                         -6.20515049e-02,  -3.41908813e-01,  -7.29932070e-01,
                         -6.84089303e-01,  -6.19417787e-01,  -6.68507099e-01,
                         -6.51135385e-01,  -6.38656557e-01,  -6.65921330e-01,
                         -6.60296559e-01,  -6.40375972e-01,  -6.66308463e-01,
                         -6.52223825e-01,  -6.02831304e-01,  -7.31518209e-01,
                         -6.91593111e-01,  -1.69185460e-01,  -9.68704969e-02,
                         -7.21183360e-01,  -7.12926865e-01,  -7.55030587e-02,
                          5.50395362e-02,  -7.00895265e-02,   1.95044577e-02,
                          2.19185725e-02,   5.09694743e-04,   3.60103026e-02,
                         -1.87951773e-02,  -1.38497930e-02,   2.15233583e-02,
                         -2.12695356e-02,   9.02814791e-03,   4.14962471e-02,
                          3.78758297e-03,   2.04166695e-02,   3.11760660e-02,
                          3.85932787e-03,  -1.38934259e-03,  -8.27073399e-03,
                          1.42353801e-02,   2.81868558e-02,  -1.06174601e-02,
                          2.40110746e-03,   3.56777012e-02,   2.62158662e-02,
                          2.28377841e-02,  -1.21541852e-02,  -3.80475745e-02,
                          1.19624967e-02,   2.81411409e-02,   1.19821830e-02,
                          2.73594428e-02,   1.25601310e-02,  -8.03624559e-03,
                          3.92998336e-03,   6.03142520e-03,   7.81751890e-03,
                          3.87380831e-04,  -1.22030405e-02,   1.14919506e-02,
                          1.29165491e-02,  -8.07038043e-03,   3.06094605e-02,
                          5.46455383e-02,  -1.71503786e-03,  -3.93859334e-02,
                         -1.62213147e-02,   1.05884997e-02,   1.97392032e-02,
                          1.53360935e-02,  -2.16594641e-03,  -9.93994437e-03,
                          3.70018836e-03,   7.58206984e-03,  -6.20475679e-04,
                          7.61085423e-03,   8.93071014e-03,  -3.44849657e-03,
                          1.11508779e-02,   2.56442763e-02,   1.16516184e-02,
                          1.43988766e-02,   2.24362593e-02,   6.62667226e-05,
                         -5.66421123e-03,   1.66047886e-02,   1.41706988e-02,
                         -6.71882415e-03,  -3.83632584e-03,   2.67625786e-02,
                          4.03630026e-02,   2.44703121e-03,  -2.12026928e-02,
                          1.05077205e-02,   1.55251063e-02,  -7.33287679e-03,
                          4.85196710e-03,   1.07302275e-02,  -5.26721939e-04,
                          1.04117404e-04,  -7.24066049e-03,   2.17312248e-03,
                          1.60849541e-02,  -7.89091364e-03,  -6.89519895e-03,
                          8.09809193e-03,  -1.49837444e-02,  -1.00219091e-02,
                          8.35109688e-03,   3.48175014e-03,   2.11485829e-02,
                          1.11043137e-02,  -2.88603511e-02,  -2.66136732e-02,
                         -2.68275309e-02,  -1.62064992e-02,   2.40784958e-02,
                          4.80769342e-03,  -9.22633987e-03,   3.54176983e-02,
                          1.35650085e-02,  -4.41133417e-02,  -2.79054344e-02,
                          6.68318383e-03,   1.38094916e-03,  -1.56106744e-02,
                         -5.47241094e-03,   1.69948284e-02,   1.30322315e-02,
                          2.16133310e-03,  -5.88691002e-03,  -8.49450659e-03,
                          1.17851449e-02,  -6.51823008e-04,  -3.12267635e-02,
                         -1.94830890e-03,   2.10255962e-02,   6.23179507e-03,
                          4.05460410e-03,  -5.95466653e-03,  -1.35894038e-03,
                          1.95269622e-02,   4.62386990e-03,  -3.12843965e-03,
                         -1.97826279e-03,  -8.93178396e-03,   1.41316475e-02,
                          1.19007314e-02,  -3.00196116e-03,   3.25517617e-02,
                          3.21032256e-02,  -5.24926325e-03,  -1.21513661e-02,
                         -8.77642445e-03,   1.08329831e-02,   5.16255759e-03,
                         -2.07543317e-02,   1.55087039e-02,   2.25352515e-02,
                         -1.36196939e-02,   1.04565751e-02,   9.85072367e-03,
                         -2.02852897e-02,   9.06814530e-04,   5.39622875e-03,
                         -1.09779472e-02,  -1.72845945e-02,  -1.86807290e-02,
                          1.33187948e-02,   2.05712281e-02,  -5.82716288e-03,
                          5.67897968e-03,   1.14880577e-02,  -2.48699635e-03,
                         -8.13432410e-03,  -1.99574474e-02,  -1.12786377e-02,
                          2.68337782e-03,   3.14261555e-03,   2.03499068e-02,
                          2.31508408e-02,   7.67076155e-03,  -2.96364585e-03,
                         -1.04380259e-02,   1.06316525e-02,   1.42670637e-02,
                         -2.04180628e-02,  -1.35397473e-02,   1.20666148e-02,
                          1.23251937e-02,   1.14186676e-02,   6.25760015e-03,
                          8.35406035e-03,   1.09197693e-02,  -1.07460376e-03,
                         -2.25410983e-03,  -8.63072369e-03,  -9.26547218e-03,
                          1.33986762e-02,   7.42845656e-03,  -7.05361785e-03,
                         -5.88971330e-03,  -2.28454415e-02,  -1.78169869e-02,
                          1.47646973e-02,   1.84790939e-02,   1.91455893e-03,
                         -8.52796808e-03,   5.94409462e-03,   2.82242093e-02,
                          1.15277832e-02,  -1.19902883e-02,  -5.56557160e-03,
                          5.92508120e-03,   3.84161191e-04,  -2.24686153e-02,
                         -1.26112765e-02,   2.50392742e-02,   3.40381414e-02,
                          3.54040340e-02,  -1.53375715e-01,  -6.27309799e-01,
                         -7.69895375e-01,  -3.04434299e-01,   7.33551458e-02,
                          7.27829337e-02,  -5.02283173e-03,  -8.26479122e-03,
                          1.31071344e-01,   4.78447042e-02,  -4.47287202e-01,
                         -5.19025147e-01,  -1.87166575e-02,   1.46460354e-01,
                         -2.81725992e-02,  -5.59664704e-03,   8.32745731e-02,
                         -2.34254394e-02,  -7.54854679e-02,   1.29889905e-01,
                          5.53262280e-03,  -4.82626975e-01,  -3.71678382e-01,
                         -8.29863101e-02,  -4.05036181e-01,  -4.19811577e-01,
                          4.62178439e-02,   1.16907775e-01,  -2.81262752e-02,
                         -2.40768015e-01,  -6.54744983e-01,  -7.05050766e-01,
                         -2.28886649e-01,   1.34856015e-01,  -5.04782796e-02,
                         -5.12980521e-01,  -7.23523557e-01,  -6.70082867e-01,
                         -5.97407222e-01,  -6.54850423e-01,  -7.55692601e-01,
                         -4.50244665e-01,  -6.13752231e-02,  -3.39388460e-01,
                         -7.38764226e-01,  -6.80571198e-01,  -6.12291694e-01,
                         -6.58174753e-01,  -6.40204787e-01,  -6.23230934e-01,
                         -6.19250298e-01,  -6.45149052e-01,  -6.62365496e-01,
                         -6.28378689e-01,  -6.40413463e-01,  -6.53006792e-01,
                         -6.18050992e-01,  -6.31501555e-01,  -6.65031135e-01,
                         -6.56649351e-01,  -6.47563577e-01,  -6.61716402e-01,
                         -6.67130709e-01,  -6.44344330e-01,  -6.29847527e-01,
                         -6.50299430e-01,  -6.77803993e-01,  -6.66528881e-01,
                         -6.22740030e-01,  -6.18521571e-01,  -6.59780979e-01,
                         -6.80914700e-01,  -6.59478307e-01,  -6.37061715e-01,
                         -6.58217311e-01,  -6.68980658e-01,  -6.50477350e-01,
                         -6.66487217e-01,  -6.64087057e-01,  -6.39764667e-01,
                         -6.55709803e-01,  -6.59998715e-01,  -6.68261886e-01,
                         -6.66961908e-01,  -6.30274713e-01,  -6.72620595e-01,
                         -6.94097996e-01,  -6.36430204e-01,  -6.79471374e-01,
                         -7.08554626e-01,  -6.50179565e-01,  -6.70566261e-01,
                         -6.96721077e-01,  -6.66759849e-01,  -6.56155050e-01,
                         -6.80662453e-01,  -7.19289720e-01,  -6.70586228e-01,
                         -6.09534502e-01,  -6.78416252e-01,  -7.13062763e-01,
                         -6.65003121e-01,  -6.68610334e-01,  -6.93819582e-01,
                         -6.99550569e-01,  -6.85207903e-01,  -6.75933540e-01,
                         -6.97447717e-01,  -6.85584188e-01,  -6.63350224e-01,
                         -6.89143181e-01,  -6.84475005e-01,  -6.36134446e-01,
                         -7.07179010e-01,  -7.96885490e-01,  -4.72327769e-01,
                         -8.09481591e-02,  -3.88363183e-01,  -8.20385039e-01,
                         -6.96691036e-01,  -5.98297000e-01,  -7.08244085e-01,
                         -6.94270730e-01,  -6.82412386e-01,  -6.86662555e-01,
                         -6.80365682e-01,  -7.28116989e-01,  -6.98095679e-01,
                         -6.68017030e-01,  -7.15704322e-01,  -7.01820910e-01,
                         -6.75115526e-01,  -6.87686801e-01,  -6.95447743e-01,
                         -7.06500292e-01,  -7.10787535e-01,  -7.13582993e-01,
                         -7.03814626e-01,  -6.86622262e-01,  -6.90268755e-01,
                         -7.10606217e-01,  -7.45036066e-01,  -6.96650863e-01,
                         -6.82889581e-01,  -8.19197059e-01,  -5.80564678e-01,
                         -8.45516101e-02,  -2.76935697e-01,  -7.96246767e-01,
                         -7.94103086e-01,  -6.65559590e-01,  -7.06466854e-01,
                         -6.76428080e-01,  -7.43642628e-01,  -8.08567286e-01,
                         -4.05586243e-01,  -5.92662692e-02,  -5.29691935e-01,
                         -9.45616543e-01,  -4.44166839e-01,  -1.20214082e-01,
                         -5.46661079e-01,  -5.30191600e-01,   5.17224036e-02,
                          2.41623186e-02,  -5.84912956e-01,  -8.18181455e-01,
                         -6.42010748e-01,  -7.05425680e-01,  -8.55206788e-01,
                         -4.69728917e-01,  -8.60011354e-02,  -5.25197685e-01,
                         -9.42032337e-01,  -4.70078558e-01,  -1.03920206e-01,
                         -4.90235060e-01,  -7.95008659e-01,  -7.58583963e-01,
                         -6.76115990e-01,  -3.32528174e-01,   7.17983544e-02,
                         -7.05437511e-02,  -6.08144879e-01,  -8.73442590e-01,
                         -5.78594685e-01,  -7.03314692e-02,   7.20563233e-02,
                         -3.57705176e-01,  -8.54871154e-01,  -7.38119841e-01,
                         -2.68803209e-01,  -5.18313088e-02,   5.21793328e-02,
                         -5.28808758e-02,  -5.03540158e-01,  -5.19713461e-01,
                         -1.77181244e-01,  -4.72190499e-01,  -9.18910682e-01,
                         -5.44940352e-01,  -6.54833764e-02,  -4.61080492e-01,
                         -9.44714308e-01,  -5.29086053e-01,  -1.34884879e-01,
                         -4.99343038e-01,  -5.74938118e-01,  -9.43438411e-02,
                          5.54445684e-02,  -1.00312218e-01,  -1.15266651e-01,
                          6.96321204e-03,  -1.65324025e-02,  -4.13008481e-01,
                         -6.19684577e-01,  -2.21650019e-01,   5.29553443e-02,
                         -6.66388571e-02,  -8.91821161e-02,  -5.66508248e-02,
                         -9.55750868e-02,  -6.68580160e-02,  -3.55870575e-02,
                         -5.00151329e-02,  -6.36840686e-02,  -2.20172759e-02,
                         -3.26158330e-02,  -4.73569691e-01,  -9.43030119e-01,
                         -5.76311469e-01,  -7.92807713e-02,  -4.28636909e-01,
                         -6.46661878e-01,  -5.97360171e-02,   1.33551270e-01,
                         -4.47417825e-01,  -6.17676556e-01,  -1.38851419e-01,
                          6.56273440e-02,  -8.75552073e-02,  -1.73392482e-02,
                          2.69692428e-02,  -4.20477152e-01,  -8.40231121e-01,
                         -6.30859852e-01,  -1.92816019e-01,  -2.58026961e-02,
                          4.43366989e-02,  -5.68092093e-02,  -5.28285444e-01,
                         -5.82296073e-01,   4.33658287e-02,   1.00405060e-01,
                         -5.22522092e-01,  -5.44923127e-01,  -1.34627325e-02,
                          8.90559927e-02,  -3.71423036e-01,  -8.00004840e-01,
                         -6.58615351e-01,  -1.45632535e-01,   1.35723919e-01,
                         -9.12410468e-02,  -6.84824884e-01,  -8.37923646e-01,
                         -2.76520222e-01,  -1.50593251e-01,  -5.10995448e-01,
                         -3.05102855e-01,  -1.14041477e-01,  -5.40410757e-01,
                         -8.01793873e-01,  -7.20927894e-01,  -4.62658793e-01,
                         -8.70858133e-02,  -3.16343069e-01,  -8.74618709e-01,
                         -5.74713528e-01,  -1.63548253e-02,  -3.24356735e-01,
                         -7.62422025e-01,  -6.22292638e-01,  -6.02344871e-01,
                         -7.88114786e-01,  -4.57857668e-01,  -5.40129691e-02,
                         -3.32256883e-01,  -7.32461154e-01,  -6.88924432e-01,
                         -5.52562237e-01,  -6.37132883e-01,  -7.56019473e-01,
                         -4.95238513e-01,  -6.89192861e-02,  -2.29428321e-01,
                         -6.75915062e-01,  -6.72213495e-01,  -5.75261354e-01,
                         -6.55818939e-01,  -6.19601309e-01,  -6.00956678e-01,
                         -6.65607154e-01,  -6.34627938e-01,  -6.13804877e-01,
                         -6.26733720e-01,  -6.30396962e-01,  -6.40146494e-01,
                         -5.86552024e-01,  -6.50133669e-01,  -7.53725946e-01,
                         -4.04012680e-01,  -2.71812268e-02,  -3.27428758e-01,
                         -7.39239633e-01,  -6.85276747e-01,  -5.76058090e-01,
                         -6.36546850e-01,  -6.43060386e-01,  -5.87528348e-01,
                         -5.90848804e-01,  -6.37338459e-01,  -6.37700558e-01,
                         -6.02597654e-01,  -6.24189556e-01,  -6.60152256e-01,
                         -6.29572809e-01,  -6.00728571e-01,  -6.17724359e-01,
                         -6.23345852e-01,  -6.16355479e-01,  -6.28906965e-01,
                         -6.36429012e-01,  -6.27920806e-01,  -6.39165103e-01,
                         -6.60807371e-01,  -6.41507864e-01,  -6.01787329e-01,
                         -6.15900517e-01,  -6.61456764e-01,  -6.47905111e-01,
                         -6.10774636e-01,  -6.29218340e-01,  -6.44250691e-01,
                         -6.18429363e-01,  -6.02031529e-01,  -6.00494027e-01,
                         -6.25172675e-01,  -6.55497670e-01,  -6.42081976e-01,
                         -6.46727324e-01,  -6.57813787e-01,  -6.15872920e-01,
                         -6.20446861e-01,  -6.50783062e-01,  -6.21287584e-01,
                         -6.29351795e-01,  -6.55900657e-01,  -6.34595335e-01,
                         -6.34207249e-01,  -6.16660714e-01,  -5.85263073e-01,
                         -6.21953785e-01,  -6.43210530e-01,  -6.25259101e-01,
                         -6.25296652e-01,  -6.10250711e-01,  -6.00387394e-01,
                         -6.20972455e-01,  -6.47754014e-01,  -6.55392230e-01,
                         -6.15215302e-01,  -6.16476297e-01,  -6.67854607e-01,
                         -6.32179439e-01,  -5.94434619e-01,  -6.34881318e-01,
                         -6.47095323e-01,  -6.30287886e-01,  -6.14525318e-01,
                         -6.49355888e-01,  -6.90978706e-01,  -5.89114070e-01,
                         -6.20602190e-01,  -7.80565441e-01,  -4.47641164e-01,
                         -4.77564111e-02,  -3.65942717e-01,  -7.46760666e-01,
                         -6.58528626e-01,  -5.83836734e-01,  -6.33961976e-01,
                         -6.29183829e-01,  -6.21267736e-01,  -6.47428572e-01,
                         -6.88685179e-01,  -6.73959315e-01,  -6.70119286e-01,
                         -7.01826334e-01,  -6.31537497e-01,  -6.76952720e-01,
                         -6.84647202e-01,  -2.10269913e-01,  -1.00178212e-01,
                         -7.28941262e-01,  -7.26921320e-01,  -6.46070093e-02,
                          8.06918070e-02,  -2.41819397e-02,   4.84572165e-02,
                         -2.88520544e-03,  -3.48929763e-02,   4.53739949e-02,
                          2.79497895e-02,  -1.01620192e-03,   7.99463131e-03,
                          4.44562081e-03,   1.97654720e-02,   9.23711993e-03,
                         -1.44792553e-02,  -4.35212348e-03,  -1.96253299e-04,
                          2.73197656e-03,   1.43760024e-02,   1.45290876e-02,
                         -7.29451329e-03,  -3.05636954e-02,   2.48970347e-03,
                          2.44547427e-02,  -2.54444350e-02,  -2.98063774e-02,
                          2.07563653e-03,  -2.08491087e-03,   2.35025976e-02,
                          4.13708277e-02,   1.27981594e-02,   8.19216575e-03,
                         -5.62821841e-03,  -3.04256845e-02,  -6.66743843e-03,
                          2.44961027e-02,   3.29382122e-02,   5.17139956e-03,
                         -4.00706418e-02,  -2.53897179e-02,   4.30597545e-04,
                         -6.00012578e-03,   1.75740570e-02,   2.60054525e-02,
                         -9.39196628e-03,  -2.65802275e-02,  -2.29757316e-02,
                          5.38479211e-03,   2.00789459e-02,  -1.97422616e-02,
                         -2.02652682e-02,   1.31712202e-02,  -7.80704315e-04,
                         -6.22457080e-03,   2.52992474e-03,  -1.62689050e-03,
                          2.13260800e-02,   2.76248623e-02,  -1.41404255e-03,
                         -1.43154701e-02,  -1.78883318e-02,   8.89867451e-03,
                          5.03779911e-02,   2.43178699e-02,  -2.31102835e-02,
                         -2.70054433e-02,  -1.53668160e-02,   1.79729064e-03,
                          9.07311123e-03,   7.53393513e-04,   9.43101849e-03,
                          2.30892189e-02,   1.49727399e-02,  -1.02474429e-02,
                         -2.19915025e-02,  -1.49294746e-03,   3.67234903e-03,
                         -1.34543870e-02,  -8.07521772e-03,  -3.63414595e-03,
                         -1.58964854e-03,   1.60604455e-02,   1.22542176e-02,
                          4.66825580e-03,   5.43507282e-03,  -9.56021994e-03,
                          3.42494994e-03,   1.39914248e-02,  -2.94322129e-02,
                         -3.40026952e-02,   9.29087680e-03,   1.43192504e-02,
                         -1.95420370e-03,  -8.79852939e-03,   2.97740544e-03,
                          1.23635894e-02,  -2.40372494e-02,  -3.38735096e-02,
                          3.45562468e-03,  -7.14067603e-03,  -2.63485424e-02,
                         -2.23748628e-02,  -2.70863026e-02,   2.07887534e-02,
                          4.64794673e-02,  -3.09800208e-02,  -4.22878750e-02,
                          1.47196222e-02,  -8.25788733e-03,  -3.10082939e-02,
                          3.79131525e-04,   1.61905289e-02,   1.70602296e-02,
                          7.81902485e-03,   7.70721864e-03,   1.87495425e-02,
                         -1.45455059e-02,  -3.36009115e-02,   1.69016831e-02,
                          4.87113260e-02,   2.27782931e-02,  -2.09179707e-02,
                         -3.17842551e-02,   8.59586895e-03,   2.87731979e-02,
                          1.69934016e-02,   2.66600624e-02,   2.69072056e-02,
                          1.31043289e-02,   1.30617050e-02,   2.48428923e-03,
                          1.33363181e-03,   1.96852535e-02,   1.32337548e-02,
                         -5.37721533e-03,  -1.20809507e-02,  -1.06980950e-02,
                         -4.68768587e-04,   6.76554919e-04,  -4.38611396e-03,
                          2.72984616e-03,   8.04700982e-03,   5.49634174e-03,
                          2.82087689e-03,   8.20895284e-03,   9.98509955e-03,
                         -1.54931666e-02,  -1.16227381e-02,   4.10580747e-02,
                          3.02276537e-02,  -2.81719752e-02,  -2.12864354e-02,
                          5.67013770e-03,   1.25147039e-02,   3.26982960e-02,
                          2.47249529e-02,  -8.38532764e-03,  -9.31623299e-03,
                          2.22795224e-03,   9.73987859e-03,   1.18229315e-02,
                          5.36140578e-04,   9.18712746e-03,   2.93058138e-02,
                          2.60859113e-02,   1.41406972e-02,  -2.36580381e-03,
                         -1.06216734e-02,  -7.69573404e-03,  -1.84604973e-02,
                         -2.18340615e-03,   2.86407750e-02,   1.30139710e-02,
                          1.24753313e-02,   2.43000723e-02,  -8.40275490e-04,
                          1.46931279e-02,   3.10281403e-02,  -2.00987123e-02,
                         -2.45786440e-02,   1.94702744e-02,   3.02087832e-02,
                          3.20272334e-02,   1.63474251e-02,  -1.79637759e-03,
                          2.39110738e-02,   4.04519029e-02,   1.37608927e-02,
                         -2.31119171e-02,  -3.55895869e-02,  -2.11815331e-02,
                         -1.05366977e-02,   1.14573510e-02,   3.51662301e-02,
                          2.12794989e-02,   9.38374922e-03,   8.01694393e-03,
                          9.98288859e-03,   1.01558678e-02,  -1.41465599e-02,
                          2.13761043e-04,  -1.38524920e-01,  -5.85345745e-01,
                         -7.37964690e-01,  -3.33306998e-01,   5.11520822e-03,
                          6.71623722e-02,   1.50644425e-02,  -2.86155473e-02,
                          1.07657142e-01,   1.03207417e-02,  -4.62726921e-01,
                         -4.76397485e-01,  -2.37106252e-02,   1.08068049e-01,
                         -1.87389385e-02,  -4.63223131e-03,   6.49209172e-02,
                         -1.55639499e-02,  -3.84467617e-02,   1.73061773e-01,
                          2.63549499e-02,  -4.68427539e-01,  -3.90332431e-01,
                         -1.44312412e-01,  -4.16739225e-01,  -4.35091138e-01,
                         -4.04877178e-02,   9.19063091e-02,   1.76614504e-02,
                         -2.47323141e-01,  -7.02967584e-01,  -7.18642890e-01,
                         -1.93082511e-01,   1.47668377e-01,  -9.48819965e-02,
                         -5.53054094e-01,  -7.31905401e-01,  -6.49462521e-01,
                         -5.88906944e-01,  -6.96752608e-01,  -7.74303913e-01,
                         -4.39391911e-01,  -8.39737430e-02,  -3.67151350e-01,
                         -7.58126438e-01,  -6.66542828e-01,  -5.55313945e-01,
                         -6.59825027e-01,  -6.93975568e-01,  -6.57968938e-01,
                         -6.59076095e-01,  -6.71660483e-01,  -6.83026314e-01,
                         -6.86032295e-01,  -6.77890301e-01,  -6.87097430e-01,
                         -6.98854148e-01,  -6.60552323e-01,  -6.33459389e-01,
                         -6.65591002e-01,  -6.62038088e-01,  -6.58391953e-01,
                         -6.99967861e-01,  -6.73250735e-01,  -6.47827268e-01,
                         -6.85913146e-01,  -6.56915247e-01,  -6.23572350e-01,
                         -6.68598175e-01,  -6.93091989e-01,  -6.70668781e-01,
                         -6.36101127e-01,  -6.37415409e-01,  -6.66534424e-01,
                         -6.49076045e-01,  -6.40863717e-01,  -6.65755033e-01,
                         -6.74999356e-01,  -7.01491177e-01,  -6.89488471e-01,
                         -6.43223941e-01,  -6.67529941e-01,  -6.76298559e-01,
                         -6.44843042e-01,  -6.59625709e-01,  -6.92135274e-01,
                         -7.30668962e-01,  -7.18914390e-01,  -6.49561763e-01,
                         -6.60865068e-01,  -6.95000410e-01,  -6.86488390e-01,
                         -7.10458636e-01,  -6.99914932e-01,  -6.60933495e-01,
                         -6.72624111e-01,  -6.88746214e-01,  -7.13905275e-01,
                         -7.03828812e-01,  -6.36956036e-01,  -6.45206988e-01,
                         -6.87675297e-01,  -6.98508382e-01,  -7.32803285e-01,
                         -7.30176151e-01,  -6.98734760e-01,  -7.00801551e-01,
                         -6.90177739e-01,  -6.69242084e-01,  -6.56958103e-01,
                         -7.04012752e-01,  -7.54765987e-01,  -6.49689138e-01,
                         -6.53284073e-01,  -7.94932783e-01,  -5.10583878e-01,
                         -1.51064977e-01,  -4.27181602e-01,  -7.83061564e-01,
                         -7.31906593e-01,  -6.67798996e-01,  -6.96623743e-01,
                         -7.12305665e-01,  -7.34592021e-01,  -6.90912724e-01,
                         -6.61114216e-01,  -7.17692614e-01,  -7.36512780e-01,
                         -7.13633716e-01,  -6.99236989e-01,  -6.98685884e-01,
                         -7.23253429e-01,  -7.23538637e-01,  -7.03115106e-01,
                         -7.15571582e-01,  -7.36064851e-01,  -7.17102468e-01,
                         -6.78866386e-01,  -6.92166507e-01,  -7.12360919e-01,
                         -7.11782694e-01,  -7.65432775e-01,  -7.39094913e-01,
                         -6.81605697e-01,  -7.79230535e-01,  -5.89511931e-01,
                         -1.55214116e-01,  -3.31953794e-01,  -7.98651040e-01,
                         -7.70123839e-01,  -6.63129151e-01,  -7.29410589e-01,
                         -6.76825523e-01,  -7.32434213e-01,  -8.11191916e-01,
                         -3.98249149e-01,  -7.35519007e-02,  -5.76911330e-01,
                         -9.33261693e-01,  -3.76836509e-01,  -1.09901443e-01,
                         -5.77537358e-01,  -5.23382485e-01,   6.12700172e-02,
                          1.03810495e-02,  -5.78489125e-01,  -8.06787491e-01,
                         -6.57345891e-01,  -7.16744184e-01,  -8.35666239e-01,
                         -4.43328500e-01,  -8.20822045e-02,  -5.28362751e-01,
                         -9.46541369e-01,  -4.84191179e-01,  -1.02593221e-01,
                         -4.84939247e-01,  -7.97148645e-01,  -7.64492512e-01,
                         -7.19613910e-01,  -3.44071120e-01,   1.17153928e-01,
                         -1.06368378e-01,  -6.65454626e-01,  -8.28116655e-01,
                         -5.21002054e-01,  -6.55838102e-02,   2.09404118e-02,
                         -4.04465050e-01,  -8.10659647e-01,  -7.12002933e-01,
                         -3.05521756e-01,  -4.84705940e-02,   5.33177219e-02,
                         -8.54213759e-02,  -5.15648663e-01,  -4.97985870e-01,
                         -1.45330161e-01,  -5.00858903e-01,  -9.64321315e-01,
                         -5.20431042e-01,  -4.78178076e-02,  -4.81046706e-01,
                         -9.72824872e-01,  -5.60900509e-01,  -1.25797004e-01,
                         -4.90635306e-01,  -5.97163439e-01,  -9.64319855e-02,
                          5.15290648e-02,  -1.00068182e-01,  -1.08364083e-01,
                         -3.44338687e-03,   8.91984999e-03,  -4.01215583e-01,
                         -6.59861386e-01,  -2.24126488e-01,   5.03020510e-02,
                         -9.75809172e-02,  -8.38984102e-02,  -3.68345901e-02,
                         -7.61488304e-02,  -5.60816862e-02,  -4.16962504e-02,
                         -4.27222215e-02,  -8.20745006e-02,  -5.33038341e-02,
                         -1.13680187e-04,  -4.18456495e-01,  -9.25414741e-01,
                         -6.04405701e-01,  -1.15658961e-01,  -4.14592087e-01,
                         -6.26340210e-01,  -7.57890642e-02,   1.10126600e-01,
                         -4.82996434e-01,  -6.31903708e-01,  -9.70313996e-02,
                          8.80118683e-02,  -1.20117143e-01,  -4.38138358e-02,
                          2.87343208e-02,  -4.10853684e-01,  -8.34466219e-01,
                         -6.45202994e-01,  -2.00697720e-01,   5.58053283e-03,
                          4.90855090e-02,  -9.23999995e-02,  -5.17813981e-01,
                         -5.34785092e-01,   6.81227073e-02,   7.79964775e-02,
                         -5.65850735e-01,  -5.35116673e-01,   8.30389187e-03,
                          7.91684091e-02,  -3.45343530e-01,  -7.78318822e-01,
                         -6.84620023e-01,  -1.83669448e-01,   8.90107676e-02,
                         -7.40199760e-02,  -6.15018666e-01,  -8.22983265e-01,
                         -2.75150836e-01,  -1.61364466e-01,  -5.54623246e-01,
                         -3.08739424e-01,  -1.15201615e-01,  -5.49948275e-01,
                         -7.75822520e-01,  -7.14152873e-01,  -4.70991224e-01,
                         -9.73832831e-02,  -3.31795901e-01,  -8.45708191e-01,
                         -5.56434155e-01,  -3.37069854e-02,  -3.03503364e-01,
                         -7.34470010e-01,  -6.30174577e-01,  -6.24760449e-01,
                         -7.81981707e-01,  -4.09520686e-01,  -4.39554192e-02,
                         -3.67293328e-01,  -7.42795169e-01,  -6.78257108e-01,
                         -5.28975725e-01,  -6.31480515e-01,  -7.98632562e-01,
                         -5.41532099e-01,  -8.34060311e-02,  -2.04712898e-01,
                         -6.74565911e-01,  -7.32484281e-01,  -5.97421646e-01,
                         -6.44435942e-01,  -6.46243572e-01,  -6.22043133e-01,
                         -6.67112768e-01,  -6.27474844e-01,  -6.19911849e-01,
                         -6.66738093e-01,  -6.41795933e-01,  -6.36229813e-01,
                         -5.87759316e-01,  -6.13557696e-01,  -7.49886215e-01,
                         -4.33533400e-01,  -2.68218927e-02,  -3.43355626e-01,
                         -7.37895131e-01,  -6.53111994e-01,  -5.84788084e-01,
                         -6.54077053e-01,  -6.60262346e-01,  -6.20857537e-01,
                         -6.12679958e-01,  -6.57085657e-01,  -6.49553418e-01,
                         -6.15751445e-01,  -6.23096585e-01,  -6.14801824e-01,
                         -6.44773602e-01,  -6.62277818e-01,  -6.09136581e-01,
                         -6.21650875e-01,  -6.46989644e-01,  -6.38841450e-01,
                         -6.58589303e-01,  -6.43319249e-01,  -6.39759421e-01,
                         -6.37782335e-01,  -5.81186295e-01,  -6.20153129e-01,
                         -6.84241831e-01,  -6.46661878e-01,  -6.35318995e-01,
                         -6.37314498e-01,  -6.15813136e-01,  -6.23459220e-01,
                         -6.17396235e-01,  -6.21553779e-01,  -6.52518988e-01,
                         -6.51468277e-01,  -6.35766506e-01,  -6.33635700e-01,
                         -6.53969049e-01,  -6.54478073e-01,  -6.09973013e-01,
                         -6.07711494e-01,  -6.25798404e-01,  -6.12447083e-01,
                         -6.37764215e-01,  -6.63585782e-01,  -6.41023457e-01,
                         -6.33213997e-01,  -6.31402791e-01,  -6.22216046e-01,
                         -6.42164350e-01,  -6.57078385e-01,  -6.34097457e-01,
                         -6.28138065e-01,  -6.57400906e-01,  -6.51915610e-01,
                         -6.22418344e-01,  -6.31103396e-01,  -6.44297183e-01,
                         -6.47383213e-01,  -6.49233699e-01,  -6.28525019e-01,
                         -6.28240168e-01,  -6.38734281e-01,  -6.24000251e-01,
                         -6.63155735e-01,  -6.95882976e-01,  -6.22736156e-01,
                         -6.09971225e-01,  -6.56659067e-01,  -5.98019719e-01,
                         -6.51358008e-01,  -7.60087013e-01,  -4.20819998e-01,
                         -5.99780157e-02,  -3.74917150e-01,  -7.45905757e-01,
                         -6.55462205e-01,  -6.05144262e-01,  -6.77907944e-01,
                         -6.48939312e-01,  -6.61244273e-01,  -6.89933658e-01,
                         -6.46253884e-01,  -6.33609354e-01,  -6.70537949e-01,
                         -6.56582594e-01,  -6.06461346e-01,  -7.32248247e-01,
                         -7.29446411e-01,  -1.99515477e-01,  -7.40674064e-02,
                         -7.32981861e-01,  -7.56943166e-01,  -7.78819472e-02,
                          7.36967474e-02,  -5.34832366e-02,   2.32268628e-02,
                          6.92552142e-03,  -8.93540401e-03,   3.86679396e-02,
                         -1.27484873e-02,  -3.13934796e-02,  -4.26977465e-04,
                          1.24270367e-02,   3.13796252e-02,  -3.38717946e-04,
                         -2.01334860e-02,   1.13613717e-02,  -3.30662471e-03,
                         -1.22312801e-02,   9.31961276e-03,   1.01057958e-04,
                         -2.39628600e-03,   6.91355555e-04,  -5.54380333e-03,
                         -8.84293171e-04,  -1.10235820e-02,  -1.68022588e-02,
                         -3.56504391e-03,  -4.33977373e-04,   9.63180512e-03,
                          1.25171542e-02,  -2.06000288e-03,   2.30900361e-04,
                         -4.03424492e-03,  -1.47389723e-02,  -3.78401089e-03,
                          4.67669731e-03,   1.00781322e-02,   4.57464624e-03,
                         -1.53601840e-02,  -4.01990907e-03,   5.04219765e-03,
                         -1.41510926e-02,  -2.40525627e-03,   1.41242789e-02,
                          4.04523360e-03,   1.30673754e-03,  -1.52087817e-02,
                         -3.00751124e-02,   8.01367627e-04,   2.32290737e-02,
                          1.17593883e-02,   5.65480860e-03,   1.27812929e-03,
                         -1.05869463e-02,  -1.62557065e-02,  -7.83651695e-03,
                          6.00872748e-03,   9.65387747e-03,   9.77106579e-03,
                          1.22685544e-03,  -1.73033513e-02,  -2.61715916e-03,
                          2.25319825e-02,   4.69848188e-03,  -1.03516411e-02,
                         -6.15058327e-03,  -1.44544588e-02,  -5.52024087e-03,
                          5.38725872e-03,  -1.46483257e-02,  -1.12894019e-02,
                          1.55167449e-02,   1.19032785e-02,  -6.32963330e-03,
                         -1.22407628e-02,  -7.59124802e-03,  -5.90571528e-03,
                         -9.40324366e-03,   5.25669567e-03,   1.79181565e-02,
                          8.73102900e-03,   8.87812302e-03,  -1.27362821e-03,
                         -2.69325133e-02,  -1.40296277e-02,   1.03694526e-02,
                          9.43359733e-03,   7.00352946e-03,  -4.17328207e-03,
                         -1.00886403e-02,   1.00172153e-02,   5.61873568e-03,
                         -2.06176490e-02,  -8.71855114e-03,   1.69525072e-02,
                          1.14734499e-02,   1.76185870e-03,   7.15443539e-03,
                          3.61971371e-03,  -5.75593067e-03,  -1.05065678e-03,
                          9.13236197e-03,   1.40293557e-02,   3.99072422e-03,
                         -1.42791737e-02,  -8.52625445e-03,   7.66212773e-03,
                          7.05816690e-03,   2.19111075e-03,  -8.39226320e-03,
                         -1.57850478e-02,  -9.73617844e-03,  -1.48544777e-02,
                         -1.16926571e-02,   1.03471233e-02,   9.70491115e-03,
                         -1.37055351e-03,  -1.42982032e-03,   7.21453544e-05,
                          1.25547964e-03,  -1.07066967e-02,  -1.45167531e-02,
                         -1.64479867e-03,  -8.76633264e-03,  -3.00194515e-04,
                          2.57216450e-02,   8.43232404e-03,  -1.03327231e-02,
                         -8.54605250e-03,  -1.78060140e-02,  -9.92447138e-03,
                          6.61497936e-03,   1.25164818e-02,   9.96427611e-03,
                         -1.51407691e-02,  -9.58415121e-03,   2.13119350e-02,
                          4.51853499e-03,  -9.57311504e-03,  -4.10967413e-03,
                         -7.05256080e-03,   1.89680774e-02,   1.84437726e-02,
                         -2.21828222e-02,  -1.86308958e-02,  -8.14031530e-03,
                         -7.56060565e-03,   7.27063045e-03,  -2.59399693e-03,
                         -4.23887605e-03,   9.50561464e-03,   7.26311794e-03,
                          1.93961915e-02,   7.57716829e-03,  -1.36567755e-02,
                          1.37732271e-02,   9.88617167e-03,  -8.38644896e-03,
                          1.17207048e-02,   9.76284849e-04,  -1.54478199e-04,
                          2.27336660e-02,   3.37771280e-03,  -4.93593374e-03,
                         -1.93600706e-03,  -9.93667636e-03,   5.04866894e-03,
                         -1.11040415e-03,  -6.13054493e-03,   1.15115726e-02,
                         -4.10936959e-03,   5.88958524e-03,   2.31243465e-02,
                         -9.27045383e-03,   3.51099909e-04,   8.03573336e-03,
                         -2.31258366e-02,   4.77748318e-03,   1.76927820e-02,
                         -5.60132414e-03,   2.00851765e-02,   1.42163504e-02,
                         -2.24060658e-02,  -3.61183286e-03,   2.01174524e-02,
                          1.53274434e-02,   1.32328412e-03,  -4.45194822e-03,
                          8.30251444e-03,   9.36398283e-03,   1.72397599e-03,
                         -3.75879859e-03,  -1.47531638e-02,  -4.78731841e-03,
                          1.03628691e-02,  -2.83856090e-04,  -5.71373897e-03,
                          1.20534953e-02,   6.04090793e-03,  -1.51976487e-02,
                          1.68762617e-02,  -1.40341312e-01,  -6.30581617e-01,
                         -7.80091882e-01,  -3.02481115e-01,   5.27408943e-02,
                          4.63035740e-02,  -3.17550078e-03,  -1.45135494e-02,
                          9.49229747e-02,   1.62759684e-02,  -4.31941271e-01,
                         -4.93208706e-01,  -5.15391715e-02,   1.15220979e-01,
                         -1.04068546e-02,  -1.62649639e-02,   5.12003601e-02,
                         -8.15237686e-03,  -4.82173003e-02,   1.06381655e-01,
                         -3.32371108e-02,  -4.69504118e-01,  -3.68442923e-01,
                         -1.44362926e-01,  -4.35585707e-01,  -4.14342284e-01,
                          7.12818187e-03,   8.22302252e-02,  -1.43795107e-02,
                         -2.34807953e-01,  -6.91480398e-01,  -7.41642356e-01,
                         -2.13045925e-01,   1.59525260e-01,  -7.41260350e-02,
                         -5.47622442e-01,  -7.28264630e-01,  -6.61357522e-01,
                         -6.04111671e-01,  -6.62765741e-01,  -7.48971283e-01,
                         -4.63042140e-01,  -8.34233686e-02,  -3.44567120e-01,
                         -7.47120857e-01,  -6.83062434e-01,  -6.24754190e-01,
                         -6.90350354e-01,  -6.46136701e-01,  -6.40178621e-01,
                         -6.58234179e-01,  -6.42031193e-01,  -6.59497499e-01,
                         -6.52255595e-01,  -6.47560000e-01,  -6.68035150e-01,
                         -6.57546580e-01,  -6.53464913e-01,  -6.45920157e-01,
                         -6.41350627e-01,  -6.66164935e-01,  -6.50159419e-01,
                         -6.38442457e-01,  -6.73022270e-01,  -6.63403153e-01,
                         -6.38977826e-01,  -6.58139527e-01,  -6.79127693e-01,
                         -6.70261562e-01,  -6.35566711e-01,  -6.30352139e-01,
                         -6.64779246e-01,  -6.68343544e-01,  -6.47373557e-01,
                         -6.53346181e-01,  -6.83886170e-01,  -6.87170029e-01,
                         -6.43458486e-01,  -6.35454595e-01,  -6.67506754e-01,
                         -6.55937314e-01,  -6.47528172e-01,  -6.83597326e-01,
                         -6.97353244e-01,  -6.68212771e-01,  -6.36325061e-01,
                         -6.49863839e-01,  -6.78963125e-01,  -6.59127474e-01,
                         -6.50710583e-01,  -6.81628585e-01,  -6.83576643e-01,
                         -6.78206980e-01,  -6.87565804e-01,  -6.77348733e-01,
                         -6.66806698e-01,  -6.76956177e-01,  -6.86288536e-01,
                         -6.71333909e-01,  -6.57111347e-01,  -6.80370867e-01,
                         -6.96557581e-01,  -6.75956666e-01,  -6.58529401e-01,
                         -6.74126089e-01,  -7.10337996e-01,  -6.96232915e-01,
                         -6.61781192e-01,  -6.82713568e-01,  -6.73521399e-01,
                         -6.79466784e-01,  -7.30602801e-01,  -6.53258204e-01,
                         -6.67091310e-01,  -7.98169017e-01,  -4.94521916e-01,
                         -1.20952658e-01,  -3.99688989e-01,  -7.83421636e-01,
                         -7.40830481e-01,  -6.45028055e-01,  -6.77830696e-01,
                         -6.98863983e-01,  -6.93684459e-01,  -7.04841673e-01,
                         -7.12123394e-01,  -6.89243495e-01,  -7.02023983e-01,
                         -7.18227506e-01,  -6.85305238e-01,  -7.08230138e-01,
                         -7.32574105e-01,  -6.96567714e-01,  -6.99710011e-01,
                         -7.05335736e-01,  -7.16099083e-01,  -7.34360993e-01,
                         -6.84641957e-01,  -6.83597207e-01,  -7.15572834e-01,
                         -7.15721071e-01,  -7.57656634e-01,  -6.92592740e-01,
                         -6.68448985e-01,  -8.23281765e-01,  -5.75697660e-01,
                         -1.29811034e-01,  -3.42518508e-01,  -7.72424161e-01,
                         -7.66415596e-01,  -6.91700697e-01,  -7.23936975e-01,
                         -6.78983212e-01,  -7.27312028e-01,  -7.90148795e-01,
                         -4.15615290e-01,  -7.90092498e-02,  -5.50705791e-01,
                         -9.44260001e-01,  -4.15441036e-01,  -1.05771415e-01,
                         -5.46947360e-01,  -5.55591881e-01,   1.50331920e-02,
                          4.93605062e-02,  -5.33822834e-01,  -8.27248216e-01,
                         -6.95773304e-01,  -7.37312496e-01,  -8.29130232e-01,
                         -4.36120033e-01,  -8.39582384e-02,  -5.14523745e-01,
                         -9.37454343e-01,  -4.94930953e-01,  -1.19855724e-01,
                         -4.96424943e-01,  -7.97575593e-01,  -7.57720709e-01,
                         -6.97352231e-01,  -3.55544269e-01,   7.61622638e-02,
                         -6.10013790e-02,  -6.21082783e-01,  -9.00249660e-01,
                         -5.83932936e-01,  -6.10185489e-02,   8.17987174e-02,
                         -3.31064075e-01,  -8.49680185e-01,  -7.55759001e-01,
                         -2.59019643e-01,  -6.88840747e-02,   4.87206969e-03,
                         -5.87508082e-02,  -5.19830883e-01,  -5.43259799e-01,
                         -1.25268117e-01,  -4.28811193e-01,  -9.67377484e-01,
                         -5.95284641e-01,  -4.61027846e-02,  -4.26398098e-01,
                         -9.54207540e-01,  -5.45517266e-01,  -1.22872822e-01,
                         -5.02520800e-01,  -6.05144143e-01,  -9.96991619e-02,
                          8.87859911e-02,  -9.84704122e-02,  -1.69699281e-01,
                         -1.89849280e-03,   2.78622825e-02,  -4.11448658e-01,
                         -6.26000226e-01,  -1.99571937e-01,   5.60735799e-02,
                         -6.91347271e-02,  -7.66858980e-02,  -2.84940191e-02,
                         -6.93055391e-02,  -7.63531551e-02,  -3.26919369e-02,
                         -2.67789643e-02,  -7.22854435e-02,  -2.93317307e-02,
                         -3.49019654e-02,  -4.68687743e-01,  -9.04670179e-01,
                         -5.77010453e-01,  -1.03104964e-01,  -4.11309958e-01,
                         -6.38680637e-01,  -5.03630638e-02,   1.26154914e-01,
                         -5.13204396e-01,  -6.33532822e-01,  -9.94769558e-02,
                          8.42956156e-02,  -7.33128637e-02,  -2.92128455e-02,
                          8.76780692e-03,  -4.10922885e-01,  -8.35038602e-01,
                         -5.99688292e-01,  -1.50848106e-01,  -6.51517045e-03,
                          6.13034144e-02,  -8.27528685e-02,  -5.33678055e-01,
                         -5.09855092e-01,   7.26208985e-02,   8.14547762e-02,
                         -5.51415145e-01,  -5.78783691e-01,   2.75581945e-02,
                          1.28877819e-01,  -3.93457443e-01,  -7.87044048e-01,
                         -6.59425378e-01,  -1.83646470e-01,   1.33178815e-01,
                         -8.19818825e-02,  -6.54573143e-01,  -8.03257644e-01,
                         -2.88134187e-01,  -1.56162754e-01,  -5.05581021e-01,
                         -3.16480398e-01,  -1.25337720e-01,  -5.48545718e-01,
                         -7.95852780e-01,  -7.15978920e-01,  -4.44905370e-01,
                         -4.31192294e-02,  -3.21771443e-01,  -8.87112677e-01,
                         -5.32705426e-01,   3.01613705e-03,  -3.14198703e-01,
                         -7.52016246e-01,  -6.57827079e-01,  -6.08898878e-01,
                         -7.41497874e-01,  -4.20672387e-01,  -5.39429560e-02,
                         -3.67257595e-01,  -7.42888808e-01,  -6.78134263e-01,
                         -5.69737315e-01,  -6.45367801e-01,  -7.59242058e-01,
                         -5.09235263e-01,  -7.23767951e-02,  -2.51909196e-01,
                         -7.04624057e-01,  -6.73603415e-01,  -5.66137314e-01,
                         -6.57984138e-01,  -6.58111453e-01,  -6.24505937e-01,
                         -6.29764259e-01,  -6.20205283e-01,  -6.42169356e-01,
                         -6.48936629e-01,  -6.45720720e-01,  -6.54832721e-01,
                         -5.94658494e-01,  -6.37589753e-01,  -7.51286328e-01,
                         -4.36564833e-01,  -4.06049080e-02,  -3.22640091e-01,
                         -7.21878946e-01,  -6.44949317e-01,  -5.91057241e-01,
                         -6.72262013e-01,  -6.30767345e-01,  -6.09889328e-01,
                         -6.27218544e-01,  -6.25703454e-01,  -6.37044668e-01,
                         -6.17756486e-01,  -6.23869181e-01,  -6.46753788e-01,
                         -6.28844798e-01,  -6.30108595e-01,  -6.20411098e-01,
                         -6.06264293e-01,  -6.34044409e-01,  -6.40865445e-01,
                         -6.32632494e-01,  -6.23569906e-01,  -6.17298841e-01,
                         -6.37422264e-01,  -6.33636534e-01,  -6.26856506e-01,
                         -6.32157922e-01,  -6.20962918e-01,  -6.43487513e-01,
                         -6.45922899e-01,  -6.18818641e-01,  -6.40226305e-01,
                         -6.25862002e-01,  -5.93763947e-01,  -6.20225251e-01,
                         -6.39208198e-01,  -6.53369963e-01,  -6.42927468e-01,
                         -6.05421126e-01,  -6.15835786e-01,  -6.22585058e-01,
                         -6.33084893e-01,  -6.61397278e-01,  -6.29927397e-01,
                         -6.19036555e-01,  -6.38377368e-01,  -6.19283974e-01,
                         -6.30888164e-01,  -6.42493904e-01,  -6.31879747e-01,
                         -6.39820635e-01,  -6.10657990e-01,  -6.02983594e-01,
                         -6.48784697e-01,  -6.46297276e-01,  -6.29719675e-01,
                         -6.33523345e-01,  -6.34745359e-01,  -6.58234179e-01,
                         -6.63471341e-01,  -6.31553411e-01,  -6.21681333e-01,
                         -6.46222115e-01,  -6.66268945e-01,  -6.49042726e-01,
                         -6.36071801e-01,  -6.55738890e-01,  -6.54263854e-01,
                         -6.50367737e-01,  -6.51637852e-01,  -6.09536350e-01,
                         -6.55653834e-01,  -7.32522428e-01,  -4.43945467e-01,
                         -9.26316530e-02,  -3.49242002e-01,  -7.37102509e-01,
                         -6.71814740e-01,  -6.09509110e-01,  -6.82945669e-01,
                         -6.37115836e-01,  -6.41902804e-01,  -6.79838955e-01,
                         -6.56889915e-01,  -6.76365197e-01,  -6.68005884e-01,
                         -6.22231662e-01,  -6.26936853e-01,  -7.40610123e-01,
                         -7.05282032e-01,  -1.97227955e-01,  -8.03744420e-02,
                         -7.51753569e-01,  -7.58950830e-01,  -5.87729774e-02,
                          6.68406487e-02,  -4.92459163e-02,   2.51984149e-02,
                         -5.74234733e-03,   4.91794571e-03,   1.07298596e-02,
                         -4.42656279e-02,   1.79327484e-02,   2.29741950e-02,
                         -1.41739184e-02,   6.37425995e-03,  -1.93259194e-02,
                          1.21990358e-03,   2.00895499e-02,  -2.31624059e-02,
                          1.34148065e-03,   7.55139510e-04,  -2.85203997e-02,
                          3.52796214e-03,   8.65206029e-03,   5.42188995e-03,
                          1.17000728e-03,  -2.15542242e-02,   1.20169099e-03,
                          6.97373552e-03,  -5.36827743e-03,   1.20559949e-02,
                         -3.24010151e-03,  -1.52610168e-02,  -3.48008424e-03,
                         -8.30092840e-03,   3.50443157e-03,   9.51958261e-03,
                         -3.62341385e-03,  -2.37248326e-03,  -6.71409909e-03,
                         -9.38147493e-03,  -2.81744893e-03,  -1.02692116e-02,
                         -1.43245049e-02,   2.80780601e-03,   1.40254796e-02,
                         -1.31700502e-03,  -8.47160071e-03,  -6.63290359e-03,
                         -1.76965948e-02,   8.68018760e-05,   1.72839370e-02,
                         -2.43066088e-03,  -2.14409782e-03,   1.84681849e-03,
                         -2.33913376e-03,   4.76614246e-03,  -4.83793527e-04,
                          1.40249832e-02,   1.54630365e-02,  -2.38590166e-02,
                         -1.14050200e-02,   8.92800372e-03,  -4.24326491e-03,
                          2.68624513e-03,  -8.70017800e-03,  -1.99572230e-03,
                          3.25662419e-02,   1.70923932e-03,  -2.64817644e-02,
                         -6.65302202e-03,   4.70223045e-03,   1.12877684e-02,
                          6.18941151e-03,   4.75121336e-03,   7.28298025e-03,
                         -5.32160094e-03,   6.35872222e-03,   5.67241246e-03,
                         -1.14602344e-02,   1.12202521e-02,   2.05824580e-02,
                          1.41186407e-02,   8.12436081e-03,  -9.57923383e-03,
                          1.10708680e-02,   1.31707871e-02,  -1.43026719e-02,
                          6.20780000e-03,   3.98428459e-03,   1.41439494e-04,
                          3.29796188e-02,   1.01004774e-02,   6.70484034e-04,
                          1.99836697e-02,  -1.86230950e-02,  -2.78894808e-02,
                         -1.19408243e-03,  -6.94400631e-03,  -9.52787977e-03,
                          3.61449178e-03,   2.58425325e-02,   9.71533917e-03,
                         -3.62244323e-02,  -1.38893416e-02,   1.24955624e-02,
                          6.49532449e-05,   1.47074964e-02,   6.32277783e-03,
                         -6.62231538e-03,   1.68408789e-02,  -1.30214030e-03,
                         -2.19883472e-02,  -3.46925599e-03,  -5.18682459e-03,
                         -9.38450173e-03,  -3.94662609e-03,  -7.61953602e-03,
                         -8.30602180e-03,  -1.32613536e-02,  -7.32667791e-03,
                          1.78417675e-02,   1.75348930e-02,  -1.40967602e-02,
                         -2.86331344e-02,   4.10606997e-04,   2.71812584e-02,
                          3.39922495e-03,  -2.24353150e-02,  -2.37116986e-03,
                          1.31864855e-02,  -8.81100725e-03,  -1.66649520e-02,
                          4.57198732e-03,   1.33728236e-02,   6.43773936e-03,
                         -1.61315668e-02,  -3.73308957e-02,  -5.15078427e-03,
                          3.22624929e-02,   1.47188688e-02,  -5.89887565e-03,
                         -4.60676244e-03,   2.58499495e-04,  -4.70380019e-03,
                         -1.93066336e-02,  -1.06081215e-03,   2.67391913e-02,
                          1.20625775e-02,  -1.38114300e-02,  -2.47270670e-02,
                          3.46438639e-04,   3.49455029e-02,   3.67899658e-03,
                         -2.74170432e-02,  -4.64269100e-03,   4.60935757e-04,
                          1.34652632e-03,   1.36346547e-02,  -4.28026635e-03,
                         -2.26076841e-02,  -8.65372643e-03,   2.21190210e-02,
                          2.45934278e-02,  -1.27497530e-02,  -2.45147143e-02,
                         -3.25088180e-03,   1.29007874e-02,   1.68244597e-02,
                         -3.92682804e-03,  -1.74865182e-02,  -9.68106091e-03,
                         -1.07426420e-02,   9.63342260e-04,   1.04252119e-02,
                          2.75542698e-04,   2.85510742e-03,  -3.34615726e-03,
                         -6.05308171e-03,   5.79786580e-03,  -1.30373575e-02,
                         -1.51425954e-02,   1.25900852e-02,   1.35654248e-02,
                          6.96905842e-03,  -6.37725508e-03,  -1.86983962e-02,
                         -9.27865505e-03,  -9.38427821e-03,   3.78678204e-03,
                          1.84033923e-02,  -1.56273821e-03,  -3.17346654e-03,
                         -4.78555623e-04,  -5.08703245e-03,   1.72679510e-03,
                         -2.54237875e-02,  -2.69742087e-02,   2.02484168e-02,
                          2.96612866e-02,   1.23882890e-02,  -6.62769750e-03,
                          2.93442886e-03,  -1.44173846e-01,  -6.21788263e-01,
                         -7.84004688e-01,  -2.92872906e-01,   6.49238154e-02,
                          4.41225059e-02,  -8.14680289e-03,  -2.88996119e-02,
                          1.00089692e-01,   3.53958011e-02,  -4.52476442e-01,
                         -5.11609495e-01,  -4.10121344e-02,   1.07278764e-01,
                         -2.45693680e-02,  -2.26772670e-02,   4.87803482e-02,
                          8.63162149e-03,  -4.23851386e-02,   1.03310995e-01,
                         -1.55932792e-02,  -4.73785013e-01,  -3.89231801e-01,
                         -1.41471758e-01,  -4.44642186e-01,  -4.35204893e-01,
                          1.13220466e-02,   1.03732765e-01,   5.94952470e-03,
                         -2.43470654e-01,  -7.18847871e-01,  -7.48714745e-01,
                         -2.27997124e-01,   1.33985624e-01,  -6.78496584e-02,
                         -5.36627233e-01,  -7.30840087e-01,  -6.55757785e-01,
                         -6.07421219e-01,  -6.90864563e-01,  -7.89991260e-01,
                         -4.88097847e-01,  -7.73474872e-02,  -3.45053941e-01,
                         -7.59700835e-01,  -6.78421438e-01,  -6.25532150e-01,
                         -6.99856281e-01,  -6.45127416e-01,  -6.53675616e-01,
                         -6.82790518e-01,  -6.58626735e-01,  -6.80094004e-01,
                         -6.54707491e-01,  -6.28200173e-01,  -6.77152455e-01,
                         -6.85474515e-01,  -6.66671932e-01,  -6.63144588e-01,
                         -6.55694902e-01,  -6.69783533e-01,  -6.78040564e-01,
                         -6.61294162e-01,  -6.51404083e-01,  -6.58959985e-01,
                         -6.75634563e-01,  -6.72331095e-01,  -6.63611174e-01,
                         -6.77478313e-01,  -6.78922534e-01,  -6.64521992e-01,
                         -6.64108753e-01,  -6.66043520e-01,  -6.54076695e-01,
                         -6.51532948e-01,  -6.73894346e-01,  -6.78576827e-01,
                         -6.64003909e-01,  -6.64659619e-01,  -6.60333991e-01,
                         -6.66889071e-01,  -6.84943259e-01,  -6.68967187e-01,
                         -6.60361350e-01,  -6.69501424e-01,  -6.66207314e-01,
                         -6.68109894e-01,  -6.54523134e-01,  -6.53519869e-01,
                         -6.77951455e-01,  -6.64994836e-01,  -6.76856220e-01,
                         -7.08023965e-01,  -6.78331077e-01,  -6.71592832e-01,
                         -6.76277578e-01,  -6.56509578e-01,  -6.88562870e-01,
                         -6.93848014e-01,  -6.64211094e-01,  -6.87698603e-01,
                         -6.85029447e-01,  -6.70650780e-01,  -6.89881265e-01,
                         -6.80631816e-01,  -6.80538893e-01,  -6.83054924e-01,
                         -6.75263643e-01,  -7.03248382e-01,  -6.85677648e-01,
                         -6.71029031e-01,  -7.07221806e-01,  -6.51724517e-01,
                         -6.87399209e-01,  -8.11037600e-01,  -5.06841779e-01,
                         -1.07716389e-01,  -3.64303559e-01,  -7.85658598e-01,
                         -7.44330764e-01,  -6.34766996e-01,  -6.94207668e-01,
                         -7.03573525e-01,  -6.92618668e-01,  -7.07614064e-01,
                         -6.92576528e-01,  -6.94459260e-01,  -7.03659952e-01,
                         -6.91927850e-01,  -6.95629060e-01,  -7.03333914e-01,
                         -7.02895224e-01,  -6.98521197e-01,  -6.86318457e-01,
                         -6.94551408e-01,  -7.19715655e-01,  -7.17822134e-01,
                         -7.05422223e-01,  -7.09234834e-01,  -6.88790143e-01,
                         -6.81495965e-01,  -7.25219429e-01,  -6.95745349e-01,
                         -6.99705005e-01,  -8.17450702e-01,  -5.82902908e-01,
                         -1.48042634e-01,  -3.22285712e-01,  -7.59463608e-01,
                         -7.60498166e-01,  -6.79627120e-01,  -7.14322627e-01,
                         -6.72534287e-01,  -7.53656983e-01,  -7.95826852e-01,
                         -3.77520829e-01,  -8.24779943e-02,  -5.65498710e-01,
                         -9.24538851e-01,  -4.03584689e-01,  -1.14091069e-01,
                         -5.66462517e-01,  -5.49011886e-01,   3.49796824e-02,
                          2.11627595e-02,  -5.60341537e-01,  -8.11824858e-01,
                         -6.65231526e-01,  -6.95589781e-01,  -8.08869004e-01,
                         -4.42038536e-01,  -9.05524418e-02,  -5.33147454e-01,
                         -9.56150174e-01,  -4.97475892e-01,  -9.30150151e-02,
                         -4.51926947e-01,  -7.98721850e-01,  -7.92823315e-01,
                         -7.11866498e-01,  -3.41358691e-01,   9.60105360e-02,
                         -8.61620829e-02,  -6.52442813e-01,  -8.75909686e-01,
                         -5.51439047e-01,  -4.15764675e-02,   7.20075145e-02,
                         -3.64351749e-01,  -8.22946012e-01,  -7.26328194e-01,
                         -2.87916690e-01,  -6.51857629e-02,   2.72416938e-02,
                         -6.48714378e-02,  -5.11378586e-01,  -5.26738882e-01,
                         -1.28527716e-01,  -4.42184508e-01,  -9.59416389e-01,
                         -5.76387823e-01,  -6.42801151e-02,  -4.39794213e-01,
                         -9.35385287e-01,  -5.38735151e-01,  -1.04934312e-01,
                         -4.64613020e-01,  -5.90265572e-01,  -1.19714193e-01,
                          5.97691238e-02,  -7.66819417e-02,  -1.24569088e-01,
                         -1.12801278e-02,   4.02199104e-03,  -4.13084626e-01,
                         -6.31140351e-01,  -2.08351642e-01,   5.51394075e-02,
                         -5.53523377e-02,  -7.21301064e-02,  -3.06533501e-02,
                         -4.71054837e-02,  -7.57205710e-02,  -5.34450673e-02,
                         -1.66171212e-02,  -6.51695505e-02,  -3.32736634e-02,
                         -3.29120234e-02,  -4.74335402e-01,  -8.89666855e-01,
                         -5.42830586e-01,  -8.59519616e-02,  -4.20820177e-01,
                         -6.71743453e-01,  -6.20118119e-02,   1.56288639e-01,
                         -4.74535018e-01,  -6.12653077e-01,  -1.26293421e-01,
                          4.63957228e-02,  -6.95104003e-02,  -2.91865598e-02,
                          4.19107778e-03,  -3.95692736e-01,  -8.59889030e-01,
                         -6.50065720e-01,  -1.58053011e-01,   1.43127795e-03,
                          6.23606406e-02,  -6.90206587e-02,  -5.38216233e-01,
                         -5.33371985e-01,   7.67739490e-02,   9.23023671e-02,
                         -5.38317919e-01,  -5.45327008e-01,   1.08086523e-02,
                          8.25098082e-02,  -3.70190859e-01,  -7.55084157e-01,
                         -6.83004558e-01,  -2.15212360e-01,   1.26187041e-01,
                         -6.74086064e-02,  -6.61349773e-01,  -8.25368047e-01,
                         -2.75669694e-01,  -1.59181759e-01,  -5.33322513e-01,
                         -3.09263289e-01,  -1.14279293e-01,  -5.56360841e-01,
                         -8.03774953e-01,  -7.22992539e-01,  -4.45283920e-01,
                         -4.76820879e-02,  -3.14992338e-01,  -8.59818876e-01,
                         -5.38356841e-01,  -3.12973708e-02,  -3.25827926e-01,
                         -7.26059496e-01,  -6.13205850e-01,  -5.97365081e-01,
                         -7.66546786e-01,  -4.40908462e-01,  -6.01522774e-02,
                         -3.59314352e-01,  -7.38116682e-01,  -6.85055494e-01,
                         -5.66887438e-01,  -6.33371532e-01,  -7.40208268e-01,
                         -5.01654029e-01,  -8.57088715e-02,  -2.41434693e-01,
                         -6.94538176e-01,  -7.04777837e-01,  -5.74981451e-01,
                         -6.25529289e-01,  -6.46004200e-01,  -6.42471790e-01,
                         -6.49607956e-01,  -6.42441154e-01,  -6.47245586e-01,
                         -5.98261893e-01,  -6.02240503e-01,  -6.73654974e-01,
                         -5.99631965e-01,  -6.08903825e-01,  -7.29200363e-01,
                         -4.25174743e-01,  -5.60334399e-02,  -3.17496389e-01,
                         -6.75623834e-01,  -6.45465016e-01,  -6.19867086e-01,
                         -6.65599704e-01,  -6.12182915e-01,  -5.90843856e-01,
                         -6.14741683e-01,  -6.24955416e-01,  -6.33892238e-01,
                         -6.05094373e-01,  -6.03188753e-01,  -6.48707807e-01,
                         -6.37308180e-01,  -6.19995356e-01,  -6.39130592e-01,
                         -6.23223484e-01,  -6.13140523e-01,  -6.29133523e-01,
                         -6.19718432e-01,  -6.29842281e-01,  -6.63250506e-01,
                         -6.43926978e-01,  -6.02029383e-01,  -6.12286031e-01,
                         -6.45951211e-01,  -6.43832982e-01,  -6.30891502e-01,
                         -6.36516154e-01,  -6.28302574e-01,  -6.12471879e-01,
                         -6.18104339e-01,  -6.30333185e-01,  -6.38612151e-01,
                         -6.30016744e-01,  -6.09783471e-01,  -6.10488713e-01,
                         -6.18031859e-01,  -6.27262771e-01,  -6.36326790e-01,
                         -6.14773154e-01,  -6.14373684e-01,  -6.50754154e-01,
                         -6.49230003e-01,  -6.40564501e-01,  -6.48895919e-01,
                         -6.33122981e-01,  -6.34068251e-01,  -6.50157571e-01,
                         -6.37906790e-01,  -6.32678449e-01,  -6.38184309e-01,
                         -6.43342495e-01,  -6.64225161e-01,  -6.66188776e-01,
                         -6.36983633e-01,  -6.17462456e-01,  -6.22063756e-01,
                         -6.40614271e-01,  -6.60362422e-01,  -6.61225498e-01,
                         -6.34130716e-01,  -6.19796455e-01,  -6.43726707e-01,
                         -6.54736936e-01,  -6.28321290e-01,  -6.14271104e-01,
                         -6.66242957e-01,  -6.90057337e-01,  -5.82311153e-01,
                         -6.17027819e-01,  -7.85125971e-01,  -4.88415569e-01,
                         -6.52560815e-02,  -3.46671820e-01,  -7.53315926e-01,
                         -6.62067890e-01,  -5.94922125e-01,  -6.89398289e-01,
                         -6.76390409e-01,  -6.53357387e-01,  -6.48140192e-01,
                         -6.47508442e-01,  -6.93515122e-01,  -7.16581583e-01,
                         -6.69441998e-01,  -6.10004485e-01,  -7.09207654e-01,
                         -6.92025006e-01,  -2.04526320e-01,  -1.01867862e-01,
                         -7.21697390e-01,  -7.29662657e-01,  -7.81160519e-02,
                          5.77859282e-02,  -7.42363334e-02,   1.45057971e-02,
                          1.92123521e-02,  -2.78139077e-02,  -8.41294229e-03,
                         -1.05424803e-02,   5.85596310e-03,   8.94070603e-03,
                         -7.99901970e-03,   5.66259306e-03,   8.90194159e-03,
                          1.48036527e-02,   1.09029347e-02,  -6.24350412e-03,
                          1.61543600e-02,   1.44263953e-02,   4.64490149e-03,
                          3.61483134e-02,   1.18993856e-02,  -2.81332918e-02,
                         -1.91340242e-02,  -2.73231138e-02,  -1.98684204e-02,
                          1.15509769e-02,   1.23409554e-02,   8.05101451e-03,
                         -1.63297739e-03,  -4.97317594e-03,   1.40994666e-02,
                          4.71696677e-03,  -1.70594119e-02,  -1.89398844e-02,
                         -5.84401377e-03,   2.37032566e-02,   2.03773770e-02,
                         -3.73480353e-03,   5.32574952e-03,   3.85761401e-03,
                         -4.90594795e-03,   7.05587631e-03,   4.71334672e-03,
                         -2.68521998e-03,  -6.46062894e-03,  -3.08208331e-03,
                          9.57508478e-03,  -1.02914767e-02,  -1.27584348e-02,
                          2.01566014e-02,  -5.70236612e-03,  -2.55412161e-02,
                          1.87272765e-02,   2.18745060e-02,  -4.72193258e-03,
                          3.78428330e-03,   1.85908508e-02,   1.40579157e-02,
                          1.51210508e-04,   1.51601667e-02,   1.76603459e-02,
                         -3.30832265e-02,  -2.15545781e-02,   3.80444825e-02,
                          3.78550552e-02,   4.47106101e-02,   3.95238325e-02,
                         -1.94444060e-02,  -1.19664371e-02,   2.53744535e-02,
                          1.27703846e-02,   1.67232417e-02,   1.87951457e-02,
                          8.23651999e-03,   2.37635169e-02,   2.54425928e-02,
                          1.93762165e-02,   9.20192804e-03,  -1.15174195e-02,
                          1.78263243e-02,   4.02242206e-02,   6.54254528e-03,
                         -1.00816076e-03,   5.71764715e-04,   2.02401029e-03,
                          2.55834237e-02,  -6.05080696e-03,  -3.11531760e-02,
                          1.76752117e-02,   1.62682962e-02,  -1.37652019e-02,
                          9.68512893e-03,   2.10486632e-02,   2.78134588e-02,
                          3.46494727e-02,  -6.27212878e-03,  -2.79399063e-02,
                         -7.68285524e-03,   7.13950675e-03,   2.80417651e-02,
                          3.38927768e-02,   1.86372083e-02,   2.39356458e-02,
                          2.70136297e-02,   6.48134062e-03,  -1.66839175e-02,
                         -1.53517593e-02,   2.28430070e-02,   3.73109058e-02,
                          1.03449607e-02,   1.52348271e-02,   2.89484188e-02,
                         -6.17361767e-03,  -3.98404114e-02,  -2.62202378e-02,
                          1.22262184e-02,   3.52964103e-02,   2.68058423e-02,
                          6.56591589e-03,  -1.21583343e-02,  -2.52950676e-02,
                         -2.18733680e-02,  -6.40642422e-04,   2.26952881e-02,
                          1.69884041e-02,  -7.93712586e-03,  -8.63174908e-03,
                          3.84209241e-04,  -4.54366766e-03,  -1.02307042e-02,
                         -1.11194663e-02,  -3.47241154e-03,  -7.12419336e-04,
                         -7.11176312e-03,  -4.58111754e-03,  -1.26361046e-02,
                         -1.39071057e-02,   1.14108026e-02,   5.45104267e-03,
                         -3.63153499e-03,   2.05854196e-02,   8.66441056e-03,
                         -1.76312570e-02,  -1.45606268e-02,  -3.85599607e-03,
                          2.02133209e-02,   1.20485462e-02,  -2.18888428e-02,
                         -6.77202037e-03,   1.39148906e-03,  -8.01478140e-03,
                          1.68365848e-04,  -2.78266575e-02,  -3.37587856e-02,
                          9.01333150e-03,   1.54129155e-02,   1.95290297e-02,
                          9.77289211e-03,  -3.24273817e-02,  -1.48890447e-02,
                          7.42204906e-03,  -7.86171295e-03,   5.53230243e-03,
                          1.06930817e-02,   1.07909199e-02,   6.38103532e-03,
                         -3.73884626e-02,  -2.99136359e-02,   5.98929776e-03,
                          3.59943486e-03,   2.42597070e-02,   9.09496006e-03,
                         -3.82778496e-02,  -1.61192324e-02,  -3.13643273e-03,
                         -8.20079912e-03,   6.34408183e-03,  -2.42163464e-02,
                         -2.92537399e-02,   1.27939470e-02,   2.21927045e-03,
                         -1.88288484e-02,  -1.39770412e-03,   2.40307301e-02,
                          1.70231629e-02,  -1.76232476e-02,  -1.93635945e-03,
                          2.29500234e-02,   8.93194415e-03,   2.03192476e-02,
                          1.49673894e-02,   5.74167469e-04,   1.59228984e-02,
                         -1.58580579e-02,  -2.39171609e-02,  -2.78035109e-03,
                         -4.89537455e-02,  -3.54810506e-02,   4.17807922e-02,
                          5.07573932e-02,  -1.37578383e-01,  -5.96015811e-01,
                         -7.67931998e-01,  -3.29680860e-01,   2.45446041e-02,
                          3.72650437e-02,  -1.16845360e-03,  -3.28292251e-02,
                          8.94054398e-02,   4.59872149e-02,  -4.19136703e-01,
                         -4.83038634e-01,  -3.40081900e-02,   9.16307345e-02,
                         -3.16832960e-02,   7.82491919e-03,   6.71401098e-02,
                         -2.70779580e-02,  -6.74091652e-02,   1.27119258e-01,
                         -7.84095377e-03,  -4.98191476e-01,  -3.85503322e-01,
                         -1.13624811e-01,  -4.41849351e-01,  -4.44289774e-01,
                          2.01159474e-02,   1.19448498e-01,   2.69142538e-02,
                         -2.15936929e-01,  -7.13581622e-01,  -7.60423481e-01,
                         -2.23955646e-01,   1.36085615e-01,  -7.73262680e-02,
                         -5.30251205e-01,  -7.25372016e-01,  -6.79980397e-01,
                         -6.38208032e-01,  -6.82382047e-01,  -7.40016937e-01,
                         -4.60629225e-01,  -8.31884146e-02,  -3.34153771e-01,
                         -7.62247443e-01,  -6.95866883e-01,  -5.97783387e-01,
                         -6.80785537e-01,  -6.61968470e-01,  -6.41989112e-01,
                         -6.71639860e-01,  -6.64663434e-01,  -6.66893303e-01,
                         -6.65451407e-01,  -6.64390802e-01,  -6.70930743e-01,
                         -6.40055120e-01,  -6.34088397e-01,  -6.71547592e-01,
                         -6.72479928e-01,  -6.52630806e-01,  -6.54075801e-01,
                         -6.66561365e-01,  -6.77668691e-01,  -6.65649772e-01,
                         -6.34835124e-01,  -6.33477092e-01,  -6.67543828e-01,
                         -6.89076126e-01,  -6.81218207e-01,  -6.69584095e-01,
                         -6.71617627e-01,  -6.80628657e-01,  -6.80194318e-01,
                         -6.80905581e-01,  -6.96415782e-01,  -6.87013328e-01,
                         -6.47267163e-01,  -6.44143343e-01,  -6.78717792e-01,
                         -7.03528821e-01,  -7.12011695e-01,  -6.87608957e-01,
                         -6.50257468e-01,  -6.63164258e-01,  -6.86427176e-01,
                         -6.76933229e-01,  -6.74895942e-01,  -6.75364077e-01,
                         -6.84133887e-01,  -7.09406614e-01,  -6.88127220e-01,
                         -6.53261364e-01,  -6.60682321e-01,  -6.61771834e-01,
                         -6.82460904e-01,  -7.20509350e-01,  -7.04090655e-01,
                         -6.72799051e-01,  -6.61319256e-01,  -6.80452526e-01,
                         -7.20516503e-01,  -6.84814155e-01,  -6.42005742e-01,
                         -7.04790115e-01,  -7.32609808e-01,  -6.80269122e-01,
                         -6.81937456e-01,  -7.17223942e-01,  -6.96132064e-01,
                         -6.79657459e-01,  -7.10025847e-01,  -6.88862145e-01,
                         -7.13176966e-01,  -7.91365564e-01,  -4.84488904e-01,
                         -8.16677064e-02,  -3.70516539e-01,  -8.13303947e-01,
                         -7.26916969e-01,  -6.38238251e-01,  -7.30716169e-01,
                         -7.05671430e-01,  -6.95593059e-01,  -7.19189107e-01,
                         -6.89588666e-01,  -7.05105722e-01,  -7.23356485e-01,
                         -7.04835951e-01,  -6.92002058e-01,  -6.90032899e-01,
                         -7.15074718e-01,  -7.25914955e-01,  -7.09314585e-01,
                         -7.12257862e-01,  -7.12051630e-01,  -7.12376416e-01,
                         -7.35695481e-01,  -7.31583476e-01,  -6.89818144e-01,
                         -7.09214032e-01,  -7.54657567e-01,  -6.78954840e-01,
                         -6.81278944e-01,  -8.28668714e-01,  -5.95066667e-01,
                         -1.73111096e-01,  -3.64679068e-01,  -7.89606214e-01,
                         -7.68210351e-01,  -6.86970353e-01,  -7.40816474e-01,
                         -6.74137175e-01,  -7.17968225e-01,  -8.14327717e-01,
                         -4.38233495e-01,  -8.60987529e-02,  -5.71004987e-01,
                         -9.77756143e-01,  -4.34440643e-01,  -1.02210566e-01,
                         -5.65086842e-01,  -5.54169953e-01,   8.48493576e-02,
                          6.88932016e-02,  -6.07409537e-01,  -8.73774767e-01,
                         -6.75625324e-01,  -7.10070848e-01,  -8.12828958e-01,
                         -4.51580733e-01,  -1.47644937e-01,  -5.35453379e-01,
                         -8.87617707e-01,  -5.06912827e-01,  -1.71465501e-01,
                         -4.82452184e-01,  -7.64554799e-01,  -7.42376328e-01,
                         -7.08311796e-01,  -3.94120157e-01,   7.22077936e-02,
                         -6.24694340e-02,  -6.40311778e-01,  -8.77123773e-01,
                         -5.53599119e-01,  -5.18973358e-02,   6.12716526e-02,
                         -3.92529905e-01,  -8.39713871e-01,  -7.19399691e-01,
                         -2.92983949e-01,  -6.10797703e-02,   4.33682129e-02,
                         -7.86197260e-02,  -5.41435897e-01,  -5.47611713e-01,
                         -1.06433474e-01,  -4.08344924e-01,  -9.77320433e-01,
                         -5.73750436e-01,  -3.33116762e-02,  -4.63701487e-01,
                         -9.62399483e-01,  -5.64010978e-01,  -1.43258199e-01,
                         -4.87053007e-01,  -6.18526936e-01,  -1.23114087e-01,
                          6.63950741e-02,  -1.24920815e-01,  -1.08327113e-01,
                          4.13672552e-02,   1.19267288e-03,  -4.37969118e-01,
                         -6.78959310e-01,  -2.30454415e-01,   7.75081664e-02,
                         -5.84732331e-02,  -9.33322683e-02,  -5.08140363e-02,
                         -1.16140142e-01,  -8.66749361e-02,  -4.53208648e-02,
                         -1.64859015e-02,  -6.43512681e-02,  -6.81154951e-02,
                         -8.01635161e-03,  -4.38518167e-01,  -9.41340685e-01,
                         -6.05921984e-01,  -1.09711230e-01,  -4.22111303e-01,
                         -6.54994905e-01,  -9.60343555e-02,   1.37783781e-01,
                         -4.78405595e-01,  -6.60341144e-01,  -1.11013822e-01,
                          1.18317738e-01,  -8.46011117e-02,  -4.79484983e-02,
                          4.29807836e-03,  -4.04122889e-01,  -8.52722168e-01,
                         -6.52090967e-01,  -1.48400143e-01,   4.41020494e-03,
                          9.87697765e-03,  -7.60318488e-02,  -5.14112473e-01,
                         -5.44991374e-01,   2.32769996e-02,   6.07492700e-02,
                         -5.39787531e-01,  -5.42904437e-01,  -1.46401087e-02,
                          9.32826251e-02,  -3.78192276e-01,  -8.00207913e-01,
                         -6.81615710e-01,  -1.82416484e-01,   1.13834761e-01,
                         -1.20772518e-01,  -6.69339001e-01,  -7.74323881e-01,
                         -3.01456630e-01,  -1.68868095e-01,  -5.06169081e-01,
                         -3.17951411e-01,  -1.43972799e-01,  -5.66534519e-01,
                         -8.03168595e-01,  -6.87586367e-01,  -4.14597481e-01,
                         -6.62031770e-02,  -3.51438910e-01,  -8.94626796e-01,
                         -5.66095829e-01,   2.92776548e-03,  -2.85687834e-01,
                         -7.70346165e-01,  -6.45769835e-01,  -5.81323624e-01,
                         -7.65853167e-01,  -4.44976360e-01,  -3.79570425e-02,
                         -3.78896177e-01,  -7.91494608e-01,  -7.08649993e-01,
                         -5.69047809e-01,  -6.36341512e-01,  -7.70086765e-01,
                         -5.34339666e-01,  -1.00434467e-01,  -2.50181288e-01,
                         -7.20061243e-01,  -7.09119856e-01,  -6.11289680e-01,
                         -6.52517080e-01,  -6.45033240e-01,  -6.31572068e-01,
                         -6.50009632e-01,  -6.27762198e-01,  -6.11957371e-01,
                         -5.99015832e-01,  -6.35552704e-01,  -6.92030013e-01,
                         -5.83664119e-01,  -6.10757053e-01,  -7.46683538e-01,
                         -4.22356635e-01,  -4.78899218e-02,  -3.42539787e-01,
                         -7.52930045e-01,  -6.93628013e-01,  -5.93760610e-01,
                         -6.31437957e-01,  -6.24753416e-01,  -6.44602537e-01,
                         -6.76426709e-01,  -6.35649741e-01,  -6.40368819e-01,
                         -6.44856453e-01,  -5.98673403e-01,  -6.03097022e-01,
                         -6.31617188e-01,  -6.14337265e-01,  -6.12819552e-01,
                         -6.08265638e-01,  -6.35321200e-01,  -5.93119085e-01,
                         -6.13959193e-01,  -6.25199914e-01,  -6.13987207e-01,
                         -5.98993897e-01,  -6.29495084e-01,  -6.21653795e-01,
                         -6.06665432e-01,  -6.22626960e-01,  -6.59324050e-01,
                         -6.60781205e-01,  -6.21866524e-01,  -6.27507687e-01,
                         -6.39134705e-01,  -6.50316715e-01,  -6.74963593e-01,
                         -6.52815759e-01,  -6.16191983e-01,  -6.30042553e-01,
                         -6.12353683e-01,  -6.35102093e-01,  -6.74361169e-01,
                         -6.53086483e-01,  -6.04711235e-01,  -6.18179739e-01,
                         -6.37109160e-01,  -6.42674088e-01,  -6.36552691e-01,
                         -6.21977568e-01,  -6.33130670e-01,  -5.84968150e-01,
                         -6.60388947e-01,  -6.31053805e-01,  -6.18157327e-01,
                         -6.28675938e-01,  -6.46142960e-01,  -6.70040548e-01,
                         -6.55249953e-01,  -6.35325313e-01,  -6.49070263e-01,
                         -6.38315558e-01,  -6.06915176e-01,  -6.08742416e-01,
                         -6.52798533e-01,  -6.18030667e-01,  -6.47429168e-01,
                         -6.55369580e-01,  -6.47132397e-01,  -6.40931427e-01,
                         -6.42719746e-01,  -6.96203470e-01,  -6.12897038e-01,
                         -6.37289047e-01,  -7.67674327e-01,  -4.67804104e-01,
                         -5.42121716e-02,  -3.31829578e-01,  -7.53170431e-01,
                         -6.75481498e-01,  -6.07738197e-01,  -6.69012547e-01,
                         -6.54183328e-01,  -6.67538822e-01,  -6.75829530e-01,
                         -6.57520592e-01,  -6.36445642e-01,  -6.81846023e-01,
                         -6.83577299e-01,  -6.34503722e-01,  -7.43648291e-01,
                         -6.52930319e-01,  -1.75649852e-01,  -1.06990114e-01,
                         -6.91578627e-01,  -8.23099077e-01,   2.51916063e-04,
                         -4.91781719e-03,   2.54140981e-03,   1.99357606e-03,
                         -3.43156559e-03,  -2.20952034e-02,  -2.52450425e-02,
                          4.39708633e-03,   1.16979424e-02,  -1.69027399e-03,
                          5.32442005e-03,   2.43946761e-02,   2.62412224e-02,
                          9.84327588e-03,  -1.31403375e-02,  -9.09922086e-03,
                         -8.28676857e-03,   9.34533775e-03,   2.25726366e-02,
                         -3.56622925e-03,   3.18074822e-02,  -4.70770865e-05,
                          2.68479548e-02,   4.38648229e-03,  -2.45071552e-03,
                         -6.49301754e-03,   1.03270849e-02,   9.28528607e-03,
                          2.54491773e-02,   1.97727922e-02,  -3.59859206e-02,
                         -1.68348232e-03,   1.66995507e-02,   4.17180825e-03,
                         -7.82169960e-03,   2.09763404e-02,   1.71198323e-02,
                          2.28670659e-03,   6.84083381e-04,   2.90359091e-02,
                         -1.08324550e-02,   8.80443957e-03,   2.86009386e-02,
                         -7.02251075e-03,   4.75754077e-03,   1.08984811e-02,
                         -3.66952992e-03,  -1.91363469e-02,   3.53838986e-04,
                          4.04574582e-03,   1.16274469e-02,   2.44510435e-02,
                          2.74767280e-02,   1.48450595e-03,   1.78857204e-02,
                         -1.97190680e-02,   3.27121355e-02,   4.29679230e-02,
                          5.26238186e-03,  -1.23275965e-02,   8.91522132e-03,
                          1.85588785e-02,   1.84937976e-02,  -2.38585826e-02,
                         -7.16066640e-03,   4.91090864e-02,  -4.56626905e-04,
                         -1.35078877e-02,  -4.73103067e-03,   2.12014746e-02,
                          4.53962125e-02,  -1.75386574e-03,  -1.81484967e-02,
                          9.59805492e-03,   3.13524739e-03,  -2.17579748e-03,
                         -1.97768607e-03,   1.53373424e-02,   1.60735492e-02,
                          5.55809140e-02,   2.98947338e-02,   1.91284176e-02,
                         -6.15353091e-03,   3.51273231e-02,   4.82398365e-03,
                          1.17329424e-02,  -2.31360085e-02,  -1.34828035e-02,
                          1.07641062e-02,   1.29773216e-02,   2.74689421e-02,
                         -8.34685226e-04,  -1.08618960e-02,   3.47109474e-02,
                         -3.10332328e-03,  -1.22799268e-02,   1.10776918e-02,
                         -2.19829641e-02,  -3.90795544e-02,  -1.34124036e-03,
                          2.30153613e-02,   5.11946902e-03,   1.83059052e-02,
                          2.93659139e-02,   1.78369619e-02,  -2.10617166e-02,
                         -8.81411508e-03,  -2.50218622e-02,  -2.71349009e-02,
                         -2.68406346e-02,  -1.04958192e-02,   1.78149529e-02,
                          3.95495556e-02,   9.16438177e-03,  -1.30831525e-02,
                          9.89648700e-03,   4.12661657e-02,  -2.08298885e-03,
                         -5.07461838e-03,   1.11347642e-02,   2.73442250e-02,
                         -6.81168074e-03,   1.43669208e-03,   1.61838643e-02,
                         -3.24143283e-02,  -1.68882590e-02,  -1.16998488e-02,
                         -1.83982830e-02,  -2.61712391e-02,   1.40005397e-02,
                          2.89910436e-02,   7.20524462e-04,  -2.69510616e-02,
                         -9.42089502e-03,  -7.73207890e-03,  -5.96482214e-03,
                          1.55075826e-02,  -1.15290005e-02,  -3.06009054e-02,
                         -4.81278682e-03,  -9.92389396e-03,   5.43859648e-03,
                         -1.55101297e-03,  -4.88453172e-03,  -3.12666176e-03,
                         -2.94751413e-02,  -5.43202125e-02,  -2.45489143e-02,
                         -3.58426906e-02,  -2.46891994e-02,  -3.92138172e-04,
                          1.44910440e-02,   1.24369357e-02,  -1.22006061e-02,
                          4.11923695e-03,   1.74235515e-02,   8.18734430e-03,
                          4.44534887e-03,   1.15788169e-03,  -4.84991679e-03,
                          9.99094639e-03,   1.84776206e-02,   9.78887826e-03,
                         -1.53960325e-02,  -8.26568808e-03,  -2.40399080e-04,
                         -3.17054316e-02,  -1.92648266e-02,   3.31005245e-03,
                         -7.37394718e-03,  -8.21729749e-03,   7.10277725e-03,
                         -5.35022514e-03,  -1.13198040e-02,  -1.95891764e-02,
                          5.48796449e-03,   2.04866044e-02,   1.38210729e-02,
                          4.53461753e-03,   1.64914597e-02,   2.72928551e-03,
                          1.29850740e-02,   1.67432316e-02,   3.09776515e-03,
                         -4.94006649e-03,  -2.30754609e-03,   2.94252764e-02,
                          2.59049069e-02,  -1.11857010e-02,   1.62357476e-03,
                          8.53328593e-03,   8.33475869e-03,   8.54103919e-03,
                          6.08720025e-03,  -1.04892682e-02,  -1.43125234e-02,
                          3.26103717e-02,   2.43374277e-02,  -1.25249391e-02,
                          1.60501469e-02,  -1.61161646e-01,  -6.23384655e-01,
                         -7.52755105e-01,  -3.10146391e-01,   6.40054345e-02,
                          7.38317370e-02,   6.44366583e-03,  -3.84547212e-03,
                          1.25642017e-01,   3.25064622e-02,  -4.33699489e-01,
                         -5.04730880e-01,  -4.41477485e-02,   1.32225320e-01,
                         -2.48463526e-02,  -2.03070268e-02,   7.63808936e-02,
                         -1.43881440e-02,  -6.67575672e-02,   1.20377615e-01,
                          4.91099386e-03,  -4.50944781e-01,  -3.67461324e-01,
                         -1.31743357e-01,  -4.25570577e-01,  -4.03077185e-01,
                          6.34027869e-02,   1.43131137e-01,   7.00473087e-03,
                         -2.17130542e-01,  -6.72823191e-01,  -7.54586101e-01,
                         -2.36331612e-01,   1.67274788e-01,  -4.09151912e-02,
                         -5.19073784e-01,  -7.28512108e-01,  -6.74202561e-01,
                         -5.96508086e-01,  -6.68332398e-01,  -7.91899145e-01,
                         -4.85452622e-01,  -8.19049478e-02,  -3.35350305e-01,
                         -7.29516387e-01,  -6.86156034e-01,  -6.25150740e-01,
                         -7.00799167e-01,  -7.12595642e-01,  -6.73118711e-01,
                         -6.46357954e-01,  -6.61015570e-01,  -6.71554208e-01,
                         -6.62644029e-01,  -6.63195372e-01,  -6.51474416e-01,
                         -6.60193205e-01,  -6.54660761e-01,  -6.24088287e-01,
                         -6.42275453e-01,  -6.58240855e-01,  -6.55177116e-01,
                         -6.59322798e-01,  -6.50118291e-01,  -6.53065622e-01,
                         -6.52379036e-01,  -6.50018930e-01,  -6.57430410e-01,
                         -6.47524893e-01,  -6.60551667e-01,  -6.50586545e-01,
                         -6.09415174e-01,  -6.35724962e-01,  -6.58660352e-01,
                         -6.45200491e-01,  -6.62957311e-01,  -6.76583588e-01,
                         -6.84397697e-01,  -6.64213240e-01,  -6.42534435e-01,
                         -6.71419501e-01,  -6.40972912e-01,  -6.24974072e-01,
                         -6.84863269e-01,  -6.42093062e-01,  -6.12323165e-01,
                         -6.57230616e-01,  -6.20530844e-01,  -6.31741703e-01,
                         -6.93734825e-01,  -6.61187351e-01,  -6.57007992e-01,
                         -6.83651686e-01,  -6.57092512e-01,  -6.61612153e-01,
                         -6.85992122e-01,  -6.70006394e-01,  -6.59204423e-01,
                         -6.78407907e-01,  -6.92946732e-01,  -6.80434883e-01,
                         -6.63129628e-01,  -6.62290037e-01,  -6.61207557e-01,
                         -6.52077675e-01,  -6.48055017e-01,  -6.57733977e-01,
                         -6.89451396e-01,  -7.11875260e-01,  -6.83894873e-01,
                         -6.93611443e-01,  -7.22547889e-01,  -6.37990534e-01,
                         -6.66060328e-01,  -7.93437779e-01,  -4.90056992e-01,
                         -1.04129069e-01,  -3.76292974e-01,  -7.81200945e-01,
                         -7.22953200e-01,  -6.32574439e-01,  -7.08544314e-01,
                         -7.07278252e-01,  -7.00097501e-01,  -7.50310183e-01,
                         -7.26703644e-01,  -6.69185877e-01,  -6.61223054e-01,
                         -6.83455348e-01,  -7.37612784e-01,  -7.50352502e-01,
                         -6.75409257e-01,  -6.60996437e-01,  -7.27442861e-01,
                         -7.28129745e-01,  -6.77757621e-01,  -6.72914028e-01,
                         -7.15153515e-01,  -7.36257315e-01,  -7.05165267e-01,
                         -7.18773365e-01,  -7.77296424e-01,  -7.25602686e-01,
                         -6.99581385e-01,  -8.10483038e-01,  -6.11062765e-01,
                         -1.77464589e-01,  -3.16076636e-01,  -7.74451673e-01,
                         -7.78439999e-01,  -6.70113564e-01,  -7.38683045e-01,
                         -6.95669949e-01,  -7.25410104e-01,  -7.80117810e-01,
                         -3.96195948e-01,  -1.05347097e-01,  -5.83242297e-01,
                         -9.19544399e-01,  -3.71435791e-01,  -8.73589590e-02,
                         -5.50121427e-01,  -5.16778708e-01,   5.03866561e-02,
                          1.83361967e-03,  -5.59626400e-01,  -8.02988768e-01,
                         -6.74812794e-01,  -7.08436191e-01,  -8.56403708e-01,
                         -4.85075176e-01,  -6.00132383e-02,  -4.94178355e-01,
                         -9.41312313e-01,  -4.77295458e-01,  -9.06224102e-02,
                         -4.54277903e-01,  -7.93686926e-01,  -8.11555505e-01,
                         -7.32009709e-01,  -3.56455326e-01,   7.01432675e-02,
                         -7.31555670e-02,  -6.04049861e-01,  -8.63477707e-01,
                         -5.83779812e-01,  -8.97304788e-02,   4.55927886e-02,
                         -3.65125000e-01,  -8.44290853e-01,  -7.44859517e-01,
                         -2.88231254e-01,  -8.83839652e-02,   2.65322383e-02,
                         -4.07937579e-02,  -5.34284890e-01,  -5.69287479e-01,
                         -1.68994516e-01,  -4.79615808e-01,  -9.58341956e-01,
                         -5.69807947e-01,  -7.23704696e-02,  -4.47553605e-01,
                         -9.78823662e-01,  -6.02686465e-01,  -1.30580828e-01,
                         -4.63105559e-01,  -5.94071269e-01,  -1.17267847e-01,
                          5.66468053e-02,  -1.15134247e-01,  -1.38755530e-01,
                          1.34778703e-02,  -3.17857624e-03,  -4.17581260e-01,
                         -6.32440865e-01,  -2.56693989e-01,   3.43625061e-02,
                         -4.88635972e-02,  -1.07072964e-01,  -7.96983838e-02,
                         -8.21533427e-02,  -7.56764039e-02,  -4.96688709e-02,
                         -5.14834933e-02,  -8.20386335e-02,  -4.32440899e-02,
                         -7.23088011e-02,  -5.05076528e-01,  -9.14625406e-01,
                         -5.68349540e-01,  -1.23517759e-01,  -4.56767678e-01,
                         -6.61263227e-01,  -6.93011060e-02,   1.25543654e-01,
                         -4.66586858e-01,  -6.10506475e-01,  -1.30672634e-01,
                          4.03215624e-02,  -9.43585262e-02,  -3.00219655e-02,
                         -9.84438043e-03,  -4.17650282e-01,  -8.28564167e-01,
                         -6.27804518e-01,  -1.54773280e-01,   1.24488696e-02,
                          5.77366874e-02,  -6.65008947e-02,  -5.33937335e-01,
                         -5.30839205e-01,   6.98460564e-02,   4.50796150e-02,
                         -5.55140018e-01,  -5.27702749e-01,   8.57869722e-03,
                          9.38217938e-02,  -3.96177858e-01,  -8.20524096e-01,
                         -6.87476635e-01,  -2.06696287e-01,   1.01106204e-01,
                         -9.55414325e-02,  -6.83643997e-01,  -8.06064308e-01,
                         -2.40459278e-01,  -1.48040563e-01,  -5.20676255e-01,
                         -3.24950784e-01,  -1.46608770e-01,  -5.40957868e-01,
                         -7.84839034e-01,  -7.32592344e-01,  -4.54575747e-01,
                         -7.62331635e-02,  -3.63791794e-01,  -8.93820345e-01,
                         -5.45489967e-01,  -1.20374616e-02,  -3.26620728e-01,
                         -7.73223281e-01,  -6.44065142e-01,  -6.13540232e-01,
                         -8.01881254e-01,  -4.47263002e-01,  -4.95634899e-02,
                         -3.61689836e-01,  -7.34912336e-01,  -7.11641252e-01,
                         -5.92822433e-01,  -6.22821331e-01,  -7.75460184e-01,
                         -5.47752261e-01,  -7.92447850e-02,  -2.49118090e-01,
                         -7.02471018e-01,  -6.89562082e-01,  -5.99426329e-01,
                         -6.74184799e-01,  -6.60557747e-01,  -6.20968819e-01,
                         -6.28542721e-01,  -6.37217581e-01,  -6.56119227e-01,
                         -6.61021709e-01,  -6.80046380e-01,  -6.77371740e-01,
                         -5.90264261e-01,  -6.41449630e-01,  -7.57013619e-01,
                         -4.42568541e-01,  -5.88571690e-02,  -3.26424509e-01,
                         -7.33359694e-01,  -6.70989811e-01,  -5.73618412e-01,
                         -6.49997950e-01,  -6.46517336e-01,  -6.31325662e-01,
                         -6.56718016e-01,  -6.45582020e-01,  -6.49266779e-01,
                         -6.47259414e-01,  -6.28121376e-01,  -6.41209245e-01,
                         -6.37654722e-01,  -6.39603257e-01,  -6.63489640e-01,
                         -6.42322063e-01,  -6.44741356e-01,  -6.52702153e-01,
                         -5.93783259e-01,  -6.15654111e-01,  -6.82776690e-01,
                         -6.48950219e-01,  -6.36689782e-01,  -6.54689848e-01,
                         -6.25795484e-01,  -6.31812751e-01,  -6.46359324e-01,
                         -6.34983778e-01,  -6.38954222e-01,  -6.25225842e-01,
                         -6.24242365e-01,  -6.44645929e-01,  -6.28682077e-01,
                         -6.26476645e-01,  -6.41441762e-01,  -6.37370110e-01,
                         -6.50917232e-01,  -6.42537057e-01,  -6.06351674e-01,
                         -6.24724388e-01,  -6.51884258e-01,  -6.29484773e-01,
                         -6.16173685e-01,  -6.33288980e-01,  -6.49228632e-01,
                         -6.45336211e-01,  -6.24172032e-01,  -6.22539937e-01,
                         -6.36183381e-01,  -6.28175616e-01,  -6.25155687e-01,
                         -6.40869200e-01,  -6.52928710e-01,  -6.61488891e-01,
                         -6.49077296e-01,  -6.25088930e-01,  -6.20782435e-01,
                         -6.26172185e-01,  -6.44621372e-01,  -6.46817982e-01,
                         -6.23817921e-01,  -6.43654406e-01,  -6.61399841e-01,
                         -6.43307090e-01,  -6.38293922e-01,  -6.13331199e-01,
                         -6.41550124e-01,  -6.96039081e-01,  -6.09143376e-01,
                         -6.51131809e-01,  -7.86966860e-01,  -4.30978268e-01,
                         -4.07517292e-02,  -3.67510736e-01,  -7.62770236e-01,
                         -6.82738125e-01,  -6.08139694e-01,  -6.72899663e-01,
                         -6.55619264e-01,  -6.42749727e-01,  -6.76642179e-01,
                         -6.62232161e-01,  -6.40612900e-01,  -6.82565153e-01,
                         -6.70373857e-01,  -6.05671406e-01,  -7.27411807e-01,
                         -7.00885415e-01,  -1.83324099e-01,  -9.44176167e-02,
                         -7.35112965e-01,  -7.60803342e-01,  -8.92952532e-02,
                          9.39998850e-02,  -4.88378555e-02,   8.03775154e-03,
                          6.14971854e-03,  -2.73370985e-02,   1.58166196e-02,
                         -5.78578794e-03,  -7.84422085e-03,   1.44005427e-02,
                         -1.24764210e-02,  -3.03366082e-03,   5.14722802e-03,
                         -1.06338309e-02,   8.87608854e-04,  -1.04711838e-02,
                         -1.68729629e-02,   3.72165255e-03,   1.67159690e-03,
                          1.25010563e-02,   1.40789794e-02,  -2.14770660e-02,
                         -2.48436145e-02,  -6.61952840e-03,   3.77886905e-03,
                          8.08240939e-03,  -6.47551008e-03,   4.40491922e-03,
                          2.76890472e-02,   3.91289213e-04,  -2.55517252e-02,
                         -6.84182718e-03,   1.41511895e-02,   9.17613879e-03,
                         -4.96636797e-03,   1.48463412e-03,   9.86594055e-03,
                          3.66001506e-03,   2.77444045e-03,  -5.72753046e-03,
                         -1.46922795e-02,  -2.51166429e-03,   1.10937255e-02,
                          1.85195543e-02,   2.67056329e-03,  -1.97482202e-02,
                          2.16296711e-03,   1.13549000e-02,  -1.07112946e-02,
                          6.67242007e-03,   1.55832842e-02,  -1.03038587e-02,
                         -3.10625462e-03,   1.16765425e-02,   2.97101424e-03,
                          4.35683271e-03,   1.07113104e-02,   6.40450162e-04,
                         -1.06045175e-02,   3.14594735e-03,   1.47374021e-02,
                         -2.48247921e-03,  -4.56992118e-03,   2.30472675e-03,
                         -1.05764065e-02,  -5.57105010e-03,   4.04057233e-03,
                         -3.71976243e-03,  -6.01217151e-03,  -7.14314263e-03,
                          4.99970187e-03,   7.51681207e-03,  -2.01689508e-02,
                         -5.12223970e-03,   2.32762955e-02,   1.00481147e-02,
                          9.64450743e-03,   5.67023410e-04,  -8.49368982e-03,
                          1.42493155e-02,  -1.00668557e-02,  -1.98903326e-02,
                          2.58077569e-02,   6.09195745e-03,  -1.43325934e-02,
                          1.36205750e-02,   4.28688200e-03,  -7.70837185e-04,
                         -6.65717060e-03,  -2.04636827e-02,   1.17395418e-02,
                          2.58818245e-03,  -1.91575214e-02,   1.77449696e-02,
                          1.43496203e-03,  -2.23816708e-02,   1.83180952e-03,
                         -5.69510972e-03,   4.52191476e-03,   9.17450525e-03,
                         -1.95607450e-02,   8.12716410e-03,   1.16966292e-02,
                         -1.10898335e-02,   1.78645290e-02,   4.27842431e-04,
                         -1.09126577e-02,   2.01079696e-02,  -1.04248915e-02,
                         -4.23791492e-03,   2.01354735e-02,  -2.22354885e-02,
                          9.56502568e-04,   2.38107536e-02,  -2.04264577e-02,
                         -7.82578439e-03,  -2.45417538e-03,  -1.54220946e-02,
                          1.31194172e-02,   9.29206144e-03,   1.07162120e-02,
                          9.96121671e-03,  -2.20576078e-02,   1.12737203e-02,
                          1.04754446e-02,  -3.77599224e-02,   1.11720217e-02,
                          2.75249742e-02,  -1.07749179e-02,   7.54830381e-03,
                         -1.95782376e-03,  -7.19792442e-03,   1.19617125e-02,
                         -1.64050274e-02,  -5.88378683e-03,   8.88059009e-03,
                         -1.39890546e-02,   1.60216186e-02,   1.80584919e-02,
                         -6.52697589e-03,   9.03534051e-03,  -1.53039768e-02,
                         -1.18054077e-02,   2.18263082e-02,  -9.93456226e-03,
                          2.33269436e-03,   1.99932009e-02,  -2.04785485e-02,
                          8.55708867e-03,   2.91597601e-02,  -1.62266172e-03,
                          1.03592332e-02,  -2.12945719e-03,  -1.22068366e-02,
                          9.29244608e-03,  -1.02813374e-02,   8.75089131e-03,
                          3.01780775e-02,  -1.55600738e-02,  -3.37178609e-03,
                          2.25916021e-02,   1.07606139e-03,   6.49614120e-03,
                         -3.80960782e-03,  -1.20949829e-02,   1.40220840e-02,
                          7.01949932e-03,   9.24008340e-03,   1.70613509e-02,
                         -2.16972665e-03,   1.70130394e-02,   2.51248758e-02,
                          3.08842654e-03,   3.69671243e-03,  -1.55045073e-02,
                         -7.94031378e-03,   3.22398916e-02,   9.18333139e-03,
                         -8.17017280e-04,   2.22203359e-02,  -1.56493264e-03,
                         -6.77602459e-03,   1.14921751e-02,  -6.50525559e-04,
                          6.37615006e-03,   3.06409672e-02,   2.16200743e-02,
                         -2.45515257e-03,   7.46489735e-04,   1.43887373e-02,
                          3.70246288e-03,  -2.76130578e-03,  -2.28630612e-03,
                          1.36196776e-03,   2.44098604e-02,   9.65812244e-03,
                         -1.11517273e-02,   7.14085181e-05,  -9.62386001e-03,
                          2.36116331e-02,  -1.23904593e-01,  -6.26366973e-01,
                         -7.74563134e-01,  -2.96996146e-01,   5.44874258e-02,
                          6.24201149e-02,  -2.24403124e-02,  -4.99032959e-02,
                          1.19108260e-01,   4.04568985e-02,  -4.45453614e-01,
                         -5.04496694e-01,  -5.76656312e-02,   1.25788629e-01,
                         -2.14296044e-03,  -2.05936860e-02,   6.82897866e-02,
                         -1.43327219e-02,  -6.41616806e-02,   1.45097211e-01,
                         -2.64736917e-02,  -5.16676426e-01,  -3.76792371e-01,
                         -1.31677523e-01,  -4.41687942e-01,  -4.32168871e-01,
                          5.76057564e-03,   1.24210209e-01,   1.65336835e-03,
                         -2.69259065e-01,  -7.02708185e-01,  -7.44072556e-01,
                         -2.27126241e-01,   1.57048851e-01,  -8.50416347e-02,
                         -5.56874514e-01,  -7.32211828e-01,  -6.81139350e-01,
                         -6.08179688e-01,  -6.56174421e-01,  -7.55863369e-01,
                         -4.65087563e-01,  -9.20364410e-02,  -3.60400826e-01,
                         -7.56695032e-01,  -6.86801672e-01,  -5.96057892e-01,
                         -6.66686475e-01,  -6.73691034e-01,  -6.53470159e-01,
                         -6.55929446e-01,  -6.79695487e-01,  -6.86655819e-01,
                         -6.40609443e-01,  -6.40432119e-01,  -6.74542308e-01,
                         -6.68605089e-01,  -6.57634854e-01,  -6.43037796e-01,
                         -6.46905720e-01,  -6.67971194e-01,  -6.51410460e-01,
                         -6.54127955e-01,  -6.74357235e-01,  -6.59140110e-01,
                         -6.60931587e-01,  -6.65976584e-01,  -6.64765716e-01,
                         -6.80328131e-01,  -6.54844701e-01,  -6.46235228e-01,
                         -6.92869604e-01,  -6.78255260e-01,  -6.39622867e-01,
                         -6.52293026e-01,  -6.68218315e-01,  -6.79957449e-01,
                         -6.69327438e-01,  -6.54697418e-01,  -6.95064962e-01,
                         -7.01284409e-01,  -6.47931755e-01,  -6.50294185e-01,
                         -6.84892476e-01,  -6.81020856e-01,  -6.63551450e-01,
                         -6.53056979e-01,  -6.53879404e-01,  -6.63445711e-01,
                         -6.76667392e-01,  -6.98038936e-01,  -7.00695217e-01,
                         -6.72588408e-01,  -6.56851053e-01,  -6.67536378e-01,
                         -6.75343394e-01,  -6.71463668e-01,  -6.61918461e-01,
                         -6.61434591e-01,  -6.85316622e-01,  -6.88367665e-01,
                         -6.59335852e-01,  -6.77098513e-01,  -7.00643897e-01,
                         -6.68374956e-01,  -6.82812691e-01,  -7.26542950e-01,
                         -7.02317119e-01,  -6.70649767e-01,  -6.62087679e-01,
                         -6.98405147e-01,  -7.43119061e-01,  -6.58478320e-01,
                         -6.60448015e-01,  -7.91755378e-01,  -5.28259873e-01,
                         -1.39895916e-01,  -3.68017852e-01,  -7.62529850e-01,
                         -7.44748771e-01,  -6.75762713e-01,  -7.13440061e-01,
                         -6.81594074e-01,  -6.77791655e-01,  -7.16007650e-01,
                         -6.96762621e-01,  -6.85511827e-01,  -7.08547831e-01,
                         -6.98425829e-01,  -6.81586802e-01,  -7.13493407e-01,
                         -7.33811677e-01,  -7.02313364e-01,  -6.90344930e-01,
                         -7.09231377e-01,  -7.18501806e-01,  -7.19776392e-01,
                         -7.17764139e-01,  -7.25808501e-01,  -7.24973977e-01,
                         -7.18744636e-01,  -7.30652273e-01,  -6.78394258e-01,
                         -6.86054051e-01,  -8.30497742e-01,  -6.18158281e-01,
                         -1.59402892e-01,  -3.09793323e-01,  -7.59642363e-01,
                         -7.54981816e-01,  -6.84150279e-01,  -7.43660986e-01,
                         -6.52915180e-01,  -7.30306745e-01,  -8.51305783e-01,
                         -4.12198663e-01,  -6.50781021e-02,  -5.74618757e-01,
                         -9.38184738e-01,  -3.92371237e-01,  -1.03671491e-01,
                         -5.75934112e-01,  -5.43619514e-01,   8.39415789e-02,
                          1.94757693e-02,  -6.16502345e-01,  -8.01141262e-01,
                         -6.42791629e-01,  -7.48585045e-01,  -8.77143621e-01,
                         -4.50474560e-01,  -3.47680859e-02,  -5.20286798e-01,
                         -1.00000000e+00,  -4.80689764e-01,  -6.56232014e-02,
                         -4.77180243e-01,  -8.04448485e-01,  -7.51735330e-01,
                         -6.54775202e-01,  -3.59507799e-01,   1.79516189e-02,
                         -7.19996840e-02,  -5.98107815e-01,  -8.69963944e-01,
                         -5.49030304e-01,  -6.82755485e-02,   4.37316149e-02,
                         -3.57999504e-01,  -8.38233411e-01,  -7.31864810e-01,
                         -2.82501101e-01,  -7.49787539e-02,   5.34277670e-02,
                         -4.26753536e-02,  -5.27758956e-01,  -5.39457560e-01,
                         -1.41262367e-01,  -4.55300868e-01,  -9.62055445e-01,
                         -5.48705757e-01,  -2.95001920e-02,  -4.73703980e-01,
                         -9.85253632e-01,  -5.43188095e-01,  -1.07811183e-01,
                         -4.77996796e-01,  -6.16015971e-01,  -1.17995359e-01,
                          9.74216163e-02,  -8.65679979e-02,  -1.37885869e-01,
                          3.46629275e-03,  -9.95504949e-03,  -4.12301064e-01,
                         -6.29116833e-01,  -2.26571575e-01,   6.07966371e-02,
                         -6.73867837e-02,  -8.93357247e-02,  -4.66672145e-02,
                         -8.68003741e-02,  -5.77046536e-02,  -3.78975645e-02,
                         -6.12912737e-02,  -6.74081519e-02,  -2.61778869e-02,
                         -1.62242465e-02,  -4.24171925e-01,  -9.21548188e-01,
                         -6.10252857e-01,  -1.07563451e-01,  -4.19825792e-01,
                         -6.40685022e-01,  -6.16692342e-02,   1.38006225e-01,
                         -4.67498571e-01,  -6.37347519e-01,  -1.18008383e-01,
                          6.28262013e-02,  -1.36385858e-01,  -4.09909897e-02,
                          4.96327020e-02,  -3.93765628e-01,  -8.48701239e-01,
                         -6.43920183e-01,  -1.59999356e-01,   3.30007332e-03,
                          2.58132350e-02,  -6.83007166e-02,  -4.91847157e-01,
                         -5.28365612e-01,   5.24904206e-02,   6.72923774e-02,
                         -5.30256152e-01,  -5.31010151e-01,  -1.00075891e-02,
                          9.80085656e-02,  -3.59962583e-01,  -7.99468637e-01,
                         -6.85791016e-01,  -1.95586801e-01,   1.23290285e-01,
                         -7.81838894e-02,  -6.86117947e-01,  -8.12781632e-01,
                         -2.53457576e-01,  -1.75773785e-01,  -5.32601774e-01,
                         -3.19799513e-01,  -1.25852168e-01,  -5.13587773e-01,
                         -7.87244499e-01,  -7.43145049e-01,  -4.67637330e-01,
                         -8.26773718e-02,  -3.16838741e-01,  -8.56364012e-01,
                         -5.44908762e-01,   6.72662514e-04,  -3.32760304e-01,
                         -7.74999678e-01,  -6.16732121e-01,  -5.97337902e-01,
                         -7.75855780e-01,  -4.28300440e-01,  -4.77770269e-02,
                         -3.54266346e-01,  -7.63998449e-01,  -7.34492362e-01,
                         -5.87887764e-01,  -6.43635929e-01,  -7.54547775e-01,
                         -5.02482831e-01,  -8.80341679e-02,  -2.50604689e-01,
                         -7.09033608e-01,  -7.26225197e-01,  -5.90526640e-01,
                         -6.33510053e-01,  -6.46224260e-01,  -6.25883222e-01,
                         -6.18035018e-01,  -6.28264189e-01,  -6.84237599e-01,
                         -6.49250567e-01,  -6.17586374e-01,  -6.72126353e-01,
                         -6.02286875e-01,  -6.17649853e-01,  -7.47838497e-01,
                         -4.36493933e-01,  -6.47119135e-02,  -3.62808526e-01,
                         -7.38274097e-01,  -6.48732901e-01,  -5.71187675e-01,
                         -6.60282731e-01,  -6.60251975e-01,  -6.26204252e-01,
                         -6.28324151e-01,  -6.33319199e-01,  -6.53965533e-01,
                         -6.49027050e-01,  -6.20095372e-01,  -6.19025171e-01,
                         -6.24486864e-01,  -6.39717460e-01,  -6.60703540e-01,
                         -6.36919916e-01,  -6.13113225e-01,  -6.30577266e-01,
                         -6.43060446e-01,  -6.43941998e-01,  -6.34997010e-01,
                         -6.24673784e-01,  -6.44816816e-01,  -6.39370799e-01,
                         -6.02502644e-01,  -6.26628280e-01,  -6.63558424e-01,
                         -6.42901480e-01,  -6.20816469e-01,  -6.17713809e-01,
                         -6.27454638e-01,  -6.38356030e-01,  -6.19214714e-01,
                         -6.21380210e-01,  -6.54415905e-01,  -6.47924602e-01,
                         -6.25715911e-01,  -6.14128947e-01,  -6.04654312e-01,
                         -6.24741614e-01,  -6.46616459e-01,  -6.47561550e-01,
                         -6.41896307e-01,  -6.16949439e-01,  -6.15619481e-01,
                         -6.41808271e-01,  -6.37071013e-01,  -6.39508486e-01,
                         -6.45041466e-01,  -6.19606912e-01,  -6.21347308e-01,
                         -6.28545046e-01,  -6.32227898e-01,  -6.70008659e-01,
                         -6.48441494e-01,  -5.99265814e-01,  -6.36265993e-01,
                         -6.61376834e-01,  -6.42692089e-01,  -6.42147481e-01,
                         -6.33040071e-01,  -6.38452411e-01,  -6.46777630e-01,
                         -6.38006270e-01,  -6.60722136e-01,  -6.50921643e-01,
                         -6.33234739e-01,  -6.50516033e-01,  -5.95434546e-01,
                         -6.56284571e-01,  -7.76955843e-01,  -4.30843502e-01,
                         -5.25416322e-02,  -3.58111531e-01,  -7.37443268e-01,
                         -6.76664948e-01,  -6.10312283e-01,  -6.62198424e-01,
                         -6.72002733e-01,  -6.72635376e-01,  -6.60230219e-01,
                         -6.50159597e-01,  -6.59404695e-01,  -6.71061158e-01,
                         -6.56112075e-01,  -6.16700590e-01,  -7.17261255e-01,
                         -6.85365021e-01,  -1.98376089e-01,  -1.21553227e-01,
                         -7.38712013e-01,  -7.31737733e-01,  -8.06722343e-02,
                          6.86322674e-02,  -4.83279526e-02,   2.47725733e-02,
                          3.38730752e-03,  -2.83498075e-02,   2.03423947e-02,
                         -4.70128516e-03,  -1.05147688e-02,   5.05144009e-03,
                         -8.73855781e-03,   1.05846077e-02,  -2.63682939e-03,
                         -2.69396100e-02,   6.33802672e-04,  -3.05656664e-04,
                         -8.79391591e-05,   2.01265346e-02,  -1.27234990e-02,
                         -3.54161114e-02,  -2.30169948e-03,   2.13277936e-02,
                          4.78275307e-03,  -2.16530412e-02,  -1.10187130e-02,
                          2.87090125e-03,  -1.52285155e-02,  -1.61180142e-02,
                         -5.97180612e-03,  -2.54744850e-03,   4.08234727e-03,
                         -5.66943316e-03,   3.04527394e-03,   1.76562462e-02,
                         -1.27505213e-02,  -1.36645762e-02,   1.16020748e-02,
                         -4.68485057e-03,  -1.19868927e-02,  -4.83625336e-03,
                          3.40888393e-03,   1.77952982e-02,  -9.27067734e-03,
                         -1.75269805e-02,   1.68479588e-02,  -2.29362631e-03,
                         -1.35078719e-02,   1.81990340e-02,   2.63397815e-03,
                         -2.10526679e-02,  -1.82554331e-02,  -1.51035590e-02,
                          2.13745021e-04,   3.95968091e-03,   4.08318033e-03,
                          3.81921860e-03,  -2.16367822e-02,  -5.50728198e-03,
                          2.52297781e-02,  -5.56145515e-03,  -1.75275244e-02,
                         -1.29195279e-03,   2.87002022e-03,   2.59981956e-02,
                          1.76994614e-02,  -1.60139464e-02,  -4.73157549e-03,
                          6.52699172e-03,   2.38502538e-03,   6.07324822e-04,
                         -1.92923145e-03,   1.96271557e-02,   1.55679062e-02,
                         -1.90166272e-02,  -7.36033171e-03,   3.51279299e-03,
                         -7.64468405e-03,   2.65563460e-04,  -6.79796934e-03,
                         -4.09352779e-03,   2.15947833e-02,   1.34128528e-02,
                         -1.37013698e-03,  -5.26098860e-03,  -4.67402255e-03,
                          1.52367651e-02,   9.20037460e-03,  -1.09667024e-02,
                         -3.75972758e-03,  -3.39334644e-03,   5.48525713e-03,
                          2.12798510e-02,   7.50229973e-03,   2.92422529e-03,
                          5.05105546e-03,   5.53215796e-04,   6.38121134e-03,
                         -7.83731788e-03,  -7.19438447e-03,   2.34217700e-02,
                          1.56229604e-02,   4.59241029e-03,   6.44046254e-03,
                         -6.79553486e-03,   1.30000515e-02,   1.97572224e-02,
                         -1.65456980e-02,  -1.23438556e-02,   7.34524278e-04,
                         -4.34781471e-03,   7.67181907e-03,  -4.06892411e-03,
                         -1.69751085e-02,   4.35018539e-03,   1.09942369e-02,
                          5.34376968e-03,  -7.04650593e-04,  -2.46686162e-03,
                          8.58230144e-03,  -5.93334669e-03,  -1.41642438e-02,
                          7.10953679e-03,  -2.64257984e-03,  -6.01894688e-03,
                          1.36381630e-02,  -8.12772487e-04,  -5.88993775e-03,
                          4.77926107e-03,  -4.09298344e-03,   8.65249243e-03,
                          1.81027818e-02,  -3.53244715e-03,  -1.92088599e-03,
                          1.17075378e-02,   1.93651963e-03,  -9.16981231e-03,
                         -1.01954967e-04,   1.52275227e-02,   4.71924152e-03,
                         -1.24319224e-02,  -4.21838881e-03,   5.96477417e-03,
                          1.00753130e-02,   8.30975454e-03,  -5.78932837e-03,
                         -6.71662996e-03,   1.08341372e-03,   1.98830594e-03,
                          8.59171990e-03,   3.92080517e-03,  -1.30016366e-02,
                         -4.40958049e-03,   2.10689902e-02,   1.26315393e-02,
                         -1.93151552e-02,  -4.71688667e-03,   2.65107900e-02,
                          6.65632170e-03,  -9.22928751e-03,  -5.11986902e-03,
                         -1.45329954e-02,  -1.52934052e-03,   9.69264191e-03,
                          5.06161153e-03,   1.66609306e-02,   5.46318432e-03,
                          8.11183546e-03,   2.80888248e-02,  -1.76019128e-02,
                         -2.26620343e-02,   2.65375245e-02,  -3.94202909e-03,
                         -1.83069464e-02,   1.14036268e-02,  -2.50781979e-03,
                          5.56627661e-03,   1.15629109e-02,  -1.30370045e-02,
                         -9.17524192e-03,  -2.26961207e-02,  -1.63669679e-02,
                          2.31145602e-02,   6.87463209e-04,  -9.26814694e-03,
                          4.37161746e-03,  -1.04670189e-02,   8.08293838e-03,
                         -1.28769204e-02,  -5.06812595e-02,   4.52628778e-03,
                          2.11535171e-02,  -4.58180642e-04,   7.90979899e-03,
                         -1.94428843e-02,  -7.45381322e-03,   1.36936810e-02,
                         -1.34718632e-02,   4.85291239e-03,  -3.78053496e-03,
                         -9.32856742e-03,  -1.18878208e-01,  -5.88960707e-01,
                         -7.92375386e-01,  -3.35010648e-01,   2.62203980e-02,
                          6.39972240e-02,   2.82578152e-02,  -3.90368663e-02,
                          9.13791656e-02,   4.22029160e-02,  -4.60447431e-01,
                         -5.17362952e-01,  -4.33725379e-02,   1.01431802e-01,
                         -2.77764574e-02,  -2.37683058e-02,   5.52148856e-02,
                          3.08060972e-03,  -6.11626171e-02,   1.18892469e-01,
                          2.42991280e-02,  -4.58533168e-01,  -3.94961536e-01,
                         -1.46526068e-01,  -4.43736553e-01,  -4.28174794e-01,
                          1.57087538e-02,   8.90960842e-02,  -1.37164267e-02,
                         -2.30588421e-01,  -6.89510643e-01,  -7.34711051e-01,
                         -2.16265813e-01,   1.38276801e-01,  -8.07794258e-02,
                         -5.49818218e-01,  -7.41198421e-01,  -6.54985070e-01,
                         -5.94668627e-01,  -6.75279737e-01,  -7.61229277e-01,
                         -4.72334653e-01,  -9.06446949e-02,  -3.53218645e-01,
                         -7.68500865e-01,  -6.77256465e-01,  -5.85368812e-01,
                         -6.71565592e-01,  -6.48863196e-01,  -6.46603167e-01,
                         -6.63569391e-01,  -6.46265268e-01,  -6.87839806e-01,
                         -6.75316870e-01,  -6.31898463e-01,  -6.55546308e-01,
                         -6.47601902e-01,  -6.45274818e-01,  -6.78126335e-01,
                         -6.69606268e-01,  -6.61895275e-01,  -6.51619196e-01,
                         -6.43448591e-01,  -6.89457536e-01,  -6.96191370e-01,
                         -6.47758901e-01,  -6.32957280e-01,  -6.39300048e-01,
                         -6.65267467e-01,  -6.84972882e-01,  -6.50787532e-01,
                         -6.40666544e-01,  -6.65450394e-01,  -6.49260581e-01,
                         -6.44783020e-01,  -6.80679619e-01,  -6.73614442e-01,
                         -6.35546982e-01,  -6.41073346e-01,  -6.65724277e-01,
                         -6.64451182e-01,  -6.60446703e-01,  -6.69534862e-01,
                         -6.71373129e-01,  -6.63929820e-01,  -6.65092409e-01,
                         -6.72072291e-01,  -6.69269443e-01,  -6.67118728e-01,
                         -6.69989407e-01,  -6.68436170e-01,  -6.79002106e-01,
                         -6.81307137e-01,  -6.56794071e-01,  -6.66362047e-01,
                         -6.90977812e-01,  -6.70330405e-01,  -6.65817022e-01,
                         -6.90599382e-01,  -6.89776003e-01,  -6.76811218e-01,
                         -6.65606380e-01,  -6.77661538e-01,  -7.02840507e-01,
                         -6.75434351e-01,  -6.44645154e-01,  -6.67454720e-01,
                         -7.05223620e-01,  -7.29954302e-01,  -6.94084704e-01,
                         -6.53179526e-01,  -6.71415806e-01,  -6.50153279e-01,
                         -7.17332661e-01,  -8.29112351e-01,  -4.89554018e-01,
                         -8.10821354e-02,  -3.78975153e-01,  -8.02232802e-01,
                         -7.23657548e-01,  -6.30194604e-01,  -7.19838798e-01,
                         -7.34898686e-01,  -7.08050251e-01,  -6.94499254e-01,
                         -6.91177070e-01,  -6.92961872e-01,  -6.80001795e-01,
                         -7.26952434e-01,  -7.65935242e-01,  -6.96875572e-01,
                         -6.59689546e-01,  -7.03101516e-01,  -7.33279347e-01,
                         -7.32083678e-01,  -7.11674929e-01,  -7.05962718e-01,
                         -7.14574039e-01,  -7.03941405e-01,  -6.97833538e-01,
                         -7.21112728e-01,  -7.35257149e-01,  -6.74121737e-01,
                         -6.83511615e-01,  -8.20573866e-01,  -6.09213650e-01,
                         -1.67307332e-01,  -3.30003083e-01,  -7.68512011e-01,
                         -7.43901491e-01,  -6.85342669e-01,  -7.76508152e-01,
                         -6.85698211e-01,  -7.20614314e-01,  -8.22319627e-01,
                         -4.24001515e-01,  -8.29143748e-02,  -5.46602726e-01,
                         -9.24694657e-01,  -4.26779509e-01,  -1.26673788e-01,
                         -5.72808206e-01,  -5.61242700e-01,   4.95433062e-02,
                          2.40846630e-02,  -5.89816689e-01,  -8.11254621e-01,
                         -6.66495442e-01,  -7.37071991e-01,  -8.40789974e-01,
                         -4.45491552e-01,  -6.89601451e-02,  -5.17029583e-01,
                         -9.65927482e-01,  -4.89523143e-01,  -9.36211199e-02,
                         -4.91499126e-01,  -8.10919166e-01,  -7.68519282e-01,
                         -6.96437538e-01,  -3.54896456e-01,   6.34425133e-02,
                         -9.28931609e-02,  -6.39751971e-01,  -8.71217012e-01,
                         -5.61498046e-01,  -1.03620976e-01,   1.89147517e-02,
                         -3.28001499e-01,  -7.97227502e-01,  -7.66613424e-01,
                         -3.12604398e-01,  -5.22855967e-02,   4.79660071e-02,
                         -7.63160363e-02,  -5.65472901e-01,  -5.52899003e-01,
                         -1.15084186e-01,  -4.61175710e-01,  -9.95895147e-01,
                         -5.62433481e-01,  -2.48539299e-02,  -4.39127922e-01,
                         -9.70315635e-01,  -5.70979714e-01,  -1.17288366e-01,
                         -4.74707514e-01,  -6.11360967e-01,  -1.23050854e-01,
                          5.01392260e-02,  -1.28334939e-01,  -1.32193342e-01,
                          3.63332108e-02,  -4.19511460e-03,  -4.52455133e-01,
                         -6.32400393e-01,  -2.04174966e-01,   3.99552286e-02,
                         -8.24131370e-02,  -8.80930945e-02,  -4.77048159e-02,
                         -1.04328968e-01,  -1.01631932e-01,  -9.54666920e-03,
                         -8.66987184e-03,  -1.03282720e-01,  -4.01276164e-02,
                         -1.67214796e-02,  -4.73498106e-01,  -9.23275530e-01,
                         -5.95774651e-01,  -1.01616360e-01,  -3.88234258e-01,
                         -6.46888137e-01,  -7.64225572e-02,   1.27030075e-01,
                         -5.03410518e-01,  -6.27091527e-01,  -1.01775356e-01,
                          5.80927059e-02,  -9.33227837e-02,  -1.00270025e-02,
                          3.47742364e-02,  -4.15977865e-01,  -8.60386431e-01,
                         -6.25990868e-01,  -1.58813253e-01,  -6.61626051e-04,
                          4.71769236e-02,  -9.46284458e-02,  -5.25943458e-01,
                         -5.16230941e-01,   5.89181967e-02,   6.09076582e-02,
                         -5.68105996e-01,  -5.62317431e-01,   1.67901330e-02,
                          9.44940895e-02,  -3.75211328e-01,  -7.58690476e-01,
                         -6.67387366e-01,  -2.25894526e-01,   9.50301662e-02,
                         -4.92787361e-02,  -6.15664423e-01,  -8.04166436e-01,
                         -2.87405103e-01,  -2.01382503e-01,  -5.54750323e-01,
                         -2.96294600e-01,  -1.14748418e-01,  -5.42310834e-01,
                         -7.59019017e-01,  -7.12295473e-01,  -4.79042828e-01,
                         -7.28328153e-02,  -3.05518717e-01,  -8.41772854e-01,
                         -5.15658736e-01,   1.78241301e-02,  -3.18661779e-01,
                         -7.88858533e-01,  -6.32171094e-01,  -5.67266464e-01,
                         -7.82396197e-01,  -4.68177259e-01,  -3.33333947e-02,
                         -3.17544311e-01,  -7.35945046e-01,  -7.05416381e-01,
                         -5.66550970e-01,  -6.17793381e-01,  -7.34744251e-01,
                         -5.06849825e-01,  -8.82045180e-02,  -2.35241905e-01,
                         -6.87777460e-01,  -6.86431944e-01,  -5.41010559e-01,
                         -6.08619332e-01,  -6.46318793e-01,  -6.42998695e-01,
                         -6.47731781e-01,  -6.20138645e-01,  -6.22176647e-01,
                         -6.06166422e-01,  -6.19784296e-01,  -6.59942508e-01,
                         -5.72662771e-01,  -6.30323052e-01,  -7.68564999e-01,
                         -4.04241621e-01,  -2.43138336e-02,  -3.22747946e-01,
                         -6.89490438e-01,  -6.54610336e-01,  -5.89819252e-01,
                         -6.35922551e-01,  -6.42812490e-01,  -6.02958739e-01,
                         -6.08018517e-01,  -6.43256426e-01,  -6.20858669e-01,
                         -5.97064674e-01,  -6.18274629e-01,  -6.30043387e-01,
                         -6.24404192e-01,  -6.03293121e-01,  -5.97774088e-01,
                         -6.17895484e-01,  -6.20078921e-01,  -6.20002151e-01,
                         -6.11657262e-01,  -6.12341702e-01,  -6.41201615e-01,
                         -6.21206880e-01,  -6.10103071e-01,  -6.36891901e-01,
                         -6.13096595e-01,  -6.23671710e-01,  -6.46234870e-01,
                         -6.12368703e-01,  -6.43609762e-01,  -6.51714921e-01,
                         -5.88887393e-01,  -6.11693740e-01,  -6.33092761e-01,
                         -6.12730384e-01,  -6.42156005e-01,  -6.53613031e-01,
                         -6.43250287e-01,  -6.29691541e-01,  -6.02637649e-01,
                         -6.28850579e-01,  -6.52337134e-01,  -6.25853837e-01,
                         -6.27639711e-01,  -6.41958535e-01,  -6.38040781e-01,
                         -6.38296485e-01,  -6.32794917e-01,  -6.18799925e-01,
                         -6.22056246e-01,  -6.43089116e-01,  -6.41972065e-01,
                         -6.38322890e-01,  -6.47867978e-01,  -6.27060235e-01,
                         -6.39972150e-01,  -6.67542636e-01,  -6.09490216e-01,
                         -6.05605245e-01,  -6.68402255e-01,  -6.37230635e-01,
                         -6.15481019e-01,  -6.56056523e-01,  -6.60038590e-01,
                         -6.56584740e-01,  -6.38726473e-01,  -6.07873440e-01,
                         -6.43715262e-01,  -6.54987752e-01,  -5.84221125e-01,
                         -6.49661422e-01,  -7.53527761e-01,  -4.36114103e-01,
                         -7.19075352e-02,  -3.59973729e-01,  -7.34513640e-01,
                         -6.42939627e-01,  -6.08327150e-01,  -7.10524261e-01,
                         -6.61663055e-01,  -6.36704326e-01,  -6.64346695e-01,
                         -6.71743333e-01,  -6.94532394e-01,  -6.85572743e-01,
                         -6.51583076e-01,  -6.31022215e-01,  -7.25161374e-01,
                         -6.87377334e-01,  -2.03618467e-01,  -1.30856723e-01,
                         -7.63946593e-01,  -7.28996456e-01,  -5.77853024e-02,
                          6.73076585e-02,  -4.44399044e-02,   2.70719994e-02,
                         -8.96162528e-04,  -2.21553985e-02,  -3.95152764e-03,
                         -2.69844439e-02,   1.78940985e-02,   1.54253943e-02,
                         -4.87648584e-02,  -2.22364664e-02,   1.60175487e-02,
                          8.77990015e-03,  -2.70106178e-03,  -1.52802384e-02,
                         -1.31463604e-02,  -1.11668482e-02,  -1.11896256e-02,
                          9.56468936e-03,   2.23519560e-02,   6.07806956e-03,
                         -1.68851204e-02,  -2.30071433e-02,  -1.88250523e-02,
                         -2.09820597e-03,   1.71825755e-02,  -1.40700256e-02,
                         -3.59729640e-02,   5.77174034e-03,   2.82890187e-03,
                         -2.83192135e-02,  -1.21701229e-02,  -1.06490636e-02,
                         -1.11782048e-02,  -1.75125475e-04,  -1.30172223e-02,
                         -5.79972379e-03,  -1.36893243e-02,  -4.89823222e-02,
                         -2.77663823e-02,   2.50471244e-03,   7.10080704e-03,
                          1.35377776e-02,  -3.38881323e-03,  -7.74005568e-03,
                          4.44853620e-04,  -1.20437406e-02,  -4.17751074e-03,
                         -3.40960477e-03,  -3.83371487e-03,   2.57087648e-02,
                          2.40168418e-03,  -2.84264386e-02,  -4.37205005e-03,
                         -1.19212829e-02,  -2.24554166e-02,  -1.02209495e-02,
                         -1.91777684e-02,   2.77115684e-03,   2.36406568e-02,
                          1.25248428e-03,  -1.46654970e-03,  -4.52971598e-03,
                          1.87685236e-03,   3.50537039e-02,   1.14065586e-02,
                         -8.82914010e-03,   3.34285907e-02,   2.86722668e-02,
                         -8.41705967e-03,  -7.83736538e-03,  -2.40959707e-04,
                          1.77337732e-02,   2.71697883e-02,   3.78920068e-03,
                          6.46589883e-03,   2.30735857e-02,   1.23995338e-02,
                          9.89297964e-03,   1.07783941e-03,  -1.45052364e-02,
                          1.13835558e-02,   1.44248893e-02,  -2.54881810e-02,
                         -1.20473932e-02,   1.79095864e-02,   8.60254839e-03,
                          2.09907424e-02,   3.74494269e-02,   1.93057861e-02,
                          5.20019978e-03,  -4.79340507e-03,  -2.14058813e-02,
                         -3.18841599e-02,  -2.58060265e-02,   8.56524240e-03,
                          3.58404145e-02,   3.08526140e-02,   2.04553530e-02,
                          4.93949000e-03,  -1.11970259e-02,  -1.25312507e-02,
                         -5.79778571e-03,  -3.24493914e-04,  -1.86443683e-02,
                         -2.75190473e-02,   1.11298300e-02,   1.86796710e-02,
                         -9.28474125e-03,   7.19217397e-03,   2.05861405e-02,
                         -7.34778959e-03,  -2.59228628e-02,  -2.57794689e-02,
                         -1.55013679e-02,  -9.43960447e-04,   1.12170167e-02,
                          1.80498902e-02,  -9.67506960e-04,  -2.11062804e-02,
                         -9.01214592e-03,   4.02923161e-03,   6.83996873e-03,
                          6.67828275e-03,  -1.95891294e-03,   3.14373686e-03,
                          1.43598402e-02,  -2.69537535e-03,  -2.36882307e-02,
                         -1.18988892e-02,   8.41068383e-03,   5.46962349e-03,
                          9.95104481e-03,   2.60913894e-02,   9.20413877e-04,
                         -2.06401218e-02,   1.32352440e-02,   1.85938627e-02,
                         -8.70246906e-03,   6.87259762e-03,   1.17911519e-02,
                         -1.41095743e-02,  -4.05913714e-04,   1.40417377e-02,
                         -9.41783562e-03,  -8.94788187e-03,   1.28674535e-02,
                          1.34081272e-02,   9.04014613e-03,   5.98383555e-03,
                         -5.08317200e-04,   4.92510572e-03,   1.61946770e-02,
                          1.52676804e-02,  -3.60888545e-03,  -1.97828989e-02,
                         -2.01223698e-03,   1.97656006e-02,   7.23508652e-03,
                         -6.03459682e-03,   3.47178685e-03,   1.27148498e-02,
                         -4.80437744e-03,  -3.82337384e-02,  -2.10554060e-02,
                          3.46824862e-02,   4.08621244e-02,   2.43054237e-02,
                          2.58711092e-02,   6.12775795e-03,  -1.81132238e-02,
                         -2.17845161e-02,  -3.18057858e-03,   3.67923528e-02,
                          2.27339063e-02,  -2.78320070e-02,  -1.25754438e-02,
                          6.22154353e-03,  -8.64829589e-03,   2.49090488e-03,
                          2.89369491e-03,   1.27277919e-03,   1.32475784e-02,
                         -1.25115644e-02,  -4.89305332e-03,   3.12723182e-02,
                          1.87352067e-03,  -1.43281566e-02,  -5.46356896e-03,
                         -9.99277178e-03,   2.35955827e-02,   1.96811371e-02,
                         -3.59986722e-03,   3.20148990e-02,   1.65054924e-03,
                         -2.83327810e-02,   9.39063728e-03,  -1.50864674e-02,
                          8.45521409e-03,  -1.03720829e-01,  -5.94660640e-01,
                         -7.69084454e-01,  -3.17625195e-01,   3.43754813e-02,
                          5.86263016e-02,  -5.57199493e-03,  -1.25254197e-02,
                          1.29290611e-01,   1.53561002e-02,  -4.38022703e-01,
                         -4.73392218e-01,  -4.79594097e-02,   1.27528712e-01,
                         -8.45468603e-03,  -2.70446073e-02,   9.04210135e-02,
                          1.45081356e-02,  -6.27539754e-02,   1.26311809e-01,
                         -3.13283354e-02,  -4.95273739e-01,  -3.54820013e-01,
                         -1.18358552e-01,  -4.35524583e-01,  -4.37836945e-01,
                          3.45956511e-03,   1.33987606e-01,   2.73618456e-02,
                         -2.36166477e-01,  -6.93722785e-01,  -7.39733517e-01,
                         -2.10085049e-01,   1.57631397e-01,  -7.81337023e-02,
                         -5.35238445e-01,  -7.30485320e-01,  -6.82193995e-01,
                         -6.17805123e-01,  -6.87539577e-01,  -7.59769678e-01,
                         -4.40587938e-01,  -7.48943239e-02,  -3.51062924e-01,
                         -7.49168694e-01,  -6.79620802e-01,  -6.11648798e-01,
                         -6.93368196e-01,  -6.69577062e-01,  -6.59217596e-01,
                         -6.70352578e-01,  -6.41958058e-01,  -6.59173369e-01,
                         -6.66052103e-01,  -6.45219028e-01,  -6.29132152e-01,
                         -6.09430134e-01,  -6.53942406e-01,  -6.93181634e-01,
                         -6.52602255e-01,  -6.44010186e-01,  -6.57281220e-01,
                         -6.54489040e-01,  -6.66359186e-01,  -6.38704300e-01,
                         -6.27927542e-01,  -6.87146246e-01,  -6.95131361e-01,
                         -6.61585689e-01,  -6.63961351e-01,  -6.60946548e-01,
                         -6.40636861e-01,  -6.27425134e-01,  -6.40043855e-01,
                         -6.64310813e-01,  -6.53618932e-01,  -6.49888813e-01,
                         -6.76043749e-01,  -6.71221375e-01,  -6.55645370e-01,
                         -6.61141038e-01,  -6.71329081e-01,  -6.85448050e-01,
                         -6.73292100e-01,  -6.44423306e-01,  -6.49755001e-01,
                         -6.61636949e-01,  -6.60995841e-01,  -6.60202861e-01,
                         -6.52089715e-01,  -6.66557431e-01,  -6.93393648e-01,
                         -6.79325402e-01,  -6.57360911e-01,  -6.64038062e-01,
                         -6.79399788e-01,  -6.91994011e-01,  -6.86563849e-01,
                         -6.69115722e-01,  -6.63766861e-01,  -6.60559535e-01,
                         -6.69805527e-01,  -6.90229058e-01,  -6.75668240e-01,
                         -6.66634917e-01,  -7.03541994e-01,  -7.03809321e-01,
                         -6.65013433e-01,  -6.54547870e-01,  -6.59011900e-01,
                         -7.05178857e-01,  -7.43825436e-01,  -6.74383521e-01,
                         -7.00767875e-01,  -7.87029326e-01,  -4.72712457e-01,
                         -1.03494316e-01,  -3.77103686e-01,  -7.79368281e-01,
                         -7.04910040e-01,  -6.14308357e-01,  -7.23016798e-01,
                         -7.17141092e-01,  -6.69424891e-01,  -6.93059385e-01,
                         -6.80021048e-01,  -6.80274427e-01,  -7.21554816e-01,
                         -7.26221919e-01,  -7.13473082e-01,  -7.00586259e-01,
                         -6.94364429e-01,  -7.11479604e-01,  -7.03980327e-01,
                         -6.90011859e-01,  -7.12382197e-01,  -7.13414788e-01,
                         -7.01179802e-01,  -7.08893657e-01,  -7.07650065e-01,
                         -7.45911062e-01,  -7.64738798e-01,  -6.62342668e-01,
                         -6.87629163e-01,  -8.36174250e-01,  -5.85601747e-01,
                         -1.63661480e-01,  -3.35060507e-01,  -7.54188359e-01,
                         -7.54948437e-01,  -6.86594605e-01,  -7.51864016e-01,
                         -6.73333406e-01,  -7.14778721e-01,  -8.13647449e-01,
                         -3.94991517e-01,  -7.23548979e-02,  -5.95208228e-01,
                         -9.48194861e-01,  -4.10711884e-01,  -1.16208091e-01,
                         -5.40197849e-01,  -5.46811283e-01,   2.61005666e-02,
                          2.78371014e-02,  -5.74685454e-01,  -8.07156265e-01,
                         -6.50231481e-01,  -7.19223917e-01,  -8.45708251e-01,
                         -4.70598757e-01,  -7.37104118e-02,  -5.04714131e-01,
                         -9.70795035e-01,  -4.89543825e-01,  -9.80519429e-02,
                         -5.06362855e-01,  -8.00463200e-01,  -7.64119744e-01,
                         -7.06360936e-01,  -3.58320922e-01,   4.95473258e-02,
                         -8.47951695e-02,  -6.15624189e-01,  -8.67835462e-01,
                         -5.34768403e-01,  -6.52221665e-02,   1.68165304e-02,
                         -3.61779183e-01,  -8.29901338e-01,  -7.48963416e-01,
                         -2.78983444e-01,  -8.31143931e-02,   2.51999358e-03,
                         -6.05635718e-02,  -5.13313949e-01,  -5.37260950e-01,
                         -1.42591283e-01,  -4.53081131e-01,  -9.56829965e-01,
                         -5.55822730e-01,  -4.66680303e-02,  -4.77183610e-01,
                         -9.82610703e-01,  -5.33683538e-01,  -9.70824286e-02,
                         -4.70968753e-01,  -5.84388912e-01,  -1.06622115e-01,
                          4.98465262e-02,  -1.27340510e-01,  -1.53194010e-01,
                          1.81556726e-03,   4.69298800e-03,  -4.26620841e-01,
                         -6.54529750e-01,  -2.09505394e-01,   6.42918050e-02,
                         -1.18368290e-01,  -1.23016857e-01,  -2.23197769e-02,
                         -7.11633340e-02,  -8.02709311e-02,  -4.26111519e-02,
                         -5.84308803e-02,  -8.72294977e-02,  -3.26478556e-02,
                         -3.10776830e-02,  -4.77645993e-01,  -9.46155190e-01,
                         -5.66432774e-01,  -6.26378804e-02,  -4.32454556e-01,
                         -6.54545903e-01,  -4.75180633e-02,   1.17744677e-01,
                         -4.78707671e-01,  -6.09579504e-01,  -1.27960384e-01,
                          6.97937533e-02,  -8.83349180e-02,  -4.52805161e-02,
                          2.77817119e-02,  -4.07183498e-01,  -8.61353159e-01,
                         -6.21297359e-01,  -1.77624628e-01,  -3.09176799e-02,
                          7.33666793e-02,  -5.51547706e-02,  -5.40220737e-01,
                         -5.40781140e-01,   3.78775932e-02,   5.18105999e-02,
                         -5.29226601e-01,  -5.51231682e-01,  -1.79482382e-02,
                          1.01475976e-01,  -3.69362175e-01,  -8.05065274e-01,
                         -6.91864967e-01,  -1.74887821e-01,   1.61811799e-01,
                         -7.36838579e-02,  -7.07344294e-01,  -8.52349222e-01,
                         -2.58309484e-01,  -1.22562975e-01,  -5.23304403e-01,
                         -3.45516235e-01,  -1.39439389e-01,  -5.44774652e-01,
                         -7.91586816e-01,  -7.31618226e-01,  -4.66295272e-01,
                         -4.01710570e-02,  -2.97730684e-01,  -8.84219766e-01,
                         -5.65332532e-01,  -3.57177146e-02,  -3.29699188e-01,
                         -7.43996441e-01,  -6.48374498e-01,  -5.99587381e-01,
                         -7.57006586e-01,  -4.80118334e-01,  -7.73802325e-02,
                         -3.34981471e-01,  -7.21648455e-01,  -6.73778415e-01,
                         -5.87956071e-01,  -6.53344095e-01,  -7.27985680e-01,
                         -5.26551843e-01,  -1.10277534e-01,  -2.38801226e-01,
                         -7.19030499e-01,  -7.07306504e-01,  -5.64125538e-01,
                         -6.52206182e-01,  -6.62456810e-01,  -6.48117423e-01,
                         -6.27716899e-01,  -5.73505998e-01,  -6.38675034e-01,
                         -6.61495626e-01,  -6.26948476e-01,  -6.48363769e-01,
                         -5.85574210e-01,  -6.32559597e-01,  -7.60083616e-01,
                         -4.37833816e-01,  -5.45311533e-02,  -3.15002501e-01,
                         -7.10101485e-01,  -6.79902017e-01,  -5.93875170e-01,
                         -6.51726902e-01,  -6.34049535e-01,  -5.95558524e-01,
                         -6.30568326e-01,  -6.37308061e-01,  -6.24960780e-01,
                         -6.32691145e-01,  -6.26333475e-01,  -6.22336984e-01,
                         -6.20139241e-01,  -6.14541292e-01,  -6.34649992e-01,
                         -6.51877999e-01,  -6.28862441e-01,  -5.96058190e-01,
                         -6.12729490e-01,  -6.53050244e-01,  -6.34636819e-01,
                         -6.06058657e-01,  -6.27476811e-01,  -6.45585358e-01,
                         -6.40345573e-01,  -6.06506228e-01,  -5.84701121e-01,
                         -6.40686929e-01,  -6.68108821e-01,  -6.20710850e-01,
                         -6.13509953e-01,  -6.36377871e-01,  -6.40558720e-01,
                         -6.30786419e-01,  -6.06249571e-01,  -6.02462888e-01,
                         -6.19566977e-01,  -6.43356323e-01,  -6.55137837e-01,
                         -6.25718355e-01,  -6.32395506e-01,  -6.55186594e-01,
                         -6.11208975e-01,  -6.08014166e-01,  -6.36181533e-01,
                         -6.26209915e-01,  -6.56427681e-01,  -6.50712430e-01,
                         -5.90427577e-01,  -6.06306911e-01,  -6.37390196e-01,
                         -6.53691411e-01,  -6.63147569e-01,  -6.14772856e-01,
                         -6.15153611e-01,  -6.55598581e-01,  -6.38136506e-01,
                         -6.41643763e-01,  -6.37562573e-01,  -6.10639215e-01,
                         -6.51747286e-01,  -6.63432658e-01,  -6.24609649e-01,
                         -6.38455689e-01,  -6.41374767e-01,  -6.22367144e-01,
                         -6.71678722e-01,  -6.95269346e-01,  -6.01273775e-01,
                         -6.21538222e-01,  -7.40609705e-01,  -4.57631528e-01,
                         -6.73699975e-02,  -3.33296508e-01,  -7.42820024e-01,
                         -6.71545148e-01,  -6.02631271e-01,  -6.85918272e-01,
                         -6.57625198e-01,  -6.51997328e-01,  -6.83696687e-01,
                         -6.53015256e-01,  -6.35481358e-01,  -6.52284861e-01,
                         -6.46020770e-01,  -6.32934272e-01,  -7.39937007e-01,
                         -6.85209155e-01,  -1.98426828e-01,  -1.29715934e-01,
                         -7.25517213e-01,  -7.05591619e-01,  -7.62194321e-02,
                          6.72503263e-02,  -4.21022587e-02,   2.06706356e-02,
                          9.47546866e-03,  -1.43977227e-02,   9.46169347e-03,
                         -9.27279238e-03,   1.39229633e-02,   2.42818929e-02,
                         -2.35465840e-02,  -1.94642358e-02,   7.55937211e-03,
                         -3.56164807e-03,  -1.51296044e-02,   3.78873618e-03,
                          1.77097134e-02,  -1.79560073e-02,  -4.40394022e-02,
                         -1.45257395e-02,   2.01683100e-02,   2.76099984e-02,
                          2.56364280e-03,  -1.08750630e-02,   1.14112999e-02,
                          2.89854850e-03,  -5.68980770e-03,   2.52251010e-02,
                          1.59805324e-02,  -3.99303064e-03,   1.00246323e-02,
                         -2.87754880e-03,  -2.84091546e-03,   2.24467516e-02,
                         -1.19504193e-02,  -3.37272808e-02,   1.86880808e-02,
                          2.34730132e-02,  -2.52003688e-02,  -1.76110752e-02,
                          5.48498519e-03,  -1.13687078e-02,  -9.45165008e-03,
                          1.36001194e-02,   1.66964438e-02,   1.59722026e-02,
                          1.19710183e-02,  -4.30914713e-03,  -9.75551270e-03,
                          1.84697867e-03,   1.44087272e-02,   7.45102577e-03,
                         -5.04692318e-03,   1.69611424e-02,   3.28129679e-02,
                         -3.90874362e-03,  -2.76962556e-02,  -1.05997929e-02,
                         -7.73364864e-03,  -9.81096737e-03,   5.10652643e-03,
                          3.97983193e-03,  -8.60089844e-04,   1.19806137e-02,
                          5.89684118e-03,  -9.30812769e-03,  -9.02489643e-04,
                         -4.75625927e-03,  -2.43039019e-02,  -1.37164751e-02,
                          8.92443117e-03,   1.20981224e-03,  -1.15898848e-02,
                          1.18279615e-02,   2.40517929e-02,  -1.82525981e-02,
                         -3.30503881e-02,  -9.48157161e-04,  -7.10293744e-03,
                         -1.91070326e-02,   7.19443243e-03,   1.70553438e-02,
                          8.73423275e-03,   2.58446625e-03,  -6.54475577e-03,
                         -5.94180403e-03,  -5.40189911e-03,  -9.07693896e-03,
                         -1.11463927e-02,  -1.60537343e-02,  -3.73972091e-03,
                          1.71660930e-02,   2.45821197e-02,   9.08059161e-03,
                         -3.48663703e-02,  -2.87632495e-02,   2.04755366e-02,
                         -4.80870251e-03,  -2.08581593e-02,   2.41871141e-02,
                          7.13973073e-04,  -2.48410515e-02,   1.62032787e-02,
                          1.29431225e-02,  -9.54458676e-03,   4.75869421e-03,
                          2.04173271e-02,   2.65623685e-02,  -7.14870112e-04,
                         -1.93000510e-02,   8.61444976e-03,   1.08314296e-02,
                          5.23330923e-03,   1.77906209e-03,  -3.41353565e-02,
                         -5.19787706e-03,   4.67445962e-02,   1.72914984e-03,
                         -2.44134963e-02,   7.64934532e-03,   1.05528431e-02,
                          7.77950836e-03,  -2.17126426e-03,  -1.55697167e-02,
                          6.82685012e-03,   2.20640004e-02,   1.88421421e-02,
                          5.87944593e-03,  -1.28291864e-02,   1.09284194e-02,
                          2.43376996e-02,  -9.85890906e-03,  -1.35831404e-02,
                         -2.18414282e-03,   4.78714192e-03,   1.97827555e-02,
                         -2.54767272e-03,  -6.52652746e-03,   2.07128115e-02,
                         -6.24726852e-03,   3.26414476e-03,   6.91078007e-02,
                          4.16556261e-02,  -2.28027683e-02,  -1.82109196e-02,
                         -7.91500509e-03,  -1.75930373e-02,  -4.84663295e-03,
                          2.27092225e-02,   1.23958495e-02,  -2.37700362e-02,
                         -1.21238949e-02,   1.26673235e-02,  -2.14569946e-03,
                         -4.59844945e-03,   8.36762786e-03,   1.16701834e-02,
                          8.21148325e-03,  -2.27801185e-02,  -3.26675735e-02,
                          1.02907885e-02,   2.46394165e-02,   4.82345512e-03,
                         -3.38506512e-03,  -9.98284109e-03,  -5.31110866e-03,
                          2.48770113e-03,  -1.24626933e-03,   1.14385141e-02,
                          1.36566637e-02,  -8.84896982e-03,   2.03190721e-03,
                          1.40610877e-02,  -2.63342224e-02,  -4.03038785e-02,
                          1.90816773e-03,   9.01957881e-03,  -1.54590476e-02,
                          2.02852744e-03,   2.82855760e-02,   1.00641483e-02,
                         -1.88393239e-02,  -1.93726774e-02,  -5.62776998e-03,
                         -6.90794957e-04,   3.25684040e-03,   1.27732996e-02,
                          1.88487414e-02,   1.69026759e-02,  -7.50877103e-03,
                         -3.09712589e-02,  -1.95721015e-02,  -1.42315039e-02,
                         -1.07067451e-02,   9.04948451e-03,   3.99335101e-03,
                          2.41940655e-02,   3.14643271e-02,  -3.63451131e-02,
                         -2.00391077e-02,  -1.34331346e-01,  -6.11647248e-01,
                         -7.75491536e-01,  -3.25884342e-01,   3.51434536e-02,
                          7.22203031e-02,  -3.58561124e-03,  -5.63120730e-02,
                          8.79515260e-02,   2.62809955e-02,  -4.62219566e-01,
                         -5.33472717e-01,  -4.35573570e-02,   1.31086931e-01,
                         -4.26166803e-02,  -2.58866940e-02,   7.01614171e-02,
                         -3.15788873e-02,  -3.69749106e-02,   1.60201862e-01,
                         -5.86172007e-02,  -5.32961786e-01,  -3.82275462e-01,
                         -1.19489267e-01,  -4.14199859e-01,  -4.44478750e-01,
                         -5.03567839e-03,   1.54626667e-01,   2.45237499e-02,
                         -2.75672913e-01,  -7.31580138e-01,  -7.66483605e-01,
                         -2.28324145e-01,   1.50819153e-01,  -6.88277856e-02,
                         -5.04446626e-01,  -6.94213748e-01,  -6.59235239e-01,
                         -5.99014640e-01,  -6.69816196e-01,  -7.50904500e-01,
                         -4.39236999e-01,  -9.59569737e-02,  -3.84472132e-01,
                         -7.47057378e-01,  -6.51961923e-01,  -5.90693951e-01,
                         -6.75140202e-01,  -6.64657831e-01,  -6.58637583e-01,
                         -6.58781648e-01,  -6.54213130e-01,  -6.88458145e-01,
                         -6.73590422e-01,  -6.49646282e-01,  -6.47729933e-01,
                         -6.17063463e-01,  -6.28278613e-01,  -6.65518761e-01,
                         -6.61051095e-01,  -6.45545363e-01,  -6.32293284e-01,
                         -6.48424745e-01,  -6.74524307e-01,  -6.59698188e-01,
                         -6.59162581e-01,  -6.69999123e-01,  -6.54014349e-01,
                         -6.60338104e-01,  -6.70540631e-01,  -6.44309819e-01,
                         -6.17195725e-01,  -6.14655614e-01,  -6.38282120e-01,
                         -6.63638651e-01,  -6.69388592e-01,  -6.67976499e-01,
                         -6.61783993e-01,  -6.60313964e-01,  -6.65453613e-01,
                         -6.64331377e-01,  -6.78382277e-01,  -6.89798892e-01,
                         -6.59390271e-01,  -6.40116096e-01,  -6.67477787e-01,
                         -6.81981146e-01,  -6.59751058e-01,  -6.41885221e-01,
                         -6.59196734e-01,  -7.01229095e-01,  -7.08166659e-01,
                         -6.67741537e-01,  -6.63523495e-01,  -6.94014490e-01,
                         -6.85966849e-01,  -6.74029052e-01,  -6.86616659e-01,
                         -6.92560434e-01,  -6.99318767e-01,  -6.89585268e-01,
                         -6.60517752e-01,  -6.55788183e-01,  -6.68997169e-01,
                         -6.92913115e-01,  -7.08350718e-01,  -6.94026470e-01,
                         -7.01606750e-01,  -7.00614393e-01,  -6.64925516e-01,
                         -7.02120662e-01,  -7.25451350e-01,  -6.35352790e-01,
                         -6.85843945e-01,  -8.06374371e-01,  -5.15963674e-01,
                         -1.36284962e-01,  -3.65381181e-01,  -7.68418133e-01,
                         -7.37250268e-01,  -6.58931911e-01,  -7.30761707e-01,
                         -7.02817917e-01,  -6.96776390e-01,  -7.38526583e-01,
                         -6.94216430e-01,  -6.91151857e-01,  -7.24648535e-01,
                         -7.09277809e-01,  -7.11808085e-01,  -7.27773488e-01,
                         -7.38609195e-01,  -7.31913388e-01,  -7.03307450e-01,
                         -7.15284765e-01,  -7.19363928e-01,  -6.86383963e-01,
                         -6.99684024e-01,  -7.30688512e-01,  -7.37495065e-01,
                         -7.49441504e-01,  -7.36491263e-01,  -6.76418662e-01,
                         -7.07559109e-01,  -8.21160972e-01,  -5.96618891e-01,
                         -1.72069609e-01,  -3.30289483e-01,  -7.78838277e-01,
                         -7.63465703e-01,  -6.70971632e-01,  -7.51880646e-01,
                         -6.86994553e-01,  -7.18581319e-01,  -7.96458006e-01,
                         -4.03238505e-01,  -9.61207524e-02,  -5.91098070e-01,
                         -9.62909341e-01,  -4.17496622e-01,  -9.38881412e-02,
                         -5.56120098e-01,  -5.45726538e-01,   5.34760430e-02,
                          1.45126367e-02,  -5.71762443e-01,  -8.16202819e-01,
                         -7.15816617e-01,  -7.27811575e-01,  -7.93352008e-01,
                         -4.49672371e-01,  -8.08784664e-02,  -5.03703654e-01,
                         -9.60720181e-01,  -4.94889051e-01,  -1.01813942e-01,
                         -4.93365914e-01,  -8.06076407e-01,  -7.71840572e-01,
                         -6.95773721e-01,  -3.50519210e-01,   5.02818488e-02,
                         -9.88806710e-02,  -6.26003027e-01,  -8.86169195e-01,
                         -5.96992135e-01,  -8.50994959e-02,   6.40545189e-02,
                         -3.46363872e-01,  -8.38301599e-01,  -7.51020133e-01,
                         -2.79905647e-01,  -4.90814894e-02,   4.22962047e-02,
                         -6.56355768e-02,  -5.39198339e-01,  -5.59980929e-01,
                         -1.55855551e-01,  -4.32955414e-01,  -9.15546060e-01,
                         -5.60257971e-01,  -7.46102929e-02,  -4.45236355e-01,
                         -9.45030153e-01,  -5.53570390e-01,  -1.26477450e-01,
                         -4.94283259e-01,  -6.05446219e-01,  -1.06439881e-01,
                          8.22567046e-02,  -7.08539113e-02,  -1.30002275e-01,
                         -2.45333444e-02,  -2.23595016e-02,  -4.22911078e-01,
                         -6.17641747e-01,  -1.96686134e-01,   5.32451756e-02,
                         -9.00101885e-02,  -1.16113633e-01,  -4.60020341e-02,
                         -5.04132770e-02,  -5.64039685e-02,  -2.97778975e-02,
                         -4.87518683e-02,  -9.80886519e-02,  -1.64249539e-02,
                         -1.00674806e-02,  -4.56153035e-01,  -8.93180490e-01,
                         -5.92014372e-01,  -1.38273135e-01,  -4.29720432e-01,
                         -6.40889585e-01,  -5.47138229e-02,   1.14682823e-01,
                         -4.98626977e-01,  -5.99578261e-01,  -9.69651490e-02,
                          7.15924054e-02,  -8.60703960e-02,  -4.26120646e-02,
                          1.63216852e-02,  -4.16136444e-01,  -8.67081344e-01,
                         -6.27369046e-01,  -1.73786402e-01,  -1.22010699e-02,
                          6.76284954e-02,  -8.72366577e-02,  -5.43072879e-01,
                         -5.22445500e-01,   6.55330792e-02,   7.17214346e-02,
                         -5.49243450e-01,  -5.42571425e-01,   1.43909315e-02,
                          8.29264820e-02,  -3.83263528e-01,  -7.93295264e-01,
                         -6.77002370e-01,  -1.69902310e-01,   1.15023091e-01,
                         -7.66442642e-02,  -6.25853896e-01,  -8.27704728e-01,
                         -2.94284821e-01,  -1.49716899e-01,  -5.21494746e-01,
                         -3.14649642e-01,  -1.47255778e-01,  -5.65665126e-01,
                         -7.69963264e-01,  -7.07558453e-01,  -4.45089698e-01,
                         -7.14599714e-02,  -3.61719698e-01,  -8.48568320e-01,
                         -5.11530399e-01,  -5.14554605e-02,  -3.42838824e-01,
                         -7.45803177e-01,  -6.26816869e-01,  -5.85224211e-01,
                         -7.87645519e-01,  -4.57712173e-01,  -3.04828361e-02,
                         -3.49099368e-01,  -7.39202261e-01,  -6.79409802e-01,
                         -5.87075114e-01,  -6.52442575e-01,  -7.40477324e-01,
                         -4.96386915e-01,  -8.39740634e-02,  -2.59805113e-01,
                         -6.96712196e-01,  -6.78363264e-01,  -5.89257836e-01,
                         -6.67073667e-01,  -6.46317661e-01,  -6.26191616e-01,
                         -6.45267725e-01,  -6.19942367e-01,  -6.21595383e-01,
                         -6.23062968e-01,  -6.58587933e-01,  -6.92883730e-01,
                         -5.77092707e-01,  -6.04472339e-01,  -7.64975071e-01,
                         -4.46374834e-01,  -3.32715325e-02,  -3.21186423e-01,
                         -7.39029169e-01,  -6.74262822e-01,  -5.77045262e-01,
                         -6.44372404e-01,  -6.41209483e-01,  -6.15591824e-01,
                         -6.27381086e-01,  -6.27822042e-01,  -6.38257265e-01,
                         -6.43587828e-01,  -6.20500505e-01,  -6.14054620e-01,
                         -6.36721075e-01,  -6.35396063e-01,  -6.07498348e-01,
                         -6.16153955e-01,  -6.49536669e-01,  -6.49448514e-01,
                         -6.25994027e-01,  -6.11111999e-01,  -6.19441092e-01,
                         -6.39029264e-01,  -6.38607621e-01,  -6.23281658e-01,
                         -6.12648189e-01,  -6.16714716e-01,  -6.28165185e-01,
                         -6.22913718e-01,  -6.24813259e-01,  -6.37019217e-01,
                         -6.15260184e-01,  -5.97579420e-01,  -6.13718331e-01,
                         -6.28966987e-01,  -6.44728780e-01,  -6.36629581e-01,
                         -6.09892011e-01,  -6.23179913e-01,  -6.33083820e-01,
                         -6.27962768e-01,  -6.47012949e-01,  -6.38073504e-01,
                         -6.29777730e-01,  -6.49878681e-01,  -6.21920168e-01,
                         -6.12366557e-01,  -6.47313297e-01,  -6.19865417e-01,
                         -6.03467166e-01,  -6.49548173e-01,  -6.56088710e-01,
                         -6.33311749e-01,  -6.23276293e-01,  -6.17008567e-01,
                         -6.21226192e-01,  -6.27381682e-01,  -6.37744427e-01,
                         -6.43150747e-01,  -6.37295246e-01,  -6.32133245e-01,
                         -6.07983768e-01,  -6.10807359e-01,  -6.48676932e-01,
                         -6.43105686e-01,  -6.36736572e-01,  -6.31251335e-01,
                         -6.15388811e-01,  -6.45634592e-01,  -6.15666449e-01,
                         -6.37641907e-01,  -7.51664221e-01,  -4.49397385e-01,
                         -4.69713509e-02,  -3.37006688e-01,  -7.35405087e-01,
                         -6.62755787e-01,  -6.10374331e-01,  -6.72160506e-01,
                         -6.44608319e-01,  -6.39214873e-01,  -6.52579844e-01,
                         -6.42114162e-01,  -6.28328264e-01,  -6.49304628e-01,
                         -6.65304542e-01,  -6.15177512e-01,  -7.24962354e-01,
                         -7.13053584e-01,  -1.67957395e-01,  -7.74407312e-02,
                         -7.45192111e-01,  -7.27255940e-01,  -7.17574880e-02,
                          6.09733127e-02,  -4.85961735e-02,   1.52249122e-02,
                          1.82323512e-02,   7.82280508e-03,   1.86852291e-02,
                          2.68810312e-03,   1.20977536e-02,   6.39758212e-03,
                          5.36717195e-03,   1.02921175e-02,  -1.42628346e-02,
                          1.49592687e-03,   2.03025416e-02,   9.51617025e-03,
                          7.19497725e-03,  -2.17051469e-02,  -1.22623555e-02,
                          2.82173865e-02,  -1.53010776e-02,  -3.21444385e-02,
                          1.45528102e-02,   5.29321656e-03,  -1.34765245e-02,
                         -9.03367437e-03,   8.17353663e-04,   2.35633068e-02,
                          1.69679333e-04,  -2.46705711e-02,   5.28980466e-03,
                          3.87039641e-03,  -1.35196932e-02,   4.06474341e-04,
                          2.19391380e-03,   5.13487821e-03,   1.38780335e-02,
                          5.05847204e-03,  -4.74193925e-03,  -1.03108268e-02,
                          1.29349052e-03,   1.17973350e-02,  -7.69920973e-03,
                         -5.55871613e-03,   1.06763272e-02,  -5.29083004e-03,
                         -9.68022738e-03,   7.25041551e-04,   1.36095867e-03,
                          3.66501277e-03,  -1.25096897e-02,  -1.62655581e-02,
                          1.66248418e-02,   1.28477672e-02,  -9.53454338e-03,
                          6.04116404e-03,   9.69060697e-03,   9.99206750e-05,
                          7.46776490e-03,   3.32664722e-03,   7.00373726e-04,
                          6.72047399e-03,  -4.45704162e-03,  -1.03936403e-03,
                          1.36867138e-02,  -3.23119550e-03,  -1.15525313e-02,
                          7.89839402e-03,   5.39472327e-03,  -4.58468962e-03,
                          8.03494826e-03,   8.49679671e-03,  -7.76249729e-03,
                         -5.81045588e-03,   1.20877102e-03,  -7.17120618e-03,
                         -4.72465577e-03,   1.28920730e-02,   1.26397246e-02,
                         -1.59901904e-03,  -1.39328314e-03,   7.54266512e-03,
                          1.42672879e-03,  -9.85974167e-03,   5.88256912e-03,
                          2.54282095e-02,   9.16747376e-03,  -4.73056640e-03,
                          4.36762907e-03,   4.40418208e-03,   1.00702830e-02,
                          1.43340193e-02,  -1.14256358e-02,  -1.62967611e-02,
                          1.11948960e-02,   1.39315976e-02,  -2.79403059e-03,
                         -5.86262671e-03,   8.22308008e-03,   1.22254174e-02,
                         -1.16940504e-02,  -1.65094640e-02,   7.14950205e-04,
                         -4.14681993e-03,   5.61639713e-03,   3.14024501e-02,
                          1.03732012e-02,  -2.51572803e-02,  -1.41333453e-02,
                          1.72726922e-02,   9.72844195e-03,  -1.83318071e-02,
                          4.76726377e-03,   3.82468551e-02,   1.53071163e-02,
                         -8.19719490e-03,  -5.65777160e-03,  -1.79998169e-03,
                          9.55701619e-03,   6.95233559e-03,  -1.01923412e-02,
                         -1.46147357e-02,  -1.15617728e-02,  -1.17303478e-03,
                          2.59068119e-03,   1.19233655e-03,   7.74630299e-03,
                         -1.49984807e-02,  -2.91459691e-02,   8.33996455e-04,
                         -2.28388724e-03,  -8.45013652e-03,   2.22353134e-02,
                          1.21269384e-02,  -9.49887093e-03,  -5.74808160e-04,
                         -2.44027167e-03,  -2.73093535e-03,  -1.46161614e-03,
                         -3.73972091e-03,  -1.56352311e-04,  -1.12726474e-02,
                         -1.92570745e-03,   1.94359645e-02,   4.92146937e-03,
                          5.88673400e-03,   8.39400943e-03,  -1.57119725e-02,
                         -1.05623901e-02,  -5.55980531e-03,  -1.02573903e-02,
                         -6.67451834e-03,  -2.75970064e-02,  -1.25055090e-02,
                          2.42865700e-02,   5.84181910e-03,  -1.56257802e-03,
                         -7.47860922e-03,  -2.04275306e-02,   1.55096967e-02,
                          5.07945567e-03,  -2.22955253e-02,   1.91279370e-02,
                          1.24375932e-02,  -1.11639164e-02,   1.13247382e-02,
                          1.65862229e-03,   6.48108404e-03,   1.40896793e-02,
                         -1.83086284e-02,  -1.05763897e-02,  -5.68102999e-03,
                         -8.42793565e-03,   2.61772610e-02,   1.00861257e-02,
                         -3.75219900e-03,   2.76822709e-02,   1.29830400e-02,
                          2.40157195e-03,  -6.24034880e-03,  -3.74156944e-02,
                         -4.43722727e-03,   2.15179436e-02,   1.04738900e-03,
                          7.89456628e-03,   5.66233695e-03,   5.09457663e-03,
                          1.29056405e-02,   1.74175599e-03,   2.50577442e-02,
                          2.75151227e-02,  -1.08589968e-02,   1.20169099e-03,
                          1.48709286e-02,   1.45460025e-03,  -4.61033452e-03,
                         -5.64668735e-04,   1.83788519e-02,   1.09801413e-02,
                          8.29032436e-03,  -1.41903505e-01,  -6.06453598e-01,
                         -7.66421854e-01,  -3.00706625e-01,   4.76173423e-02,
                          4.13856916e-02,  -5.60848415e-03,  -1.72556974e-02,
                          1.03155293e-01,   1.77808814e-02,  -4.34255421e-01,
                         -4.69473392e-01,  -3.72835472e-02,   1.02751382e-01,
                         -1.26170116e-02,  -1.59945153e-03,   7.66374394e-02,
                          1.76312414e-03,  -5.77818900e-02,   1.30917728e-01,
                          8.06349271e-04,  -4.72175658e-01,  -3.66747797e-01,
                         -1.40215561e-01,  -4.53151256e-01,  -4.19162244e-01,
                          2.64118947e-02,   1.19562022e-01,   2.27115303e-02,
                         -2.35275790e-01,  -7.03941524e-01,  -7.37638235e-01,
                         -2.25599080e-01,   1.40777782e-01,  -5.88444173e-02,
                         -5.25233746e-01,  -7.27938414e-01,  -6.53122723e-01,
                         -5.84629953e-01,  -6.63001537e-01,  -7.54124105e-01,
                         -4.59341198e-01,  -8.15103948e-02,  -3.39461446e-01,
                         -7.49992907e-01,  -6.74469709e-01,  -5.80404639e-01,
                         -6.82756424e-01,  -6.79443777e-01,  -6.37860119e-01,
                         -6.54571414e-01,  -6.47694230e-01,  -6.28039360e-01,
                         -6.33721113e-01,  -6.66190028e-01,  -6.76663637e-01,
                         -6.48469567e-01,  -6.50329709e-01,  -6.68033183e-01,
                         -6.59215808e-01,  -6.62082374e-01,  -6.67889118e-01,
                         -6.57184899e-01,  -6.55086637e-01,  -6.39877021e-01,
                         -6.25122011e-01,  -6.54675007e-01,  -6.61827147e-01,
                         -6.37961090e-01,  -6.74187303e-01,  -7.09641755e-01,
                         -6.67806149e-01,  -6.30799055e-01,  -6.38133347e-01,
                         -6.53463185e-01,  -6.56701744e-01,  -6.48659945e-01,
                         -6.67749763e-01,  -6.87742889e-01,  -6.54168308e-01,
                         -6.36534274e-01,  -6.59342766e-01,  -6.49913013e-01,
                         -6.46620512e-01,  -6.92871571e-01,  -7.02929854e-01,
                         -6.60849094e-01,  -6.49053156e-01,  -6.53050184e-01,
                         -6.42887771e-01,  -6.68616176e-01,  -6.93364441e-01,
                         -6.62886441e-01,  -6.48744702e-01,  -6.66763246e-01,
                         -6.65864587e-01,  -6.70353413e-01,  -6.88620389e-01,
                         -6.83415234e-01,  -6.62174404e-01,  -6.59823239e-01,
                         -6.72377527e-01,  -6.70871437e-01,  -6.71903789e-01,
                         -6.93753541e-01,  -7.03341067e-01,  -6.88938320e-01,
                         -6.80610418e-01,  -6.87159479e-01,  -6.86283112e-01,
                         -6.95551157e-01,  -6.95999920e-01,  -6.36753321e-01,
                         -6.97416842e-01,  -8.13861132e-01,  -4.94846404e-01,
                         -1.04838312e-01,  -3.87819380e-01,  -7.86552072e-01,
                         -7.14521468e-01,  -6.37040138e-01,  -7.03720033e-01,
                         -6.98656082e-01,  -6.95311129e-01,  -6.93204761e-01,
                         -6.85158491e-01,  -7.21046746e-01,  -7.23129034e-01,
                         -6.83555484e-01,  -6.64800942e-01,  -6.91798329e-01,
                         -7.27754712e-01,  -7.09309757e-01,  -6.87256634e-01,
                         -6.98084593e-01,  -7.11828053e-01,  -7.27453053e-01,
                         -7.15742111e-01,  -6.97576642e-01,  -7.05800474e-01,
                         -7.23307967e-01,  -7.26870537e-01,  -6.60387814e-01,
                         -6.99671507e-01,  -8.60583425e-01,  -6.00594580e-01,
                         -1.39131978e-01,  -3.24296117e-01,  -7.63122261e-01,
                         -7.52903044e-01,  -6.75815761e-01,  -7.45905399e-01,
                         -6.94381833e-01,  -7.23029375e-01,  -8.14626634e-01,
                         -4.34924066e-01,  -6.54787645e-02,  -5.52985013e-01,
                         -9.55904782e-01,  -4.04428273e-01,  -1.14370085e-01,
                         -5.65273166e-01,  -5.24709523e-01,   3.96884158e-02,
                          3.07141691e-02,  -5.40287435e-01,  -8.21463704e-01,
                         -6.80678844e-01,  -7.14258373e-01,  -8.34391415e-01,
                         -4.39277083e-01,  -8.09720606e-02,  -5.44191182e-01,
                         -9.68352079e-01,  -5.11408567e-01,  -1.04952075e-01,
                         -4.51042831e-01,  -8.04740727e-01,  -7.86789954e-01,
                         -6.74303532e-01,  -3.37384164e-01,   5.00359572e-02,
                         -1.11179352e-01,  -6.28842652e-01,  -8.37484837e-01,
                         -5.67254543e-01,  -1.04314238e-01,   6.58951551e-02,
                         -3.41291875e-01,  -8.56928885e-01,  -7.66366243e-01,
                         -2.86853671e-01,  -4.03090678e-02,   4.44868058e-02,
                         -8.11664239e-02,  -5.27546704e-01,  -5.35471559e-01,
                         -1.54451340e-01,  -4.53984290e-01,  -9.45914030e-01,
                         -5.61965346e-01,  -7.20666721e-02,  -4.65001911e-01,
                         -9.40981388e-01,  -5.55388629e-01,  -1.50107786e-01,
                         -4.86451328e-01,  -5.93317628e-01,  -1.04921192e-01,
                          8.04460272e-02,  -1.04331441e-01,  -1.58389315e-01,
                         -7.98620563e-03,   1.68147851e-02,  -4.11090195e-01,
                         -6.39231086e-01,  -1.88664600e-01,   4.85057533e-02,
                         -1.37518540e-01,  -1.01686180e-01,  -1.04008159e-02,
                         -6.02997057e-02,  -6.36409298e-02,  -5.02318591e-02,
                         -5.07270098e-02,  -7.55613670e-02,  -3.99108939e-02,
                         -1.25504564e-02,  -4.33780909e-01,  -9.02406871e-01,
                         -5.81756890e-01,  -1.35071322e-01,  -4.40303683e-01,
                         -6.34462595e-01,  -7.25538433e-02,   1.14468962e-01,
                         -4.83026713e-01,  -6.06723309e-01,  -8.32578018e-02,
                          5.31866774e-02,  -1.18201651e-01,  -8.98248050e-03,
                          3.36852334e-02,  -4.14544880e-01,  -8.57226193e-01,
                         -6.55231655e-01,  -1.74867272e-01,   6.35382067e-03,
                          6.20312579e-02,  -7.17396960e-02,  -5.35833657e-01,
                         -5.34225404e-01,   6.38288856e-02,   8.03627819e-02,
                         -5.23807108e-01,  -5.46818078e-01,   1.87731686e-03,
                          1.04740456e-01,  -3.83029848e-01,  -7.85409927e-01,
                         -6.74724996e-01,  -2.16297269e-01,   1.25726610e-01,
                         -5.13688847e-02,  -6.60777867e-01,  -8.22724342e-01,
                         -2.63865262e-01,  -1.39479741e-01,  -5.18262804e-01,
                         -3.32871914e-01,  -1.47292808e-01,  -5.62720358e-01,
                         -7.78836548e-01,  -6.91655695e-01,  -4.68769997e-01,
                         -9.80507880e-02,  -3.25713009e-01,  -8.47748697e-01,
                         -5.24256051e-01,  -2.59735119e-02,  -3.40805322e-01,
                         -7.48443186e-01,  -6.31065369e-01,  -6.05787456e-01,
                         -7.69570589e-01,  -4.25471276e-01,  -4.11818922e-02,
                         -3.86925966e-01,  -7.61686385e-01,  -6.69941425e-01,
                         -5.67939758e-01,  -6.36363447e-01,  -7.53426909e-01,
                         -5.35883725e-01,  -8.47950429e-02,  -2.53333360e-01,
                         -7.21682012e-01,  -6.81301117e-01,  -5.86026609e-01,
                         -6.76875949e-01,  -6.51297092e-01,  -6.39155746e-01,
                         -6.41905189e-01,  -6.19807780e-01,  -6.54674232e-01,
                         -6.21163428e-01,  -6.28005624e-01,  -6.89371288e-01,
                         -5.83514988e-01,  -6.08949661e-01,  -7.55959928e-01,
                         -4.44540977e-01,  -6.97999522e-02,  -3.18594664e-01,
                         -6.72533453e-01,  -6.53161585e-01,  -6.22313976e-01,
                         -6.62175059e-01,  -6.05473220e-01,  -5.93832791e-01,
                         -6.43215120e-01,  -6.37553394e-01,  -6.24969661e-01,
                         -6.27563477e-01,  -6.28167331e-01,  -6.33180022e-01,
                         -6.35399222e-01,  -6.50181413e-01,  -6.50941432e-01,
                         -6.22332275e-01,  -6.10766411e-01,  -6.16892993e-01,
                         -6.37374163e-01,  -6.44082546e-01,  -6.08498454e-01,
                         -6.22096300e-01,  -6.75045967e-01,  -6.52392268e-01,
                         -6.07978225e-01,  -6.11002266e-01,  -6.24042928e-01,
                         -6.26372576e-01,  -6.18799865e-01,  -6.23057902e-01,
                         -6.35739982e-01,  -6.27243698e-01,  -6.24025226e-01,
                         -6.25433981e-01,  -6.12546086e-01,  -6.19875550e-01,
                         -6.33554876e-01,  -6.27108753e-01,  -6.25437260e-01,
                         -6.19996607e-01,  -6.11570001e-01,  -6.32388294e-01,
                         -6.45821095e-01,  -6.16575956e-01,  -6.08275771e-01,
                         -6.46015108e-01,  -6.53297603e-01,  -6.20686889e-01,
                         -6.10888600e-01,  -6.26890838e-01,  -6.37645125e-01,
                         -6.33484244e-01,  -6.40036583e-01,  -6.53301597e-01,
                         -6.22831404e-01,  -6.14881277e-01,  -6.62769020e-01,
                         -6.44769549e-01,  -6.15382612e-01,  -6.51133955e-01,
                         -6.40598357e-01,  -6.24357402e-01,  -6.51597202e-01,
                         -6.48804307e-01,  -6.45859063e-01,  -6.21846080e-01,
                         -6.16854370e-01,  -6.78336620e-01,  -6.32451355e-01,
                         -6.49808943e-01,  -7.73007393e-01,  -4.44793373e-01,
                         -3.75027545e-02,  -3.39539856e-01,  -7.45501935e-01,
                         -6.90535843e-01,  -6.28549278e-01,  -6.81660533e-01,
                         -6.62484527e-01,  -6.44739449e-01,  -6.60832584e-01,
                         -6.51948571e-01,  -6.31254792e-01,  -6.80766165e-01,
                         -6.92259431e-01,  -6.07491672e-01,  -7.10376978e-01,
                         -6.84006870e-01,  -1.54024169e-01,  -9.94750336e-02,
                         -7.62872040e-01,  -7.42146194e-01,  -6.78355470e-02,
                          6.87865764e-02,  -8.79522488e-02,   4.32125665e-03,
                          3.90663557e-02,  -2.16704365e-02,  -3.50420736e-03,
                         -1.10230381e-02,  -2.53363140e-02,   8.03821627e-03,
                          5.79080172e-03,  -6.18201075e-03,   7.24175014e-03,
                          1.88974687e-03,  -2.56394711e-03,  -1.30452705e-03,
                         -1.34561490e-02,  -8.39947164e-03,  -2.94431206e-03,
                         -1.83534790e-02,  -1.77558139e-02,  -2.45902874e-03,
                          4.86082537e-03,  -4.34534810e-03,  -1.97796002e-02,
                         -5.55967726e-03,   3.68634867e-03,  -2.43949797e-02,
                         -2.15599760e-02,   5.85274352e-03,  -3.17497225e-03,
                         -1.29398713e-02,   9.28246736e-05,   7.46795721e-03,
                         -2.55838898e-03,  -2.31995843e-02,  -2.01351214e-02,
                          2.68964097e-03,   2.30961246e-03,  -8.09783489e-03,
                         -1.27476705e-02,  -8.79729632e-03,   1.38772642e-02,
                          2.60314345e-03,  -4.50988226e-02,  -3.67183946e-02,
                          4.98214597e-03,   2.33693910e-03,  -6.11635298e-03,
                          3.47853056e-03,  -1.07005779e-02,  -3.40516940e-02,
                         -2.86222436e-02,  -9.14862007e-03,   1.99375208e-03,
                          2.43581878e-03,  -1.45220235e-02,  -3.20064425e-02,
                         -1.45460824e-02,   8.08385108e-03,  -1.26724336e-02,
                         -3.64659503e-02,  -1.39428582e-02,   2.12800428e-02,
                          2.20285524e-02,  -7.76110357e-03,  -3.45669314e-02,
                         -3.42965946e-02,  -9.44750104e-03,   1.56674758e-02,
                          2.03956217e-02,   5.14748460e-03,  -1.79775357e-02,
                         -1.71607751e-02,   1.39529500e-02,   1.07803317e-02,
                         -2.59336103e-02,  -1.78864244e-02,   9.48999729e-03,
                          4.93835239e-03,  -3.17077548e-03,  -6.53757993e-03,
                         -6.07113400e-03,  -1.09366525e-03,  -9.80074704e-03,
                         -1.39647871e-02,  -7.36329518e-03,   3.86395701e-03,
                          2.32347436e-02,   1.05053820e-02,  -1.26398690e-02,
                         -4.86388453e-04,  -4.47789719e-03,  -1.22213494e-02,
                          7.24604260e-03,   5.69933886e-03,   5.30071324e-03,
                          7.14423181e-03,  -1.53625067e-02,   3.15892219e-04,
                          2.09288318e-02,  -4.82122833e-03,  -2.88317120e-03,
                          1.60118788e-02,   9.58452001e-03,   1.17082587e-02,
                          1.17149381e-02,  -2.12271372e-03,  -4.72433539e-03,
                          1.35355350e-02,   2.63134148e-02,   4.73295292e-03,
                          2.70304794e-04,   1.66640542e-02,  -7.52419652e-03,
                         -1.29345376e-02,   1.39208650e-02,   6.66944077e-03,
                          3.97888664e-03,   5.17690973e-03,  -2.38702772e-03,
                          2.08601467e-02,   1.74184088e-02,  -7.08107278e-03,
                          1.06789535e-02,   1.58328135e-02,   2.65470543e-03,
                         -3.57330922e-04,   2.85105489e-04,   2.32197344e-02,
                          1.88979488e-02,  -1.07620070e-02,   2.71469308e-03,
                          1.00914594e-02,   1.33378878e-02,   3.71250473e-02,
                          1.61469765e-02,  -3.19518684e-03,   1.42375100e-02,
                          1.63765308e-02,   2.16411389e-02,   1.43373990e-02,
                         -3.18834721e-03,   1.37955239e-02,   1.31614171e-02,
                          5.26345521e-03,   2.50544753e-02,   2.14349069e-02,
                          1.02377040e-02,  -3.81197850e-03,  -1.28139853e-02,
                          3.73358615e-02,   5.40998839e-02,   4.58161440e-03,
                         -5.95935970e-04,   9.21917986e-03,   6.90897461e-03,
                          2.81374399e-02,   2.48566214e-02,   8.14263802e-03,
                          1.54071813e-02,   1.10600078e-02,  -1.73933734e-03,
                          3.06904479e-03,   2.31286716e-02,   3.07350568e-02,
                          1.11967539e-02,   2.52915593e-03,   1.00405216e-02,
                          1.57529321e-02,   1.94102712e-02,   4.43205377e-03,
                         -5.25949849e-03,   2.52668909e-03,   2.67174863e-03,
                          1.31687531e-02,   1.90751255e-02,   2.11213846e-02,
                          3.66265662e-02,   4.37618280e-03,  -1.98801458e-02,
                          1.74745843e-02,   6.57195458e-03,  -1.22239757e-02,
                          2.32206322e-02,   2.94444505e-02,   1.96211170e-02,
                          6.06773794e-03,  -1.24012958e-02,   5.22813527e-04,
                         -6.34914357e-03,   3.95870395e-03,   4.55989391e-02,
                          1.58909597e-02,  -1.08767925e-02,  -3.83584527e-04,
                         -4.45731403e-03,   7.93006178e-03,  -3.25019308e-03,
                          5.61180012e-03,  -1.31048977e-01,  -6.19278312e-01,
                         -7.72860229e-01,  -2.82427788e-01,   4.38935123e-02,
                          4.35367711e-02,   1.74214051e-03,  -5.19838035e-02,
                          8.90252814e-02,   3.52736302e-02,  -4.51104969e-01,
                         -4.88312453e-01,  -3.39934342e-02,   1.08643584e-01,
                         -1.23808412e-02,  -3.73330899e-02,   3.60015072e-02,
                          2.48888653e-04,  -5.36646582e-02,   1.34923577e-01,
                         -1.91388617e-03,  -5.00896096e-01,  -3.76827925e-01,
                         -1.32005289e-01,  -4.70420241e-01,  -4.43931818e-01,
                          1.12068933e-02,   9.82808843e-02,  -5.04136458e-03,
                         -2.39126489e-01,  -6.80120945e-01,  -7.35562623e-01,
                         -2.40135670e-01,   1.30450368e-01,  -1.00166097e-01,
                         -5.62571585e-01,  -7.29296565e-01,  -6.72364175e-01,
                         -6.03324771e-01,  -6.63543880e-01,  -7.87161589e-01,
                         -4.88013327e-01,  -7.31385201e-02,  -3.49693775e-01,
                         -7.81254351e-01,  -6.97401166e-01,  -5.90832353e-01,
                         -6.72126293e-01,  -6.74785495e-01,  -6.50096297e-01,
                         -6.39977336e-01,  -6.35587215e-01,  -6.68595850e-01,
                         -6.69439793e-01,  -6.54558003e-01,  -6.59732103e-01,
                         -6.59783483e-01,  -6.74786270e-01,  -6.62425816e-01,
                         -6.36531651e-01,  -6.67151630e-01,  -6.69706583e-01,
                         -6.47756159e-01,  -6.77372813e-01,  -6.74930334e-01,
                         -6.40394688e-01,  -6.48246884e-01,  -6.69469893e-01,
                         -6.75585747e-01,  -6.54554486e-01,  -6.51159167e-01,
                         -6.85019016e-01,  -6.62336826e-01,  -6.30129516e-01,
                         -6.61683977e-01,  -6.70397878e-01,  -6.52690172e-01,
                         -6.43615007e-01,  -6.43722236e-01,  -6.71641409e-01,
                         -6.75950289e-01,  -6.71267807e-01,  -6.81241632e-01,
                         -6.47984266e-01,  -6.53932035e-01,  -6.95110619e-01,
                         -6.59533262e-01,  -6.50661647e-01,  -6.81353092e-01,
                         -6.60477281e-01,  -6.64730132e-01,  -6.93175137e-01,
                         -6.90937281e-01,  -6.79793894e-01,  -6.58370674e-01,
                         -6.55254185e-01,  -6.68882310e-01,  -6.69603229e-01,
                         -6.77773058e-01,  -6.80353224e-01,  -6.86177313e-01,
                         -6.89843833e-01,  -6.55399442e-01,  -6.47013962e-01,
                         -6.76734090e-01,  -6.91900611e-01,  -6.98236644e-01,
                         -6.93233430e-01,  -6.83522701e-01,  -6.61136806e-01,
                         -6.62126720e-01,  -7.03216910e-01,  -6.68773770e-01,
                         -7.09335387e-01,  -8.16750109e-01,  -4.95357752e-01,
                         -1.07654512e-01,  -3.79412144e-01,  -7.56101429e-01,
                         -7.08686888e-01,  -6.54381275e-01,  -7.22253263e-01,
                         -7.22967923e-01,  -6.83510780e-01,  -6.70708895e-01,
                         -7.12582052e-01,  -7.38112032e-01,  -6.92460716e-01,
                         -6.72640145e-01,  -7.10967839e-01,  -7.33411729e-01,
                         -7.21724808e-01,  -7.15252757e-01,  -6.99096262e-01,
                         -6.86454773e-01,  -7.44587123e-01,  -7.50332296e-01,
                         -6.65454268e-01,  -6.84922457e-01,  -7.35812485e-01,
                         -7.34459221e-01,  -7.50618994e-01,  -6.70493662e-01,
                         -6.71453834e-01,  -8.29967380e-01,  -5.77971935e-01,
                         -1.38121560e-01,  -3.41659606e-01,  -7.78813183e-01,
                         -7.67495811e-01,  -6.87144756e-01,  -7.61706889e-01,
                         -7.02061653e-01,  -7.03638613e-01,  -8.04470837e-01,
                         -4.60309505e-01,  -1.06382340e-01,  -5.69414318e-01,
                         -9.38181818e-01,  -3.90668660e-01,  -1.05571970e-01,
                         -5.73545992e-01,  -5.69715023e-01,   2.39622369e-02,
                          2.85149068e-02,  -5.80070138e-01,  -8.23566020e-01,
                         -6.57321870e-01,  -7.27937758e-01,  -8.57108414e-01,
                         -4.79963928e-01,  -9.89445001e-02,  -4.93334800e-01,
                         -9.35241103e-01,  -5.12905478e-01,  -1.09668002e-01,
                         -4.64415759e-01,  -7.93401003e-01,  -8.01116288e-01,
                         -7.42189884e-01,  -3.55108023e-01,   8.43365714e-02,
                         -8.10863599e-02,  -6.26843572e-01,  -8.76762688e-01,
                         -5.68089604e-01,  -7.38698393e-02,   3.26001532e-02,
                         -3.75419170e-01,  -8.42760146e-01,  -7.45160937e-01,
                         -2.68996239e-01,  -5.16497940e-02,   2.75296997e-02,
                         -8.33334699e-02,  -5.56293607e-01,  -5.38557291e-01,
                         -1.13257520e-01,  -4.43200380e-01,  -9.62352276e-01,
                         -5.79662383e-01,  -6.34161681e-02,  -4.39210981e-01,
                         -9.70433354e-01,  -5.84821463e-01,  -1.25522658e-01,
                         -4.95531887e-01,  -6.41255677e-01,  -1.30265191e-01,
                          8.94841030e-02,  -7.64468908e-02,  -1.39782131e-01,
                          1.66910291e-02,   4.14928831e-02,  -4.22315627e-01,
                         -6.70486748e-01,  -2.37729460e-01,   3.56850401e-02,
                         -6.84501603e-02,  -7.17464685e-02,  -4.84479107e-02,
                         -7.11397380e-02,  -5.51292039e-02,  -4.71204929e-02,
                         -6.45219088e-02,  -8.58109891e-02,   4.44587739e-03,
                          8.82942788e-03,  -4.86642599e-01,  -9.49267745e-01,
                         -5.84146023e-01,  -9.31977928e-02,  -4.08203661e-01,
                         -6.63677037e-01,  -8.35011974e-02,   1.49819553e-01,
                         -4.75730807e-01,  -6.31568551e-01,  -9.12832990e-02,
                          7.39034638e-02,  -1.08898893e-01,  -9.64298565e-03,
                          6.23544380e-02,  -4.02489573e-01,  -8.82312536e-01,
                         -6.55948400e-01,  -1.52683333e-01,   1.97203010e-02,
                          7.17502981e-02,  -6.65459484e-02,  -5.45928955e-01,
                         -5.45700788e-01,   6.69069663e-02,   6.77283704e-02,
                         -5.52854836e-01,  -5.61375380e-01,  -5.61247254e-03,
                          1.22932270e-01,  -3.64765197e-01,  -8.09774697e-01,
                         -6.64005816e-01,  -1.89689472e-01,   9.49463099e-02,
                         -7.22817928e-02,  -6.69242501e-01,  -8.29256773e-01,
                         -2.48523787e-01,  -1.67095140e-01,  -5.37912846e-01,
                         -3.07606131e-01,  -1.56654805e-01,  -5.63211858e-01,
                         -7.79515386e-01,  -7.13078499e-01,  -4.22072291e-01,
                         -7.58101568e-02,  -3.72933805e-01,  -8.42536390e-01,
                         -5.01744390e-01,  -1.03599057e-02,  -3.08974653e-01,
                         -7.56198585e-01,  -6.55461133e-01,  -6.19192481e-01,
                         -7.68085420e-01,  -3.99664849e-01,  -4.72597554e-02,
                         -3.90306145e-01,  -7.17701197e-01,  -6.49235308e-01,
                         -5.73086977e-01,  -6.53139174e-01,  -7.78835237e-01,
                         -5.32528698e-01,  -7.71483034e-02,  -2.31973544e-01,
                         -6.79338157e-01,  -6.70625925e-01,  -5.69087148e-01,
                         -6.54434264e-01,  -6.57161236e-01,  -6.18983150e-01,
                         -6.30074263e-01,  -6.23626411e-01,  -6.11103654e-01,
                         -6.08993888e-01,  -6.51647687e-01,  -6.74347162e-01,
                         -5.89222133e-01,  -6.23471975e-01,  -7.30716109e-01,
                         -4.27824944e-01,  -4.53020744e-02,  -2.96096116e-01,
                         -7.06234515e-01,  -6.65078402e-01,  -5.77566028e-01,
                         -6.48354352e-01,  -6.27788484e-01,  -5.90797842e-01,
                         -6.06803179e-01,  -6.26031756e-01,  -6.69670284e-01,
                         -6.39509082e-01,  -5.70449173e-01,  -6.10253215e-01,
                         -6.52253807e-01,  -6.33083940e-01,  -6.30183399e-01,
                         -6.30419672e-01,  -6.41446590e-01,  -6.46223485e-01,
                         -6.01143003e-01,  -5.88982344e-01,  -6.22330010e-01,
                         -6.27383709e-01,  -6.28374159e-01,  -6.32969856e-01,
                         -6.21389151e-01,  -6.11528158e-01,  -5.95939398e-01,
                         -6.08618140e-01,  -6.59389675e-01,  -6.38781250e-01,
                         -5.75303972e-01,  -6.06070280e-01,  -6.53595030e-01,
                         -6.21754229e-01,  -6.05046690e-01,  -6.34747982e-01,
                         -6.44351065e-01,  -6.27203047e-01,  -6.15136981e-01,
                         -6.38289869e-01,  -6.52204871e-01,  -6.11748040e-01,
                         -6.12625241e-01,  -6.59818470e-01,  -6.38522923e-01,
                         -6.03725970e-01,  -6.26574337e-01,  -6.47674143e-01,
                         -6.50716484e-01,  -6.39666855e-01,  -6.13196015e-01,
                         -6.11824214e-01,  -6.39061809e-01,  -6.53500378e-01,
                         -6.37703478e-01,  -6.28918350e-01,  -6.36124432e-01,
                         -6.17636383e-01,  -6.14941359e-01,  -6.41608119e-01,
                         -6.40569925e-01,  -6.52017713e-01,  -6.51285350e-01,
                         -6.09942794e-01,  -6.38800919e-01,  -6.75086975e-01,
                         -6.57876313e-01,  -6.60032988e-01,  -6.19173050e-01,
                         -6.59789979e-01,  -7.53010213e-01,  -4.27392185e-01,
                         -6.03500344e-02,  -3.68761152e-01,  -7.60210395e-01,
                         -6.68833077e-01,  -5.86596668e-01,  -6.80306137e-01,
                         -6.78422987e-01,  -6.37714803e-01,  -6.57804787e-01,
                         -6.71607733e-01,  -6.53976619e-01,  -6.58770084e-01,
                         -6.51670158e-01,  -6.29388094e-01,  -7.37122893e-01,
                         -6.66898191e-01,  -1.66205913e-01,  -1.10201418e-01,
                         -7.31511652e-01,  -7.39769042e-01,  -7.99056068e-02,
                          9.91957262e-02,  -5.01188673e-02,   4.16054763e-03,
                          1.17854979e-02,  -3.27019803e-02,   4.10754373e-03,
                          4.78751026e-03,   1.61477756e-02,   2.75293309e-02,
                         -1.92915294e-02,   2.74482300e-03,   4.64350171e-02,
                          8.96953791e-03,  -2.20598355e-02,  -1.31039442e-02,
                          2.56443899e-02,   5.38403764e-02,   5.38434368e-03,
                         -1.93594452e-02,   1.74383521e-02,  -5.74487785e-04,
                         -2.68576778e-02,   7.49879191e-03,   2.66297087e-02,
                          1.19966632e-02,   2.90117553e-03,   4.53474559e-03,
                          8.46799649e-03,   1.34157678e-02,   2.30079927e-02,
                          4.24943166e-03,  -2.89476495e-02,  -6.95042964e-03,
                          1.59089155e-02,  -1.33776767e-02,  -2.17841957e-02,
                         -5.95263205e-03,   8.01912276e-04,   9.95000359e-03,
                         -4.48729988e-04,  -7.90585857e-03,   1.09083969e-02,
                         -8.47483636e-04,  -3.54899727e-02,  -3.79811153e-02,
                         -4.94697038e-03,   2.19746195e-02,   1.07140013e-03,
                         -6.89266808e-03,   2.04519425e-02,  -4.17275308e-03,
                         -1.81493610e-02,   3.09459344e-02,   2.06359737e-02,
                         -2.70999018e-02,  -1.84412915e-02,   4.53479355e-03,
                          4.44433931e-03,  -2.20330842e-02,  -3.04967724e-02,
                          5.34109492e-03,   1.00706834e-02,   1.04958350e-02,
                          3.72294523e-02,   2.16969452e-03,  -3.33222449e-02,
                         -4.24007699e-03,   3.77957383e-03,  -4.39554872e-03,
                         -5.30663971e-03,  -1.54129956e-02,  -6.97237393e-03,
                          8.95537843e-04,   3.66988219e-03,   1.32049862e-02,
                         -4.10631020e-03,  -1.35592734e-02,  -5.35873044e-03,
                         -2.09236741e-02,  -2.08973400e-02,  -5.59671098e-05,
                          8.13690294e-03,   9.47301835e-03,   1.11674727e-03,
                          4.42290737e-04,   1.92093407e-03,  -1.13844695e-02,
                         -1.27732996e-02,  -1.66501030e-02,  -3.74370953e-03,
                          3.57095934e-02,   1.93891115e-02,  -3.62713006e-03,
                          9.55253188e-03,  -1.41012445e-02,  -8.05620477e-03,
                          2.81902831e-02,   6.77669747e-03,   5.87462448e-03,
                          1.48256933e-02,  -1.50446445e-02,  -6.05269708e-03,
                          6.39139907e-03,   7.32201617e-04,   1.09668300e-02,
                         -5.37450844e-03,  -1.53421002e-04,   1.88465323e-02,
                         -1.49270557e-02,  -9.12987906e-03,   1.34548359e-02,
                         -1.86268762e-02,  -1.96332745e-02,  -5.56605216e-03,
                         -8.52912199e-03,  -4.31507360e-03,  -2.45347209e-02,
                         -8.77402164e-03,   3.74526307e-02,   1.30206505e-02,
                         -8.38167500e-03,   7.89945200e-03,  -7.57482927e-03,
                         -2.71063261e-02,  -2.05231905e-02,   6.73863851e-03,
                          1.78137999e-02,   6.13334822e-03,   3.41211483e-02,
                          4.04827520e-02,   2.34504423e-05,   6.81845658e-03,
                         -1.56344299e-03,  -3.35425921e-02,  -6.15212135e-03,
                          8.89338844e-04,  -1.16137834e-02,   4.72827582e-03,
                         -1.02536101e-02,  -1.11927167e-02,   1.46234818e-02,
                          1.35384663e-03,  -1.04742113e-03,   5.65634621e-03,
                         -1.58115737e-02,  -9.93643608e-03,   1.63868945e-02,
                          1.15234582e-02,  -6.33222843e-03,  -1.30962080e-03,
                          1.89950189e-03,  -2.11386848e-02,  -1.56426150e-02,
                          7.41517730e-03,  -5.32576535e-03,  -7.09928526e-03,
                         -3.53954313e-03,  -1.09195132e-02,   1.65839326e-02,
                          2.38604415e-02,  -6.52069692e-03,  -1.55452248e-02,
                         -1.78567916e-02,  -4.56577260e-03,   1.07472390e-02,
                         -3.88437998e-04,   6.63301535e-03,  -4.49947361e-03,
                         -3.23938243e-02,  -2.22984236e-03,   1.57768782e-02,
                         -7.79502967e-04,   7.38687348e-03,   1.10555226e-02,
                          1.23370793e-02,   9.07126907e-03,  -5.74252335e-03,
                          5.07159065e-03,   2.14936770e-03,   1.57845183e-03,
                          3.25779505e-02,   1.51870130e-02,  -1.75843085e-03,
                          1.30642196e-02,  -1.28222825e-02,  -7.76156830e-03,
                          1.74867585e-02,  -1.86663284e-03,   1.47695988e-02,
                          2.17133164e-02,  -5.19054104e-03,   2.14634500e-02,
                          2.52062157e-02,  -3.02821468e-03,   1.97315286e-03,
                         -7.71175185e-03,  -9.96462815e-03,   1.64241362e-02,
                          3.22087184e-02,  -1.29486397e-01,  -5.81876934e-01,
                         -7.59203911e-01,  -3.24982584e-01,   3.30464169e-02,
                          4.14370783e-02,   3.23343812e-03,  -2.16625221e-02,
                          8.59937817e-02,   3.01880240e-02,  -4.36717749e-01,
                         -5.14141619e-01,  -6.21596277e-02,   1.00118190e-01,
                         -1.26263658e-02,  -1.25871375e-02,   5.98646551e-02,
                          2.36841142e-02,  -5.20173609e-02,   1.04386799e-01,
                          1.79336779e-02,  -4.83368009e-01,  -4.21377361e-01,
                         -1.38401747e-01,  -4.46257502e-01,  -4.38305587e-01,
                          6.43178076e-03,   6.46723211e-02,  -1.10361241e-02,
                         -2.02470168e-01,  -6.65309966e-01,  -7.36154735e-01,
                         -2.62746096e-01,   1.21887922e-01,  -4.53257822e-02,
                         -5.30693054e-01,  -7.34974563e-01,  -6.76227093e-01,
                         -6.43727541e-01,  -6.93636060e-01,  -7.64691412e-01,
                         -4.73611176e-01,  -7.88414627e-02,  -3.35578591e-01,
                         -7.42936790e-01,  -6.96790338e-01,  -6.40667260e-01,
                         -6.87437236e-01,  -6.64017737e-01,  -6.68936133e-01,
                         -6.59251392e-01,  -6.58628404e-01,  -7.01347947e-01,
                         -6.58317924e-01,  -6.26930475e-01,  -6.82007909e-01,
                         -6.74919486e-01,  -6.46584153e-01,  -6.75958097e-01,
                         -6.66134298e-01,  -6.50323570e-01,  -6.74329817e-01,
                         -6.48748279e-01,  -6.49211943e-01,  -6.97835922e-01,
                         -6.60116076e-01,  -6.40452623e-01,  -6.78659260e-01,
                         -6.53924465e-01,  -6.48280919e-01,  -6.68375432e-01,
                         -6.65744364e-01,  -6.78858817e-01,  -6.46983206e-01,
                         -6.48876488e-01,  -7.04951644e-01,  -6.58698678e-01,
                         -6.33204222e-01,  -6.68711126e-01,  -6.62665308e-01,
                         -6.91967964e-01,  -6.67725563e-01,  -6.13189757e-01,
                         -6.78861618e-01,  -6.79404616e-01,  -6.33265615e-01,
                         -6.78888142e-01,  -6.71735168e-01,  -6.57696009e-01,
                         -6.91212893e-01,  -6.74443960e-01,  -6.68904543e-01,
                         -6.76890254e-01,  -6.66071355e-01,  -6.70641303e-01,
                         -6.70715392e-01,  -6.83817983e-01,  -6.77961648e-01,
                         -6.46761119e-01,  -6.69458866e-01,  -6.80493057e-01,
                         -6.64580524e-01,  -6.73874855e-01,  -6.58291996e-01,
                         -6.59479141e-01,  -6.82837129e-01,  -6.66133940e-01,
                         -6.73996747e-01,  -6.84357107e-01,  -6.54228270e-01,
                         -6.83701217e-01,  -7.09927320e-01,  -6.29700661e-01,
                         -6.65049732e-01,  -7.86287725e-01,  -5.05714655e-01,
                         -1.24934353e-01,  -3.84183913e-01,  -7.80306160e-01,
                         -7.09550321e-01,  -6.43683136e-01,  -7.09464729e-01,
                         -6.60454094e-01,  -6.61656439e-01,  -7.18890250e-01,
                         -7.29412079e-01,  -7.18343079e-01,  -6.63169563e-01,
                         -6.65940166e-01,  -7.28781581e-01,  -7.02015340e-01,
                         -6.58050179e-01,  -6.99436009e-01,  -7.44089723e-01,
                         -7.01720536e-01,  -6.59792960e-01,  -7.05240309e-01,
                         -7.11752117e-01,  -6.66440606e-01,  -6.76207125e-01,
                         -7.24290729e-01,  -7.63536632e-01,  -6.96841061e-01,
                         -6.72722101e-01,  -8.05262864e-01,  -5.73135018e-01,
                         -1.26110047e-01,  -3.38804603e-01,  -7.95056760e-01,
                         -7.57829249e-01,  -6.70515716e-01,  -7.26666212e-01,
                         -6.51979506e-01,  -7.14553773e-01,  -8.38894010e-01,
                         -4.57836598e-01,  -1.04714558e-01,  -5.65312028e-01,
                         -9.08264935e-01,  -3.88101608e-01,  -1.48368642e-01,
                         -5.66810489e-01,  -4.94512200e-01,   6.17493093e-02,
                          2.47399937e-02,  -5.74432850e-01,  -8.13831627e-01,
                         -6.13191485e-01,  -6.74291611e-01,  -8.61964107e-01,
                         -5.00542104e-01,  -1.02108054e-01,  -4.86065358e-01,
                         -9.06947196e-01,  -5.06891131e-01,  -1.33716375e-01,
                         -4.72078562e-01,  -7.92556822e-01,  -7.80226469e-01,
                         -6.88841283e-01,  -3.30332994e-01,   6.43119738e-02,
                         -9.53675210e-02,  -6.18245959e-01,  -8.68394315e-01,
                         -5.73741257e-01,  -8.05236623e-02,   2.68159509e-02,
                         -3.79025787e-01,  -8.25851619e-01,  -7.35140800e-01,
                         -2.80613124e-01,  -2.97782980e-02,   7.67587274e-02,
                         -6.44736961e-02,  -5.63285947e-01,  -5.43824613e-01,
                         -1.03391513e-01,  -4.27603275e-01,  -9.56159949e-01,
                         -5.72302938e-01,  -7.22034201e-02,  -4.53882933e-01,
                         -9.38749671e-01,  -5.55894554e-01,  -1.22657061e-01,
                         -4.49243039e-01,  -5.92904449e-01,  -1.29286945e-01,
                          8.52951854e-02,  -8.52519721e-02,  -1.61521137e-01,
                         -2.95938179e-02,  -2.10003201e-02,  -4.15159672e-01,
                         -6.19794071e-01,  -2.28872657e-01,   4.72870022e-02,
                         -6.40031174e-02,  -1.20524384e-01,  -6.44686967e-02,
                         -2.71358471e-02,  -2.81233285e-02,  -4.81577925e-02,
                         -6.62598684e-02,  -6.86084330e-02,   4.16951440e-02,
                          1.32995090e-02,  -5.13713777e-01,  -9.26127791e-01,
                         -5.36123753e-01,  -1.04950488e-01,  -4.25524771e-01,
                         -6.25793695e-01,  -6.24214262e-02,   1.21188559e-01,
                         -4.86026555e-01,  -6.21464372e-01,  -1.12850450e-01,
                          6.31346628e-02,  -8.15056339e-02,  -2.72471886e-02,
                          9.03341826e-03,  -3.99525911e-01,  -8.45323265e-01,
                         -6.53051078e-01,  -1.91425472e-01,  -1.70458127e-02,
                          5.92571571e-02,  -7.95180649e-02,  -5.30434430e-01,
                         -5.07550895e-01,   6.30567968e-02,   6.66611195e-02,
                         -5.34712970e-01,  -5.51546752e-01,   2.84416545e-02,
                          1.24697670e-01,  -3.91930223e-01,  -7.97729015e-01,
                         -6.83938563e-01,  -2.04024687e-01,   1.23451397e-01,
                         -1.01698808e-01,  -6.78179681e-01,  -8.00563931e-01,
                         -2.77362943e-01,  -1.60854504e-01,  -5.11924863e-01,
                         -3.28941494e-01,  -1.41576454e-01,  -5.39273202e-01,
                         -7.77499914e-01,  -7.16220379e-01,  -4.62451190e-01,
                         -8.74594674e-02,  -3.48093122e-01,  -8.49567771e-01,
                         -5.11822939e-01,  -2.44650431e-02,  -3.21594238e-01,
                         -7.47312605e-01,  -6.60290062e-01,  -6.14478588e-01,
                         -7.65807509e-01,  -4.33078289e-01,  -5.31305335e-02,
                         -3.73994082e-01,  -7.34395981e-01,  -6.90182030e-01,
                         -6.02323413e-01,  -6.47880137e-01,  -7.74156153e-01,
                         -5.26886165e-01,  -6.20392188e-02,  -2.68155456e-01,
                         -7.28648961e-01,  -7.01403022e-01,  -6.11650884e-01,
                         -6.40024126e-01,  -6.22998297e-01,  -6.46144331e-01,
                         -6.38332367e-01,  -6.24555528e-01,  -6.57209754e-01,
                         -6.39109075e-01,  -6.44505680e-01,  -6.39250755e-01,
                         -5.77829599e-01,  -6.84475422e-01,  -7.70571530e-01,
                         -4.09027755e-01,  -5.20223267e-02,  -3.28575253e-01,
                         -7.21547544e-01,  -6.79360271e-01,  -6.07311130e-01,
                         -6.69535279e-01,  -6.33244991e-01,  -6.12070978e-01,
                         -6.41978204e-01,  -6.33028448e-01,  -6.37235403e-01,
                         -6.23889685e-01,  -6.04775667e-01,  -6.29419386e-01,
                         -6.38802707e-01,  -6.37325227e-01,  -6.47379577e-01,
                         -6.48266077e-01,  -6.32146537e-01,  -6.08847976e-01,
                         -6.19172394e-01,  -6.39977574e-01,  -6.37791753e-01,
                         -6.35401011e-01,  -6.30336523e-01,  -6.42379522e-01,
                         -6.47067070e-01,  -6.13661051e-01,  -6.18682683e-01,
                         -6.37955189e-01,  -6.26900196e-01,  -6.31702960e-01,
                         -6.20692849e-01,  -6.13856852e-01,  -6.45032644e-01,
                         -6.46376133e-01,  -6.29596174e-01,  -6.17767274e-01,
                         -6.13392413e-01,  -6.30322576e-01,  -6.18800044e-01,
                         -6.20953739e-01,  -6.67054534e-01,  -6.55564725e-01,
                         -6.15243137e-01,  -6.22462928e-01,  -6.46605730e-01,
                         -6.44202828e-01,  -6.10824049e-01,  -6.22093976e-01,
                         -6.62762463e-01,  -6.40101612e-01,  -6.29933119e-01,
                         -6.59403801e-01,  -6.47404075e-01,  -6.36914551e-01,
                         -6.46377385e-01,  -6.32555068e-01,  -6.26463950e-01,
                         -6.42703414e-01,  -6.52487099e-01,  -6.50781274e-01,
                         -6.37196064e-01,  -6.16508842e-01,  -6.40056789e-01,
                         -6.91601872e-01,  -6.58815861e-01,  -6.14132643e-01,
                         -6.83259547e-01,  -6.96974754e-01,  -5.96284866e-01,
                         -6.60232186e-01,  -7.81004548e-01,  -4.79173094e-01,
                         -8.47022608e-02,  -3.25487405e-01,  -7.51342714e-01,
                         -7.12985098e-01,  -6.30760968e-01,  -6.97489917e-01,
                         -6.64966226e-01,  -6.64878011e-01,  -6.75031781e-01,
                         -6.25986397e-01,  -6.62266791e-01,  -6.90719962e-01,
                         -6.44804657e-01,  -6.29279077e-01,  -7.26868868e-01,
                         -6.83630943e-01,  -1.87355727e-01,  -7.70405382e-02,
                         -7.47643173e-01,  -7.72124171e-01,  -7.39328861e-02,
                          6.91723526e-02,  -4.95606363e-02,   2.13427544e-02,
                         -1.23190107e-02,  -2.79840995e-02,  -2.01436095e-02,
                         -3.19656618e-02,   2.85487846e-02,  -5.97196631e-03,
                         -3.07038054e-02,   3.01964339e-02,  -3.69395735e-03,
                         -2.41669156e-02,  -1.91779137e-02,  -3.12497504e-02,
                          2.11982708e-02,   1.67811625e-02,  -1.02502787e-02,
                          1.89370979e-02,   3.74221988e-03,   6.66415459e-03,
                          9.58114024e-03,  -1.52961118e-02,   2.58186664e-02,
                          2.43722033e-02,  -9.96558927e-03,   5.58918249e-03,
                         -1.75013505e-02,  -1.31495958e-02,   2.02282649e-02,
                          3.90618062e-03,   1.19049279e-02,  -2.65867799e-04,
                         -1.82434991e-02,   2.10586265e-02,   8.27222411e-03,
                         -2.09404127e-04,   2.59802081e-02,  -1.29509717e-02,
                         -1.71436034e-02,   1.11556994e-02,  -3.86165036e-03,
                          6.92757173e-03,   3.04051652e-03,  -1.92787629e-02,
                         -9.05861426e-03,  -1.61538627e-02,   3.85412201e-03,
                          3.23989987e-02,  -1.04758283e-02,  -2.48537064e-02,
                          1.35544839e-03,  -3.71761597e-03,   2.63417023e-04,
                          1.30360760e-02,   1.57584418e-02,   6.43629767e-03,
                         -1.66038275e-02,  -4.81834542e-03,   8.42769537e-03,
                         -1.12415878e-02,   6.58154953e-03,   2.53831986e-02,
                         -3.53678805e-03,  -7.28360517e-03,   8.75566527e-03,
                         -2.85249646e-03,  -1.16337901e-02,  -8.31145211e-04,
                          1.13929268e-02,   7.65668182e-03,  -9.56289563e-03,
                         -1.73940137e-02,  -1.05948746e-02,   9.50868987e-03,
                          2.50434559e-02,   6.21717051e-03,  -1.18259434e-02,
                          1.84337457e-03,   9.80566535e-03,   5.57787390e-03,
                         -4.91635967e-03,  -1.75189227e-02,   7.57157803e-03,
                          2.05151178e-02,  -1.73807032e-02,  -4.55468800e-03,
                          2.16313191e-02,  -2.22956054e-02,  -1.64546985e-02,
                          3.00816167e-02,   1.39267119e-02,   1.14580086e-02,
                          1.20386314e-02,  -1.83311179e-02,   7.59400334e-03,
                          2.14365236e-02,  -1.89121105e-02,  -1.29527980e-02,
                          5.46326442e-03,   8.72295629e-03,   1.90078337e-02,
                         -5.36585879e-03,  -2.60124840e-02,  -1.65629163e-02,
                         -4.02604369e-03,   2.10576653e-02,   1.57149360e-02,
                          1.82961510e-03,   2.50065010e-02,   9.01744794e-03,
                         -1.78518426e-02,  -3.85408988e-03,  -2.93808104e-03,
                          7.16181984e-03,   1.77548360e-02,  -7.86070363e-04,
                          6.53665105e-04,   7.19062006e-03,   2.00241804e-02,
                          2.89138351e-02,  -1.52060427e-02,  -1.64333787e-02,
                          2.39154156e-02,   4.04102076e-03,  -5.86725597e-04,
                          1.60031971e-02,   1.37149857e-03,   1.44729600e-03,
                         -6.26956578e-03,  -8.12577084e-03,   1.32713169e-02,
                         -5.32264169e-03,  -4.80288779e-03,   2.59799678e-02,
                          5.14102913e-03,  -1.93037521e-02,  -1.87345166e-02,
                         -9.68625024e-03,   6.54711062e-03,   5.65839652e-03,
                          2.42776647e-02,   4.05560844e-02,   8.45172256e-03,
                          1.98694458e-03,  -1.30263693e-03,  -3.08611840e-02,
                         -1.19443648e-02,   5.84201142e-03,  -9.77484602e-03,
                         -8.69604584e-04,   1.42634120e-02,   1.62320156e-02,
                          2.32758466e-04,  -4.63843020e-03,   2.68151965e-02,
                          1.47865620e-02,  -9.37626883e-03,   1.71363316e-02,
                         -1.10221887e-03,  -3.67481746e-02,  -1.53878797e-02,
                          3.15856957e-03,   1.54034812e-02,   1.59930903e-02,
                         -6.00619661e-03,  -1.87369680e-03,  -8.08335468e-03,
                         -2.31145434e-02,   6.28995663e-03,   2.07160804e-02,
                          7.68461730e-03,   3.96999670e-03,  -8.18524603e-03,
                         -1.38593717e-02,  -6.87793177e-03,   6.45207532e-04,
                          1.91055436e-03,  -1.99553333e-02,  -2.03539599e-02,
                          9.59228817e-03,   1.26171233e-02,  -5.12549141e-03,
                         -3.17460857e-02,  -3.53639908e-02,   6.84916333e-04,
                         -8.03807192e-03,  -3.33483070e-02,  -6.28635241e-03,
                          5.45671303e-03,  -5.66249713e-03,  -1.49241406e-02,
                         -1.95137635e-02,   1.68220093e-03,  -5.11871604e-03,
                         -1.55638382e-02,  -7.66861532e-03,  -3.08755040e-02,
                          1.30867893e-02,  -1.14322782e-01,  -6.34190619e-01,
                         -8.04770529e-01,  -3.13489616e-01,   4.22321334e-02,
                          3.87093760e-02,  -2.10807305e-02,  -3.56603079e-02,
                          9.72452536e-02,   2.32708808e-02,  -4.23842400e-01,
                         -4.92944181e-01,  -7.48789459e-02,   8.98889303e-02,
                         -4.06216122e-02,  -1.95225105e-02,   9.29796323e-02,
                         -1.69807151e-02,  -8.68593827e-02,   1.33895010e-01,
                         -7.87356682e-03,  -4.96754587e-01,  -3.92008573e-01,
                         -1.41290620e-01,  -4.29078460e-01,  -4.34040666e-01,
                         -3.02853505e-03,   1.07842483e-01,  -1.00297416e-02,
                         -2.40067795e-01,  -6.81810021e-01,  -7.51919866e-01,
                         -2.24617735e-01,   1.39504567e-01,  -1.13185085e-01,
                         -5.56139708e-01,  -7.26116121e-01,  -6.56389832e-01,
                         -5.92674255e-01,  -6.99937403e-01,  -7.70100236e-01,
                         -4.28271741e-01,  -8.54692087e-02,  -3.54112327e-01,
                         -7.28780806e-01,  -6.75140679e-01,  -5.97737610e-01,
                         -6.80845261e-01,  -6.82040989e-01,  -6.43819392e-01,
                         -6.53203368e-01,  -6.60728693e-01,  -6.54823780e-01,
                         -6.45139456e-01,  -6.57029986e-01,  -6.66260481e-01,
                         -6.45441055e-01,  -6.57552063e-01,  -6.78523183e-01,
                         -6.49670422e-01,  -6.42050326e-01,  -6.70414448e-01,
                         -6.73215449e-01,  -6.61315024e-01,  -6.51455164e-01,
                         -6.53221011e-01,  -6.71738386e-01,  -6.59881830e-01,
                         -6.36138737e-01,  -6.55548513e-01,  -6.57842338e-01,
                         -6.25468075e-01,  -6.41109765e-01,  -6.78404272e-01,
                         -6.72886848e-01,  -6.53160751e-01,  -6.44846022e-01,
                         -6.59285128e-01,  -6.80480719e-01,  -6.55186653e-01,
                         -6.27638161e-01,  -6.60404146e-01,  -6.89973652e-01,
                         -6.70161963e-01,  -6.50681019e-01,  -6.62279367e-01,
                         -6.58600271e-01,  -6.29672170e-01,  -6.62279248e-01,
                         -7.14490116e-01,  -6.79330170e-01,  -6.64843917e-01,
                         -6.98268056e-01,  -6.55763626e-01,  -6.25342071e-01,
                         -6.57961309e-01,  -6.59567475e-01,  -6.83521211e-01,
                         -7.19617188e-01,  -6.84608161e-01,  -6.51833057e-01,
                         -6.52860582e-01,  -6.66919827e-01,  -6.93587363e-01,
                         -6.92354262e-01,  -6.86804295e-01,  -6.79696321e-01,
                         -6.61923409e-01,  -6.90782666e-01,  -6.98668242e-01,
                         -6.93690896e-01,  -7.23686934e-01,  -6.41526341e-01,
                         -6.43608332e-01,  -8.05675089e-01,  -5.34001648e-01,
                         -8.92887786e-02,  -3.33893687e-01,  -7.80211449e-01,
                         -7.47601807e-01,  -6.49495721e-01,  -6.98497117e-01,
                         -6.95137084e-01,  -6.99557841e-01,  -7.20812917e-01,
                         -7.01273739e-01,  -6.87776446e-01,  -6.86416566e-01,
                         -6.98390543e-01,  -7.04503357e-01,  -6.90087855e-01,
                         -7.05879211e-01,  -7.26937294e-01,  -7.18645751e-01,
                         -7.10912466e-01,  -6.95394456e-01,  -6.95627809e-01,
                         -7.31412172e-01,  -7.26957083e-01,  -6.86243296e-01,
                         -7.04326391e-01,  -7.35270262e-01,  -6.84043765e-01,
                         -7.01217413e-01,  -8.04410577e-01,  -5.67532361e-01,
                         -1.52515322e-01,  -3.32712680e-01,  -7.88299084e-01,
                         -7.51509488e-01,  -6.34500504e-01,  -7.34029114e-01,
                         -6.84492588e-01,  -7.21066892e-01,  -8.15930724e-01,
                         -3.88330758e-01,  -6.04847483e-02,  -5.76054633e-01,
                         -9.11531627e-01,  -3.68149042e-01,  -1.05985850e-01,
                         -5.77620804e-01,  -5.66445172e-01,   4.94313389e-02,
                          1.80424731e-02,  -6.02972865e-01,  -7.76626468e-01,
                         -6.06652856e-01,  -7.19728529e-01,  -8.56927097e-01,
                         -4.83607262e-01,  -9.89194438e-02,  -4.96366054e-01,
                         -9.16073382e-01,  -4.49210942e-01,  -9.42361653e-02,
                         -5.15361667e-01,  -8.04753840e-01,  -7.46676803e-01,
                         -6.92782938e-01,  -3.74689460e-01,   5.68854399e-02,
                         -3.13498788e-02,  -5.75216830e-01,  -8.75042498e-01,
                         -5.65870285e-01,  -7.20902532e-02,   3.79064567e-02,
                         -3.57539624e-01,  -8.43342185e-01,  -7.42404580e-01,
                         -2.39967078e-01,  -4.68082875e-02,  -8.83235916e-05,
                         -6.10813089e-02,  -4.95058954e-01,  -5.56037307e-01,
                         -1.70281738e-01,  -4.46162313e-01,  -9.58623409e-01,
                         -5.69561660e-01,  -3.62888090e-02,  -4.32038695e-01,
                         -9.33120787e-01,  -5.46164930e-01,  -1.35168731e-01,
                         -4.71850723e-01,  -6.16649747e-01,  -1.58318102e-01,
                          6.69671446e-02,  -9.61285084e-02,  -1.43998861e-01,
                          2.34931000e-02,   1.63760334e-02,  -4.14843023e-01,
                         -6.41875863e-01,  -2.35455349e-01,   5.80353290e-02,
                         -7.38034472e-02,  -8.62638503e-02,   5.92791662e-03,
                         -5.89177310e-02,  -1.03015214e-01,  -5.92412986e-02,
                         -7.19169676e-02,  -1.08123921e-01,  -3.01860385e-02,
                         -1.26198623e-02,  -4.35004175e-01,  -9.00493324e-01,
                         -5.95239818e-01,  -1.10182226e-01,  -4.30624664e-01,
                         -6.67984664e-01,  -6.03988916e-02,   1.37665167e-01,
                         -5.06114244e-01,  -6.58018649e-01,  -1.11247383e-01,
                          1.05345689e-01,  -8.43474492e-02,  -5.71211465e-02,
                          1.51769053e-02,  -4.10100758e-01,  -8.65813315e-01,
                         -6.27734780e-01,  -1.63435966e-01,  -2.18699090e-02,
                          4.97985072e-02,  -8.81052688e-02,  -5.56776524e-01,
                         -5.16521037e-01,   8.71418938e-02,   5.79721555e-02,
                         -5.54552853e-01,  -5.33907413e-01,   1.76879931e-02,
                          8.37291628e-02,  -4.03710276e-01,  -7.82902539e-01,
                         -6.67185068e-01,  -2.22575769e-01,   1.00785106e-01,
                         -8.52428749e-02,  -6.80538237e-01,  -8.10060322e-01,
                         -2.54488856e-01,  -1.50717974e-01,  -5.09588838e-01,
                         -3.29898059e-01,  -1.61055341e-01,  -5.48641682e-01,
                         -7.88774014e-01,  -7.31747746e-01,  -4.57969755e-01,
                         -7.53498450e-02,  -3.36581916e-01,  -8.59011233e-01,
                         -5.30553579e-01,  -1.35303289e-02,  -3.11442345e-01,
                         -7.43271649e-01,  -6.41579449e-01,  -6.08182549e-01,
                         -7.78698981e-01,  -4.43488061e-01,  -2.83059180e-02,
                         -3.46755981e-01,  -7.68725336e-01,  -7.08040893e-01,
                         -5.58108747e-01,  -6.16097510e-01,  -7.68372297e-01,
                         -5.45327365e-01,  -5.98034188e-02,  -2.05034524e-01,
                         -7.11600900e-01,  -7.23882616e-01,  -5.66015959e-01,
                         -5.93839109e-01,  -6.46110415e-01,  -6.85952008e-01,
                         -6.42411172e-01,  -6.05350494e-01,  -6.48670673e-01,
                         -6.19099557e-01,  -6.32515192e-01,  -6.66654468e-01,
                         -5.68983972e-01,  -6.32958591e-01,  -7.48829007e-01,
                         -4.18411702e-01,  -5.76887131e-02,  -3.08685243e-01,
                         -7.07939923e-01,  -6.71814084e-01,  -5.71692526e-01,
                         -6.64191008e-01,  -6.46217346e-01,  -6.02619529e-01,
                         -6.61718965e-01,  -6.23321235e-01,  -5.95452607e-01,
                         -6.49715364e-01,  -6.21710598e-01,  -6.05009794e-01,
                         -6.45655632e-01,  -6.49131775e-01,  -6.27779484e-01,
                         -5.92416525e-01,  -6.12738311e-01,  -6.60791576e-01,
                         -6.22384906e-01,  -6.13385260e-01,  -6.55250192e-01,
                         -6.41916752e-01,  -6.37091517e-01,  -6.40872300e-01,
                         -6.24054074e-01,  -6.27350390e-01,  -6.34303510e-01,
                         -6.52948976e-01,  -6.42662287e-01,  -5.95096588e-01,
                         -6.22304976e-01,  -6.58717692e-01,  -6.29037201e-01,
                         -6.13748312e-01,  -6.15618765e-01,  -6.38654172e-01,
                         -6.57157898e-01,  -6.16390824e-01,  -6.10728741e-01,
                         -6.39755368e-01,  -6.29528403e-01,  -6.27897322e-01,
                         -6.21281445e-01,  -6.16894305e-01,  -6.56936109e-01,
                         -6.60758853e-01,  -6.26012683e-01,  -6.18387818e-01,
                         -6.25808477e-01,  -6.39861882e-01,  -6.44539237e-01,
                         -6.36035204e-01,  -6.37781382e-01,  -6.44508541e-01,
                         -6.50947452e-01,  -6.46209240e-01,  -6.39022410e-01,
                         -6.43724144e-01,  -6.41482115e-01,  -6.42767787e-01,
                         -6.36516273e-01,  -6.29145503e-01,  -6.58192694e-01,
                         -6.55114710e-01,  -6.19512498e-01,  -6.24919176e-01,
                         -6.53927803e-01,  -6.70065701e-01,  -6.12156093e-01,
                         -6.33913636e-01,  -7.57364213e-01,  -4.57335174e-01,
                         -5.63625321e-02,  -3.84666055e-01,  -7.75620401e-01,
                         -6.35904551e-01,  -6.01050556e-01,  -7.09267855e-01,
                         -6.87241137e-01,  -6.83835745e-01,  -6.51443839e-01,
                         -6.50489926e-01,  -7.07999885e-01,  -6.65735245e-01,
                         -6.27808094e-01,  -6.39171064e-01,  -7.45428145e-01,
                         -7.15072036e-01,  -1.82253405e-01,  -6.64578155e-02,
                         -7.51134932e-01,  -7.63740540e-01,  -8.52280855e-02,
                          6.68985844e-02,  -3.37174609e-02,   1.69751737e-02,
                          9.71783826e-04,  -4.92632296e-03,  -1.62146837e-02,
                         -2.92825401e-02,   2.52888687e-02,   1.50037669e-02,
                          7.66678900e-03,   1.62439160e-02,  -3.23459134e-02,
                          3.14948731e-03,   2.52131354e-02,  -3.95808704e-02,
                         -7.64058344e-03,   3.34041156e-02,  -4.02412144e-03,
                         -2.84618549e-02,  -3.73671427e-02,  -3.52200354e-03,
                          2.04359721e-02,  -2.23623682e-02,  -1.85845401e-02,
                          5.06676920e-03,  -1.00077325e-02,   2.64839432e-03,
                          1.02587361e-02,  -1.54058519e-03,  -1.62567318e-04,
                         -7.90294353e-03,  -4.28668968e-03,   3.84699390e-03,
                          7.89817050e-03,   2.89051868e-02,   5.04200533e-03,
                         -3.75051871e-02,  -1.69520266e-02,   8.17927066e-03,
                          1.40249990e-02,   1.02250343e-02,  -2.06545871e-02,
                         -9.08574928e-03,   3.26360501e-02,   1.92989297e-02,
                         -4.28676978e-03,  -1.00976098e-02,  -1.15193734e-02,
                          5.68565913e-03,  -6.07201504e-03,  -2.56754328e-02,
                          1.08813103e-02,   2.37146448e-02,  -5.89519134e-03,
                         -3.29363393e-03,  -1.43297584e-04,  -8.59678164e-03,
                         -2.32804916e-03,  -4.34278511e-03,   4.40347753e-03,
                          1.04724169e-02,  -2.23391578e-02,  -2.54365876e-02,
                          5.33268508e-03,   3.61683033e-03,  -4.66775941e-03,
                         -1.84492837e-03,  -6.31592193e-05,  -1.27990730e-03,
                         -2.42918711e-02,  -2.79244483e-02,   9.73247830e-03,
                          2.14029495e-02,   3.42978747e-04,  -1.20458389e-02,
                          2.82004382e-03,   2.76291706e-02,   9.25558899e-03,
                         -1.24757318e-02,   8.31944495e-03,   9.40756814e-04,
                         -2.49017123e-02,  -1.78497601e-02,  -1.18016116e-02,
                         -6.90514641e-03,  -9.42497980e-03,  -2.20819246e-02,
                          1.24955305e-03,   1.07139535e-02,  -1.79298185e-02,
                         -1.35794887e-02,  -5.79823414e-03,  -1.56890675e-02,
                         -1.16376032e-03,   1.07783941e-03,  -1.59666445e-02,
                         -1.06799146e-02,   2.36227969e-03,   9.54356138e-03,
                          7.74782477e-03,  -3.13881948e-03,  -6.67584781e-03,
                         -1.19366283e-02,  -1.62039995e-02,  -4.32900945e-03,
                         -7.67495856e-03,  -2.96969116e-02,  -2.58530565e-02,
                         -1.46918790e-02,  -2.48796064e-02,  -8.69711861e-03,
                          1.65012795e-02,  -7.19973445e-03,  -1.25177475e-02,
                          4.19165473e-03,  -2.65853051e-02,  -1.70960464e-02,
                          2.99458150e-02,   5.03463729e-04,  -2.26504691e-02,
                         -9.21551138e-04,  -2.88557378e-03,   1.04674194e-02],
                         dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri9",
    rate = 41000,
    data = numpy.array([  3.80392112e-02,   2.20843442e-02,   4.76478823e-02,
                          4.47596237e-02,   6.00431114e-02,   5.52655235e-02,
                          4.83506806e-02,   4.92020808e-02,   4.97470647e-02,
                          6.00744449e-02,   7.08236918e-02,   8.93546119e-02,
                          9.65972096e-02,   9.66644958e-02,   1.40089124e-01,
                          1.30728871e-01,   1.31494209e-01,   1.17106229e-01,
                          1.42977268e-01,   1.43694118e-01,   1.52533695e-01,
                          1.61103219e-01,   1.66062370e-01,   1.78336605e-01,
                          1.85697779e-01,   1.77598581e-01,   1.88456520e-01,
                          1.94153368e-01,   1.92958608e-01,   2.26196378e-01,
                          2.06204012e-01,   2.16468170e-01,   2.32031420e-01,
                          2.50397503e-01,   2.55919963e-01,   2.46245921e-01,
                          2.58113354e-01,   2.69830287e-01,   2.87382364e-01,
                          2.93154448e-01,   3.08138639e-01,   2.99445629e-01,
                          3.16290408e-01,   3.20545852e-01,   3.38010997e-01,
                          3.11938018e-01,   3.43652397e-01,   3.50053161e-01,
                          5.71267724e-01,   6.06508672e-01,   5.98249078e-01,
                          6.18218422e-01,   6.36983514e-01,   6.03774369e-01,
                          6.60959959e-01,   6.29106939e-01,   6.72914863e-01,
                          6.41447127e-01,   6.73155367e-01,   6.93981171e-01,
                          6.87904418e-01,   7.04880059e-01,   6.71151102e-01,
                          7.14320421e-01,   7.19107449e-01,   7.18086362e-01,
                          7.64659286e-01,   7.44716465e-01,   7.75711775e-01,
                          7.68386006e-01,   7.62228966e-01,   7.52315104e-01,
                          7.38018036e-01,   7.70492375e-01,   7.80367494e-01,
                          7.36436844e-01,   6.91305637e-01,   8.66947532e-01,
                          8.92727137e-01,   9.02850151e-01,   8.84447038e-01,
                          8.98164749e-01,   8.92642438e-01,   8.99147868e-01,
                          9.06897604e-01,   9.21111405e-01,   8.88792694e-01,
                          9.20875847e-01,   9.03361738e-01,   9.17379856e-01,
                          9.05889988e-01,   9.13064659e-01,   9.19767916e-01,
                          8.06708038e-01,   6.61520064e-01,   7.31146693e-01,
                          8.93726468e-01,   9.17811751e-01,   9.33539033e-01,
                          9.11023438e-01,   9.18297231e-01,   9.31612611e-01,
                          9.13769960e-01,   9.09550130e-01,   9.15450037e-01,
                          8.98621261e-01,   9.01835740e-01,   7.17699707e-01,
                          3.72246087e-01,  -3.90850246e-01,  -6.01921260e-01,
                         -6.89130187e-01,  -6.54435694e-01,  -5.75745404e-01,
                         -4.74283993e-01,  -3.58909607e-01,  -1.77651465e-01,
                         -4.47916659e-03,   2.20419988e-01,   4.32299584e-01,
                          6.29744828e-01,   7.94528365e-01,   8.95329535e-01,
                          8.87866855e-01,   9.40645456e-01,   9.43696678e-01,
                          9.44683254e-01,   9.21126783e-01,   9.30252910e-01,
                          8.96934450e-01,   8.30499351e-01,   7.46653020e-01,
                          7.18339145e-01,   7.11309314e-01,   6.75989509e-01,
                          5.92889905e-01,   5.28767943e-01,   6.05197668e-01,
                          7.77438879e-01,   8.90949249e-01,   8.85564983e-01,
                          8.61697197e-01,   9.02395368e-01,   9.08340931e-01,
                          9.08967137e-01,   9.16380882e-01,   3.95155758e-01,
                          1.09395936e-01,  -5.37182204e-02,   4.47407328e-02,
                          1.79031000e-01,   2.19714805e-01,   2.30481490e-01,
                          3.57682168e-01,   4.20065731e-01,   4.43133622e-01,
                          3.57931852e-01,   2.73615062e-01,   2.69465834e-01,
                          2.23456636e-01,   2.36859947e-01,   2.16122121e-01,
                          1.80486277e-01,   1.91599384e-01,   1.76135108e-01,
                          1.59325942e-01,   1.31313041e-01,   1.70414850e-01,
                          2.13326156e-01,   2.19781265e-01,   2.26992160e-01,
                          2.78843284e-01,   3.86531323e-01,   4.63670433e-01,
                          4.86217231e-01,   4.10031617e-01,   2.35400647e-01,
                          8.93823057e-02,   1.32885855e-02,   6.45485818e-02,
                          8.41685459e-02,   1.40520781e-01,   1.49592951e-01,
                          1.77559018e-01,   1.33104756e-01,   1.11323692e-01,
                          5.61510026e-02,   5.42527959e-02,   4.09535021e-02,
                          2.72326525e-02,   1.13377437e-01,   2.64552712e-01,
                          3.63979876e-01,   4.90189791e-01,   5.62500298e-01,
                          6.72158122e-01,   7.63880491e-01,   8.17241788e-01,
                          8.37996542e-01,   8.13044667e-01,   7.21616030e-01,
                          6.38055980e-01,   5.93113720e-01,   5.28264225e-01,
                          5.30479908e-01,   4.73223299e-01,   5.10181904e-01,
                          4.95266974e-01,   5.69778204e-01,   5.02836049e-01,
                          3.02540690e-01,  -2.73985177e-01,  -3.33025455e-01,
                         -1.23842090e-01,   9.04301181e-02,   2.22198159e-01,
                          2.54312009e-01,   3.36214930e-01,   3.92220914e-01,
                          4.26612794e-01,   3.46066862e-01,   2.76433647e-01,
                          3.29085767e-01,   4.34490144e-01,   5.54018736e-01,
                          3.97016823e-01,  -2.80953318e-01,  -4.55716848e-01,
                         -4.08357441e-01,  -3.33166599e-01,  -2.48243123e-01,
                         -2.03278914e-01,  -1.07253231e-01,   2.27848925e-02,
                          1.36394603e-02,  -2.86183581e-02,  -1.11615799e-01,
                         -1.86848789e-02,   1.51251331e-01,   3.58423740e-01,
                          5.07500231e-01,   6.28157914e-01,   6.86204433e-01,
                          7.88462281e-01,   7.91510224e-01,   6.59071684e-01,
                          1.92688525e-01,  -6.73632175e-02,  -1.15464620e-01,
                         -1.54729053e-01,  -6.32942691e-02,   2.07265299e-02,
                          1.03778742e-01,   2.19882771e-01,   3.18403125e-01,
                          3.60861093e-01,   3.49913567e-01,   3.53386432e-01,
                          2.88339853e-01,   1.50923401e-01,  -2.01341107e-01,
                         -3.16644281e-01,  -4.10197437e-01,  -4.03589427e-01,
                         -4.98271137e-01,  -5.63652098e-01,  -6.37576520e-01,
                         -7.28617847e-01,  -6.61925197e-01,  -5.79034925e-01,
                         -5.00692070e-01,  -3.76247048e-01,  -3.08992743e-01,
                         -1.96321175e-01,  -9.27127153e-02,  -3.63398306e-02,
                          3.32496725e-02,   1.51145905e-02,   1.16365254e-01,
                          2.42033809e-01,   3.73988420e-01,   5.04829884e-01,
                          5.19844830e-01,   5.39773405e-01,   5.52833498e-01,
                          6.73298717e-01,   6.74466431e-01,   4.34024274e-01,
                         -1.13521643e-01,  -3.14771742e-01,  -3.11119795e-01,
                         -2.19614163e-01,  -1.34733260e-01,  -2.00382411e-01,
                         -2.31622547e-01,  -2.76765853e-01,  -2.49498338e-01,
                         -2.77113855e-01,  -2.28490204e-01,  -2.51013845e-01,
                         -2.61973917e-01,  -3.04384410e-01,  -2.42853999e-01,
                         -2.20701709e-01,  -2.25293577e-01,  -2.25761339e-01,
                         -7.27586970e-02,   1.19483143e-01,   3.09752315e-01,
                          2.84970194e-01,  -1.63585499e-01,  -2.78759152e-01,
                         -1.98263094e-01,  -7.84679279e-02,   1.26018468e-02,
                         -2.56767888e-02,  -3.13499346e-02,   2.32936405e-02,
                         -6.79577217e-02,  -1.55725971e-01,  -2.36199781e-01,
                         -2.02612534e-01,  -2.04325184e-01,  -1.02894373e-01,
                         -1.21196315e-01,  -3.20457779e-02,  -1.33471750e-02,
                         -9.89355668e-02,  -1.41451821e-01,  -1.72738478e-01,
                         -1.90004304e-01,  -2.63635844e-01,  -2.39812881e-01,
                         -2.07638323e-01,  -1.39193654e-01,  -1.64201424e-01,
                         -1.60320550e-01,  -2.22046509e-01,  -2.81582296e-01,
                         -2.59695858e-01,  -2.97810197e-01,  -2.77506143e-01,
                         -2.77747959e-01,  -2.05302820e-01,  -1.77414000e-01,
                         -1.60506532e-01,  -1.48976222e-01,  -1.27624258e-01,
                         -1.17726572e-01,  -5.20968810e-02,  -5.78528922e-03,
                         -9.00364518e-02,  -2.02744585e-02,   6.91773817e-02,
                          2.02768028e-01,   3.01207870e-01,   4.40454543e-01,
                          4.76189137e-01,   4.42914307e-01,   4.00530994e-01,
                          2.88933456e-01,   1.58590347e-01,   4.99131680e-02,
                         -1.22667216e-01,  -1.97157085e-01,  -2.07025498e-01,
                         -1.53533116e-01,  -5.46513312e-02,   3.57133187e-02,
                          1.84848130e-01,   3.11335742e-01,   3.48044068e-01,
                          3.74072433e-01,   3.24809551e-01,   2.85198182e-01,
                          2.53644258e-01,   2.31595442e-01,   1.61624923e-01,
                         -5.70324510e-02,  -4.16462943e-02,  -2.10168548e-02,
                         -9.75556578e-03,   6.04437385e-03,   4.16402780e-02,
                          6.29740059e-02,   1.01956345e-01,   2.14939475e-01,
                          3.43964159e-01,   1.27613559e-01,   2.25125760e-01,
                          3.02577674e-01,   2.77460307e-01,   2.98889726e-01,
                          3.03566396e-01,   3.98946553e-01,   5.44516265e-01,
                          6.63958132e-01,   7.35351384e-01,   6.40795946e-01,
                          2.32094616e-01,   8.82093981e-02,   4.35527600e-03,
                          1.88075588e-03,  -1.30993947e-02,  -6.17327467e-02,
                         -1.56928703e-01,  -2.50434518e-01,  -2.99350321e-01,
                         -3.67477000e-01,  -4.14178699e-01,  -5.26418686e-01,
                         -5.46018839e-01,  -4.48429734e-01,  -2.76989341e-01,
                         -7.58658499e-02,   9.15328413e-03,   9.76835713e-02,
                          2.01524615e-01,   3.77472490e-01,   6.26525879e-01,
                          7.82555819e-01,   8.80879164e-01,   9.02847648e-01,
                          8.67946863e-01,   9.25386548e-01,   8.27318668e-01,
                          7.75116384e-01,   6.61497653e-01,   6.48601532e-01,
                          6.35167956e-01,   6.77707613e-01,   7.96935737e-01,
                          8.88808310e-01,   9.06884730e-01,   9.14688706e-01,
                          4.77995217e-01,   3.85017395e-01,   2.75209218e-01,
                          2.54312009e-01,   1.51477292e-01,   5.85170723e-02,
                          1.50466226e-02,   6.61968514e-02,   1.94103464e-01,
                          2.34995082e-01,   2.73882329e-01,   3.05670440e-01,
                          4.72260803e-01,   5.86770117e-01,   7.00368762e-01,
                          6.64600253e-01,   2.30080381e-01,   1.67585328e-01,
                          2.27368101e-01,   1.92054138e-01,   1.33416146e-01,
                          1.31982729e-01,   2.07006097e-01,   2.70166129e-01,
                          2.73643345e-01,   2.79467523e-01,   2.61335403e-01,
                          2.42735565e-01,   1.42002344e-01,  -9.16347355e-02,
                         -2.61870883e-02,   1.04063898e-01,   2.26986870e-01,
                          3.07708085e-01,   4.81865078e-01,   5.38939714e-01,
                          5.95952630e-01,   6.17659569e-01,   5.63058913e-01,
                          5.27092159e-01,   5.31158626e-01,   6.91683710e-01,
                          8.12896490e-01,   9.03951466e-01,   9.16729093e-01,
                          8.91783535e-01,   8.89317095e-01,   9.09542739e-01,
                          3.77292961e-01,   1.73808739e-01,   1.68410614e-01,
                          1.86669260e-01,   2.45799854e-01,   2.49492437e-01,
                          2.15415299e-01,   2.65038818e-01,   3.46793622e-01,
                          3.76786441e-01,   3.72747093e-01,   3.35799396e-01,
                          3.28866214e-01,   3.82469445e-01,   4.65323865e-01,
                          5.38342297e-01,   5.11357546e-01,   2.43447796e-01,
                          2.25509614e-01,   4.30965543e-01,   6.46388292e-01,
                          7.41574645e-01,   7.35417843e-01,   6.93871081e-01,
                          5.98245919e-01,   5.29620111e-01,   4.73199099e-01,
                          4.59874719e-01,   4.84119892e-01,   5.26739478e-01,
                          5.45375943e-01,   5.92041969e-01,   5.70924103e-01,
                          4.13684994e-01,   1.64883181e-01,   1.15392767e-01,
                          1.51722804e-01,   3.25073034e-01,   3.96781832e-01,
                          4.61321115e-01,   4.62618232e-01,   5.45794725e-01,
                          6.92137837e-01,   8.01616788e-01,   8.91030610e-01,
                          9.11914051e-01,   8.74417007e-01,   8.44845355e-01,
                          8.63644660e-01,   8.94716680e-01,   8.98192167e-01,
                          8.97842407e-01,   8.75413716e-01,   8.44130814e-01,
                          5.81422508e-01,   1.30726218e-01,   3.34633254e-02,
                          1.35847211e-01,   2.41012812e-01,   3.96863103e-01,
                          3.91741663e-01,   3.56805980e-01,   3.21461767e-01,
                          3.61639410e-01,   3.39768738e-01,   2.63221085e-01,
                          2.24799946e-01,   4.01935160e-01,   6.57526791e-01,
                          8.99896681e-01,   9.08649027e-01,   6.77398801e-01,
                          4.56239462e-01,   3.37375760e-01,   3.82979095e-01,
                          4.73043740e-01,   6.85668111e-01,   8.54479253e-01,
                          8.55303049e-01,   9.03692007e-01,   8.85770321e-01,
                          8.98880363e-01,   8.74683678e-01,   9.13103104e-01,
                          9.33117151e-01,   9.38922524e-01,   9.55539167e-01,
                          9.42451417e-01,   9.14713562e-01,   9.31814492e-01,
                          9.06542361e-01,   9.51704204e-01,   9.31844234e-01,
                          9.43745315e-01,   9.02972102e-01,   8.87619257e-01,
                          9.00875449e-01,   9.27553594e-01,   8.91003907e-01,
                          7.21588492e-01,   4.00613397e-01,   2.35766470e-01,
                          8.92799348e-02,  -9.07431781e-01,  -9.06987071e-01,
                         -8.89109254e-01,  -8.48479271e-01,  -7.72005200e-01,
                         -5.84523439e-01,  -2.94135273e-01,   2.20466405e-02,
                          2.69432366e-01,   4.59180415e-01,   4.90529954e-01,
                          3.21842134e-01,   7.40562752e-02,   9.32800584e-03,
                          7.81862736e-02,   3.53351116e-01,   5.79895198e-01,
                          5.72761536e-01,   6.30170703e-01,   6.65878415e-01,
                          8.03500414e-01,   9.01280522e-01,   8.91830564e-01,
                          8.97246003e-01,   9.01781023e-01,   8.80083263e-01,
                          9.43437874e-01,   9.02600110e-01,   8.52768242e-01,
                          3.66162449e-01,  -5.07950366e-01,  -8.17979336e-01,
                         -8.91405880e-01,  -8.37211549e-01,  -7.99840569e-01,
                         -8.93686891e-01,  -9.16250527e-01,  -9.32349324e-01,
                         -9.11377728e-01,  -8.85218441e-01,  -7.46002316e-01,
                         -7.02569127e-01,  -6.01181209e-01,  -4.58401293e-01,
                         -3.17503572e-01,  -1.90168068e-01,  -1.56681031e-01,
                         -1.46904692e-01,  -8.42809752e-02,  -5.82256280e-02,
                         -2.18518659e-01,  -2.52837598e-01,  -2.60140985e-01,
                         -1.91958144e-01,  -1.53057903e-01,  -6.45743534e-02,
                          1.62687059e-02,   6.58642054e-02,   8.60327706e-02,
                          8.87551084e-02,  -3.98935657e-03,  -1.24720978e-02,
                         -9.70081836e-02,  -2.34183624e-01,  -2.14605793e-01,
                         -1.67014986e-01,  -1.07061930e-01,  -2.08291650e-01,
                         -7.39061415e-01,  -7.75360823e-01,  -6.73726976e-01,
                         -6.07605934e-01,  -5.33286810e-01,  -4.99773830e-01,
                         -3.93931568e-01,  -2.46264458e-01,  -1.64737910e-01,
                         -4.61787842e-02,  -1.05301216e-01,  -2.01896146e-01,
                         -2.86825091e-01,  -3.12968761e-01,  -2.83581108e-01,
                         -3.99952233e-01,  -3.01740378e-01,  -7.33522177e-02,
                          1.79389894e-01,   4.56906736e-01,   5.50358891e-01,
                          5.20048261e-01,   4.94246840e-01,   3.55994493e-01,
                          3.57193708e-01,   3.17568332e-01,   2.12689698e-01,
                          1.98043466e-01,   1.69896364e-01,   2.67213285e-01,
                          3.52674514e-01,   4.09754783e-01,   3.43382657e-01,
                          2.31201917e-01,   1.64208174e-01,   1.76333681e-01,
                          2.01493785e-01,   1.57482624e-01,   1.21029943e-01,
                          4.21596095e-02,  -4.36505191e-02,  -2.82426132e-03,
                         -1.47916153e-02,  -2.03351746e-03,   1.16010271e-01,
                          1.15376905e-01,   1.09728806e-01,   9.02165323e-02,
                          6.13945425e-02,   6.64732754e-02,   7.52103701e-02,
                          2.46471584e-01,   4.22470272e-01,   5.74755192e-01,
                          5.38821757e-01,   3.32617313e-01,  -6.90729767e-02,
                         -1.39558613e-01,   1.31768882e-01,   3.83160174e-01,
                          6.27122462e-01,   7.05501437e-01,   7.80885458e-01,
                          7.98625112e-01,   8.04061472e-01,   8.15917671e-01,
                          8.18659127e-01,   7.88401127e-01,   7.53081024e-01,
                          7.31064439e-01,   8.26678634e-01,   9.02262926e-01,
                          8.57892215e-01,   3.89352411e-01,   1.81458965e-01,
                          3.32656413e-01,   4.34145033e-01,   5.23290575e-01,
                          4.27972734e-01,   2.60543317e-01,   1.23937592e-01,
                          7.39828125e-03,   3.48070301e-02,   6.85535893e-02,
                          6.39704317e-02,   4.73546125e-02,   1.15487073e-02,
                          4.97489348e-02,   1.38304606e-01,   2.65849441e-01,
                          2.99473882e-01,   2.17605516e-01,   5.96125796e-02,
                         -1.18532106e-01,  -2.38343924e-01,  -2.07748681e-01,
                         -2.01253846e-01,  -1.16811633e-01,  -7.43305087e-02,
                         -1.14322053e-02,   1.58403680e-01,   3.73695761e-01,
                          5.78067005e-01,   7.18183875e-01,   8.58305514e-01,
                          8.90860915e-01,   9.24030185e-01,   9.23747063e-01,
                          8.89168203e-01,   9.02956307e-01,   8.51081610e-01,
                          8.55207920e-01,   8.89923215e-01,   8.88422310e-01,
                          9.65600908e-01,   8.90354037e-01,   8.76459241e-01,
                          3.77899081e-01,   2.42387280e-01,   2.31149986e-01,
                          1.54700488e-01,  -6.03638031e-02,  -1.88015759e-01,
                         -3.37047338e-01,  -3.40857029e-01,  -4.68179464e-01,
                         -5.62081575e-01,  -6.49396181e-01,  -6.42358661e-01,
                         -6.01984799e-01,  -3.72908950e-01,  -7.07097650e-02,
                          2.13354260e-01,   3.49154443e-01,   4.63944405e-01,
                          6.02819324e-01,   7.28149533e-01,   7.54462481e-01,
                          7.40937412e-01,   7.19723642e-01,   7.54474163e-01,
                          8.79734516e-01,   8.90021265e-01,   9.33470249e-01,
                          7.41170168e-01,   6.91988528e-01,   7.95004010e-01,
                          9.05365407e-01,   9.14450049e-01,   8.72108579e-01,
                          8.52559686e-01,   8.18895757e-01,   7.78221905e-01,
                          7.99353480e-01,   7.44163692e-01,   6.44168496e-01,
                          4.90491718e-01,   3.90801787e-01,   4.35754895e-01,
                          4.29231942e-01,   4.70666379e-01,   5.43011308e-01,
                          5.29119849e-01,   5.17185211e-01,   4.56131071e-01,
                          4.13147271e-01,   3.03053856e-01,   1.12041555e-01,
                          2.29629744e-02,  -3.85088213e-02,   6.64623901e-02,
                          1.10327832e-01,   1.54903218e-01,   2.51336962e-01,
                          3.97539079e-01,   5.51750183e-01,   7.04985023e-01,
                          8.57739568e-01,   9.65552807e-01,   9.18531299e-01,
                          8.56877267e-01,   9.05314386e-01,   9.19561863e-01,
                          8.71386945e-01,   8.78226578e-01,   8.41332912e-01,
                          9.18447077e-01,   7.05809653e-01,   4.22361851e-01,
                          4.77371544e-01,   6.76977694e-01,   9.15846229e-01,
                          9.31950212e-01,   8.08432460e-01,   3.39372665e-01,
                         -1.65704936e-01,  -3.78701806e-01,  -6.37534440e-01,
                         -7.05960274e-01,  -4.79257345e-01,  -2.21806586e-01,
                          6.30110651e-02,   3.75018597e-01,   6.47782564e-01,
                          8.89420509e-01,   8.91956449e-01,   9.37583804e-01,
                          9.33705270e-01,   9.57357287e-01,   9.36776400e-01,
                          9.35639143e-01,   9.05638874e-01,   8.55004370e-01,
                          9.17899966e-01,   7.87260652e-01,  -6.84712380e-02,
                         -6.26142740e-01,  -5.35237193e-01,  -4.95294869e-01,
                         -5.03311753e-01,  -4.58866686e-01,  -1.90992519e-01,
                          4.55555171e-02,   3.85240704e-01,   5.33985615e-01,
                          5.88820994e-01,   8.14702213e-01,   9.50791776e-01,
                          9.08608079e-01,   9.31846619e-01,   8.52880061e-01,
                          9.06716645e-01,   8.78468812e-01,   9.28000271e-01,
                          8.88926983e-01,   9.11429644e-01,   8.89798164e-01,
                          9.15530443e-01,   8.86356950e-01,   8.22594464e-01,
                          7.98926950e-01,   8.66406918e-01,   7.50506461e-01,
                          6.00684464e-01,   6.31761491e-01,   1.01488352e-01,
                          7.21570253e-02,   8.62258554e-01,   9.02611315e-01,
                          9.51713085e-01,   9.42276001e-01,   8.85067821e-01,
                          8.48907828e-01,   8.51822317e-01,   9.25997019e-01,
                          9.04277503e-01,   9.49730575e-01,   9.14095998e-01,
                          9.06349659e-01,   9.77412581e-01,   9.38793421e-01,
                          9.25928652e-01,   8.97287786e-01,   8.70733023e-01,
                          9.15135503e-01,   8.87714803e-01,   8.75806808e-01,
                          9.25446928e-01,   9.34241414e-01,   9.75295007e-01,
                          9.64060009e-01,   8.92298222e-01,   9.38619852e-01,
                          8.72745335e-01,   8.98184240e-01,   5.48751771e-01,
                          9.13672149e-02,   2.29106858e-01,   2.50490099e-01,
                          1.84019089e-01,   3.36722225e-01,   7.20784605e-01,
                          8.99303913e-01,   8.82514715e-01,   8.67438018e-01,
                          8.74233365e-01,   8.49193811e-01,   8.89587462e-01,
                          9.02653337e-01,   8.89267981e-01,   8.28993261e-01,
                          8.34497273e-01,   8.34441245e-01,   7.80059636e-01,
                          6.75873399e-01,   8.44217122e-01,   9.54537213e-01,
                          9.73555744e-01,   9.81885374e-01,   9.89092588e-01,
                          9.49315548e-01,   8.55817914e-01,   8.81415784e-01,
                          8.90917838e-01,   6.74768567e-01,   8.05891454e-01,
                          8.58414233e-01,   9.72022772e-01,   9.21072364e-01,
                          9.61052239e-01,   9.09630179e-01,   8.25518548e-01,
                          8.52000356e-01,   8.41961741e-01,   8.61583292e-01,
                          9.13574755e-01,   9.35395360e-01,   6.55857742e-01,
                         -4.66810614e-02,  -2.19227105e-01,  -1.63436234e-01,
                         -1.98344976e-01,  -1.74752906e-01,  -1.89444497e-01,
                         -1.41957775e-01,  -4.41682450e-02,   1.41930684e-01,
                          2.61487067e-01,   4.62489039e-01,   5.69524527e-01,
                          7.62140870e-01,   8.43611181e-01,   9.18591440e-01,
                          8.93315613e-01,   9.07108843e-01,   9.84888017e-01,
                          8.53504181e-01,   8.81200075e-01,   8.97578657e-01,
                          9.18413579e-01,   9.09630477e-01,   8.88518691e-01,
                          8.64876390e-01,   8.79182220e-01,   8.87284279e-01,
                          8.82845819e-01,   8.58869612e-01,   8.91408682e-01,
                          9.16221499e-01,   9.15010214e-01,   8.90401542e-01,
                          9.06820595e-01,   9.29097414e-01,   9.25581038e-01,
                          7.59665430e-01,   4.03126836e-01,   6.32645637e-02,
                         -1.96962297e-01,  -2.78847307e-01,  -2.28715107e-01,
                         -1.83828175e-01,  -1.94903225e-01,  -1.18571430e-01,
                         -1.44247487e-01,  -1.66359693e-01,  -1.69193730e-01,
                         -1.68784618e-01,  -1.10616617e-01,  -7.41630942e-02,
                         -3.52892727e-02,   3.95850884e-03,  -4.78505716e-02,
                          9.49104205e-02,   2.00052410e-01,   2.07658619e-01,
                          5.15096635e-02,  -3.66727442e-01,  -4.60613847e-01,
                         -3.84124458e-01,  -2.97399908e-01,  -8.16802084e-02,
                         -4.89441259e-03,   2.06197090e-02,   7.28185922e-02,
                          2.04590544e-01,   3.03734094e-01,   3.11607361e-01,
                          3.43448937e-01,   3.17792714e-01,   5.73752582e-01,
                          7.50097156e-01,   9.30267930e-01,   8.79192293e-01,
                          5.20507157e-01,   3.12684953e-01,   3.81934494e-01,
                          4.78911728e-01,   4.68754530e-01,   4.37193662e-01,
                          4.93665427e-01,   6.38444781e-01,   7.17467725e-01,
                          7.92074323e-01,   8.50460470e-01,   8.45648289e-01,
                          7.69307196e-01,   6.46815062e-01,   6.90581262e-01,
                          9.58707452e-01,   9.68876541e-01,   6.41595662e-01,
                         -1.33065194e-01,  -4.34345752e-01,  -9.93902832e-02,
                          4.92510498e-01,   9.26776707e-01,   8.52334917e-01,
                          1.56092187e-02,  -8.24446082e-02,  -4.06039804e-02,
                         -8.02285895e-02,  -8.49815756e-02,  -8.07864219e-02,
                          5.03145792e-02,   1.19933836e-01,   1.27279937e-01,
                          2.32753396e-01,   3.21133912e-01,   3.68557304e-01,
                          4.25560534e-01,   5.11382222e-01,   6.12966537e-01,
                          6.84897065e-01,   6.92223191e-01,   4.94520694e-01,
                          2.91087300e-01,  -1.46588698e-01,  -4.35094982e-01,
                         -3.49300921e-01,  -3.37912112e-01,  -1.96744725e-01,
                         -7.28355646e-02,   4.57736142e-02,   1.69135943e-01,
                          1.99554056e-01,   2.49737039e-01,   1.31441399e-01,
                          2.10623115e-01,   3.65488797e-01,   4.25713986e-01,
                          4.81617063e-01,   3.61359656e-01,   3.32811028e-01,
                          1.92366302e-01,   1.94900438e-01,   2.02345431e-01,
                          1.93149760e-01,   1.04780465e-01,  -1.81570143e-01,
                         -1.72196895e-01,  -9.86478627e-02,   5.42021692e-02,
                          3.17161530e-01,   5.33788979e-01,   8.46783936e-01,
                          9.13167894e-01,   8.76631558e-01,   8.59210610e-01,
                          9.06251848e-01,   9.45039868e-01,   9.59280491e-01,
                          8.69691253e-01,   9.55207407e-01,   9.28296745e-01,
                          9.14235413e-01,   9.31662738e-01,   9.05919015e-01,
                          8.17832172e-01,   7.84658015e-01,   7.35925913e-01,
                          7.76770115e-01,   7.29831278e-01,   6.02745473e-01,
                          4.92440313e-01,   4.56932604e-01,   6.57576025e-01,
                          9.13939476e-01,   9.35268164e-01,   8.88216197e-01,
                          9.29235935e-01,   8.44562590e-01,   9.02208626e-01,
                          8.69914412e-01,   8.71801138e-01,   9.15458918e-01,
                          9.22983229e-01,   1.00000000e+00,   9.27252173e-01,
                          9.04284060e-01,   8.98006022e-01,   7.29929388e-01,
                          4.62173164e-01,   2.03119382e-01,  -2.93907404e-01,
                         -6.63194299e-01,  -8.49730313e-01,  -5.46623886e-01,
                          1.37730703e-01,   8.60927641e-01,   9.23847258e-01,
                          9.11841273e-01,   9.19260919e-01,   8.69752765e-01,
                          9.14249063e-01,   8.81858826e-01,   9.12498713e-01,
                          8.95932794e-01,   9.18992400e-01,   9.21046376e-01,
                          9.21152413e-01,   9.44064319e-01,   9.34345484e-01,
                          9.00143743e-01,   9.30543363e-01,   9.04976130e-01,
                          9.05161262e-01,   8.23454857e-01,   6.54388607e-01,
                          4.14388627e-01,   7.18039796e-02,  -2.14233652e-01,
                         -2.92695284e-01,  -2.52384245e-01,   1.26064599e-01,
                          5.19433320e-01,   8.60100627e-01,   8.87911379e-01,
                          9.00112867e-01,   9.27899778e-01,   9.16906953e-01,
                          9.31428492e-01,   9.40835953e-01,   9.07270193e-01,
                          8.92091811e-01,   9.13796723e-01,   9.07263696e-01,
                          9.05276656e-01,   9.02267754e-01,   9.19917881e-01,
                          9.37144637e-01,   9.20562327e-01,   9.28937793e-01,
                          9.35343981e-01,   9.13943887e-01,   8.84245038e-01,
                          8.77746701e-01,   8.58151793e-01,   5.00522375e-01,
                          3.75585377e-01,   4.08371717e-01,   4.76592809e-01,
                          5.28066218e-01,   5.11702657e-01,   5.02508700e-01,
                          5.18905044e-01,   5.71501672e-01,   6.42151415e-01,
                          8.17717493e-01,   9.01848078e-01,   8.75452220e-01,
                          6.01120174e-01,   4.56554592e-01,   4.71347243e-01,
                          5.22662103e-01,   5.42469621e-01,   4.93606478e-01,
                          5.16836107e-01,   6.70566738e-01,   8.02152514e-01,
                          8.73309910e-01,   8.03126454e-01,   6.87724650e-01,
                          6.87680781e-01,   7.50075400e-01,   8.85329783e-01,
                          9.53236520e-01,   9.12488103e-01,   9.07744825e-01,
                          9.10712242e-01,   9.15978372e-01,   9.56455112e-01,
                          9.38079953e-01,   8.14401567e-01,   6.22883439e-01,
                          5.61372042e-01,   5.57127833e-01,   4.63745296e-01,
                          4.47251946e-01,   2.69592226e-01,   1.29536688e-01,
                          2.67899018e-02,  -2.89923940e-02,  -9.40489173e-02,
                         -1.40285715e-01,  -1.71117961e-01,  -1.35407358e-01,
                         -1.56987801e-01,  -1.84702992e-01,  -5.49755394e-01,
                         -6.16583049e-01,  -7.34654725e-01,  -6.81361139e-01,
                         -5.95934868e-01,  -5.47969878e-01,  -4.41353232e-01,
                         -4.10133988e-01,  -3.08264226e-01,  -2.28734061e-01,
                         -1.88883707e-01,  -1.38863236e-01,  -3.20824087e-02,
                          9.40720364e-02,   1.76214695e-01,   2.86284268e-01,
                          4.13628697e-01,   3.89920354e-01,   1.93659991e-01,
                         -4.36177909e-01,  -6.32483661e-01,  -6.45014167e-01,
                         -6.14744544e-01,  -6.20041668e-01,  -6.72248304e-01,
                         -6.36873782e-01,  -6.24502659e-01,  -5.34651458e-01,
                         -5.84547520e-01,  -5.90091288e-01,  -6.48513615e-01,
                         -6.40581131e-01,  -6.22827828e-01,  -5.44535816e-01,
                         -5.28339624e-01,  -5.10949790e-01,  -5.81239760e-01,
                         -5.77230871e-01,  -5.47446847e-01,  -5.33730567e-01,
                         -5.02095163e-01,  -5.13580859e-01,  -5.01657486e-01,
                         -5.01306295e-01,  -4.68354464e-01,  -4.72878456e-01,
                         -4.77999389e-01,  -4.54498708e-01,  -4.38408047e-01,
                         -3.80856246e-01,  -3.32151860e-01,  -3.15312177e-01,
                         -1.86302230e-01,  -1.99988618e-01,  -4.04787540e-01,
                         -6.25237823e-01,  -6.17353439e-01,  -5.75796783e-01,
                         -5.63230455e-01,  -4.95858759e-01,  -4.98388290e-01,
                         -4.36270267e-01,  -4.32906330e-01,  -4.26253766e-01,
                         -3.70066404e-01,  -3.29601645e-01,  -3.25871408e-01,
                         -3.14309210e-01,  -3.04876029e-01,  -2.47493863e-01,
                         -2.18580365e-01,  -2.12072611e-01,  -2.35692784e-01,
                         -2.00364992e-01,  -2.08999291e-01,  -1.83076739e-01,
                         -2.50509679e-01,  -2.25794032e-01,  -2.31724769e-01,
                         -1.98988661e-01,  -1.46074116e-01,  -1.05028249e-01,
                         -4.99684811e-02,  -4.92220335e-02,  -5.66041172e-02,
                         -3.11115701e-02,  -2.79873889e-02,   4.87666652e-02,
                          1.02303497e-01,   1.68154404e-01,   1.60065725e-01,
                          2.70234108e-01,   3.33074033e-01,   4.00567144e-01,
                          1.94890320e-01,  -4.78363335e-01,  -6.78397894e-01,
                         -6.34976983e-01,  -5.04731297e-01,  -4.87431169e-01,
                         -4.75720614e-01,  -5.08044481e-01,   1.22340573e-02,
                          2.53704160e-01,  -1.95506550e-02,  -3.62354577e-01,
                         -4.07015771e-01,  -3.60206068e-01,  -3.22580755e-01,
                         -2.48345703e-01,  -2.79947013e-01,  -2.97967643e-01,
                         -3.26762170e-01,  -2.85375327e-01,  -2.99942166e-01,
                         -2.63605356e-01,  -3.03768009e-01,  -2.54610002e-01,
                         -1.10112846e-01,  -2.74106842e-02,  -1.96595341e-02,
                         -1.22461170e-01,  -2.16417938e-01,  -1.99892208e-01,
                         -1.97450280e-01,  -2.11464092e-01,  -2.04486206e-01,
                         -2.44145721e-01,  -2.41349846e-01,  -2.13787511e-01,
                         -1.81271732e-01,  -1.78987965e-01,  -1.39202237e-01,
                         -1.04800746e-01,  -1.82528630e-01,  -3.09114307e-01,
                         -3.39418918e-01,  -2.50142276e-01,  -1.87876359e-01,
                         -5.99275827e-02,  -2.33923718e-01,  -2.21272260e-01,
                         -9.97945368e-02,  -6.11567311e-02,  -1.08644336e-01,
                         -3.98556858e-01,  -4.71385330e-01,  -4.44562256e-01,
                         -4.19393599e-01,  -3.96013439e-01,  -3.62495661e-01,
                         -3.05442065e-01,  -2.64417589e-01,  -2.17138186e-01,
                         -2.22868606e-01,  -2.19244212e-01,  -2.39085153e-01,
                         -2.16097400e-01,  -1.55114681e-01,  -8.40620399e-02,
                          2.60265563e-02,   6.96485117e-02,   2.02891484e-01,
                          3.14038515e-01,   4.47043180e-01,   3.68633986e-01,
                          1.47775502e-03,   7.58293122e-02,   6.24696791e-01,
                          8.67497504e-01,   9.07008231e-01,   8.93281579e-01,
                          8.76493454e-01,   8.80558550e-01,   9.19460595e-01,
                          9.24122691e-01,   8.94183815e-01,   9.11209464e-01,
                          9.12737012e-01,   9.42324221e-01,   8.86559486e-01,
                          6.98500752e-01,   6.12002254e-01,   6.70038640e-01,
                          8.32559228e-01,   9.09260333e-01,   9.10009205e-01,
                          7.88012743e-01,   7.53471136e-01,   8.03133786e-01,
                          7.85125852e-01,   5.09810746e-01,   5.21261573e-01,
                          5.68810165e-01,   7.06683457e-01,   8.94316554e-01,
                          9.00933206e-01,   8.96818459e-01,   9.19381559e-01,
                          9.44529116e-01,   8.86013865e-01,   9.27068353e-01,
                          8.40990305e-01,   9.16588128e-01,   8.57179344e-01,
                          8.74204338e-01,   8.66989017e-01,   8.75692427e-01,
                          8.86216164e-01,   8.43980253e-01,   8.64142001e-01,
                          8.64778697e-01,   8.74178588e-01,   8.78077090e-01,
                          9.02327299e-01,   9.22321737e-01,   9.05919135e-01,
                          9.39417064e-01,   8.88775289e-01,   9.37944233e-01,
                          9.10705447e-01,   9.28129137e-01,   9.32399392e-01,
                          8.78558457e-01,   9.05823529e-01,   8.42656910e-01,
                          8.59794617e-01,   8.38332534e-01,   8.80813479e-01,
                          9.22970176e-01,   8.90016258e-01,   9.21487927e-01,
                          9.10159707e-01,   8.96515548e-01,   8.81462157e-01,
                          8.66078436e-01,   8.67254376e-01,   8.63458216e-01,
                          9.19875741e-01,   8.87320995e-01,   8.80052745e-01,
                          8.87279809e-01,   8.96189392e-01,   8.81156862e-01,
                          8.87238741e-01,   8.73072684e-01,   8.74721110e-01,
                          7.37972498e-01,   6.15838408e-01,   7.68243670e-01,
                          9.32902873e-01,   8.86882186e-01,   8.96351576e-01,
                          8.83617401e-01,   9.00859177e-01,   9.18073475e-01,
                          9.07842636e-01,   9.01890755e-01,   9.15195763e-01,
                          9.05125618e-01,   9.01165128e-01,   9.12361264e-01,
                          8.96804690e-01,   8.84991825e-01,   8.63693178e-01,
                          8.46293569e-01,   8.96482408e-01,   9.24277008e-01,
                          9.42426682e-01,   9.14171219e-01,   8.58022273e-01,
                          9.09401059e-01,   8.98905039e-01,   8.92781198e-01,
                          9.05027807e-01,   8.98367822e-01,   9.31684017e-01,
                          9.29880142e-01,   9.22952354e-01,   9.35759962e-01,
                          8.89785409e-01,   8.90344560e-01,   8.57698739e-01,
                          9.03241634e-01,   8.66408885e-01,   9.34471190e-01,
                          8.58345211e-01,   8.80559027e-01,   8.57976496e-01,
                          8.89624953e-01,   9.20426428e-01,   9.00429666e-01,
                          9.41435158e-01,   9.29149747e-01,   8.15777779e-01,
                          7.02269733e-01,   6.56829894e-01,   7.31267571e-01,
                          8.85649681e-01,   9.07237113e-01,   9.37576115e-01,
                          9.06623304e-01,   9.37543690e-01,   8.78501177e-01,
                          8.65395010e-01,   8.96384478e-01,   8.79993558e-01,
                          9.22374725e-01,   9.12526667e-01,   8.83090258e-01,
                          8.71402144e-01,   8.72133434e-01,   8.88715088e-01,
                          8.63839388e-01,   8.35624278e-01,   8.43547106e-01,
                          7.60256112e-01,   3.94182980e-01,   1.82312146e-01,
                          6.86221421e-02,   3.15880887e-02,  -2.68666428e-02,
                          1.67173848e-01,   3.69442880e-01,   4.52843010e-01,
                          4.84975994e-01,   6.00236893e-01,   7.60969818e-01,
                          9.08921480e-01,   9.44217026e-01,   8.59609663e-01,
                          7.76938379e-01,   7.29131818e-01,   7.73418844e-01,
                          8.34771872e-01,   8.67947638e-01,   8.71865928e-01,
                          8.95365655e-01,   7.86835134e-01,   6.21254504e-01,
                          4.99769241e-01,   5.05990922e-01,   5.29521465e-01,
                          6.45658970e-01,   6.93040431e-01,   7.24243283e-01,
                          8.02488804e-01,   7.87717044e-01,   7.66010463e-01,
                          6.79956317e-01,   5.73306441e-01,   5.93336463e-01,
                          5.48675478e-01,   4.74411756e-01,   3.82038862e-01,
                          2.20311448e-01,   8.85575563e-02,  -1.48641452e-01,
                         -6.13606334e-01,  -7.45677352e-01,  -7.30717480e-01,
                         -6.05610192e-01,  -5.61563909e-01,  -5.33896089e-01,
                         -5.44475615e-01,  -5.10017037e-01,  -4.83155012e-01,
                         -4.32104856e-01,  -4.21616286e-01,  -3.90689462e-01,
                         -3.70622903e-01,  -3.99154335e-01,  -3.19639146e-01,
                         -2.93227941e-01,  -2.91397691e-01,  -5.44488609e-01,
                         -5.96843421e-01,  -5.89127064e-01,  -5.81948876e-01,
                         -5.41338623e-01,  -5.14120340e-01,  -4.11751747e-01,
                         -3.77077550e-01,  -3.22572351e-01,  -3.16522568e-01,
                         -2.84812272e-01,  -2.34432042e-01,  -1.78165004e-01,
                         -2.38711193e-01,  -4.60276455e-01,  -5.24138093e-01,
                         -4.90239888e-01,  -3.76806796e-01,  -4.05539453e-01,
                         -3.65439624e-01,  -3.74183297e-01,  -3.77340972e-01,
                         -3.49187106e-01,  -2.61083484e-01,  -2.04426080e-01,
                         -3.95216420e-02,  -2.06803367e-01,  -2.23680884e-01,
                         -1.58345640e-01,  -1.46191865e-01,  -1.21323228e-01,
                         -1.19267218e-01,  -7.93096721e-02,  -4.67166817e-03,
                          1.03317844e-02,   7.95856817e-04,   9.80310589e-02,
                          1.33976132e-01,   3.81625891e-02,  -4.70185339e-01,
                         -5.58078110e-01,  -5.17546237e-01,  -4.09665972e-01,
                         -3.80256921e-01,  -3.28478903e-01,  -3.22085023e-01,
                         -2.53052115e-01,  -1.88975319e-01,  -1.25947192e-01,
                         -7.29336292e-02,  -3.44895273e-02,  -7.03581199e-02,
                         -3.14752817e-01,  -3.89856696e-01,  -3.52396786e-01,
                         -3.52107197e-01,  -3.09296817e-01,  -3.16296458e-01,
                         -3.07306707e-01,  -2.77155191e-01,  -2.90110528e-01,
                         -2.56449521e-01,  -2.38863990e-01,  -2.31315598e-01,
                         -2.15530574e-01,  -1.98356181e-01,  -1.92964226e-01,
                         -1.73578128e-01,  -1.02372341e-01,  -1.57293528e-01,
                         -1.81169599e-01,  -1.76093653e-01,  -1.24089979e-01,
                         -1.12505704e-01,  -7.23590478e-02,  -1.00291416e-01,
                         -6.29524961e-02,  -1.20303920e-02,  -4.07528803e-02,
                         -6.91510085e-03,  -2.73542590e-02,   3.29719968e-02,
                          3.63333039e-02,   6.15020096e-02,   2.22052429e-02,
                          5.96016981e-02,   4.38248254e-02,   1.00159325e-01,
                          1.14591308e-01,   1.21506505e-01,   3.79945077e-02,
                          1.36269033e-02,   3.17378342e-02,   9.59632918e-02,
                          2.57938564e-01,   3.51769328e-01,   3.19554627e-01,
                          2.85606772e-01,   2.11091802e-01,   2.55594552e-01,
                          2.14385256e-01,   2.62992263e-01,   2.61526644e-01,
                          2.81131834e-01,   3.48452866e-01,   4.16519791e-01,
                          4.79891539e-01,   3.25847089e-01,  -2.20415190e-01,
                         -3.46906811e-01,  -3.29084694e-01,  -2.29202479e-01,
                          4.47506979e-02,   3.89325917e-02,   2.26593185e-02,
                         -1.21147960e-01,  -8.33364204e-02,  -7.31427968e-02,
                         -9.24706981e-02,  -8.90277982e-01,  -9.05816138e-01,
                         -8.70900154e-01,  -8.94740105e-01,  -7.88492978e-01,
                         -7.41825819e-01,  -7.01487422e-01,  -8.02557468e-01,
                         -8.06364834e-01,  -7.21078694e-01,  -5.97970784e-01,
                         -4.82272595e-01,  -2.06411064e-01,   1.66035771e-01,
                          5.65355122e-01,   6.63300097e-01,   6.49186492e-01,
                          2.79782087e-01,   1.55224115e-01,   1.75086230e-01,
                          2.39592880e-01,   2.32277751e-01,   2.49930367e-01,
                          2.87299305e-01,   3.03357869e-01,   2.94933498e-01,
                          2.30680838e-01,   2.20824614e-01,   1.15673624e-01,
                          2.04951055e-02,  -5.92168309e-02,  -9.18437764e-02,
                         -1.62102524e-02,   1.78791046e-01,   3.42156500e-01,
                          5.98612964e-01,   8.33876014e-01,   8.72363567e-01,
                          9.24956083e-01,   8.96582723e-01,   9.17028606e-01,
                          9.08235788e-01,   9.21944320e-01,   6.99691296e-01,
                          5.27131617e-01,   4.51426715e-01,   4.89099264e-01,
                          5.90654254e-01,   7.14081049e-01,   8.77372205e-01,
                          9.26816821e-01,   9.00435507e-01,   9.14935827e-01,
                          8.52868855e-01,   6.20109975e-01,   8.10538411e-01,
                          9.03971553e-01,   8.81964326e-01,   9.08740759e-01,
                          8.95366371e-01,   9.21163023e-01,   9.11936402e-01,
                          8.86403084e-01,   9.10565138e-01,   8.93009722e-01,
                          9.03325081e-01,   8.80364299e-01,   8.62491846e-01,
                          9.11718369e-01,   8.89199138e-01,   9.08691406e-01,
                          9.08358991e-01,   9.22440171e-01,   9.03179348e-01,
                          9.11707878e-01,   9.10352290e-01,   8.65640461e-01,
                          8.81343305e-01,   8.70191634e-01,   8.99298906e-01,
                          9.17925656e-01,   8.90503109e-01,   9.07329798e-01,
                          9.04218137e-01,   9.10896003e-01,   9.49294746e-01,
                          9.03109610e-01,   9.20078337e-01,   8.84532869e-01,
                          8.99483263e-01,   9.21955049e-01,   9.01497900e-01,
                          9.09601390e-01,   8.84234548e-01,   8.97071540e-01,
                          8.93364608e-01,   9.13333893e-01,   8.97398412e-01,
                          8.95081997e-01,   8.88805866e-01,   8.93630743e-01,
                          9.07805920e-01,   9.12984967e-01,   8.85992765e-01,
                          9.05597746e-01,   8.93152297e-01,   9.26192045e-01,
                          9.34355140e-01,   8.83775532e-01,   8.47312689e-01,
                          8.38210821e-01,   9.08972681e-01,   9.04765308e-01,
                          9.00012612e-01,   9.13827538e-01,   9.16400313e-01,
                          9.04630482e-01,   8.99911344e-01,   9.04209912e-01,
                          8.92919362e-01,   9.29051220e-01,   8.90787780e-01,
                          9.22406912e-01,   9.04206574e-01,   9.04620945e-01,
                          9.16395485e-01,   8.86632144e-01,   9.12570119e-01,
                          8.82672787e-01,   9.33345795e-01,   8.87814403e-01,
                          9.14568841e-01,   9.00338829e-01,   8.82854402e-01,
                          9.21978652e-01,   8.93770337e-01,   8.97515416e-01,
                          9.06391680e-01,   9.09155309e-01,   9.02086258e-01,
                          9.17159021e-01,   8.86451542e-01,   9.14488018e-01,
                          8.90711010e-01,   9.00901556e-01,   9.11720157e-01,
                          8.95811856e-01,   9.18896019e-01,   9.18308735e-01,
                          9.01815355e-01,   9.20039773e-01,   9.02526259e-01,
                          9.13198471e-01,   9.02267218e-01,   9.10224378e-01,
                          8.94692421e-01,   9.26618099e-01,   8.95253181e-01,
                          9.11162853e-01,   9.08085883e-01,   9.05591130e-01,
                          9.10274863e-01,   9.08963203e-01,   8.91312063e-01,
                          9.14933085e-01,   8.88535082e-01,   9.12440360e-01,
                          9.08259392e-01,   9.20674384e-01,   9.00970936e-01,
                          9.07490671e-01,   9.06818032e-01,   8.96669447e-01,
                          9.04452980e-01,   8.91748786e-01,   9.04380441e-01,
                          9.13902223e-01,   8.97830546e-01,   9.22331035e-01,
                          8.99230123e-01,   8.76740515e-01,   8.30351412e-01,
                          8.00013244e-01,   8.68289769e-01,   8.96398425e-01,
                          9.10451531e-01,   9.08603311e-01,   9.02450860e-01,
                          9.24286127e-01,   8.97057295e-01,   9.23823714e-01,
                          9.03704166e-01,   9.05861139e-01,   9.09551859e-01,
                          9.15901303e-01,   9.10825431e-01,   9.15872753e-01,
                          8.93406510e-01,   9.20550525e-01,   8.94475758e-01,
                          8.47790539e-01,   5.56673527e-01,   3.85583252e-01,
                          3.56578827e-01,   4.14758652e-01,   5.75614274e-01,
                          7.50972450e-01,   8.78979564e-01,   8.69111240e-01,
                          4.20439094e-01,   4.71907496e-01,   7.01136172e-01,
                          9.12385225e-01,   9.01095629e-01,   9.13346469e-01,
                          9.11885262e-01,   9.18734014e-01,   9.16345298e-01,
                          9.12761629e-01,   9.02170122e-01,   9.04506922e-01,
                          9.03819382e-01,   9.01741147e-01,   7.61611044e-01,
                          5.51891923e-01,   3.15100431e-01,   1.16525434e-01,
                         -7.21791014e-02,  -1.92444339e-01,  -2.51150310e-01,
                         -2.14305788e-01,  -9.40410495e-02,   8.92004296e-02,
                          2.38828897e-01,   3.81876916e-01,   4.68482494e-01,
                          4.92020726e-01,   4.72736657e-01,   4.20797884e-01,
                          3.82588416e-01,   3.99321169e-01,   4.15839672e-01,
                          4.24404383e-01,   4.76196349e-01,   4.88615334e-01,
                          5.31010389e-01,   5.28949380e-01,   4.58248466e-01,
                          3.70964527e-01,   2.66423017e-01,   3.01485270e-01,
                          3.09947908e-01,   2.22662836e-01,  -2.16925889e-01,
                         -3.17283064e-01,  -3.69178832e-01,  -3.93195778e-01,
                         -3.41275007e-01,  -2.93954253e-01,  -2.86116660e-01,
                         -2.13190868e-01,  -1.21549390e-01,  -9.24752802e-02,
                         -5.63559607e-02,  -6.63560405e-02,  -5.20916888e-03,
                          1.05661131e-01,   1.58991665e-01,   8.33485126e-02,
                         -3.71701986e-01,  -4.67799127e-01,  -4.69544381e-01,
                         -9.01496470e-01,  -8.99924397e-01,  -8.90840650e-01,
                         -7.63011038e-01,  -7.20127761e-01,  -6.49654448e-01,
                         -6.95644319e-01,  -6.53562784e-01,  -5.59321702e-01,
                         -4.94579524e-01,  -4.15888518e-01,  -3.76717716e-01,
                         -3.79173815e-01,  -5.00525117e-01,  -6.03710949e-01,
                         -9.14122760e-01,  -8.98483872e-01,  -9.13030684e-01,
                         -9.14658546e-01,  -8.94250154e-01,  -9.31125224e-01,
                         -8.38669717e-01,  -7.28564560e-01,  -6.07565045e-01,
                         -5.73191345e-01,  -5.60591102e-01,  -6.53508067e-01,
                         -7.14136183e-01,  -6.71522677e-01,  -6.11895144e-01,
                         -5.82375228e-01,  -5.26715338e-01,  -4.27431017e-01,
                         -3.78322244e-01,  -5.30515492e-01,  -8.86057198e-01,
                         -9.20942962e-01,  -9.11642313e-01,  -9.04137790e-01,
                         -9.18015540e-01,  -9.14999187e-01,  -8.41580689e-01,
                         -7.19760001e-01,  -5.09005070e-01,  -4.06826526e-01,
                         -2.60384858e-01,  -2.08340555e-01,  -1.89930454e-01,
                         -2.41143629e-01,  -3.35090876e-01,  -4.78857458e-01,
                         -6.22237444e-01,  -7.30254650e-01,  -8.29970300e-01,
                         -8.45104575e-01,  -8.64707947e-01,  -8.39990139e-01,
                         -7.60453999e-01,  -5.31963170e-01,  -4.90262032e-01,
                         -4.63607222e-01,  -4.62757647e-01,  -3.75601649e-01,
                         -2.55467772e-01,  -1.82644159e-01,  -1.23843208e-01,
                         -1.51762590e-01,  -1.73069701e-01,  -1.72771618e-01,
                         -2.58548319e-01,  -4.72363859e-01,  -9.02845442e-01,
                         -9.07493293e-01,  -9.10416842e-01,  -8.86330485e-01,
                         -9.14616287e-01,  -8.82910311e-01,  -8.46121430e-01,
                         -6.21476412e-01,  -4.40891057e-01,  -3.37186038e-01,
                         -3.19856703e-01,  -3.09558481e-01,  -3.06134522e-01,
                         -2.58349985e-01,  -2.54583061e-01,  -2.54402697e-01,
                         -3.49676430e-01,  -4.93565917e-01,  -6.42803192e-01,
                         -7.11262047e-01,  -6.71140730e-01,  -5.38854241e-01,
                         -4.60717499e-01,  -3.50183547e-01,  -1.51038751e-01,
                          1.62072867e-01,   4.99464214e-01,   7.40619540e-01,
                          9.26259577e-01,   9.19003904e-01,   9.15628135e-01,
                          9.07381237e-01,   9.14185762e-01,   8.99054885e-01,
                          4.68953013e-01,   3.77597660e-01,   4.34694052e-01,
                          4.42937791e-01,   3.48652750e-01,   2.29704976e-01,
                          1.89127371e-01,   2.16480896e-01,   2.76014328e-01,
                          3.52716267e-01,   3.72106105e-01,   3.79822642e-01,
                          3.06565672e-01,   2.77478158e-01,   1.72882706e-01,
                          6.76152036e-02,  -6.46833554e-02,  -3.32097746e-02,
                         -2.64964290e-02,   1.92757875e-01,   2.99720794e-01,
                          5.75243711e-01,   5.29852033e-01,   1.81244001e-01,
                          2.89062768e-01,   1.62297040e-01,   1.22441210e-01,
                         -3.81658413e-02,  -1.35456296e-02,  -8.55555162e-02,
                          2.41113916e-01,   7.35090971e-01,   6.96906328e-01,
                          7.41920829e-01,   7.99845636e-01,   9.15227830e-01,
                          8.91966462e-01,   9.24409151e-01,   9.02539909e-01,
                          9.03409243e-01,   9.13223624e-01,   8.95648599e-01,
                          9.10421550e-01,   9.22471821e-01,   8.82860422e-01,
                          9.16645348e-01,   8.59663367e-01,   7.54112601e-01,
                          6.01788282e-01,   5.76274455e-01,   2.28197441e-01,
                         -1.23847350e-01,   3.56682763e-02,   1.87677950e-01,
                          2.94696927e-01,   5.30208051e-01,   6.48384988e-01,
                          6.45008683e-01,   8.66952956e-01,   8.87529731e-01,
                          8.92070234e-01,   8.93735588e-01,   9.09499347e-01,
                          8.38723361e-01,   8.99529159e-01,   9.04305100e-01,
                          9.17053938e-01,   9.02896583e-01,   9.12705481e-01,
                          9.01437342e-01,   9.02510583e-01,   9.18532252e-01,
                          9.17917430e-01,   9.15546060e-01,   9.15911198e-01,
                          9.06200051e-01,   7.37786949e-01,   6.01882637e-01,
                          5.68682075e-01,   1.37664244e-01,   1.42494246e-01,
                          2.20415950e-01,   2.50375777e-01,   2.81891465e-01,
                          2.62235999e-01,   2.74580210e-01,   2.63099939e-01,
                          2.60938138e-01,   4.63578790e-01,   9.03532088e-01,
                          8.95133376e-01,   9.17924762e-01,   9.04483080e-01,
                          9.25788403e-01,   8.98455441e-01,   8.95899713e-01,
                          9.22239900e-01,   9.25059378e-01,   9.14576113e-01,
                          9.21418965e-01,   9.07208860e-01,   9.03859735e-01,
                          9.16353762e-01,   9.03794825e-01,   9.05923247e-01,
                          8.64004433e-01,   7.44671106e-01,   7.61784434e-01,
                          8.10392797e-01,   7.93725252e-01,   8.14941347e-01,
                          8.85242343e-01,   9.12411928e-01,   9.10350502e-01,
                          8.90511096e-01,   6.64528787e-01,   7.70931005e-01,
                          8.30296099e-01,   7.31131732e-01,   1.22980505e-01,
                          1.50830969e-01,   5.68348944e-01,   7.81057358e-01,
                          8.36534381e-01,   9.08777058e-01,   9.07881141e-01,
                          9.28772748e-01,   8.84750187e-01,   9.23801363e-01,
                          8.98872614e-01,   9.22635674e-01,   9.05337989e-01,
                          9.08698499e-01,   8.86399388e-01,   8.76224577e-01,
                          7.21887410e-01,   1.68517128e-01,  -3.73527035e-02,
                         -1.61402985e-01,  -9.16478261e-02,  -3.26152369e-02,
                         -8.86681676e-02,  -4.80482168e-03,   6.98731169e-02,
                          2.09644765e-01,   3.44256878e-01,   4.87305224e-01,
                          6.76572859e-01,   9.15458143e-01,   9.05409276e-01,
                          9.10301983e-01,   8.37373853e-01,   6.81804955e-01,
                          5.99198282e-01,   5.32389581e-01,   4.32473511e-01,
                          2.92591572e-01,   9.97384638e-02,   5.95759824e-02,
                         -3.60653251e-02,  -5.75262830e-02,  -1.53677106e-01,
                         -2.25725591e-01,  -2.52069533e-01,  -2.85364121e-01,
                         -2.93543190e-01,  -3.15220445e-01,  -2.37172276e-01,
                         -2.14132875e-01,  -2.22734362e-01,  -1.57645151e-01,
                          1.87433958e-02,   1.56139165e-01,   1.84846058e-01,
                          1.38825074e-01,  -3.17414217e-02,  -1.11306861e-01,
                         -1.56769961e-01,  -1.57463506e-01,  -5.99413440e-02,
                          2.69904435e-02,   3.72617655e-02,   1.12650931e-01,
                          5.51641993e-02,   4.65472341e-02,  -1.63508251e-01,
                         -2.70782590e-01,  -3.05777133e-01,  -3.23424399e-01,
                         -2.30401903e-01,  -1.26356736e-01,  -5.46115227e-02,
                          2.69750766e-02,   1.36312693e-01,   3.09721828e-01,
                          3.41340810e-01,   2.94863433e-01,   1.27464741e-01,
                         -1.57834664e-01,  -3.59070390e-01,  -4.21354681e-01,
                         -4.39495802e-01,  -4.76768166e-01,  -5.01380682e-01,
                         -5.95070839e-01,  -5.94952643e-01,  -6.02232993e-01,
                         -5.92031300e-01,  -4.68184680e-01,  -2.79383421e-01,
                         -1.58727020e-01,  -1.37874618e-01,  -2.67183632e-01,
                         -3.69590253e-01,  -4.03334022e-01,  -3.66814375e-01,
                         -3.47937554e-01,  -3.71625006e-01,  -4.75443542e-01,
                         -5.62418103e-01,  -5.54216146e-01,  -6.05169713e-01,
                         -5.56809187e-01,  -4.69058692e-01,  -4.38622177e-01,
                         -3.17450941e-01,  -2.67785370e-01,  -2.39392236e-01,
                         -3.60127211e-01,  -3.25562179e-01,  -2.97133148e-01,
                         -2.78802603e-01,  -3.07536334e-01,  -2.78090447e-01,
                         -2.49843895e-01,  -2.62396723e-01,  -3.85994047e-01,
                         -3.91771674e-01,  -4.22072172e-01,  -4.55399573e-01,
                         -4.91524577e-01,  -5.20772815e-01,  -4.41154480e-01,
                         -4.00921851e-01,  -3.22843343e-01,  -2.85997689e-01,
                         -3.31363797e-01,  -4.95735168e-01,  -5.30118465e-01,
                         -5.36923349e-01,  -4.70545143e-01,  -4.01245296e-01,
                         -3.33228111e-01,  -2.16294616e-01,  -1.58752725e-01,
                         -1.52048633e-01,  -2.01467454e-01,  -2.53645867e-01,
                         -3.72596323e-01,  -3.58353108e-01,  -2.25790381e-01,
                         -2.43261993e-01,  -2.18549415e-01,  -2.70468235e-01,
                         -3.82460624e-01,  -5.18707037e-01,  -5.38111329e-01,
                         -5.14245808e-01,  -4.82541591e-01,  -4.71428007e-01,
                         -5.35464287e-01,  -5.59027791e-01,  -5.45037270e-01,
                         -4.87130523e-01,  -4.82940078e-01,  -4.63533759e-01,
                         -4.86012816e-01,  -3.93010706e-01,  -3.25298697e-01,
                         -2.32137561e-01,  -1.37154400e-01,  -6.30320907e-02,
                         -1.37832016e-02,   5.93225807e-02,   1.55691236e-01,
                          2.51403660e-01,   3.24309736e-01,   3.51532668e-01,
                          4.18634087e-01,   4.71921712e-01,   4.45348769e-01,
                          4.13824171e-01,   1.42350480e-01,  -8.70570354e-03,
                         -9.37870890e-02,  -1.71394080e-01,  -2.82834470e-01,
                         -2.84937978e-01,  -2.22641498e-01,  -1.17410898e-01,
                          2.50218827e-02,   1.36630028e-01,   2.06680477e-01,
                          2.21209705e-01,   5.61015345e-02,  -5.61013699e-01,
                         -8.11663985e-01,  -7.95030951e-01,  -6.88372195e-01,
                         -3.86837155e-01,  -1.02467850e-01,   1.88017115e-01,
                          3.43827188e-01,   4.50583637e-01,   4.82821822e-01,
                          4.55562323e-01,   3.91009837e-01,   1.69316694e-01,
                         -1.95242420e-01,  -3.21987122e-01,  -2.98316121e-01,
                         -2.46282086e-01,  -2.28878096e-01,  -2.30343148e-01,
                         -2.75850892e-01,  -2.61333942e-01,  -2.15302333e-01,
                         -2.66190529e-01,  -2.95071155e-01,  -2.47283518e-01,
                         -1.77593723e-01,   6.35948358e-03,   2.95677036e-01,
                          3.82635474e-01,   4.21072513e-01,   3.40407610e-01,
                          2.52738804e-01,   2.13262245e-01,   2.14279294e-01,
                          2.43701205e-01,   2.06113651e-01,  -4.22107428e-02,
                         -1.19571000e-01,  -1.48737326e-01,  -1.96886808e-01,
                         -3.32703918e-01,  -3.52064937e-01,  -3.39948446e-01,
                         -2.82487988e-01,  -1.55366734e-01,   1.82423387e-02,
                          1.40623659e-01,   2.46149644e-01,   3.22256625e-01,
                          3.72428715e-01,   4.48685676e-01,   6.26925886e-01,
                          8.55180323e-01,   9.14796650e-01,   9.09580350e-01,
                          8.98217201e-01,   9.13947940e-01,   8.81839454e-01,
                          8.85722280e-01,   7.48465896e-01,   7.27509439e-01,
                          7.05787122e-01,   7.94455171e-01,   8.79462421e-01,
                          9.24632728e-01,   9.45219100e-01,   9.18730497e-01,
                          8.77922595e-01,   8.97278011e-01,   9.35489297e-01,
                          9.13625419e-01,   7.15831935e-01,   5.54314017e-01,
                          5.32226443e-01,   6.07124507e-01,   6.98913932e-01,
                          8.65172863e-01,   8.97278726e-01,   9.17407990e-01,
                          9.03572381e-01,   8.79301786e-01,   9.13737357e-01,
                          9.01356876e-01,   9.14387822e-01,   8.75656307e-01,
                          8.88040602e-01,   8.74022961e-01,   9.20978069e-01,
                          9.18416023e-01,   9.42491889e-01,   9.21056151e-01,
                          9.36334729e-01,   9.12830710e-01,   8.89190733e-01,
                          8.96917403e-01,   8.87221098e-01,   4.03918684e-01,
                         -2.12618839e-02,  -9.17852372e-02,  -7.67898336e-02,
                         -7.75305107e-02,  -9.81313065e-02,   5.92803396e-02,
                          3.06935042e-01,   4.37580973e-01,   3.97206962e-01,
                          3.72773856e-01,   4.20689225e-01,   5.32031536e-01,
                          6.57295644e-01,   8.41787159e-01,   9.00781155e-01,
                          9.34547246e-01,   9.51279879e-01,   9.16286469e-01,
                          7.54216075e-01,   4.83651429e-01,   3.39176714e-01,
                          2.93755293e-01,   1.51414499e-01,   1.30430773e-01,
                          1.44294694e-01,   7.09069893e-02,   7.61962906e-02,
                          7.56118819e-02,   3.50320414e-02,   5.35650998e-02,
                          1.03095114e-01,   1.74522117e-01,   2.48751730e-01,
                          2.86882460e-01,   3.67853343e-01,   4.30419147e-01,
                          3.93089354e-01,   2.33951181e-01,   1.56098187e-01,
                          1.45164177e-01,   1.26838773e-01,   1.45737141e-01,
                          1.48703128e-01,   1.86441481e-01,   3.00340742e-01,
                          4.31150973e-01,   4.77661908e-01,   4.70109999e-01,
                          4.07075644e-01,   2.90022850e-01,   1.88207000e-01,
                          7.85776526e-02,   1.58539787e-02,  -9.17962473e-03,
                          3.15479152e-02,   6.79091290e-02,   1.49850190e-01,
                          2.19953030e-01,   3.32386881e-01,   3.84506077e-01,
                          4.70527887e-01,   6.21121526e-01,   7.82679379e-01,
                          8.88132334e-01,   8.67202103e-01,   8.38917017e-01,
                          7.35364199e-01,   6.07458949e-01,   5.26667714e-01,
                          4.53188539e-01,   4.57556576e-01,   4.34190392e-01,
                          4.89913970e-01,   5.85598350e-01,   5.85769773e-01,
                          4.33756232e-01,  -1.65481165e-01,  -3.22894484e-01,
                         -2.18361065e-01,  -5.02854958e-02,   5.72838001e-02,
                          1.19531788e-01,   1.20313704e-01,   1.79258987e-01,
                          1.57990590e-01,   6.43981919e-02,  -2.82641985e-02,
                         -1.16388343e-01,  -1.38554856e-01,  -2.37346381e-01,
                         -2.51913428e-01,  -2.75509506e-01,  -1.99227169e-01,
                         -6.93217516e-02,   3.84575501e-02,   9.07092839e-02,
                          1.29258499e-01,   1.33292794e-01,   1.91951558e-01,
                          2.40255207e-01,   3.38351399e-01,   3.76474589e-01,
                          3.29290688e-01,   4.24857914e-01,   6.21519983e-01,
                          7.58239985e-01,   6.28002822e-01,   5.81139475e-02,
                         -1.39278561e-01,  -1.59772515e-01,  -1.36978449e-02,
                          8.65274519e-02,   1.18121825e-01,   1.42849207e-01,
                          1.47348106e-01,   1.39606297e-01,   1.66891292e-02,
                         -6.24326169e-02,  -8.60603079e-02,  -2.83369031e-02,
                          3.79997455e-02,   8.69392678e-02,   8.09774697e-02,
                          9.28248763e-02,   1.10240608e-01,   1.03310212e-01,
                          1.04070604e-01,   1.24102570e-01,   1.13747559e-01,
                          7.97557905e-02,   3.78906503e-02,  -1.79305002e-02,
                         -6.79739043e-02,   7.04108784e-03,   7.98639730e-02,
                          1.79309234e-01,   2.63935626e-01,   4.12952006e-01,
                          4.80864018e-01,   3.30221504e-01,  -1.04539968e-01,
                         -1.68442771e-01,  -2.46565733e-02,   6.68749958e-02,
                          7.98322633e-02,   8.74760896e-02,   1.36455536e-01,
                          1.97267368e-01,   2.29494750e-01,   2.33292967e-01,
                          2.54465610e-01,   3.54295194e-01,   5.25587142e-01,
                          6.20633066e-01,   4.90287632e-01,   2.32151356e-02,
                         -2.35509351e-01,  -2.79253095e-01,  -2.60110438e-01,
                         -2.05509260e-01,  -2.05217287e-01,  -1.21283680e-01,
                         -4.67823595e-02,   4.70249495e-03,  -2.20675562e-02,
                         -8.39205757e-02,  -1.07488506e-01,  -1.09899543e-01,
                         -7.75423720e-02,  -7.19795078e-02,  -8.01788494e-02,
                         -1.17194839e-01,  -4.26135547e-02,   1.69742424e-02,
                          1.49805695e-01,   3.26755583e-01,   4.11893904e-01,
                          3.54736507e-01,   3.16836029e-01,   2.69437194e-01,
                          2.66796410e-01,   2.40000740e-01,   2.57620178e-02,
                         -3.82137060e-01,  -4.31579947e-01,  -2.95419008e-01,
                         -1.58644274e-01,  -5.47327064e-02,   2.82442532e-02,
                          8.36079381e-03,  -2.21325345e-02,  -2.95197032e-02,
                          8.26542750e-02,   2.03189299e-01,   2.02194750e-01,
                          1.05463833e-01,   9.24595892e-02,   1.40047655e-01,
                          1.25175491e-01,   7.27903051e-03,  -4.08391505e-01,
                         -5.22233248e-01,  -5.52673638e-01,  -5.36402762e-01,
                         -4.81004626e-01,  -4.16947395e-01,  -3.61898899e-01,
                         -2.60519415e-01,  -1.26694471e-01,   2.19594445e-02,
                          1.77880362e-01,   3.15528989e-01,   2.71247119e-01,
                          1.98044032e-01,   3.37821431e-02,   4.71239462e-02,
                          1.56003192e-01,   2.81321049e-01,   3.52857441e-01,
                          3.09485883e-01,   2.62125105e-01,   2.05353126e-01,
                          1.01937898e-01,   1.73229363e-03,   4.80002463e-02,
                          2.48947069e-02,   9.08810347e-02,   1.04048155e-01,
                          1.70728087e-01,   2.24636659e-01,   2.49076352e-01,
                          3.33020091e-01,   2.76592910e-01,   2.39609197e-01,
                          2.55228043e-01,   2.53494203e-01,   2.92410523e-01,
                          3.14052582e-01,   3.33031565e-01,   3.58723521e-01,
                          3.58448327e-01,   4.74451840e-01,   5.88889897e-01,
                          7.53488898e-01,   8.28157425e-01,   8.10820401e-01,
                          8.84365916e-01,   8.90075982e-01,   8.75166237e-01,
                          8.50695729e-01,   7.99583852e-01,   8.07631135e-01,
                          8.05728614e-01,   7.55088508e-01,   7.22294986e-01,
                          6.19323373e-01,   5.56537330e-01,   6.03159249e-01,
                          6.20557547e-01,   6.41557753e-01,   7.12242365e-01,
                          7.51424193e-01,   8.64319384e-01,   9.31133330e-01,
                          9.59909081e-01,   9.62459028e-01,   9.49807823e-01,
                          9.15933073e-01,   9.21337187e-01,   9.11572158e-01,
                          8.84314716e-01,   8.71655405e-01,   8.78119588e-01,
                          9.08758640e-01,   9.24967468e-01,   9.14254308e-01,
                          9.26733971e-01,   8.78127396e-01,   9.12917316e-01,
                          8.85270357e-01,   7.38359213e-01,   7.51678109e-01,
                          7.79652357e-01,   8.67471039e-01,   9.27385032e-01,
                          9.14816082e-01,   9.40282762e-01,   9.46295261e-01,
                          9.33794737e-01,   9.62357283e-01,   9.51495349e-01,
                          9.44558501e-01,   9.15221572e-01,   9.02663291e-01,
                          8.94440472e-01,   8.82205307e-01,   9.09874797e-01,
                          9.22679007e-01,   6.73366010e-01,   6.81104720e-01,
                          6.98544025e-01,   7.68894553e-01,   7.13972807e-01,
                          7.14304447e-01,   6.35287583e-01,   5.81171274e-01,
                          5.08882463e-01,   5.79276502e-01,   7.62688816e-01,
                          9.16032374e-01,   9.52798426e-01,   9.32523072e-01,
                          9.44314778e-01,   8.82579505e-01,   7.64050782e-01,
                          6.78759992e-01,   5.84667027e-01,   5.47355950e-01,
                          4.98043716e-01,   4.88213271e-01,   4.67814684e-01,
                          4.98052895e-01,   6.74889863e-01,   8.19849312e-01,
                          8.91435981e-01,   8.95665765e-01,   8.65140140e-01,
                          9.16736662e-01,   9.04138982e-01,   9.40677345e-01,
                          9.23292458e-01,   8.74478459e-01,   9.08849895e-01,
                          6.23089433e-01,   5.39025724e-01,   4.75130200e-01,
                          4.81675863e-01,   4.66651082e-01,   5.34613073e-01,
                          5.81330478e-01,   6.75648391e-01,   7.25522161e-01,
                          7.82818377e-01,   8.32994461e-01,   8.59530926e-01,
                          9.13825870e-01,   9.33144510e-01,   8.82886350e-01,
                          8.76250267e-01,   8.90590727e-01,   9.18795764e-01,
                          9.41395819e-01,   9.05514181e-01,   8.91847551e-01,
                          8.84669602e-01,   8.52627873e-01,   5.54338098e-01,
                          3.71141583e-01,   4.22756642e-01,   4.47692126e-01,
                          4.57811922e-01,   4.62577224e-01,   4.47313726e-01,
                          5.38522720e-01,   5.55339634e-01,   7.17012882e-01,
                          8.92359495e-01,   9.19718742e-01,   8.95134568e-01,
                          8.53987932e-01,   9.13774312e-01,   8.91401350e-01,
                          8.99818540e-01,   6.33243620e-01,   4.93379623e-01,
                          5.88748157e-01,   7.33121216e-01,   8.10347557e-01,
                          8.90698254e-01,   8.83224428e-01,   9.35181320e-01,
                          9.25876260e-01,   9.18343902e-01,   9.18389380e-01,
                          8.81154060e-01,   4.94533867e-01,   3.65424216e-01,
                          3.38459760e-01,   3.54805082e-01,   3.58294487e-01,
                          3.20936322e-01,   3.38619262e-01,   3.99016768e-01,
                          4.03119206e-01,   3.01625371e-01,  -4.93543111e-02,
                         -1.93891585e-01,  -1.37517124e-01,  -2.22835392e-02,
                          1.32048383e-01,   2.63619751e-01,   4.60517406e-01,
                          6.90434873e-01,   7.69653022e-01,   6.98905289e-01,
                          6.24962807e-01,   4.88314599e-01,   3.67142290e-01,
                          2.22719997e-01,   1.79613799e-01,   1.62576675e-01,
                          2.52728790e-01,   1.51256666e-01,  -2.19345540e-01,
                         -2.86197692e-01,  -9.32907835e-02,   1.11334555e-01,
                          2.13057533e-01,   2.29289114e-01,   3.11973602e-01,
                          3.71857971e-01,   4.43545759e-01,   4.10697758e-01,
                          3.75733227e-01,   4.45110202e-01,   5.58556497e-01,
                          7.11561620e-01,   8.91260326e-01,   9.02747214e-01,
                          8.84638786e-01,   8.25108409e-01,   1.06575690e-01,
                         -1.47035271e-01,  -2.34149426e-01,  -2.09546700e-01,
                         -2.17818171e-01,  -2.45037943e-01,  -1.89385131e-01,
                         -1.44305289e-01,  -3.04358285e-02,   5.57768298e-03,
                          1.73004437e-02,  -5.41124828e-02,  -8.34159181e-02,
                         -6.31322712e-02,  -7.01356307e-03,   1.33378923e-01,
                          1.97415784e-01,   1.78925186e-01,   2.15308473e-01,
                          2.36681893e-01,   2.74722308e-01,   2.31897637e-01,
                          2.75582284e-01,   3.31565708e-01,   4.02241975e-01,
                          4.06137258e-01,   1.66837409e-01,  -4.00015801e-01,
                         -6.00131452e-01,  -6.23278022e-01,  -6.03113115e-01,
                         -6.96916640e-01,  -7.57795155e-01,  -8.04361224e-01,
                         -7.58550346e-01,  -7.19845772e-01,  -6.59864604e-01,
                         -6.15071416e-01,  -5.13001144e-01,  -4.60682511e-01,
                         -4.80580300e-01,  -6.76057458e-01,  -6.03009641e-01,
                         -4.77797598e-01,  -3.35666269e-01,  -3.59362781e-01,
                         -3.10662091e-01,  -3.38981479e-01,  -2.84199655e-01,
                         -2.78470010e-01,  -2.43950933e-01,  -2.10301712e-01,
                         -1.37323380e-01,  -1.32892251e-01,  -1.78810850e-01,
                         -4.09437925e-01,  -3.55678707e-01,  -2.89001346e-01,
                         -3.65658462e-01,  -4.26569134e-01,  -4.93379027e-01,
                         -4.48415607e-01,  -5.10210633e-01,  -5.74298620e-01,
                         -6.23856366e-01,  -6.46720707e-01,  -5.95091999e-01,
                         -4.57921058e-01,  -3.66207212e-01,  -2.03489944e-01,
                         -1.46065608e-01,  -1.70402959e-01,  -2.15706557e-01,
                         -2.97984749e-01,  -3.23104471e-01,  -4.34220046e-01,
                         -7.36719966e-01,  -7.96364665e-01,  -8.53280604e-01,
                         -8.01847458e-01,  -8.13633084e-01,  -8.19923937e-01,
                         -8.12530339e-01,  -6.81178153e-01,  -5.32303631e-01,
                         -3.96611959e-01,  -3.10052902e-01,  -2.35632852e-01,
                         -1.58809304e-01,  -1.86971977e-01,  -4.13890719e-01,
                         -8.94166112e-01,  -9.28898513e-01,  -9.01342869e-01,
                         -8.80600095e-01,  -8.65498662e-01,  -8.94051552e-01,
                         -9.11632955e-01,  -8.05728078e-01,  -6.47598267e-01,
                         -4.92344856e-01,  -2.77189940e-01,  -1.60827607e-01,
                         -7.11415112e-02,   6.95960596e-02,   1.09891154e-01,
                          1.24790207e-01,  -2.63028406e-02,  -4.05452490e-01,
                         -4.97321606e-01,  -4.47158992e-01,  -3.68447185e-01,
                         -2.84210891e-01,  -2.76653260e-01,  -2.68801898e-01,
                         -2.87608445e-01,  -3.79895419e-01,  -4.16670412e-01,
                         -5.39232969e-01,  -6.09731317e-01,  -5.37524164e-01,
                         -4.63210136e-01,  -3.54146093e-01,  -2.38319531e-01,
                         -1.68531373e-01,  -1.66919142e-01,  -7.39310458e-02,
                         -7.57230222e-02,  -5.32899946e-02,  -7.05472156e-02,
                         -6.92448393e-02,   3.12249623e-02,   7.04105943e-02,
                          1.68477431e-01,   1.13970071e-01,   1.52342319e-01,
                          1.49820507e-01,   1.31038859e-01,   1.12079971e-01,
                          1.04311883e-01,   3.89524512e-02,  -5.68562448e-02,
                         -1.49956793e-01,  -2.04044789e-01,  -2.85558879e-01,
                         -3.57422322e-01,  -4.04546440e-01,  -3.92463148e-01,
                         -3.27125847e-01,  -2.42630392e-01,  -1.77092850e-01,
                         -1.03415735e-01,  -1.95913073e-02,  -1.01767266e-02,
                          3.17319892e-02,   5.08115701e-02,   9.01631191e-02,
                          1.43449098e-01,   1.68653801e-01,   2.30241552e-01,
                          2.46235922e-01,   3.09531033e-01,   3.39047968e-01,
                          3.65365475e-01,   3.77613246e-01,   3.05294842e-01,
                          2.42923573e-01,   1.79902449e-01,   9.79306400e-02,
                          1.54099176e-02,  -1.59652963e-01,  -4.72548634e-01,
                         -5.35521209e-01,  -4.97702122e-01,  -4.49251026e-01,
                         -4.38558221e-01,  -4.51409429e-01,  -4.17292893e-01,
                         -3.54393095e-01,  -2.90489048e-01,  -2.50723809e-01,
                         -2.44316742e-01,  -2.04205006e-01,  -1.55980691e-01,
                         -8.40892717e-02,   7.03019053e-02,   1.64220825e-01,
                          2.33283490e-01,   2.79159129e-01,   2.70243198e-01,
                          2.71612316e-01,   2.39727199e-01,   2.17521206e-01,
                          1.89123079e-01,   1.00943878e-01,   1.19338058e-01,
                          7.48320743e-02,   8.18593428e-02,  -5.68515100e-02,
                         -4.14283946e-02,   7.04675466e-02,   1.48462683e-01,
                          1.85268909e-01,   1.73850223e-01,   1.20196328e-01,
                          1.23735063e-01,   2.89324839e-02,  -6.47458422e-04,
                         -4.55012843e-02,  -1.34134695e-01,  -1.52729928e-01,
                         -1.72104508e-01,  -2.07781136e-01,  -2.32154608e-01,
                         -3.52870196e-01,  -4.51397061e-01,  -4.55026656e-01,
                         -4.65386033e-01,  -4.37864244e-01,  -5.00251412e-01,
                         -4.72274601e-01,  -4.64754701e-01,  -4.13843036e-01,
                         -3.51242930e-01,  -2.80204386e-01,  -2.33770654e-01,
                         -1.31322399e-01,  -5.78199215e-02,  -5.86718554e-03,
                          9.96749848e-02,   1.92793369e-01,   2.88207918e-01,
                          3.73670936e-01,   3.14505547e-01,   6.27724230e-02,
                         -1.02997579e-01,  -1.31171584e-01,  -1.46970972e-01,
                         -1.70439258e-01,  -1.78930998e-01,  -2.15802878e-01,
                         -1.87426209e-01,  -2.14995876e-01,  -1.89850256e-01,
                         -1.95705980e-01,  -1.98792711e-01,  -2.64118940e-01,
                         -3.04639041e-01,  -3.14673394e-01,  -3.25518072e-01,
                         -3.35446775e-01,  -4.66175973e-01,  -7.15421736e-01,
                         -7.70205975e-01,  -6.99037194e-01,  -5.97506762e-01,
                         -5.10836720e-01,  -4.32202309e-01,  -4.49537218e-01,
                         -5.12972891e-01,  -4.72583979e-01,  -3.82569879e-01,
                         -2.55798012e-01,  -1.08865589e-01,  -1.78917676e-01,
                         -4.50621367e-01,  -5.19109905e-01,  -4.80641872e-01,
                         -3.83612573e-01,  -2.85324544e-01,  -2.66045898e-01,
                         -2.99083143e-01,  -3.36541891e-01,  -3.09879839e-01,
                         -2.77475566e-01,  -2.29607150e-01,  -2.32685477e-01,
                         -2.42447197e-01,  -1.28172085e-01,  -3.36400745e-03,
                          4.71947193e-02,  -7.25601986e-02,  -5.76872528e-01,
                         -7.22807586e-01,  -7.07700133e-01,  -6.25234008e-01,
                         -5.02465487e-01,  -5.04105985e-01,  -4.46758121e-01,
                         -4.03204978e-01,  -3.58059376e-01,  -4.62165684e-01,
                         -6.37794614e-01,  -8.79843473e-01,  -8.94920647e-01,
                         -8.91397774e-01,  -8.95562828e-01,  -9.12305653e-01,
                         -9.05943632e-01,  -9.51489866e-01,  -8.74038279e-01,
                         -8.74084175e-01,  -8.90901506e-01,  -9.31458533e-01,
                         -8.21330965e-01,  -7.13947237e-01,  -5.22099435e-01,
                         -3.77843767e-01,  -3.36061150e-01,  -3.58520508e-01,
                         -4.80775297e-01,  -5.48008382e-01,  -6.51453495e-01,
                         -6.86155736e-01,  -6.31227851e-01,  -6.42221510e-01,
                         -6.21870399e-01,  -6.00467324e-01,  -4.91660565e-01,
                         -4.26312864e-01,  -5.72209418e-01,  -9.05881345e-01,
                         -8.99980903e-01,  -8.98750365e-01,  -9.01308537e-01,
                         -9.14997995e-01,  -9.30848598e-01,  -9.32643592e-01,
                         -9.39505577e-01,  -9.22511935e-01,  -9.21862364e-01,
                         -9.30582702e-01,  -9.17456865e-01,  -9.20529485e-01,
                         -9.32811916e-01,  -8.97910178e-01,  -8.81250381e-01,
                         -8.61189365e-01,  -8.18143487e-01,  -8.21529686e-01,
                         -8.14512908e-01,  -8.30450654e-01,  -8.54391754e-01,
                         -8.04309368e-01,  -7.98777282e-01,  -7.47153401e-01,
                         -8.02766681e-01,  -7.74763942e-01,  -7.38721371e-01,
                         -6.57492101e-01,  -6.38839602e-01,  -7.87074506e-01,
                         -9.02629375e-01,  -8.99235129e-01,  -8.92909646e-01,
                         -9.08195019e-01,  -9.26012218e-01,  -8.88429880e-01,
                         -9.35886025e-01,  -9.19123948e-01,  -9.37799096e-01,
                         -9.26422417e-01,  -9.35690284e-01,  -9.01546180e-01,
                         -9.39845741e-01,  -9.18615043e-01,  -8.75932634e-01,
                         -8.57141376e-01,  -8.40826750e-01,  -8.70368063e-01,
                         -8.56205881e-01,  -8.48376751e-01,  -8.21173310e-01,
                         -8.18573534e-01,  -7.97164202e-01,  -8.30468118e-01,
                         -7.94747591e-01,  -8.07339847e-01,  -6.80174530e-01,
                         -5.95642924e-01,  -5.17988682e-01,  -4.58434314e-01,
                         -3.95779461e-01,  -3.40454578e-01,  -3.20787519e-01,
                         -6.65790856e-01,  -6.97879016e-01,  -6.13987684e-01,
                         -4.47186708e-01,  -3.38446736e-01,  -2.76650727e-01,
                         -1.86892569e-01,  -5.77453561e-02,   6.28984943e-02,
                          1.43564776e-01,   2.11174309e-01,   3.35229307e-01,
                          3.94923389e-01,   3.11377764e-01,  -2.26993993e-01,
                         -4.10471648e-01,  -4.30990219e-01,  -3.94548863e-01,
                         -3.51404220e-01,  -4.15549934e-01,  -4.24143970e-01,
                         -3.89878035e-01,  -3.44241172e-01,  -2.88371772e-01,
                         -2.49162793e-01,  -2.47726843e-01,  -2.16791302e-01,
                         -2.45133907e-01,  -2.11679891e-01,  -1.84567437e-01,
                         -1.73203483e-01,  -1.26925737e-01,  -7.37073198e-02,
                          1.29965311e-02,   1.12277545e-01,   1.46845639e-01,
                          1.37398764e-01,  -2.30995636e-03,   2.71645520e-04,
                          4.81007285e-02,   4.96126786e-02,   9.17908326e-02,
                          1.14465572e-01,   1.29611790e-01,   1.76692173e-01,
                          2.23598719e-01,   2.63247311e-01,   3.54882598e-01,
                          3.74742478e-01,   3.03367764e-01,  -1.02885757e-02,
                         -5.76049685e-02,   6.17900267e-02,   2.10859820e-01,
                          3.18194002e-01,   3.66188347e-01,   4.14950162e-01,
                          4.51755166e-01,   5.03618360e-01,   4.93960977e-01,
                          5.43868124e-01,   5.73049068e-01,   6.49440289e-01,
                          8.11060250e-01,   8.94722760e-01,   9.01632071e-01,
                          9.34144557e-01,   6.11130357e-01,   3.91192943e-01,
                          2.81518757e-01,   2.53823131e-01,   2.70062447e-01,
                          2.78314620e-01,   3.38519931e-01,   4.11922008e-01,
                          4.86995250e-01,   5.28126121e-01,   5.71332395e-01,
                          6.52843118e-01,   6.86532259e-01,   6.96033716e-01,
                          7.38109350e-01,   8.34132910e-01,   8.64865303e-01,
                          8.53116930e-01,   7.12235272e-01,   6.79528058e-01,
                          7.38581359e-01,   8.21106732e-01,   8.50511074e-01,
                          8.46870661e-01,   8.09822440e-01,   8.84879589e-01,
                          8.50005805e-01,   8.27113330e-01,   7.41863847e-01,
                          8.30826879e-01,   7.63516903e-01,   7.44378924e-01,
                          7.49857664e-01,   8.05807412e-01,   8.20621133e-01,
                          7.58800626e-01,   3.40285540e-01,   2.88174868e-01,
                          2.69709021e-01,   3.63107234e-01,   4.36038792e-01,
                          4.90305573e-01,   6.41573191e-01,   7.97414899e-01,
                          8.78416598e-01,   8.70251834e-01,   8.74914408e-01,
                          8.76829743e-01,   8.17233682e-01,   8.58114183e-01,
                          8.98543239e-01,   9.13038552e-01,   9.29486036e-01,
                          9.46359336e-01,   9.17621017e-01,   9.02639747e-01,
                          8.67565155e-01,   8.69378626e-01,   8.85623693e-01,
                          8.79755557e-01,   5.21777332e-01,   4.19612527e-01,
                          4.52742934e-01,   4.92171794e-01,   5.61220586e-01,
                          5.85328341e-01,   5.75961351e-01,   6.19935632e-01,
                          7.56993949e-01,   9.12152708e-01,   9.28634882e-01,
                          9.12323654e-01,   9.13239241e-01,   9.02483821e-01,
                          8.71725917e-01,   8.81099582e-01,   9.02644098e-01,
                          8.84074628e-01,   6.89821362e-01,   5.55105269e-01,
                          6.57501638e-01,   7.81062841e-01,   9.04786527e-01,
                          8.89975131e-01,   9.18993235e-01,   9.45758462e-01,
                          9.15594876e-01,   9.34278011e-01,   9.08806264e-01,
                          9.29480314e-01,   9.24650490e-01,   9.07932460e-01,
                          9.06224906e-01,   7.83257246e-01,   7.68324316e-01,
                          8.53615463e-01,   8.57464433e-01,   8.47629249e-01,
                          8.68477285e-01,   8.79675984e-01,   9.43869293e-01,
                          8.93454850e-01,   8.93556118e-01,   8.79140377e-01,
                          9.40236688e-01,   8.83523703e-01,   9.18441951e-01,
                          8.48620951e-01,   8.83646548e-01,   8.60469341e-01,
                          8.94455314e-01,   9.18373108e-01,   8.78669918e-01,
                          8.84296477e-01,   8.79504979e-01,   9.33419287e-01,
                          9.23856378e-01,   9.34393406e-01,   9.01747346e-01,
                          8.91266644e-01,   9.16396439e-01,   9.09627736e-01,
                          9.37882781e-01,   9.18086052e-01,   9.21127796e-01,
                          8.80653203e-01,   8.84487271e-01,   8.81762147e-01,
                          8.72251093e-01,   8.64940763e-01,   8.97243261e-01,
                          9.41394806e-01,   9.41053212e-01,   9.25873637e-01,
                          8.79305899e-01,   8.79040658e-01,   9.03055549e-01,
                          9.09896255e-01,   9.00800645e-01,   9.33684051e-01,
                          9.30802047e-01,   9.26275015e-01,   9.01784301e-01,
                          8.83264601e-01,   9.01911259e-01,   8.98283303e-01,
                          8.93165946e-01,   8.95388305e-01,   9.23432946e-01,
                          9.66699600e-01,   9.93010819e-01,   9.24490392e-01,
                          9.54528093e-01,   8.98858190e-01,   8.63241494e-01,
                          8.58210504e-01,   8.45978141e-01,   9.14688349e-01,
                          9.05376256e-01,   9.37312603e-01,   8.82171571e-01,
                          9.17573273e-01,   9.32637691e-01,   9.15788889e-01,
                          9.30063426e-01,   9.35116827e-01,   9.38009977e-01,
                          9.36703265e-01,   9.56639707e-01,   9.46474731e-01,
                          9.01800871e-01,   8.81972909e-01,   9.14332807e-01,
                          9.28293645e-01,   8.76293957e-01,   8.92816126e-01,
                          8.87439609e-01,   9.09003496e-01,   9.21702981e-01,
                          9.32442844e-01,   9.49022412e-01,   9.01616931e-01,
                          9.48180139e-01,   9.14244652e-01,   9.20403898e-01,
                          9.33307171e-01,   9.31428254e-01,   9.13875520e-01,
                          9.00713265e-01,   8.94434273e-01,   9.04959202e-01,
                          8.92570198e-01,   8.88383031e-01,   8.81423354e-01,
                          8.32425356e-01,   7.76353657e-01,   7.99499452e-01,
                          7.92369843e-01,   8.37858796e-01,   9.21091497e-01,
                          9.16501939e-01,   9.09869075e-01,   7.46650398e-01,
                         -2.06363630e-02,  -2.45637670e-01,  -1.17861360e-01,
                          5.20496555e-02,   1.70153528e-01,   1.53278038e-01,
                          1.12789355e-01,   1.08253486e-01,   1.63531110e-01,
                          1.83986932e-01,   1.59581050e-01,   1.83988288e-01,
                          2.96254337e-01,   4.40517306e-01,   5.21069646e-01,
                          3.63631546e-01,  -1.47173405e-01,  -4.12708133e-01,
                         -4.43622053e-01,  -3.78147215e-01,  -3.66982609e-01,
                         -3.63980770e-01,  -3.88019830e-01,  -3.20350140e-01,
                         -3.02015871e-01,  -2.12314352e-01,  -1.21632479e-01,
                         -2.24198289e-02,   7.78030306e-02,   2.58107364e-01,
                          2.95392364e-01,   3.23416322e-01,   6.37855977e-02,
                         -4.36923802e-01,  -5.48467755e-01,  -5.38243949e-01,
                         -4.45994586e-01,  -4.33829397e-01,  -3.34650785e-01,
                         -2.73986250e-01,  -1.15959078e-01,  -3.40598673e-02,
                          6.42670551e-03,   7.16763288e-02,   3.66997272e-02,
                          9.65178758e-02,   1.06558450e-01,   1.56810269e-01,
                          1.90516219e-01,   2.22989827e-01,   2.47626200e-01,
                          3.16198409e-01,   9.13738012e-02,  -6.11968160e-01,
                         -8.32213819e-01,  -8.03663015e-01,  -7.44482636e-01,
                         -6.33855581e-01,  -6.47361159e-01,  -5.79510152e-01,
                         -5.51226735e-01,  -4.87615675e-01,  -5.10516107e-01,
                         -5.56289494e-01,  -6.18503630e-01,  -6.07655048e-01,
                         -5.89814723e-01,  -5.48747540e-01,  -5.23198187e-01,
                         -5.17284513e-01,  -4.77018535e-01,  -4.45642501e-01,
                         -3.90986294e-01,  -4.13750082e-01,  -4.47337747e-01,
                         -4.60534215e-01,  -4.93671507e-01,  -4.50185925e-01,
                         -4.10564691e-01,  -3.70994419e-01,  -3.67521077e-01,
                         -3.28144789e-01,  -2.66160458e-01,  -2.09760353e-01,
                         -1.16185658e-01,  -9.94726121e-02,  -8.28060582e-02,
                         -6.17697462e-02,  -2.76747756e-02,   7.04849586e-02,
                          8.70211422e-02,   9.76550281e-02,   3.54624689e-02,
                          3.20082158e-02,  -1.32395271e-02,  -2.23482866e-02,
                          1.85744651e-02,   5.37816808e-02,   5.26449308e-02,
                          1.28872052e-01,   2.47997150e-01,   2.46818647e-01,
                          2.59202063e-01,   2.13434339e-01,   1.96492910e-01,
                          2.05658123e-01,   1.39111593e-01,   1.19031921e-01,
                          9.11582485e-02,   6.01167977e-02,   8.34813789e-02,
                          3.86978537e-02,   5.68034910e-02,   3.76518816e-02,
                          3.53883170e-02,   1.82973698e-01,   2.22791269e-01,
                          9.97412279e-02,  -2.90769398e-01,  -4.24238026e-01,
                         -2.46286646e-01,  -5.33895418e-02,   4.21394743e-02,
                          1.30983859e-01,   1.45383984e-01,   3.18195820e-01,
                          4.21217382e-01,   4.26127523e-01,   3.82196903e-01,
                          4.66135949e-01,   5.50660610e-01,   6.58005774e-01,
                          4.74680305e-01,  -2.01044500e-01,  -4.15436149e-01,
                         -3.91754806e-01,  -2.61830568e-01,  -2.45459124e-01,
                         -2.42164344e-01,  -2.26560056e-01,  -2.15149403e-01,
                         -1.43565118e-01,  -1.69590220e-01,  -7.93705210e-02,
                         -1.07934147e-01,  -1.96613744e-02,   7.62248039e-02,
                          1.38745949e-01,   2.51849204e-01,   2.79528111e-01,
                          3.91069651e-01,   4.47353929e-01,   2.81911582e-01,
                         -2.92191859e-02,  -1.46929860e-01,  -8.36725309e-02,
                         -4.67715077e-02,  -8.57225731e-02,  -3.54871005e-02,
                         -4.05613147e-02,   9.23736244e-02,   1.69422910e-01,
                          2.32688665e-01,   3.28872055e-01,   4.28460568e-01,
                          5.19693494e-01,   4.98403460e-01,   2.48794794e-01,
                          1.61770850e-01,   1.53016612e-01,   1.82479158e-01,
                          9.50938165e-02,   7.38615692e-02,  -2.48443540e-02,
                         -1.63214117e-01,  -1.81732595e-01,  -1.36544719e-01,
                         -8.23087394e-02,   2.60065589e-02,   4.17015627e-02,
                          1.04664586e-01,   9.49493647e-02,   1.70529857e-01,
                          9.94434208e-02,   8.49030241e-02,   2.34567691e-02,
                         -3.26263509e-03,   7.38216564e-02,   1.71889812e-01,
                          3.17462355e-01,   3.78750384e-01,   5.39690673e-01,
                          7.38785565e-01,   8.13475311e-01,   8.02471757e-01,
                          4.15520996e-01,   3.36403191e-01,   3.36709142e-01,
                          4.26280230e-01,   4.46271986e-01,   4.11631763e-01,
                          3.89782369e-01,   4.06233251e-01,   4.17305529e-01,
                          4.07133609e-01,   4.36986774e-01,   5.07803917e-01,
                          4.64168847e-01,   4.78053898e-01,   4.37682420e-01,
                          4.86149967e-01,   5.34227133e-01,   4.85500455e-01,
                          5.53534985e-01,   5.62355220e-01,   5.74683249e-01,
                          4.24872577e-01,  -3.70307788e-02,  -1.85134411e-01,
                         -7.46278167e-02,   2.92387977e-02,   9.80944782e-02,
                          1.04630895e-01,   1.51394233e-01,   2.68552989e-01,
                          3.29718322e-01,   3.89914870e-01,   4.17354494e-01,
                          3.95419836e-01,   3.92242521e-01,   3.21560949e-01,
                          8.71902406e-02,  -2.61865347e-03,  -6.90533668e-02,
                         -1.18926808e-01,  -1.28588453e-01,  -1.99610338e-01,
                         -2.07590267e-01,  -2.13241190e-01,  -1.67974532e-01,
                         -1.95751429e-01,  -1.91255286e-01,  -2.07670763e-01,
                         -1.49070218e-01,  -1.42160788e-01,  -9.43892896e-02,
                         -4.18966748e-02,   1.71327312e-02,   3.03207878e-02,
                          8.07591081e-02,   1.03794396e-01,   1.14454836e-01,
                          1.59912929e-01,   2.17344835e-01,   2.91183472e-01,
                          2.50745356e-01,   2.88976312e-01,   1.72969863e-01,
                         -5.59040718e-02,  -1.74591407e-01,  -2.74437100e-01,
                         -3.51717502e-01,  -3.97839129e-01,  -4.41516608e-01,
                         -4.57315207e-01,  -4.29304302e-01,  -3.48908156e-01,
                         -2.16094926e-01,  -9.10264030e-02,   1.83846224e-02,
                          6.95389509e-03,   6.32360876e-02,   5.11060283e-02,
                          7.18912557e-02,   9.03179348e-02,   8.79466608e-02,
                          1.58282176e-01,   1.89671770e-01,   3.24449450e-01,
                          3.83985460e-01,   3.91352624e-01,   3.22926551e-01,
                          2.24478453e-01,   3.09066270e-02,  -1.43083274e-01,
                         -2.72685677e-01,  -4.29074883e-01,  -5.18384576e-01,
                         -5.61375916e-01,  -5.54152548e-01,  -5.43919206e-01,
                         -5.13952076e-01,  -4.52997506e-01,  -4.12430197e-01,
                         -3.57330769e-01,  -3.79298806e-01,  -4.20299232e-01,
                         -4.11164492e-01,  -3.90187711e-01,  -3.87396067e-01,
                         -3.70701969e-01,  -3.75329256e-01,  -3.36269945e-01,
                         -2.88131893e-01,  -2.62370497e-01,  -4.80195731e-01,
                         -8.01575840e-01,  -9.52711999e-01,  -8.45667243e-01,
                         -7.43500590e-01,  -7.26764739e-01,  -7.10240781e-01,
                         -7.36351132e-01,  -7.16350198e-01,  -6.97716773e-01,
                         -7.48381019e-01,  -6.95247829e-01,  -6.97449923e-01,
                         -6.77303672e-01,  -6.54406369e-01,  -6.08570099e-01,
                         -5.35270929e-01,  -4.80631471e-01,  -4.39980626e-01,
                         -4.04317647e-01,  -4.11285043e-01,  -4.94223207e-01,
                         -5.07401228e-01,  -6.62754476e-01,  -7.06047893e-01,
                         -7.38596261e-01,  -7.19861805e-01,  -6.87565804e-01,
                         -6.87890410e-01,  -6.55396938e-01,  -5.88944256e-01,
                         -5.68974614e-01,  -5.28207660e-01,  -5.16653657e-01,
                         -4.19416964e-01,  -3.52769256e-01,  -4.72095281e-01,
                         -8.78078222e-01,  -9.13527846e-01,  -9.30374742e-01,
                         -8.78859460e-01,  -7.51862645e-01,  -7.42609143e-01,
                         -7.33329892e-01,  -7.13096797e-01,  -6.84698999e-01,
                         -6.43157542e-01,  -6.62670434e-01,  -6.47639453e-01,
                         -6.20103240e-01,  -5.11146307e-01,  -4.17531729e-01,
                         -5.32720029e-01,  -9.10621047e-01,  -9.35941160e-01,
                         -9.08769369e-01,  -9.06253338e-01,  -8.72696996e-01,
                         -8.45717728e-01,  -8.41056347e-01,  -7.21737862e-01,
                         -6.92309260e-01,  -6.25819087e-01,  -5.86049020e-01,
                         -5.72521806e-01,  -6.56219959e-01,  -8.78248155e-01,
                         -9.14477587e-01,  -8.97209466e-01,  -9.15467799e-01,
                         -9.20305848e-01,  -9.25320864e-01,  -9.27201688e-01,
                         -8.58360946e-01,  -8.23210776e-01,  -8.63755643e-01,
                         -8.22672844e-01,  -7.36503065e-01,  -6.54751182e-01,
                         -5.87757647e-01,  -5.11867881e-01,  -4.48070675e-01,
                         -3.27498376e-01,  -3.17473561e-01,  -4.21957493e-01,
                         -8.73604119e-01,  -9.11924958e-01,  -9.30394113e-01,
                         -9.49582875e-01,  -9.05188620e-01,  -9.31608498e-01,
                         -8.93866420e-01,  -8.09516966e-01,  -8.29199612e-01,
                         -8.36791277e-01,  -8.28026593e-01,  -8.21128845e-01,
                         -7.95411170e-01,  -7.54818201e-01,  -6.56085312e-01,
                         -5.77493250e-01,  -6.06196582e-01,  -8.82263005e-01,
                         -9.19630110e-01,  -9.16539133e-01,  -9.35875654e-01,
                         -8.75424981e-01,  -8.05809319e-01,  -7.67570019e-01,
                         -7.27518499e-01,  -7.22451746e-01,  -6.97704017e-01,
                         -6.90540969e-01,  -7.70525575e-01,  -8.29378009e-01,
                         -8.44926715e-01,  -8.21580350e-01,  -7.94137299e-01,
                         -8.26936483e-01,  -9.12644923e-01,  -8.92446876e-01,
                         -8.75991285e-01,  -9.28982139e-01,  -9.42508459e-01,
                         -9.47579563e-01,  -9.22193885e-01,  -8.83943915e-01,
                         -8.66944611e-01,  -8.83114576e-01,  -8.54476094e-01,
                         -8.44663382e-01,  -7.66785860e-01,  -6.27969205e-01,
                         -5.22984207e-01,  -4.24709320e-01,  -4.33056295e-01,
                         -3.61047298e-01,  -2.87430733e-01,  -2.31869936e-01,
                         -3.27772677e-01,  -7.59087741e-01,  -9.14013267e-01,
                         -9.03057575e-01,  -8.08254361e-01,  -6.94430709e-01,
                         -6.04881585e-01,  -5.19279599e-01,  -4.29958314e-01,
                         -3.32614928e-01,  -3.07878584e-01,  -2.98497647e-01,
                         -2.60475487e-01,  -1.43486679e-01,  -1.23796305e-02,
                          9.67423320e-02,  -5.64161595e-03,  -3.79345208e-01,
                         -5.03658772e-01,  -4.96350884e-01,  -4.38735276e-01,
                         -4.68304843e-01,  -4.41180557e-01,  -4.23026502e-01,
                         -3.82032990e-01,  -3.05405736e-01,  -3.14721495e-01,
                         -2.71941662e-01,  -1.35435611e-01,  -9.00451094e-02,
                         -5.46620823e-02,  -5.61599806e-02,  -3.30391265e-02,
                         -2.28360854e-02,   2.15353910e-02,   6.95624650e-02,
                          1.29256323e-01,   2.40614951e-01,   2.80890942e-01,
                          3.58928740e-01,   4.77382064e-01,   6.27184629e-01,
                          6.81070387e-01,   4.83220637e-01,  -1.54546425e-01,
                         -3.35209429e-01,  -3.37329626e-01,  -2.38535270e-01,
                         -1.57328457e-01,  -1.83887482e-01,  -1.58371165e-01,
                         -2.03592062e-01,  -2.52137631e-01,  -3.43792468e-01,
                         -4.40473735e-01,  -4.92983341e-01,  -4.96395528e-01,
                         -4.50434774e-01,  -2.81387269e-01,  -1.81978434e-01,
                         -2.39817619e-01,  -4.93950039e-01,  -5.73719323e-01,
                         -5.28236210e-01,  -4.48302090e-01,  -3.39035124e-01,
                         -2.70142257e-01,  -1.55998096e-01,  -1.28789872e-01,
                         -4.75437045e-02,   6.07139692e-02,   2.37187937e-01,
                          3.37301016e-01,   3.72823089e-01,   4.62163955e-01,
                          5.81360400e-01,   7.27191567e-01,   7.39261925e-01,
                          5.63117146e-01,  -1.17108196e-01,  -3.48043412e-01,
                         -3.45147491e-01,  -2.69915730e-01,  -1.54835686e-01,
                         -6.87233210e-02,  -1.09808110e-02,   2.47025080e-02,
                          2.68050544e-02,   4.63153198e-02,   1.12505585e-01,
                          8.04014653e-02,   1.08366996e-01,   5.39802127e-02,
                          1.01167411e-01,   1.34346411e-01,   1.86383575e-01,
                          3.00038934e-01,   3.09525490e-01,   2.48187304e-01,
                          1.09689318e-01,   9.37224478e-02,   4.50358950e-02,
                          7.10199773e-02,   1.71861909e-02,   2.95566525e-02,
                          5.54652922e-02,   1.13477416e-01,   2.15676680e-01,
                          2.39984021e-01,   3.25022846e-01,   5.03386617e-01,
                          6.13082230e-01,   7.22280085e-01,   7.72249877e-01,
                          8.77565861e-01,   8.30272138e-01,   6.87056899e-01,
                          6.57289252e-02,  -1.25089094e-01,  -1.36927947e-01,
                         -1.21744096e-01,  -1.03609532e-01,  -1.36223689e-01,
                         -1.13260642e-01,  -6.79938942e-02,  -7.73244887e-04,
                          5.36311790e-02,   1.13587894e-01,   1.49060354e-01,
                          2.50071347e-01,   3.34833354e-01,   3.10493410e-01,
                          1.16595300e-02,  -7.87905827e-02,  -5.14563955e-02,
                          5.91699369e-02,   1.43319353e-01,   1.42329350e-01,
                          1.47673786e-01,   2.25936309e-01,   2.29561731e-01,
                          2.74569273e-01,   2.41175964e-01,   3.10452223e-01,
                          3.33084941e-01,   3.59234899e-01,   3.59252185e-01,
                          2.98214406e-01,   2.84249276e-01,   2.98414469e-01,
                          3.11824799e-01,   2.68381804e-01,   2.19806403e-01,
                          1.83617502e-01,   1.27859846e-01,   1.22042745e-01,
                          1.78903893e-01,   2.29019970e-01,   3.02615404e-01,
                          2.99808949e-01,   3.26915503e-01,   3.46942186e-01,
                          3.03900808e-01,   3.47526491e-01,   2.74826467e-01,
                          3.33007902e-01,   3.45083892e-01,   4.11077917e-01,
                          4.11977053e-01,   4.67844695e-01,   5.59878051e-01,
                          5.60927391e-01,   4.57454801e-01,  -1.93736292e-02,
                         -1.09160557e-01,  -4.78306562e-02,   3.36268023e-02,
                          1.13634370e-01,   1.29764110e-01,   1.14579827e-01,
                          2.09125832e-01,   2.67313361e-01,   3.53606641e-01,
                          3.66189778e-01,   3.47705752e-01,   3.38286698e-01,
                          3.87624621e-01,   5.34189284e-01,   6.30901158e-01,
                          5.02849102e-01,   2.97620464e-02,  -4.78836447e-02,
                          1.03653520e-01,   3.15415591e-01,   4.14718062e-01,
                          5.04410744e-01,   5.72519958e-01,   6.03109479e-01,
                          5.86606503e-01,   5.07232010e-01,   4.37495947e-01,
                          4.16721582e-01,   4.09437060e-01,   4.39652175e-01,
                          5.00030518e-01,   4.58104849e-01,   4.51206505e-01,
                          4.44332659e-01,   4.41048533e-01,   4.50053841e-01,
                          4.28994238e-01,   4.31812614e-01,   4.42348987e-01,
                          4.03136641e-01,   3.76333892e-01,   3.45307171e-01,
                          3.36980522e-01,   3.93724173e-01,   4.67869610e-01,
                          4.90652651e-01,   5.72026074e-01,   5.71934402e-01,
                          5.57194889e-01,   4.89618301e-01,   4.58698630e-01,
                          4.68011349e-01,   5.35628021e-01,   6.32212758e-01,
                          6.91298723e-01,   7.47542858e-01,   8.87036145e-01,
                          9.85411167e-01,   9.16858852e-01,   9.12677228e-01,
                          5.93957067e-01,   4.21204895e-01,   4.41541255e-01,
                          4.56972897e-01,   4.63123232e-01,   4.41912830e-01,
                          4.87403512e-01,   5.14300883e-01,   5.08392572e-01,
                          4.93249536e-01,   4.27966118e-01,   3.81089181e-01,
                          3.60672504e-01,   3.92405301e-01,   4.15555656e-01,
                          4.37192231e-01,   5.35192013e-01,   6.51930392e-01,
                          6.62806809e-01,   7.72208273e-01,   7.91962445e-01,
                          8.54525626e-01,   8.16366315e-01,   8.63126159e-01,
                          9.09206569e-01,   8.98678839e-01,   7.44270384e-01,
                          2.82334268e-01,   1.57060102e-01,   2.04477742e-01,
                          3.29555482e-01,   3.88404667e-01,   3.48009020e-01,
                          3.09138954e-01,   2.43916959e-01,   1.44993871e-01,
                          8.38412642e-02,  -5.29134832e-02,  -1.02484621e-01,
                         -1.68842599e-01,  -1.21677712e-01,  -9.05633047e-02,
                          2.26590876e-02,   1.35469854e-01,   2.17327669e-01,
                          3.21126550e-01,   3.94341409e-01,   4.08369392e-01,
                          4.06788021e-01,   4.03501928e-01,   2.86306351e-01,
                          1.74428716e-01,   1.60907760e-01,   1.67406321e-01,
                          1.97975785e-01,   2.78506517e-01,   3.28472942e-01,
                          3.12833279e-01,   2.78553039e-01,   2.69211829e-01,
                          3.03624660e-01,   3.38139534e-01,   3.52874011e-01,
                          3.24080974e-01,   2.89942741e-01,   2.79446542e-01,
                          2.43334189e-01,   1.32796749e-01,   7.09889606e-02,
                          7.81556815e-02,   8.08747187e-02,   1.50396600e-01,
                          1.73418060e-01,   2.27643356e-01,   2.39358544e-01,
                          2.79644877e-01,   2.97993124e-01,   4.30240989e-01,
                          4.78484809e-01,   3.95839721e-01,   1.33112758e-01,
                          7.99757168e-02,   1.55231655e-01,   2.98139572e-01,
                          3.63646775e-01,   4.50482070e-01,   5.13796508e-01,
                          5.61838567e-01,   5.59923470e-01,   5.50521255e-01,
                          5.45458674e-01,   5.78860283e-01,   5.73926687e-01,
                          6.38016284e-01,   7.47678041e-01,   7.55472839e-01,
                          7.40616322e-01,   4.48881358e-01,   3.99734646e-01,
                          3.49853009e-01,   4.08079058e-01,   4.27471459e-01,
                          4.31939334e-01,   5.18520355e-01,   6.40604854e-01,
                          7.33294129e-01,   8.09987068e-01,   8.44495952e-01,
                          8.71492088e-01,   9.29423630e-01,   9.48647797e-01,
                          9.42901671e-01,   9.07954276e-01,   9.00172889e-01,
                          8.78090739e-01,   7.02610672e-01,   6.37777090e-01,
                          7.02288747e-01,   7.94140816e-01,   8.72076392e-01,
                          8.23826849e-01,   9.04081106e-01,   9.31890726e-01,
                          9.20856059e-01,   9.23513889e-01,   9.10427928e-01,
                          9.04538751e-01,   8.46592903e-01,   8.37929964e-01,
                          8.53444278e-01,   8.76641452e-01,   8.92099798e-01,
                          8.91014040e-01,   9.36947942e-01,   9.01611090e-01,
                          9.18075860e-01,   8.97868872e-01,   5.62783122e-01,
                          3.39024901e-01,   4.21947151e-01,   5.99920452e-01,
                          6.61873162e-01,   6.35965049e-01,   7.60690093e-01,
                          9.02348876e-01,   9.14993763e-01,   9.14641738e-01,
                          9.11606550e-01,   9.12800908e-01,   9.13379371e-01,
                          9.15333986e-01,   9.07756686e-01,   8.67873192e-01,
                          8.64727080e-01,   9.02439952e-01,   8.99632871e-01,
                          8.80374312e-01,   6.18415475e-01,   5.28097630e-01,
                          5.99060535e-01,   6.81535006e-01,   7.13469982e-01,
                          7.28958249e-01,   7.36563027e-01,   7.95812070e-01,
                          7.45881915e-01,   6.91331267e-01,   6.62485659e-01,
                          7.09027469e-01,   7.46713400e-01,   7.36442327e-01,
                          7.46581435e-01,   8.09619725e-01,   8.93625915e-01,
                          8.82737756e-01,   8.68431091e-01,   6.85923636e-01,
                          7.26217210e-01,   7.95527399e-01,   8.82410884e-01,
                          9.09686863e-01,   9.31454122e-01,   9.39925253e-01,
                          9.27960992e-01,   8.83425236e-01,   8.20374012e-01,
                          7.74005115e-01,   8.04350138e-01,   7.92076588e-01,
                          8.57467830e-01,   8.91459823e-01,   8.79266143e-01,
                          8.79280210e-01,   8.70761633e-01,   8.85164559e-01,
                          8.92575622e-01,   8.39287043e-01,   7.89797843e-01,
                          8.09571683e-01,   7.38236666e-01,   7.27485716e-01,
                          6.82438910e-01,   7.16102898e-01,   6.65102184e-01,
                          6.64774001e-01,   6.62603259e-01,   7.28794754e-01,
                          7.24679828e-01,   7.35201478e-01,   7.43129790e-01,
                          8.05063426e-01,   7.77957380e-01,   8.12139809e-01,
                          7.68016636e-01,   7.41034865e-01,   6.93312883e-01,
                          6.91192269e-01,   6.83997095e-01,   7.00107157e-01,
                          7.44103432e-01,   7.43512809e-01,   6.91371083e-01,
                          6.99696898e-01,   7.07988918e-01,   7.25028694e-01,
                          5.82976520e-01,   1.79265976e-01,   8.30945969e-02,
                          8.68976638e-02,   1.59933835e-01,   1.83999509e-01,
                          1.91809312e-01,   1.89741611e-01,   2.44927540e-01,
                          2.50130683e-01,   1.84321925e-01,   3.98792401e-02,
                          2.45588552e-02,   9.20079127e-02,   1.37168631e-01,
                          2.10483193e-01,   2.11704746e-01,   2.48465493e-01,
                          3.07743669e-01,   3.96358550e-01,   4.60873663e-01,
                          5.03952742e-01,   5.04657209e-01,   5.26902080e-01,
                          5.17072022e-01,   5.11115253e-01,   5.09330511e-01,
                          4.88555491e-01,   5.17482042e-01,   4.41600949e-01,
                          4.80538636e-01,   4.71430123e-01,   4.60907370e-01,
                          3.87153864e-01,  -9.43857804e-02,  -1.97212294e-01,
                         -1.75838411e-01,  -1.08316429e-01,  -1.68873575e-02,
                         -4.16148314e-03,   6.62229210e-02,   6.14088103e-02,
                          5.15787713e-02,   1.32269695e-01,   1.63342252e-01,
                          2.33222067e-01,   2.83099234e-01,   3.85194868e-01,
                          5.18502414e-01,   5.99674821e-01,   4.84361351e-01,
                         -3.44116911e-02,  -1.88027456e-01,  -1.55897856e-01,
                         -2.53252108e-02,   6.23498447e-02,   6.62804171e-02,
                          5.32030575e-02,  -2.03911345e-02,  -8.55797082e-02,
                         -1.49964556e-01,  -1.36031479e-01,  -1.60032913e-01,
                         -1.90596297e-01,  -1.51055038e-01,  -3.54229510e-02,
                          9.74177122e-02,   1.82689056e-01,   7.63148591e-02,
                         -4.75178003e-01,  -5.56728542e-01,  -5.73540211e-01,
                         -4.70840186e-01,  -4.41785902e-01,  -4.50072110e-01,
                         -4.18812901e-01,  -3.73320222e-01,  -4.05626655e-01,
                         -4.76267219e-01,  -4.77511227e-01,  -4.43378776e-01,
                         -3.59857500e-01,  -4.30483282e-01,  -5.61766386e-01,
                         -5.81373572e-01,  -5.23167789e-01,  -4.59505618e-01,
                         -4.44127470e-01,  -4.93749768e-01,  -5.42830706e-01,
                         -6.52444482e-01,  -7.41492033e-01,  -8.61300528e-01,
                         -9.02691603e-01,  -8.88367832e-01,  -8.17548215e-01,
                         -7.65214562e-01,  -7.53897309e-01,  -7.04661667e-01,
                         -6.84523523e-01,  -6.91510439e-01,  -7.19664156e-01,
                         -7.56735027e-01,  -7.66006470e-01,  -7.94845998e-01,
                         -7.99269974e-01,  -8.34161043e-01,  -9.48469698e-01,
                         -9.00778472e-01,  -8.64032149e-01,  -8.05977762e-01,
                         -8.07135046e-01,  -7.64357924e-01,  -7.47908771e-01,
                         -7.27630794e-01,  -8.09955597e-01,  -8.96003425e-01,
                         -8.83999944e-01,  -9.32922482e-01,  -8.97875845e-01,
                         -8.98775935e-01,  -9.07416880e-01,  -8.51481795e-01,
                         -7.73912847e-01,  -6.95523441e-01,  -7.71302879e-01,
                         -8.49244356e-01,  -8.66663516e-01,  -7.88447618e-01,
                         -7.46407449e-01,  -6.85117543e-01,  -5.45598567e-01,
                         -5.27547657e-01,  -5.96762598e-01,  -9.02004361e-01,
                         -9.18146610e-01,  -9.28544283e-01,  -9.12539840e-01,
                         -9.08343136e-01,  -9.24694598e-01,  -9.22908187e-01,
                         -9.30295289e-01,  -9.07082736e-01,  -9.36940312e-01,
                         -8.61702681e-01,  -8.35589707e-01,  -7.92051911e-01,
                         -7.43566692e-01,  -7.01157808e-01,  -6.27649784e-01,
                         -6.16820335e-01,  -6.37193620e-01,  -6.31477714e-01,
                         -5.78704596e-01,  -5.40985405e-01,  -5.39959252e-01,
                         -5.61490595e-01,  -6.06938243e-01,  -8.58382940e-01,
                         -9.16153789e-01,  -8.28644693e-01,  -7.77939200e-01,
                         -7.40522981e-01,  -7.42303848e-01,  -6.98189974e-01,
                         -7.02329993e-01,  -7.45084405e-01,  -8.79339516e-01,
                         -9.21865821e-01,  -9.14252520e-01,  -9.14459825e-01,
                         -8.16879869e-01,  -7.39484131e-01,  -7.13462651e-01,
                         -6.78674340e-01,  -6.52137876e-01,  -6.92703187e-01,
                         -7.08101988e-01,  -7.68325746e-01,  -8.40458989e-01,
                         -8.27514946e-01,  -8.57430816e-01,  -8.41393948e-01,
                         -8.92486274e-01,  -8.04488003e-01,  -7.93935776e-01,
                         -6.61814332e-01,  -5.08515418e-01,  -3.93148720e-01,
                         -3.47481340e-01,  -2.60402888e-01,  -1.99695081e-01,
                         -1.43771544e-01,  -1.53110430e-01,  -2.16535583e-01,
                         -6.07640028e-01,  -7.89096415e-01,  -8.42655361e-01,
                         -7.54845679e-01,  -6.80893898e-01,  -4.96932477e-01,
                         -3.98311943e-01,  -2.67392635e-01,  -2.39365250e-01,
                         -2.80677408e-01,  -3.81411195e-01,  -4.83352065e-01,
                         -5.37761629e-01,  -5.70464432e-01,  -5.48936605e-01,
                         -4.74107355e-01,  -4.06711370e-01,  -3.95360917e-01,
                         -3.38735551e-01,  -2.69158423e-01,  -1.35083973e-01,
                         -5.52954227e-02,  -3.69895287e-02,  -2.22812090e-02,
                         -2.59496365e-03,   7.93046430e-02,   2.31899872e-01,
                          2.97056437e-01,   3.61857831e-01,   4.49162096e-01,
                          5.46479821e-01,   5.67414224e-01,   4.04573292e-01,
                         -5.95353879e-02,  -1.48822978e-01,  -8.04299116e-02,
                          6.67288303e-02,   1.37244821e-01,   1.81849003e-01,
                          2.00756252e-01,   3.21537048e-01,   3.24380100e-01,
                          3.49314749e-01,   3.28670353e-01,   3.94231051e-01,
                          5.07606745e-01,   6.24054849e-01,   7.20065653e-01,
                          7.76696324e-01,   7.45411694e-01,   7.24806666e-01,
                          7.63657451e-01,   8.25788617e-01,   8.57025981e-01,
                          6.54357374e-01,   1.81587666e-01,  -7.22973747e-03,
                         -5.34610189e-02,   4.46402244e-02,   1.62731558e-01,
                          2.15517119e-01,   2.34218523e-01,   2.41394147e-01,
                          2.37875476e-01,   2.42844880e-01,   2.69571096e-01,
                          2.47618586e-01,   1.64496005e-01,   1.93909034e-01,
                          1.94860309e-01,   1.65289491e-01,  -7.53206015e-02,
                         -1.61595400e-02,   8.20026621e-02,   2.63386428e-01,
                          4.32575047e-01,   5.25538385e-01,   6.18141353e-01,
                          6.86060429e-01,   7.65981913e-01,   8.08577418e-01,
                          8.50983500e-01,   8.62722516e-01,   8.33050787e-01,
                          7.73380160e-01,   7.15590477e-01,   8.30294192e-01,
                          9.10243750e-01,   9.19646621e-01,   9.01361465e-01,
                          3.83680910e-01,   1.52628094e-01,   1.57889321e-01,
                          2.38956228e-01,   3.94015253e-01,   4.58917469e-01,
                          5.78690886e-01,   7.49737501e-01,   8.59153271e-01,
                          8.69364619e-01,   8.27422082e-01,   7.06435204e-01,
                          6.32210791e-01,   6.17008805e-01,   5.51230073e-01,
                          5.02749443e-01,   3.87577415e-01,   3.64816904e-01,
                          3.15589756e-01,   3.10511500e-01,   3.25686485e-01,
                          3.46185386e-01,   3.58392417e-01,   3.71596277e-01,
                          4.38135833e-01,   4.90170598e-01,   5.51517904e-01,
                          5.17502964e-01,   4.72347856e-01,   4.21385765e-01,
                          4.95288104e-01,   5.35553932e-01,   5.75429082e-01,
                          5.39003253e-01,   4.98080373e-01,   2.91711688e-01,
                          2.65951604e-01,   2.81235099e-01,   3.95140857e-01,
                          4.18965101e-01,   4.66511279e-01,   4.72318709e-01,
                          5.26384652e-01,   5.21677911e-01,   4.90385830e-01,
                          4.49125499e-01,   4.43007529e-01,   4.28283244e-01,
                          4.41683829e-01,   4.50695515e-01,   4.67684805e-01,
                          4.53924388e-01,   4.30746675e-01,   4.07205909e-01,
                          4.37101603e-01,   3.93634468e-01,   4.38434601e-01,
                          4.10519630e-01,   4.31460142e-01,   3.96598995e-01,
                          3.88254672e-01,   4.56262380e-01,   5.22241116e-01,
                          6.33366108e-01,   6.58872724e-01,   6.72342241e-01,
                          6.61284566e-01,   6.42767191e-01,   6.44442022e-01,
                          6.66455626e-01,   7.06529975e-01,   7.47555614e-01,
                          7.90735841e-01,   9.13513839e-01,   9.59644437e-01,
                          9.07400012e-01,   2.61694044e-01,   1.27463592e-02,
                          5.77795766e-02,   1.97490528e-01,   2.53531009e-01,
                          2.53974080e-01,   1.68535143e-01,   1.61076888e-01,
                          1.51502982e-01,   9.98644009e-02,   1.07926428e-01,
                          7.50897676e-02,   4.15084884e-02,   6.33509457e-02,
                          4.85809818e-02,   5.03845178e-02,   5.95095605e-02,
                          2.13595349e-02,   9.77509283e-03,   8.95742141e-03,
                          3.11912932e-02,   8.74544159e-02,   7.88850412e-02,
                          1.20095655e-01,   1.22614264e-01,   1.20608084e-01,
                          1.22806564e-01,   1.20756298e-01,   1.32851735e-01,
                          7.35507905e-02,   6.93265870e-02,   3.90448272e-02,
                          2.24099103e-02,   7.26984441e-03,  -3.60873602e-02,
                         -4.34469394e-02,   7.46736955e-03,   5.16313016e-02,
                          8.45403075e-02,  -1.43719800e-02,  -2.79336721e-01,
                         -3.31143290e-01,  -2.72049576e-01,  -1.44154876e-01,
                         -1.11289017e-01,  -6.84623644e-02,  -4.91723083e-02,
                          1.77937392e-02,   9.20260325e-03,  -1.05286367e-01,
                         -4.04342026e-01,  -4.73400146e-01,  -4.58440304e-01,
                         -4.17980373e-01,  -4.27144825e-01,  -4.50745076e-01,
                         -4.59774524e-01,  -3.87161374e-01,  -3.71777982e-01,
                         -3.44650060e-01,  -4.05228525e-01,  -4.44295645e-01,
                         -4.42499846e-01,  -4.52898592e-01,  -3.64500731e-01,
                         -3.58111709e-01,  -3.06151956e-01,  -2.83399284e-01,
                         -1.59041420e-01,  -1.31713778e-01,  -2.77829111e-01,
                         -6.55940771e-01,  -7.50722587e-01,  -6.92322373e-01,
                         -6.19554043e-01,  -5.55806816e-01,  -5.49551547e-01,
                         -4.65244621e-01,  -3.81647259e-01,  -3.36668104e-01,
                         -3.12226593e-01,  -2.96770751e-01,  -2.79322654e-01,
                         -2.79361367e-01,  -2.77438313e-01,  -3.24263990e-01,
                         -3.76381785e-01,  -4.23953235e-01,  -4.22367096e-01,
                         -4.07396525e-01,  -3.40885341e-01,  -3.59588563e-01,
                         -2.67232269e-01,  -1.86989203e-01,  -1.05085686e-01,
                         -1.78420991e-01,  -5.48690140e-01,  -6.14823401e-01,
                         -5.75384140e-01,  -4.87589926e-01,  -4.76426840e-01,
                         -5.03767729e-01,  -4.64547992e-01,  -4.30390209e-01,
                         -3.71788830e-01,  -4.06920820e-01,  -3.59512746e-01,
                         -3.12761664e-01,  -2.65198350e-01,  -2.99935997e-01,
                         -5.47279835e-01,  -6.42877996e-01,  -6.14074528e-01,
                         -5.75583160e-01,  -5.86439550e-01,  -5.60896635e-01,
                         -4.94374186e-01,  -4.23187584e-01,  -3.42561811e-01,
                         -3.56347531e-01,  -2.91031301e-01,  -2.40365416e-01,
                         -1.96450919e-01,  -2.73674816e-01,  -6.53028429e-01,
                         -7.39233792e-01,  -7.12333143e-01,  -6.36383712e-01,
                         -5.35148799e-01,  -4.61435109e-01,  -4.45388585e-01,
                         -3.85016680e-01,  -3.13032895e-01,  -2.06076667e-01,
                         -2.24918708e-01,  -2.81834364e-01,  -5.57974577e-01,
                         -5.86150348e-01,  -5.67598343e-01,  -4.84504938e-01,
                         -4.82951283e-01,  -4.98222023e-01,  -5.07788718e-01,
                         -4.81650978e-01,  -4.48018283e-01,  -4.18850005e-01,
                         -3.13521236e-01,  -2.04113841e-01,  -1.20220780e-01,
                         -2.32699022e-01,  -6.90104067e-01,  -8.13418210e-01,
                         -8.33302379e-01,  -7.39841700e-01,  -6.77639067e-01,
                         -6.39720559e-01,  -6.05849385e-01,  -5.90245724e-01,
                         -5.38123369e-01,  -5.35213172e-01,  -5.75395644e-01,
                         -5.53648293e-01,  -5.45052350e-01,  -5.07249057e-01,
                         -4.76317883e-01,  -4.46289897e-01,  -4.63151038e-01,
                         -4.93458271e-01,  -4.27214831e-01,  -3.48761380e-01,
                         -3.11703235e-01,  -3.96240801e-01,  -6.70429647e-01,
                         -7.78765261e-01,  -7.47567713e-01,  -7.14829743e-01,
                         -6.69447660e-01,  -5.98322928e-01,  -5.01378417e-01,
                         -4.61432278e-01,  -4.22970921e-01,  -3.78360987e-01,
                         -3.20823342e-01,  -4.00610059e-01,  -4.32715237e-01,
                         -5.22622168e-01,  -4.74264175e-01,  -4.29133147e-01,
                         -3.89685273e-01,  -3.96252781e-01,  -3.75924140e-01,
                         -3.96024108e-01,  -3.62247765e-01,  -4.00463164e-01,
                         -3.49572897e-01,  -3.18814337e-01,  -2.39743933e-01,
                         -2.11031824e-01,  -1.56283274e-01,  -1.08801872e-01,
                         -1.17851850e-02,   3.49363275e-02,   3.53215113e-02,
                          3.65689280e-03,   4.79353182e-02,   1.41034514e-01,
                          2.72525996e-01,   3.14379305e-01,   2.81457037e-01,
                          4.38833958e-04,  -1.09077625e-01,  -1.23794772e-01,
                         -8.04344118e-02,  -7.72994906e-02,  -2.88995262e-02,
                          1.93346292e-02,   3.07871494e-02,   1.64464395e-02,
                          3.93566191e-02,   4.72077392e-02,   4.03796844e-02,
                          1.68658141e-02,   1.12807220e-02,   3.98540348e-02,
                          7.97762424e-02,   6.91573694e-02,  -6.19524792e-02,
                         -5.41726053e-02,   3.17343883e-02,   1.59526281e-02,
                          6.16994351e-02,   1.22923665e-01,   1.75292388e-01,
                          2.61367619e-01,   3.19281459e-01,   3.62425715e-01,
                          4.19931322e-01,   3.87302279e-01,   3.73467416e-01,
                          3.49931002e-01,   3.85196656e-01,   3.77832681e-01,
                          4.03655529e-01,   3.34289670e-01,   3.65163088e-01,
                          3.51560146e-01,   3.94917637e-01,   4.18655038e-01,
                          4.23632294e-01,   4.27309513e-01,   4.11894739e-01,
                          3.80122304e-01,   4.13122952e-01,   4.01351899e-01,
                          3.94614041e-01,   4.13732111e-01,   4.26119298e-01,
                          4.62704241e-01,   4.19168293e-01,   4.52489197e-01,
                          5.66246688e-01,   5.86846471e-01,   5.68274140e-01,
                          2.42659137e-01,   1.99888229e-01,   2.63873994e-01,
                          3.84175032e-01,   4.41208363e-01,   4.96462971e-01,
                          4.98264611e-01,   4.67376769e-01,   4.32040215e-01,
                          3.98364305e-01,   4.06549305e-01,   4.39184189e-01,
                          4.63489383e-01,   5.93857527e-01,   6.65692508e-01,
                          6.53499246e-01,   5.64693153e-01,   3.09736311e-01,
                          2.80995548e-01,   3.49898160e-01,   3.82274330e-01,
                          4.08247143e-01,   3.88521016e-01,   3.85141104e-01,
                          4.33692753e-01,   3.85497212e-01,   3.69295806e-01,
                          3.65836918e-01,   4.44461405e-01,   5.24593771e-01,
                          4.56328630e-01,   1.43321529e-01,   2.95445900e-02,
                          1.62107330e-02,   7.33300671e-02,   9.04815346e-02,
                          1.48703352e-01,   2.10204095e-01,   2.89248616e-01,
                          3.16004753e-01,   3.43272805e-01,   3.84052217e-01,
                          4.26815778e-01,   5.15964210e-01,   5.70543468e-01,
                          6.03533030e-01,   6.04370892e-01,   5.90389669e-01,
                          6.33748651e-01,   6.28908575e-01,   6.30255163e-01,
                          6.27790630e-01,   6.70269847e-01,   7.70250380e-01,
                          7.99095035e-01,   6.98739231e-01,   1.78987324e-01,
                          7.38605410e-02,   9.72458571e-02,   2.06206575e-01,
                          2.72312015e-01,   2.88613647e-01,   3.43918115e-01,
                          4.26868528e-01,   5.07133186e-01,   5.79681396e-01,
                          5.68099797e-01,   6.08822107e-01,   4.75564450e-01,
                          1.70904309e-01,   8.28836262e-02,   5.97244352e-02,
                          7.10418448e-02,   7.74110183e-02,   4.72276621e-02,
                          1.01949915e-01,   1.76603496e-01,   2.06799746e-01,
                          1.79086328e-01,   1.57781318e-01,   1.97917446e-01,
                          2.52093583e-01,   2.60800302e-01,   3.01878721e-01,
                          2.95974672e-01,   3.41836482e-01,   3.40065926e-01,
                          3.83563906e-01,   4.01570827e-01,   4.60178554e-01,
                          4.51847076e-01,   4.77874398e-01,   5.12414277e-01,
                          5.15673876e-01,   5.59647381e-01,   5.93270123e-01,
                          5.81026256e-01,   6.27130866e-01,   6.43539727e-01,
                          7.02542782e-01,   6.39945388e-01,   6.54981375e-01,
                          5.76920986e-01,   5.63650429e-01,   5.41229606e-01,
                          4.77069676e-01,   4.51230735e-01,   4.21157330e-01,
                          4.38948721e-01,   4.49799776e-01,   4.46577728e-01,
                          4.73799139e-01,   4.56611395e-01,   4.85612035e-01,
                          4.65668559e-01,   4.87040728e-01,   5.21122396e-01,
                          6.11546636e-01,   7.14653432e-01,   8.02462220e-01,
                          9.02675390e-01,   9.02079225e-01,   8.61812592e-01,
                          8.62085462e-01,   8.78968418e-01,   4.15257633e-01,
                          2.46799096e-01,   2.41884947e-01,   2.95596451e-01,
                          2.98580408e-01,   2.14122415e-01,   1.75944492e-01,
                          1.80429831e-01,   3.06919783e-01,   3.64058852e-01,
                          3.88566971e-01,   3.72655958e-01,   1.91859186e-01,
                          1.85988680e-01,   2.37105504e-01,   2.84802079e-01,
                          3.24834645e-01,   2.73035109e-01,   2.09162489e-01,
                          1.85571685e-01,   1.78021520e-01,   1.94020867e-01,
                          2.51989812e-01,   2.68531352e-01,   3.09057683e-01,
                          3.48979115e-01,   3.26305360e-01,   1.87867343e-01,
                         -1.80821016e-01,  -3.28820854e-01,  -3.12692910e-01,
                         -2.67123163e-01,  -1.24305040e-01,  -1.17217399e-01,
                         -8.42068717e-02,  -6.10985495e-02,  -2.62498241e-02,
                         -6.92479089e-02,  -1.48261443e-01,  -2.35475078e-01,
                         -2.22952425e-01,  -1.96032807e-01,  -1.75560921e-01,
                         -8.62352401e-02,  -6.03951514e-02,  -5.18023558e-02,
                         -4.39838730e-02,  -2.34647957e-03,   3.52069698e-02,
                          1.68361086e-02,   5.01763932e-02,   6.28770962e-02,
                          7.30115697e-02,   5.07837161e-03,  -2.98190027e-01,
                         -3.27266246e-01,  -2.21909538e-01,  -9.77946892e-02,
                         -1.68017671e-02,  -8.84838849e-02,  -4.44774292e-02,
                          3.91534418e-02,   8.72869790e-02,   5.97806051e-02,
                         -1.32434458e-01,  -1.48566812e-01,  -1.17943421e-01,
                         -3.01107783e-02,   4.62679798e-03,  -1.52740413e-02,
                          1.13092817e-03,   6.40529953e-03,   7.66395479e-02,
                          2.45165639e-02,  -3.43974531e-02,  -1.10392407e-01,
                         -1.40383095e-01,  -1.42934114e-01,  -1.43018782e-01,
                         -1.19407289e-01,  -1.25301421e-01,  -1.15916312e-01,
                         -7.85555243e-02,  -9.69129279e-02,  -6.01971895e-02,
                         -8.29673484e-02,  -7.67109543e-02,  -3.75941359e-02,
                          1.74429864e-02,   5.29676676e-02,   7.60706291e-02,
                          1.59034744e-01,   2.34798759e-01,   2.86692977e-01,
                          2.16397300e-01,  -6.51755705e-02,  -1.22372203e-01,
                         -6.25623092e-02,   5.74311651e-02,   1.19575687e-01,
                          1.51353791e-01,   1.56527206e-01,   2.36483917e-01,
                          2.55583018e-01,   2.72515506e-01,   2.97805846e-01,
                          3.49613994e-01,   4.07309711e-01,   4.57048804e-01,
                          4.54542309e-01,   4.67821479e-01,   4.45004046e-01,
                          4.90515858e-01,   5.12583315e-01,   5.04510105e-01,
                          5.14063299e-01,   5.75320125e-01,   7.53898263e-01,
                          8.26707780e-01,   7.14122713e-01,   2.09133044e-01,
                          3.84229906e-02,   2.35833824e-02,   7.37109855e-02,
                          1.21606678e-01,   8.12872201e-02,   5.08883111e-02,
                          5.17925955e-02,   9.84666273e-02,   8.07432309e-02,
                          4.45988216e-03,  -1.06719591e-01,  -1.61580205e-01,
                         -1.28578484e-01,  -1.04668424e-01,  -4.96524610e-02,
                          6.80002151e-04,   5.05276583e-02,   1.32109880e-01,
                          2.47494549e-01,   2.95068800e-01,   3.37716669e-01,
                          3.67749542e-01,   4.06769574e-01,   4.18199182e-01,
                          3.35136235e-01,   3.05462331e-02,  -8.28425288e-02,
                         -4.36219051e-02,   1.38943307e-02,   7.05882013e-02,
                          5.07908873e-02,   6.19546771e-02,   5.88947833e-02,
                          6.25180751e-02,   9.44976881e-02,   1.49658456e-01,
                          2.24367023e-01,   2.68681765e-01,   3.20143670e-01,
                          3.68292570e-01,   3.90899926e-01,   3.82740825e-01,
                          3.92514378e-01,   3.87222439e-01,   4.03722137e-01,
                          3.71468812e-01,   3.95488769e-01,   3.75799924e-01,
                          3.63566786e-01,   4.04905826e-01,   4.06537950e-01,
                          4.18421715e-01,   3.98039788e-01,   4.12643790e-01,
                          3.71590048e-01,   4.09230858e-01,   3.32033902e-01,
                          3.41288209e-01,   2.67852098e-01,   3.12463850e-01,
                          3.26193154e-01,   3.44254076e-01,   3.96066844e-01,
                          4.55399543e-01,   5.04637241e-01,   5.63911974e-01,
                          5.96226931e-01,   6.24449551e-01,   6.27874851e-01,
                          6.13283098e-01,   6.21244371e-01,   5.69916189e-01,
                          5.46620131e-01,   5.00405848e-01,   4.72850084e-01,
                          4.34234262e-01,   4.41655368e-01,   4.51403350e-01,
                          4.73959208e-01,   4.96187329e-01,   4.80938852e-01,
                          4.55615312e-01,   4.14120615e-01,   3.60529900e-01,
                          3.66009861e-01,   4.12677228e-01,   4.65766340e-01,
                          4.89076406e-01,   5.00433445e-01,   5.36293209e-01,
                          5.55334449e-01,   6.30976975e-01,   6.95997059e-01,
                          7.10469961e-01,   7.05446839e-01,   7.22641468e-01,
                          8.52348447e-01,   8.54022384e-01,   6.79087937e-01,
                          5.98645248e-02,  -8.55501145e-02,  -8.72209668e-02,
                         -5.03715575e-02,   2.27031414e-03,   3.96301411e-02,
                          9.34507102e-02,   1.29025146e-01,   1.54204160e-01,
                          1.48390859e-01,   1.73055917e-01,   1.67861566e-01,
                          1.98486432e-01,   2.34578580e-01,   2.74870664e-01,
                          2.97381401e-01,   3.15357268e-01,   2.24839270e-01,
                          2.03446239e-01,   1.81959882e-01,   1.96269095e-01,
                          2.40249887e-01,   2.73047805e-01,   2.58679777e-01,
                          2.34260798e-01,   2.14628533e-01,   1.28744081e-01,
                          2.31412668e-02,   2.59660985e-02,   6.94274828e-02,
                          2.02142611e-01,   2.22920895e-01,   2.18826681e-01,
                          3.18127275e-01,   3.80181015e-01,   4.99697983e-01,
                          5.55381358e-01,   6.09120250e-01,   6.18420362e-01,
                          6.24247134e-01,   7.00325906e-01,   7.63788164e-01,
                          7.79541850e-01,   5.81288755e-01,  -7.18689989e-03,
                         -1.73658907e-01,  -1.66491434e-01,  -7.92647302e-02,
                         -4.48820330e-02,  -4.44544517e-02,   1.08791135e-01,
                          2.70381451e-01,   4.80354548e-01,   5.45037568e-01,
                          5.75647712e-01,   6.15773499e-01,   6.13946319e-01,
                          6.47674322e-01,   6.45211697e-01,   5.09636045e-01,
                          4.46164310e-02,  -1.15571909e-01,  -1.11078754e-01,
                         -1.55130448e-02,   1.48341745e-01,   1.96632177e-01,
                          2.32554719e-01,   3.33770454e-01,   4.36261088e-01,
                          4.61866319e-01,   4.57386822e-01,   5.15362799e-01,
                          5.44684231e-01,   5.81015229e-01,   6.62004113e-01,
                          7.05958009e-01,   7.48122871e-01,   5.92398226e-01,
                          1.76368117e-01,   8.88197497e-02,   1.68748260e-01,
                          2.52498239e-01,   2.56163418e-01,   1.68968588e-01,
                          2.05471650e-01,   2.48564497e-01,   3.02081376e-01,
                          2.91523516e-01,   2.80404449e-01,   2.16891885e-01,
                          1.94629550e-01,   2.65078038e-01,   3.51741940e-01,
                          3.75222743e-01,   4.17584598e-01,   5.30221939e-01,
                          5.98861456e-01,   4.76224452e-01,  -9.07741487e-02,
                         -2.45808646e-01,  -1.77057639e-01,  -2.34338380e-02,
                          9.27677453e-02,   2.07598314e-01,   2.35835269e-01,
                          2.33208761e-01,   1.81921795e-01,   1.30455181e-01,
                          1.02332711e-01,   9.21128318e-02,   5.47067598e-02,
                          1.17284209e-01,   1.68845147e-01,   2.51704216e-01,
                          1.60193309e-01,   1.35293856e-01,   8.67798850e-02,
                          3.79151553e-02,   4.79209945e-02,   1.16337398e-02,
                         -3.81209925e-02,  -8.04807544e-02,  -8.47234949e-02,
                         -3.84910144e-02,   3.50959823e-02,   2.56159697e-02,
                          8.05100128e-02,   1.03346184e-01,   2.14206889e-01,
                          2.23149002e-01,   3.24527353e-01,   3.96217138e-01,
                          3.87694448e-01,   2.19123706e-01,  -2.34065592e-01,
                         -3.01490039e-01,  -2.12289423e-01,  -3.82376984e-02,
                          1.05756916e-01,   1.57784134e-01,   1.37824655e-01,
                          1.91662475e-01,   2.69352585e-01,   2.23150864e-01,
                          1.52560487e-01,   1.13276474e-01,   1.60432562e-01,
                          7.64999613e-02,   5.18735163e-02,   2.36240681e-02,
                          7.94792995e-02,   1.68611676e-01,   1.62954032e-01,
                          2.06732675e-01,   2.42885694e-01,   3.81680846e-01,
                          4.10350591e-01,   4.07939345e-01,   4.27616209e-01,
                          3.78364325e-01,   3.34981620e-01,   2.49583125e-01,
                          2.05510139e-01,   2.46281043e-01,   4.00300533e-01,
                          5.09468794e-01,   5.97445250e-01,   5.37301540e-01,
                          8.12433437e-02,  -8.52505639e-02,  -5.73013015e-02,
                          8.58119652e-02,   1.63166955e-01,   1.54241383e-01,
                          1.21931642e-01,   1.10728264e-01,   1.42998978e-01,
                          1.28353983e-01,   1.17138401e-01,   6.41040951e-02,
                          5.84191233e-02,   1.54730037e-01,   2.78243870e-01,
                          2.71579206e-01,   2.39730880e-01,   1.98614120e-01,
                          2.07387060e-01,   2.33686462e-01,   2.49761224e-01,
                          2.34540373e-01,   2.10578427e-01,   1.30058989e-01,
                          6.11090735e-02,  -5.49143227e-03,  -1.77191272e-02,
                          6.65234923e-02,   7.90951401e-02,   9.91281047e-02,
                          1.76216707e-01,   2.90817291e-01,   3.97610992e-01,
                          4.55780536e-01,   4.23979193e-01,   4.07973379e-01,
                          3.78022760e-01,   3.95213872e-01,   3.81037503e-01,
                          3.82656455e-01,   3.60943288e-01,   3.02287251e-01,
                          2.09277973e-01,   2.11382702e-01,   2.23229110e-01,
                          2.62067795e-01,   2.75720805e-01,   3.07637155e-01,
                          3.48956347e-01,   4.20818657e-01,   4.21569318e-01,
                          4.84057814e-01,   5.30875921e-01,   5.51177144e-01,
                          5.97779512e-01,   5.90411723e-01,   5.91513634e-01,
                          6.04875445e-01,   6.12630665e-01,   7.36829162e-01,
                          7.93613970e-01,   6.70637906e-01,   1.52175993e-01,
                          7.26368278e-02,   1.41400650e-01,   2.08947361e-01,
                          1.96151227e-01,   8.65024701e-02,   8.39735940e-02,
                          2.04277053e-01,   2.67668903e-01,   2.47486383e-01,
                          2.62177795e-01,   3.00854921e-01,   2.79317915e-01,
                          2.21207008e-01,  -2.21620686e-02,  -4.87362891e-02,
                         -4.30406183e-02,   3.03231901e-03,   1.72650199e-02,
                         -1.29349371e-02,  -1.10986000e-02,  -2.93044746e-02,
                          3.89688946e-02,   1.35251820e-01,   1.79531693e-01,
                          2.47799113e-01,   3.28270823e-01,   4.42202926e-01,
                          5.74598432e-01,   6.26799107e-01,   5.07807255e-01,
                          8.90605003e-02,   1.56102162e-02,   9.18780416e-02,
                          2.23776385e-01,   2.46689811e-01,   3.17810267e-01,
                          3.85924578e-01,   4.73873794e-01,   5.81358552e-01,
                          6.81472719e-01,   7.15045512e-01,   6.38250172e-01,
                          2.86026210e-01,   1.97803646e-01,   2.15477467e-01,
                          2.74185389e-01,   2.73467153e-01,   3.01843703e-01,
                          3.37935507e-01,   3.90550345e-01,   4.32338059e-01,
                          4.17785674e-01,   4.77414906e-01,   5.61377287e-01,
                          6.29506946e-01,   5.24183273e-01,  -1.45577881e-02,
                         -1.95662871e-01,  -1.92942217e-01,  -8.87599066e-02,
                          7.42874108e-03,   3.60889733e-02,   5.59739657e-02,
                          1.48126572e-01,   3.14569890e-01,   3.84511024e-01,
                          4.90711629e-01,   5.79930961e-01,   7.00962901e-01,
                          7.77901232e-01,   9.03163612e-01,   8.83712351e-01,
                          7.81603754e-01,   2.48257235e-01,   3.08980956e-03,
                         -4.55849916e-02,  -1.71790067e-02,  -7.15351244e-03,
                         -3.33807506e-02,  -4.63059172e-02,  -1.79789159e-02,
                          3.29374783e-02,   3.59485932e-02,   2.24122610e-02,
                          4.39554118e-02,   1.07863992e-01,   1.29509956e-01,
                          6.37683943e-02,  -8.36504400e-02,  -1.11784324e-01,
                         -1.78085621e-02,   6.29279166e-02,   1.41368613e-01,
                          1.98159561e-01,   1.40420794e-01,   1.34138629e-01,
                          1.69738337e-01,   2.01091915e-01,   2.14118183e-01,
                          1.83942050e-01,   1.89706236e-01,   2.14062795e-01,
                          2.43078336e-01,   2.75114775e-01,   2.58785784e-01,
                          2.15585589e-01,   1.74151331e-01,   1.42862305e-01,
                          1.18754774e-01,   9.33562964e-02,   6.74614236e-02,
                          3.95862795e-02,   9.38394573e-03,   1.87042654e-02,
                          2.07814053e-02,   3.35457548e-02,   3.25733162e-02,
                          3.68538238e-02,   1.02156937e-01,   1.63773373e-01,
                          1.99346557e-01,   2.42548227e-01,   2.68467337e-01,
                          3.00600678e-01,   3.24022025e-01,   3.43676031e-01,
                          4.02410537e-01,   4.71513182e-01,   5.15247107e-01,
                          5.18632233e-01,   5.48132420e-01,   5.75169206e-01,
                          5.39522469e-01,   4.99515325e-01,   4.58127081e-01,
                          4.70529675e-01,   5.04727125e-01,   4.96754408e-01,
                          4.92324978e-01,   3.93283874e-01,   3.29562515e-01,
                          3.07521701e-01,   3.22451144e-01,   3.93201649e-01,
                          4.49831367e-01,   4.84954327e-01,   4.72470254e-01,
                          4.42050934e-01,   4.25160050e-01,   3.79034579e-01,
                          3.30052495e-01,   2.88157642e-01,   2.33698070e-01,
                          2.41456553e-01,   2.69066185e-01,   2.64141738e-01,
                          2.41613671e-01,   2.32490391e-01,   2.14825556e-01,
                          2.65947431e-01,   2.64023840e-01,   2.83801973e-01,
                          2.97867358e-01,   3.04354817e-01,   2.90378302e-01,
                          3.25125813e-01,   3.20908755e-01,   2.99818099e-01,
                          2.95746744e-01,   3.25879693e-01,   3.40965599e-01,
                          3.43379140e-01,   3.50397110e-01,   3.35909337e-01,
                          3.09749991e-01,   3.06350112e-01,   3.42380881e-01,
                          3.68296444e-01,   3.63247633e-01,   2.91838884e-01,
                          2.32123926e-01,   1.30334750e-01,   4.27057408e-02,
                         -4.22451738e-03,  -2.69505754e-03,  -2.40254756e-02,
                         -3.05564553e-02,  -1.77296263e-03,   6.57400070e-03,
                         -7.99051952e-03,  -1.70628875e-02,  -5.24492078e-02,
                         -4.58062515e-02,  -2.95974836e-02,  -6.62984177e-02,
                         -6.40579909e-02,  -5.50528988e-02,  -2.11814232e-02,
                         -1.21926805e-02,  -2.97982600e-02,  -2.54248027e-02,
                         -2.05242112e-02,  -1.89863164e-02,  -1.13320770e-03,
                          1.10524045e-02,  -6.59694001e-02,  -1.16466716e-01,
                         -1.14786573e-01,  -9.79352593e-02,  -8.70197564e-02,
                         -6.86052442e-02,  -6.02832474e-02,  -6.21705800e-02,
                         -3.48409712e-02,  -2.88637057e-02,   1.83275789e-02,
                          1.67284980e-02,   1.86892375e-02,   2.29155179e-02,
                          4.99767177e-02,   8.00927132e-02,   1.18132636e-01,
                          1.50773212e-01,   1.66582569e-01,   2.17160523e-01,
                          2.20863074e-01,   2.41167977e-01,   2.70991176e-01,
                          2.86258191e-01,   2.91526526e-01,   3.05293590e-01,
                          2.94645995e-01,   2.88266718e-01,   2.79179007e-01,
                          2.77998030e-01,   3.18063408e-01,   3.15064788e-01,
                          3.12540382e-01,   3.25781912e-01,   3.76652390e-01,
                          3.54532808e-01,   1.33698687e-01,  -5.01353264e-01,
                         -6.88129842e-01,  -6.41058505e-01,  -5.14236629e-01,
                         -4.58980858e-01,  -4.24141943e-01,  -3.47839832e-01,
                         -2.42300481e-01,  -1.75533548e-01,  -1.08984545e-01,
                         -2.81596724e-02,   2.80485731e-02,  -1.71518493e-02,
                         -2.86942035e-01,  -3.80789995e-01,  -3.68143737e-01,
                         -3.42679560e-01,  -3.13649029e-01,  -3.11166912e-01,
                         -3.13072145e-01,  -2.82058537e-01,  -2.62607068e-01,
                         -2.01066822e-01,  -1.73414484e-01,  -1.39800638e-01,
                         -9.05841440e-02,  -4.49686646e-02,  -4.00698325e-03,
                          2.10318528e-02,   5.77020179e-03,   8.39992054e-03,
                         -2.10838132e-02,   1.71866640e-02,   5.90902455e-02,
                          6.97143450e-02,  -4.29660501e-03,  -2.48777375e-01,
                         -3.20334256e-01,  -3.04643750e-01,  -2.34576553e-01,
                         -1.95163727e-01,  -1.81119248e-01,  -1.73578829e-01,
                         -1.70446903e-01,  -1.76730275e-01,  -1.64693505e-01,
                         -1.64559126e-01,  -1.18217714e-01,  -9.58869904e-02,
                         -5.06646708e-02,  -1.68967471e-02,   1.27463173e-02,
                          2.82979347e-02,   5.10806069e-02,   6.73917234e-02,
                          5.51093556e-02,   5.48790433e-02,   4.46589366e-02,
                          6.25574961e-02,   9.61508751e-02,   1.45540059e-01,
                          1.71024457e-01,   1.58955336e-01,   1.37434214e-01,
                          1.42457530e-01,   1.67494655e-01,   2.19011948e-01,
                          2.43768752e-01,   2.91918099e-01,   3.24012607e-01,
                          4.00643945e-01,   4.65384871e-01,   5.32018423e-01,
                          6.04687691e-01,   6.60962939e-01,   7.20563412e-01,
                          7.22899616e-01,   7.38741577e-01,   7.31849790e-01,
                          6.98856175e-01,   6.94934368e-01,   7.21169651e-01,
                          7.34165370e-01,   7.35960901e-01,   7.20276833e-01,
                          6.70554698e-01,   6.37682676e-01,   6.25699282e-01,
                          6.98203981e-01,   7.70045161e-01,   7.87197411e-01,
                          7.98288226e-01,   8.23737264e-01,   8.31961036e-01,
                          8.49809825e-01,   7.97006071e-01,  -2.02641025e-01,
                         -5.29572785e-01,  -5.08292317e-01,  -3.53555322e-01,
                         -3.11288863e-01,  -2.67304003e-01,  -1.98504910e-01,
                         -7.14537576e-02,  -9.66053829e-03,  -1.44850805e-01,
                         -1.71797872e-01,  -1.88842684e-01,  -1.10856459e-01,
                         -5.94447181e-02,  -1.09635629e-02,   2.85486635e-02,
                          6.14080280e-02,   5.43063879e-02,   3.05806268e-02,
                         -5.45877554e-02,  -2.44280353e-01,  -2.98721343e-01,
                         -3.31349254e-01,  -2.76485324e-01,  -2.56571889e-01,
                         -2.66200483e-01,  -2.81894296e-01,  -3.30799788e-01,
                         -3.40252727e-01,  -3.59609216e-01,  -3.35725307e-01,
                         -3.18431705e-01,  -3.08208197e-01,  -3.22182745e-01,
                         -2.91844815e-01,  -2.25201279e-01,  -2.20160887e-01,
                         -2.66540676e-01,  -5.29255569e-01,  -6.27242386e-01,
                         -6.61098719e-01,  -6.43800020e-01,  -6.63036764e-01,
                         -6.48282945e-01,  -6.07093871e-01,  -5.68905175e-01,
                         -5.39893508e-01,  -5.42895317e-01,  -5.23655772e-01,
                         -5.66827297e-01,  -5.13562500e-01,  -4.88600314e-01,
                         -4.62689370e-01,  -4.43882048e-01,  -3.78628880e-01,
                         -3.48650157e-01,  -3.36596906e-01,  -2.94798702e-01,
                         -2.05080926e-01,  -1.16312854e-01,  -8.30725133e-02,
                         -3.03924158e-02,  -8.60965718e-03,  -6.70540286e-03,
                          1.74053516e-02,  -3.11999721e-03,   3.22343297e-02,
                          6.74515441e-02,   6.55514225e-02,   1.08309917e-01,
                          2.10382670e-01,   2.95005977e-01,   3.44331801e-01,
                          4.47660178e-01,   5.68893492e-01,   6.57848120e-01,
                          5.16677380e-01,  -1.33559993e-02,  -1.87933594e-01,
                         -1.69905543e-01,  -8.59350041e-02,  -3.38396318e-02,
                         -5.37590906e-02,  -8.16197246e-02,  -8.51143077e-02,
                         -5.39090000e-02,  -1.42368544e-02,  -8.98483023e-03,
                          1.35214580e-02,   9.85835940e-02,   1.76791698e-01,
                          2.73385495e-01,   3.41685772e-01,   3.50790173e-01,
                          3.86063725e-01,   3.58758837e-01,   3.09736818e-01,
                          2.26539254e-01,   1.68999091e-01,   1.91699088e-01,
                          2.05367550e-01,   2.83916026e-01,   3.01639110e-01,
                          3.89317930e-01,   4.87631977e-01,   7.00300097e-01,
                          8.65785837e-01,   7.35252082e-01,   1.53012142e-01,
                          1.61429141e-02,   6.66245148e-02,   2.26392955e-01,
                          2.73982584e-01,   2.72490144e-01,   2.66613573e-01,
                          2.80833840e-01,   2.93283045e-01,   2.75659263e-01,
                          2.42546529e-01,   2.17202976e-01,   2.08722815e-01,
                          2.40538076e-01,   2.75038630e-01,   2.99013555e-01,
                          2.79890925e-01,   2.82480866e-01,   2.82223850e-01,
                          3.26035738e-01,   3.83520305e-01,   4.39176172e-01,
                          4.70742375e-01,   4.88096386e-01,   5.16541362e-01,
                          5.95931172e-01,   6.40235603e-01,   6.85390472e-01,
                          7.09831953e-01,   7.67143846e-01,   8.71684790e-01,
                          8.59790206e-01,   7.63004482e-01,   3.12978685e-01,
                          2.65697420e-01,   3.59197706e-01,   5.09925604e-01,
                          5.91165423e-01,   6.12167895e-01,   6.68338835e-01,
                          6.87350214e-01,   7.47417748e-01,   7.36986756e-01,
                          7.32866228e-01,   7.83089995e-01,   8.67705822e-01,
                          9.07703698e-01,   8.13927054e-01,   3.41769159e-01,
                          1.96419314e-01,   1.94047585e-01,   2.48590156e-01,
                          2.89553851e-01,   2.99407393e-01,   3.28149498e-01,
                          3.64284903e-01,   4.17329788e-01,   3.87963980e-01,
                          3.39741409e-01,   2.79798925e-01,   2.85194993e-01,
                          3.28243941e-01,   4.24586445e-01,   4.89218056e-01,
                          5.39922297e-01,   5.47128320e-01,   5.33706903e-01,
                          5.15877545e-01,   4.97739822e-01,   4.64217663e-01,
                          4.58584577e-01,   3.93948525e-01,   4.26758945e-01,
                          4.70664918e-01,   4.68213558e-01,   3.56360286e-01,
                         -8.64000544e-02,  -1.42609522e-01,  -7.91312978e-02,
                          5.15423007e-02,   1.76923513e-01,   2.57610172e-01,
                          3.22484761e-01,   3.24060768e-01,   3.13247144e-01,
                          3.68946820e-01,   3.95271629e-01,   3.95293802e-01,
                          3.12776983e-01,   2.85912216e-01,   3.83322299e-01,
                          4.80851889e-01,   4.36032474e-01,   7.04786777e-02,
                          6.44905353e-03,   9.44008678e-02,   2.58102447e-01,
                          3.13812822e-01,   3.15277457e-01,   3.15655172e-01,
                          3.71134609e-01,   3.80272597e-01,   3.97730827e-01,
                          4.33252960e-01,   5.05498350e-01,   4.88689870e-01,
                          3.90159845e-01,   1.13670915e-01,   2.89835986e-02,
                          1.74635276e-02,   9.56474990e-02,   1.60905570e-01,
                          1.77112356e-01,   2.20597178e-01,   2.07416594e-01,
                          2.21619248e-01,   2.49387816e-01,   2.73591578e-01,
                          2.93253511e-01,   2.88135350e-01,   2.82648861e-01,
                          2.40222231e-01,   2.52809107e-01,   2.27285266e-01,
                          2.16921017e-01,   1.82106107e-01,   2.03760907e-01,
                          2.32460022e-01,   2.91943878e-01,   3.34034741e-01,
                          2.87489593e-01,   2.22262725e-01,   2.14685917e-01,
                          2.22803578e-01,   2.67663211e-01,   3.00265640e-01,
                          3.24721158e-01,   2.70121664e-01,   2.38097399e-01,
                          2.07266718e-01,   2.55479604e-01,   3.02134693e-01,
                          3.18681747e-01,   3.27350646e-01,   2.96480775e-01,
                          2.86812007e-01,   3.01937580e-01,   3.15425098e-01,
                          3.11461210e-01,   3.04322541e-01,   3.02113324e-01,
                          2.90880173e-01,   2.42572263e-01,   1.81164280e-01,
                          1.20139457e-01,   1.22289613e-01,   1.31417230e-01,
                          1.40014991e-01,   1.70504257e-01,   2.32464820e-01,
                          2.70270407e-01,   3.48769486e-01,   3.42141539e-01,
                          3.45128447e-01,   3.36658388e-01,   3.22753549e-01,
                          3.34960222e-01,   3.33395720e-01,   3.39871764e-01,
                          3.67416561e-01,   3.57205391e-01,   3.69413346e-01,
                          3.42229813e-01,   3.42859358e-01,   3.93604845e-01,
                          4.20894653e-01,   4.75028157e-01,   4.08533692e-01,
                          3.19347858e-01,   2.62005329e-01,   2.22656935e-01,
                          1.86267540e-01,   2.13713273e-01,   2.50536203e-01,
                          2.92604685e-01,   2.96576679e-01,   3.80782872e-01,
                          5.10420740e-01,   5.41666508e-01,   4.24926251e-01,
                         -1.55554205e-01,  -2.95221537e-01,  -2.64280081e-01,
                         -1.97170585e-01,  -1.15549311e-01,  -1.10421501e-01,
                         -4.85321581e-02,   3.07914242e-02,   1.04606621e-01,
                          1.51391432e-01,   1.61561802e-01,   1.32835329e-01,
                          1.12857014e-01,   8.40093568e-02,   1.14608720e-01,
                          1.12115793e-01,   7.94833228e-02,   4.84511741e-02,
                          2.47385073e-02,   5.70206009e-02,   6.81867450e-02,
                          8.01273137e-02,   1.10881276e-01,   1.28223747e-01,
                          1.70748547e-01,   1.58157662e-01,   1.61636323e-01,
                          1.48781791e-01,   1.84541121e-01,   2.06419319e-01,
                          2.27528334e-01,   2.22117916e-01,   2.67489672e-01,
                          3.31962168e-01,   3.84891868e-01,   3.29997718e-01,
                          7.24947751e-02,   1.69249368e-03,   3.32111344e-02,
                          6.67365193e-02,   1.11196265e-01,   1.41617581e-01,
                          1.25467569e-01,   1.49650618e-01,   1.26158357e-01,
                          1.18944153e-01,   1.11608095e-01,   8.24461356e-02,
                          9.54248235e-02,   6.36928380e-02,   8.90467986e-02,
                          1.01750039e-01,   1.42605513e-01,   1.39239997e-01,
                          1.18825436e-01,   1.64283872e-01,   2.43384048e-01,
                          3.08403403e-01,   2.26838812e-01,  -2.14407474e-01,
                         -3.17021966e-01,  -2.84337044e-01,  -1.62020177e-01,
                         -4.50040996e-02,  -3.17663997e-02,  -1.74642317e-02,
                         -9.35856439e-03,   7.86006302e-02,   2.04056725e-01,
                          2.88765728e-01,   3.50690752e-01,   3.83893698e-01,
                          4.98905361e-01,   6.51244462e-01,   7.15956569e-01,
                          5.23153663e-01,  -1.55358940e-01,  -3.24386418e-01,
                         -3.29188704e-01,  -2.09371924e-01,  -1.28580123e-01,
                         -5.79101853e-02,  -2.31098733e-03,   9.68220457e-02,
                          1.93136975e-01,   2.63664871e-01,   2.57089764e-01,
                          2.20161662e-01,  -8.16245154e-02,  -8.30551982e-02,
                         -6.11560941e-02,   3.09686642e-02,   8.26589093e-02,
                          7.35545978e-02,   6.05942383e-02,   7.36111403e-02,
                          6.34187311e-02,   8.37501232e-03,  -2.54177541e-01,
                         -3.41467589e-01,  -2.90612727e-01,  -2.16180474e-01,
                         -1.25757620e-01,  -5.43054268e-02,  -4.70570028e-02,
                         -1.11164609e-02,   1.31420149e-02,   1.51513482e-03,
                          3.27511914e-02,   9.42826178e-03,   5.22817448e-02,
                          9.94365364e-02,   1.72684029e-01,   2.92790741e-01,
                          3.25146973e-01,   2.02285141e-01,  -1.67204380e-01,
                         -2.83603817e-01,  -1.93875834e-01,  -8.11774731e-02,
                          2.44696699e-02,   1.14339113e-01,   1.65666565e-01,
                          2.02528238e-01,   2.21993223e-01,   2.06552535e-01,
                          2.10063726e-01,   2.66481370e-01,   2.97487110e-01,
                          3.11547965e-01,   4.08906609e-01,   5.32502413e-01,
                          6.39944375e-01,   5.27005434e-01,  -1.15059346e-01,
                         -3.34346503e-01,  -2.91439921e-01,  -1.87114194e-01,
                         -7.95230865e-02,  -1.03328370e-01,  -1.38386950e-01,
                         -1.05342768e-01,  -1.02900304e-01,  -9.43972617e-02,
                         -1.19053341e-01,  -6.68878257e-02,  -1.66868921e-02,
                          2.97818761e-02,   9.47941691e-02,   1.02111205e-01,
                          1.34556070e-01,   1.89802885e-01,   1.60097256e-01,
                          2.33759835e-01,   2.96432644e-01,   3.42161059e-01,
                          3.45919281e-01,   3.59834015e-01,   4.54136580e-01,
                          5.13631284e-01,   3.75281990e-01,  -1.26996875e-01,
                         -2.87548363e-01,  -1.82283834e-01,  -5.86183853e-02,
                          3.14195938e-02,   2.48910468e-02,   4.51400466e-02,
                          1.41459376e-01,   1.38491064e-01,   1.27826884e-01,
                          7.86680654e-02,   8.95510316e-02,   1.13166682e-01,
                          7.91937262e-02,  -1.51882485e-01,  -1.69935867e-01,
                         -1.51439294e-01,  -9.79796946e-02,  -8.86098146e-02,
                         -1.46139592e-01,  -1.33143932e-01,  -1.12192445e-01,
                         -8.12561437e-02,  -9.14469585e-02,  -5.56913577e-03,
                          2.68205665e-02,   2.71222815e-02,  -5.64894937e-02,
                         -3.31453025e-01,  -3.98297608e-01,  -3.96769911e-01,
                         -3.18426460e-01,  -2.62487322e-01,  -2.64011353e-01,
                         -2.20140085e-01,  -1.77352190e-01,  -1.37985915e-01,
                         -8.84277895e-02,  -8.72246474e-02,  -2.06808206e-02,
                         -1.66703649e-02,   3.06230336e-02,   5.55246957e-02,
                          1.08893611e-01,   1.17792659e-01,   1.13923989e-01,
                          1.64364666e-01,   1.44134015e-01,   6.42017722e-02,
                         -2.03116372e-01,  -2.12908208e-01,  -1.06530443e-01,
                         -2.49709021e-02,   3.30771618e-02,   7.58203045e-02,
                          1.24320164e-02,   1.88792292e-02,   7.08283633e-02,
                          9.49619710e-02,   1.04309276e-01,   1.62144288e-01,
                          2.48254105e-01,   2.77174443e-01,   1.59539104e-01,
                         -3.74997377e-01,  -4.27330941e-01,  -4.20501620e-01,
                         -3.08964521e-01,  -2.44217739e-01,  -2.38311172e-01,
                         -1.45778403e-01,   3.89851443e-02,   1.46050513e-01,
                          1.99572399e-01,   2.05862939e-01,   1.75416008e-01,
                          1.27955243e-01,   1.42719015e-01,   1.81210563e-01,
                          2.69878447e-01,   2.09362462e-01,  -1.36953279e-01,
                         -2.55572408e-01,  -2.36922532e-01,  -1.20711714e-01,
                         -8.02569389e-02,  -3.85009088e-02,  -1.17692407e-02,
                          3.82533483e-02,   8.29048753e-02,   1.10822186e-01,
                          1.44224241e-01,   1.62181586e-01,   1.47109032e-01,
                          9.79515538e-02,   6.09938242e-02,   2.74138115e-02,
                          7.32339546e-02,   1.32621825e-01,   1.30199477e-01,
                          8.52301344e-02,   2.28472278e-02,  -1.60934739e-02,
                         -1.37766942e-01,  -1.45074770e-01,  -1.14483640e-01,
                          1.41349584e-02,   1.40239134e-01,   1.40528336e-01,
                          1.25370324e-01,   1.38606995e-01,   2.60332555e-01,
                          3.89126062e-01,   3.73712480e-01,   3.57504755e-01,
                          4.29986447e-01,   4.48817164e-01,   4.94177848e-01,
                          4.59399760e-01,   4.56954479e-01,   4.47528720e-01,
                          4.48353559e-01,   4.51220065e-01,   4.49129820e-01,
                          3.90832603e-01,   3.71977985e-01,   3.54620248e-01,
                          4.00964230e-01,   3.95100564e-01,   3.87534738e-01,
                          3.71124357e-01,   3.93496275e-01,   4.38103914e-01,
                          4.06036645e-01,   3.82461011e-01,   3.89095813e-01,
                          4.55505550e-01,   4.95284021e-01,   5.02138853e-01,
                          4.84911263e-01,   4.99573380e-01,   5.25868058e-01,
                          5.18044710e-01,   4.46159422e-01,   1.45269901e-01,
                          9.80013534e-02,   1.39639109e-01,   1.85957789e-01,
                          2.23131150e-01,   1.83612913e-01,   2.30077341e-01,
                          2.09387690e-01,   2.44744480e-01,   2.62295246e-01,
                          2.74044186e-01,   2.70476341e-01,   2.04210371e-01,
                          2.14970723e-01,   2.53987938e-01,   2.80761838e-01,
                          2.67150670e-01,   2.37587675e-01,   2.64595538e-01,
                          2.95451909e-01,   3.01450372e-01,   3.01282138e-01,
                          2.49193400e-01,   2.64241129e-01,   2.59860396e-01,
                          2.66219586e-01,   2.19046921e-01,   3.16580236e-02,
                         -1.14822350e-02,   2.85214204e-02,   3.78781334e-02,
                          1.22391365e-01,   1.36011258e-01,   1.54262647e-01,
                          2.16526330e-01,   2.45587453e-01,   2.54303694e-01,
                          3.15605611e-01,   3.28362703e-01,   3.69732082e-01,
                          3.57039213e-01,   3.67952883e-01,   3.44818175e-01,
                          3.16486239e-01,   1.37271494e-01,   8.13900754e-02,
                          7.13326931e-02,   1.03267565e-01,   1.28093705e-01,
                          1.31453812e-01,   1.47741839e-01,   1.49459198e-01,
                          1.69914395e-01,   1.57431990e-01,   1.27927348e-01,
                          1.52911901e-01,   1.76836282e-01,   2.05382183e-01,
                          1.92511499e-01,   2.33434558e-01,   2.99142957e-01,
                          3.59128237e-01,   3.14063191e-01,   8.18770900e-02,
                          6.89059496e-02,   8.71301815e-02,   1.46702930e-01,
                          2.22486869e-01,   2.21293539e-01,   2.08390236e-01,
                          2.32749000e-01,   2.43788972e-01,   2.43359387e-01,
                          2.75258988e-01,   2.94904202e-01,   3.53240341e-01,
                          3.34661901e-01,   3.63440663e-01,   3.67246658e-01,
                          3.87720495e-01,   3.22906226e-01,   5.94827868e-02,
                          4.84688990e-02,   5.30956425e-02,   1.03701435e-01,
                          1.38161004e-01,   1.90745801e-01,   2.57509887e-01,
                          2.91636556e-01,   3.42367589e-01,   3.34793687e-01,
                          4.18062866e-01,   3.93459439e-01,   3.42014521e-01,
                          3.86415012e-02,   5.18553017e-04,   4.98783477e-02,
                          1.29415125e-01,   1.93450436e-01,   1.99543819e-01,
                          2.21742988e-01,   2.61754990e-01,   2.55720466e-01,
                          3.10940385e-01,   3.58634531e-01,   4.06047910e-01,
                          4.03260499e-01,   4.76391226e-01,   6.31336808e-01,
                          6.65484428e-01,   5.29048026e-01,   8.62489194e-02,
                         -4.91945371e-02,   2.82240696e-02,   1.32385939e-01,
                          1.98515162e-01,   2.03692049e-01,   2.40482360e-01,
                          3.49528104e-01,   5.05075395e-01,   5.90241432e-01,
                          5.46533406e-01,   2.02051476e-01,   7.40981996e-02,
                          9.87096801e-02,   1.88461438e-01,   2.37255618e-01,
                          2.83672988e-01,   2.75610447e-01,   3.33437771e-01,
                          2.90751368e-01,   2.55541503e-01,   1.37349650e-01,
                          3.03184874e-02,   4.24295180e-02,   1.01191208e-01,
                          1.84105143e-01,   2.75048494e-01,   3.66057277e-01,
                          4.75416362e-01,   5.01511693e-01,   4.55706149e-01,
                          4.29447204e-01,   3.70797008e-01,   4.20685381e-01,
                          4.22840357e-01,   4.69300777e-01,   5.04773915e-01,
                          4.86233830e-01,   4.25191164e-01,   3.90861630e-02,
                         -2.86524091e-02,  -3.53301945e-03,   7.81766623e-02,
                          4.97857891e-02,   6.51331395e-02,   5.41590452e-02,
                          1.11648180e-01,   1.36399657e-01,   1.16484500e-01,
                          1.17034549e-02,  -1.28769547e-01,  -1.59138128e-01,
                         -1.53371871e-01,  -1.99128270e-01,  -2.22258613e-01,
                         -2.69994140e-01,  -2.59787858e-01,  -2.84331262e-01,
                         -2.88610727e-01,  -3.44129533e-01,  -3.15453202e-01,
                         -2.77954310e-01,  -2.12199166e-01,  -1.16043732e-01,
                         -1.15078893e-02,   2.94709927e-03,  -4.80400175e-02,
                         -8.69312286e-02,  -1.19894579e-01,  -1.59789860e-01,
                         -1.84924707e-01,  -1.69265822e-01,  -1.98649153e-01,
                         -2.39297420e-01,  -2.73795128e-01,  -3.44782293e-01,
                         -3.16191137e-01,  -2.82386303e-01,  -2.83096492e-01,
                         -3.10814381e-01,  -3.67093831e-01,  -4.10377651e-01,
                         -3.96775454e-01,  -4.35069472e-01,  -5.15348673e-01,
                         -5.14212012e-01,  -5.09462476e-01,  -4.39256579e-01,
                         -3.95191610e-01,  -4.50149059e-01,  -5.07556081e-01,
                         -5.51475108e-01,  -5.01031578e-01,  -4.77020681e-01,
                         -4.76020098e-01,  -5.20354569e-01,  -5.66786110e-01,
                         -5.87105811e-01,  -6.04323208e-01,  -6.04502022e-01,
                         -5.91853023e-01,  -5.96385062e-01,  -5.62775612e-01,
                         -5.09356916e-01,  -5.12341082e-01,  -5.35229385e-01,
                         -5.51013529e-01,  -5.25763333e-01,  -5.37065148e-01,
                         -5.11959016e-01,  -4.92838651e-01,  -4.98461813e-01,
                         -4.93377268e-01,  -5.06636262e-01,  -5.57323456e-01,
                         -6.13941133e-01,  -6.42299771e-01,  -6.64095223e-01,
                         -6.99070275e-01,  -7.02236712e-01,  -7.13298261e-01,
                         -6.66849673e-01,  -6.96074128e-01,  -6.34263992e-01,
                         -6.44808471e-01,  -6.10598207e-01,  -5.69911897e-01,
                         -5.42116702e-01,  -5.72841763e-01,  -5.80154002e-01,
                         -5.96565068e-01,  -6.34677708e-01,  -6.67843640e-01,
                         -6.53032660e-01,  -6.45894885e-01,  -6.39406383e-01,
                         -6.50590360e-01,  -6.39217615e-01,  -6.68492854e-01,
                         -6.84977055e-01,  -6.69035614e-01,  -6.98462069e-01,
                         -7.03051865e-01,  -6.99120581e-01,  -7.11943269e-01,
                         -6.96139216e-01,  -6.87020242e-01,  -6.58950567e-01,
                         -6.29418850e-01,  -5.91188610e-01,  -5.77672184e-01,
                         -5.32897413e-01,  -5.18947840e-01,  -5.23013473e-01,
                         -5.32652795e-01,  -5.50452709e-01,  -5.90659559e-01,
                         -5.60791731e-01,  -5.50952494e-01,  -5.21659791e-01,
                         -5.26099503e-01,  -5.39716899e-01,  -5.48999786e-01,
                         -5.56078494e-01,  -5.90364575e-01,  -6.19820356e-01,
                         -6.70274138e-01,  -6.57224953e-01,  -6.71363175e-01,
                         -6.64683580e-01,  -6.61109447e-01,  -7.22176075e-01,
                         -7.42659450e-01,  -7.65449464e-01,  -7.85479605e-01,
                         -7.63086557e-01,  -7.46067822e-01,  -7.39194810e-01,
                         -7.12781191e-01,  -7.36720264e-01,  -7.20407248e-01,
                         -7.46013463e-01,  -7.45749116e-01,  -7.47539222e-01,
                         -7.40070820e-01,  -7.29808092e-01,  -6.93651736e-01,
                         -6.89493954e-01,  -6.74472034e-01,  -6.30321980e-01,
                         -5.93646765e-01,  -5.84454417e-01,  -5.86149752e-01,
                         -5.97802162e-01,  -5.93622684e-01,  -6.13356411e-01,
                         -6.20199978e-01,  -5.92984617e-01,  -6.03086054e-01,
                         -6.22769117e-01,  -6.27396464e-01,  -5.93168199e-01,
                         -5.34106314e-01,  -5.08820355e-01,  -4.99350071e-01,
                         -4.87168163e-01,  -4.76607889e-01,  -4.81662273e-01,
                         -4.83931273e-01,  -5.28735042e-01,  -5.51580608e-01,
                         -5.80958068e-01,  -5.93423963e-01,  -5.79525054e-01,
                         -5.45955420e-01,  -5.63542068e-01,  -5.18664598e-01,
                         -5.15099704e-01,  -4.76502806e-01,  -4.76308286e-01,
                         -4.91071373e-01,  -5.05552113e-01,  -5.22224009e-01,
                         -5.37509322e-01,  -5.53650320e-01,  -5.98856330e-01,
                         -6.34935915e-01,  -6.74948752e-01,  -6.54451430e-01,
                         -6.41160965e-01,  -6.33291781e-01,  -5.71395874e-01,
                         -5.29407680e-01,  -5.39624751e-01,  -5.15423000e-01,
                         -4.93985742e-01,  -4.66947943e-01,  -4.42431539e-01,
                         -4.11174923e-01,  -4.00129914e-01,  -3.91664684e-01,
                         -3.67132097e-01,  -3.74613345e-01,  -3.49375099e-01,
                         -3.76316488e-01,  -4.16549653e-01,  -4.17383224e-01,
                         -5.22617877e-01,  -6.12938583e-01,  -6.76517487e-01,
                         -6.31914377e-01,  -5.78678906e-01,  -5.35752773e-01,
                         -3.93259168e-01,  -3.25818002e-01,  -2.91783631e-01,
                         -2.67465383e-01,  -3.11400443e-01,  -2.92895824e-01,
                         -2.63677001e-01,  -2.68331617e-01,  -2.87300587e-01,
                         -2.67957121e-01,  -2.39068225e-01,  -2.09912658e-01,
                         -1.55937046e-01,  -1.66227788e-01,  -1.95047870e-01,
                         -2.68016458e-01,  -2.81825334e-01,  -2.80794382e-01,
                         -2.16997460e-01,  -1.82327777e-01,  -1.44676849e-01,
                         -1.51231304e-01,  -1.89326212e-01,  -2.22189784e-01,
                         -1.89783841e-01,  -1.47568122e-01,  -1.73484176e-01,
                         -1.89640954e-01,  -1.96511596e-01,  -2.51336068e-01,
                         -1.84639677e-01,  -1.49334237e-01,  -1.37824491e-01,
                         -1.39281198e-01,  -1.88291103e-01,  -2.40396738e-01,
                         -2.62655348e-01,  -3.14191967e-01,  -3.57393146e-01,
                         -3.91089648e-01,  -3.62996250e-01,  -3.12692255e-01,
                         -2.93792903e-01,  -3.13328475e-01,  -3.53824943e-01,
                         -3.32870156e-01,  -2.41411090e-01,  -1.23329177e-01,
                         -3.04307742e-03,   5.07267155e-02,   9.74358991e-02,
                          5.01371734e-02,   9.76510122e-02,   1.73562363e-01,
                          2.10220084e-01,   2.09354490e-01,   2.09798962e-01,
                          2.20460385e-01,   2.38906533e-01,   2.14352220e-01,
                          1.72550708e-01,   1.62142307e-01,   1.42024159e-01,
                          1.54394209e-01,   2.02809751e-01,   1.70749322e-01,
                          1.56105667e-01,   1.51458472e-01,   1.64097846e-01,
                          2.17260018e-01,   2.96908736e-01,   2.83771932e-01,
                          2.75194466e-01,   2.73218989e-01,   3.26294929e-01,
                          3.48423004e-01,   3.59084666e-01,   3.65505844e-01,
                          3.75422776e-01,   3.58675420e-01,   3.76267165e-01,
                          4.07252192e-01,   3.95318121e-01,   3.69898856e-01,
                          3.79292637e-01,   3.59623313e-01,   2.77126878e-01,
                          1.85113773e-01,   1.76693395e-01,   1.25761762e-01,
                          5.18968627e-02,   2.28431448e-02,  -1.16744256e-02,
                          2.43203510e-02,   1.23573840e-01,   2.12788373e-01,
                          2.57579029e-01,   3.67430359e-01,   4.60007370e-01,
                          4.79425460e-01,   4.51675594e-01,   4.38137442e-01,
                          4.52051550e-01,   4.56368983e-01,   5.52074671e-01,
                          6.22351527e-01,   6.35307431e-01,   6.40914619e-01,
                          6.60021126e-01,   6.76485240e-01,   7.18154073e-01,
                          6.97488070e-01,   6.61223888e-01,   6.60910010e-01,
                          7.03699291e-01,   7.19029844e-01,   7.11706460e-01,
                          7.74860442e-01,   8.14454615e-01,   7.97000170e-01,
                          7.71656573e-01,   7.56399095e-01,   7.55335927e-01,
                          7.59275436e-01,   7.13806987e-01,   6.42849088e-01,
                          5.66761911e-01,   5.51218748e-01,   5.29764354e-01,
                          5.10115325e-01,   5.55063665e-01,   6.46104455e-01,
                          7.09972084e-01,   7.59892881e-01,   7.89745331e-01,
                          8.12551022e-01,   7.98158348e-01,   8.07334006e-01,
                          8.28578651e-01,   7.92918682e-01,   7.72152066e-01,
                          8.22734654e-01,   8.96965742e-01,   9.09154415e-01,
                          9.14388597e-01,   9.13776040e-01,   9.20210719e-01,
                          9.07065928e-01,   9.13553238e-01,   9.06443059e-01,
                          9.08114970e-01,   9.07218993e-01,   9.05112624e-01,
                          9.04634893e-01,   8.95164371e-01,   8.30266058e-01,
                          7.16661990e-01,   6.58302486e-01,   6.46592796e-01,
                          6.84804916e-01,   7.27549136e-01,   7.63933659e-01,
                          7.84610569e-01,   8.06585073e-01,   8.31576765e-01,
                          8.79897058e-01,   9.06402826e-01,   9.05837595e-01,
                          8.97664964e-01,   9.00586247e-01,   9.13081765e-01,
                          9.13531363e-01,   9.14722741e-01,   9.02414620e-01,
                          9.08528924e-01,   9.00745034e-01,   9.03028488e-01,
                          9.06830013e-01,   9.03408885e-01,   9.13690329e-01,
                          9.02545035e-01,   9.01373506e-01,   9.08320546e-01,
                          8.90170872e-01,   8.66293490e-01,   8.58528912e-01,
                          8.80652070e-01,   9.11163390e-01,   9.07976866e-01,
                          9.10108209e-01,   9.04159427e-01,   8.97456050e-01,
                          8.96830499e-01,   8.99934769e-01,   9.03923929e-01,
                          8.99137020e-01,   8.93915892e-01,   9.04902816e-01,
                          8.97363305e-01,   8.79671991e-01,   9.07598495e-01,
                          9.11082566e-01,   9.15113688e-01,   8.66758347e-01,
                          8.26770365e-01,   8.30207944e-01,   8.33927333e-01,
                          8.31231475e-01,   8.49079072e-01,   8.81016910e-01,
                          8.95754993e-01,   9.08541501e-01,   9.06190574e-01,
                          9.04198527e-01,   9.01319265e-01,   9.01987314e-01,
                          8.97934556e-01,   9.03181851e-01,   9.00381923e-01,
                          9.03761625e-01,   8.97696972e-01,   8.43972564e-01,
                          7.55054295e-01,   6.68456674e-01,   6.32967591e-01,
                          6.02488399e-01,   5.43207288e-01,   5.22110164e-01,
                          5.08103788e-01,   4.79522139e-01,   4.91756350e-01,
                          5.13584495e-01,   5.25459886e-01,   5.48927069e-01,
                          5.46652794e-01,   5.42232811e-01,   5.21423042e-01,
                          5.06612897e-01,   4.97870684e-01,   4.61396545e-01,
                          4.16717619e-01,   3.99617672e-01,   4.43046451e-01,
                          4.94143724e-01,   5.17339408e-01,   5.71101785e-01,
                          6.38399541e-01,   6.67479455e-01,   6.51820958e-01,
                          5.63558340e-01,   4.84225214e-01,   4.36828196e-01,
                          4.10954595e-01,   3.90005618e-01,   3.54522973e-01,
                          3.17074805e-01,   3.08403134e-01,   3.15513372e-01,
                          3.28151345e-01,   3.41407508e-01,   3.50324839e-01,
                          3.47174525e-01,   3.37386519e-01,   3.19666743e-01,
                          2.60845989e-01,   1.88691020e-01,   1.35891467e-01,
                          9.86922756e-02,   6.48169219e-02,   2.92430427e-02,
                         -3.28392605e-03,  -1.41646340e-02,   6.36196742e-03,
                          6.55626319e-03,   1.85060664e-03,   3.75444745e-03,
                         -2.16563977e-03,   8.77640210e-03,   1.34193227e-02,
                          4.10463996e-02,   7.18614012e-02,   1.09920964e-01,
                          1.19600654e-01,   1.08801760e-01,   1.14424258e-01,
                          1.28886074e-01,   1.35379821e-01,   1.30133778e-01,
                          1.13398708e-01,   1.12990625e-01,   1.21612146e-01,
                          1.25217110e-01,   1.19297974e-01,   9.70781446e-02,
                          7.61629343e-02,   5.07072806e-02,   5.14543615e-02,
                          4.66584153e-02,   4.05713245e-02,   3.27241383e-02,
                          3.43838818e-02,   4.96097878e-02,   4.00942490e-02,
                         -1.92030482e-02,  -1.00739352e-01,  -1.82218686e-01,
                         -2.17110977e-01,  -2.10571036e-01,  -2.13419050e-01,
                         -2.19329417e-01,  -2.50550956e-01,  -2.78787494e-01,
                         -2.87722647e-01,  -3.18443328e-01,  -3.57562989e-01,
                         -3.98019075e-01,  -4.11394596e-01,  -3.62182349e-01,
                         -2.95800477e-01,  -2.58165210e-01,  -2.14743510e-01,
                         -1.72257319e-01,  -1.16135120e-01,  -6.81025982e-02,
                         -7.62290284e-02,  -1.17092609e-01,  -1.63759932e-01,
                         -1.86638027e-01,  -1.87374249e-01,  -1.41555205e-01,
                         -1.03451163e-01,  -1.15854643e-01,  -1.61445364e-01,
                         -1.92131028e-01,  -2.20490769e-01,  -2.25091308e-01,
                         -2.34516427e-01,  -2.45478779e-01,  -2.43585035e-01,
                         -2.54372954e-01,  -2.56324500e-01,  -2.51773596e-01,
                         -2.64627874e-01,  -2.91485101e-01,  -2.86694080e-01,
                         -2.59632021e-01,  -1.99655741e-01,  -1.48156703e-01,
                         -1.04634836e-01,  -9.24322829e-02,  -1.26430914e-01,
                         -9.01090205e-02,   8.65903962e-03,   2.30885744e-02,
                          1.69475283e-02,   2.32107136e-02,   2.41327621e-02,
                          2.55484451e-02,  -1.30748777e-02,  -5.67011833e-02,
                         -8.01926330e-02,  -7.96790123e-02,  -1.09452158e-01,
                         -1.76658034e-01,  -2.71080047e-01,  -3.70960683e-01,
                         -3.85816932e-01,  -3.65110338e-01,  -3.74517828e-01,
                         -3.79547626e-01,  -3.31664503e-01,  -2.67191678e-01,
                         -2.70905823e-01,  -3.28752488e-01,  -3.36509198e-01,
                         -2.71841139e-01,  -1.80645704e-01,  -7.79781938e-02,
                         -4.50495332e-02,  -6.74358755e-02,  -1.11871392e-01,
                         -1.59913331e-01,  -1.92558303e-01,  -2.21957862e-01,
                         -2.37569869e-01,  -2.18489319e-01,  -1.99572638e-01,
                         -1.85087472e-01,  -1.72372580e-01,  -1.45485193e-01,
                         -1.19066551e-01,  -1.13285303e-01,  -1.19978055e-01,
                         -1.43462867e-01,  -1.84000015e-01,  -2.27658406e-01,
                         -2.60515779e-01,  -2.91209877e-01,  -3.02293986e-01,
                         -3.37787747e-01,  -3.41939569e-01,  -3.28324914e-01,
                         -3.22100759e-01,  -2.96000570e-01,  -2.51968414e-01,
                         -2.16397122e-01,  -2.22792283e-01,  -2.42822185e-01,
                         -2.56813556e-01,  -2.66231149e-01,  -2.70393938e-01,
                         -2.79668778e-01,  -2.87090063e-01,  -3.11029524e-01,
                         -3.35738510e-01,  -3.38933915e-01,  -3.22068542e-01,
                         -2.95847118e-01,  -2.84224153e-01,  -2.65924901e-01,
                         -2.72205532e-01,  -2.90333182e-01,  -2.94405311e-01,
                         -2.73393989e-01,  -2.51540989e-01,  -2.41471365e-01,
                         -2.25969687e-01,  -1.99321911e-01,  -1.59898266e-01,
                         -1.46867737e-01,  -1.49319127e-01,  -1.42435074e-01,
                         -1.51931986e-01,  -1.57826841e-01,  -1.56304434e-01,
                         -1.39210865e-01,  -1.07105874e-01,  -6.84476346e-02,
                         -3.55749168e-02,  -1.48709165e-02,  -1.52112925e-02,
                         -4.02927808e-02,  -7.96545446e-02,  -1.13809332e-01,
                         -1.14955015e-01,  -1.22441687e-01,  -1.54084161e-01,
                         -1.82167709e-01,  -1.94016829e-01,  -2.01087281e-01,
                         -2.19729543e-01,  -2.18694672e-01,  -1.78830087e-01,
                         -1.61741093e-01,  -1.64429069e-01,  -1.72157198e-01,
                         -1.67613074e-01,  -1.69090226e-01,  -1.61428601e-01,
                         -1.51305303e-01,  -1.41030684e-01,  -1.37782663e-01,
                         -1.44863024e-01,  -1.63962260e-01,  -1.84223562e-01,
                         -1.71330914e-01,  -1.57214984e-01,  -1.31739929e-01,
                         -1.21989451e-01,  -1.26068920e-01,  -1.39849111e-01,
                         -1.54628426e-01,  -1.52126059e-01,  -1.41324937e-01,
                         -1.26925796e-01,  -7.74887800e-02,  -2.19304413e-02,
                          1.35272741e-02,   4.14008312e-02,   8.65565315e-02,
                          1.38236389e-01,   1.71655580e-01,   1.88920379e-01,
                          1.97272956e-01,   1.91228002e-01,   1.42785117e-01,
                          9.40039158e-02,   5.59911542e-02,   2.86169779e-02,
                          2.08940934e-02,   2.81581432e-02,   5.59413768e-02,
                          7.81055093e-02,   9.73790139e-02,   1.09757334e-01,
                          1.14629880e-01,   1.21904351e-01,   1.23677701e-01,
                          1.26952678e-01,   1.42793551e-01,   1.63226217e-01,
                          1.70917928e-01,   1.59719095e-01,   1.55785769e-01,
                          1.80610374e-01,   1.77234128e-01,   1.65112719e-01,
                          1.51366457e-01,   1.49455905e-01,   1.51317894e-01,
                          1.67760476e-01,   2.07974225e-01,   2.52591372e-01,
                          2.88030237e-01,   3.10835689e-01,   3.26213062e-01,
                          3.21492910e-01,   3.08484674e-01,   2.98146188e-01,
                          3.08383882e-01,   3.15743148e-01,   3.12222838e-01,
                          2.92662740e-01,   2.76103973e-01,   2.48443574e-01,
                          2.32826725e-01,   2.20081210e-01,   2.14346394e-01,
                          2.09174186e-01,   1.85926318e-01,   1.75478727e-01,
                          1.70792043e-01,   1.65249586e-01,   1.53787807e-01,
                          1.46559581e-01,   1.59513578e-01,   1.87949568e-01,
                          2.07195461e-01,   2.21624061e-01,   2.36235067e-01,
                          2.70529836e-01,   3.07271212e-01,   3.31630588e-01,
                          3.51177901e-01,   3.56914192e-01,   3.70900929e-01,
                          3.91050309e-01,   4.16059226e-01,   4.33486640e-01,
                          4.33271974e-01,   4.35865134e-01,   4.46490109e-01,
                          4.56471175e-01,   4.25870717e-01,   3.66207063e-01,
                          3.07178766e-01,   2.57486045e-01,   1.97330400e-01,
                          1.48662820e-01,   1.39162540e-01,   1.53821707e-01,
                          1.74522191e-01,   1.97885901e-01,   2.15705141e-01,
                          2.37497553e-01,   2.51220971e-01,   2.59974271e-01,
                          2.62583882e-01,   2.45939270e-01,   2.51738101e-01,
                          2.83968538e-01,   3.42560947e-01,   3.88807923e-01,
                          4.17253911e-01,   4.31874454e-01,   4.42953676e-01,
                          4.36977655e-01,   4.15059716e-01,   3.80210847e-01,
                          3.39726180e-01,   2.97097296e-01,   2.54798323e-01,
                          2.50644952e-01,   2.83551306e-01,   3.40620697e-01,
                          3.98316950e-01,   4.21792358e-01,   4.11108583e-01,
                          3.91637594e-01,   3.83135974e-01,   3.84256333e-01,
                          3.68135095e-01,   3.37420672e-01,   3.07339787e-01,
                          2.93036431e-01,   2.76708961e-01,   2.54369527e-01,
                          2.22581849e-01,   1.80813223e-01,   1.33707210e-01,
                          1.04692183e-01,   9.78772268e-02,   8.80895182e-02,
                          8.34203288e-02,   8.73887017e-02,   9.97731164e-02,
                          1.15537882e-01,   1.35533988e-01,   1.74685866e-01,
                          2.10249573e-01,   2.24823236e-01,   2.06465900e-01,
                          1.72259092e-01,   1.30395755e-01,   7.64888823e-02,
                          1.79151781e-02,  -3.46817523e-02,  -5.11531830e-02,
                         -3.45565267e-02,   9.40808270e-04,   2.73438022e-02,
                          5.47825024e-02,   7.43142366e-02,   6.24497905e-02,
                          4.32800986e-02,   1.98024195e-02,  -7.05609843e-03,
                         -2.37735063e-02,  -4.96297143e-02,  -8.69989097e-02,
                         -1.33069247e-01,  -1.94987968e-01,  -2.61572301e-01,
                         -2.67343700e-01,  -2.49593243e-01,  -2.47160405e-01,
                         -2.38798827e-01,  -2.48340279e-01,  -2.41146266e-01,
                         -1.86657384e-01,  -1.26409486e-01,  -9.74805132e-02,
                         -1.01585224e-01,  -1.32944852e-01,  -1.20864503e-01,
                         -7.05305114e-02,  -5.03183529e-02,  -7.05937594e-02,
                         -1.12936892e-01,  -1.59505650e-01,  -1.93309858e-01,
                         -2.26454899e-01,  -2.77583480e-01,  -3.53936613e-01,
                         -4.42266166e-01,  -5.40441632e-01,  -6.24466240e-01,
                         -6.52975440e-01,  -6.41394317e-01,  -6.22726560e-01,
                         -6.19528174e-01,  -6.34335518e-01,  -6.53700292e-01,
                         -6.51917160e-01,  -6.39918447e-01,  -6.29492164e-01,
                         -6.35380626e-01,  -6.60736322e-01,  -6.69095576e-01,
                         -6.40832663e-01,  -6.13317132e-01,  -5.99336565e-01,
                         -5.50760984e-01,  -5.24386466e-01,  -5.46795905e-01,
                         -5.36411524e-01,  -5.26625931e-01,  -5.62749445e-01,
                         -6.05161726e-01,  -6.32792771e-01,  -6.75845802e-01,
                         -7.14781940e-01,  -7.22251117e-01,  -7.20596611e-01,
                         -7.18273818e-01,  -7.02591300e-01,  -6.84757531e-01,
                         -6.64645493e-01,  -6.49482250e-01,  -6.51891530e-01,
                         -6.57826543e-01,  -6.62990093e-01,  -6.64531887e-01,
                         -6.73445165e-01,  -6.83223248e-01,  -6.80457711e-01,
                         -6.66229069e-01,  -6.62644148e-01,  -6.48380578e-01,
                         -6.19926274e-01,  -5.95765173e-01,  -5.76295853e-01,
                         -5.57139993e-01,  -5.43593049e-01,  -5.38307369e-01,
                         -5.48030198e-01,  -5.88173151e-01,  -6.48192227e-01,
                         -6.86416566e-01,  -6.85871482e-01,  -6.79710269e-01,
                         -6.70066118e-01,  -6.62086308e-01,  -6.59970939e-01,
                         -6.53342068e-01,  -6.49957895e-01,  -6.48741722e-01,
                         -6.37296498e-01,  -6.30902767e-01,  -6.19890034e-01,
                         -5.85186839e-01,  -5.49394011e-01,  -5.19322693e-01,
                         -4.93530601e-01,  -4.79644418e-01,  -4.75602567e-01,
                         -4.80021209e-01,  -4.90388155e-01,  -5.04091620e-01,
                         -5.15411735e-01,  -5.31098545e-01,  -5.46359062e-01,
                         -5.43859780e-01,  -5.21873295e-01,  -4.99674201e-01,
                         -4.81367916e-01,  -4.67546284e-01,  -4.59535420e-01,
                         -4.51935530e-01,  -4.47019219e-01,  -4.55285251e-01,
                         -4.78868455e-01,  -4.95085090e-01,  -5.05774260e-01,
                         -5.23527205e-01,  -5.44501841e-01,  -5.49755752e-01,
                         -5.33269823e-01,  -5.15267730e-01,  -5.12685955e-01,
                         -5.09685159e-01,  -4.95975375e-01,  -4.75649565e-01,
                         -4.53187943e-01,  -4.23960805e-01,  -3.93613875e-01,
                         -3.71619642e-01,  -3.48048806e-01,  -3.12315285e-01,
                         -2.60934532e-01,  -2.11624011e-01,  -1.69815212e-01,
                         -1.39108926e-01,  -1.25572830e-01,  -1.17003269e-01,
                         -1.11258067e-01,  -1.22740932e-01,  -1.50903910e-01,
                         -1.75081372e-01,  -1.81406841e-01,  -1.81653857e-01,
                         -1.93274274e-01,  -2.12094754e-01,  -2.29688898e-01,
                         -2.44875818e-01,  -2.54842132e-01,  -2.61279404e-01,
                         -2.62100279e-01,  -2.59006143e-01,  -2.64338881e-01,
                         -2.76876271e-01,  -2.83752292e-01,  -2.84727573e-01,
                         -2.80862659e-01,  -2.71635562e-01,  -2.51050860e-01,
                         -2.13888898e-01,  -1.80815473e-01,  -1.63936585e-01,
                         -1.64817646e-01,  -1.86858609e-01,  -2.15016767e-01,
                         -2.24262103e-01,  -2.05477819e-01,  -1.64728403e-01,
                         -1.25665501e-01,  -1.09686777e-01,  -1.04213536e-01,
                         -8.59732702e-02,  -5.67846186e-02,  -3.52587402e-02,
                         -3.09542660e-02,  -3.16130891e-02,  -3.04158274e-02,
                         -3.62939015e-02,  -2.80537121e-02,   9.36005544e-03,
                          3.87736410e-02,   4.76403609e-02,   6.76425695e-02,
                          1.00824349e-01,   1.31098822e-01,   1.58833236e-01,
                          1.84197739e-01,   2.04740152e-01,   2.15593651e-01,
                          2.09567100e-01,   1.94218248e-01,   1.81497142e-01,
                          1.72657609e-01,   1.69218138e-01,   1.80982247e-01,
                          2.10930884e-01,   2.35347018e-01,   2.32869431e-01,
                          2.25412577e-01,   2.31639117e-01,   2.35002384e-01,
                          2.22156689e-01,   2.01552898e-01,   1.88123181e-01,
                          1.80380881e-01,   1.68492302e-01,   1.62772089e-01,
                          1.72897115e-01,   1.84491724e-01,   1.88168794e-01,
                          1.90412298e-01,   1.99980974e-01,   2.19967812e-01,
                          2.37422585e-01,   2.34751314e-01,   2.15684146e-01,
                          1.93745047e-01,   1.66796029e-01,   1.36804849e-01,
                          1.31808802e-01,   1.68096870e-01,   2.13809222e-01,
                          2.31807366e-01,   2.32792169e-01,   2.50723511e-01,
                          2.88719296e-01,   3.18917781e-01,   3.35483789e-01,
                          3.59312147e-01,   3.88455689e-01,   4.06886339e-01,
                          4.19226736e-01,   4.27263051e-01,   4.23686266e-01,
                          4.14352894e-01,   4.08610642e-01,   4.15485561e-01,
                          4.39289719e-01,   4.64884311e-01,   4.78413969e-01,
                          4.80716318e-01,   4.76223201e-01,   4.73589897e-01,
                          4.78618860e-01,   4.88917321e-01,   4.92820561e-01,
                          4.72982347e-01,   4.32149798e-01,   3.92107844e-01,
                          3.68465573e-01,   3.60539079e-01,   3.51867676e-01,
                          3.44683170e-01,   3.55436593e-01,   3.67307425e-01,
                          3.80146980e-01,   4.14890110e-01,   4.20589477e-01,
                          3.70640039e-01,   3.52586597e-01,   3.91925395e-01,
                          4.16019827e-01,   4.26432729e-01,   4.62153137e-01,
                          4.91386324e-01,   4.96742308e-01,   5.26636899e-01,
                          5.81738293e-01,   5.95729768e-01,   5.85125625e-01,
                          6.27064943e-01,   6.91546142e-01,   7.24713504e-01,
                          7.55157113e-01,   7.65402734e-01,   7.10283101e-01,
                          6.54049695e-01,   6.64756954e-01,   6.79644227e-01,
                          6.20970845e-01,   5.51116645e-01,   5.61302960e-01,
                          5.98045588e-01,   5.90646446e-01,   5.86171746e-01,
                          6.22746825e-01,   6.64017618e-01,   6.62646532e-01,
                          6.05018973e-01,   5.53581417e-01,   5.79476476e-01,
                          6.58802807e-01,   7.42704272e-01,   8.22343707e-01,
                          8.75606537e-01,   8.79608989e-01,   8.56526077e-01,
                          8.41285765e-01,   8.44767511e-01,   8.48206699e-01,
                          8.28782380e-01,   7.92524278e-01,   7.49577522e-01,
                          7.01795995e-01,   6.63962841e-01,   6.40984416e-01,
                          6.23633504e-01,   6.03544772e-01,   5.72844386e-01,
                          5.48356712e-01,   5.46048284e-01,   5.50052702e-01,
                          5.58114052e-01,   5.81003606e-01,   6.15107358e-01,
                          6.50214553e-01,   6.66350245e-01,   6.54090524e-01,
                          6.29011214e-01,   6.13503754e-01,   6.22967124e-01,
                          6.43743694e-01,   6.52019560e-01,   6.49861932e-01,
                          6.50892556e-01,   6.62496328e-01,   6.68108821e-01,
                          6.41176820e-01,   5.96516669e-01,   5.69915295e-01,
                          5.62198877e-01,   5.48724830e-01,   5.34005642e-01,
                          5.41705549e-01,   5.50951421e-01,   5.43366671e-01,
                          5.48840821e-01,   5.68965614e-01,   5.75711012e-01,
                          5.60094774e-01,   5.25847256e-01,   4.89923686e-01,
                          4.58264142e-01,   4.21936482e-01,   3.82898092e-01,
                          3.41144145e-01,   3.06619346e-01,   2.92295277e-01,
                          2.85761684e-01,   2.81236410e-01,   2.87053347e-01,
                          3.12164992e-01,   3.55208933e-01,   3.84445757e-01,
                          3.79284978e-01,   3.47400129e-01,   2.97499567e-01,
                          2.47495055e-01,   2.04332992e-01,   1.68895558e-01,
                          1.59826413e-01,   1.68776333e-01,   1.76691964e-01,
                          1.92670688e-01,   2.17186481e-01,   2.40915194e-01,
                          2.51435995e-01,   2.31503874e-01,   1.93666667e-01,
                          1.58870354e-01,   1.26136854e-01,   9.72148255e-02,
                          7.33900964e-02,   5.00645079e-02,   2.91881040e-02,
                          1.57992877e-02,   1.88450497e-02,   3.73831466e-02,
                          5.53997047e-02,   7.13840276e-02,   8.98211449e-02,
                          9.91191342e-02,   8.47433507e-02,   4.72019240e-02,
                          1.39247486e-02,   8.01568385e-03,   1.70334969e-02,
                          2.53557395e-02,   2.75933091e-02,   3.28694321e-02,
                          6.43729046e-02,   9.99361724e-02,   9.51012820e-02,
                          6.41229749e-02,   4.50701118e-02,   4.31138165e-02,
                          3.80612984e-02,   2.21704971e-02,   1.20517388e-02,
                          1.95453968e-03,  -2.57231034e-02,  -5.94237559e-02,
                         -8.63818303e-02,  -9.84384567e-02,  -9.14193839e-02,
                         -8.11119080e-02,  -7.69878700e-02,  -7.31324553e-02,
                         -6.36731386e-02,  -5.53178824e-02,  -6.75608143e-02,
                         -9.76869911e-02,  -1.23234853e-01,  -1.34814247e-01,
                         -1.40935689e-01,  -1.55638680e-01,  -1.71108246e-01,
                         -1.77154079e-01,  -1.83088422e-01,  -1.82073981e-01,
                         -1.71522692e-01,  -1.65873498e-01,  -1.56104058e-01,
                         -1.39608786e-01,  -1.34151608e-01,  -1.33509532e-01,
                         -1.19892351e-01,  -1.00902461e-01,  -9.12072957e-02,
                         -7.81896785e-02,  -5.47252670e-02,  -3.96696851e-02,
                         -2.80442145e-02,  -8.65053944e-03,  -7.57241447e-04,
                         -1.28413662e-02,  -3.20876092e-02,  -5.01274578e-02,
                         -6.94128722e-02,  -9.26907584e-02,  -1.13430344e-01,
                         -1.32459924e-01,  -1.55221120e-01,  -1.79090783e-01,
                         -2.04417825e-01,  -2.27221280e-01,  -2.37626135e-01,
                         -2.33636856e-01,  -2.27078363e-01,  -2.31388777e-01,
                         -2.34075025e-01,  -2.23010093e-01,  -2.05920145e-01,
                         -1.83383197e-01,  -1.70297623e-01,  -1.80184841e-01,
                         -1.89096153e-01,  -1.87248334e-01,  -1.88997388e-01,
                         -1.97051704e-01,  -2.05094531e-01,  -2.05673456e-01,
                         -2.02375665e-01,  -1.99469000e-01,  -1.91711932e-01,
                         -1.77062184e-01,  -1.50721580e-01,  -1.17210738e-01,
                         -9.10274759e-02,  -7.05549866e-02,  -5.03984876e-02,
                         -3.41293924e-02,  -3.15621085e-02,  -4.28812169e-02,
                         -5.23014292e-02,  -6.03155866e-02,  -7.07713440e-02,
                         -7.72453398e-02,  -8.51086080e-02,  -9.49383080e-02,
                         -1.19139336e-01,  -1.73603535e-01,  -2.17773214e-01,
                         -2.17406258e-01,  -1.98645219e-01,  -1.76861942e-01,
                         -1.37148395e-01,  -8.35467875e-02,  -4.73342575e-02,
                         -3.69424671e-02,  -2.36204509e-02,   6.50728540e-03,
                          4.06942293e-02,   6.69695511e-02,   8.39037225e-02,
                          9.07407105e-02,   7.95269981e-02,   5.75000383e-02,
                          3.80651616e-02,   1.81130823e-02,   2.15036911e-04,
                         -6.11499604e-03,   7.71927461e-03,   3.93425263e-02,
                          6.91715628e-02,   9.53543186e-02,   1.15222327e-01,
                          1.12504683e-01,   1.01192124e-01,   9.34976339e-02,
                          8.39531645e-02,   7.74039328e-02,   6.78042546e-02,
                          4.99170609e-02,   3.08518764e-02,   1.75846368e-02,
                          2.34641787e-02,   4.46745232e-02,   6.37405366e-02,
                          7.55343884e-02,   7.61852413e-02,   7.15133101e-02,
                          7.78264776e-02,   9.76106375e-02,   1.02486566e-01,
                          5.69945388e-02,  -1.55270118e-02,  -6.01135828e-02,
                         -6.16908967e-02,  -2.86925249e-02,   2.53407247e-02,
                          9.68036354e-02,   1.91106260e-01,   2.77719587e-01,
                          3.17955256e-01,   3.12040716e-01,   2.89293259e-01,
                          2.79698253e-01,   2.74991602e-01,   2.55805880e-01,
                          2.33636647e-01,   2.20641047e-01,   2.22724006e-01,
                          2.38968462e-01,   2.55348206e-01,   2.77885228e-01,
                          3.13589513e-01,   3.40834439e-01,   3.47024947e-01,
                          3.45664531e-01,   3.48031104e-01,   3.41572911e-01,
                          3.15903038e-01,   2.92130023e-01,   2.84486800e-01,
                          2.89287955e-01,   3.11541378e-01,   3.42102975e-01,
                          3.61532837e-01,   3.66831243e-01,   3.69522214e-01,
                          3.78925025e-01,   3.52148563e-01,   2.69464403e-01,
                          2.19705567e-01,   2.11023226e-01,   1.56841829e-01,
                          8.80544633e-02,   3.32744531e-02,  -4.55109440e-02,
                         -9.87664834e-02,  -1.03230260e-01,  -1.01307750e-01,
                         -7.20825493e-02,  -2.23232545e-02,  -1.34750707e-02,
                         -4.00927886e-02,  -4.08104211e-02,  -4.97636851e-03,
                          1.79240201e-02,   4.21988219e-02,   1.03001133e-01,
                          1.33816957e-01,   9.92850065e-02,   5.73657304e-02,
                          5.53406328e-02,   1.02793083e-01,   1.57177359e-01,
                          1.75349548e-01,   1.73549756e-01,   1.92477614e-01,
                          2.46485949e-01,   2.73794144e-01,   2.43173510e-01,
                          2.06852794e-01,   1.52441323e-01,   8.75755399e-02,
                          7.88895264e-02,   8.87735561e-02,   8.74259844e-02,
                          1.02908127e-01,   1.08448073e-01,   9.54345539e-02,
                          7.73990974e-02,   4.94316109e-02,   1.64212845e-02,
                         -3.26312259e-02,  -9.10512656e-02,  -1.32633790e-01,
                         -1.56732008e-01,  -1.63935438e-01,  -1.70487955e-01,
                         -1.88327774e-01,  -1.91759124e-01,  -1.71681434e-01,
                         -1.40197590e-01,  -1.08147174e-01,  -7.98736066e-02,
                         -5.29237501e-02,  -4.09962013e-02,  -4.52880859e-02,
                         -4.58848178e-02,  -4.21635993e-02,  -4.11843471e-02,
                         -4.61362340e-02,  -5.73848188e-02,  -7.00715631e-02,
                         -8.34493339e-02,  -9.82039422e-02,  -1.14351109e-01,
                         -1.23256229e-01,  -1.20762616e-01,  -1.21766932e-01,
                         -1.33683205e-01,  -1.66633338e-01,  -2.20840991e-01,
                         -2.60228187e-01,  -2.70024359e-01,  -2.57542580e-01,
                         -2.24971354e-01,  -1.88395426e-01,  -1.55132532e-01,
                         -1.33236274e-01,  -1.31686956e-01,  -1.31374553e-01,
                         -1.27279520e-01,  -1.22830093e-01,  -1.14789151e-01,
                         -1.22359239e-01,  -1.47509322e-01,  -1.74285591e-01,
                         -1.96780041e-01,  -2.01997340e-01,  -1.95726231e-01,
                         -1.92819268e-01,  -1.87543169e-01,  -1.80327907e-01,
                         -1.71550721e-01,  -1.63497940e-01,  -1.69815302e-01,
                         -1.81869403e-01,  -1.84875086e-01,  -1.87735260e-01,
                         -2.02552214e-01,  -2.26319462e-01,  -2.36703619e-01,
                         -2.19874844e-01,  -1.99530229e-01,  -2.00138643e-01,
                         -2.13385686e-01,  -2.20794439e-01,  -2.16554850e-01,
                         -2.12130412e-01,  -2.19013795e-01,  -2.30554983e-01,
                         -2.46080682e-01,  -2.73351371e-01,  -3.02490950e-01,
                         -3.25729281e-01,  -3.43485385e-01,  -3.51006448e-01,
                         -3.49787056e-01,  -3.39458168e-01,  -3.27339739e-01,
                         -3.29821765e-01,  -3.34152997e-01,  -3.28613341e-01,
                         -3.26439083e-01,  -3.19508761e-01,  -2.86917776e-01,
                         -2.37986952e-01,  -2.08488688e-01,  -2.18805268e-01,
                         -2.51815587e-01,  -2.81921238e-01,  -2.92443305e-01,
                         -2.77481258e-01,  -2.42368400e-01,  -2.02117965e-01,
                         -1.86714485e-01,  -1.96936607e-01,  -2.03638732e-01,
                         -2.19666705e-01,  -2.64167517e-01,  -3.18006575e-01,
                         -3.70039523e-01,  -4.21975791e-01,  -4.62614387e-01,
                         -4.73051578e-01,  -4.67018455e-01,  -4.81513590e-01,
                         -5.02900839e-01,  -5.02665758e-01,  -4.96938407e-01,
                         -5.02223432e-01,  -5.14616966e-01,  -5.19297719e-01,
                         -5.12792826e-01,  -5.12008071e-01,  -5.17671764e-01,
                         -5.26512444e-01,  -5.36393762e-01,  -5.32183886e-01,
                         -5.19348621e-01,  -5.11327565e-01,  -5.09532452e-01,
                         -5.12126207e-01,  -5.11128306e-01,  -5.12945473e-01,
                         -5.18960118e-01,  -5.11493742e-01,  -4.90161687e-01,
                         -4.63299870e-01,  -4.41169113e-01,  -4.25433129e-01,
                         -4.01722014e-01,  -3.75881076e-01,  -3.53253245e-01,
                         -3.34812999e-01,  -3.39524806e-01,  -3.66231650e-01,
                         -4.05458719e-01,  -4.51388448e-01,  -4.87186015e-01,
                         -5.08609653e-01,  -5.17236233e-01,  -5.27850270e-01,
                         -5.52976251e-01,  -5.67076743e-01,  -5.69664776e-01,
                         -5.83638012e-01,  -6.04144335e-01,  -6.24480188e-01,
                         -6.33400559e-01,  -6.27829015e-01,  -6.19275689e-01,
                         -6.04007125e-01,  -5.86417496e-01,  -5.68481147e-01,
                         -5.44787347e-01,  -5.25561929e-01,  -5.11445463e-01,
                         -5.10493994e-01,  -5.23960412e-01,  -5.26154160e-01,
                         -5.25428295e-01,  -5.27935803e-01,  -5.16088843e-01,
                         -5.05424500e-01,  -5.04759192e-01,  -5.09665310e-01,
                         -5.23755193e-01,  -5.30751646e-01,  -5.28458238e-01,
                         -5.32188714e-01,  -5.39215386e-01,  -5.44101119e-01,
                         -5.37375927e-01,  -5.15048921e-01,  -5.01647830e-01,
                         -5.15663743e-01,  -5.37484586e-01,  -5.37806511e-01,
                         -5.16309977e-01,  -4.90993708e-01,  -4.65819240e-01,
                         -4.33347732e-01,  -4.01077390e-01,  -3.81153733e-01,
                         -3.60028177e-01,  -3.32503587e-01,  -3.17331761e-01,
                         -3.14509064e-01,  -3.22948515e-01,  -3.43242079e-01,
                         -3.56785029e-01,  -3.60895872e-01,  -3.61380547e-01,
                         -3.63259584e-01,  -3.76132876e-01,  -3.86580050e-01,
                         -3.93485546e-01,  -4.08176035e-01,  -4.12695855e-01,
                         -4.03016239e-01,  -3.93500686e-01,  -3.90498251e-01,
                         -3.93553585e-01,  -3.92336130e-01,  -3.98368597e-01,
                         -4.20332819e-01,  -4.33880985e-01,  -4.31033552e-01,
                         -4.13452893e-01,  -3.89160901e-01,  -3.76719028e-01,
                         -3.62725973e-01,  -3.36805701e-01,  -3.12498391e-01,
                         -2.98402756e-01,  -3.03675532e-01,  -3.20690453e-01,
                         -3.43663365e-01,  -3.77387226e-01,  -3.92995387e-01,
                         -3.78884703e-01,  -3.61186564e-01,  -3.39794964e-01,
                         -3.08611840e-01,  -2.86649853e-01,  -2.87348807e-01,
                         -2.96482712e-01,  -2.96942651e-01,  -2.93124110e-01,
                         -2.77446181e-01,  -2.38446280e-01,  -1.99519873e-01,
                         -1.76336199e-01,  -1.59598574e-01,  -1.52171925e-01,
                         -1.62618905e-01,  -1.83110476e-01,  -1.96915358e-01,
                         -2.04941094e-01,  -2.14005560e-01,  -2.09253743e-01,
                         -1.94355711e-01,  -1.94810182e-01,  -1.96359217e-01,
                         -1.81606680e-01,  -1.80148691e-01,  -1.83495671e-01,
                         -1.27844870e-01,  -4.27443758e-02,  -2.53755990e-02,
                         -4.25101370e-02,  -2.02319138e-02,  -9.26509593e-03,
                         -2.17251778e-02,  -8.35786201e-03,  -2.66420320e-02,
                         -9.26477760e-02,  -1.21957913e-01,  -1.25602663e-01,
                         -1.41781807e-01,  -1.53989092e-01,  -1.57238752e-01,
                         -1.31056219e-01,  -8.72138813e-02,  -6.59788400e-02,
                         -6.08549081e-02,  -8.14403221e-02,  -1.00986555e-01,
                         -5.79026490e-02,   1.36322808e-02,   6.97103292e-02,
                          8.86515006e-02,   5.99004254e-02,   3.27278711e-02,
                          1.15996199e-02,   8.47434346e-03,   6.52953014e-02,
                          1.25045449e-01,   1.80791989e-01,   2.39598662e-01,
                          2.17835382e-01,   1.70099497e-01,   1.77667648e-01,
                          1.96138844e-01,   2.16686741e-01,   2.26462290e-01,
                          2.13508949e-01,   2.10386023e-01,   2.15081111e-01,
                          2.47236207e-01,   3.04349333e-01,   3.32702786e-01,
                          3.31271946e-01,   3.25407028e-01,   3.72598052e-01,
                          4.72563356e-01,   5.17902911e-01,   5.26816905e-01,
                          5.61148107e-01,   5.76010168e-01,   5.83847761e-01,
                          6.05322599e-01,   6.10325873e-01,   6.13690853e-01,
                          6.23248160e-01,   6.32461667e-01,   6.39329255e-01,
                          6.26368284e-01,   6.00944042e-01,   5.72317898e-01,
                          5.41926384e-01,   5.20648360e-01,   4.99635309e-01,
                          4.80078697e-01,   4.75234717e-01,   4.77695704e-01,
                          4.77863312e-01,   4.71576601e-01,   4.76759940e-01,
                          5.12224317e-01,   5.49672544e-01,   5.66441655e-01,
                          5.77643514e-01,   5.85238576e-01,   5.71732640e-01,
                          5.32107055e-01,   4.79813725e-01,   4.24116462e-01,
                          3.70017022e-01,   3.42681319e-01,   3.54908705e-01,
                          3.72955203e-01,   3.72778386e-01,   3.68586928e-01,
                          3.60901445e-01,   3.45010757e-01,   3.45572174e-01,
                          3.74050528e-01,   4.11502302e-01,   4.43958223e-01,
                          4.65412915e-01,   4.65633988e-01,   4.39014226e-01,
                          4.01950747e-01,   3.71938556e-01,   3.39780003e-01,
                          3.03959787e-01,   2.85144061e-01,   2.88404167e-01,
                          2.94211209e-01,   2.83446223e-01,   2.62038648e-01,
                          2.45793715e-01,   2.39124045e-01,   2.44084790e-01,
                          2.51404822e-01,   2.48770446e-01,   2.39001334e-01,
                          2.27654010e-01,   2.27435440e-01,   2.37728208e-01,
                          2.33459070e-01,   2.14921147e-01,   2.04546094e-01,
                          2.11716950e-01,   2.25349918e-01,   2.21855924e-01,
                          2.00166494e-01,   1.73314467e-01,   1.46752357e-01,
                          1.33133844e-01,   1.32739291e-01,   1.31834939e-01,
                          1.28851965e-01,   1.24199174e-01,   1.17792949e-01,
                          1.20024502e-01,   1.43649921e-01,   1.74993739e-01,
                          1.87726542e-01,   1.92726776e-01,   2.01506838e-01,
                          2.01198757e-01,   1.92488998e-01,   1.69070333e-01,
                          1.33997083e-01,   1.16967954e-01,   1.02606662e-01,
                          5.79862669e-02,   3.92411975e-03,  -2.70658936e-02,
                         -3.45886573e-02,  -3.93641926e-02,  -5.38672060e-02,
                         -6.95897937e-02,  -7.74794668e-02,  -8.06097686e-02,
                         -8.36431310e-02,  -8.31409842e-02,  -7.85779953e-02,
                         -7.62618631e-02,  -7.35920221e-02,  -6.71424046e-02,
                         -6.34723157e-02,  -6.88096210e-02,  -7.75080025e-02,
                         -7.84741491e-02,  -7.59780034e-02,  -7.56817013e-02,
                         -7.62705505e-02,  -8.29769224e-02,  -8.97106379e-02,
                         -9.17173997e-02,  -9.71756130e-02,  -1.02456078e-01,
                         -1.07097998e-01,  -1.09226324e-01,  -1.06157936e-01,
                         -1.13157958e-01,  -1.24846213e-01,  -1.30142346e-01,
                         -1.32469147e-01,  -1.23467758e-01,  -1.16178423e-01,
                         -1.20038323e-01,  -1.13105841e-01,  -1.01100713e-01,
                         -9.44111347e-02,  -9.11188796e-02,  -9.95367318e-02,
                         -1.04876623e-01,  -9.09276083e-02,  -7.16444552e-02,
                         -6.72661215e-02,  -8.41394588e-02,  -1.04816869e-01,
                         -1.17845200e-01,  -1.29263565e-01,  -1.47469446e-01,
                         -1.82874709e-01,  -2.17263177e-01,  -2.30018929e-01,
                         -2.35744193e-01,  -2.37347409e-01,  -2.29783073e-01,
                         -2.19046414e-01,  -2.08959565e-01,  -2.11487517e-01,
                         -2.23555773e-01,  -2.36219451e-01,  -2.60362327e-01,
                         -2.83512384e-01,  -2.78458744e-01,  -2.44998753e-01,
                         -2.06774071e-01,  -1.92036316e-01,  -1.98905006e-01,
                         -2.05013201e-01,  -2.01712668e-01,  -1.86361089e-01,
                         -1.58306450e-01,  -1.20407082e-01,  -8.32238570e-02,
                         -6.36095852e-02,  -6.57694712e-02,  -8.06004480e-02,
                         -8.53398889e-02,  -6.81699961e-02,  -5.98305278e-02,
                         -7.85620958e-02,  -9.24081430e-02,  -7.17021152e-02,
                         -3.59551683e-02,  -3.12901288e-02,  -4.98007685e-02,
                         -4.87729572e-02,  -4.43924852e-02,  -6.05277829e-02,
                         -7.98240155e-02,  -1.04738206e-01,  -1.30534559e-01,
                         -1.20845176e-01,  -8.23714584e-02,  -6.14557825e-02,
                         -9.37993154e-02,  -1.76493332e-01,  -2.38658011e-01,
                         -2.41888463e-01,  -2.55251288e-01,  -2.93410152e-01,
                         -2.92646796e-01,  -2.74519861e-01,  -2.81182647e-01,
                         -2.80981660e-01,  -2.54265726e-01,  -2.12064177e-01,
                         -1.72233805e-01,  -1.46419421e-01,  -1.10521033e-01,
                         -6.81977272e-02,  -5.08032106e-02,  -2.61216722e-02,
                          2.64802724e-02,   5.50327040e-02,   4.15216684e-02,
                          1.52656175e-02,  -6.38399133e-03,  -6.99235732e-03,
                          2.12924331e-02,   6.41788691e-02,   9.92454737e-02,
                          1.00354426e-01,   7.43710846e-02,   6.54026493e-02,
                          8.00023675e-02,   7.81478956e-02,   3.14792953e-02,
                         -5.17018288e-02,  -1.34496436e-01,  -2.00134262e-01,
                         -2.69652694e-01,  -3.37525159e-01,  -3.75900984e-01,
                         -4.04452384e-01,  -4.49741513e-01,  -4.81632650e-01,
                         -4.75504816e-01,  -4.46474046e-01,  -3.82070988e-01,
                         -2.82072484e-01,  -2.30195954e-01,  -2.59498030e-01,
                         -2.81181842e-01,  -2.56752670e-01,  -2.27939785e-01,
                         -2.05185547e-01,  -2.13154331e-01,  -2.79132217e-01,
                         -3.34088147e-01,  -3.19233447e-01,  -2.81260699e-01,
                         -2.74838716e-01,  -3.04032177e-01,  -3.37557852e-01,
                         -3.61748129e-01,  -4.10734683e-01,  -4.57853079e-01,
                         -4.26122397e-01,  -3.57396394e-01,  -3.37502778e-01,
                         -3.44286144e-01,  -3.41062784e-01,  -3.39507073e-01,
                         -3.31747442e-01,  -3.04363340e-01,  -2.80562043e-01,
                         -2.83854216e-01,  -2.94588596e-01,  -2.80376792e-01,
                         -2.50476927e-01,  -2.28048831e-01,  -2.14740783e-01,
                         -2.11233854e-01,  -2.03882888e-01,  -1.74704388e-01,
                         -1.48652107e-01,  -1.43983275e-01,  -1.37543023e-01,
                         -1.20509312e-01,  -9.65051427e-02,  -6.52855784e-02,
                         -3.80451344e-02,  -1.48590123e-02,   8.63404106e-03,
                          2.38470472e-02,   3.79196852e-02,   5.34321666e-02,
                          5.38018383e-02,   5.05611151e-02,   5.95018379e-02,
                          5.97705990e-02,   4.48642708e-02,   4.16291840e-02,
                          5.65411486e-02,   6.51161298e-02,   5.40277287e-02,
                          3.84771712e-02,   3.34537029e-02,   3.95835824e-02,
                          5.73514700e-02,   7.77336359e-02,   8.27620700e-02,
                          8.14537108e-02,   9.99206454e-02,   1.35809332e-01,
                          1.66322276e-01,   1.88107699e-01,   2.15017438e-01,
                          2.44321868e-01,   2.59975672e-01,   2.64306307e-01,
                          2.72135526e-01,   2.81892508e-01,   2.82860696e-01,
                          2.79525846e-01,   2.83707321e-01,   2.94618726e-01,
                          3.09447736e-01,   3.30495447e-01,   3.46911281e-01,
                          3.46582562e-01,   3.38879824e-01,   3.34234864e-01,
                          3.31464887e-01,   3.31758171e-01,   3.35367113e-01,
                          3.38724405e-01,   3.41244191e-01,   3.43547940e-01,
                          3.43272150e-01,   3.33880991e-01,   3.18834484e-01,
                          3.18288386e-01,   3.37400168e-01,   3.56386840e-01,
                          3.62905830e-01,   3.62423390e-01,   3.64199877e-01,
                          3.68198067e-01,   3.64215910e-01,   3.47534269e-01,
                          3.22319359e-01,   2.99440026e-01,   2.86167353e-01,
                          2.62450099e-01,   2.17823401e-01,   1.88641265e-01,
                          1.94431901e-01,   2.14681670e-01,   2.39509448e-01,
                          2.60151744e-01,   2.69453704e-01,   2.90352196e-01,
                          3.30551893e-01,   3.60808104e-01,   3.67086142e-01,
                          3.58179122e-01,   3.36047053e-01,   2.96640605e-01,
                          2.49070421e-01,   2.19668627e-01,   2.23620027e-01,
                          2.52010345e-01,   2.90146351e-01,   3.20464522e-01,
                          3.31861764e-01,   3.31552297e-01,   3.23760152e-01,
                          3.08744133e-01,   3.00112635e-01,   3.07607710e-01,
                          3.26517373e-01,   3.44926953e-01,   3.55609059e-01,
                          3.63010347e-01,   3.72905970e-01,   3.85476142e-01,
                          4.02776361e-01,   4.20111686e-01,   4.22824383e-01,
                          4.04216617e-01,   3.70519251e-01,   3.32135558e-01,
                          2.94044256e-01,   2.53629684e-01,   2.13178113e-01,
                          1.80424824e-01,   1.55889913e-01,   1.41689613e-01,
                          1.44761831e-01,   1.61994070e-01,   1.83121219e-01,
                          2.03570217e-01,   2.21825197e-01,   2.29672506e-01,
                          2.25957066e-01,   2.22845122e-01,   2.21086577e-01,
                          2.11522147e-01,   2.00455979e-01,   1.94020227e-01,
                          1.86941728e-01,   1.78358525e-01,   1.65294498e-01,
                          1.43566847e-01,   1.21928886e-01,   1.11338131e-01,
                          1.07476830e-01,   9.47471261e-02,   7.30987564e-02,
                          6.65111616e-02,   8.36617053e-02,   1.03235148e-01,
                          1.13472253e-01,   1.21393546e-01,   1.31799132e-01,
                          1.43547848e-01,   1.55869707e-01,   1.66215107e-01,
                          1.69475272e-01,   1.57784030e-01,   1.27358779e-01,
                          8.82386789e-02,   5.46566993e-02,   3.10307387e-02,
                          1.17501915e-02,  -1.28432326e-02,  -4.06291559e-02,
                         -5.77381812e-02,  -5.60596846e-02,  -4.02113013e-02,
                         -2.57261079e-02,  -2.54515819e-02,  -3.63553874e-02,
                         -5.51601313e-02,  -7.37545267e-02,  -8.70773122e-02,
                         -8.79590139e-02,  -7.98602328e-02,  -7.30814710e-02,
                         -7.12623894e-02,  -7.54177645e-02,  -8.45763907e-02,
                         -9.22794491e-02,  -9.63397175e-02,  -1.00552417e-01,
                         -1.11266464e-01,  -1.38879150e-01,  -1.75364837e-01,
                         -1.93882853e-01,  -1.87065586e-01,  -1.79083094e-01,
                         -1.81941375e-01,  -1.97557911e-01,  -2.36957684e-01,
                         -2.89561510e-01,  -3.33411604e-01,  -3.54064018e-01,
                         -3.60563159e-01,  -3.76628697e-01,  -4.06772703e-01,
                         -4.31126833e-01,  -4.38159555e-01,  -4.34435546e-01,
                         -4.29712236e-01,  -4.24191892e-01,  -4.14834380e-01,
                         -4.15322781e-01,  -4.28971887e-01,  -4.47873682e-01,
                         -4.73424613e-01,  -5.02974033e-01,  -5.29352307e-01,
                         -5.47001719e-01,  -5.63630044e-01,  -5.86280465e-01,
                         -6.08546853e-01,  -6.16797626e-01,  -6.19519830e-01,
                         -6.33801758e-01,  -6.64719284e-01,  -6.89617634e-01,
                         -6.79628730e-01,  -6.35460258e-01,  -5.75974822e-01,
                         -5.12639344e-01,  -4.50067431e-01,  -4.06900078e-01,
                         -3.80962610e-01,  -3.58416110e-01,  -3.64673138e-01,
                         -3.95843416e-01,  -4.14676875e-01,  -4.28190917e-01,
                         -4.50555593e-01,  -4.54826951e-01,  -4.41496074e-01,
                         -4.44912404e-01,  -4.78248745e-01,  -5.21393597e-01,
                         -5.56940496e-01,  -5.74386358e-01,  -5.81539750e-01,
                         -5.82605302e-01,  -5.77175498e-01,  -5.65231144e-01,
                         -5.37880182e-01,  -5.08158445e-01,  -5.06857514e-01,
                         -5.24497271e-01,  -5.44321179e-01,  -5.44129908e-01,
                         -5.36468446e-01,  -5.36058187e-01,  -5.46103239e-01,
                         -5.57447076e-01,  -5.63384354e-01,  -5.53782642e-01,
                         -5.32605886e-01,  -5.11136353e-01,  -4.97536987e-01,
                         -4.96961743e-01,  -5.07987976e-01,  -5.31301320e-01,
                         -5.52048564e-01,  -5.58030546e-01,  -5.59373558e-01,
                         -5.54135442e-01,  -5.49912214e-01,  -5.44077337e-01,
                         -5.44066489e-01,  -5.34924805e-01,  -5.12081921e-01,
                         -4.73833889e-01,  -4.24973667e-01,  -3.89978796e-01,
                         -3.81073922e-01,  -3.96627307e-01,  -4.22209173e-01,
                         -4.64478076e-01,  -5.17407000e-01,  -5.54372072e-01,
                         -5.75895905e-01,  -5.83090246e-01,  -5.74767113e-01,
                         -5.44989645e-01,  -5.09531975e-01,  -4.76368517e-01,
                         -4.57675606e-01,  -4.52981532e-01,  -4.71960276e-01,
                         -5.03811061e-01,  -5.32995105e-01,  -5.59691131e-01,
                         -5.64809561e-01,  -5.49824893e-01,  -5.26588380e-01,
                         -5.09640872e-01,  -4.92926449e-01,  -4.68245924e-01,
                         -4.51171666e-01,  -4.48380828e-01,  -4.39235747e-01,
                         -4.22682613e-01,  -4.07261610e-01,  -3.91128480e-01,
                         -3.64766598e-01,  -3.25694442e-01,  -2.76578248e-01,
                         -2.22343594e-01,  -1.72773868e-01,  -1.44920930e-01,
                         -1.32376015e-01,  -1.22979060e-01,  -1.25635073e-01,
                         -1.62306800e-01,  -2.15504751e-01,  -2.63443619e-01,
                         -3.10756683e-01,  -3.56886685e-01,  -3.94243866e-01,
                         -3.96849155e-01,  -3.67949337e-01,  -3.24008524e-01,
                         -2.82568187e-01,  -2.65453279e-01,  -2.76799321e-01,
                         -2.89267510e-01,  -2.90388227e-01,  -2.92304039e-01,
                         -2.89198399e-01,  -2.82809526e-01,  -2.71354556e-01,
                         -2.64165521e-01,  -2.54381239e-01,  -2.36717492e-01,
                         -2.14226499e-01,  -1.83361799e-01,  -1.43496633e-01,
                         -1.00973256e-01,  -7.76401460e-02,  -8.40689391e-02,
                         -1.04570329e-01,  -1.20404735e-01,  -1.35366127e-01,
                         -1.49604499e-01,  -1.62654176e-01,  -1.74480200e-01,
                         -1.84525460e-01,  -1.93246022e-01,  -1.92716360e-01,
                         -1.83232069e-01,  -1.78285748e-01,  -1.81344777e-01,
                         -1.76238313e-01,  -1.42295465e-01,  -1.03407316e-01,
                         -7.10559860e-02,  -4.70226593e-02,  -3.08045503e-02,
                         -3.35134305e-02,  -5.45056611e-02,  -8.92505050e-02,
                         -1.16304964e-01,  -1.37669697e-01,  -1.45234212e-01,
                         -1.37990847e-01,  -1.28029570e-01,  -1.13016993e-01,
                         -1.08216390e-01,  -8.29450265e-02,  -5.31161837e-02,
                         -1.59228835e-02,   1.69305746e-02,   4.01707217e-02,
                          5.32193966e-02,   5.35303727e-02,   5.77189103e-02,
                          7.38877729e-02,   9.67139378e-02,   1.08750328e-01,
                          1.16582833e-01,   1.14339367e-01,   1.16927259e-01,
                          1.32797346e-01,   1.62688211e-01,   1.93020225e-01,
                          1.97980151e-01,   2.03083292e-01,   2.11496919e-01,
                          2.14069068e-01,   1.96146309e-01,   1.90299556e-01,
                          1.78880244e-01,   1.46602586e-01,   9.95921567e-02,
                          6.22805431e-02,   4.30004522e-02,   3.75427864e-02,
                          2.86925416e-02,   3.11203934e-02,   4.88332845e-02,
                          7.74322748e-02,   1.14489980e-01,   1.45289376e-01,
                          1.67587534e-01,   2.10960761e-01,   2.43707329e-01,
                          2.58054316e-01,   2.37133563e-01,   2.17343315e-01,
                          2.09861368e-01,   2.14610010e-01,   2.16931865e-01,
                          2.80200750e-01,   3.36956233e-01,   3.33720028e-01,
                          2.84762859e-01,   1.99939683e-01,   1.63663685e-01,
                          1.57049224e-01,   1.68315053e-01,   1.93153858e-01,
                          2.05208674e-01,   2.07478225e-01,   1.97891280e-01,
                          1.94051921e-01,   1.89041123e-01,   1.91394627e-01,
                          1.86474279e-01,   2.33572081e-01,   2.98004866e-01,
                          3.08985919e-01,   2.50330478e-01,   2.00988099e-01,
                          2.00056195e-01,   2.50611186e-01,   2.95559645e-01,
                          2.57527530e-01,   2.37413183e-01,   2.33045042e-01,
                          1.99227810e-01,   2.09380925e-01,   2.46126428e-01,
                          2.55080223e-01,   2.18433589e-01,   1.87227532e-01,
                          1.47977814e-01,   1.03872709e-01,   1.10475495e-01,
                          1.02989905e-01,   8.33688155e-02,   7.50921890e-02,
                          5.93629070e-02,   1.08866066e-01,   2.07740217e-01,
                          2.51279414e-01,   2.87768275e-01,   2.82217324e-01,
                          2.74405658e-01,   3.10830802e-01,   3.34924042e-01,
                          4.08089310e-01,   5.07746756e-01,   5.51277101e-01,
                          5.78396082e-01,   5.53863406e-01,   5.11560261e-01,
                          5.39064884e-01,   5.85540473e-01,   6.64489150e-01,
                          7.67080724e-01,   8.12944591e-01,   8.49155605e-01,
                          8.54448080e-01,   8.15829515e-01,   7.54385650e-01,
                          6.44996762e-01,   4.97573346e-01,   4.00018424e-01,
                          3.50429177e-01,   3.24572772e-01,   2.97735393e-01,
                          2.64852434e-01,   2.59491354e-01,   2.57012933e-01,
                          2.22513258e-01,   2.22185567e-01,   2.57661492e-01,
                          2.50582457e-01,   2.20309660e-01,   1.98925182e-01,
                          1.15168378e-01,   9.50522870e-02,   1.99902341e-01,
                          3.46838236e-01,   4.50474113e-01,   4.81753081e-01,
                          5.04506409e-01,   5.37998736e-01,   5.61723709e-01,
                          5.77744544e-01,   5.74313283e-01,   5.28145730e-01,
                          4.89097357e-01,   4.69693005e-01,   4.71305907e-01,
                          4.97425377e-01,   4.86875981e-01,   4.69405651e-01,
                          5.04809797e-01,   5.32107770e-01,   5.08888900e-01,
                          5.22500098e-01,   5.28992832e-01,   4.88910615e-01,
                          4.43555504e-01,   3.63895267e-01,   2.87726253e-01,
                          2.58250266e-01,   2.54595280e-01,   2.67269254e-01,
                          2.70187497e-01,   2.80068636e-01,   3.09231639e-01,
                          3.12281460e-01,   3.11494917e-01,   3.15826535e-01,
                          3.19086939e-01,   3.38053674e-01,   3.45459998e-01,
                          3.46720785e-01,   3.48165512e-01,   3.33660960e-01,
                          3.15292060e-01,   2.94956207e-01,   2.83055484e-01,
                          2.84855157e-01,   2.86915064e-01,   2.53868163e-01,
                          1.91332757e-01,   1.75770834e-01,   2.00219780e-01,
                          1.90965787e-01,   1.55749679e-01,   1.02213867e-01,
                          8.65123719e-02,   1.00333102e-01,   6.94643110e-02,
                          4.71014716e-02,   4.73548211e-02,   5.88209629e-02,
                          9.26499590e-02,   6.91753179e-02,  -1.95323713e-02,
                         -9.40613672e-02,  -1.27646923e-01,  -1.44498974e-01,
                         -1.85100839e-01,  -1.95054725e-01,  -1.75067589e-01,
                         -1.91260874e-01,  -1.88533619e-01,  -1.67967439e-01,
                         -1.43916011e-01,  -1.05220445e-01,  -1.05640128e-01,
                         -1.07779168e-01,  -8.77091438e-02,  -9.26380828e-02,
                         -7.12635741e-02,  -4.09135185e-02,  -4.98638079e-02,
                         -7.57692382e-02,  -1.35450751e-01,  -1.93377599e-01,
                         -1.94616348e-01,  -1.59018040e-01,  -1.47467420e-01,
                         -1.98200583e-01,  -2.38864049e-01,  -2.31934115e-01,
                         -2.36300066e-01,  -2.49205485e-01,  -2.64586508e-01,
                         -2.90276647e-01,  -3.00494045e-01,  -2.85641640e-01,
                         -2.47309729e-01,  -2.23147511e-01,  -2.54008502e-01,
                         -3.05505127e-01,  -3.48536640e-01,  -3.69935513e-01,
                         -3.47779989e-01,  -3.31157237e-01,  -3.48915756e-01,
                         -3.74352276e-01,  -4.00272936e-01,  -4.00375903e-01,
                         -3.77906114e-01,  -3.73383373e-01,  -3.66790771e-01,
                         -3.44679832e-01,  -3.25433552e-01,  -2.95245677e-01,
                         -2.83502668e-01,  -3.25217098e-01,  -3.87505561e-01,
                         -4.31020111e-01,  -4.29515421e-01,  -4.17598009e-01,
                         -4.26466107e-01,  -4.23964024e-01,  -4.21666145e-01,
                         -4.19635534e-01,  -4.04352039e-01,  -4.01424378e-01,
                         -3.83665204e-01,  -3.53821248e-01,  -3.50263655e-01,
                         -3.60484064e-01,  -3.80634993e-01,  -3.75782102e-01,
                         -3.29229385e-01,  -2.82386601e-01,  -2.34236956e-01,
                         -1.99321643e-01,  -1.82733551e-01,  -1.63010418e-01,
                         -1.50934786e-01,  -1.27299041e-01,  -9.50050801e-02,
                         -7.96255246e-02,  -7.72839040e-02,  -9.62710828e-02,
                         -1.26714885e-01,  -1.45812377e-01,  -1.62622929e-01,
                         -1.67921573e-01,  -1.60673141e-01,  -1.59354508e-01,
                         -1.50099605e-01,  -1.56683326e-01,  -1.75219834e-01,
                         -1.95819914e-01,  -2.54895002e-01,  -3.08098823e-01,
                         -3.20963681e-01,  -3.09389889e-01,  -2.92283505e-01,
                         -2.93201029e-01,  -2.91981429e-01,  -2.79822171e-01,
                         -2.69968301e-01,  -2.51865059e-01,  -2.24374622e-01,
                         -1.94957018e-01,  -1.65523499e-01,  -1.48484170e-01,
                         -1.51254609e-01,  -1.57304391e-01,  -1.60468161e-01,
                         -1.53218046e-01,  -1.37324631e-01,  -1.25258729e-01,
                         -1.23136058e-01,  -1.43253803e-01,  -1.56525165e-01,
                         -1.56587958e-01,  -1.50357410e-01,  -1.38547301e-01,
                         -1.29567415e-01,  -1.08586669e-01,  -8.51292908e-02,
                         -5.39543927e-02,  -1.79216303e-02,   2.07276759e-03,
                          6.31088950e-03,   2.98889331e-03,   9.33746062e-03,
                          2.32038703e-02,   1.42458826e-02,  -1.22064855e-02,
                         -2.54431032e-02,  -3.40127014e-02,  -4.19596173e-02,
                         -4.98699173e-02,  -6.13134764e-02,  -7.48686194e-02,
                         -1.05442628e-01,  -1.39372513e-01,  -1.54246524e-01,
                         -1.67919427e-01,  -1.56912938e-01,  -1.00221321e-01,
                         -4.48747948e-02,  -1.31853512e-02,   1.16911324e-04,
                          4.13510064e-03,  -1.07859699e-02,  -4.90385965e-02,
                         -7.56291524e-02,  -8.48396122e-02,  -8.96878764e-02,
                         -7.61567652e-02,  -5.80779053e-02,  -3.70237790e-02,
                         -9.94609110e-03,   8.53834860e-03,   2.37633064e-02,
                          3.91545799e-03,  -3.84709835e-02,  -6.11059777e-02,
                         -5.88610619e-02,  -4.42422591e-02,  -2.19202060e-02,
                          1.01403138e-02,   4.43801247e-02,   7.53757730e-02,
                          8.01071599e-02,   7.88959339e-02,   8.41151699e-02,
                          8.85126889e-02,   9.68636945e-02,   1.21032350e-01,
                          1.64421245e-01,   1.93652391e-01,   1.93252161e-01,
                          1.68539539e-01,   1.56056166e-01,   1.62925407e-01,
                          1.66879132e-01,   1.71159655e-01,   1.72546864e-01,
                          1.74405620e-01,   1.85057923e-01,   2.08618805e-01,
                          2.36720055e-01,   2.30669916e-01,   2.03672484e-01,
                          1.87263489e-01,   1.63715363e-01,   1.27970114e-01,
                          9.46036875e-02,   7.87835196e-02,   5.63084558e-02,
                          3.54704596e-02,   3.39475870e-02,   3.48341577e-02,
                          2.87950393e-02,   2.10973453e-02,   3.23253572e-02,
                          5.36201000e-02,   7.25940093e-02,   7.90058821e-02,
                          1.04962692e-01,   1.49742290e-01,   1.73967734e-01,
                          1.76510662e-01,   1.74633875e-01,   1.95353404e-01,
                          2.20650330e-01,   2.26795703e-01,   2.22183645e-01,
                          2.21829236e-01,   2.08993956e-01,   1.83318183e-01,
                          1.58747166e-01,   1.51078284e-01,   1.71794400e-01,
                          2.03800723e-01,   2.35584259e-01,   2.48787165e-01,
                          2.45212242e-01,   2.38337725e-01,   2.33522549e-01,
                          2.32207060e-01,   2.38989159e-01,   2.44794637e-01,
                          2.44541913e-01,   2.27091298e-01,   1.88920632e-01,
                          1.39767736e-01,   8.86736959e-02,   7.54416808e-02,
                          8.36085156e-02,   9.00057405e-02,   8.75803605e-02,
                          8.58297423e-02,   1.33698285e-01,   1.82059675e-01,
                          1.73828706e-01,   1.64229527e-01,   1.55127645e-01,
                          1.28991708e-01,   1.09340563e-01,   1.21121839e-01,
                          1.71419501e-01,   2.19686016e-01,   2.60449260e-01,
                          2.50079393e-01,   2.40345106e-01,   2.60886580e-01,
                          2.41023853e-01,   2.46987417e-01,   2.49455824e-01,
                          2.39203602e-01,   2.75938362e-01,   2.98301369e-01,
                          3.06380659e-01,   3.39657634e-01,   3.47975850e-01,
                          3.39269996e-01,   3.44472051e-01,   3.43742937e-01,
                          3.81026179e-01,   4.50940222e-01,   4.84891772e-01,
                          4.70524549e-01,   4.16846126e-01,   3.27513933e-01,
                          2.45059669e-01,   2.21635893e-01,   2.43500367e-01,
                          2.70899534e-01,   3.24325472e-01,   3.93080503e-01,
                          4.31638807e-01,   4.26099569e-01,   4.08027142e-01,
                          4.56619620e-01,   5.12142241e-01,   5.07438481e-01,
                          4.72653419e-01,   4.39882606e-01,   4.24152404e-01,
                          3.76116186e-01,   3.10758382e-01,   2.69690514e-01,
                          2.18001932e-01,   1.66449890e-01,   1.46060422e-01,
                          1.63911581e-01,   2.48736173e-01,   3.09496403e-01,
                          2.52846450e-01,   1.52554646e-01,   1.20637812e-01,
                          1.23200357e-01,   6.92985058e-02,   4.08445895e-02,
                          4.15638685e-02,  -2.88748126e-02,  -1.05080783e-01,
                         -9.35291275e-02,  -6.09503202e-02,  -1.61071960e-02,
                          8.65515918e-02,   1.39125615e-01,   1.30023599e-01,
                          1.22816220e-01,   9.92408469e-02,   8.03941712e-02,
                          8.14317912e-02,   7.90694505e-02,   6.62525892e-02,
                          5.98767586e-02,   9.02045146e-02,   1.43105447e-01,
                          2.00681686e-01,   2.27547854e-01,   2.16095388e-01,
                          1.96235448e-01,   1.28724769e-01,   6.29307106e-02,
                          5.89983910e-02,   6.74723834e-02,   1.42572382e-02,
                         -8.25205147e-02,  -1.28791466e-01,  -1.69718474e-01,
                         -2.16395199e-01,  -1.64978087e-01,  -4.62680720e-02,
                          4.77994420e-02,   8.22405070e-02,   6.62096888e-02,
                          4.53788713e-02,   3.61251123e-02,   7.13785663e-02,
                          1.32222012e-01,   1.63429990e-01,   1.80286378e-01,
                          1.82978109e-01,   1.63003027e-01,   1.27968118e-01,
                          1.12750031e-01,   9.81121510e-02,   6.10164888e-02,
                          2.41321232e-02,  -9.68667399e-03,  -7.06879562e-03,
                          1.19735235e-02,   1.14139821e-02,   1.04621553e-03,
                         -1.41234752e-02,  -1.91332307e-02,  -4.46081460e-02,
                         -9.83266011e-02,  -1.31638750e-01,  -1.45632967e-01,
                         -1.69438437e-01,  -2.11724088e-01,  -2.05807254e-01,
                         -1.46070719e-01,  -1.10211752e-01,  -1.01750083e-01,
                         -1.10749379e-01,  -1.20132603e-01,  -1.59439489e-01,
                         -2.38486454e-01,  -2.76304007e-01,  -2.41075546e-01,
                         -1.80760100e-01,  -1.97928622e-01,  -3.03313047e-01,
                         -4.03384119e-01,  -4.23697323e-01,  -3.42592061e-01,
                         -2.43119925e-01,  -1.80563584e-01,  -1.48198739e-01,
                         -1.66254029e-01,  -1.93029150e-01,  -1.85373843e-01,
                         -1.59061655e-01,  -1.43194526e-01,  -1.23358212e-01,
                         -8.82789046e-02,  -8.10079798e-02,  -6.61348403e-02,
                         -3.23617868e-02,  -1.10408664e-02,  -3.35279736e-03,
                         -3.55012901e-02,  -9.65293795e-02,  -1.70661718e-01,
                         -2.35417128e-01,  -2.87610024e-01,  -3.50243300e-01,
                         -3.88969183e-01,  -3.97460282e-01,  -4.02384847e-01,
                         -4.33622599e-01,  -4.76818562e-01,  -4.79054898e-01,
                         -4.74133819e-01,  -4.83117729e-01,  -4.97901738e-01,
                         -5.17137885e-01,  -5.21704435e-01,  -5.19548357e-01,
                         -4.97056663e-01,  -4.71717656e-01,  -4.68311340e-01,
                         -4.75151300e-01,  -4.92290705e-01,  -5.00814497e-01,
                         -5.12631297e-01,  -5.26696622e-01,  -5.25341570e-01,
                         -5.21570802e-01,  -5.14658570e-01,  -5.19530773e-01,
                         -5.29239953e-01,  -5.30831575e-01,  -5.26621282e-01,
                         -5.12073755e-01,  -5.02973020e-01,  -4.85065877e-01,
                         -4.60842371e-01,  -4.50646102e-01,  -4.46147442e-01,
                         -4.38515186e-01,  -4.17992026e-01,  -4.11973804e-01,
                         -4.15685505e-01,  -4.08617556e-01,  -4.07299072e-01,
                         -4.02064145e-01,  -3.98358405e-01,  -3.96383762e-01,
                         -3.89809102e-01,  -3.82363677e-01,  -3.78994733e-01,
                         -3.98624718e-01,  -4.27545518e-01,  -4.55901176e-01,
                         -4.67035443e-01,  -4.53548938e-01,  -4.38135237e-01,
                         -4.11570817e-01,  -3.89290541e-01,  -3.68201256e-01,
                         -3.36165875e-01,  -3.18156600e-01,  -3.08833450e-01,
                         -3.06179523e-01,  -2.98018962e-01,  -2.91416526e-01,
                         -2.98126757e-01,  -3.05153161e-01,  -3.26364368e-01,
                         -3.35951060e-01,  -3.27769160e-01,  -3.13985765e-01,
                         -2.90314972e-01,  -2.82355428e-01,  -2.77741849e-01,
                         -2.72404373e-01,  -2.65976995e-01,  -2.55827963e-01,
                         -2.55622476e-01,  -2.48228416e-01,  -2.43656412e-01,
                         -2.35367313e-01,  -2.20934108e-01,  -2.16520026e-01,
                         -2.03303218e-01,  -1.96339592e-01,  -1.88395053e-01,
                         -1.73394442e-01,  -1.65679678e-01,  -1.51385605e-01,
                         -1.43410340e-01,  -1.41207501e-01,  -1.47676617e-01,
                         -1.51844382e-01,  -1.27034411e-01,  -1.03763178e-01,
                         -9.03104022e-02,  -7.32264295e-02,  -5.15584014e-02,
                         -3.64736021e-02,  -3.32892425e-02,  -2.10312400e-02,
                         -7.67490733e-03,   4.47561312e-03,   1.67522524e-02,
                          2.07849666e-02,   2.61878129e-02,   3.17249596e-02,
                          4.33033220e-02,   5.35801090e-02,   5.65349013e-02,
                          6.33857250e-02,   6.67530373e-02,   6.96135834e-02,
                          7.37915263e-02,   7.71634206e-02,   6.93232417e-02,
                          4.47470807e-02,   2.68417988e-02,   2.11291816e-02,
                          2.79683303e-02,   4.32135351e-02,   6.30967692e-02,
                          8.82743001e-02,   1.01083614e-01,   1.07165858e-01,
                          1.04972184e-01,   8.59682709e-02,   6.67689815e-02,
                          5.99018596e-02,   7.01474920e-02,   7.73216486e-02,
                          8.23072419e-02,   9.84552801e-02,   1.02406748e-01,
                          8.72617215e-02,   6.60174713e-02,   6.96407706e-02,
                          9.93321091e-02,   1.21362709e-01,   1.49828687e-01,
                          1.82258695e-01,   2.02201143e-01,   2.21038759e-01,
                          2.38477692e-01,   2.58960694e-01,   2.72155643e-01,
                          2.79656410e-01,   2.96806037e-01,   3.04610014e-01,
                          3.08064789e-01,   3.09243232e-01,   2.94253677e-01,
                          2.82838255e-01,   2.77213097e-01,   2.66177773e-01,
                          2.62450725e-01,   2.63142556e-01,   2.44567737e-01,
                          2.51936346e-01,   3.19255382e-01,   3.62838924e-01,
                          3.80535036e-01,   4.12152261e-01,   4.17936146e-01,
                          4.19433922e-01,   4.08419341e-01,   3.57768565e-01,
                          3.24933469e-01,   3.33765805e-01,   3.95831764e-01,
                          4.96192515e-01,   5.63489795e-01,   5.81077456e-01,
                          5.93787551e-01,   6.20295525e-01,   6.34647846e-01,
                          6.45499885e-01,   6.83088958e-01,   7.53433406e-01,
                          8.10184598e-01,   7.91537285e-01,   7.53338993e-01,
                          7.50536442e-01,   7.58360803e-01,   7.56970525e-01,
                          7.33015656e-01,   7.35736966e-01,   7.79908538e-01,
                          8.12049508e-01,   8.39282274e-01,   8.65956426e-01,
                          8.70818377e-01,   8.54619920e-01,   8.42327714e-01,
                          8.49384665e-01,   8.56292129e-01,   8.43178988e-01,
                          8.04967821e-01,   7.69133449e-01,   7.49151170e-01,
                          7.46227801e-01,   7.69331157e-01,   7.76087761e-01,
                          7.55773723e-01,   7.32161045e-01,   7.02775180e-01,
                          6.76585019e-01,   6.58803761e-01,   6.62489712e-01,
                          6.87856853e-01,   7.11798012e-01,   7.24370360e-01,
                          7.20191956e-01,   7.13544905e-01,   7.17551470e-01,
                          7.25459993e-01,   7.22538590e-01,   7.14804888e-01,
                          7.29153693e-01,   7.44935393e-01,   7.36724615e-01,
                          7.09600687e-01,   6.68939948e-01,   6.34361804e-01,
                          6.10593438e-01,   5.98270535e-01,   6.06643677e-01,
                          6.16150320e-01,   6.06332600e-01,   5.76766789e-01,
                          5.34211457e-01,   4.90902126e-01,   4.58519608e-01,
                          4.44470525e-01,   4.51022506e-01,   4.73565459e-01,
                          4.97718781e-01,   5.11799335e-01,   5.22115409e-01,
                          5.28474808e-01,   5.18378437e-01,   4.97599512e-01,
                          4.80602145e-01,   4.76843238e-01,   4.84606594e-01,
                          4.91881728e-01,   4.90923256e-01,   4.71819490e-01,
                          4.45710093e-01,   4.34232771e-01,   4.37218964e-01,
                          4.50232059e-01,   4.63039368e-01,   4.79285330e-01,
                          4.98778135e-01,   5.01146555e-01,   4.92589384e-01,
                          4.84904587e-01,   4.89545912e-01,   5.06462097e-01,
                          5.12308717e-01,   5.10053217e-01,   5.06779730e-01,
                          4.96136904e-01,   4.74371552e-01,   4.46013302e-01,
                          4.29600686e-01,   4.23464566e-01,   4.15370464e-01,
                          4.14997101e-01,   4.32698369e-01,   4.57502842e-01,
                          4.75507379e-01,   4.87151593e-01,   4.90355730e-01,
                          4.80917633e-01,   4.56750125e-01,   4.16111052e-01,
                          3.59723568e-01,   2.94742942e-01,   2.50047833e-01,
                          2.38717929e-01,   2.34653145e-01,   2.37825230e-01,
                          2.70849526e-01,   3.12465519e-01,   3.37787360e-01,
                          3.47814292e-01,   3.43597561e-01,   3.44163895e-01,
                          3.42638254e-01,   3.17139387e-01,   2.86261559e-01,
                          2.58548021e-01,   2.43503958e-01,   2.47557208e-01,
                          2.64232844e-01,   2.98993200e-01,   3.28860730e-01,
                          3.42287987e-01,   3.52714986e-01,   3.56928021e-01,
                          3.48687887e-01,   3.33421409e-01,   3.39286774e-01,
                          3.63809258e-01,   3.74113917e-01,   3.62540007e-01,
                          3.46860319e-01,   3.49237889e-01,   3.51863146e-01,
                          3.36730301e-01,   3.12902898e-01,   2.90840715e-01,
                          2.75863141e-01,   2.42703423e-01,   1.92193940e-01,
                          1.50718704e-01,   1.26238048e-01,   1.38255104e-01,
                          1.77857712e-01,   2.12596625e-01,   2.41352454e-01,
                          2.77481198e-01,   3.19708794e-01,   3.45335990e-01,
                          3.45444322e-01,   3.43609750e-01,   3.48174483e-01,
                          3.39057267e-01,   3.21212232e-01,   3.09447676e-01,
                          2.94364065e-01,   2.67746687e-01,   2.34599844e-01,
                          2.12673888e-01,   1.99144825e-01,   1.89079091e-01,
                          1.88829616e-01,   1.85456976e-01,   1.81033656e-01,
                          1.61270976e-01,   1.20673269e-01,   8.93836021e-02,
                          5.86708225e-02,   2.89028659e-02,   1.21207759e-02,
                          1.78185571e-02,   7.23200589e-02,   1.49725780e-01,
                          1.73926011e-01,   1.27639621e-01,   7.81148747e-02,
                          2.96993405e-02,  -2.20076423e-02,  -3.41893174e-02,
                         -6.71178028e-02,  -1.28233850e-01,  -1.67821929e-01,
                         -2.34140038e-01,  -3.25071841e-01,  -3.88697892e-01,
                         -4.01093423e-01,  -3.85620654e-01,  -3.68411064e-01,
                         -3.17810893e-01,  -2.57183701e-01,  -2.37159401e-01,
                         -2.56324828e-01,  -2.84618378e-01,  -3.03708166e-01,
                         -3.28956991e-01,  -3.49676311e-01,  -3.55912209e-01,
                         -3.38823706e-01,  -2.89403617e-01,  -2.41983175e-01,
                         -2.03633219e-01,  -1.80751681e-01,  -1.78979442e-01,
                         -1.74710527e-01,  -1.68263987e-01,  -1.55817181e-01,
                         -1.46912947e-01,  -1.42506912e-01,  -1.27220213e-01,
                         -1.23950161e-01,  -1.40077010e-01,  -1.58750176e-01,
                         -1.63398370e-01,  -1.62721053e-01,  -1.83474928e-01,
                         -2.10163414e-01,  -2.15987876e-01,  -2.08723068e-01,
                         -2.06883937e-01,  -2.06141725e-01,  -1.94053024e-01,
                         -1.78240061e-01,  -1.67709202e-01,  -1.69301987e-01,
                         -1.73819140e-01,  -1.61947563e-01,  -1.32690802e-01,
                         -9.50919613e-02,  -6.74489066e-02,  -5.75809255e-02,
                         -5.17765135e-02,  -4.44433801e-02,  -3.76679339e-02,
                         -2.94182114e-02,  -2.88060959e-02,  -3.70183922e-02,
                         -4.01273891e-02,  -3.54285575e-02,  -2.84117404e-02,
                         -2.13207509e-02,  -3.56398243e-03,   1.58518963e-02,
                          2.29828637e-02,   3.00191119e-02,   4.11477163e-02,
                          4.28254157e-02,   2.78632175e-02,   1.26219494e-02,
                         -2.44244497e-04,  -2.55978368e-02,  -4.93204929e-02,
                         -7.22278431e-02,  -1.03509068e-01,  -1.30907312e-01,
                         -1.33454993e-01,  -1.13798611e-01,  -9.72925499e-02,
                         -7.79906437e-02,  -4.39051948e-02,  -1.85666289e-02,
                         -1.62173249e-02,  -2.33128183e-02,  -1.27299512e-02,
                         -2.20185611e-03,  -8.09184555e-03,  -1.14052473e-02,
                         -1.62676834e-02,  -3.65676433e-02,  -8.07587355e-02,
                         -1.35371134e-01,  -1.76382393e-01,  -1.97322488e-01,
                         -2.03001931e-01,  -2.08656445e-01,  -2.16810167e-01,
                         -2.26100937e-01,  -2.45143220e-01,  -2.76394725e-01,
                         -3.13983172e-01,  -3.42057556e-01,  -3.50555062e-01,
                         -3.51792514e-01,  -3.42402726e-01,  -3.22798789e-01,
                         -2.96744734e-01,  -2.74135768e-01,  -2.62254924e-01,
                         -2.67584175e-01,  -2.81517774e-01,  -2.91759819e-01,
                         -3.08565885e-01,  -3.36661398e-01,  -3.56381029e-01,
                         -3.56107980e-01,  -3.36680025e-01,  -3.14972043e-01,
                         -2.90934324e-01,  -2.69610614e-01,  -2.64830738e-01,
                         -2.69610971e-01,  -2.63144255e-01,  -2.41776004e-01,
                         -2.31603399e-01,  -2.39973828e-01,  -2.51645654e-01,
                         -2.49021560e-01,  -2.39165142e-01,  -2.43143961e-01,
                         -2.48910323e-01,  -2.63880819e-01,  -2.87615478e-01,
                         -3.13919127e-01,  -3.48034382e-01,  -3.77592713e-01,
                         -3.96330714e-01,  -3.98055941e-01,  -3.86364937e-01,
                         -3.91282886e-01,  -4.04556662e-01,  -4.14397985e-01,
                         -4.16747570e-01,  -4.15324360e-01,  -4.24755007e-01,
                         -4.48363513e-01,  -4.79887038e-01,  -4.99833256e-01,
                         -5.08588195e-01,  -5.21016181e-01,  -5.32630622e-01,
                         -5.62269509e-01,  -5.88742375e-01,  -5.96173584e-01,
                         -5.83983421e-01,  -5.57410240e-01,  -5.35922408e-01,
                         -5.24022818e-01,  -5.17495275e-01,  -5.18183351e-01,
                         -5.26840806e-01,  -5.18892348e-01,  -4.79122639e-01,
                         -4.23591882e-01,  -3.81945431e-01,  -3.69346082e-01,
                         -3.74539375e-01,  -3.75859827e-01,  -3.74907613e-01,
                         -3.84358615e-01,  -4.01201993e-01,  -4.19592321e-01,
                         -4.34069753e-01,  -4.55545515e-01,  -4.81133819e-01,
                         -5.09707332e-01,  -5.33530116e-01,  -5.39310277e-01,
                         -5.26673019e-01,  -5.04265010e-01,  -4.96819049e-01,
                         -5.05688488e-01,  -5.17836809e-01,  -5.34290731e-01,
                         -5.32117486e-01,  -5.08091450e-01,  -4.56913769e-01,
                         -4.07021821e-01,  -3.83149266e-01,  -3.66704136e-01,
                         -3.58155429e-01,  -3.56389523e-01,  -3.61892402e-01,
                         -3.53912950e-01,  -3.35089445e-01,  -3.09328109e-01,
                         -2.66523391e-01,  -2.56887108e-01,  -2.69917846e-01,
                         -2.53950387e-01,  -2.00685531e-01,  -1.77277416e-01,
                         -2.37960190e-01,  -2.73077041e-01,  -2.59413809e-01,
                         -2.38289878e-01,  -1.67370662e-01,  -9.55891758e-02,
                         -8.26890618e-02,  -5.99197522e-02,   1.42477453e-02,
                          8.60896856e-02,   1.27798051e-01,   1.55867323e-01,
                          1.46966025e-01,   1.04277365e-01,   5.99511303e-02,
                          2.97743138e-02,   3.28577347e-02,   4.80896272e-02,
                          6.95251822e-02,   9.79612991e-02,   1.10455438e-01,
                          1.02722652e-01,   8.28679278e-02,   5.71952909e-02,
                          3.89937721e-02,   1.84067786e-02,   7.58984964e-03,
                          8.27242993e-03,  -7.16700638e-03,  -1.33117810e-02,
                         -2.27290411e-02,  -2.55276356e-02,  -2.93635111e-02,
                         -5.41662760e-02,  -6.70807883e-02,  -5.45910075e-02,
                         -2.72149742e-02,  -1.43595692e-03,   8.11260380e-03,
                          2.71866694e-02,   4.28856388e-02,   3.80194597e-02,
                          2.19499804e-02,  -4.31513938e-04,  -1.89376697e-02,
                         -3.75774838e-02,  -4.86155115e-02,  -3.26535553e-02,
                         -3.59637290e-03,   1.69616658e-02,   1.08660599e-02,
                         -5.44556475e-04,  -1.17956279e-02,  -3.32019292e-02,
                         -5.53036556e-02,  -7.49603286e-02,  -8.48537534e-02,
                         -8.47137123e-02,  -7.53742307e-02,  -4.58962359e-02,
                         -7.84916431e-03,   2.77906805e-02,   5.34754060e-02,
                          7.00390413e-02,   8.32866803e-02,   9.56284329e-02,
                          1.12377077e-01,   1.40489787e-01,   1.62938297e-01,
                          1.70668572e-01,   1.54155910e-01,   1.27477020e-01,
                          1.10042788e-01,   1.16629951e-01,   1.26456663e-01,
                          1.38255462e-01,   1.42812759e-01,   1.40155792e-01,
                          1.26113132e-01,   9.82513502e-02,   7.21922368e-02,
                          5.43488078e-02,   3.50431874e-02,   1.28676854e-02,
                         -5.98001061e-03,  -1.60050541e-02,  -2.54815388e-02,
                         -2.85542626e-02,  -2.50568371e-02,  -2.42352374e-02,
                         -3.03374380e-02,  -4.13265787e-02,  -5.07635809e-02,
                         -6.57639503e-02,  -7.44085535e-02,  -6.26657754e-02,
                         -3.23322564e-02,   8.64710892e-04,   1.37816202e-02,
                          1.96360573e-02,   1.43342260e-02,  -7.99598638e-03,
                         -3.66988555e-02,  -3.33720557e-02,  -1.43153509e-02,
                          1.66147109e-02,   5.26788980e-02,   8.60197544e-02,
                          1.13805734e-01,   1.23898521e-01,   1.21874392e-01,
                          1.18796088e-01,   1.18476257e-01,   1.08216673e-01,
                          8.95957872e-02,   6.21121600e-02,   1.84152480e-02,
                         -1.29386401e-02,  -5.11269867e-02,  -8.77016112e-02,
                         -1.09949395e-01,  -1.06255390e-01,  -8.51745531e-02,
                         -5.12380712e-02,  -1.26028266e-02,  -6.99017569e-03,
                         -1.43082095e-02,  -1.53029338e-02,   5.64358430e-03,
                          2.85732951e-02,   3.42748612e-02,   4.82321456e-02,
                          5.75768389e-02,   4.39895540e-02,   1.67498197e-02,
                         -2.44593888e-04,  -4.45126696e-03,  -1.15512982e-02,
                         -1.44982906e-02,  -5.01966244e-03,   5.05520590e-03,
                          1.93637609e-02,   4.37979363e-02,   8.47590193e-02,
                          1.14014223e-01,   1.38590053e-01,   1.58635095e-01,
                          1.64023861e-01,   1.60199285e-01,   1.60587221e-01,
                          1.80433169e-01,   2.08307549e-01,   2.08133221e-01,
                          1.93228468e-01,   1.84533224e-01,   1.82546422e-01,
                          1.99555889e-01,   2.31375352e-01,   2.70869434e-01,
                          3.06863666e-01,   3.50729793e-01,   3.96034032e-01,
                          4.20301497e-01,   4.14772153e-01,   3.93485576e-01,
                          3.65181834e-01,   3.33425939e-01,   3.16910565e-01,
                          3.23953599e-01,   3.32159758e-01,   3.26024652e-01,
                          3.20998043e-01,   3.30432892e-01,   3.35751534e-01,
                          3.12341422e-01,   2.76066810e-01,   2.44904116e-01,
                          2.28682980e-01,   2.41848096e-01,   2.68009722e-01,
                          3.06446463e-01,   3.50548148e-01,   3.76968473e-01,
                          3.91586691e-01,   3.93201739e-01,   3.92784595e-01,
                          4.09151942e-01,   4.28796500e-01,   4.49997425e-01,
                          4.80046540e-01,   4.99965131e-01,   5.05867124e-01,
                          4.96490955e-01,   4.84481335e-01,   4.72057760e-01,
                          4.47991014e-01,   4.32908207e-01,   4.23403382e-01,
                          4.22829688e-01,   4.09164816e-01,   3.88299406e-01,
                          3.72756928e-01,   3.88503969e-01,   4.09540117e-01,
                          4.19785857e-01,   4.29606706e-01,   4.42554861e-01,
                          4.64959025e-01,   4.96090174e-01,   5.30576646e-01,
                          5.50397396e-01,   5.50413132e-01,   5.44998109e-01,
                          5.41904747e-01,   5.58469951e-01,   5.88276744e-01,
                          6.03110492e-01,   6.02261722e-01,   6.01487279e-01,
                          5.97454250e-01,   5.76687813e-01,   5.47242522e-01,
                          5.20208180e-01,   5.04334509e-01,   5.08338809e-01,
                          5.14925182e-01,   5.18434048e-01,   4.87600207e-01,
                          4.34728146e-01,   3.86739850e-01,   3.63424301e-01,
                          3.46001744e-01,   3.25557768e-01,   3.11852813e-01,
                          2.86460072e-01,   2.61200637e-01,   2.36262321e-01,
                          2.18297407e-01,   2.49626637e-01,   2.89626151e-01,
                          3.26837033e-01,   3.35336328e-01,   3.50954354e-01,
                          3.58291388e-01,   3.04223955e-01,   2.27755278e-01,
                          1.57365441e-01,   1.10771604e-01,   8.93616155e-02,
                          1.02496013e-01,   1.23004794e-01,   1.08124912e-01,
                          1.20066583e-01,   1.28550723e-01,   1.23747982e-01,
                          1.33688241e-01,   1.09275989e-01,   6.00850098e-02,
                          2.10412480e-02,   1.25841564e-02,   4.44625653e-02,
                          5.27205952e-02,  -2.52296422e-02,  -1.00106724e-01,
                         -1.24309011e-01,  -1.63635567e-01,  -2.01363266e-01,
                         -2.25103706e-01,  -2.31266111e-01,  -2.31653094e-01,
                         -2.29580060e-01,  -2.28168339e-01,  -2.05628127e-01,
                         -1.98534936e-01,  -2.06972286e-01,  -2.20375940e-01,
                         -2.34145537e-01,  -2.46448576e-01,  -2.65628994e-01,
                         -2.75303185e-01,  -2.74584711e-01,  -2.69859880e-01,
                         -2.60527223e-01,  -2.52710402e-01,  -2.46569067e-01,
                         -2.36158609e-01,  -2.15907946e-01,  -1.92194015e-01,
                         -1.74960345e-01,  -1.72271430e-01,  -1.70668140e-01,
                         -1.72107920e-01,  -1.81535259e-01,  -2.03716949e-01,
                         -2.26291314e-01,  -2.45786220e-01,  -2.58503556e-01,
                         -2.45804876e-01,  -2.32500136e-01,  -2.25060582e-01,
                         -2.13471696e-01,  -2.02321589e-01,  -1.88925087e-01,
                         -1.72684148e-01,  -1.58549458e-01,  -1.50840059e-01,
                         -1.24052614e-01,  -8.96656588e-02,  -6.09916411e-02,
                         -5.90739474e-02,  -8.41604918e-02,  -1.21414937e-01,
                         -1.57161847e-01,  -1.91331074e-01,  -2.22753823e-01,
                         -2.48662457e-01,  -2.65358418e-01,  -2.76878357e-01,
                         -2.72402972e-01,  -2.51625001e-01,  -2.37729296e-01,
                         -2.36234248e-01,  -2.29099154e-01,  -2.23014906e-01,
                         -2.25485563e-01,  -2.30264455e-01,  -2.24546134e-01,
                         -1.88507944e-01,  -1.58798769e-01,  -1.39619574e-01,
                         -1.33643255e-01,  -1.20424926e-01,  -9.66562778e-02,
                         -6.71854317e-02,  -3.97172421e-02,  -3.00679915e-02,
                         -1.48006864e-02,  -8.57821215e-05,  -5.88357216e-04,
                         -3.81002910e-02,  -1.12333849e-01,  -1.87251151e-01,
                         -2.34651983e-01,  -2.69002676e-01,  -3.06953520e-01,
                         -3.28842074e-01,  -3.21253449e-01,  -3.02153230e-01,
                         -2.94018418e-01,  -2.92772233e-01,  -2.76844651e-01,
                         -2.46915817e-01,  -2.12573543e-01,  -1.94895208e-01,
                         -2.22490579e-01,  -2.51792550e-01,  -2.50946909e-01,
                         -2.39674225e-01,  -2.44437039e-01,  -2.54570484e-01,
                         -2.68719763e-01,  -2.94606358e-01,  -3.18590134e-01,
                         -3.29989672e-01,  -3.13997924e-01,  -2.74377465e-01,
                         -2.33855769e-01,  -1.88438982e-01,  -1.59433022e-01,
                         -1.44476026e-01,  -1.56136692e-01,  -1.65463522e-01,
                         -1.60639837e-01,  -1.51916519e-01,  -1.64446220e-01,
                         -1.89386502e-01,  -2.23623931e-01,  -2.43560821e-01,
                         -2.24210605e-01,  -2.39947975e-01,  -2.43970409e-01,
                         -2.08080560e-01,  -1.94865197e-01,  -1.80853084e-01,
                         -1.70419365e-01,  -1.65008828e-01,  -1.93896085e-01,
                         -2.57272303e-01,  -2.84466058e-01,  -3.06059510e-01,
                         -3.33363920e-01,  -3.73015761e-01,  -4.27124470e-01,
                         -4.42387998e-01,  -4.59822237e-01,  -4.60921735e-01,
                         -4.53076899e-01,  -4.33044970e-01,  -3.94234329e-01,
                         -3.59416425e-01,  -3.42811912e-01,  -3.45241100e-01,
                         -3.43929201e-01,  -3.28863800e-01,  -3.16709399e-01,
                         -3.07284385e-01,  -3.13522756e-01,  -3.23695272e-01,
                         -3.48604530e-01,  -3.63479137e-01,  -3.57937038e-01,
                         -3.48043859e-01,  -3.42475146e-01,  -3.42070520e-01,
                         -3.36300850e-01,  -3.37954849e-01,  -3.31292272e-01,
                         -2.95125335e-01,  -2.54692435e-01,  -2.26900265e-01,
                         -2.41368458e-01,  -2.77387023e-01,  -3.00815493e-01,
                         -3.19944501e-01,  -3.24916720e-01,  -3.09946626e-01,
                         -2.83641100e-01,  -2.33903334e-01,  -1.98583513e-01,
                         -1.73218921e-01,  -1.58075631e-01,  -1.72528848e-01,
                         -1.99030310e-01,  -2.32044429e-01,  -2.25047544e-01,
                         -1.86382413e-01,  -1.61734268e-01,  -1.27931610e-01,
                         -1.11651316e-01,  -1.31312609e-01,  -2.09357604e-01,
                         -2.58813739e-01,  -2.75669366e-01,  -2.94960439e-01,
                         -2.99036294e-01,  -2.86260426e-01,  -2.63867825e-01,
                         -2.62207568e-01,  -2.82461315e-01,  -2.87383199e-01,
                         -2.59471983e-01,  -2.18194410e-01,  -1.98369458e-01,
                         -1.85304984e-01,  -1.10720098e-01,  -7.50411302e-02,
                         -1.11900285e-01,  -9.45538580e-02,  -8.72331709e-02,
                         -1.07264213e-01,  -7.96300471e-02,  -5.68929315e-02,
                         -6.99689984e-02,  -6.76765889e-02,  -6.11216500e-02,
                         -5.90830557e-02,  -5.68213016e-02,  -9.50465575e-02,
                         -1.38933331e-01,  -1.62480056e-01,  -2.09702730e-01,
                         -2.56887197e-01,  -3.04664403e-01,  -3.26570183e-01,
                         -3.11079621e-01,  -2.81545013e-01,  -2.50459701e-01,
                         -2.36159429e-01,  -2.40371540e-01,  -2.49224454e-01,
                         -2.56932318e-01,  -2.63435781e-01,  -2.79273123e-01,
                         -3.05865169e-01,  -3.28681201e-01,  -3.43809068e-01,
                         -3.55775148e-01,  -3.48695457e-01,  -3.29669237e-01,
                         -3.09925348e-01,  -3.01799655e-01,  -3.11321050e-01,
                         -3.11371863e-01,  -3.12814295e-01,  -3.15277159e-01,
                         -3.03804606e-01,  -2.62582630e-01,  -2.20454961e-01,
                         -2.05262870e-01,  -2.03246638e-01,  -1.95572883e-01,
                         -1.79236695e-01,  -1.58361867e-01,  -1.47565439e-01,
                         -1.36105046e-01,  -1.17076337e-01,  -1.18100509e-01,
                         -1.51528776e-01,  -1.87603265e-01,  -1.85894161e-01,
                         -1.64271191e-01,  -1.47119641e-01,  -1.59471259e-01,
                         -1.79656148e-01,  -1.96547240e-01,  -2.12992251e-01,
                         -2.24444449e-01,  -2.33433738e-01,  -2.30730265e-01,
                         -2.25501537e-01,  -2.09913924e-01,  -2.07590953e-01,
                         -2.19402373e-01,  -2.29611695e-01,  -2.26064518e-01,
                         -2.16502622e-01,  -2.02123627e-01,  -1.89578891e-01,
                         -1.81880832e-01,  -1.76378071e-01,  -1.62072301e-01,
                         -1.40685439e-01,  -1.23460159e-01,  -9.76086184e-02,
                         -5.96995987e-02,  -4.35672328e-02,  -4.05609906e-02,
                         -4.63609770e-02,  -5.44509701e-02,  -6.45616204e-02,
                         -7.69599751e-02,  -7.39316568e-02,  -5.15880473e-02,
                         -3.40076089e-02,  -2.98202615e-02,  -3.53336111e-02,
                         -4.13211882e-02,  -4.86114211e-02,  -4.76773754e-02,
                         -3.98405008e-02,  -4.25375253e-02,  -5.50642759e-02,
                         -8.00465643e-02,  -1.23678230e-01,  -1.80964589e-01,
                         -2.27914661e-01,  -2.42214650e-01,  -2.01540142e-01,
                         -1.20631889e-01,  -5.41023426e-02,   3.28913284e-03,
                          4.31208797e-02,   6.67244941e-02,   7.72939920e-02,
                          8.79143700e-02,   8.35268870e-02,   6.93926141e-02,
                          4.93549258e-02,   3.36052850e-02,   1.93608794e-02,
                          2.71979556e-03,  -1.39289070e-02,  -2.09750608e-02,
                         -2.13726256e-02,  -1.19808689e-02,  -1.60863101e-02,
                         -3.26512866e-02,  -2.93325558e-02,  -1.03026107e-02,
                          9.48809180e-03,   2.46968493e-02,   3.55611891e-02,
                          6.54272959e-02,   1.10381797e-01,   1.53756544e-01,
                          1.91997245e-01,   2.04134405e-01,   1.82068959e-01,
                          1.27924845e-01,   7.48466104e-02,   5.77770993e-02,
                          5.59131317e-02,   5.72714545e-02,   6.04941547e-02,
                          9.32238027e-02,   1.29538223e-01,   1.58314392e-01,
                          1.86179891e-01,   2.21498027e-01,   2.06772804e-01,
                          1.32135153e-01,   8.28611255e-02,   6.23871274e-02,
                          7.37699866e-02,   1.10862777e-01,   1.57499060e-01,
                          1.83702841e-01,   1.43419817e-01,   1.24102131e-01,
                          1.36067420e-01,   2.09894091e-01,   3.38271528e-01,
                          4.07989740e-01,   3.98946732e-01,   3.78088564e-01,
                          3.65590245e-01,   3.60440493e-01,   3.99404913e-01,
                          4.45215821e-01,   4.84298408e-01,   5.48443675e-01,
                          6.16288543e-01,   6.87680781e-01,   7.37275898e-01,
                          6.90802753e-01,   6.12447739e-01,   5.86725891e-01,
                          5.65977991e-01,   5.46953440e-01,   5.59461951e-01,
                          5.71260154e-01,   5.66901922e-01,   5.66590011e-01,
                          5.75584948e-01,   6.11353695e-01,   6.48112655e-01,
                          6.66466177e-01,   6.79922581e-01,   7.02306271e-01,
                          7.04988956e-01,   6.77478790e-01,   6.36410892e-01,
                          6.04374766e-01,   5.97881496e-01,   6.07255876e-01,
                          6.27320230e-01,   6.58478618e-01,   6.74413085e-01,
                          6.61598325e-01,   6.18232071e-01,   5.60515225e-01,
                          5.17990470e-01,   4.94767487e-01,   4.92836148e-01,
                          5.03355980e-01,   5.26848912e-01,   5.40355623e-01,
                          5.22673249e-01,   4.74700183e-01,   4.16225165e-01,
                          3.77150178e-01,   3.58738810e-01,   3.53347391e-01,
                          3.54407996e-01,   3.73568028e-01,   4.04277802e-01,
                          4.21734512e-01,   4.29246336e-01,   4.13523793e-01,
                          3.82912248e-01,   3.43426675e-01,   3.10244918e-01,
                          3.00794899e-01,   3.00940603e-01,   3.10830593e-01,
                          3.32140952e-01,   3.61192256e-01,   3.79516244e-01,
                          3.91903281e-01,   4.09675390e-01,   4.28094089e-01,
                          4.36553180e-01,   4.34135258e-01,   4.20770913e-01,
                          4.00109142e-01,   3.84697020e-01,   3.88315350e-01,
                          4.05431449e-01,   4.10278469e-01,   4.14658785e-01,
                          4.13920194e-01,   4.04791981e-01,   3.85013074e-01,
                          3.64861786e-01,   3.51295054e-01,   3.63298655e-01,
                          3.98032427e-01,   4.34291571e-01,   4.51965362e-01,
                          4.60353047e-01,   4.53068078e-01,   4.26773489e-01,
                          4.01424468e-01,   3.89750510e-01,   3.95356685e-01,
                          4.05168474e-01,   4.06358242e-01,   3.73616338e-01,
                          3.26916158e-01,   3.01967651e-01,   2.76610523e-01,
                          2.53704429e-01,   2.38000661e-01,   2.22310111e-01,
                          2.05242589e-01,   2.02110589e-01,   2.21004128e-01,
                          2.50831306e-01,   2.74624020e-01,   2.85439044e-01,
                          3.01769227e-01,   3.26722622e-01,   3.44992042e-01,
                          3.55441958e-01,   3.55789125e-01,   3.61870408e-01,
                          3.66338670e-01,   3.64524871e-01,   3.59851182e-01,
                          3.61090571e-01,   3.63567621e-01,   3.55044246e-01,
                          3.30723196e-01,   3.05430621e-01,   2.81830877e-01,
                          2.69194901e-01,   2.54367650e-01,   2.38068029e-01,
                          2.27415815e-01,   2.21770734e-01,   2.06141740e-01,
                          1.82710737e-01,   1.64282799e-01,   1.50529116e-01,
                          1.42981008e-01,   1.27929062e-01,   8.95432085e-02,
                          5.03537878e-02,   2.72800662e-02,   8.98047630e-03,
                         -4.52035107e-03,  -1.26558477e-02,  -1.71043538e-02,
                         -1.95825808e-02,  -2.70510204e-02,  -2.53935121e-02,
                         -1.91776417e-02,  -2.60907989e-02,  -2.09530275e-02,
                         -6.15352206e-03,  -2.34879628e-02,  -5.79379760e-02,
                         -8.17827433e-02,  -9.78579596e-02,  -1.35892913e-01,
                         -1.59170583e-01,  -1.67531699e-01,  -1.68795720e-01,
                         -1.68959007e-01,  -1.63712814e-01,  -1.31732017e-01,
                         -1.09788120e-01,  -9.88233611e-02,  -1.02087282e-01,
                         -1.13880724e-01,  -1.00726150e-01,  -7.84755722e-02,
                         -4.71991785e-02,  -2.10464839e-02,  -7.96389021e-03,
                          1.84889382e-03,   7.72462646e-03,   5.78055531e-03,
                          1.72434803e-02,   3.38999964e-02,   3.16844098e-02,
                          3.32353674e-02,   2.98100691e-02,   1.32108266e-02,
                         -5.87475253e-04,  -4.51518269e-03,   4.79010073e-03,
                          8.71532876e-03,  -1.27683878e-02,  -4.71271724e-02,
                         -8.47353637e-02,  -1.36000559e-01,  -1.94849059e-01,
                         -2.49914587e-01,  -2.89345086e-01,  -3.15012366e-01,
                         -3.17582428e-01,  -2.89158553e-01,  -2.43655354e-01,
                         -1.97557405e-01,  -1.50211141e-01,  -1.09457031e-01,
                         -7.92415813e-02,  -5.58310002e-02,  -4.37447540e-02,
                         -4.32448387e-02,  -3.49761546e-02,  -2.88689882e-02,
                         -3.50537226e-02,  -4.86989766e-02,  -6.79541454e-02,
                         -8.39155316e-02,  -1.06108703e-01,  -1.43405020e-01,
                         -1.89189643e-01,  -2.23243788e-01,  -2.38691717e-01,
                         -2.25775570e-01,  -1.92000553e-01,  -1.60137430e-01,
                         -1.43834427e-01,  -1.37520298e-01,  -1.26409009e-01,
                         -1.21360809e-01,  -1.25813991e-01,  -1.25773102e-01,
                         -1.32274255e-01,  -1.48699939e-01,  -1.60943568e-01,
                         -1.73004866e-01,  -1.76270127e-01,  -1.69159397e-01,
                         -1.72178462e-01,  -1.78589746e-01,  -1.84278086e-01,
                         -1.98722944e-01,  -1.86805561e-01,  -1.84459388e-01,
                         -2.79235691e-01,  -3.81087303e-01,  -4.07421947e-01,
                         -4.44457829e-01,  -5.01229942e-01,  -5.24953485e-01,
                         -5.40966988e-01,  -5.56995034e-01,  -5.75094581e-01,
                         -6.18315279e-01,  -6.51230991e-01,  -6.51865482e-01,
                         -6.39617503e-01,  -6.04478896e-01,  -5.66699982e-01,
                         -5.61038077e-01,  -5.65649688e-01,  -5.55284142e-01,
                         -5.69579542e-01,  -6.19221091e-01,  -6.71134770e-01,
                         -7.01114774e-01,  -7.11720943e-01,  -6.96379840e-01,
                         -6.50570214e-01,  -5.97582638e-01,  -5.55686772e-01,
                         -5.26794374e-01,  -5.09397745e-01,  -5.08167267e-01,
                         -5.27444005e-01,  -5.56587696e-01,  -5.75822592e-01,
                         -5.80155790e-01,  -5.72932780e-01,  -5.62308371e-01,
                         -5.54650903e-01,  -5.51150203e-01,  -5.53923130e-01,
                         -5.60327411e-01,  -5.55772126e-01,  -5.35538197e-01,
                         -5.17028451e-01,  -5.00417233e-01,  -4.90800858e-01,
                         -4.88408923e-01,  -4.90031630e-01,  -4.91980642e-01,
                         -4.87117410e-01,  -4.95972812e-01,  -5.33079684e-01,
                         -5.55067182e-01,  -5.46315789e-01,  -5.38480997e-01,
                         -5.35016537e-01,  -5.29497504e-01,  -5.25418460e-01,
                         -5.18416405e-01,  -5.10703146e-01,  -4.94467676e-01,
                         -4.76081192e-01,  -4.69848722e-01,  -4.65828270e-01,
                         -4.46195066e-01,  -4.19621378e-01,  -4.06118006e-01,
                         -3.95607173e-01,  -3.85973394e-01,  -4.00992751e-01,
                         -4.35954094e-01,  -4.56014544e-01,  -4.46072340e-01,
                         -4.11646307e-01,  -3.53082895e-01,  -2.90720910e-01,
                         -2.34780237e-01,  -1.80322543e-01,  -1.41593054e-01,
                         -1.22216277e-01,  -1.25531092e-01,  -1.49977341e-01,
                         -1.73260272e-01,  -1.89935178e-01,  -2.14145362e-01,
                         -2.46861607e-01,  -2.78418660e-01,  -3.01759303e-01,
                         -3.04160804e-01,  -2.83271462e-01,  -2.50895947e-01,
                         -2.29566976e-01,  -2.28565976e-01,  -2.39429742e-01,
                         -2.45297551e-01,  -2.38320082e-01,  -2.08962590e-01,
                         -1.63007841e-01,  -1.32856220e-01,  -1.15027145e-01,
                         -9.34807360e-02,  -7.23485202e-02,  -5.26023768e-02,
                         -3.04775368e-02,  -4.91561880e-03,   1.89493317e-02,
                          3.12852673e-02,   2.31185872e-02,  -1.91309943e-03,
                         -3.53678428e-02,  -6.84830844e-02,  -9.70832258e-02,
                         -1.23618998e-01,  -1.37137786e-01,  -1.37676612e-01,
                         -1.41982689e-01,  -1.45282790e-01,  -1.38248265e-01,
                         -1.32732719e-01,  -1.36337355e-01,  -1.55156150e-01,
                         -1.89411253e-01,  -2.16222122e-01,  -2.17156261e-01,
                         -2.01378256e-01,  -1.82187304e-01,  -1.52104676e-01,
                         -1.10179678e-01,  -6.62402809e-02,  -1.77849177e-02,
                          2.84735858e-02,   4.45819497e-02,   2.38852911e-02,
                         -6.94926362e-03,  -3.98178324e-02,  -8.03715065e-02,
                         -1.17954768e-01,  -1.44459367e-01,  -1.48950428e-01,
                         -1.25930622e-01,  -8.52067322e-02,  -3.23258489e-02,
                          1.31397480e-02,   3.74866277e-02,   6.42258748e-02,
                          9.14663449e-02,   9.21668559e-02,   9.87736732e-02,
                          1.26982763e-01,   1.22294515e-01,   9.01262015e-02,
                          7.36460984e-02,   5.81842773e-02,   3.59950177e-02,
                          1.58271324e-02,  -1.31063825e-02,  -4.77312580e-02,
                         -7.64986351e-02,  -9.93824005e-02,  -1.07104309e-01,
                         -9.20792893e-02,  -6.50403351e-02,  -3.79986688e-02,
                         -2.45234314e-02,  -1.89852118e-02,   5.33892633e-03,
                          5.16769402e-02,   1.04968451e-01,   1.44995600e-01,
                          1.76647738e-01,   2.33450770e-01,   3.03941190e-01,
                          3.53359133e-01,   3.98885161e-01,   4.65313315e-01,
                          5.20342827e-01,   5.28824687e-01,   4.96200174e-01,
                          4.52533901e-01,   4.31251317e-01,   4.17669147e-01,
                          3.94150525e-01,   3.73772621e-01,   3.42970312e-01,
                          3.23292255e-01,   3.71771038e-01,   4.43828285e-01,
                          4.57522959e-01,   4.41495657e-01,   4.43799913e-01,
                          4.49907601e-01,   4.66289997e-01,   4.94735926e-01,
                          4.91679072e-01,   4.68433172e-01,   4.88379151e-01,
                          5.50230086e-01,   5.96029818e-01,   6.02639556e-01,
                          5.94994664e-01,   6.01054251e-01,   6.16169930e-01,
                          6.19866610e-01,   6.12247407e-01,   5.96939147e-01,
                          5.80632329e-01,   5.80551744e-01,   5.86147189e-01,
                          5.91989756e-01,   6.15055561e-01,   6.38794780e-01,
                          6.52054667e-01,   6.60603642e-01,   6.60551369e-01,
                          6.62255704e-01,   6.58718228e-01,   6.44238532e-01,
                          6.30308509e-01,   6.04059398e-01,   5.63689947e-01,
                          5.21137178e-01,   4.82249737e-01,   4.56396580e-01,
                          4.50479656e-01,   4.57846850e-01,   4.59751904e-01,
                          4.56601709e-01,   4.51464385e-01,   4.39959675e-01,
                          4.25286740e-01,   4.11772817e-01,   4.06014979e-01,
                          3.98306042e-01,   3.98516059e-01,   4.22609359e-01,
                          4.41600949e-01,   4.49837923e-01,   4.61125582e-01,
                          4.70703483e-01,   4.77345377e-01,   4.76930737e-01,
                          4.66041028e-01,   4.48988736e-01,   4.24966455e-01,
                          3.85667831e-01,   3.43851745e-01,   3.17693830e-01,
                          3.01039219e-01,   2.86469489e-01,   2.65873134e-01,
                          2.46793211e-01,   2.52487481e-01,   2.83470452e-01,
                          3.21386516e-01,   3.48260194e-01,   3.63118470e-01,
                          3.71044695e-01,   3.75503123e-01,   3.85354847e-01,
                          3.92716646e-01,   3.87812346e-01,   3.83154720e-01,
                          3.81859124e-01,   3.69889438e-01,   3.49366277e-01,
                          3.26029271e-01,   3.02465498e-01,   2.87295878e-01,
                          2.57953763e-01,   2.04521507e-01,   1.69242427e-01,
                          1.61510974e-01,   1.61936954e-01,   1.83086589e-01,
                          2.24278480e-01,   2.43328929e-01,   2.15190902e-01,
                          1.68814257e-01,   1.35324657e-01,   1.03913888e-01,
                          7.38555938e-02,   6.72983751e-02,   7.53912926e-02,
                          8.03785995e-02,   8.54576081e-02,   9.42627117e-02,
                          9.73823145e-02,   8.19538906e-02,   6.00809902e-02,
                          4.77718003e-02,   3.98219675e-02,   3.57524008e-02,
                          4.26475815e-02,   5.01746461e-02,   3.07872184e-02,
                         -2.09242087e-02,  -8.13545510e-02,  -1.34479284e-01,
                         -1.87668875e-01,  -2.48075381e-01,  -2.98785627e-01,
                         -3.06822538e-01,  -2.42433488e-01,  -1.47355378e-01,
                         -8.89450684e-02,  -4.39179651e-02,  -2.70513911e-02,
                         -8.49056691e-02,  -1.63645566e-01,  -2.58372933e-01,
                         -3.84073794e-01,  -4.54498023e-01,  -4.57161784e-01,
                         -4.52571779e-01,  -4.23814088e-01,  -3.72725666e-01,
                         -3.51522624e-01,  -3.42072636e-01,  -3.31162244e-01,
                         -3.47497672e-01,  -3.74864042e-01,  -4.25598532e-01,
                         -4.94268537e-01,  -5.20502448e-01,  -5.36713421e-01,
                         -5.48339605e-01,  -5.07094443e-01,  -4.85304743e-01,
                         -5.25735915e-01,  -5.61618268e-01,  -5.42057514e-01,
                         -4.57905203e-01,  -3.84819478e-01,  -4.07064170e-01,
                         -4.73004192e-01,  -5.01602352e-01,  -5.02286315e-01,
                         -5.01756132e-01,  -5.06740808e-01,  -5.20645022e-01,
                         -5.29813588e-01,  -5.28474748e-01,  -5.11620104e-01,
                         -4.85152334e-01,  -4.92204159e-01,  -5.32119632e-01,
                         -5.77587545e-01,  -6.22100413e-01,  -6.45857394e-01,
                         -6.56393349e-01,  -6.59089804e-01,  -6.37984753e-01,
                         -6.09527647e-01,  -5.78536451e-01,  -5.47436774e-01,
                         -5.29117405e-01,  -5.09252131e-01,  -4.82907206e-01,
                         -4.59164917e-01,  -4.43057716e-01,  -4.39436644e-01,
                         -4.42120284e-01,  -4.40696746e-01,  -4.33319896e-01,
                         -4.19140726e-01,  -3.92306179e-01,  -3.52077007e-01,
                         -3.00016820e-01,  -2.52679586e-01,  -2.24594370e-01,
                         -2.13496342e-01,  -2.46876910e-01,  -3.15769553e-01,
                         -3.68673891e-01,  -4.01522577e-01,  -4.16529000e-01,
                         -4.09239322e-01,  -3.78448665e-01,  -3.48777652e-01,
                         -3.51455271e-01,  -3.61422777e-01,  -3.72111857e-01,
                         -3.80004376e-01,  -3.75159800e-01,  -3.67911339e-01,
                         -3.45785648e-01,  -3.34992319e-01,  -3.31741929e-01,
                         -3.15100163e-01,  -3.29934746e-01,  -3.59806389e-01,
                         -3.88510793e-01,  -4.21023250e-01,  -4.22926992e-01,
                         -4.09253538e-01,  -3.98998797e-01,  -3.88300925e-01,
                         -3.68645132e-01,  -3.22393954e-01,  -2.73636281e-01,
                         -2.44590551e-01,  -2.26198554e-01,  -2.21174866e-01,
                         -2.29406312e-01,  -2.39598051e-01,  -2.50681579e-01,
                         -2.60335743e-01,  -2.63618171e-01,  -2.56348997e-01,
                         -2.30405718e-01,  -1.96670562e-01,  -1.68613136e-01,
                         -1.52776837e-01,  -1.58899829e-01,  -1.76781848e-01,
                         -1.90972462e-01,  -1.90443620e-01,  -1.70314297e-01,
                         -1.48511037e-01,  -1.40474662e-01,  -1.42145187e-01,
                         -1.55892655e-01,  -1.89299658e-01,  -2.26837799e-01,
                         -2.53590494e-01,  -2.68966377e-01,  -2.71228641e-01,
                         -2.62565106e-01,  -2.45663747e-01,  -2.36076310e-01,
                         -2.47343823e-01,  -2.66434789e-01,  -2.83646792e-01,
                         -3.05008054e-01,  -3.24778557e-01,  -3.18459094e-01,
                         -2.93166995e-01,  -2.87725717e-01,  -3.03448915e-01,
                         -3.09053987e-01,  -2.95881748e-01,  -2.74629623e-01,
                         -2.37464830e-01,  -1.76230475e-01,  -1.25465572e-01,
                         -1.20605394e-01,  -1.38724804e-01,  -1.74930871e-01,
                         -2.20500737e-01,  -1.91133603e-01,  -1.14663355e-01,
                         -5.33590987e-02,   2.14278828e-02,   3.68892476e-02,
                         -2.02020677e-03,   3.56162265e-02,   1.34935036e-01,
                          2.25735396e-01,   2.92628735e-01,   3.49791765e-01,
                          3.99569899e-01,   4.60043937e-01,   5.56333721e-01,
                          6.09473646e-01,   5.95031798e-01,   5.62055230e-01,
                          5.01078844e-01,   4.36495543e-01,   3.83211225e-01,
                          3.36593568e-01,   3.23379248e-01,   3.31587136e-01,
                          3.37884486e-01,   3.39966118e-01,   3.50337654e-01,
                          3.86853099e-01,   4.49131012e-01,   5.20525694e-01,
                          5.74060142e-01,   6.04308069e-01,   6.28162146e-01,
                          6.46751344e-01,   6.47458792e-01,   6.41383588e-01,
                          6.38459921e-01,   6.13287210e-01,   5.71598530e-01,
                          5.38179219e-01,   5.15554547e-01,   5.01584232e-01,
                          4.76006687e-01,   4.50300306e-01,   4.46499676e-01,
                          4.50305790e-01,   4.62852210e-01,   4.69449133e-01,
                          4.56523538e-01,   4.29845572e-01,   3.87083948e-01,
                          3.66684467e-01,   3.84818286e-01,   4.04653609e-01,
                          4.12392467e-01,   4.15556937e-01,   4.23060328e-01,
                          4.22291994e-01,   4.09519970e-01,   4.09010470e-01,
                          4.22141403e-01,   4.41647083e-01,   4.71200734e-01,
                          5.12791872e-01,   5.48378766e-01,   5.57465136e-01,
                          5.50781429e-01,   5.39191842e-01,   5.28011858e-01,
                          5.17695785e-01,   5.10511816e-01,   5.14057457e-01,
                          5.07105887e-01,   4.95207012e-01,   4.89060581e-01,
                          4.65501100e-01,   4.46627796e-01,   4.50229824e-01,
                          4.78815079e-01,   5.31870306e-01,   5.72803378e-01,
                          6.10243499e-01,   6.47842824e-01,   6.59168601e-01,
                          6.51873529e-01,   6.29401088e-01,   6.11826241e-01,
                          5.99551737e-01,   5.71722567e-01,   5.41325033e-01,
                          5.02162278e-01,   4.63983119e-01,   4.54131931e-01,
                          4.62104410e-01,   4.59710658e-01,   4.35908467e-01,
                          4.15970802e-01,   4.12373781e-01,   4.19672459e-01,
                          4.34184164e-01,   4.50326324e-01,   4.67799962e-01,
                          4.72643673e-01,   4.69954044e-01,   4.76592511e-01,
                          4.84013140e-01,   4.84497041e-01,   4.74776149e-01,
                          4.56172675e-01,   4.33528572e-01,   4.14519370e-01,
                          4.04990673e-01,   4.06911165e-01,   4.22422826e-01,
                          4.36752647e-01,   4.43837762e-01,   4.57743406e-01,
                          4.76147920e-01,   4.81215119e-01,   4.68318194e-01,
                          4.50209260e-01,   4.41933244e-01,   4.42141145e-01,
                          4.31527883e-01,   4.08962846e-01,   3.85392219e-01,
                          3.70108187e-01,   3.73529404e-01,   3.85094196e-01,
                          3.91213685e-01,   3.87231350e-01,   3.78113598e-01,
                          3.68178368e-01,   3.57625067e-01,   3.53662252e-01,
                          3.45813602e-01,   3.32570940e-01,   3.18911642e-01,
                          3.07238877e-01,   3.14205617e-01,   3.30776870e-01,
                          3.35091561e-01,   3.14836949e-01,   2.92422771e-01,
                          3.01104128e-01,   3.27412456e-01,   3.47595155e-01,
                          3.53671074e-01,   3.57497811e-01,   3.51149529e-01,
                          3.26387852e-01,   3.07091862e-01,   2.90712476e-01,
                          2.75775373e-01,   2.64774561e-01,   2.57959723e-01,
                          2.48677224e-01,   2.25095734e-01,   2.11406186e-01,
                          2.06248924e-01,   2.01815486e-01,   1.97132975e-01,
                          1.92067593e-01,   2.09301636e-01,   2.30208963e-01,
                          2.34295949e-01,   2.11409658e-01,   1.84051916e-01,
                          1.91226497e-01,   2.01583281e-01,   2.12933451e-01,
                          2.39580676e-01,   2.79775530e-01,   3.24147433e-01,
                          3.31942439e-01,   3.07635725e-01,   2.51318395e-01,
                          1.79174975e-01,   1.30317077e-01,   9.03527960e-02,
                          6.99244663e-02,   6.68687373e-02,   6.48345053e-02,
                          6.82241619e-02,   6.63641393e-02,   7.10519329e-02,
                          6.90701604e-02,   6.60191774e-02,   7.59194270e-02,
                          4.35367487e-02,   1.36638703e-02,   3.10871173e-02,
                          2.35452186e-02,   6.21629180e-03,   1.11076925e-02,
                          2.15484928e-02,   4.38596830e-02,   4.04893458e-02,
                         -1.42957466e-02,  -6.32369816e-02,  -5.00738285e-02,
                         -1.76127236e-02,  -3.33152078e-02,  -8.58269110e-02,
                         -1.60787463e-01,  -2.31632173e-01,  -2.27662146e-01,
                         -1.59575611e-01,  -1.46531060e-01,  -2.02265501e-01,
                         -2.38616571e-01,  -2.66853720e-01,  -2.68640637e-01,
                         -2.40713120e-01,  -2.66537368e-01,  -2.96848297e-01,
                         -2.80248821e-01,  -2.55802512e-01,  -2.48544604e-01,
                         -2.73351371e-01,  -3.27722281e-01,  -3.97295177e-01,
                         -4.51845050e-01,  -4.99589980e-01,  -5.38144350e-01,
                         -5.35948873e-01,  -5.14399469e-01,  -4.84468997e-01,
                         -4.72335309e-01,  -4.87072676e-01,  -4.95087236e-01,
                         -5.02371132e-01,  -5.09524286e-01,  -5.11873841e-01,
                         -5.02479792e-01,  -4.77582306e-01,  -4.48526055e-01,
                         -4.26720619e-01,  -4.30660307e-01,  -4.51783508e-01,
                         -4.75171804e-01,  -5.04431427e-01,  -5.38954198e-01,
                         -5.53619206e-01,  -5.50614595e-01,  -5.54872870e-01,
                         -5.52310765e-01,  -5.49568474e-01,  -5.33927143e-01,
                         -4.89469260e-01,  -4.45344687e-01,  -4.07542437e-01,
                         -3.86261344e-01,  -3.80404264e-01,  -3.79514813e-01,
                         -3.69013131e-01,  -3.43060464e-01,  -3.31047237e-01,
                         -3.34854662e-01,  -3.58279407e-01,  -3.93937647e-01,
                         -4.28639114e-01,  -4.70566779e-01,  -5.01695395e-01,
                         -5.10518491e-01,  -4.93334025e-01,  -4.60037887e-01,
                         -4.24222797e-01,  -3.94563437e-01,  -3.81555557e-01,
                         -3.80476445e-01,  -3.95582080e-01,  -4.06293124e-01,
                         -4.01686430e-01,  -3.87980133e-01,  -3.68783832e-01,
                         -3.64938796e-01,  -3.53459895e-01,  -3.36136222e-01,
                         -3.22390944e-01,  -2.99708426e-01,  -3.02855611e-01,
                         -3.31606209e-01,  -3.72275054e-01,  -4.19091463e-01,
                         -4.52150971e-01,  -4.68597054e-01,  -4.65868026e-01,
                         -4.51048583e-01,  -4.28690702e-01,  -4.00315702e-01,
                         -3.77269596e-01,  -3.63763988e-01,  -3.40525210e-01,
                         -3.16079050e-01,  -3.03537756e-01,  -2.80450225e-01,
                         -2.62378484e-01,  -2.39190832e-01,  -2.22864926e-01,
                         -2.40038440e-01,  -2.50064582e-01,  -2.53742129e-01,
                         -2.52218127e-01,  -2.63457179e-01,  -2.96786189e-01,
                         -3.25629383e-01,  -3.62287641e-01,  -3.99797112e-01,
                         -4.36476707e-01,  -4.64294732e-01,  -4.83408898e-01,
                         -5.05343497e-01,  -5.06468654e-01,  -4.87585157e-01,
                         -4.64816988e-01,  -4.47381198e-01,  -4.18627262e-01,
                         -3.71683121e-01,  -3.34325641e-01,  -3.08778584e-01,
                         -2.75667191e-01,  -2.37141281e-01,  -2.14544326e-01,
                         -2.00111657e-01,  -1.66967392e-01,  -1.00068629e-01,
                         -4.42139730e-02,  -1.87905878e-02,   5.04161343e-02,
                          1.00784704e-01,   9.70471650e-02,   1.24682680e-01,
                          9.95302051e-02,   3.46436389e-02,  -7.95910507e-03,
                         -8.21434781e-02,  -1.49314836e-01,  -2.37089530e-01,
                         -3.15773457e-01,  -3.29025924e-01,  -3.05793911e-01,
                         -2.21425638e-01,  -1.56083196e-01,  -1.26285896e-01,
                         -9.51510146e-02,  -8.74319598e-02,  -8.61994773e-02,
                         -1.12353817e-01,  -1.25481963e-01,  -8.53621140e-02,
                         -4.19798717e-02,   1.44534768e-03,   7.67954066e-02,
                          1.42909348e-01,   1.94539830e-01,   2.84714848e-01,
                          3.47793877e-01,   3.65070045e-01,   3.81829113e-01,
                          4.04676795e-01,   4.31638807e-01,   4.26490366e-01,
                          4.36278164e-01,   4.73771155e-01,   4.82698649e-01,
                          4.83347237e-01,   4.74897295e-01,   4.61174637e-01,
                          4.53634828e-01,   4.43315953e-01,   4.51258928e-01,
                          4.60544258e-01,   4.40862536e-01,   3.98485333e-01,
                          3.46914440e-01,   3.09692264e-01,   2.95849234e-01,
                          2.88608402e-01,   2.84494549e-01,   2.92566061e-01,
                          3.05212677e-01,   3.03519875e-01,   2.91312456e-01,
                          2.92660713e-01,   3.01128328e-01,   3.05773616e-01,
                          3.10151756e-01,   3.02788407e-01,   2.82572657e-01,
                          2.53770649e-01,   2.28058755e-01,   2.10436225e-01,
                          1.89256042e-01,   1.66250527e-01,   1.49584815e-01,
                          1.49046540e-01,   1.55388311e-01,   1.61891952e-01,
                          1.67807683e-01,   1.63606510e-01,   1.58338442e-01,
                          1.58155933e-01,   1.63837507e-01,   1.80069134e-01,
                          1.99353799e-01,   2.07880169e-01,   1.98382393e-01,
                          1.69527635e-01,   1.39688775e-01,   1.33239061e-01,
                          1.50943130e-01,   1.72871232e-01,   1.82460487e-01,
                          1.94785416e-01,   2.26420939e-01,   2.67746359e-01,
                          2.88538456e-01,   2.72088140e-01,   2.37948373e-01,
                          2.05813661e-01,   1.70248896e-01,   1.26510710e-01,
                          8.98033753e-02,   6.63409308e-02,   5.04136086e-02,
                          3.61870043e-02,   3.47259790e-02,   3.84822637e-02,
                          4.25908044e-02,   6.79667667e-02,   9.52074453e-02,
                          1.21855475e-01,   1.44201100e-01,   1.57717466e-01,
                          1.70300841e-01,   1.60890400e-01,   1.36842683e-01,
                          1.13951936e-01,   1.07059859e-01,   1.05441272e-01,
                          8.69982019e-02,   7.02949166e-02,   6.65724277e-02,
                          6.51414320e-02,   6.02029338e-02,   5.35017513e-02,
                          5.58374785e-02,   7.75859430e-02,   9.50297713e-02,
                          1.08938962e-01,   1.19023234e-01,   1.19475171e-01,
                          1.27246931e-01,   1.25869289e-01,   1.07467018e-01,
                          6.53669536e-02,   2.68117692e-02,   8.44110921e-03,
                         -4.23103193e-04,   8.14423617e-03,   6.63638674e-03,
                         -4.47601778e-03,  -2.01046411e-02,  -2.14405209e-02,
                          3.06042726e-03,   2.83983182e-02,   5.47817945e-02,
                          7.35618174e-02,   9.26507339e-02,   9.77853760e-02,
                          9.30838436e-02,   1.06751889e-01,   1.12581238e-01,
                          1.19305447e-01,   1.32779136e-01,   1.39808938e-01,
                          1.40036866e-01,   1.26107678e-01,   1.08155452e-01,
                          7.78102428e-02,   4.31652330e-02,   1.92124303e-02,
                         -5.71732968e-03,  -2.55984794e-02,  -4.25238609e-02,
                         -5.30816428e-02,  -6.69277385e-02,  -8.11945647e-02,
                         -9.25268605e-02,  -1.18898906e-01,  -1.45765930e-01,
                         -1.68094188e-01,  -1.70424953e-01,  -1.91343606e-01,
                         -1.93424195e-01,  -1.27358645e-01,  -9.40283388e-02,
                         -5.45204096e-02,  -2.09139865e-02,  -3.89732122e-02,
                         -3.86060178e-02,  -5.41420132e-02,  -8.76485780e-02,
                         -1.02016248e-01,  -9.24513713e-02,  -8.95611420e-02,
                         -1.15307942e-01,  -1.52245134e-01,  -2.00120687e-01,
                         -1.98446646e-01,  -1.49835467e-01,  -1.45374849e-01,
                         -1.74788773e-01,  -2.01462090e-01,  -2.62883425e-01,
                         -3.52418900e-01,  -4.15771961e-01,  -4.70006883e-01,
                         -5.12914896e-01,  -5.11958241e-01,  -5.25089383e-01,
                         -5.71037114e-01,  -5.97605228e-01,  -6.06997967e-01,
                         -5.88709772e-01,  -5.41312873e-01,  -5.39149284e-01,
                         -5.86988270e-01,  -5.81377923e-01,  -5.60374677e-01,
                         -6.01315081e-01,  -6.05013311e-01,  -5.64226270e-01,
                         -5.36171734e-01,  -5.27613223e-01,  -5.48339784e-01,
                         -5.73420703e-01,  -6.15808785e-01,  -6.59549177e-01,
                         -6.67246461e-01,  -6.51005805e-01,  -6.26337171e-01,
                         -6.00509048e-01,  -5.76436400e-01,  -5.49443424e-01,
                         -5.07477462e-01,  -4.76512671e-01,  -4.53126460e-01,
                         -4.30762559e-01,  -4.34970558e-01,  -4.54495966e-01,
                         -4.86305505e-01,  -5.09772539e-01,  -5.23184955e-01,
                         -5.38480937e-01,  -5.45262098e-01,  -5.68508565e-01,
                         -5.94220459e-01,  -6.10760212e-01,  -6.29093587e-01,
                         -6.49979353e-01,  -6.79191172e-01,  -6.75284386e-01,
                         -6.40811265e-01,  -6.10910296e-01,  -5.96696854e-01,
                         -5.86867750e-01,  -5.58385313e-01,  -5.36544502e-01,
                         -5.25247395e-01,  -5.22702157e-01,  -5.17080367e-01,
                         -5.02047598e-01,  -4.90810245e-01,  -4.88259941e-01,
                         -5.07628024e-01,  -5.15767157e-01,  -5.14436305e-01,
                         -5.10073006e-01,  -5.09117484e-01,  -4.78511691e-01,
                         -4.17139709e-01,  -4.37250108e-01,  -4.60730910e-01,
                         -4.46585178e-01,  -4.44523692e-01,  -4.29886281e-01,
                         -4.34714973e-01,  -4.40403402e-01,  -4.46363539e-01,
                         -4.57855791e-01,  -4.64743674e-01,  -4.93887007e-01,
                         -5.35348296e-01,  -5.71446180e-01,  -5.85301399e-01,
                         -5.77589929e-01,  -5.60612023e-01,  -5.48663616e-01,
                         -5.44197381e-01,  -5.50448418e-01,  -5.65428257e-01,
                         -5.66296995e-01,  -5.57180882e-01,  -5.28816640e-01,
                         -4.86278653e-01,  -4.26911265e-01,  -3.24952513e-01,
                         -2.62640953e-01,  -2.64000803e-01,  -2.64900595e-01,
                         -2.82516807e-01,  -2.89882690e-01,  -2.92983890e-01,
                         -3.20810467e-01,  -3.40911806e-01,  -3.79339218e-01,
                         -4.17069793e-01,  -4.34118003e-01,  -4.53500897e-01,
                         -4.60800081e-01,  -4.41749662e-01,  -4.26193446e-01,
                         -4.41056728e-01,  -4.35095310e-01,  -4.11317408e-01,
                         -3.82426202e-01,  -3.08028370e-01,  -2.50881761e-01,
                         -2.50567198e-01,  -2.39436612e-01,  -2.24309668e-01,
                         -2.08193094e-01,  -1.78836972e-01,  -1.75225720e-01,
                         -1.17231295e-01,  -1.03044305e-02,   3.51215154e-02,
                          5.56432232e-02,   7.80883059e-02,   1.00198343e-01,
                          1.35233447e-01,   1.28107831e-01,   8.51166919e-02,
                          7.83689916e-02,   7.75614604e-02,   7.74387643e-02,
                          1.02162503e-01,   1.39271528e-01,   1.89979598e-01,
                          2.47319594e-01,   3.37884039e-01,   4.09642905e-01,
                          4.26551610e-01,   4.40691859e-01,   4.49751496e-01,
                          4.51296479e-01,   4.52789575e-01,   4.56525266e-01,
                          4.53664988e-01,   4.51612175e-01,   4.47214127e-01,
                          4.41485256e-01,   4.46000278e-01,   4.45546210e-01,
                          4.48722839e-01,   4.44965243e-01,   4.34984177e-01,
                          4.24953043e-01,   4.13283437e-01,   4.07725811e-01,
                          3.99708778e-01,   3.82365853e-01,   3.66038233e-01,
                          3.70536864e-01,   3.79665285e-01,   3.94185334e-01,
                          4.10587639e-01,   4.18725014e-01,   4.28091019e-01,
                          4.40449446e-01,   4.67573136e-01,   4.88984942e-01,
                          4.99711037e-01,   5.13485134e-01,   5.26736021e-01,
                          5.35982966e-01,   5.45553625e-01,   5.55916309e-01,
                          5.66394925e-01,   5.97460508e-01,   6.39085472e-01,
                          6.71762884e-01,   6.74996555e-01,   6.44584596e-01,
                          6.14233673e-01,   6.07505202e-01,   6.19342327e-01,
                          6.26863718e-01,   6.33666635e-01,   6.43704653e-01,
                          6.53135955e-01,   6.66417241e-01,   6.89961016e-01,
                          7.11321831e-01,   7.10149169e-01,   6.99948728e-01,
                          6.84309125e-01,   6.64896667e-01,   6.44202888e-01,
                          6.31773293e-01,   6.42088056e-01,   6.48830354e-01,
                          6.42098010e-01,   6.24074399e-01,   5.93281507e-01,
                          5.67443192e-01,   5.49798667e-01,   5.46752870e-01,
                          5.67431569e-01,   5.96452415e-01,   6.27382040e-01,
                          6.62699282e-01,   6.85445905e-01,   6.96727216e-01,
                          7.09798515e-01,   7.23446786e-01,   7.36599684e-01,
                          7.19668627e-01,   6.77369654e-01,   6.35437429e-01,
                          6.01785362e-01,   5.96065283e-01,   5.86029530e-01,
                          5.82381427e-01,   6.01505518e-01,   6.11077428e-01,
                          6.10462785e-01,   6.02727294e-01,   6.08017743e-01,
                          6.10937595e-01,   5.95500290e-01,   5.63476503e-01,
                          5.28339624e-01,   5.08832991e-01,   4.95164633e-01,
                          4.88609284e-01,   4.84523654e-01,   4.99319822e-01,
                          5.17373145e-01,   5.33813953e-01,   5.52778959e-01,
                          5.64475119e-01,   5.72910666e-01,   5.53343415e-01,
                          5.23305297e-01,   4.81557995e-01,   4.36117738e-01,
                          3.96701306e-01,   3.83969218e-01,   3.66919219e-01,
                          3.18313897e-01,   3.38793427e-01,   3.53684425e-01,
                          3.52354288e-01,   3.96207482e-01,   4.10251945e-01,
                          4.10694927e-01,   4.40756202e-01,   4.50097948e-01,
                          3.69425267e-01,   2.62411892e-01,   1.86687887e-01,
                          1.88167214e-01,   2.29180694e-01,   2.18295619e-01,
                          1.87593371e-01,   1.33237690e-01,   9.50149372e-02,
                          5.78218102e-02,   2.55458765e-02,   3.93896457e-03,
                         -7.17781782e-02,  -1.19683690e-01,  -1.31135851e-01,
                         -1.43743679e-01,  -1.37846872e-01,  -1.07316457e-01,
                         -7.46700242e-02,  -3.89247723e-02,  -3.03819291e-02,
                         -8.96290541e-02,  -1.28468707e-01,  -1.48643509e-01,
                         -1.78567380e-01,  -2.19342574e-01,  -2.62892812e-01,
                         -2.73821115e-01,  -2.91615307e-01,  -3.10661823e-01,
                         -3.25299472e-01,  -3.35665286e-01,  -3.04239780e-01,
                         -2.43903637e-01,  -2.40180656e-01,  -2.92356282e-01,
                         -3.12770396e-01,  -3.19805682e-01,  -3.34351122e-01,
                         -3.55459511e-01,  -3.69143724e-01,  -3.67522210e-01,
                         -3.79652321e-01,  -3.90891433e-01,  -3.97154719e-01,
                         -3.91262949e-01,  -3.74082267e-01,  -3.62869084e-01,
                         -3.59033167e-01,  -3.79332900e-01,  -4.06425625e-01,
                         -4.11229938e-01,  -4.09253120e-01,  -4.11158502e-01,
                         -4.04596925e-01,  -3.97950113e-01,  -4.03234959e-01,
                         -4.20426190e-01,  -4.42060202e-01,  -4.52071756e-01,
                         -4.75990236e-01,  -5.15273929e-01,  -5.40335417e-01,
                         -5.60378373e-01,  -5.68954349e-01,  -5.70186436e-01,
                         -5.72563648e-01,  -5.69221616e-01,  -5.65815866e-01,
                         -5.61043084e-01,  -5.53266525e-01,  -5.41529834e-01,
                         -5.33541024e-01,  -5.30345023e-01,  -5.28890193e-01,
                         -5.22060454e-01,  -5.12887716e-01,  -5.14706314e-01,
                         -5.10018647e-01,  -5.01156151e-01,  -5.01373351e-01,
                         -5.13665795e-01,  -5.30324996e-01,  -5.39084733e-01,
                         -5.43532372e-01,  -5.51425397e-01,  -5.51781893e-01,
                         -5.37651598e-01,  -5.35793841e-01,  -5.40227056e-01,
                         -5.53937376e-01,  -5.74636638e-01,  -5.93537450e-01,
                         -6.10893607e-01,  -6.08373761e-01,  -6.12310827e-01,
                         -6.15620553e-01,  -6.07473671e-01,  -6.09061658e-01,
                         -6.15940690e-01,  -6.19827688e-01,  -6.22335613e-01,
                         -6.21831536e-01,  -6.24069214e-01,  -6.30747557e-01,
                         -6.24275208e-01,  -6.31165266e-01,  -6.37207329e-01,
                         -6.37837827e-01,  -6.44273758e-01,  -6.29191101e-01,
                         -6.25580251e-01,  -6.27854764e-01,  -6.33478642e-01,
                         -6.40671313e-01,  -6.36276960e-01,  -6.39119506e-01,
                         -6.46207809e-01,  -6.59486651e-01,  -6.65791810e-01,
                         -6.57385290e-01,  -6.31249487e-01,  -6.12443566e-01,
                         -5.99637568e-01,  -5.98752618e-01,  -6.17276728e-01,
                         -6.16536796e-01,  -6.22305214e-01,  -6.31192625e-01,
                         -6.39144242e-01,  -6.39310062e-01,  -6.33159459e-01,
                         -6.32004082e-01,  -6.27692580e-01,  -6.30752087e-01,
                         -6.17792606e-01,  -6.19817555e-01,  -6.38588965e-01,
                         -6.54007852e-01,  -6.74759209e-01,  -6.84083998e-01,
                         -6.85327172e-01,  -6.85371280e-01,  -6.85584068e-01,
                         -6.79165244e-01,  -6.78367734e-01,  -6.65676355e-01,
                         -6.39265656e-01,  -6.19542956e-01,  -6.00496769e-01,
                         -5.91714621e-01,  -5.80015838e-01,  -5.85000157e-01,
                         -6.10298932e-01,  -6.35469615e-01,  -6.64269686e-01,
                         -6.83137655e-01,  -6.89502537e-01,  -6.83941782e-01,
                         -6.63270891e-01,  -6.16882801e-01,  -5.74734747e-01,
                         -5.51701725e-01,  -5.25163293e-01,  -4.94871885e-01,
                         -4.63501066e-01,  -4.43150163e-01,  -4.44040149e-01,
                         -4.66498375e-01,  -4.88127828e-01,  -4.99450296e-01,
                         -5.03643870e-01,  -5.11045933e-01,  -5.11652172e-01,
                         -4.95348245e-01,  -4.79542762e-01,  -4.63192284e-01,
                         -4.46539640e-01,  -4.23068315e-01,  -4.08084720e-01,
                         -4.05484617e-01,  -4.01062191e-01,  -3.88515681e-01,
                         -3.56758296e-01,  -3.13323408e-01,  -2.80623615e-01,
                         -2.69089311e-01,  -2.67749816e-01,  -2.80469000e-01,
                         -3.00964326e-01,  -3.15664589e-01,  -3.19611907e-01,
                         -3.14084113e-01,  -3.15319300e-01,  -3.21982920e-01,
                         -3.22679132e-01,  -3.09658229e-01,  -2.93990999e-01,
                         -2.73952007e-01,  -2.54492909e-01,  -2.63400137e-01,
                         -2.39209175e-01,  -1.75015450e-01,  -1.44577533e-01,
                         -1.42105356e-01,  -1.61991343e-01,  -2.03898564e-01,
                         -2.35379845e-01,  -2.42458448e-01,  -2.40800291e-01,
                         -2.33497337e-01,  -2.10530072e-01,  -1.59858271e-01,
                         -8.79413486e-02,  -1.11701423e-02,   6.21493980e-02,
                          1.24232344e-01,   1.88792601e-01,   2.46962413e-01,
                          3.08659047e-01,   4.10781711e-01,   5.02422452e-01,
                          5.50109684e-01,   5.88302076e-01,   6.06496692e-01,
                          5.87107718e-01,   5.60895681e-01,   5.79344273e-01,
                          6.02241993e-01,   6.00683391e-01,   5.99189281e-01,
                          5.90047061e-01,   5.90124905e-01,   5.91410577e-01,
                          5.92866600e-01,   5.93698859e-01,   5.94369233e-01,
                          5.92337430e-01,   5.90533316e-01,   5.91090143e-01,
                          5.83229065e-01,   5.92032313e-01,   5.92526376e-01,
                          5.87948620e-01,   5.87293208e-01,   5.81689537e-01,
                          5.80109000e-01,   5.79876244e-01,   5.84239542e-01,
                          5.75858533e-01,   5.76919973e-01,   5.78530550e-01,
                          5.79358518e-01,   5.90763748e-01,   5.85058630e-01,
                          5.90590954e-01,   5.93892157e-01,   5.97052813e-01,
                          6.00385547e-01,   5.94476759e-01,   5.95474064e-01,
                          5.90169072e-01,   5.90674162e-01,   5.87213635e-01,
                          5.89152455e-01,   5.86795866e-01,   5.86038709e-01,
                          5.91820359e-01,   5.91250300e-01,   5.89761674e-01,
                          5.76463699e-01,   5.82368195e-01,   5.83887041e-01,
                          5.78594804e-01,   5.76561570e-01,   5.72304666e-01,
                          5.74743569e-01,   5.77135742e-01,   5.83603621e-01,
                          5.81733346e-01,   5.84662080e-01,   5.85403502e-01,
                          5.81970692e-01,   5.80334008e-01,   5.73614776e-01,
                          5.76817274e-01,   5.77856481e-01,   5.80196440e-01,
                          5.82965910e-01,   5.78461766e-01,   5.82867026e-01,
                          5.84162235e-01,   5.84944129e-01,   5.85955739e-01,
                          5.82504630e-01,   5.84196091e-01,   5.87623000e-01,
                          5.88645339e-01,   5.89314342e-01,   5.89610875e-01,
                          5.86031556e-01,   5.86981773e-01,   5.88464141e-01,
                          5.90849519e-01,   5.90559304e-01,   5.88706791e-01,
                          5.90437293e-01,   5.90834975e-01,   5.92276633e-01,
                          5.94307065e-01,   5.93378782e-01,   5.91244280e-01,
                          5.94246149e-01,   5.94273925e-01,   5.93847394e-01,
                          5.96358597e-01,   5.96970081e-01,   5.94808817e-01,
                          5.95334888e-01,   5.89449346e-01,   5.88317990e-01,
                          5.93730628e-01,   5.96803606e-01,   6.00799680e-01,
                          5.95613003e-01,   5.99821448e-01,   5.98504186e-01,
                          5.99280477e-01,   5.98239481e-01,   5.67731738e-01,
                          5.39303005e-01,   5.26345670e-01,   5.20370841e-01,
                          5.16139209e-01,   5.13945878e-01,   5.24277329e-01,
                          5.45241952e-01,   5.67181349e-01,   5.90995491e-01,
                          5.97310543e-01,   5.93175709e-01,   5.87267339e-01,
                          5.77052534e-01,   5.84664941e-01,   5.76798558e-01,
                          5.35699308e-01,   4.94283587e-01,   4.51616824e-01,
                          4.20998096e-01,   4.05153841e-01,   3.98813277e-01,
                          4.08894420e-01,   4.26567972e-01,   4.58405197e-01,
                          4.96249408e-01,   5.26262999e-01,   5.36725402e-01,
                          5.29620945e-01,   5.11173785e-01,   4.87994462e-01,
                          4.57215339e-01,   4.31977183e-01,   4.27211314e-01,
                          4.31774348e-01,   4.51290876e-01,   4.69898641e-01,
                          4.77201790e-01,   4.71754193e-01,   4.59727287e-01,
                          4.51951236e-01,   4.52126414e-01,   4.37660515e-01,
                          4.31100726e-01,   4.41818416e-01,   4.28587854e-01,
                          4.21708941e-01,   3.88787657e-01,   3.15120637e-01,
                          2.91808486e-01,   3.44345748e-01,   3.98209810e-01,
                          4.01397318e-01,   3.80182832e-01,   3.51577878e-01,
                          3.24753493e-01,   3.19199443e-01,   3.01990926e-01,
                          2.88278043e-01,   2.95186371e-01,   2.71472812e-01,
                          2.30294093e-01,   1.45135581e-01,   2.67602485e-02,
                         -3.89638320e-02,  -1.17963478e-01,  -2.12814227e-01,
                         -2.31039807e-01,  -2.13557154e-01,  -1.74868241e-01,
                         -1.60386696e-01,  -1.83870777e-01,  -1.71656683e-01,
                         -1.58888265e-01,  -1.48955643e-01,  -1.54957101e-01,
                         -2.05334917e-01,  -2.54324585e-01,  -3.18514198e-01,
                         -3.95141274e-01,  -4.28274751e-01,  -4.45792764e-01,
                         -4.59180415e-01,  -4.65378106e-01,  -4.81300652e-01,
                         -5.06291926e-01,  -5.36999941e-01,  -5.65446317e-01,
                         -5.77822447e-01,  -5.48907638e-01,  -5.03959775e-01,
                         -4.70020503e-01,  -4.42838132e-01,  -4.17967588e-01,
                         -4.12001759e-01,  -4.24277931e-01,  -4.55284655e-01,
                         -4.90079701e-01,  -5.09261489e-01,  -5.29837489e-01,
                         -5.43031693e-01,  -5.66897094e-01,  -5.89607775e-01,
                         -5.92925251e-01,  -5.79942703e-01,  -5.58930576e-01,
                         -5.48294902e-01,  -5.31362116e-01,  -5.00488102e-01,
                         -4.61631417e-01,  -4.30166662e-01,  -4.10139352e-01,
                         -3.92009199e-01,  -3.77561063e-01,  -3.70816022e-01,
                         -3.85419816e-01,  -3.97580981e-01,  -3.92661601e-01,
                         -3.95737797e-01,  -4.04037893e-01,  -4.13429081e-01,
                         -4.15495217e-01,  -4.29738671e-01,  -4.53583568e-01,
                         -4.75200921e-01,  -4.92485046e-01,  -5.18021405e-01,
                         -5.64506054e-01,  -5.85988760e-01,  -5.85873723e-01,
                         -5.82840621e-01,  -5.80725431e-01,  -5.63859582e-01,
                         -5.40914893e-01,  -5.20146608e-01,  -5.00443280e-01,
                         -4.94013131e-01,  -4.92234260e-01,  -5.02133489e-01,
                         -5.02854288e-01,  -4.98414278e-01,  -4.98673171e-01,
                         -4.93600845e-01,  -4.90655959e-01,  -4.85570580e-01,
                         -4.75022584e-01,  -4.66511518e-01,  -4.58147973e-01,
                         -4.52526867e-01,  -4.52566564e-01,  -4.55054730e-01,
                         -4.50833857e-01,  -4.49652225e-01,  -4.68466103e-01,
                         -4.96082366e-01,  -5.06646454e-01,  -4.86832678e-01,
                         -4.70479280e-01,  -4.69905168e-01,  -4.80128676e-01,
                         -4.95194852e-01,  -5.20533144e-01,  -5.49095929e-01,
                         -5.60435891e-01,  -5.60012341e-01,  -5.51327527e-01,
                         -5.37705362e-01,  -5.28781116e-01,  -5.40051997e-01,
                         -5.57416499e-01,  -5.75325906e-01,  -5.90390682e-01,
                         -5.94485819e-01,  -5.85805774e-01,  -5.66817343e-01,
                         -5.51973224e-01,  -5.51694632e-01,  -5.60817838e-01,
                         -5.81594288e-01,  -5.97427070e-01,  -5.92206419e-01,
                         -5.85017979e-01,  -5.65173984e-01,  -5.44265509e-01,
                         -5.27537107e-01,  -5.08753538e-01,  -4.96748090e-01,
                         -4.73790258e-01,  -4.43415642e-01,  -4.40693468e-01,
                         -4.02369440e-01,  -3.10855418e-01,  -2.41532400e-01,
                         -1.62893936e-01,  -1.22980922e-01,  -1.74773052e-01,
                         -2.13684216e-01,  -2.13704899e-01,  -2.22518310e-01,
                         -2.20811650e-01,  -2.20445752e-01,  -2.13554874e-01,
                         -1.71689346e-01,  -1.30437642e-01,  -1.28002122e-01,
                         -1.53012231e-01,  -1.45266503e-01,  -1.25201911e-01,
                         -1.35472208e-01,  -1.40383050e-01,  -1.55131742e-01,
                         -1.86125621e-01,  -1.41377702e-01,  -6.83264211e-02,
                         -4.89879213e-02,  -2.46867649e-02,   1.56133948e-02,
                          3.98138389e-02,   8.10031146e-02,   1.50265187e-01,
                          1.98942944e-01,   2.12946251e-01,   2.12515011e-01,
                          2.12080479e-01,   2.09158912e-01,   2.20093757e-01,
                          2.44906053e-01,   2.75552332e-01,   2.96479702e-01,
                          2.99386799e-01,   3.00198257e-01,   3.06605637e-01,
                          3.19247305e-01,   3.25317591e-01,   3.29842180e-01,
                          3.37242007e-01,   3.42552751e-01,   3.36421251e-01,
                          3.39650005e-01,   3.49996835e-01,   3.52142870e-01,
                          3.44867647e-01,   3.29864651e-01,   3.12473506e-01,
                          2.80425847e-01,   2.45340630e-01,   2.16087759e-01,
                          1.95290685e-01,   1.80795521e-01,   1.61370948e-01,
                          1.36515737e-01,   1.27912894e-01,   1.33922085e-01,
                          1.45173088e-01,   1.57472894e-01,   1.62635148e-01,
                          1.58612564e-01,   1.52788267e-01,   1.54149264e-01,
                          1.58983991e-01,   1.65283352e-01,   1.71786562e-01,
                          1.89070925e-01,   2.03428999e-01,   2.10549086e-01,
                          2.15364307e-01,   2.16092825e-01,   2.20374107e-01,
                          2.36639962e-01,   2.52415746e-01,   2.63380021e-01,
                          2.61558950e-01,   2.37525225e-01,   2.15646476e-01,
                          1.92082211e-01,   1.76663443e-01,   1.73943073e-01,
                          1.78314805e-01,   1.85945854e-01,   1.97885975e-01,
                          2.19239980e-01,   2.36443803e-01,   2.40838706e-01,
                          2.33060524e-01,   2.10470989e-01,   1.92581296e-01,
                          1.87759936e-01,   1.82264626e-01,   1.92947358e-01,
                          2.12429717e-01,   2.50810951e-01,   2.81283319e-01,
                          2.64219820e-01,   2.28090703e-01,   1.84671849e-01,
                          1.43189803e-01,   1.22890793e-01,   1.12944536e-01,
                          1.17895924e-01,   1.33787602e-01,   1.43044978e-01,
                          1.64852425e-01,   1.83482423e-01,   1.91014469e-01,
                          1.86392620e-01,   1.80801302e-01,   1.77163720e-01,
                          1.68207884e-01,   1.78427562e-01,   1.97700307e-01,
                          2.08064198e-01,   2.02170581e-01,   1.79243311e-01,
                          1.77975833e-01,   1.76103204e-01,   1.19363762e-01,
                          8.06685984e-02,   1.03666261e-01,   1.48007840e-01,
                          1.44642845e-01,   9.69801843e-02,   9.68470573e-02,
                          1.33600563e-01,   1.47552311e-01,   1.14879347e-01,
                          2.83205844e-02,  -2.58744415e-02,  -1.91922933e-02,
                         -3.83053347e-02,  -2.03008354e-02,   1.91397667e-02,
                         -2.71675605e-02,  -7.35865310e-02,  -9.79443416e-02,
                         -1.49098828e-01,  -1.44721076e-01,  -1.12313688e-01,
                         -7.72812888e-02,  -1.24559961e-02,  -5.23739420e-02,
                         -1.62315711e-01,  -2.21244618e-01,  -2.53520787e-01,
                         -2.72020549e-01,  -3.00330162e-01,  -3.23375911e-01,
                         -3.15466851e-01,  -3.57705116e-01,  -4.04341191e-01,
                         -3.98739100e-01,  -3.97871614e-01,  -3.84908020e-01,
                         -3.68229479e-01,  -3.59759629e-01,  -3.54050487e-01,
                         -3.62112045e-01,  -3.77940029e-01,  -3.95564407e-01,
                         -4.10561413e-01,  -4.22248900e-01,  -4.38072324e-01,
                         -4.42619711e-01,  -4.39744502e-01,  -4.29805756e-01,
                         -4.19435173e-01,  -4.29000586e-01,  -4.31174189e-01,
                         -4.40254092e-01,  -4.54072565e-01,  -4.59332734e-01,
                         -4.60884780e-01,  -4.44928348e-01,  -4.24136639e-01,
                         -4.15293813e-01,  -4.09471065e-01,  -4.08661544e-01,
                         -4.01151896e-01,  -3.87843639e-01,  -3.79872859e-01,
                         -3.63603652e-01,  -3.51422101e-01,  -3.31546217e-01,
                         -3.03957880e-01,  -2.82179832e-01,  -2.73767263e-01,
                         -2.78627336e-01,  -2.93443441e-01,  -3.26567888e-01,
                         -3.75629127e-01,  -4.29438978e-01,  -4.73026425e-01,
                         -4.93172407e-01,  -4.95955914e-01,  -4.85631108e-01,
                         -4.50467199e-01,  -4.13440645e-01,  -3.78259629e-01,
                         -3.56775045e-01,  -3.56263846e-01,  -3.64768773e-01,
                         -3.87124866e-01,  -4.21171993e-01,  -4.54701900e-01,
                         -4.78595018e-01,  -4.91673976e-01,  -4.89116907e-01,
                         -4.79951560e-01,  -4.74563032e-01,  -4.76304680e-01,
                         -4.72912163e-01,  -4.68417764e-01,  -4.67193484e-01,
                         -4.70599145e-01,  -4.71718878e-01,  -4.78720576e-01,
                         -4.98533100e-01,  -5.10257840e-01,  -5.13463616e-01,
                         -5.05407929e-01,  -4.94553924e-01,  -4.81811732e-01,
                         -4.60977972e-01,  -4.44831550e-01,  -4.42391425e-01,
                         -4.41670179e-01,  -4.48496580e-01,  -4.56549466e-01,
                         -4.69587117e-01,  -4.91361648e-01,  -4.95449483e-01,
                         -4.83298272e-01,  -4.68485624e-01,  -4.61114734e-01,
                         -4.53851432e-01,  -4.47039723e-01,  -4.40513909e-01,
                         -4.38555300e-01,  -4.45518136e-01,  -4.63653594e-01,
                         -4.91497517e-01,  -5.11219263e-01,  -4.94560659e-01,
                         -4.65172082e-01,  -4.64086264e-01,  -4.72610086e-01,
                         -4.72506493e-01,  -4.63005543e-01,  -4.61487055e-01,
                         -4.55601424e-01,  -4.25730526e-01,  -3.85600805e-01,
                         -3.62580955e-01,  -3.64274472e-01,  -3.84629041e-01,
                         -4.12808210e-01,  -4.43660915e-01,  -4.68685269e-01,
                         -4.75354970e-01,  -4.72510099e-01,  -4.60346848e-01,
                         -4.52798933e-01,  -4.43533123e-01,  -4.13570285e-01,
                         -3.68584394e-01,  -3.21588576e-01,  -2.68720746e-01,
                         -2.27358073e-01,  -2.11863652e-01,  -2.08233953e-01,
                         -2.06667766e-01,  -2.04417363e-01,  -2.09420502e-01,
                         -2.14011565e-01,  -2.22293988e-01,  -2.39722818e-01,
                         -2.60082006e-01,  -2.66014457e-01,  -2.51860112e-01,
                         -2.28090867e-01,  -2.14709774e-01,  -2.10324839e-01,
                         -2.12912381e-01,  -2.24866897e-01,  -2.28295177e-01,
                         -2.23463058e-01,  -2.11175561e-01,  -2.01396197e-01,
                         -1.95243031e-01,  -1.90372556e-01,  -1.89168602e-01,
                         -1.87073350e-01,  -1.65949985e-01,  -1.22540280e-01,
                         -7.39198476e-02,  -4.94173989e-02,  -4.93889004e-02,
                         -4.56199385e-02,  -3.43918912e-02,  -2.31261496e-02,
                         -2.66777296e-02,  -2.68767495e-02,  -1.51768019e-02,
                         -7.26359384e-03,  -1.08453995e-02,  -1.60972141e-02,
                         -1.22424765e-02,   2.25673919e-03,   2.07907092e-02,
                          3.67416888e-02,   4.31119986e-02,   4.46100123e-02,
                          5.90846539e-02,   7.98377916e-02,   1.02463454e-01,
                          1.17527254e-01,   1.26673132e-01,   1.24952562e-01,
                          1.17048793e-01,   1.04439735e-01,   6.97415844e-02,
                          2.66999025e-02,  -1.45077836e-02,  -5.03467061e-02,
                         -5.01665063e-02,  -2.03130729e-02,   1.28906844e-02,
                          6.69600219e-02,   1.47511870e-01,   2.73760557e-01,
                          4.21419948e-01,   5.25137484e-01,   5.57927966e-01,
                          5.37533760e-01,   5.15257120e-01,   5.15267491e-01,
                          5.18683016e-01,   5.29403925e-01,   5.54614067e-01,
                          5.67168832e-01,   5.75997412e-01,   5.94447315e-01,
                          6.10851765e-01,   6.18964970e-01,   6.25134468e-01,
                          6.21604025e-01,   6.28179610e-01,   6.52475953e-01,
                          6.64884150e-01,   6.59027040e-01,   6.29741013e-01,
                          5.95241606e-01,   5.80659091e-01,   5.85125208e-01,
                          6.03257179e-01,   6.20162845e-01,   6.16882086e-01,
                          6.10190094e-01,   5.90252817e-01,   5.57055950e-01,
                          5.29296339e-01,   5.03502131e-01,   4.87751037e-01,
                          4.78264600e-01,   4.76311088e-01,   4.92757887e-01,
                          5.16376436e-01,   5.34277976e-01,   5.55412352e-01,
                          5.67829549e-01,   5.68809450e-01,   5.61439335e-01,
                          5.47725916e-01,   5.34793913e-01,   5.27587950e-01,
                          5.38079143e-01,   5.74012518e-01,   6.22288883e-01,
                          6.66997552e-01,   7.06169367e-01,   7.16412187e-01,
                          7.07711995e-01,   7.03875065e-01,   7.03921974e-01,
                          7.06471920e-01,   7.06610858e-01,   6.97833002e-01,
                          6.98175490e-01,   7.01175034e-01,   6.92337215e-01,
                          6.88849747e-01,   6.86045587e-01,   6.86104834e-01,
                          6.88312948e-01,   6.85144186e-01,   6.82366967e-01,
                          6.82567716e-01,   6.78590417e-01,   6.76134884e-01,
                          6.71304345e-01,   6.70239747e-01,   6.72856987e-01,
                          6.67759538e-01,   6.69426322e-01,   6.68190002e-01,
                          6.63747966e-01,   6.65118933e-01,   6.51683629e-01,
                          6.20617986e-01,   5.99226654e-01,   5.91432393e-01,
                          5.95127285e-01,   5.98451257e-01,   6.02993608e-01,
                          6.09794259e-01,   6.08266413e-01,   6.12166762e-01,
                          6.12040639e-01,   6.03290379e-01,   5.94719291e-01,
                          5.88548899e-01,   5.99426329e-01,   6.24286771e-01,
                          6.30901039e-01,   6.27340317e-01,   6.27088726e-01,
                          6.28619850e-01,   6.26657903e-01,   6.21379673e-01,
                          6.22216761e-01,   6.19579017e-01,   6.18322134e-01,
                          6.19145334e-01,   6.15973115e-01,   6.12241149e-01,
                          6.11105382e-01,   6.07188642e-01,   5.97591460e-01,
                          5.89801908e-01,   5.99566698e-01,   6.05958402e-01,
                          5.99294782e-01,   5.99457264e-01,   5.95853627e-01,
                          5.92450738e-01,   5.93035400e-01,   5.91517806e-01,
                          5.89357436e-01,   5.85068405e-01,   5.80880761e-01,
                          5.85887253e-01,   5.79893887e-01,   5.53380132e-01,
                          5.20949006e-01,   4.98786569e-01,   4.95087534e-01,
                          4.92972136e-01,   4.83663470e-01,   4.67054516e-01,
                          4.51940835e-01,   4.56296951e-01,   4.85215336e-01,
                          5.14890075e-01,   5.31630337e-01,   5.31385541e-01,
                          5.22417426e-01,   5.07605076e-01,   4.80393201e-01,
                          4.54735577e-01,   4.37868953e-01,   4.29115623e-01,
                          4.26376730e-01,   4.28294867e-01,   4.38134313e-01,
                          4.41769063e-01,   3.92517805e-01,   3.00784647e-01,
                          2.26144612e-01,   1.65741250e-01,   7.64206648e-02,
                         -6.98972819e-03,  -6.09613918e-02,  -1.17300294e-01,
                         -1.40721425e-01,  -1.45427585e-01,  -1.75237611e-01,
                         -1.91285208e-01,  -2.06406549e-01,  -2.16895401e-01,
                         -1.65947184e-01,  -1.33455992e-01,  -1.45504981e-01,
                         -1.45926967e-01,  -1.64468437e-01,  -1.84313759e-01,
                         -1.96867093e-01,  -2.44081616e-01,  -2.80451179e-01,
                         -2.78001666e-01,  -2.71467894e-01,  -2.55548388e-01,
                         -2.48348624e-01,  -2.62271136e-01,  -2.80054152e-01,
                         -2.98634917e-01,  -3.10920775e-01,  -3.18618178e-01,
                         -3.31672609e-01,  -3.45148474e-01,  -3.67999762e-01,
                         -4.00060654e-01,  -4.16608721e-01,  -4.26567465e-01,
                         -4.36743528e-01,  -4.44390982e-01,  -4.40359175e-01,
                         -4.12886292e-01,  -3.83777738e-01,  -3.82337421e-01,
                         -4.01519269e-01,  -4.22326237e-01,  -4.33061033e-01,
                         -4.37237024e-01,  -4.41609532e-01,  -4.36561555e-01,
                         -4.29360807e-01,  -4.29494351e-01,  -4.40757304e-01,
                         -4.60278302e-01,  -4.80787098e-01,  -4.91526961e-01,
                         -4.88447219e-01,  -4.82166201e-01,  -4.79475617e-01,
                         -4.69765097e-01,  -4.52375650e-01,  -4.45721865e-01,
                         -4.51648086e-01,  -4.60084438e-01,  -4.64811653e-01,
                         -4.67668384e-01,  -4.66775686e-01,  -4.63948697e-01,
                         -4.49849039e-01,  -4.19283360e-01,  -3.92072678e-01,
                         -3.91929090e-01,  -4.18533593e-01,  -4.47746485e-01,
                         -4.75403756e-01,  -5.12224495e-01,  -5.53038776e-01,
                         -5.83166897e-01,  -5.98862648e-01,  -6.16470337e-01,
                         -6.53325021e-01,  -6.78132713e-01,  -6.75362825e-01,
                         -6.66707575e-01,  -6.55093074e-01,  -6.40711665e-01,
                         -6.24338865e-01,  -6.14165246e-01,  -6.24711037e-01,
                         -6.40035033e-01,  -6.46564305e-01,  -6.60863161e-01,
                         -6.74800396e-01,  -6.79563165e-01,  -6.79384828e-01,
                         -6.74449325e-01,  -6.70757353e-01,  -6.71075463e-01,
                         -6.67226553e-01,  -6.55661106e-01,  -6.37479961e-01,
                         -6.15926802e-01,  -6.06920481e-01,  -6.15371883e-01,
                         -6.27828360e-01,  -6.31069481e-01,  -6.25376463e-01,
                         -6.05397820e-01,  -5.74387431e-01,  -5.53056180e-01,
                         -5.53586125e-01,  -5.68139076e-01,  -5.81544638e-01,
                         -5.90250850e-01,  -5.95288873e-01,  -5.92010677e-01,
                         -5.84723294e-01,  -5.93641698e-01,  -6.18020535e-01,
                         -6.35536849e-01,  -6.35745287e-01,  -6.35106742e-01,
                         -6.35716081e-01,  -6.28421247e-01,  -6.23879194e-01,
                         -6.23768330e-01,  -6.21973872e-01,  -6.21344388e-01,
                         -6.21121585e-01,  -6.20760322e-01,  -6.21274173e-01,
                         -6.16451621e-01,  -6.13326848e-01,  -6.15476131e-01,
                         -6.14800215e-01,  -6.11151159e-01,  -6.09994292e-01,
                         -6.07837319e-01,  -6.04761779e-01,  -6.03103876e-01,
                         -5.99296927e-01,  -6.00481033e-01,  -6.01065874e-01,
                         -5.88971019e-01,  -5.66608191e-01,  -5.46701968e-01,
                         -5.54176390e-01,  -5.79139292e-01,  -5.85402548e-01,
                         -5.87131500e-01,  -5.88870466e-01,  -5.82875133e-01,
                         -5.83091557e-01,  -5.74307561e-01,  -5.64136565e-01,
                         -5.65334618e-01,  -5.50908208e-01,  -5.23734033e-01,
                         -4.94372308e-01,  -4.57137883e-01,  -4.32777107e-01,
                         -4.37950850e-01,  -4.64402258e-01,  -4.92790520e-01,
                         -5.16297460e-01,  -5.38765967e-01,  -5.57290971e-01,
                         -5.63622475e-01,  -5.55606842e-01,  -5.56016266e-01,
                         -5.57810009e-01,  -5.38625360e-01,  -5.10825813e-01,
                         -4.78380293e-01,  -4.61500794e-01,  -4.47528273e-01,
                         -3.96814167e-01,  -3.65868121e-01,  -3.22543263e-01,
                         -1.96548119e-01,  -1.01451397e-01,  -6.30847812e-02,
                         -2.41498593e-02,  -4.07610498e-02,  -9.33056921e-02,
                         -8.51297677e-02,   1.52109567e-06,   8.35854635e-02,
                          9.50400159e-02,   8.53795782e-02,   9.76115987e-02,
                          1.19463257e-01,   1.47813022e-01,   1.50506049e-01,
                          1.47050664e-01,   1.59846678e-01,   1.55122086e-01,
                          1.63433462e-01,   1.93982825e-01,   2.14524075e-01,
                          2.36082122e-01,   2.50776827e-01,   2.67883927e-01,
                          2.89048761e-01,   2.87425369e-01,   3.04539025e-01,
                          3.50110054e-01,   3.81425411e-01,   4.00650531e-01,
                          4.10535216e-01,   4.12790388e-01,   4.08359289e-01,
                          3.87654215e-01,   3.61698031e-01,   3.33201587e-01,
                          3.17266405e-01,   3.36261690e-01,   3.70796651e-01,
                          4.04521048e-01,   4.24862534e-01,   4.20933604e-01,
                          4.14311975e-01,   4.11110073e-01,   3.94797206e-01,
                          3.69932532e-01,   3.54172766e-01,   3.53935272e-01,
                          3.56879473e-01,   3.58672589e-01,   3.70786279e-01,
                          3.93485427e-01,   4.19366837e-01,   4.43077713e-01,
                          4.61981893e-01,   4.81693745e-01,   5.03229201e-01,
                          5.12343645e-01,   4.95937109e-01,   4.57916975e-01,
                          4.18615550e-01,   3.97805065e-01,   3.96010637e-01,
                          3.99903446e-01,   4.00452852e-01,   3.98430765e-01,
                          3.95795137e-01,   3.81976247e-01,   3.51262271e-01,
                          3.25544596e-01,   3.20273519e-01,   3.27972293e-01,
                          3.46537739e-01,   3.73029470e-01,   3.93255800e-01,
                          3.98678750e-01,   3.93237144e-01,   3.85165036e-01,
                          3.68988901e-01,   3.45978975e-01,   3.41134965e-01,
                          3.52028102e-01,   3.58574510e-01,   3.63588244e-01,
                          3.58994961e-01,   3.37775469e-01,   3.11753988e-01,
                          2.87725896e-01,   2.80473173e-01,   2.94826537e-01,
                          3.19025546e-01,   3.45143497e-01,   3.54767323e-01,
                          3.55407834e-01,   3.76672000e-01,   4.10539865e-01,
                          4.35793579e-01,   4.44150209e-01,   4.43541318e-01,
                          4.41160768e-01,   4.25931871e-01,   4.09620821e-01,
                          4.02527660e-01,   3.96211118e-01,   3.99464458e-01,
                          4.00015831e-01,   3.86465013e-01,   3.75529438e-01,
                          3.64586025e-01,   3.59044880e-01,   3.64385456e-01,
                          3.68284762e-01,   3.80869925e-01,   3.96341205e-01,
                          3.95668179e-01,   3.88087213e-01,   3.76648515e-01,
                          3.52908194e-01,   3.15583259e-01,   2.81374574e-01,
                          2.64671087e-01,   2.52099812e-01,   2.51223236e-01,
                          2.74438858e-01,   2.95790941e-01,   3.03406179e-01,
                          3.11843067e-01,   3.39182079e-01,   3.84523839e-01,
                          4.19433504e-01,   4.40011650e-01,   4.61721212e-01,
                          4.88012820e-01,   5.18880963e-01,   5.41894019e-01,
                          5.48962951e-01,   5.44632494e-01,   5.32449365e-01,
                          5.19487858e-01,   5.06155372e-01,   4.87355620e-01,
                          4.55669999e-01,   4.12531555e-01,   3.75918567e-01,
                          3.47096503e-01,   3.22504014e-01,   3.08198005e-01,
                          3.08219731e-01,   3.27725559e-01,   3.47322494e-01,
                          3.56300056e-01,   3.71561468e-01,   3.82520437e-01,
                          3.86661142e-01,   3.97805661e-01,   4.11249101e-01,
                          4.27278429e-01,   4.37881321e-01,   4.39948976e-01,
                          4.36962157e-01,   4.10454035e-01,   3.78900915e-01,
                          3.73957545e-01,   3.80148143e-01,   3.87481987e-01,
                          3.99248153e-01,   4.15181905e-01,   4.34969842e-01,
                          4.45248455e-01,   4.43613499e-01,   4.39087421e-01,
                          4.35290366e-01,   4.43906695e-01,   4.59098458e-01,
                          4.60134327e-01,   4.59641993e-01,   4.76229042e-01,
                          4.98113334e-01,   5.06024301e-01,   4.89584267e-01,
                          4.59472775e-01,   4.31419671e-01,   4.01798099e-01,
                          3.77713859e-01,   3.66481692e-01,   3.61730903e-01,
                          3.72239619e-01,   3.90683919e-01,   3.99799198e-01,
                          4.00871068e-01,   3.86571288e-01,   3.61929476e-01,
                          3.34096819e-01,   2.99659014e-01,   2.85434306e-01,
                          2.93265015e-01,   2.74063200e-01,   2.21516073e-01,
                          1.81791052e-01,   1.49407044e-01,   9.24683884e-02,
                          5.28199896e-02,   3.12115103e-02,  -2.17721537e-02,
                         -6.99864775e-02,  -1.07434109e-01,  -1.53279603e-01,
                         -1.77521273e-01,  -2.11005703e-01,  -2.65463799e-01,
                         -3.18996638e-01,  -3.79305959e-01,  -3.99913043e-01,
                         -3.88534784e-01,  -4.08832610e-01,  -4.38731670e-01,
                         -4.54537183e-01,  -4.54247892e-01,  -4.44462776e-01,
                         -4.54759210e-01,  -4.68470573e-01,  -4.55333889e-01,
                         -4.20401663e-01,  -3.83944511e-01,  -3.60131443e-01,
                         -3.36946845e-01,  -3.09800506e-01,  -2.95239359e-01,
                         -2.96639711e-01,  -2.92836428e-01,  -2.72865444e-01,
                         -2.57484943e-01,  -2.51636267e-01,  -2.49298528e-01,
                         -2.54004300e-01,  -2.58302093e-01,  -2.63663977e-01,
                         -2.66796589e-01,  -2.55445808e-01,  -2.41669878e-01,
                         -2.42761508e-01,  -2.61889726e-01,  -2.79450059e-01,
                         -2.90238231e-01,  -3.16102296e-01,  -3.31833333e-01,
                         -3.07974368e-01,  -2.73655593e-01,  -2.48264343e-01,
                         -2.24267691e-01,  -2.06904933e-01,  -2.08250925e-01,
                         -2.19725817e-01,  -2.19369248e-01,  -2.03245774e-01,
                         -1.75453827e-01,  -1.45004094e-01,  -1.26824349e-01,
                         -1.14347242e-01,  -1.01873904e-01,  -9.66594070e-02,
                         -1.00083694e-01,  -1.16163984e-01,  -1.29097581e-01,
                         -1.18098751e-01,  -9.50376540e-02,  -7.30420575e-02,
                         -7.11301044e-02,  -9.92370471e-02,  -1.29948199e-01,
                         -1.50860205e-01,  -1.62564829e-01,  -1.67977974e-01,
                         -1.76575392e-01,  -1.76781744e-01,  -1.73970699e-01,
                         -1.82284981e-01,  -1.90650210e-01,  -1.94470301e-01,
                         -1.97849020e-01,  -2.12872684e-01,  -2.30955794e-01,
                         -2.30415672e-01,  -2.28786245e-01,  -2.32138649e-01,
                         -2.39321634e-01,  -2.68950462e-01,  -3.10879350e-01,
                         -3.44962925e-01,  -3.58043373e-01,  -3.52808297e-01,
                         -3.46755058e-01,  -3.33499581e-01,  -3.11334819e-01,
                         -2.92101562e-01,  -2.88535625e-01,  -3.10271531e-01,
                         -3.29360008e-01,  -3.27191114e-01,  -3.24807584e-01,
                         -3.29673886e-01,  -3.35708052e-01,  -3.39290708e-01,
                         -3.38230342e-01,  -3.31068695e-01,  -3.10148895e-01,
                         -2.76666850e-01,  -2.50173002e-01,  -2.43833467e-01,
                         -2.50473648e-01,  -2.64429569e-01,  -2.88368493e-01,
                         -3.13190132e-01,  -3.20344567e-01,  -3.02390635e-01,
                         -2.71149546e-01,  -2.48584345e-01,  -2.47627214e-01,
                         -2.54551083e-01,  -2.54063845e-01,  -2.58826762e-01,
                         -2.70780623e-01,  -2.78102309e-01,  -2.88896561e-01,
                         -2.98551261e-01,  -2.89923072e-01,  -2.69472390e-01,
                         -2.52095997e-01,  -2.44341165e-01,  -2.42384210e-01,
                         -2.35431686e-01,  -2.17043862e-01,  -1.90589651e-01,
                         -1.69732437e-01,  -1.64538831e-01,  -1.69682935e-01,
                         -1.77476466e-01,  -1.88063353e-01,  -2.01080248e-01,
                         -2.11381271e-01,  -2.13313013e-01,  -2.10116014e-01,
                         -2.18786314e-01,  -2.42675245e-01,  -2.55769581e-01,
                         -2.50748515e-01,  -2.53898591e-01,  -2.60133475e-01,
                         -2.37248287e-01,  -1.96398467e-01,  -1.63278535e-01,
                         -1.34091914e-01,  -1.07038215e-01,  -9.07223374e-02,
                         -9.20552760e-02,  -1.06359370e-01,  -1.18759230e-01,
                         -1.26268923e-01,  -1.33103952e-01,  -1.43898651e-01,
                         -1.56442493e-01,  -1.62416816e-01,  -1.68158203e-01,
                         -1.76257193e-01,  -1.74732581e-01,  -1.50806069e-01,
                         -1.12068921e-01,  -8.92704427e-02,  -8.17289501e-02,
                         -7.12572932e-02,  -6.14064001e-02,  -5.08381203e-02,
                         -3.78029831e-02,  -2.19137818e-02,  -1.30431179e-03,
                          1.85562801e-02,   3.32982503e-02,   3.58852670e-02,
                          3.17740440e-02,   2.69552078e-02,   1.15241231e-02,
                         -1.14795472e-02,  -3.26117054e-02,  -4.51216400e-02,
                         -5.23255542e-02,  -6.51146844e-02,  -7.75529370e-02,
                         -8.35270137e-02,  -8.08173716e-02,  -7.16188923e-02,
                         -6.00012541e-02,  -4.23864648e-02,  -2.82109044e-02,
                         -1.52541902e-02,   5.61533123e-03,   2.44424809e-02,
                          3.90452258e-02,   4.56086434e-02,   4.78204340e-02,
                          5.34966774e-02,   5.15199751e-02,   4.79082763e-02,
                          5.24646491e-02,   5.81108555e-02,   5.97294755e-02,
                          6.00586496e-02,   6.35891780e-02,   6.02638461e-02,
                          5.47618866e-02,   5.71768358e-02,   5.57572469e-02,
                          5.62244952e-02,   6.18756041e-02,   6.45556599e-02,
                          6.70389310e-02,   6.48153722e-02,   5.98194115e-02,
                          5.66011183e-02,   5.55083454e-02,   5.94968870e-02,
                          5.84672354e-02,   4.96572442e-02,   4.38480712e-02,
                          4.31840383e-02,   3.54907066e-02,   1.17871528e-02,
                         -1.64416544e-02,  -5.05263023e-02,  -9.87599641e-02,
                         -1.42096207e-01,  -1.62392542e-01,  -1.52834818e-01,
                         -1.17435843e-01,  -8.22234303e-02,  -6.96026012e-02,
                         -7.56882206e-02,  -7.87017122e-02,  -6.55339584e-02,
                         -5.19325957e-02,  -5.65766692e-02,  -6.58033937e-02,
                         -6.24051988e-02,  -5.69675490e-02,  -6.26939014e-02,
                         -7.49917030e-02,  -7.74714351e-02,  -7.24498704e-02,
                         -7.25198239e-02,  -6.53648078e-02,  -5.57507537e-02,
                         -5.92804700e-02,  -6.27897605e-02,  -6.81051761e-02,
                         -8.40400159e-02,  -1.04628406e-01,  -1.25796631e-01,
                         -1.35430083e-01,  -1.29108757e-01,  -1.11993551e-01,
                         -8.94287303e-02,  -7.62506202e-02,  -7.51560852e-02,
                         -7.92578608e-02,  -8.75723958e-02,  -9.96136665e-02,
                         -1.20415807e-01,  -1.50177374e-01,  -1.77159905e-01,
                         -1.89820632e-01,  -1.86523885e-01,  -1.82828993e-01,
                         -1.96620002e-01,  -2.20508054e-01,  -2.36404508e-01,
                         -2.51552433e-01,  -2.72407860e-01,  -2.84207612e-01,
                         -2.88585156e-01,  -2.94207901e-01,  -2.99513012e-01,
                         -3.05115759e-01,  -3.03732038e-01,  -2.97778100e-01,
                         -2.95784980e-01,  -2.84711182e-01,  -2.62125462e-01,
                         -2.41408736e-01,  -2.32128561e-01,  -2.42727935e-01,
                         -2.66133755e-01,  -2.88116395e-01,  -2.99405098e-01,
                         -2.93496937e-01,  -2.80564338e-01,  -2.72419542e-01,
                         -2.70282596e-01,  -2.78128296e-01,  -2.89036900e-01,
                         -2.86950529e-01,  -2.80223221e-01,  -2.91264415e-01,
                         -3.17821354e-01,  -3.39718550e-01,  -3.46097618e-01,
                         -3.43517274e-01,  -3.44978094e-01,  -3.52938980e-01,
                         -3.65968883e-01,  -3.79974812e-01,  -3.89637649e-01,
                         -4.00064170e-01,  -4.08509761e-01,  -4.13457394e-01,
                         -4.20492351e-01,  -4.31214780e-01,  -4.58846152e-01,
                         -4.92131919e-01,  -5.05506158e-01,  -5.03796220e-01,
                         -4.95708019e-01,  -5.01079559e-01,  -5.21628916e-01,
                         -5.38757503e-01,  -5.61863601e-01,  -5.74261427e-01,
                         -5.71055055e-01,  -5.73087394e-01,  -5.50371706e-01,
                         -5.06694198e-01,  -4.75957543e-01,  -4.56340998e-01,
                         -4.57009196e-01,  -4.71970439e-01,  -4.82663333e-01,
                         -4.92725372e-01,  -5.05445719e-01,  -5.22231162e-01,
                         -5.33870697e-01,  -5.34224033e-01,  -5.27441919e-01,
                         -5.12344539e-01,  -4.99913275e-01,  -5.02202928e-01,
                         -5.11837840e-01,  -5.16018808e-01,  -5.12569964e-01,
                         -4.94631946e-01,  -4.54038739e-01,  -4.26158428e-01,
                         -4.45779949e-01,  -4.91425306e-01,  -5.25946319e-01,
                         -5.34210861e-01,  -5.31752110e-01,  -5.32824039e-01,
                         -5.32575846e-01,  -5.30575454e-01,  -5.27300358e-01,
                         -5.25978923e-01,  -5.26061296e-01,  -5.22001982e-01,
                         -5.18542290e-01,  -5.17093122e-01,  -5.17758965e-01,
                         -5.16705036e-01,  -5.13430119e-01,  -5.17381787e-01,
                         -5.16414821e-01,  -5.08097529e-01,  -5.06274402e-01,
                         -5.06341100e-01,  -5.07063985e-01,  -5.07479727e-01,
                         -5.08802116e-01,  -5.06202519e-01,  -4.87701833e-01,
                         -4.81475979e-01,  -4.93532330e-01,  -4.93936539e-01,
                         -4.92374152e-01,  -4.91961718e-01,  -4.87023532e-01,
                         -4.88749504e-01,  -4.90118384e-01,  -4.89431471e-01,
                         -4.87490296e-01,  -4.80483949e-01,  -4.79173928e-01,
                         -4.82502103e-01,  -4.82057810e-01,  -4.77349579e-01,
                         -4.73315746e-01,  -4.76026684e-01,  -4.78909135e-01,
                         -4.75954592e-01,  -4.69277471e-01,  -4.66225415e-01,
                         -4.67759222e-01,  -4.65860039e-01,  -4.64152217e-01,
                         -4.61904973e-01,  -4.57376629e-01,  -4.55342203e-01,
                         -4.55656916e-01,  -4.53799844e-01,  -4.20865059e-01,
                         -3.63386035e-01,  -3.20248127e-01,  -2.79002458e-01,
                         -2.31308118e-01,  -1.65185735e-01,  -7.78240561e-02,
                         -2.24294290e-02,   1.45464041e-03,   8.84389319e-03,
                         -1.18214870e-02,  -3.28872241e-02,  -3.23003419e-02,
                         -5.11590065e-03,   1.45496884e-02,   2.10207747e-03,
                         -9.15997848e-03,  -1.86881982e-02,  -1.14678983e-02,
                          1.48857655e-02,   3.46527919e-02,   9.30860788e-02,
                          1.63482159e-01,   1.80800751e-01,   1.81268975e-01,
                          1.82008252e-01,   1.79412380e-01,   1.80488452e-01,
                          1.77249581e-01,   1.74779534e-01,   1.74473628e-01,
                          1.76117584e-01,   1.79077640e-01,   1.79972023e-01,
                          1.80273846e-01,   1.78777784e-01,   1.79317132e-01,
                          1.78507462e-01,   1.75666764e-01,   1.74923971e-01,
                          1.73793480e-01,   1.75745681e-01,   1.76040098e-01,
                          1.74171045e-01,   1.73467934e-01,   1.72972828e-01,
                          1.75414458e-01,   1.73581809e-01,   1.88603446e-01,
                          2.35703424e-01,   2.82557219e-01,   3.16983551e-01,
                          3.34751248e-01,   3.32452029e-01,   3.28874439e-01,
                          3.24927777e-01,   3.04545939e-01,   2.69085765e-01,
                          2.45758474e-01,   2.43109599e-01,   2.47384965e-01,
                          2.57569909e-01,   2.70252287e-01,   2.85096645e-01,
                          2.94687450e-01,   2.96254754e-01,   3.08681995e-01,
                          3.23013574e-01,   3.28999639e-01,   3.28721702e-01,
                          3.18591923e-01,   3.09626281e-01,   2.99567342e-01,
                          2.90816873e-01,   2.95956701e-01,   3.05946320e-01,
                          3.22734386e-01,   3.45639318e-01,   3.64068747e-01,
                          3.82458299e-01,   4.00502056e-01,   4.15583789e-01,
                          4.29422110e-01,   4.38525885e-01,   4.44710046e-01,
                          4.50015575e-01,   4.45638746e-01,   4.41153258e-01,
                          4.54133719e-01,   4.68582422e-01,   4.69565064e-01,
                          4.63268101e-01,   4.63402450e-01,   4.75435853e-01,
                          4.82534885e-01,   4.87004101e-01,   4.96296704e-01,
                          5.07412195e-01,   5.28600872e-01,   5.44157267e-01,
                          5.46574712e-01,   5.49502850e-01,   5.51673114e-01,
                          5.56079030e-01,   5.59414744e-01,   5.64071536e-01,
                          5.72300971e-01,   5.69793820e-01,   5.60077012e-01,
                          5.44274509e-01,   5.29856980e-01,   5.31311274e-01,
                          5.38148582e-01,   5.42227805e-01,   5.42118430e-01,
                          5.47799826e-01,   5.64642251e-01,   5.81852198e-01,
                          6.05757594e-01,   6.38842046e-01,   6.78849578e-01,
                          7.18598962e-01,   7.39858449e-01,   7.40684032e-01,
                          7.22084820e-01,   6.95635378e-01,   6.76887631e-01,
                          6.65164351e-01,   6.57991052e-01,   6.48035705e-01,
                          6.39150500e-01,   6.37887299e-01,   6.42326772e-01,
                          6.44670844e-01,   6.30299926e-01,   6.20288849e-01,
                          6.34624839e-01,   6.58420980e-01,   6.81910574e-01,
                          6.95232093e-01,   6.92422390e-01,   6.74777269e-01,
                          6.59542024e-01,   6.59441173e-01,   6.52427673e-01,
                          6.34226024e-01,   6.12012923e-01,   5.94554961e-01,
                          5.95987439e-01,   6.06609941e-01,   6.20482147e-01,
                          6.19685173e-01,   6.02234542e-01,   6.02296114e-01,
                          6.10965371e-01,   6.15765810e-01,   6.26804590e-01,
                          6.45615041e-01,   6.66714072e-01,   6.73074365e-01,
                          6.71544969e-01,   6.73317969e-01,   6.80698752e-01,
                          6.99830949e-01,   7.11934507e-01,   7.10707963e-01,
                          7.09094167e-01,   7.12227404e-01,   7.17338860e-01,
                          7.16479003e-01,   7.14045048e-01,   7.09337234e-01,
                          7.07401395e-01,   7.01648891e-01,   6.65123701e-01,
                          6.21215165e-01,   5.94118655e-01,   5.76905787e-01,
                          5.68851829e-01,   5.63310564e-01,   5.64189792e-01,
                          5.67861319e-01,   5.63754797e-01,   5.59678495e-01,
                          5.63793123e-01,   5.79058170e-01,   5.92151403e-01,
                          6.00283265e-01,   6.08278334e-01,   6.08822286e-01,
                          6.12417102e-01,   6.22040331e-01,   6.38551772e-01,
                          6.60886526e-01,   6.67839170e-01,   6.66214824e-01,
                          6.66106284e-01,   6.61484957e-01,   6.58175588e-01,
                          6.57284141e-01,   6.56744480e-01,   6.53247058e-01,
                          6.40651941e-01,   6.19324565e-01,   5.95952630e-01,
                          5.80786109e-01,   5.78252614e-01,   5.78997731e-01,
                          5.75389564e-01,   5.68568528e-01,   5.43663681e-01,
                          5.08549571e-01,   4.86021578e-01,   4.66031581e-01,
                          4.56772208e-01,   4.51897204e-01,   4.51203257e-01,
                          4.71270204e-01,   4.62237298e-01,   4.24965888e-01,
                          3.67332906e-01,   2.77191073e-01,   2.24145517e-01,
                          1.88921034e-01,   1.35198072e-01,   8.43727365e-02,
                          4.88460436e-02,   7.64073879e-02,   8.01211596e-02,
                          1.94725674e-02,  -3.47484718e-03,  -1.64318979e-02,
                          5.77500788e-03,   6.12620190e-02,   4.08794135e-02,
                         -2.65988498e-03,  -1.40171601e-02,  -1.03002712e-02,
                         -3.77311222e-02,  -1.20190129e-01,  -1.61967665e-01,
                         -1.55783877e-01,  -1.48264930e-01,  -1.30772740e-01,
                         -1.25552550e-01,  -1.21172786e-01,  -1.15480311e-01,
                         -1.23086199e-01,  -1.25850946e-01,  -1.28770813e-01,
                         -1.34174332e-01,  -1.42929897e-01,  -1.52622774e-01,
                         -1.57664329e-01,  -1.71155244e-01,  -1.88074127e-01,
                         -2.06289381e-01,  -2.29211614e-01,  -2.49035507e-01,
                         -2.63935626e-01,  -2.73053169e-01,  -2.76249349e-01,
                         -2.60850102e-01,  -2.27471814e-01,  -2.02419296e-01,
                         -1.85531273e-01,  -1.66190729e-01,  -1.55837521e-01,
                         -1.65776312e-01,  -1.88493297e-01,  -2.09617361e-01,
                         -2.24432647e-01,  -2.29427919e-01,  -2.12662324e-01,
                         -1.76656827e-01,  -1.45456865e-01,  -1.23570368e-01,
                         -1.07327603e-01,  -1.05420776e-01,  -1.09113067e-01,
                         -1.14839680e-01,  -1.26981765e-01,  -1.39471740e-01,
                         -1.48962051e-01,  -1.50714591e-01,  -1.51922911e-01,
                         -1.53632134e-01,  -1.50174797e-01,  -1.54277235e-01,
                         -1.62367508e-01,  -1.73995882e-01,  -1.95766911e-01,
                         -2.18078405e-01,  -2.35697508e-01,  -2.32868761e-01,
                         -2.13125125e-01,  -2.00195715e-01,  -1.94405735e-01,
                         -1.99273005e-01,  -2.13882849e-01,  -2.35281810e-01,
                         -2.64110327e-01,  -2.87842005e-01,  -3.09053391e-01,
                         -3.31308424e-01,  -3.49834979e-01,  -3.59808326e-01,
                         -3.51464301e-01,  -3.36982936e-01,  -3.30022931e-01,
                         -3.28571856e-01,  -3.30989033e-01,  -3.25463176e-01,
                         -3.00653100e-01,  -2.58392543e-01,  -2.11716771e-01,
                         -1.83219030e-01,  -1.82763204e-01,  -1.97794452e-01,
                         -2.20929548e-01,  -2.52597928e-01,  -2.82047629e-01,
                         -2.98984230e-01,  -2.94917375e-01,  -2.74413109e-01,
                         -2.50936151e-01,  -2.18509674e-01,  -1.85101748e-01,
                         -1.67865828e-01,  -1.67768672e-01,  -1.83019191e-01,
                         -2.05935568e-01,  -2.40117654e-01,  -2.77176797e-01,
                         -2.91880250e-01,  -2.81676143e-01,  -2.51137972e-01,
                         -2.19020516e-01,  -1.98991343e-01,  -1.82131156e-01,
                         -1.69810206e-01,  -1.59274951e-01,  -1.52507737e-01,
                         -1.54927820e-01,  -1.55292213e-01,  -1.44480631e-01,
                         -1.26837969e-01,  -1.33316144e-01,  -1.72799587e-01,
                         -2.08022237e-01,  -2.31314555e-01,  -2.56836236e-01,
                         -2.78684467e-01,  -2.92206585e-01,  -3.01093847e-01,
                         -3.06215793e-01,  -3.01997811e-01,  -2.86280513e-01,
                         -2.66102910e-01,  -2.43701681e-01,  -2.21008271e-01,
                         -2.09026650e-01,  -2.07312092e-01,  -2.01767430e-01,
                         -1.83808520e-01,  -1.60173029e-01,  -1.47578314e-01,
                         -1.46784589e-01,  -1.51896179e-01,  -1.72859177e-01,
                         -2.15709999e-01,  -2.62707323e-01,  -2.86628813e-01,
                         -2.89209962e-01,  -2.85834193e-01,  -2.74652421e-01,
                         -2.63738394e-01,  -2.71035284e-01,  -2.98419774e-01,
                         -3.23030025e-01,  -3.30478638e-01,  -3.40755403e-01,
                         -3.57859612e-01,  -3.61510962e-01,  -3.45943123e-01,
                         -3.24618340e-01,  -3.11688572e-01,  -3.00857991e-01,
                         -2.91639268e-01,  -2.92688549e-01,  -2.88400829e-01,
                         -2.61783481e-01,  -2.20974132e-01,  -1.86653465e-01,
                         -1.69012040e-01,  -1.59902602e-01,  -1.52712598e-01,
                         -1.55362919e-01,  -1.69075623e-01,  -1.81598634e-01,
                         -1.90774068e-01,  -2.01917037e-01,  -2.19498396e-01,
                         -2.40810469e-01,  -2.48886585e-01,  -2.38480136e-01,
                         -2.28271410e-01,  -2.36378774e-01,  -2.50195801e-01,
                         -2.46960968e-01,  -2.36647338e-01,  -2.35483631e-01,
                         -2.43676186e-01,  -2.56652117e-01,  -2.71510154e-01,
                         -2.91018903e-01,  -3.08703035e-01,  -3.14368367e-01,
                         -3.07022274e-01,  -2.90627599e-01,  -2.72075564e-01,
                         -2.58029997e-01,  -2.57671565e-01,  -2.71645129e-01,
                         -2.85158098e-01,  -2.83333927e-01,  -2.70332605e-01,
                         -2.62284070e-01,  -2.54177183e-01,  -2.36271366e-01,
                         -2.12975606e-01,  -1.86350301e-01,  -1.53118759e-01,
                         -1.08747058e-01,  -6.94910362e-02,  -5.39541058e-02,
                         -4.96809557e-02,  -4.79985960e-02,  -5.57722189e-02,
                         -7.09236637e-02,  -8.03768262e-02,  -8.03600177e-02,
                         -8.39392468e-02,  -9.14109796e-02,  -9.42035094e-02,
                         -9.90766138e-02,  -1.15174055e-01,  -1.39016002e-01,
                         -1.56580925e-01,  -1.66189134e-01,  -1.82395473e-01,
                         -1.99348032e-01,  -2.01470673e-01,  -2.01607645e-01,
                         -2.14837804e-01,  -2.30220571e-01,  -2.28166968e-01,
                         -2.05837682e-01,  -1.85218528e-01,  -1.82394847e-01,
                         -1.86057761e-01,  -1.86567038e-01,  -1.98430523e-01,
                         -2.28416592e-01,  -2.53981769e-01,  -2.64558285e-01,
                         -2.66439348e-01,  -2.62345940e-01,  -2.61829555e-01,
                         -2.68248528e-01,  -2.81682670e-01,  -2.99815357e-01,
                         -3.06974292e-01,  -3.01892310e-01,  -2.90488750e-01,
                         -2.70817906e-01,  -2.49790266e-01,  -2.37082154e-01,
                         -2.41568252e-01,  -2.66970068e-01,  -2.94684023e-01,
                         -3.06653768e-01,  -3.06543678e-01,  -2.95331568e-01,
                         -2.77075887e-01,  -2.66548038e-01,  -2.66959012e-01,
                         -2.74495304e-01,  -2.75848627e-01,  -2.73403645e-01,
                         -2.90951252e-01,  -3.13987315e-01,  -3.23655367e-01,
                         -3.29397202e-01,  -3.37495327e-01,  -3.53804946e-01,
                         -3.70377988e-01,  -3.83694857e-01,  -3.99142683e-01,
                         -4.04314637e-01,  -4.11174595e-01,  -4.27910626e-01,
                         -4.21680540e-01,  -3.95781726e-01,  -3.82994771e-01,
                         -3.84687304e-01,  -3.90219003e-01,  -3.93223047e-01,
                         -3.97492886e-01,  -4.10553485e-01,  -4.17306840e-01,
                         -4.09864843e-01,  -4.00072962e-01,  -3.92477304e-01,
                         -4.00190771e-01,  -4.27080572e-01,  -4.44727838e-01,
                         -4.33939695e-01,  -4.05387670e-01,  -3.82737786e-01,
                         -3.70927721e-01,  -3.53587091e-01,  -3.33190262e-01,
                         -3.24523985e-01,  -3.21407795e-01,  -3.10700744e-01,
                         -2.89301604e-01,  -2.62958765e-01,  -2.46193603e-01,
                         -2.51031816e-01,  -2.75353312e-01,  -3.02055091e-01,
                         -3.13202411e-01,  -3.13758343e-01,  -3.21400970e-01,
                         -3.40268046e-01,  -3.66076142e-01,  -3.90138835e-01,
                         -3.98623407e-01,  -3.89155626e-01,  -3.66945356e-01,
                         -3.35209161e-01,  -3.10045660e-01,  -3.08436096e-01,
                         -3.26411635e-01,  -3.51712316e-01,  -3.70249331e-01,
                         -3.80766481e-01,  -3.91110688e-01,  -3.94293606e-01,
                         -3.97208452e-01,  -4.09400433e-01,  -4.14126158e-01,
                         -4.10162777e-01,  -4.07493412e-01,  -4.01246369e-01,
                         -3.97102118e-01,  -4.04988915e-01,  -4.18578178e-01,
                         -4.25282836e-01,  -4.19933289e-01,  -4.10964549e-01,
                         -4.00546581e-01,  -3.80807221e-01,  -3.56041700e-01,
                         -3.33022296e-01,  -3.08756471e-01,  -2.85098165e-01,
                         -2.62283564e-01,  -2.34492749e-01,  -2.08098978e-01,
                         -1.98756456e-01,  -2.15511724e-01,  -2.52578169e-01,
                         -2.95698911e-01,  -3.33706170e-01,  -3.65825653e-01,
                         -3.88030887e-01,  -3.93027633e-01,  -3.87872934e-01,
                         -3.75086457e-01,  -3.54617506e-01,  -3.42744857e-01,
                         -3.45158190e-01,  -3.50934833e-01,  -3.50640446e-01,
                         -3.37199271e-01,  -3.27022135e-01,  -3.32534999e-01,
                         -3.42980385e-01,  -3.57420623e-01,  -3.71513724e-01,
                         -3.77321839e-01,  -3.72463197e-01,  -3.56258392e-01,
                         -3.48133504e-01,  -3.58803958e-01,  -3.78710955e-01,
                         -4.08350587e-01,  -4.23784405e-01,  -4.11651731e-01,
                         -3.82602572e-01,  -3.22969794e-01,  -2.58079290e-01,
                         -2.18966648e-01,  -1.98788032e-01,  -2.01870963e-01,
                         -1.72368363e-01,  -9.18612257e-02,  -8.19619596e-02,
                         -1.25775993e-01,  -1.14370726e-01,  -8.96199867e-02,
                         -5.89007735e-02,   1.87035743e-02,   7.65736550e-02,
                          8.67709965e-02,   9.70761552e-02,   1.20560184e-01,
                          1.62434161e-01,   2.15143114e-01,   2.53887594e-01,
                          2.64256984e-01,   2.49784082e-01,   2.33157784e-01,
                          2.28966534e-01,   2.44598791e-01,   2.82285273e-01,
                          3.19495112e-01,   3.34616095e-01,   3.27548623e-01,
                          3.08353066e-01,   2.92123377e-01,   2.80196041e-01,
                          2.76405871e-01,   2.81129926e-01,   2.84905255e-01,
                          2.89187700e-01,   2.91398525e-01,   2.92006940e-01,
                          2.99624383e-01,   3.12643260e-01,   3.26044232e-01,
                          3.38178933e-01,   3.47149700e-01,   3.60908449e-01,
                          3.77463579e-01,   3.85652214e-01,   3.83296669e-01,
                          3.72595519e-01,   3.53817403e-01,   3.33385020e-01,
                          3.30080718e-01,   3.47655594e-01,   3.66298735e-01,
                          3.73748660e-01,   3.81392956e-01,   3.87472749e-01,
                          3.85787070e-01,   3.83781999e-01,   3.82992834e-01,
                          3.74363750e-01,   3.53780359e-01,   3.35218549e-01,
                          3.27235758e-01,   3.17376673e-01,   3.03146839e-01,
                          2.97087610e-01,   2.94585764e-01,   2.87217766e-01,
                          2.72827953e-01,   2.66326487e-01,   2.76223779e-01,
                          2.91822314e-01,   3.10275704e-01,   3.36074769e-01,
                          3.81226301e-01,   4.34495956e-01,   4.73037213e-01,
                          5.06189704e-01,   5.48662961e-01,   5.91991663e-01,
                          6.23377264e-01,   6.27017260e-01,   6.13510013e-01,
                          5.97288668e-01,   5.70945203e-01,   5.43519258e-01,
                          5.21706700e-01,   5.07620871e-01,   4.99511570e-01,
                          4.86322522e-01,   4.67358470e-01,   4.63259012e-01,
                          4.77376133e-01,   5.01897275e-01,   5.33368587e-01,
                          5.58461905e-01,   5.67029238e-01,   5.57260513e-01,
                          5.39845943e-01,   5.18432081e-01,   4.93692458e-01,
                          4.79137361e-01,   4.86844510e-01,   4.95382279e-01,
                          4.90906298e-01,   4.77807283e-01,   4.66202497e-01,
                          4.73105520e-01,   4.94035155e-01,   5.23611307e-01,
                          5.52151442e-01,   5.81451058e-01,   6.17319524e-01,
                          6.50010705e-01,   6.66109383e-01,   6.64780140e-01,
                          6.52987957e-01,   6.38905287e-01,   6.21392012e-01,
                          6.03232265e-01,   5.94504595e-01,   5.90827882e-01,
                          6.10994995e-01,   6.53880119e-01,   7.00694621e-01,
                          7.31275380e-01,   7.38442481e-01,   7.44377196e-01,
                          7.48785794e-01,   7.30858684e-01,   6.95790350e-01,
                          6.67205572e-01,   6.50963008e-01,   6.51199102e-01,
                          6.53498411e-01,   6.52121723e-01,   6.48743808e-01,
                          6.42942190e-01,   6.34518206e-01,   6.28102243e-01,
                          6.33143544e-01,   6.47738636e-01,   6.63704038e-01,
                          6.63080096e-01,   6.57234073e-01,   6.48046553e-01,
                          6.38094068e-01,   6.34301901e-01,   6.44985676e-01,
                          6.75141215e-01,   6.92185104e-01,   6.86691225e-01,
                          6.94635987e-01,   7.19151258e-01,   7.17856288e-01,
                          6.97879076e-01,   6.91936910e-01,   7.07124770e-01,
                          7.14937091e-01,   7.20973313e-01,   7.32730091e-01,
                          7.32605517e-01,   7.27350354e-01,   7.12581933e-01,
                          7.04025984e-01,   6.98406279e-01,   6.76360130e-01,
                          6.55972302e-01,   6.59589410e-01,   6.67268157e-01,
                          6.66498303e-01,   6.52776480e-01,   6.33177042e-01,
                          6.23726368e-01,   6.11887634e-01,   6.03957415e-01,
                          6.06490314e-01,   6.24684811e-01,   6.46778882e-01,
                          6.58904552e-01,   6.56944335e-01,   6.60486996e-01,
                          6.70141041e-01,   6.68955505e-01,   6.65360570e-01,
                          6.61126196e-01,   6.71274126e-01,   6.80263281e-01,
                          6.70821905e-01,   6.50814235e-01,   6.36067867e-01,
                          6.31367564e-01,   6.34364963e-01,   6.29158735e-01,
                          6.16531849e-01,   6.13980889e-01,   6.21680140e-01,
                          6.38230383e-01,   6.33159816e-01,   6.09241486e-01,
                          5.84341347e-01,   5.79293609e-01,   5.75488210e-01,
                          5.53578734e-01,   5.47193408e-01,   5.58817387e-01,
                          5.76144040e-01,   5.86870611e-01,   5.96784830e-01,
                          6.19514763e-01,   6.45240188e-01,   6.48747206e-01,
                          6.45704746e-01,   6.43518329e-01,   6.41811550e-01,
                          6.40645683e-01,   6.34374082e-01,   6.34241581e-01,
                          6.32678866e-01,   6.31958485e-01,   6.29665554e-01,
                          6.29751027e-01,   6.28178060e-01,   6.26236498e-01,
                          6.23015702e-01,   6.19351625e-01,   6.20515823e-01,
                          6.18573844e-01,   6.17244005e-01,   6.15682125e-01,
                          6.11802161e-01,   6.12204015e-01,   6.03371024e-01,
                          5.41614532e-01,   4.76711839e-01,   4.32863772e-01,
                          3.99406195e-01,   3.90875548e-01,   3.83132428e-01,
                          3.77842277e-01,   3.47615212e-01,   3.18252385e-01,
                          3.11559319e-01,   2.47348115e-01,   1.63262367e-01,
                          1.58907846e-01,   1.85946435e-01,   1.78758174e-01,
                          9.19080749e-02,  -2.84320973e-02,  -7.14134276e-02,
                         -7.22372159e-02,  -6.09552860e-02,  -4.31360640e-02,
                         -3.32752801e-02,  -2.95843650e-02,  -3.06925904e-02,
                         -2.81700473e-02,  -3.01530100e-02,  -3.19122821e-02,
                         -3.71348746e-02,  -5.86743504e-02,  -7.19549805e-02,
                         -7.31264725e-02,  -7.30554163e-02,  -6.42358884e-02,
                         -6.43498078e-02,  -5.32973297e-02,  -4.85519581e-02,
                         -6.17701299e-02,  -7.06625432e-02,  -8.45370442e-02,
                         -8.96638930e-02,  -9.96058211e-02,  -1.09712966e-01,
                         -1.07704051e-01,  -1.10483095e-01,  -1.26855940e-01,
                         -1.41247332e-01,  -1.49974555e-01,  -1.55439302e-01,
                         -1.71517566e-01,  -2.02841744e-01,  -2.19139844e-01,
                         -2.20581204e-01,  -2.10350052e-01,  -2.13243067e-01,
                         -2.29503214e-01,  -2.42059588e-01,  -2.53088802e-01,
                         -2.63509631e-01,  -2.72615552e-01,  -2.65367806e-01,
                         -2.49012247e-01,  -2.34794408e-01,  -2.22728446e-01,
                         -2.12670952e-01,  -2.07438350e-01,  -2.22056210e-01,
                         -2.70246297e-01,  -3.20690542e-01,  -3.55445832e-01,
                         -3.79374802e-01,  -3.98337036e-01,  -4.17147100e-01,
                         -4.22644377e-01,  -4.24636424e-01,  -4.24351633e-01,
                         -4.25726384e-01,  -4.42958593e-01,  -4.61485207e-01,
                         -4.64131773e-01,  -4.56517249e-01,  -4.34425563e-01,
                         -4.13836479e-01,  -4.05639559e-01,  -4.15117890e-01,
                         -4.45166469e-01,  -4.60065424e-01,  -4.69933987e-01,
                         -4.75717932e-01,  -4.75921005e-01,  -4.72956717e-01,
                         -4.67445165e-01,  -4.67860818e-01,  -4.56439704e-01,
                         -4.46729660e-01,  -4.45362240e-01,  -4.53674257e-01,
                         -4.72676009e-01,  -4.91301119e-01,  -5.11357665e-01,
                         -5.28086424e-01,  -5.35361648e-01,  -5.45033991e-01,
                         -5.59734762e-01,  -5.68038344e-01,  -5.68715632e-01,
                         -5.61237037e-01,  -5.48156738e-01,  -5.43614745e-01,
                         -5.46791375e-01,  -5.38379788e-01,  -5.15962005e-01,
                         -4.87107426e-01,  -4.66585636e-01,  -4.55756634e-01,
                         -4.51994896e-01,  -4.57936525e-01,  -4.66135144e-01,
                         -4.86869395e-01,  -5.27891457e-01,  -5.67777991e-01,
                         -5.87103009e-01,  -5.88645577e-01,  -5.81011534e-01,
                         -5.75743616e-01,  -5.63075304e-01,  -5.45596063e-01,
                         -5.23600459e-01,  -4.91870522e-01,  -4.74436283e-01,
                         -4.62114692e-01,  -4.56966579e-01,  -4.74971890e-01,
                         -5.10440528e-01,  -5.48359454e-01,  -5.69582760e-01,
                         -5.72842896e-01,  -5.80244064e-01,  -5.97681999e-01,
                         -5.96511424e-01,  -5.86366773e-01,  -5.78181028e-01,
                         -5.69818079e-01,  -5.60995698e-01,  -5.31684816e-01,
                         -5.03461301e-01,  -4.86009300e-01,  -4.72842425e-01,
                         -4.75637376e-01,  -4.87255335e-01,  -5.10914505e-01,
                         -5.32492578e-01,  -5.44632912e-01,  -5.58046639e-01,
                         -5.64420342e-01,  -5.70653319e-01,  -5.72297454e-01,
                         -5.64918518e-01,  -5.62513590e-01,  -5.64451993e-01,
                         -5.64371586e-01,  -5.61125457e-01,  -5.52232146e-01,
                         -5.42537689e-01,  -5.41648805e-01,  -5.53927779e-01,
                         -5.73155582e-01,  -5.75942755e-01,  -5.73345244e-01,
                         -5.76834500e-01,  -5.72348893e-01,  -5.70410013e-01,
                         -5.70644379e-01,  -5.69370627e-01,  -5.57631671e-01,
                         -5.08938134e-01,  -4.39527601e-01,  -3.86938870e-01,
                         -3.32577109e-01,  -2.60324538e-01,  -2.06489339e-01,
                         -1.75498247e-01,  -1.37754083e-01,  -1.02454856e-01,
                         -8.88737217e-02,  -6.10764362e-02,  -3.38719152e-02,
                         -3.47029008e-02,  -1.73964340e-03,   4.97067757e-02,
                          9.75101143e-02,   1.52572691e-01,   1.59762725e-01,
                          1.30471155e-01,   1.01596184e-01,   7.29464144e-02,
                          6.27371147e-02,   6.60569221e-02,   6.48130253e-02,
                          6.81248680e-02,   7.07609281e-02,   6.36088327e-02,
                          6.57907873e-02,   6.76791370e-02,   7.14171976e-02,
                          8.05040523e-02,   7.30657503e-02,   7.03380555e-02,
                          7.21404776e-02,   6.65862709e-02,   6.47331998e-02,
                          6.95182532e-02,   8.65381807e-02,   9.71080884e-02,
                          8.81790072e-02,   8.28125179e-02,   9.12475362e-02,
                          1.10207491e-01,   1.42772213e-01,   1.68693006e-01,
                          1.77159399e-01,   1.82513431e-01,   1.83610544e-01,
                          1.82603538e-01,   1.81865603e-01,   1.81260079e-01,
                          1.77135289e-01,   1.61276892e-01,   1.34112388e-01,
                          9.86227095e-02,   6.80543780e-02,   5.87430187e-02,
                          6.29085451e-02,   5.92448525e-02,   5.70864268e-02,
                          6.11718372e-02,   6.31706193e-02,   6.27038628e-02,
                          5.33508658e-02,   5.19457869e-02,   5.75474165e-02,
                          6.05938360e-02,   6.31906986e-02,   6.52834997e-02,
                          7.73887187e-02,   7.78932944e-02,   7.17375204e-02,
                          7.47630671e-02,   7.43095875e-02,   7.91900977e-02,
                          9.11826864e-02,   1.07002854e-01,   1.15100183e-01,
                          1.14728071e-01,   1.19565941e-01,   1.26557350e-01,
                          1.33187816e-01,   1.36609793e-01,   1.36758849e-01,
                          1.35135978e-01,   1.31795034e-01,   1.19559929e-01,
                          1.04856223e-01,   9.70434844e-02,   9.21539292e-02,
                          1.02813110e-01,   1.23725273e-01,   1.52558610e-01,
                          1.92554086e-01,   2.20612988e-01,   2.23489404e-01,
                          2.01211184e-01,   1.68017536e-01,   1.31100163e-01,
                          8.86058062e-02,   6.16487786e-02,   5.70748709e-02,
                          5.79630062e-02,   6.93027750e-02,   8.65623504e-02,
                          9.49304700e-02,   1.03824757e-01,   1.13063805e-01,
                          1.15786001e-01,   1.07354276e-01,   1.00645676e-01,
                          1.03621259e-01,   1.00733809e-01,   1.00464933e-01,
                          1.08404100e-01,   1.27572089e-01,   1.46457866e-01,
                          1.55140162e-01,   1.66011900e-01,   1.62079662e-01,
                          1.48511365e-01,   1.35075301e-01,   1.14310764e-01,
                          9.46779847e-02,   8.72164890e-02,   9.98317450e-02,
                          1.16544642e-01,   1.17273323e-01,   1.07008487e-01,
                          1.05741389e-01,   1.05112828e-01,   9.43550020e-02,
                          8.26252475e-02,   7.42180720e-02,   8.46354067e-02,
                          9.29696187e-02,   8.31323341e-02,   7.14154020e-02,
                          5.81136160e-02,   5.60239144e-02,   5.37650548e-02,
                          4.90230508e-02,   6.84258193e-02,   1.08346321e-01,
                          1.53655782e-01,   1.94147930e-01,   2.29624406e-01,
                          2.61764556e-01,   2.74935991e-01,   2.60141760e-01,
                          2.39232570e-01,   2.33331695e-01,   2.56390333e-01,
                          2.98776597e-01,   3.32086205e-01,   3.48163843e-01,
                          3.44525963e-01,   3.20845991e-01,   2.84348339e-01,
                          2.51690954e-01,   2.30371386e-01,   2.15197489e-01,
                          2.08268628e-01,   2.13521689e-01,   2.34434739e-01,
                          2.54560351e-01,   2.76507646e-01,   3.09389085e-01,
                          3.34652364e-01,   3.50303680e-01,   3.54500800e-01,
                          3.60415757e-01,   3.76401812e-01,   4.02079433e-01,
                          4.29713637e-01,   4.47710454e-01,   4.65058416e-01,
                          4.70433176e-01,   4.53973085e-01,   4.23439622e-01,
                          3.99527669e-01,   3.85139376e-01,   3.72296453e-01,
                          3.77674878e-01,   3.91124278e-01,   3.95747721e-01,
                          3.88080120e-01,   3.73079211e-01,   3.69857967e-01,
                          3.61757755e-01,   3.38904321e-01,   3.13801885e-01,
                          2.97173500e-01,   2.91262776e-01,   2.90029794e-01,
                          3.03395003e-01,   3.36293638e-01,   3.77414703e-01,
                          4.06186551e-01,   4.27957714e-01,   4.54475701e-01,
                          4.64996636e-01,   4.50049549e-01,   4.23570156e-01,
                          3.95575374e-01,   3.69808704e-01,   3.41924101e-01,
                          3.26235920e-01,   3.33759665e-01,   3.46836388e-01,
                          3.71257216e-01,   3.76850903e-01,   3.21090430e-01,
                          2.46239573e-01,   1.81363314e-01,   1.51147485e-01,
                          1.72889054e-01,   2.02014238e-01,   2.21098304e-01,
                          2.16627523e-01,   1.47450909e-01,   2.68577933e-02,
                         -6.46854639e-02,  -9.27479044e-02,  -9.25833359e-02,
                         -8.98278803e-02,  -7.39037469e-02,  -5.05266041e-02,
                         -7.33545274e-02,  -1.29081398e-01,  -1.81128263e-01,
                         -2.48485669e-01,  -3.34023416e-01,  -4.12419349e-01,
                         -4.42079812e-01,  -4.37512100e-01,  -4.14687216e-01,
                         -3.77332121e-01,  -3.56027722e-01,  -3.31905574e-01,
                         -2.97325432e-01,  -2.64222503e-01,  -2.28395626e-01,
                         -2.03651220e-01,  -1.96402743e-01,  -1.88393593e-01,
                         -1.77166179e-01,  -1.69782579e-01,  -1.66353926e-01,
                         -1.74344644e-01,  -1.88052550e-01,  -2.06638381e-01,
                         -2.25433514e-01,  -2.39189774e-01,  -2.49637261e-01,
                         -2.46045992e-01,  -2.31441021e-01,  -1.99142233e-01,
                         -1.66404873e-01,  -1.44881099e-01,  -1.46847680e-01,
                         -1.72832221e-01,  -2.13781193e-01,  -2.63666064e-01,
                         -2.88237631e-01,  -2.95450360e-01,  -2.95313329e-01,
                         -2.99252748e-01,  -2.97804236e-01,  -2.98346132e-01,
                         -3.16495478e-01,  -3.32653582e-01,  -3.15985262e-01,
                         -2.79516846e-01,  -2.59425253e-01,  -2.53585726e-01,
                         -2.49425665e-01,  -2.23636776e-01,  -1.94751754e-01,
                         -1.71893492e-01,  -1.63037688e-01,  -1.80766702e-01,
                         -1.99540064e-01,  -2.05647454e-01,  -2.08132938e-01,
                         -2.12165490e-01,  -2.09145650e-01,  -1.94938704e-01,
                         -1.82465911e-01,  -1.88615948e-01,  -2.07552552e-01,
                         -2.09967911e-01,  -2.02985093e-01,  -1.92500755e-01,
                         -1.74896210e-01,  -1.59999415e-01,  -1.42172351e-01,
                         -1.36254653e-01,  -1.45835727e-01,  -1.66276827e-01,
                         -1.89041331e-01,  -1.95139229e-01,  -1.87759012e-01,
                         -1.78297997e-01,  -1.64829642e-01,  -1.59642875e-01,
                         -1.60265952e-01,  -1.58035800e-01,  -1.56535089e-01,
                         -1.51063755e-01,  -1.48275867e-01,  -1.44161001e-01,
                         -1.22719698e-01,  -9.08564106e-02,  -7.04421103e-02,
                         -6.80959076e-02,  -7.16958418e-02,  -7.10136369e-02,
                         -7.40576312e-02,  -8.34451988e-02,  -9.22515094e-02,
                         -9.51810107e-02,  -9.79184508e-02,  -1.07122712e-01,
                         -1.23062752e-01,  -1.40674114e-01,  -1.59626484e-01,
                         -1.74117491e-01,  -1.82153374e-01,  -1.63871631e-01,
                         -1.25902757e-01,  -9.08696875e-02,  -5.84737509e-02,
                         -4.14891616e-02,  -1.51768913e-02,   8.92945379e-03,
                          1.79311056e-02,   1.36648240e-02,  -5.25172520e-03,
                         -2.66567580e-02,  -4.74323705e-02,  -5.91466054e-02,
                         -6.35361671e-02,  -5.52188978e-02,  -4.86311354e-02,
                         -5.01777194e-02,  -5.85347526e-02,  -6.67136088e-02,
                         -6.26059324e-02,  -6.78114891e-02,  -8.13699588e-02,
                         -8.43894333e-02,  -7.91107267e-02,  -7.64901191e-02,
                         -8.63928720e-02,  -1.05247393e-01,  -1.08586594e-01,
                         -9.25541371e-02,  -7.53967240e-02,  -8.22883770e-02,
                         -9.36039165e-02,  -8.65610763e-02,  -8.52034837e-02,
                         -1.02797724e-01,  -1.40980959e-01,  -1.78627819e-01,
                         -2.01919451e-01,  -2.00950548e-01,  -1.82874292e-01,
                         -1.51774481e-01,  -1.14601508e-01,  -6.69433847e-02,
                         -1.65103562e-02,   1.72787942e-02,   4.13216874e-02,
                          5.72751500e-02,   7.52135664e-02,   7.53082260e-02,
                          7.16224611e-02,   6.39325902e-02,   4.89303097e-02,
                          3.89802381e-02,   2.25611795e-02,   1.51473852e-02,
                          7.31615024e-03,  -1.24091832e-02,  -4.54739481e-02,
                         -9.07979086e-02,  -1.27082616e-01,  -1.51105434e-01,
                         -1.59950495e-01,  -1.52432218e-01,  -1.26866639e-01,
                         -1.06678247e-01,  -1.10056259e-01,  -1.19898617e-01,
                         -1.25881523e-01,  -1.23983704e-01,  -1.34410590e-01,
                         -1.41889334e-01,  -1.26992181e-01,  -1.02459267e-01,
                         -8.31612572e-02,  -6.05501756e-02,  -3.72095816e-02,
                         -2.58336142e-02,  -1.72908902e-02,   3.87278618e-04,
                          3.29734087e-02,   6.24189936e-02,   7.70769045e-02,
                          1.06205404e-01,   1.40533000e-01,   1.09193936e-01,
                          5.70010655e-02,   4.06157114e-02,  -1.60813592e-02,
                         -9.46711376e-02,  -1.23417079e-01,  -1.42780393e-01,
                         -1.60227060e-01,  -1.61141992e-01,  -1.60199851e-01,
                         -1.61766931e-01,  -1.58687189e-01,  -1.60861358e-01,
                         -1.62007794e-01,  -1.54909194e-01,  -1.44303590e-01,
                         -1.31804362e-01,  -1.32239252e-01,  -1.31960079e-01,
                         -1.29861444e-01,  -1.25916019e-01,  -1.19111039e-01,
                         -1.13861360e-01,  -1.17645457e-01,  -1.37099847e-01,
                         -1.54043913e-01,  -1.60812691e-01,  -1.56624526e-01,
                         -1.44431561e-01,  -1.57588348e-01,  -1.77340716e-01,
                         -1.89934015e-01,  -1.98861107e-01,  -2.06194788e-01,
                         -2.24544615e-01,  -2.35271707e-01,  -2.40126312e-01,
                         -2.31548682e-01,  -2.02200919e-01,  -1.60347909e-01,
                         -1.31648421e-01,  -1.36800900e-01,  -1.69330746e-01,
                         -2.11673722e-01,  -2.56204158e-01,  -2.96220064e-01,
                         -3.19906354e-01,  -3.11445177e-01,  -2.70315349e-01,
                         -2.20357805e-01,  -1.78148463e-01,  -1.51663542e-01,
                         -1.53990269e-01,  -1.83293015e-01,  -2.29155943e-01,
                         -2.57902861e-01,  -2.67049581e-01,  -2.76079714e-01,
                         -2.59972602e-01,  -2.42310956e-01,  -2.29027376e-01,
                         -2.16071352e-01,  -2.16847137e-01,  -2.30980948e-01,
                         -2.46424973e-01,  -2.42813095e-01,  -2.13739038e-01,
                         -1.90219671e-01,  -1.92868859e-01,  -2.04288587e-01,
                         -2.14889199e-01,  -2.26295128e-01,  -2.42376268e-01,
                         -2.49580726e-01,  -2.37772137e-01,  -2.20063865e-01,
                         -2.17126250e-01,  -2.26607591e-01,  -2.48702317e-01,
                         -2.72031873e-01,  -2.76001990e-01,  -2.57716060e-01,
                         -2.27009729e-01,  -2.07971528e-01,  -2.00485751e-01,
                         -1.78779110e-01,  -1.62095383e-01,  -1.59462169e-01,
                         -1.72332942e-01,  -1.95423886e-01,  -2.21727982e-01,
                         -2.38508612e-01,  -2.38398582e-01,  -2.44960681e-01,
                         -2.43735731e-01,  -2.31562570e-01,  -2.05417484e-01,
                         -1.91586673e-01,  -1.90289527e-01,  -1.94165960e-01,
                         -2.05800831e-01,  -2.26991698e-01,  -2.51083702e-01,
                         -2.53798097e-01,  -2.52257735e-01,  -2.61531472e-01,
                         -2.78912365e-01,  -2.80307174e-01,  -2.82387257e-01,
                         -2.96847731e-01,  -3.10010046e-01,  -3.11900944e-01,
                         -3.00127327e-01,  -2.80250609e-01,  -2.46213406e-01,
                         -1.99761316e-01,  -1.67691290e-01,  -1.67669564e-01,
                         -1.72763214e-01,  -1.81138963e-01,  -1.95059314e-01,
                         -2.16754988e-01,  -2.30395317e-01,  -2.27786914e-01,
                         -2.32420802e-01,  -2.30335698e-01,  -2.13579640e-01,
                         -1.76167831e-01,  -1.53211877e-01,  -1.61345959e-01,
                         -1.85840353e-01,  -2.14905843e-01,  -2.42877796e-01,
                         -2.68639863e-01,  -2.79647529e-01,  -2.84354091e-01,
                         -2.97617614e-01,  -3.30891043e-01,  -3.64065021e-01,
                         -3.83925468e-01,  -3.82348061e-01,  -3.76324534e-01,
                         -3.66841525e-01,  -3.63131315e-01,  -3.65260661e-01,
                         -3.48557681e-01,  -3.21435928e-01,  -2.98997074e-01,
                         -2.94672847e-01,  -2.97611475e-01,  -3.05990130e-01,
                         -3.17701399e-01,  -3.15686673e-01,  -2.94167042e-01,
                         -2.61803269e-01,  -2.36061022e-01,  -2.17127874e-01,
                         -2.05456600e-01,  -2.17643097e-01,  -2.51530468e-01,
                         -3.06253701e-01,  -3.58939111e-01,  -3.87156099e-01,
                         -3.77442986e-01,  -3.52735400e-01,  -3.30335319e-01,
                         -3.07164907e-01,  -2.81048477e-01,  -2.73861051e-01,
                         -2.31765807e-01,  -1.47077754e-01,  -1.34952530e-01,
                         -1.08980715e-01,  -1.81745198e-02,   7.99793154e-02,
                          7.48172477e-02,  -2.85905469e-02,  -5.53981438e-02,
                         -2.10307408e-02,  -2.28236360e-03,  -2.23006643e-02,
                         -4.37777042e-02,  -4.27931547e-02,  -1.48120625e-02,
                          1.81675274e-02,  -2.45882254e-02,  -5.28274383e-03,
                          8.04144740e-02,   1.63657427e-01,   2.34186292e-01,
                          2.50336826e-01,   2.91286707e-01,   3.37536544e-01,
                          3.76731813e-01,   3.86167675e-01,   3.93801600e-01,
                          4.18825924e-01,   4.60766017e-01,   4.69777107e-01,
                          4.31710958e-01,   4.18467462e-01,   4.50944185e-01,
                          4.94125783e-01,   4.81168658e-01,   5.00273049e-01,
                          5.19042373e-01,   5.08204639e-01,   5.02517223e-01,
                          5.03766179e-01,   5.15168250e-01,   5.09107947e-01,
                          4.98777568e-01,   4.90523279e-01,   4.87229288e-01,
                          4.73021239e-01,   4.48568583e-01,   4.30848897e-01,
                          4.24549758e-01,   4.28056240e-01,   4.21481222e-01,
                          4.22502428e-01,   4.23733234e-01,   3.96653503e-01,
                          3.60230565e-01,   3.30744028e-01,   3.35363299e-01,
                          3.48886073e-01,   3.52581412e-01,   3.56373906e-01,
                          3.62021655e-01,   3.63426596e-01,   3.57744932e-01,
                          3.49728018e-01,   3.54571640e-01,   3.87366056e-01,
                          4.19199556e-01,   4.39377099e-01,   4.39819723e-01,
                          4.29139704e-01,   4.05908316e-01,   3.87768447e-01,
                          3.98417354e-01,   4.00151104e-01,   3.83296192e-01,
                          3.55987132e-01,   3.35691839e-01,   3.19906265e-01,
                          3.10646236e-01,   3.19178760e-01,   3.23973507e-01,
                          3.24224263e-01,   3.20243269e-01,   3.23269218e-01,
                          3.34151924e-01,   3.32464814e-01,   3.21118534e-01,
                          3.20189148e-01,   3.27182144e-01,   3.36818665e-01,
                          3.61552984e-01,   4.00457144e-01,   4.44705725e-01,
                          4.80892986e-01,   5.10266125e-01,   5.37558436e-01,
                          5.54856837e-01,   5.56531608e-01,   5.43509841e-01,
                          5.38736999e-01,   5.44933915e-01,   5.64930677e-01,
                          5.92942834e-01,   6.12371027e-01,   6.14643455e-01,
                          5.98660231e-01,   5.85931242e-01,   5.72684228e-01,
                          5.76811314e-01,   5.88266432e-01,   5.96946836e-01,
                          6.05159581e-01,   6.03559673e-01,   5.80182314e-01,
                          5.30714691e-01,   4.70044345e-01,   4.23248947e-01,
                          3.87293965e-01,   3.49538684e-01,   3.15481544e-01,
                          2.95506924e-01,   3.19758296e-01,   3.57624173e-01,
                          3.88622254e-01,   4.00982291e-01,   4.03165489e-01,
                          3.95993024e-01,   3.91832471e-01,   3.84006500e-01,
                          3.62194359e-01,   3.33718777e-01,   3.17636788e-01,
                          3.25750262e-01,   3.25717479e-01,   3.16011667e-01,
                          2.90374070e-01,   2.69912213e-01,   2.63450414e-01,
                          2.70470768e-01,   2.76066333e-01,   2.78191715e-01,
                          2.67562807e-01,   2.62697995e-01,   2.67304748e-01,
                          2.89103121e-01,   3.31700981e-01,   3.76119763e-01,
                          4.05235022e-01,   3.96559417e-01,   3.85815412e-01,
                          3.89570326e-01,   3.99076700e-01,   3.87540936e-01,
                          3.58525336e-01,   3.26544583e-01,   3.04894984e-01,
                          2.81973153e-01,   2.67914742e-01,   2.63014615e-01,
                          2.55499065e-01,   2.39367202e-01,   2.22938180e-01,
                          2.22270638e-01,   2.34528571e-01,   2.44923487e-01,
                          2.51405060e-01,   2.65558809e-01,   2.80985534e-01,
                          2.93778658e-01,   2.84414023e-01,   2.72181541e-01,
                          2.68419057e-01,   2.83179373e-01,   2.86592335e-01,
                          2.85852522e-01,   2.91892588e-01,   2.94314295e-01,
                          2.89355040e-01,   2.66321838e-01,   2.43427485e-01,
                          2.27328196e-01,   2.31900662e-01,   2.35332072e-01,
                          2.32364357e-01,   2.28526026e-01,   2.24361554e-01,
                          2.11421102e-01,   1.91451207e-01,   1.73582375e-01,
                          1.70041144e-01,   1.78206712e-01,   1.85975030e-01,
                          2.05616221e-01,   2.22590953e-01,   2.30575845e-01,
                          2.33026564e-01,   2.39283904e-01,   2.39630714e-01,
                          2.22992420e-01,   2.15985492e-01,   2.16949910e-01,
                          2.24496916e-01,   2.22210109e-01,   2.21358702e-01,
                          2.50187278e-01,   2.84967840e-01,   3.21504623e-01,
                          3.35454732e-01,   3.18542659e-01,   2.90630400e-01,
                          2.65498847e-01,   2.59287506e-01,   2.68510640e-01,
                          2.80579031e-01,   2.95465499e-01,   3.12919617e-01,
                          3.24697971e-01,   3.39615405e-01,   3.49012166e-01,
                          3.57825577e-01,   3.69863570e-01,   3.67613405e-01,
                          3.38910878e-01,   2.75672257e-01,   2.21671596e-01,
                          1.84230477e-01,   1.50464833e-01,   1.32924318e-01,
                          1.27797365e-01,   1.32449284e-01,   1.47375986e-01,
                          1.64267778e-01,   1.74233422e-01,   1.70634776e-01,
                          1.60492688e-01,   1.53043076e-01,   1.38007894e-01,
                          1.24719545e-01,   1.25227734e-01,   1.39448166e-01,
                          1.53954506e-01,   1.65223762e-01,   1.75471216e-01,
                          1.96136326e-01,   2.11513773e-01,   2.21186593e-01,
                          2.23749205e-01,   2.24289894e-01,   2.26468533e-01,
                          2.29530409e-01,   2.40321517e-01,   2.47315735e-01,
                          2.59505361e-01,   2.54554898e-01,   2.50730276e-01,
                          2.47811690e-01,   2.49008566e-01,   2.47639477e-01,
                          2.46607214e-01,   2.31780306e-01,   1.94085151e-01,
                          1.93050697e-01,   1.96354896e-01,   1.56091332e-01,
                          1.50697887e-01,   1.89780280e-01,   2.10037485e-01,
                          2.19817460e-01,   2.09807947e-01,   1.94848657e-01,
                          1.86074272e-01,   2.01591879e-01,   2.15617687e-01,
                          2.21756667e-01,   2.03162402e-01,   1.86137795e-01,
                          1.82044163e-01,   1.76946387e-01,   1.85708553e-01,
                          1.23913892e-01,   7.27941319e-02,   6.70566559e-02,
                          3.68420407e-02,   1.13949152e-02,  -1.26439268e-02,
                         -1.38569977e-02,   2.73434147e-02,   5.47479689e-02,
                          1.11558944e-01,   2.18796015e-01,   2.33558521e-01,
                          1.26505315e-01,   7.71040767e-02,   1.28757313e-01,
                          1.46415249e-01,   1.10845141e-01,   6.79595992e-02,
                          4.38935347e-02,   7.22837746e-02,   9.81535167e-02,
                          9.96490940e-02,   1.08005479e-01,   1.05835840e-01,
                          1.05993517e-01,   1.23947173e-01,   1.53700605e-01,
                          1.90875977e-01,   2.46481612e-01,   2.62712687e-01,
                          2.31048092e-01,   1.72668055e-01,   9.40373689e-02,
                          5.34229651e-02,   6.72297627e-02,   9.93977413e-02,
                          7.94128850e-02,   1.51427928e-02,  -3.07326075e-02,
                         -8.93530101e-02,  -1.65945530e-01,  -2.04303682e-01,
                         -1.91136599e-01,  -1.42276958e-01,  -9.89353284e-02,
                         -4.17628437e-02,   7.62268296e-03,   2.27526724e-02,
                          1.84025727e-02,   3.52094439e-03,  -3.63506493e-03,
                         -3.66745517e-02,  -8.50377008e-02,  -1.26432151e-01,
                         -1.59285471e-01,  -1.78676948e-01,  -1.77834079e-01,
                         -1.55670777e-01,  -1.38284221e-01,  -1.37333855e-01,
                         -1.32459983e-01,  -8.24019536e-02,  -3.42637524e-02,
                         -4.88723479e-02,  -5.24674207e-02,  -1.93099082e-02,
                          1.61236227e-02,   3.25899348e-02,  -5.50929736e-03,
                         -4.69028875e-02,  -4.62715253e-02,  -2.23699696e-02,
                         -7.72209140e-03,  -1.92214511e-02,  -2.86762323e-03,
                          6.11657314e-02,   1.11270264e-01,   9.29633901e-02,
                          4.23769392e-02,  -1.98246147e-02,  -5.82642145e-02,
                         -5.21900915e-02,  -6.18366152e-02,  -9.41072628e-02,
                         -1.42149165e-01,  -1.84789270e-01,  -1.95242301e-01,
                         -1.96617857e-01,  -2.06818134e-01,  -2.20767930e-01,
                         -2.67061085e-01,  -2.82041907e-01,  -2.53899127e-01,
                         -2.49724448e-01,  -2.42820486e-01,  -2.61364728e-01,
                         -3.20678204e-01,  -3.61795306e-01,  -4.02839303e-01,
                         -4.36104685e-01,  -4.22357291e-01,  -3.91556084e-01,
                         -3.30071747e-01,  -2.65051246e-01,  -2.43262693e-01,
                         -2.43366271e-01,  -2.35933810e-01,  -2.29391038e-01,
                         -2.48860374e-01,  -2.81516016e-01,  -2.89278299e-01,
                         -2.68796057e-01,  -2.59823352e-01,  -2.93778360e-01,
                         -3.42882454e-01,  -3.47553968e-01,  -3.10795426e-01,
                         -2.59825200e-01,  -1.97344497e-01,  -1.69147313e-01,
                         -1.71784282e-01,  -1.57033220e-01,  -1.54954746e-01,
                         -1.67781264e-01,  -1.86241210e-01,  -2.10053831e-01,
                         -2.32783079e-01,  -2.44684950e-01,  -2.44700149e-01,
                         -2.45054454e-01,  -2.42904380e-01,  -2.37278357e-01,
                         -2.27896973e-01,  -2.08630890e-01,  -1.98668674e-01,
                         -2.14566886e-01,  -2.44005218e-01,  -2.66884267e-01,
                         -2.77597487e-01,  -2.90908873e-01,  -2.95482308e-01,
                         -2.77414680e-01,  -2.43613124e-01,  -2.19788000e-01,
                         -1.97790816e-01,  -1.82179645e-01,  -2.00164735e-01,
                         -2.32497305e-01,  -2.50793487e-01,  -2.64699847e-01,
                         -2.66749352e-01,  -2.38102958e-01,  -1.92026243e-01,
                         -1.55203640e-01,  -1.42723843e-01,  -1.51663467e-01,
                         -1.83544889e-01,  -2.16886386e-01,  -2.29813308e-01,
                         -2.27672175e-01,  -2.23807395e-01,  -2.11393282e-01,
                         -1.86602995e-01,  -1.58149153e-01,  -1.43114939e-01,
                         -1.36435062e-01,  -1.36248991e-01,  -1.44068092e-01,
                         -1.59593895e-01,  -1.73878834e-01,  -1.62672698e-01,
                         -1.31587684e-01,  -9.49322209e-02,  -7.08199888e-02,
                         -6.38733134e-02,  -5.68216182e-02,  -4.53993157e-02,
                         -4.16095592e-02,  -4.21277992e-02,  -4.03617695e-02,
                         -4.38652150e-02,  -5.51983826e-02,  -5.81063479e-02,
                         -6.17516823e-02,  -6.46332875e-02,  -7.98690915e-02,
                         -9.78643969e-02,  -8.51544365e-02,  -7.20990747e-02,
                         -6.00226969e-02,  -3.96093428e-02,  -2.83338912e-02,
                         -2.44590044e-02,  -3.13792787e-02,  -4.73865308e-02,
                         -5.75152971e-02,  -7.56600127e-02,  -9.92008522e-02,
                         -1.13017634e-01,  -1.28871903e-01,  -1.41687572e-01,
                         -1.37389496e-01,  -1.22561730e-01,  -9.38925222e-02,
                         -8.07001144e-02,  -7.58274794e-02,  -6.60326928e-02,
                         -7.63539374e-02,  -8.79818723e-02,  -1.07164010e-01,
                         -1.44511893e-01,  -1.75197184e-01,  -2.00344071e-01,
                         -2.13711947e-01,  -2.13296056e-01,  -2.22830042e-01,
                         -2.24182189e-01,  -2.35492527e-01,  -2.60545254e-01,
                         -2.71234632e-01,  -2.72179395e-01,  -2.62623727e-01,
                         -2.42689595e-01,  -2.30899051e-01,  -2.11259559e-01,
                         -1.75921217e-01,  -1.40353635e-01,  -1.02075078e-01,
                         -8.87535438e-02,  -9.30096209e-02,  -1.05428986e-01,
                         -1.32400736e-01,  -1.72583878e-01,  -2.18443155e-01,
                         -2.56131291e-01,  -2.80016452e-01,  -2.88880765e-01,
                         -2.95885116e-01,  -2.96381354e-01,  -2.92144507e-01,
                         -2.79787272e-01,  -2.51541406e-01,  -2.30070785e-01,
                         -2.02406392e-01,  -1.70174390e-01,  -1.52778164e-01,
                         -1.30898193e-01,  -1.18328348e-01,  -1.32290184e-01,
                         -1.59226924e-01,  -1.76758304e-01,  -1.72792703e-01,
                         -1.59767374e-01,  -1.45144016e-01,  -1.29064679e-01,
                         -1.06779858e-01,  -9.20497030e-02,  -8.94955993e-02,
                         -9.81277972e-02,  -1.23204760e-01,  -1.55366123e-01,
                         -2.07460985e-01,  -2.58682162e-01,  -3.01191866e-01,
                         -3.37308019e-01,  -3.58353436e-01,  -3.79946947e-01,
                         -3.96449149e-01,  -4.12033498e-01,  -4.27487314e-01,
                         -4.17156070e-01,  -3.79033983e-01,  -3.30671191e-01,
                         -2.93033630e-01,  -2.58617252e-01,  -2.15479791e-01,
                         -1.89749941e-01,  -1.78893760e-01,  -1.71983078e-01,
                         -1.66418910e-01,  -1.78009450e-01,  -1.99037641e-01,
                         -2.09381238e-01,  -2.16591895e-01,  -2.25874543e-01,
                         -2.38168836e-01,  -2.59247780e-01,  -3.07824731e-01,
                         -3.61328542e-01,  -3.88495058e-01,  -3.92189562e-01,
                         -3.92119557e-01,  -3.97391677e-01,  -3.94906968e-01,
                         -3.87820035e-01,  -3.86217207e-01,  -3.82851124e-01,
                         -3.90598476e-01,  -4.01601553e-01,  -3.98716360e-01,
                         -3.93936157e-01,  -3.86411518e-01,  -3.79152030e-01,
                         -3.67512226e-01,  -3.54225725e-01,  -3.72702330e-01,
                         -3.98466349e-01,  -4.14513528e-01,  -4.23998117e-01,
                         -4.25186038e-01,  -4.31367904e-01,  -4.16829705e-01,
                         -3.86673778e-01,  -3.62420142e-01,  -3.58550310e-01,
                         -3.69388670e-01,  -3.89490426e-01,  -4.11118776e-01,
                         -4.21198577e-01,  -4.22007352e-01,  -4.15973455e-01,
                         -4.13913578e-01,  -4.17192072e-01,  -4.24230903e-01,
                         -4.29726481e-01,  -4.29874688e-01,  -4.38742071e-01,
                         -4.57324952e-01,  -4.59856480e-01,  -4.53895032e-01,
                         -4.44434464e-01,  -4.40091163e-01,  -4.49435383e-01,
                         -4.45496410e-01,  -4.02733326e-01,  -3.49726826e-01,
                         -3.11000288e-01,  -2.72881269e-01,  -2.48859674e-01,
                         -2.37824857e-01,  -2.17293516e-01,  -1.78689286e-01,
                         -1.20203741e-01,  -4.61396798e-02,   5.36814659e-05,
                          1.32655641e-02,   2.76390612e-02,   2.46045049e-02,
                          1.17871491e-02,   6.41060248e-02,   1.60394862e-01,
                          2.02423573e-01,   1.97176918e-01,   1.96925357e-01,
                          2.00285628e-01,   1.98479205e-01,   2.01881170e-01,
                          2.09366336e-01,   2.17353463e-01,   2.29861230e-01,
                          2.46741444e-01,   2.56042719e-01,   2.57471919e-01,
                          2.60146439e-01,   2.74013311e-01,   3.03805023e-01,
                          3.31749767e-01,   3.37599069e-01,   3.25221866e-01,
                          3.28419298e-01,   3.48157972e-01,   3.46067280e-01,
                          3.22593659e-01,   3.09952646e-01,   3.11270058e-01,
                          3.13637137e-01,   3.18656504e-01,   3.28941613e-01,
                          3.37355465e-01,   3.32311034e-01,   3.20687771e-01,
                          3.13087076e-01,   3.09578389e-01,   3.10721010e-01,
                          3.13480258e-01,   3.13194424e-01,   3.09852332e-01,
                          3.12445700e-01,   3.15702647e-01,   3.08089077e-01,
                          2.96735764e-01,   2.82851785e-01,   2.63518751e-01,
                          2.38709316e-01,   2.13586643e-01,   1.95395127e-01,
                          1.81897879e-01,   1.72682211e-01,   1.73655003e-01,
                          1.85516566e-01,   2.03159839e-01,   2.24536508e-01,
                          2.46103466e-01,   2.62732059e-01,   2.67779171e-01,
                          2.62249470e-01,   2.57501274e-01,   2.65724033e-01,
                          2.81519651e-01,   2.87010610e-01,   2.76992321e-01,
                          2.65798092e-01,   2.65396357e-01,   2.65561372e-01,
                          2.63934106e-01,   2.68637508e-01,   2.74997860e-01,
                          2.77891278e-01,   2.85342962e-01,   3.00208181e-01,
                          3.13244492e-01,   3.16924870e-01,   3.05689663e-01,
                          2.81884521e-01,   2.60891676e-01,   2.56652236e-01,
                          2.70656914e-01,   2.93224514e-01,   3.12461436e-01,
                          3.26675087e-01,   3.41042489e-01,   3.58010858e-01,
                          3.71573895e-01,   3.71243715e-01,   3.50856751e-01,
                          3.19004208e-01,   2.93579847e-01,   2.85873860e-01,
                          2.90340006e-01,   2.92601883e-01,   2.91449845e-01,
                          2.91554302e-01,   2.90139556e-01,   2.81774819e-01,
                          2.66046911e-01,   2.44446531e-01,   2.30037242e-01,
                          2.32754111e-01,   2.42992908e-01,   2.45824531e-01,
                          2.36116439e-01,   2.18568414e-01,   1.99013591e-01,
                          1.84390739e-01,   1.82096243e-01,   1.85358688e-01,
                          1.84393823e-01,   1.87896296e-01,   2.09220693e-01,
                          2.35529512e-01,   2.51480699e-01,   2.59272575e-01,
                          2.63476014e-01,   2.60444492e-01,   2.48484746e-01,
                          2.38783479e-01,   2.37166464e-01,   2.41580427e-01,
                          2.53031939e-01,   2.78618366e-01,   3.07244092e-01,
                          3.25162828e-01,   3.35647225e-01,   3.40093404e-01,
                          3.27373028e-01,   2.91793048e-01,   2.50557721e-01,
                          2.28096396e-01,   2.29189038e-01,   2.39789978e-01,
                          2.49897912e-01,   2.62776792e-01,   2.72415042e-01,
                          2.79068708e-01,   2.88958788e-01,   3.04038912e-01,
                          3.18919748e-01,   3.28908592e-01,   3.29148024e-01,
                          3.11885923e-01,   2.82328695e-01,   2.58723855e-01,
                          2.65777618e-01,   3.01455677e-01,   3.36216778e-01,
                          3.50792170e-01,   3.57351154e-01,   3.63824219e-01,
                          3.59346896e-01,   3.52806509e-01,   3.51420343e-01,
                          3.43074709e-01,   3.29018593e-01,   3.14507365e-01,
                          2.93168247e-01,   2.64106929e-01,   2.51735657e-01,
                          2.74347216e-01,   3.22173774e-01,   3.61726940e-01,
                          3.87325108e-01,   4.12344545e-01,   4.28589910e-01,
                          4.25786525e-01,   4.09752905e-01,   3.95154804e-01,
                          3.87010098e-01,   3.83828759e-01,   3.83411944e-01,
                          3.82250339e-01,   3.65135133e-01,   3.25790048e-01,
                          2.90653348e-01,   2.76275814e-01,   2.75438875e-01,
                          2.84972936e-01,   3.07044446e-01,   3.37263435e-01,
                          3.56971860e-01,   3.57390285e-01,   3.46684754e-01,
                          3.35222274e-01,   3.23323071e-01,   3.20151836e-01,
                          3.27386409e-01,   3.39878082e-01,   3.48462671e-01,
                          3.43839437e-01,   3.43358129e-01,   3.58052045e-01,
                          3.72226000e-01,   3.80857795e-01,   3.86749715e-01,
                          3.86454672e-01,   3.77259731e-01,   3.57901484e-01,
                          3.39982629e-01,   3.32082599e-01,   3.19841921e-01,
                          3.09400499e-01,   3.23416978e-01,   3.45027804e-01,
                          3.57201457e-01,   3.68038595e-01,   3.76536697e-01,
                          3.61571580e-01,   3.30986440e-01,   3.12484026e-01,
                          3.04915339e-01,   2.95065552e-01,   2.92597741e-01,
                          3.00602913e-01,   3.06802422e-01,   3.07192087e-01,
                          3.11432719e-01,   3.20720673e-01,   3.25851858e-01,
                          3.29929411e-01,   3.54859352e-01,   3.89147907e-01,
                          4.01263386e-01,   3.95598471e-01,   3.75671327e-01,
                          3.52243364e-01,   3.42626721e-01,   3.10415447e-01,
                          2.35963777e-01,   2.06976548e-01,   2.43189946e-01,
                          2.43178114e-01,   1.83584273e-01,   1.21091723e-01,
                          6.35973141e-02,   4.45870217e-03,  -3.02521884e-02,
                         -3.79192084e-02,  -5.56256399e-02,  -7.65058920e-02,
                         -9.37831178e-02,  -1.34267077e-01,  -1.84212267e-01,
                         -2.01276869e-01,  -1.99446380e-01,  -1.64149836e-01,
                         -7.94579461e-02,  -4.18680049e-02,  -9.27851871e-02,
                         -1.67072102e-01,  -2.26683900e-01,  -2.60549277e-01,
                         -2.63633221e-01,  -2.74928808e-01,  -3.04657191e-01,
                         -3.26452374e-01,  -3.43649000e-01,  -3.47390026e-01,
                         -3.26644897e-01,  -2.89945275e-01,  -2.51385003e-01,
                         -2.39783943e-01,  -2.45729253e-01,  -2.56275326e-01,
                         -2.78533161e-01,  -3.14576179e-01,  -3.36582243e-01,
                         -3.44797939e-01,  -3.40325326e-01,  -3.21410388e-01,
                         -3.12042564e-01,  -3.11276019e-01,  -3.00117046e-01,
                         -2.81140059e-01,  -2.71328509e-01,  -2.57012635e-01,
                         -2.37610191e-01,  -2.33173758e-01,  -2.37948641e-01,
                         -2.51998782e-01,  -2.71010756e-01,  -2.96489924e-01,
                         -3.19371790e-01,  -3.21248263e-01,  -3.15241754e-01,
                         -3.10207307e-01,  -3.07815284e-01,  -3.05078447e-01,
                         -3.11847210e-01,  -3.22259367e-01,  -3.35528642e-01,
                         -3.31932276e-01,  -3.17265034e-01,  -3.02806437e-01,
                         -2.90330857e-01,  -3.03464890e-01,  -3.17396581e-01,
                         -3.05640608e-01,  -2.83504397e-01,  -2.66143799e-01,
                         -2.68273503e-01,  -2.77731329e-01,  -2.86153644e-01,
                         -3.02497566e-01,  -3.23457718e-01,  -3.28529418e-01,
                         -3.28026891e-01,  -3.20659459e-01,  -3.10529828e-01,
                         -3.09170961e-01,  -2.94433385e-01,  -2.78959930e-01,
                         -2.58540034e-01,  -2.39500210e-01,  -2.32394472e-01,
                         -2.31307834e-01,  -2.31389716e-01,  -2.33751461e-01,
                         -2.29304209e-01,  -2.15209797e-01,  -2.01633975e-01,
                         -1.91506088e-01,  -1.98036879e-01,  -2.21183226e-01,
                         -2.33520955e-01,  -2.29421228e-01,  -2.05644563e-01,
                         -1.81817159e-01,  -1.56386659e-01,  -1.33268103e-01,
                         -1.29629657e-01,  -1.45849362e-01,  -1.57895252e-01,
                         -1.59611344e-01,  -1.49675161e-01,  -1.18060775e-01,
                         -1.21829897e-01,  -1.57890439e-01,  -1.65700153e-01,
                         -1.46215990e-01,  -1.26308426e-01,  -1.13212086e-01,
                         -1.06653959e-01,  -1.00400358e-01,  -9.39019620e-02,
                         -9.20161307e-02,  -1.04226790e-01,  -1.29264995e-01,
                         -1.45010337e-01,  -1.48996189e-01,  -1.57608926e-01,
                         -1.29434019e-01,  -9.15057063e-02,  -9.22031403e-02,
                         -1.15162976e-01,  -1.05983332e-01,  -4.49408740e-02,
                          1.00736413e-02,   1.93575136e-02,  -6.90495595e-03,
                         -6.04192056e-02,  -1.02497309e-01,  -9.16669965e-02,
                         -5.12004755e-02,  -1.24450764e-02,   1.20866261e-02,
                          2.89740264e-02,   5.16441055e-02,   5.47212921e-02,
                          4.21759784e-02,   4.67804968e-02,   5.93002699e-02,
                          8.03361610e-02,   9.73810181e-02,   1.02819622e-01,
                          9.66795608e-02,   1.01187937e-01,   1.36839077e-01,
                          2.10257769e-01,   3.02504033e-01,   3.56286228e-01,
                          3.54896754e-01,   3.60049784e-01,   3.60404998e-01,
                          3.14598054e-01,   2.51538724e-01,   1.99698403e-01,
                          1.74894780e-01,   1.71992660e-01,   1.55291334e-01,
                          1.67646974e-01,   2.19923973e-01,   2.50863314e-01,
                          2.62385309e-01,   2.71411151e-01,   3.03933382e-01,
                          3.55644077e-01,   3.90918702e-01,   4.15905923e-01,
                          4.47644442e-01,   4.68330204e-01,   4.69416201e-01,
                          4.56429452e-01,   4.52180535e-01,   4.61409539e-01,
                          4.68452871e-01,   4.59413052e-01,   4.21053767e-01,
                          3.62924427e-01,   3.32773894e-01,   3.29037845e-01,
                          3.41807097e-01,   3.51836979e-01,   3.72802287e-01,
                          4.18050617e-01,   4.47196275e-01,   4.61401731e-01,
                          4.67690676e-01,   4.46654916e-01,   3.94425988e-01,
                          3.31879228e-01,   2.90398091e-01,   2.72331864e-01,
                          2.34696001e-01,   2.04514667e-01,   2.35533029e-01,
                          2.65709877e-01,   2.57214516e-01,   2.54246384e-01,
                          2.64659643e-01,   2.74026811e-01,   2.87430793e-01,
                          3.36775750e-01,   3.77271026e-01,   3.67976397e-01,
                          3.18548739e-01,   2.75734633e-01,   2.58012682e-01,
                          2.67166853e-01,   2.96415955e-01,   2.89550096e-01,
                          2.42648587e-01,   2.14517578e-01,   2.12825194e-01,
                          2.04525277e-01,   2.14215428e-01,   2.27898553e-01,
                          1.77745610e-01,   1.20836280e-01,   1.07274950e-01,
                          7.92390406e-02,   2.85469554e-02,   2.49696206e-02,
                          3.62269729e-02,  -2.01669168e-02,  -1.08109139e-01,
                         -1.74767628e-01,  -1.66891530e-01,  -1.39230147e-01,
                         -1.40533328e-01,  -1.10231973e-01,  -4.54389863e-02,
                         -2.09891293e-02,  -4.32627052e-02,  -1.00940876e-01,
                         -1.81286529e-01,  -2.32742459e-01,  -2.89287090e-01,
                         -3.72930586e-01,  -4.15494621e-01,  -3.97179037e-01,
                         -3.56825262e-01,  -3.40940922e-01,  -3.14394712e-01,
                         -2.93961167e-01,  -3.08331490e-01,  -2.96241134e-01,
                         -2.77401984e-01,  -3.12775701e-01,  -3.56922001e-01,
                         -3.65484923e-01,  -3.86988163e-01,  -3.93441916e-01,
                         -3.81166488e-01,  -3.76565278e-01,  -3.79822671e-01,
                         -3.93055469e-01,  -4.11970586e-01,  -4.32380706e-01,
                         -4.43066001e-01,  -4.46499109e-01,  -4.45698380e-01,
                         -4.40175831e-01,  -4.43082064e-01,  -4.38556135e-01,
                         -4.30097580e-01,  -4.11363840e-01,  -3.93378407e-01,
                         -3.80986005e-01,  -3.77987981e-01,  -3.77331883e-01,
                         -3.79026622e-01,  -3.88356149e-01,  -3.84686440e-01,
                         -3.72973263e-01,  -3.46863180e-01,  -3.31944823e-01,
                         -3.41955990e-01,  -3.62488568e-01,  -3.84712875e-01,
                         -4.10840988e-01,  -4.43971485e-01,  -4.68974262e-01,
                         -4.72696722e-01,  -4.59599912e-01,  -4.47710007e-01,
                         -4.46464002e-01,  -4.39681262e-01,  -4.39886212e-01,
                         -4.40711081e-01,  -4.45613086e-01,  -4.45048392e-01,
                         -4.47558016e-01,  -4.56916958e-01,  -4.75582153e-01,
                         -4.99746472e-01,  -5.08502424e-01,  -5.02647340e-01,
                         -4.95103568e-01,  -4.89175081e-01,  -4.65802342e-01,
                         -4.34060425e-01,  -4.12667572e-01,  -4.05192673e-01,
                         -4.14089710e-01,  -4.19787645e-01,  -4.16412741e-01,
                         -4.22999829e-01,  -4.39847320e-01,  -4.56950396e-01,
                         -4.61114854e-01,  -4.61742759e-01,  -4.60704327e-01,
                         -4.67397779e-01,  -4.73507017e-01,  -4.87142771e-01,
                         -5.00646055e-01,  -5.09430766e-01,  -5.21231830e-01,
                         -5.35805881e-01,  -5.38580894e-01,  -5.31300962e-01,
                         -5.27256012e-01,  -5.30194998e-01,  -5.29836237e-01,
                         -5.22430301e-01,  -5.13378143e-01,  -5.09146154e-01,
                         -4.96732801e-01,  -4.90046442e-01,  -5.03199518e-01,
                         -5.20433784e-01,  -5.48284769e-01,  -5.75928628e-01,
                         -5.88351905e-01,  -5.92383862e-01,  -6.02809310e-01,
                         -6.08504593e-01,  -6.11519635e-01,  -6.16461992e-01,
                         -6.21692240e-01,  -6.16103530e-01,  -6.12405062e-01,
                         -6.20016217e-01,  -6.23450637e-01,  -6.19072139e-01,
                         -6.19201720e-01,  -6.08759224e-01,  -6.07765317e-01,
                         -6.10350609e-01,  -6.08708024e-01,  -6.08872533e-01,
                         -6.09631896e-01,  -6.10709250e-01,  -6.09125614e-01,
                         -6.03561938e-01,  -6.01535499e-01,  -6.03823364e-01,
                         -5.90502083e-01,  -5.73988795e-01,  -5.64910591e-01,
                         -5.67333698e-01,  -5.83053887e-01,  -5.92037916e-01,
                         -5.90700030e-01,  -5.85580945e-01,  -5.80185354e-01,
                         -5.81420064e-01,  -5.81268966e-01,  -5.83217740e-01,
                         -5.76233387e-01,  -5.73830783e-01,  -5.70631444e-01,
                         -5.72482407e-01,  -5.71241319e-01,  -5.68803191e-01,
                         -5.67338586e-01,  -5.64684451e-01,  -5.63417137e-01,
                         -5.60043573e-01,  -5.61221242e-01,  -5.60789466e-01,
                         -5.58280945e-01,  -5.56763768e-01,  -5.56684732e-01,
                         -5.59576511e-01,  -5.55522025e-01,  -5.53880394e-01,
                         -5.50202787e-01,  -5.50242662e-01,  -5.52144825e-01,
                         -5.48021436e-01,  -5.50323546e-01,  -5.43100715e-01,
                         -5.39188683e-01,  -5.37184238e-01,  -5.39111316e-01,
                         -5.38590074e-01,  -5.38078666e-01,  -5.15949070e-01,
                         -4.88059759e-01,  -4.75898445e-01,  -4.64078695e-01,
                         -4.58092034e-01,  -4.55195934e-01,  -4.61960703e-01,
                         -4.80350643e-01,  -4.90612328e-01,  -4.95680332e-01,
                         -4.91302073e-01,  -4.84126717e-01,  -4.65829194e-01,
                         -4.43023503e-01,  -4.23022509e-01,  -4.09908742e-01,
                         -3.95130455e-01,  -3.76949459e-01,  -3.58344972e-01,
                         -3.30542088e-01,  -3.42186987e-01,  -3.63628447e-01,
                         -3.68112236e-01,  -3.71834606e-01,  -3.67074102e-01,
                         -3.49012583e-01,  -3.39654624e-01,  -3.30954969e-01,
                         -3.30873638e-01,  -3.48467320e-01,  -3.28471124e-01,
                         -2.86888450e-01,  -2.43985236e-01,  -1.38684332e-01,
                         -2.56245434e-02,   4.72630709e-02,   9.66086537e-02,
                          1.32308155e-01,   1.66343644e-01,   2.20448032e-01,
                          2.52180874e-01,   2.50966012e-01,   2.55315214e-01,
                          2.56430745e-01,   2.64007449e-01,   2.71790415e-01,
                          2.89207458e-01,   3.15052301e-01,   3.35046768e-01,
                          3.55291396e-01,   3.79029959e-01,   3.93103033e-01,
                          3.99917901e-01,   4.17760491e-01,   4.39332694e-01,
                          4.51304704e-01,   4.61318284e-01,   4.65000600e-01,
                          4.72082525e-01,   4.76170659e-01,   4.88027155e-01,
                          4.95550811e-01,   5.00415862e-01,   5.00268161e-01,
                          4.96490389e-01,   4.91657227e-01,   4.82165396e-01,
                          4.75782543e-01,   4.69080061e-01,   4.64148492e-01,
                          4.60712373e-01,   4.67230320e-01,   4.88743335e-01,
                          5.21536529e-01,   5.53755879e-01,   5.68751991e-01,
                          5.63200593e-01,   5.43178082e-01,   5.19392133e-01,
                          4.90989476e-01,   4.41837698e-01,   4.00850177e-01,
                          3.79765540e-01,   3.71674001e-01,   3.73176783e-01,
                          3.93207669e-01,   4.11024481e-01,   4.35554206e-01,
                          4.68262851e-01,   4.99990225e-01,   5.28294027e-01,
                          5.46305239e-01,   5.53086877e-01,   5.52589536e-01,
                          5.45975447e-01,   5.44894874e-01,   5.42894065e-01,
                          5.31807899e-01,   5.20053387e-01,   5.02115965e-01,
                          4.71842676e-01,   4.41723078e-01,   4.23905849e-01,
                          4.13655758e-01,   4.08303589e-01,   4.12833661e-01,
                          4.41826552e-01,   4.79893655e-01,   5.14421940e-01,
                          5.37152052e-01,   5.56131661e-01,   5.73611736e-01,
                          5.90541005e-01,   5.98827899e-01,   5.92155695e-01,
                          5.67282856e-01,   5.47098279e-01,   5.28390169e-01,
                          5.12256563e-01,   5.01313567e-01,   4.96748477e-01,
                          5.08260190e-01,   5.37966669e-01,   5.69110215e-01,
                          5.92533350e-01,   6.07874453e-01,   6.10824108e-01,
                          6.06612265e-01,   5.99301338e-01,   5.96417665e-01,
                          5.97265780e-01,   5.99098861e-01,   6.05391920e-01,
                          6.18432403e-01,   6.37904108e-01,   6.57233357e-01,
                          6.65009260e-01,   6.74042225e-01,   6.81140304e-01,
                          6.87503278e-01,   6.82807446e-01,   6.81057870e-01,
                          6.78412199e-01,   6.69625878e-01,   6.52814567e-01,
                          6.30285382e-01,   5.99246860e-01,   5.69506764e-01,
                          5.49705267e-01,   5.39382994e-01,   5.43436170e-01,
                          5.49837351e-01,   5.57674706e-01,   5.74206173e-01,
                          5.87383330e-01,   5.99865258e-01,   6.07871652e-01,
                          6.15415692e-01,   6.18626893e-01,   6.06287777e-01,
                          5.92689157e-01,   5.86537242e-01,   5.93841851e-01,
                          6.03231132e-01,   6.12420857e-01,   6.10647321e-01,
                          6.15482628e-01,   6.16978049e-01,   6.13137841e-01,
                          5.99667966e-01,   5.75249135e-01,   5.61353385e-01,
                          5.62704027e-01,   5.70209861e-01,   5.77659726e-01,
                          5.86823106e-01,   6.02929711e-01,   6.09993339e-01,
                          6.02957308e-01,   5.89300334e-01,   5.93227148e-01,
                          6.09351754e-01,   6.23971999e-01,   6.23726130e-01,
                          6.17786169e-01,   6.17446184e-01,   6.14908695e-01,
                          6.17763877e-01,   6.07930183e-01,   5.99658549e-01,
                          6.00225747e-01,   6.03970110e-01,   5.98210990e-01,
                          5.87799251e-01,   5.74241161e-01,   5.63436925e-01,
                          5.55486023e-01,   5.36878765e-01,   5.10259390e-01,
                          4.86300081e-01,   4.76522774e-01,   4.83311564e-01,
                          4.84848857e-01,   4.96607095e-01,   5.06951928e-01,
                          5.12414277e-01,   5.19672453e-01,   5.27902424e-01,
                          5.32338560e-01,   5.34993768e-01,   5.33870459e-01,
                          5.33833861e-01,   5.42235792e-01,   5.39422393e-01,
                          5.35710633e-01,   5.22240162e-01,   5.06399333e-01,
                          4.98153299e-01,   4.89240378e-01,   4.90174830e-01,
                          5.01749992e-01,   5.14884233e-01,   5.34966946e-01,
                          5.53337038e-01,   5.62273800e-01,   5.59845090e-01,
                          5.57711542e-01,   5.51091909e-01,   5.50813675e-01,
                          5.50258458e-01,   5.52151322e-01,   5.46917081e-01,
                          5.45054615e-01,   5.47480524e-01,   5.39163470e-01,
                          5.23196757e-01,   4.99792814e-01,   4.92732406e-01,
                          5.03940701e-01,   5.15576422e-01,   5.25711060e-01,
                          5.21559894e-01,   5.03519952e-01,   4.89350498e-01,
                          4.71820503e-01,   4.61113155e-01,   4.59613979e-01,
                          4.57894206e-01,   4.67737675e-01,   4.71450210e-01,
                          4.53619063e-01,   4.41282839e-01,   4.18997496e-01,
                          3.96105200e-01,   3.62069517e-01,   3.24573696e-01,
                          2.99550742e-01,   2.82257497e-01,   2.80588567e-01,
                          3.03574532e-01,   3.11807841e-01,   2.99756229e-01,
                          2.95779377e-01,   3.03137362e-01,   3.23654592e-01,
                          3.29256266e-01,   3.29435229e-01,   3.57792050e-01,
                          3.75198513e-01,   3.65615219e-01,   3.36519927e-01,
                          2.81867743e-01,   2.24173665e-01,   1.79496571e-01,
                          1.44550100e-01,   1.13193542e-01,   7.99334571e-02,
                          2.52482966e-02,  -2.68889647e-02,  -5.38515896e-02,
                         -5.26367687e-02,  -5.00203483e-02,  -6.13180473e-02,
                         -7.53465593e-02,  -6.65149391e-02,  -7.58172572e-02,
                         -1.07821137e-01,  -1.29272476e-01,  -1.52966365e-01,
                         -1.73330083e-01,  -1.83550328e-01,  -1.99142635e-01,
                         -2.06311971e-01,  -2.08769187e-01,  -2.18496397e-01,
                         -2.29064107e-01,  -2.37830669e-01,  -2.28712648e-01,
                         -2.09042460e-01,  -1.81834504e-01,  -1.42472222e-01,
                         -1.31991506e-01,  -1.46927312e-01,  -1.51819676e-01,
                         -1.55902848e-01,  -1.73086897e-01,  -2.12733001e-01,
                         -2.75959849e-01,  -3.36656690e-01,  -3.39464426e-01,
                         -3.20604622e-01,  -3.14495534e-01,  -2.94464946e-01,
                         -2.35920325e-01,  -1.72752947e-01,  -9.75812078e-02,
                         -5.64406551e-02,  -6.11166507e-02,  -2.90537924e-02,
                          6.97884662e-03,   2.44462695e-02,   2.21960321e-02,
                          1.72833782e-02,   3.71271325e-03,  -4.05419022e-02,
                         -9.13119912e-02,  -1.21964037e-01,  -1.35949075e-01,
                         -1.99032426e-01,  -2.17789531e-01,  -1.90957487e-01,
                         -1.66692168e-01,  -9.89212170e-02,  -2.58612204e-02,
                          5.58864884e-02,   7.90055618e-02,   7.11528882e-02,
                          6.69489875e-02,   7.19019622e-02,   1.05415627e-01,
                          1.13945931e-01,   1.06540568e-01,   1.04539678e-01,
                          9.87416059e-02,   8.03674310e-02,   8.04303661e-02,
                          1.11641906e-01,   1.48099706e-01,   1.65026829e-01,
                          1.63384736e-01,   1.53508350e-01,   1.05350383e-01,
                          8.36349577e-02,   1.20481141e-01,   1.68066218e-01,
                          1.78486064e-01,   1.47355437e-01,   1.39848530e-01,
                          1.65067852e-01,   1.79068595e-01,   1.71389475e-01,
                          1.66743889e-01,   1.67060763e-01,   1.76856592e-01,
                          1.80930197e-01,   1.78689927e-01,   1.74835697e-01,
                          1.65901780e-01,   1.58171177e-01,   1.51166767e-01,
                          1.50300935e-01,   1.58005223e-01,   1.68746650e-01,
                          1.76469743e-01,   1.89802885e-01,   2.10111722e-01,
                          2.30900794e-01,   2.43677378e-01,   2.40910113e-01,
                          2.30581388e-01,   2.13937044e-01,   1.97329313e-01,
                          1.90004766e-01,   1.95394024e-01,   2.06265375e-01,
                          2.19633058e-01,   2.19738126e-01,   2.14246392e-01,
                          2.08524570e-01,   1.92154214e-01,   1.82852060e-01,
                          1.79167718e-01,   1.93119362e-01,   2.08930567e-01,
                          2.15930507e-01,   2.18524501e-01,   2.10022315e-01,
                          1.92385152e-01,   1.74283817e-01,   1.68325707e-01,
                          1.61657438e-01,   1.59257919e-01,   1.58625022e-01,
                          1.59626707e-01,   1.58840999e-01,   1.49455220e-01,
                          1.37992322e-01,   1.25469387e-01,   1.16920687e-01,
                          1.05520763e-01,   9.44448784e-02,   8.14207345e-02,
                          6.31474927e-02,   4.71965596e-02,   3.23132910e-02,
                          1.84224229e-02,   1.62696950e-02,   1.27577148e-02,
                          8.35228059e-03,   4.42740647e-03,  -9.75845475e-03,
                         -1.07523100e-02,  -3.72479670e-03,   1.87450275e-02,
                          4.29229140e-02,   7.11775050e-02,   7.68505931e-02,
                          6.58616424e-02,   1.04679056e-01,   1.11998551e-01,
                          1.02645837e-01,   8.96636769e-02,   5.12146093e-02,
                          1.47827910e-02,  -5.32584935e-02,  -1.23408526e-01,
                         -1.50722668e-01,  -1.24161422e-01,  -1.22475483e-01,
                         -1.67927042e-01,  -1.94111779e-01,  -1.95502877e-01,
                         -1.71469137e-01,  -1.50963396e-01,  -1.69676229e-01,
                         -2.05500543e-01,  -2.27691665e-01,  -2.91729957e-01,
                         -3.73585790e-01,  -3.94233584e-01,  -4.06679451e-01,
                         -4.49311763e-01,  -4.95153993e-01,  -5.42096436e-01,
                         -5.78458786e-01,  -5.65279722e-01,  -5.37637770e-01,
                         -5.14429390e-01,  -5.02814233e-01,  -5.36565304e-01,
                         -5.39637744e-01,  -5.35771549e-01,  -6.26363218e-01,
                         -7.04002261e-01,  -7.10035145e-01,  -7.18044519e-01,
                         -7.15038061e-01,  -6.94616675e-01,  -6.68674469e-01,
                         -6.33421957e-01,  -6.04330242e-01,  -5.83747268e-01,
                         -5.69216490e-01,  -5.68257332e-01,  -5.83854496e-01,
                         -6.06738865e-01,  -6.29955769e-01,  -6.43336892e-01,
                         -6.51990414e-01,  -6.62554204e-01,  -6.72797680e-01,
                         -6.79138660e-01,  -6.83717966e-01,  -6.95002675e-01,
                         -7.18213797e-01,  -7.49976575e-01,  -7.64835358e-01,
                         -7.71004617e-01,  -7.68427014e-01,  -7.50102520e-01,
                         -7.30039418e-01,  -7.06118166e-01,  -6.88486040e-01,
                         -6.76589489e-01,  -6.70925319e-01,  -6.71859860e-01,
                         -6.72809184e-01,  -6.70586824e-01,  -6.60298645e-01,
                         -6.38040841e-01,  -6.08900666e-01,  -5.88765502e-01,
                         -5.80640972e-01,  -5.87503791e-01,  -5.94377100e-01,
                         -6.01336956e-01,  -6.13831162e-01,  -6.16415560e-01,
                         -6.19776666e-01,  -6.26153171e-01,  -6.35515273e-01,
                         -6.43835247e-01,  -6.46390915e-01,  -6.52579844e-01,
                         -6.51812494e-01,  -6.43316269e-01,  -6.30364060e-01,
                         -6.13739014e-01,  -6.09012127e-01,  -6.17393732e-01,
                         -6.32570744e-01,  -6.45410299e-01,  -6.43802345e-01,
                         -6.37486637e-01,  -6.37397170e-01,  -6.40643120e-01,
                         -6.46514535e-01,  -6.50234282e-01,  -6.51710391e-01,
                         -6.50297225e-01,  -6.49404466e-01,  -6.57149494e-01,
                         -6.66587412e-01,  -6.87304199e-01,  -7.08974481e-01,
                         -7.15639949e-01,  -7.20326602e-01,  -7.17504263e-01,
                         -7.11328804e-01,  -7.04272091e-01,  -6.93158507e-01,
                         -6.87080741e-01,  -6.86022997e-01,  -6.83402300e-01,
                         -6.77395821e-01,  -6.70445800e-01,  -6.66339397e-01,
                         -6.67138040e-01,  -6.58524334e-01,  -6.42200470e-01,
                         -6.21718585e-01,  -5.96438646e-01,  -5.79192162e-01,
                         -5.72821379e-01,  -5.78475595e-01,  -5.85868955e-01,
                         -5.91827333e-01,  -5.95943809e-01,  -5.95356584e-01,
                         -5.90204060e-01,  -5.81692576e-01,  -5.85302830e-01,
                         -5.91074646e-01,  -5.88590026e-01,  -5.86884022e-01,
                         -5.86400986e-01,  -5.89355588e-01,  -5.96295595e-01,
                         -6.03066087e-01,  -6.08597636e-01,  -6.07817054e-01,
                         -6.03432477e-01,  -6.04027092e-01,  -5.99061787e-01,
                         -5.91967881e-01,  -5.91525674e-01,  -5.94145179e-01,
                         -6.01682365e-01,  -6.01280510e-01,  -5.90913177e-01,
                         -5.80781698e-01,  -5.64488769e-01,  -5.44299841e-01,
                         -5.23238003e-01,  -5.04774451e-01,  -5.01548827e-01,
                         -5.12836397e-01,  -5.30884981e-01,  -5.51978946e-01,
                         -5.78949332e-01,  -6.04660451e-01,  -6.21116221e-01,
                         -6.26676202e-01,  -6.16784453e-01,  -6.00360394e-01,
                         -5.81395328e-01,  -5.62430143e-01,  -5.45948207e-01,
                         -5.27114332e-01,  -5.08202851e-01,  -4.95567977e-01,
                         -4.89260435e-01,  -4.85547423e-01,  -4.80890095e-01,
                         -4.71849561e-01,  -4.69105572e-01,  -4.70649123e-01,
                         -4.67923194e-01,  -4.62422192e-01,  -4.54518497e-01,
                         -4.49607581e-01,  -4.41724539e-01,  -4.32495534e-01,
                         -4.30400431e-01,  -4.36232924e-01,  -4.50115800e-01,
                         -4.63231683e-01,  -4.72089052e-01,  -4.78505671e-01,
                         -4.81904387e-01,  -4.85530376e-01,  -4.90220189e-01,
                         -4.99812663e-01,  -5.15473366e-01,  -5.25369704e-01,
                         -5.23462176e-01,  -5.12176037e-01,  -4.98323411e-01,
                         -4.85881656e-01,  -4.73683357e-01,  -4.62679297e-01,
                         -4.53640848e-01,  -4.49244767e-01,  -4.46276307e-01,
                         -4.39020723e-01,  -4.25558686e-01,  -4.09242809e-01,
                         -3.95546764e-01,  -3.86183619e-01,  -3.83204460e-01,
                         -3.85016054e-01,  -3.88082296e-01,  -3.89999956e-01,
                         -3.86943370e-01,  -3.76895845e-01,  -3.65159750e-01,
                         -3.57960612e-01,  -3.52917612e-01,  -3.45281720e-01,
                         -3.31921995e-01,  -3.13053757e-01,  -2.94008553e-01,
                         -2.74847150e-01,  -2.53158182e-01,  -2.34545738e-01,
                         -2.25436509e-01,  -2.29020491e-01,  -2.41769060e-01,
                         -2.53879935e-01,  -2.67651647e-01,  -2.84287810e-01,
                         -2.84959048e-01,  -2.73301303e-01,  -2.46295422e-01,
                         -1.54285118e-01,  -7.77144358e-03,   1.20942183e-01,
                          2.02167034e-01,   2.33520582e-01,   2.46381357e-01,
                          3.00718874e-01,   3.73489767e-01,   3.94178897e-01,
                          3.71736169e-01,   3.49417388e-01,   3.38674992e-01,
                          3.50811541e-01,   3.78935486e-01,   3.94833952e-01,
                          4.04410511e-01,   4.21368092e-01,   4.41864789e-01,
                          4.61317837e-01,   4.73235458e-01,   4.76618022e-01,
                          4.66442615e-01,   4.44802552e-01,   4.30961281e-01,
                          4.25431103e-01,   4.23379868e-01,   4.32211071e-01,
                          4.52892214e-01,   4.83467042e-01,   5.16804397e-01,
                          5.44454992e-01,   5.65401256e-01,   5.74343741e-01,
                          5.68811417e-01,   5.50559461e-01,   5.20852447e-01,
                          4.92661744e-01,   4.76131320e-01,   4.70325351e-01,
                          4.76880372e-01,   4.92624402e-01,   5.14635265e-01,
                          5.36734700e-01,   5.47459781e-01,   5.50837994e-01,
                          5.47824800e-01,   5.39540648e-01,   5.35527945e-01,
                          5.33656120e-01,   5.35163701e-01,   5.36166072e-01,
                          5.31704187e-01,   5.30507147e-01,   5.29721498e-01,
                          5.30949831e-01,   5.38701057e-01,   5.46593189e-01,
                          5.58074057e-01,   5.69382310e-01,   5.75150669e-01,
                          5.81620514e-01,   5.85274220e-01,   5.86104333e-01,
                          5.87904930e-01,   5.83163559e-01,   5.74228346e-01,
                          5.64570248e-01,   5.52235544e-01,   5.45741439e-01,
                          5.40809095e-01,   5.36627710e-01,   5.46837091e-01,
                          5.69690347e-01,   6.00258172e-01,   6.16390169e-01,
                          6.04819000e-01,   5.87184966e-01,   5.63634038e-01,
                          5.40768921e-01,   5.33040166e-01,   5.29218554e-01,
                          5.29784858e-01,   5.31789303e-01,   5.30409455e-01,
                          5.27582645e-01,   5.22783220e-01,   5.25026560e-01,
                          5.28705299e-01,   5.29453397e-01,   5.30122936e-01,
                          5.30241787e-01,   5.36894560e-01,   5.43576777e-01,
                          5.55191159e-01,   5.76557457e-01,   5.96341431e-01,
                          6.19836986e-01,   6.34386122e-01,   6.33180439e-01,
                          6.33635759e-01,   6.31179750e-01,   6.27817392e-01,
                          6.27013624e-01,   6.15009069e-01,   5.96657276e-01,
                          5.81496596e-01,   5.66003025e-01,   5.55661082e-01,
                          5.57165802e-01,   5.66566765e-01,   5.78853369e-01,
                          5.85492730e-01,   5.84656477e-01,   5.82497895e-01,
                          5.76520324e-01,   5.65553546e-01,   5.52308857e-01,
                          5.39428115e-01,   5.30166447e-01,   5.25071144e-01,
                          5.20641387e-01,   5.12853026e-01,   5.06841540e-01,
                          4.98965085e-01,   4.90763575e-01,   4.96694684e-01,
                          5.09543121e-01,   5.24683297e-01,   5.34066200e-01,
                          5.35004795e-01,   5.43841183e-01,   5.49752891e-01,
                          5.53636134e-01,   5.57447791e-01,   5.53116918e-01,
                          5.53375781e-01,   5.48412740e-01,   5.41511834e-01,
                          5.38052380e-01,   5.24876893e-01,   5.15481949e-01,
                          5.09162903e-01,   5.03482163e-01,   4.99099791e-01,
                          4.86956984e-01,   4.76800561e-01,   4.66615736e-01,
                          4.54859048e-01,   4.44063008e-01,   4.29257780e-01,
                          4.18792337e-01,   4.14471388e-01,   4.16262716e-01,
                          4.18418169e-01,   4.14554805e-01,   4.11491215e-01,
                          4.08363551e-01,   4.08327907e-01,   4.11159873e-01,
                          4.14968580e-01,   4.18799400e-01,   4.15927470e-01,
                          4.12221968e-01,   4.05356139e-01,   3.99785846e-01,
                          4.04226422e-01,   4.12321210e-01,   4.25149232e-01,
                          4.36294675e-01,   4.45747048e-01,   4.52512354e-01,
                          4.44059163e-01,   4.24663097e-01,   4.01993036e-01,
                          3.82897973e-01,   3.72824878e-01,   3.76610577e-01,
                          3.89498025e-01,   4.00309205e-01,   4.12430286e-01,
                          4.19141412e-01,   4.11468357e-01,   3.91418189e-01,
                          3.63935381e-01,   3.41801465e-01,   3.27144742e-01,
                          3.19628656e-01,   3.17341179e-01,   3.07908803e-01,
                          2.96336323e-01,   2.86545604e-01,   2.75585920e-01,
                          2.74835318e-01,   2.86101162e-01,   3.07153136e-01,
                          3.28346401e-01,   3.35292399e-01,   3.33632261e-01,
                          3.25429142e-01,   3.08187068e-01,   2.83813804e-01,
                          2.55938530e-01,   2.28862092e-01,   2.12438881e-01,
                          2.05747038e-01,   2.00725958e-01,   2.07107767e-01,
                          2.13534221e-01,   2.28166357e-01,   2.51498401e-01,
                          2.70034313e-01,   2.96864569e-01,   2.54162610e-01,
                          1.58063009e-01,   9.43378955e-02,   8.58232845e-03,
                         -5.76959066e-02,  -7.66199976e-02,  -1.12152673e-01,
                         -1.54910743e-01,  -2.33081684e-01,  -3.27363849e-01,
                         -3.69891495e-01,  -3.82721096e-01,  -3.87857258e-01,
                         -3.85671347e-01,  -3.85784775e-01,  -3.88662785e-01,
                         -3.93054664e-01,  -4.00358051e-01,  -4.04643834e-01,
                         -4.04094696e-01,  -3.99176478e-01,  -3.87520224e-01,
                         -3.77007216e-01,  -3.68457556e-01,  -3.65570992e-01,
                         -3.69211048e-01,  -3.72677058e-01,  -3.79891127e-01,
                         -3.80897582e-01,  -3.75234962e-01,  -3.68305832e-01,
                         -3.57397884e-01,  -3.56015533e-01,  -3.63330632e-01,
                         -3.75149429e-01,  -3.91963184e-01,  -4.02805895e-01,
                         -4.11066055e-01,  -4.19832796e-01,  -4.25691426e-01,
                         -4.33065563e-01,  -4.42065150e-01,  -4.49800164e-01,
                         -4.60095763e-01,  -4.70859885e-01,  -4.80472267e-01,
                         -4.93750989e-01,  -5.06589413e-01,  -5.24102032e-01,
                         -5.40649891e-01,  -5.42278290e-01,  -5.34030616e-01,
                         -5.18481731e-01,  -5.04469335e-01,  -4.95748907e-01,
                         -4.89427775e-01,  -4.83905643e-01,  -4.77816850e-01,
                         -4.78138238e-01,  -4.82289404e-01,  -4.87435430e-01,
                         -4.88984495e-01,  -4.88087893e-01,  -4.84932482e-01,
                         -4.74562198e-01,  -4.66900408e-01,  -4.62026596e-01,
                         -4.68528688e-01,  -4.80704963e-01,  -4.92321849e-01,
                         -5.11301875e-01,  -5.24026036e-01,  -5.38006783e-01,
                         -5.50017834e-01,  -5.52462697e-01,  -5.50004363e-01,
                         -5.41934311e-01,  -5.36216021e-01,  -5.25500000e-01,
                         -5.10515809e-01,  -4.93737608e-01,  -4.78297800e-01,
                         -4.69076514e-01,  -4.62783933e-01,  -4.65974271e-01,
                         -4.70239371e-01,  -4.73837465e-01,  -4.78630960e-01,
                         -4.84830916e-01,  -4.91028696e-01,  -4.87243921e-01,
                         -4.78842437e-01,  -4.63603228e-01,  -4.47202265e-01,
                         -4.35635686e-01,  -4.27164018e-01,  -4.20491070e-01,
                         -4.17774051e-01,  -4.21795100e-01,  -4.22598213e-01,
                         -4.24959183e-01,  -4.22030449e-01,  -4.17131960e-01,
                         -4.19880420e-01,  -4.17401493e-01,  -4.18241829e-01,
                         -4.21230555e-01,  -4.24535960e-01,  -4.30689722e-01,
                         -4.31183964e-01,  -4.33254659e-01,  -4.33930993e-01,
                         -4.35230672e-01,  -4.45502639e-01,  -4.56453592e-01,
                         -4.60765779e-01,  -4.61180180e-01,  -4.58479345e-01,
                         -4.57732677e-01,  -4.60685730e-01,  -4.66761827e-01,
                         -4.79334086e-01,  -4.87414867e-01,  -4.95143324e-01,
                         -4.90208000e-01,  -4.71532583e-01,  -4.50831145e-01,
                         -4.26670194e-01,  -4.19425488e-01,  -4.23373312e-01,
                         -4.36128736e-01,  -4.55002129e-01,  -4.64824736e-01,
                         -4.72767591e-01,  -4.71976936e-01,  -4.68302131e-01,
                         -4.59719539e-01,  -4.53790754e-01,  -4.60742056e-01,
                         -4.64137435e-01,  -4.71522808e-01,  -4.71991390e-01,
                         -4.72011983e-01,  -4.70452964e-01,  -4.61784691e-01,
                         -4.47911590e-01,  -4.26255196e-01,  -4.12309676e-01,
                         -3.96989077e-01,  -3.86493057e-01,  -3.82589340e-01,
                         -3.78943264e-01,  -3.79993856e-01,  -3.73960137e-01,
                         -3.72685075e-01,  -3.73006612e-01,  -3.72338653e-01,
                         -3.76749724e-01,  -3.74949694e-01,  -3.72711927e-01,
                         -3.65872681e-01,  -3.63095850e-01,  -3.60432923e-01,
                         -3.59443128e-01,  -3.56576353e-01,  -3.59536946e-01,
                         -3.75630379e-01,  -3.87068599e-01,  -4.01181966e-01,
                         -4.07662570e-01,  -4.15203243e-01,  -4.24302578e-01,
                         -4.19860899e-01,  -4.16622460e-01,  -4.02864546e-01,
                         -3.87585312e-01,  -3.79314780e-01,  -3.67301345e-01,
                         -3.64024699e-01,  -3.65817517e-01,  -3.69205356e-01,
                         -3.73488873e-01,  -3.79069954e-01,  -3.50258172e-01,
                         -3.39501828e-01,  -3.58861655e-01,  -3.33383262e-01,
                         -3.28417301e-01,  -3.23139995e-01,  -2.61054397e-01,
                         -2.38958433e-01,  -2.71209449e-01,  -3.05359125e-01,
                         -3.38782728e-01,  -3.65400136e-01,  -3.81128401e-01,
                         -3.87275279e-01,  -3.94479603e-01,  -4.21009660e-01,
                         -4.42420840e-01,  -3.87376726e-01,  -2.93000549e-01,
                         -2.39427343e-01,  -2.29263827e-01,  -2.27895305e-01,
                         -2.20483616e-01,  -1.95861936e-01,  -1.60861120e-01,
                         -1.32600367e-01,  -9.82749835e-02,  -7.22606480e-02,
                         -6.00172281e-02,  -3.28895487e-02,  -1.06244057e-03,
                          3.45610529e-02,   9.05386135e-02,   1.10169895e-01,
                          1.23658374e-01,   1.70047686e-01,   1.76383153e-01,
                          1.81202829e-01,   2.22496465e-01,   2.35310972e-01,
                          2.60497570e-01,   2.82960057e-01,   2.79411346e-01,
                          2.78452158e-01,   2.54740894e-01,   2.30914190e-01,
                          2.15891391e-01,   1.89164579e-01,   1.73663259e-01,
                          1.81232736e-01,   1.99442118e-01,   2.41625175e-01,
                          2.63920754e-01,   2.61695951e-01,   2.66395271e-01,
                          2.49766469e-01,   2.36583471e-01,   2.69411922e-01,
                          3.16114306e-01,   3.54379505e-01,   3.70410651e-01,
                          3.73890609e-01,   3.62720102e-01,   3.69996995e-01,
                          3.95899355e-01,   3.92796487e-01,   3.93315583e-01,
                          3.90753806e-01,   3.87565106e-01,   3.84465784e-01,
                          3.79897058e-01,   3.82504672e-01,   3.86737317e-01,
                          3.91151637e-01,   3.89035612e-01,   3.42985541e-01,
                          2.79776365e-01,   2.58046716e-01,   2.56142765e-01,
                          2.62813389e-01,   2.85669118e-01,   2.75399148e-01,
                          2.69677550e-01,   2.59770304e-01,   2.01015174e-01,
                          1.55266970e-01,   1.23675980e-01,   1.23235352e-01,
                          1.35522768e-01,   1.50776520e-01,   1.49237677e-01,
                          8.31493437e-02,   1.21722845e-02,   9.56723094e-03,
                          3.91008966e-02,   6.38525710e-02,   6.99803233e-02,
                          4.26592305e-02,   5.61783230e-03,   3.17763258e-03,
                          4.18398194e-02,   8.54508951e-02,   9.97604728e-02,
                          1.08839482e-01,   1.17573582e-01,   1.09630339e-01,
                          1.39585763e-01,   1.58654898e-01,   1.52666956e-01,
                          1.64961889e-01,   1.83227673e-01,   1.86215743e-01,
                          2.04064220e-01,   2.14709982e-01,   2.14200884e-01,
                          2.53937006e-01,   2.56126732e-01,   1.97750062e-01,
                          1.41525164e-01,   6.55902177e-02,  -2.89880820e-02,
                         -8.28578845e-02,  -6.56080171e-02,  -4.70632501e-02,
                         -6.83811679e-02,  -6.10897169e-02,  -5.94119467e-02,
                         -6.40113950e-02,  -7.36951828e-02,  -1.01170808e-01,
                         -1.36605531e-01,  -1.61052793e-01,  -1.54589400e-01,
                         -1.29187152e-01,  -9.03049782e-02,  -7.41660595e-02,
                         -7.45419487e-02,  -8.94712135e-02,  -1.26925021e-01,
                         -1.10514358e-01,  -8.27341825e-02,  -8.77736583e-02,
                         -6.11598976e-02,  -8.10664743e-02,  -1.18117414e-01,
                         -1.15783103e-01,  -1.54632151e-01,  -1.92258582e-01,
                         -1.66578308e-01,  -1.72116846e-01,  -1.93426564e-01,
                         -1.93367541e-01,  -2.35243797e-01,  -2.64725626e-01,
                         -2.10010916e-01,  -1.38028815e-01,  -1.24041095e-01,
                         -1.45179316e-01,  -1.48699597e-01,  -1.21919818e-01,
                         -1.09395862e-01,  -1.12186179e-01,  -1.25487387e-01,
                         -1.37824938e-01,  -1.32168770e-01,  -1.27400711e-01,
                         -1.57828569e-01,  -1.93202525e-01,  -1.80666804e-01,
                         -1.60146475e-01,  -1.73461258e-01,  -1.68596223e-01,
                         -1.76898196e-01,  -1.95474178e-01,  -1.76211357e-01,
                         -1.44211978e-01,  -5.86692579e-02,   1.07116494e-02,
                          1.69586353e-02,   1.77598260e-02,   1.18760078e-03,
                         -4.14513459e-04,   1.64743811e-02,  -4.19495581e-03,
                         -1.80014931e-02,  -2.80970391e-02,  -2.74425335e-02,
                          2.61414121e-03,   2.87301652e-02,   4.56792377e-02,
                          3.11802737e-02,  -1.12018976e-02,  -1.97404511e-02,
                          1.36397714e-02,   6.16090856e-02,   8.67671818e-02,
                          5.93547411e-02,   3.87111418e-02,   4.79721017e-02,
                          6.15973808e-02,   6.06891178e-02,   6.18247390e-02,
                          7.47996569e-02,   1.00619704e-01,   1.24844663e-01,
                          1.43193260e-01,   1.56264648e-01,   1.52277365e-01,
                          1.15150452e-01,   5.20452857e-02,   4.13475111e-02,
                          9.81981009e-02,   1.28332168e-01,   1.19220339e-01,
                          1.15748137e-01,   1.13614663e-01,   1.12179041e-01,
                          1.08647697e-01,   1.15075819e-01,   1.20980531e-01,
                          1.35162413e-01,   1.45029798e-01,   1.49463117e-01,
                          1.59350023e-01,   1.66711584e-01,   1.79063886e-01,
                          1.94568291e-01,   2.08964199e-01,   2.21105039e-01,
                          2.29454458e-01,   2.32442632e-01,   2.35249519e-01,
                          2.44541287e-01,   2.57214010e-01,   2.65622854e-01,
                          2.66682982e-01,   2.53121018e-01,   2.42571384e-01,
                          2.24499881e-01,   2.06605777e-01,   1.94245934e-01,
                          1.88086718e-01,   1.86071798e-01,   1.83913469e-01,
                          1.83511168e-01,   1.85190350e-01,   1.90297663e-01,
                          1.87588483e-01,   1.84559613e-01,   1.80898353e-01,
                          1.79114267e-01,   1.81425571e-01,   1.78486228e-01,
                          1.71931401e-01,   1.68497026e-01,   1.64974287e-01,
                          1.74805656e-01,   1.85697287e-01,   1.97711706e-01,
                          2.10812151e-01,   2.20867008e-01,   2.31343359e-01,
                          2.36552477e-01,   2.37533584e-01,   2.39015147e-01,
                          2.40542382e-01,   2.44766116e-01,   2.53551871e-01,
                          2.62151182e-01,   2.78895169e-01,   2.92049587e-01,
                          3.02564472e-01,   3.09760332e-01,   3.12840402e-01,
                          3.13880473e-01,   3.14145237e-01,   3.13025951e-01,
                          3.07889074e-01,   3.00803244e-01,   2.94077873e-01,
                          2.93907613e-01,   3.05570573e-01,   3.19782645e-01,
                          3.36783558e-01,   3.47890258e-01,   3.48885357e-01,
                          3.50839615e-01,   3.42614353e-01,   3.37385476e-01,
                          3.35605025e-01,   3.38012010e-01,   3.51900190e-01,
                          3.59375358e-01,   3.59774351e-01,   3.60013574e-01,
                          3.51052403e-01,   3.43562275e-01,   3.36279899e-01,
                          3.27004433e-01,   3.25676024e-01,   3.23340863e-01,
                          3.24780583e-01,   3.32440704e-01,   3.37106466e-01,
                          3.46817106e-01,   3.58918011e-01,   3.65495563e-01,
                          3.75789076e-01,   3.81479770e-01,   3.82668436e-01,
                          3.80893141e-01,   3.73078048e-01,   3.72225136e-01,
                          3.75809401e-01,   3.77336025e-01,   3.87903750e-01,
                          4.02822822e-01,   4.17997092e-01,   4.34227556e-01,
                          4.42454308e-01,   4.50926304e-01,   4.60007221e-01,
                          4.67209667e-01,   4.78357673e-01,   4.82645184e-01,
                          4.82053995e-01,   4.80748206e-01,   4.74617332e-01,
                          4.68743533e-01,   4.57876742e-01,   4.46082652e-01,
                          4.36089367e-01,   4.19992357e-01,   4.08219248e-01,
                          3.98894012e-01,   3.93643588e-01,   3.94872755e-01,
                          3.90723437e-01,   3.90146226e-01,   3.92938107e-01,
                          3.92235637e-01,   3.92798454e-01,   3.94763470e-01,
                          3.97941321e-01,   4.04834509e-01,   4.10000414e-01,
                          4.10623938e-01,   4.09305573e-01,   4.07924950e-01,
                          4.13632691e-01,   4.26002890e-01,   4.43560362e-01,
                          4.60526735e-01,   4.70566422e-01,   4.75638986e-01,
                          4.73492593e-01,   4.66375619e-01,   4.57724303e-01,
                          4.49436784e-01,   4.40257430e-01,   4.28887635e-01,
                          4.15759146e-01,   4.05593455e-01,   3.99547786e-01,
                          3.98540318e-01,   3.99579316e-01,   3.99192750e-01,
                          4.00424898e-01,   3.99242580e-01,   3.99932951e-01,
                          3.98768663e-01,   3.95143718e-01,   3.89172107e-01,
                          3.80531132e-01,   3.74879390e-01,   3.69414449e-01,
                          3.61011386e-01,   3.51780832e-01,   3.45577508e-01,
                          3.40860635e-01,   3.37190926e-01,   3.34725916e-01,
                          3.33185136e-01,   3.33056480e-01,   3.30790609e-01,
                          3.32557291e-01,   3.36841315e-01,   3.41335714e-01,
                          3.46581846e-01,   3.45072418e-01,   3.39037806e-01,
                          3.30052078e-01,   3.28273445e-01,   3.28566760e-01,
                          3.34613025e-01,   3.42871636e-01,   3.50604028e-01,
                          3.60858411e-01,   3.61589879e-01,   3.66523474e-01,
                          3.61022860e-01,   2.92147130e-01,   2.05055669e-01,
                          1.67476058e-01,   1.29568219e-01,   7.41922110e-02,
                          2.67077032e-02,  -1.53621119e-02,  -7.79694840e-02,
                         -1.58534229e-01,  -2.12151185e-01,  -2.30210260e-01,
                         -2.64763772e-01,  -2.92088121e-01,  -2.93059826e-01,
                         -3.05635124e-01,  -3.14839125e-01,  -3.21508378e-01,
                         -3.26943070e-01,  -3.33545953e-01,  -3.41824681e-01,
                         -3.52044761e-01,  -3.55900139e-01,  -3.62606496e-01,
                         -3.62075448e-01,  -3.58639985e-01,  -3.56436521e-01,
                         -3.53793859e-01,  -3.58489156e-01,  -3.60630304e-01,
                         -3.70609075e-01,  -3.80344421e-01,  -3.91382843e-01,
                         -3.99232328e-01,  -4.05115604e-01,  -4.05905068e-01,
                         -4.07629073e-01,  -4.01758403e-01,  -3.87639940e-01,
                         -3.76608223e-01,  -3.78501832e-01,  -3.87657613e-01,
                         -3.96244228e-01,  -4.12025452e-01,  -4.24530745e-01,
                         -4.35863942e-01,  -4.41949069e-01,  -4.47870463e-01,
                         -4.52841789e-01,  -4.56430256e-01,  -4.53394353e-01,
                         -4.51102644e-01,  -4.46890950e-01,  -4.44650710e-01,
                         -4.46403533e-01,  -4.44937110e-01,  -4.55159366e-01,
                         -4.62487519e-01,  -4.66226518e-01,  -4.71437722e-01,
                         -4.77060467e-01,  -4.87004071e-01,  -4.95900244e-01,
                         -5.06950557e-01,  -5.15384257e-01,  -5.19132614e-01,
                         -5.16795814e-01,  -5.09173334e-01,  -5.01313448e-01,
                         -4.92308855e-01,  -4.89414155e-01,  -4.94095147e-01,
                         -5.10417163e-01,  -5.29169679e-01,  -5.52415729e-01,
                         -5.73296547e-01,  -5.90048015e-01,  -6.02151334e-01,
                         -6.05018914e-01,  -6.05788946e-01,  -6.02392912e-01,
                         -6.00037694e-01,  -5.97368836e-01,  -5.93511939e-01,
                         -5.87458611e-01,  -5.82303643e-01,  -5.74552178e-01,
                         -5.69010794e-01,  -5.60487211e-01,  -5.55649102e-01,
                         -5.55322826e-01,  -5.51107585e-01,  -5.48886895e-01,
                         -5.44437289e-01,  -5.39904177e-01,  -5.35750747e-01,
                         -5.37222803e-01,  -5.42770863e-01,  -5.53725898e-01,
                         -5.71241915e-01,  -5.84746063e-01,  -5.96254826e-01,
                         -6.00614905e-01,  -5.96658349e-01,  -5.94567478e-01,
                         -5.89544535e-01,  -5.83948553e-01,  -5.76647997e-01,
                         -5.71795821e-01,  -5.68361759e-01,  -5.66013038e-01,
                         -5.61934233e-01,  -5.55243611e-01,  -5.51766992e-01,
                         -5.44840276e-01,  -5.40704966e-01,  -5.36760092e-01,
                         -5.35802662e-01,  -5.38232744e-01,  -5.33924460e-01,
                         -5.33902049e-01,  -5.33898234e-01,  -5.32929242e-01,
                         -5.35843849e-01,  -5.38300157e-01,  -5.41758776e-01,
                         -5.39258122e-01,  -5.33904791e-01,  -5.21699846e-01,
                         -5.10659754e-01,  -4.99947697e-01,  -4.93970066e-01,
                         -4.93663967e-01,  -4.99511302e-01,  -5.14325082e-01,
                         -5.26374400e-01,  -5.33857942e-01,  -5.36044836e-01,
                         -5.40749192e-01,  -5.46685100e-01,  -5.58123589e-01,
                         -5.67757130e-01,  -5.77357948e-01,  -5.78637004e-01,
                         -5.73045075e-01,  -5.65344214e-01,  -5.59360921e-01,
                         -5.60851038e-01,  -5.65448880e-01,  -5.64150989e-01,
                         -5.63302279e-01,  -5.63442767e-01,  -5.58965445e-01,
                         -5.58750331e-01,  -5.51539123e-01,  -5.40763676e-01,
                         -5.28724074e-01,  -5.17907977e-01,  -5.06751180e-01,
                         -4.95561182e-01,  -4.77943212e-01,  -4.67808366e-01,
                         -4.55829740e-01,  -4.48318303e-01,  -4.42800373e-01,
                         -4.37627226e-01,  -4.37780976e-01,  -4.35036302e-01,
                         -4.38948989e-01,  -4.43827659e-01,  -4.42628920e-01,
                         -4.37738061e-01,  -4.34520960e-01,  -4.24597591e-01,
                         -4.10624743e-01,  -3.92102957e-01,  -3.79935324e-01,
                         -3.67913514e-01,  -3.67895544e-01,  -3.10764283e-01,
                         -2.40730897e-01,  -2.12501854e-01,  -2.19815239e-01,
                         -2.34898642e-01,  -2.29087606e-01,  -2.28174239e-01,
                         -2.38718450e-01,  -2.93012977e-01,  -2.73066401e-01,
                         -2.61149168e-01,  -3.07281584e-01,  -3.47486556e-01,
                         -3.40110719e-01,  -2.54381329e-01,  -2.00178429e-01,
                         -1.96926922e-01,  -1.84995577e-01,  -1.60308823e-01,
                         -1.67639673e-01,  -1.83650360e-01,  -1.84775263e-01,
                         -1.84566706e-01,  -1.95866391e-01,  -1.87089473e-01,
                         -1.46967396e-01,  -1.11767471e-01,  -8.26836079e-02,
                         -4.42621000e-02,  -4.59471531e-02,  -9.01692212e-02,
                         -1.02851883e-01,  -1.10645227e-01,  -1.34398878e-01,
                         -1.53296024e-01,  -1.67637721e-01,  -1.44738346e-01,
                         -9.73605439e-02,  -4.83050980e-02,  -1.80249494e-02,
                          7.38951657e-03,   3.13024819e-02,   5.08547388e-02,
                          8.15627649e-02,   8.54675621e-02,   7.38491192e-02,
                          7.37606809e-02,   9.22397524e-02,   1.28257319e-01,
                          1.90507710e-01,   2.27470115e-01,   2.43921295e-01,
                          2.33331978e-01,   1.76521093e-01,   1.05487742e-01,
                          8.40890706e-02,   1.45233229e-01,   2.25680515e-01,
                          2.77122110e-01,   2.66371518e-01,   2.60290563e-01,
                          2.70042956e-01,   2.81134456e-01,   2.98644394e-01,
                          3.12932938e-01,   3.31972063e-01,   3.49311024e-01,
                          3.63649935e-01,   3.72072309e-01,   3.80602509e-01,
                          3.84605974e-01,   3.79334390e-01,   3.72885942e-01,
                          3.63776475e-01,   3.55166346e-01,   3.51712972e-01,
                          3.51122826e-01,   3.55341643e-01,   3.61731529e-01,
                          3.69767249e-01,   3.76954585e-01,   3.78682256e-01,
                          3.73530090e-01,   3.64297181e-01,   3.53219807e-01,
                          3.45861077e-01,   3.35076451e-01,   3.29338521e-01,
                          3.23815614e-01,   3.19663674e-01,   3.21718693e-01,
                          3.20917338e-01,   3.25392067e-01,   3.32280368e-01,
                          3.36933523e-01,   3.45819265e-01,   3.48815411e-01,
                          3.54938626e-01,   3.59018981e-01,   3.54357928e-01,
                          3.50818962e-01,   3.35659295e-01,   3.19954813e-01,
                          3.01435143e-01,   2.83570081e-01,   2.67333925e-01,
                          2.57939070e-01,   2.54963130e-01,   2.57392794e-01,
                          2.67023534e-01,   2.82004893e-01,   2.89469779e-01,
                          2.83548743e-01,   2.75839269e-01,   2.68246472e-01,
                          2.57866353e-01,   2.46559188e-01,   2.41503954e-01,
                          2.42529824e-01,   2.50759155e-01,   2.56766647e-01,
                          2.65953422e-01,   2.73577720e-01,   2.83917308e-01,
                          2.86696553e-01,   2.88653761e-01,   2.86477417e-01,
                          2.79257566e-01,   2.81809270e-01,   2.84362346e-01,
                          2.87107348e-01,   2.91013807e-01,   2.96362698e-01,
                          3.00802469e-01,   3.04631293e-01,   3.04465085e-01,
                          3.05428088e-01,   3.06184292e-01,   3.07187200e-01,
                          3.05731088e-01,   3.04335415e-01,   3.03917706e-01,
                          3.06944489e-01,   3.04677427e-01,   2.96727449e-01,
                          2.87022501e-01,   2.75821924e-01,   2.65576690e-01,
                          2.54254758e-01,   2.45107219e-01,   2.39085928e-01,
                          2.34337643e-01,   2.26555482e-01,   2.18377963e-01,
                          2.03345895e-01,   1.88794106e-01,   1.79382026e-01,
                          1.78544074e-01,   1.81491196e-01,   1.92282170e-01,
                          2.01838911e-01,   2.16869622e-01,   2.33884066e-01,
                          2.43901744e-01,   2.48461917e-01,   2.47060344e-01,
                          2.40819141e-01,   2.33706921e-01,   2.24941552e-01,
                          2.18698367e-01,   2.15987712e-01,   2.14749947e-01,
                          2.17630938e-01,   2.25268155e-01,   2.29777545e-01,
                          2.34845027e-01,   2.47939691e-01,   2.54707456e-01,
                          2.66290963e-01,   2.68673182e-01,   2.64583170e-01,
                          2.62992352e-01,   2.57019103e-01,   2.59040117e-01,
                          2.60821313e-01,   2.59556413e-01,   2.59157717e-01,
                          2.54344255e-01,   2.45626047e-01,   2.42990956e-01,
                          2.36982435e-01,   2.36162782e-01,   2.39565179e-01,
                          2.39954159e-01,   2.43087649e-01,   2.40126088e-01,
                          2.35577703e-01,   2.35343814e-01,   2.29402497e-01,
                          2.22508147e-01,   2.17198119e-01,   2.12628797e-01,
                          2.09562898e-01,   1.97829619e-01,   1.85592070e-01,
                          1.70954451e-01,   1.61938548e-01,   1.54739544e-01,
                          1.60218149e-01,   1.40461370e-01,   3.56199518e-02,
                         -3.53179462e-02,  -4.05790322e-02,  -9.11226422e-02,
                         -1.17514648e-01,  -1.50973961e-01,  -2.15190724e-01,
                         -2.51478881e-01,  -2.60539323e-01,  -2.60473371e-01,
                         -2.42017642e-01,  -2.13575229e-01,  -2.00939119e-01,
                         -2.12184131e-01,  -2.30306759e-01,  -2.14838222e-01,
                         -1.95219010e-01,  -2.10731044e-01,  -2.45908022e-01,
                         -2.75292546e-01,  -2.64268607e-01,  -2.12192282e-01,
                         -2.07769513e-01,  -2.37763330e-01,  -2.51996011e-01,
                         -2.93477833e-01,  -3.18929881e-01,  -3.23758721e-01,
                         -3.36945534e-01,  -3.41551840e-01,  -3.40011925e-01,
                         -3.45529020e-01,  -3.48240286e-01,  -3.32316041e-01,
                         -3.48721206e-01,  -3.89599264e-01,  -3.76642168e-01,
                         -3.27320218e-01,  -3.02912116e-01,  -3.13928306e-01,
                         -3.34193826e-01,  -3.80572289e-01,  -4.15404260e-01,
                         -4.15671200e-01,  -4.20784086e-01,  -4.22485024e-01,
                         -4.25147563e-01,  -4.27959353e-01,  -4.25663531e-01,
                         -4.20803159e-01,  -4.15568978e-01,  -4.07287329e-01,
                         -4.04993951e-01,  -3.84637624e-01,  -3.88093799e-01,
                         -3.98833483e-01,  -4.05573457e-01,  -3.98293018e-01,
                         -3.84343803e-01,  -4.02407050e-01,  -4.26276088e-01,
                         -4.23080921e-01,  -4.18839484e-01,  -4.13894057e-01,
                         -4.05231237e-01,  -4.03703541e-01,  -4.03458089e-01,
                         -4.03500050e-01,  -4.00714189e-01,  -3.93827707e-01,
                         -3.87652546e-01,  -3.80135804e-01,  -3.78318936e-01,
                         -3.77126992e-01,  -3.78103614e-01,  -3.78413051e-01,
                         -3.75264525e-01,  -3.72422278e-01,  -3.58177513e-01,
                         -3.54257911e-01,  -3.72593790e-01,  -3.84277880e-01,
                         -3.75148594e-01,  -3.53736460e-01,  -3.16505045e-01,
                         -2.48329416e-01,  -2.07974330e-01,  -1.92938924e-01,
                         -1.73313841e-01,  -1.38749465e-01,  -9.99326557e-02,
                         -8.05066079e-02,  -7.75243565e-02,  -5.88810816e-02,
                         -1.27654821e-02,   3.31844948e-02,   1.04430296e-01,
                          1.58341810e-01,   1.47312433e-01,   1.38270348e-01,
                          1.24202564e-01,   9.57962424e-02,   1.05405092e-01,
                          1.30938128e-01,   1.93441883e-01,   2.36647457e-01,
                          2.26280093e-01,   1.87524825e-01,   1.59783483e-01,
                          1.50193140e-01,   1.52159616e-01,   1.58662811e-01,
                          1.75479695e-01,   1.96755394e-01,   2.09466010e-01,
                          2.33469710e-01,   2.65951902e-01,   2.77417839e-01,
                          2.83599257e-01,   2.94242650e-01,   3.12578589e-01,
                          3.46590549e-01,   3.94680589e-01,   4.18975592e-01,
                          4.14815098e-01,   4.15153265e-01,   4.18749571e-01,
                          4.18723822e-01,   4.22377437e-01,   4.28111374e-01,
                          4.35681701e-01,   4.39907879e-01,   4.41851199e-01,
                          4.45239663e-01,   4.50074822e-01,   4.49272960e-01,
                          4.48379457e-01,   4.48854417e-01,   4.50263798e-01,
                          4.47659731e-01,   4.46230531e-01,   4.40514296e-01,
                          4.41465169e-01,   4.43978071e-01,   4.47347462e-01,
                          4.47913289e-01,   4.44793314e-01,   4.42452192e-01,
                          4.40597564e-01,   4.43805575e-01,   4.51021135e-01,
                          4.59767789e-01,   4.60318208e-01,   4.60001528e-01,
                          4.59036767e-01,   4.63224083e-01,   4.58964705e-01,
                          4.56132025e-01,   4.47791874e-01,   4.45624560e-01,
                          4.42272514e-01,   4.39394534e-01,   4.38432157e-01,
                          4.35070604e-01,   4.25190479e-01,   4.14808244e-01,
                          4.01235193e-01,   3.91163737e-01,   3.83277148e-01,
                          3.81820530e-01,   3.87603581e-01,   3.92241091e-01,
                          3.97469074e-01,   4.04302180e-01,   3.77869129e-01,
                          3.51696372e-01,   3.73417407e-01,   4.08010155e-01,
                          4.12816316e-01,   4.13763583e-01,   4.19500768e-01,
                          4.20742869e-01,   4.26213950e-01,   4.06339198e-01,
                          3.43583405e-01,   2.73262054e-01,   2.42704794e-01,
                          2.49588296e-01,   2.68230587e-01,   2.70426661e-01,
                          2.34704733e-01,   1.72553584e-01,   1.16190262e-01,
                          9.78542343e-02,   1.02506623e-01,   1.21663839e-01,
                          1.35985672e-01,   1.64881945e-01,   1.78632930e-01,
                          1.59755588e-01,   1.17934197e-01,   7.28523359e-02,
                          5.85650466e-02,   2.57393885e-02,   3.02419369e-03,
                          5.00348862e-03,   1.65391236e-03,   9.65448344e-05,
                         -2.48741265e-02,  -6.90864921e-02,  -1.01869620e-01,
                         -1.41242623e-01,  -1.82003990e-01,  -2.28401914e-01,
                         -2.54655719e-01,  -2.16013134e-01,  -1.99463308e-01,
                         -2.38895446e-01,  -2.40533054e-01,  -2.34095067e-01,
                         -2.29101971e-01,  -2.27002740e-01,  -2.23849371e-01,
                         -2.25269645e-01,  -2.29387492e-01,  -2.29101047e-01,
                         -2.38785267e-01,  -2.45232627e-01,  -2.48159736e-01,
                         -2.46001095e-01,  -2.40253896e-01,  -2.33177200e-01,
                         -2.16000423e-01,  -1.94251046e-01,  -1.81174979e-01,
                         -1.74893424e-01,  -1.71781808e-01,  -1.75624862e-01,
                         -1.83287725e-01,  -1.96375504e-01,  -2.07296103e-01,
                         -2.19222292e-01,  -2.30810598e-01,  -2.40176484e-01,
                         -2.44145036e-01,  -2.47222796e-01,  -2.52811790e-01,
                         -2.51760513e-01,  -2.47984141e-01,  -2.47512683e-01,
                         -2.48768240e-01,  -2.46799439e-01,  -2.37548843e-01,
                         -2.33433783e-01,  -2.27638707e-01,  -2.23567426e-01,
                         -2.24931046e-01,  -2.25975335e-01,  -2.28543043e-01,
                         -2.29980230e-01,  -2.34385103e-01,  -2.45306417e-01,
                         -2.52672076e-01,  -2.60001093e-01,  -2.73892224e-01,
                         -2.83536971e-01,  -2.97994614e-01,  -3.08457136e-01,
                         -3.15079153e-01,  -3.18483979e-01,  -3.16467971e-01,
                         -3.12454730e-01,  -3.07543039e-01,  -3.04449230e-01,
                         -3.05114090e-01,  -3.06367517e-01,  -3.08966160e-01,
                         -3.08643132e-01,  -3.10619086e-01,  -3.08953255e-01,
                         -3.00701231e-01,  -2.94613332e-01,  -2.84355879e-01,
                         -2.75427580e-01,  -2.70742148e-01,  -2.66922146e-01,
                         -2.69293785e-01,  -2.74780184e-01,  -2.83487141e-01,
                         -2.93988556e-01,  -2.97975659e-01,  -3.02684963e-01,
                         -3.07578921e-01,  -3.09921205e-01,  -3.19514573e-01,
                         -3.23922455e-01,  -3.24027449e-01,  -3.24095905e-01,
                         -3.24397504e-01,  -3.27567607e-01,  -3.29340398e-01,
                         -3.34338158e-01,  -3.43922198e-01,  -3.53664190e-01,
                         -3.60116094e-01,  -3.64011317e-01,  -3.66846025e-01,
                         -3.70744824e-01,  -3.77506047e-01,  -3.82966250e-01,
                         -3.86261791e-01,  -3.90988767e-01,  -3.91561121e-01,
                         -3.88612688e-01,  -3.88066232e-01,  -3.82837325e-01,
                         -3.79630268e-01,  -3.78075302e-01,  -3.73660475e-01,
                         -3.74850988e-01,  -3.77926320e-01,  -3.84886146e-01,
                         -4.00527537e-01,  -4.14170563e-01,  -4.29513127e-01,
                         -4.47992772e-01,  -4.59196776e-01,  -4.72682923e-01,
                         -4.78303879e-01,  -4.74251479e-01,  -4.72865909e-01,
                         -4.68704194e-01,  -4.64132041e-01,  -4.58024979e-01,
                         -4.46467012e-01,  -4.36233431e-01,  -4.25573677e-01,
                         -4.12567973e-01,  -4.02840257e-01,  -3.92905116e-01,
                         -3.93311441e-01,  -3.93179029e-01,  -3.88028681e-01,
                         -3.90555531e-01,  -3.90962332e-01,  -3.90258223e-01,
                         -3.85178894e-01,  -3.81543696e-01,  -3.82399797e-01,
                         -3.85963857e-01,  -3.93863767e-01,  -4.07195181e-01,
                         -4.23375219e-01,  -4.37382907e-01,  -4.48635578e-01,
                         -4.60108936e-01,  -4.69132006e-01,  -4.69830573e-01,
                         -4.71381724e-01,  -4.72340524e-01,  -4.74470437e-01,
                         -4.72003579e-01,  -4.66692120e-01,  -4.58867401e-01,
                         -4.50184733e-01,  -4.47762012e-01,  -4.45893645e-01,
                         -4.52003241e-01,  -4.54387456e-01,  -4.54976827e-01,
                         -4.56145465e-01,  -4.53904063e-01,  -4.49562132e-01,
                         -4.44975883e-01,  -4.42813396e-01,  -4.37219590e-01,
                         -4.32886362e-01,  -4.30105865e-01,  -4.27150637e-01,
                         -4.23703134e-01,  -4.22604710e-01,  -4.21722293e-01,
                         -4.26636428e-01,  -4.33204770e-01,  -4.39707220e-01,
                         -4.41680461e-01,  -4.38703656e-01,  -4.37108994e-01,
                         -4.28845674e-01,  -4.24965054e-01,  -4.18030769e-01,
                         -4.12415355e-01,  -4.04634953e-01,  -4.00066495e-01,
                         -4.01784331e-01,  -3.95562917e-01,  -3.96204978e-01,
                         -3.94757181e-01,  -3.98073971e-01,  -4.09595102e-01,
                         -4.12491590e-01,  -4.17226732e-01,  -4.30572242e-01,
                         -4.38663483e-01,  -4.45433050e-01,  -4.48013186e-01,
                         -4.49850053e-01,  -4.51675087e-01,  -4.51669008e-01,
                         -4.57367688e-01,  -4.59943354e-01,  -4.64645743e-01,
                         -4.59002405e-01,  -4.59213674e-01,  -4.57739621e-01,
                         -4.48912561e-01,  -4.05390382e-01,  -2.96166450e-01,
                         -2.19983742e-01,  -1.78053454e-01,  -1.52371883e-01,
                         -1.47028133e-01,  -1.02102183e-01,  -8.01942423e-02,
                         -6.87152073e-02,   5.13098342e-03,   4.67834622e-02,
                          8.85293558e-02,   1.53280690e-01,   1.60761282e-01,
                          1.48347884e-01,   1.29739225e-01,   1.30631447e-01,
                          1.36185154e-01,   1.22059196e-01,   1.10739991e-01,
                          9.60557237e-02,   9.16111618e-02,   9.21128318e-02,
                          9.09030363e-02,   9.07951370e-02,   9.10485908e-02,
                          9.25544202e-02,   9.33463201e-02,   9.47058350e-02,
                          1.04112186e-01,   1.06120735e-01,   1.08119138e-01,
                          1.12755291e-01,   1.11171454e-01,   1.11509472e-01,
                          1.03416711e-01,   9.95755047e-02,   9.85067561e-02,
                          9.84289795e-02,   9.92408991e-02,   1.09620050e-01,
                          1.22706950e-01,   1.32382616e-01,   1.45977139e-01,
                          1.52129978e-01,   1.61852688e-01,   1.62647203e-01,
                          1.63534090e-01,   1.69315681e-01,   1.70554370e-01,
                          1.75622717e-01,   1.79884315e-01,   1.86098605e-01,
                          1.99170560e-01,   2.06826359e-01,   2.12502211e-01,
                          2.18797639e-01,   2.20770478e-01,   2.29600236e-01,
                          2.26669326e-01,   2.28039846e-01,   2.28677407e-01,
                          2.21285164e-01,   2.21685112e-01,   2.17622682e-01,
                          2.18564779e-01,   2.13846609e-01,   2.08384991e-01,
                          2.07294837e-01,   2.02967644e-01,   2.01401219e-01,
                          2.10239157e-01,   2.20079288e-01,   2.27449372e-01,
                          2.35079199e-01,   2.38923430e-01,   2.48212337e-01,
                          2.56419152e-01,   2.61312902e-01,   2.64298022e-01,
                          2.65542060e-01,   2.60920882e-01,   2.54767895e-01,
                          2.45075420e-01,   2.38027304e-01,   2.33468100e-01,
                          2.29604185e-01,   2.34559894e-01,   2.31967404e-01,
                          2.38294989e-01,   2.46538222e-01,   2.56176054e-01,
                          2.70948797e-01,   2.79441208e-01,   2.91530579e-01,
                          2.99983978e-01,   3.02885652e-01,   3.00358653e-01,
                          2.96258062e-01,   2.92042136e-01,   2.90709585e-01,
                          2.92397738e-01,   2.92738080e-01,   2.94405133e-01,
                          2.98777342e-01,   3.00312132e-01,   3.11639071e-01,
                          3.24787050e-01,   3.29150915e-01,   3.37047726e-01,
                          3.32473367e-01,   3.32850784e-01,   3.33463222e-01,
                          3.30119193e-01,   3.36583674e-01,   3.39219660e-01,
                          3.39563906e-01,   3.35920155e-01,   3.33398759e-01,
                          3.28160971e-01,   3.20367426e-01,   3.12433541e-01,
                          3.03461313e-01,   2.96807110e-01,   2.90985793e-01,
                          2.85468698e-01,   2.78617710e-01,   2.72042572e-01,
                          2.65827328e-01,   2.57683575e-01,   2.52395034e-01,
                          2.49766693e-01,   2.44744986e-01,   2.46346116e-01,
                          2.49090284e-01,   2.58200407e-01,   2.69845992e-01,
                          2.79562443e-01,   2.96090275e-01,   3.05780053e-01,
                          3.16099167e-01,   3.30605060e-01,   3.43254238e-01,
                          3.53364974e-01,   3.65249574e-01,   3.74130875e-01,
                          3.81004035e-01,   3.93418491e-01,   4.03926879e-01,
                          4.07592237e-01,   4.01414186e-01,   3.96761835e-01,
                          3.91455084e-01,   3.86297852e-01,   3.82730126e-01,
                          3.83178055e-01,   3.91140342e-01,   3.97852808e-01,
                          4.14169282e-01,   4.28830594e-01,   4.38474745e-01,
                          4.50145125e-01,   4.53436375e-01,   4.55729038e-01,
                          4.55140084e-01,   4.50525820e-01,   4.45382506e-01,
                          4.39756632e-01,   4.40200567e-01,   4.37647849e-01,
                          4.39573139e-01,   4.48284924e-01,   4.54894513e-01,
                          4.67253894e-01,   4.74631816e-01,   4.79344308e-01,
                          4.85488445e-01,   4.89498079e-01,   4.89689976e-01,
                          4.86034244e-01,   4.83630031e-01,   4.79361564e-01,
                          4.76934224e-01,   4.75983888e-01,   4.79292035e-01,
                          4.83006030e-01,   4.88096297e-01,   4.89075243e-01,
                          4.89685386e-01,   5.03997743e-01,   5.10755599e-01,
                          5.22975266e-01,   5.34740806e-01,   5.33906639e-01,
                          5.36252260e-01,   5.29058516e-01,   5.19841135e-01,
                          5.14473021e-01,   5.12071729e-01,   5.06685436e-01,
                          5.01874626e-01,   5.01432359e-01,   4.91845101e-01,
                          4.90058124e-01,   4.91995454e-01,   4.94814783e-01,
                          4.99998540e-01,   5.04638612e-01,   5.20723403e-01,
                          5.31559825e-01,   5.41098118e-01,   5.47313750e-01,
                          5.47716856e-01,   5.47017336e-01,   5.39684534e-01,
                          5.40048242e-01,   5.34229398e-01,   5.31644166e-01,
                          5.26528835e-01,   5.20916522e-01,   5.19058108e-01,
                          4.62751538e-01,   4.02849704e-01,   3.68229657e-01,
                          3.24136257e-01,   2.88520873e-01,   2.69591510e-01,
                          2.71730691e-01,   2.46294677e-01,   1.86861336e-01,
                          1.47844136e-01,   1.19506985e-01,   8.29998404e-02,
                          4.75632772e-02,   1.36026423e-02,   2.02796143e-03,
                          3.61807756e-02,   5.89736700e-02,   6.14241138e-02,
                          6.45217597e-02,   3.10653411e-02,  -1.62270144e-02,
                         -5.94120771e-02,  -9.09486786e-02,  -9.73153859e-02,
                         -1.06475398e-01,  -1.14125550e-01,  -1.16117194e-01,
                         -1.20425709e-01,  -1.24615498e-01,  -1.25022918e-01,
                         -1.19460776e-01,  -1.19235322e-01,  -1.13760017e-01,
                         -1.05086282e-01,  -1.03847869e-01,  -1.00915365e-01,
                         -1.01772889e-01,  -1.03729688e-01,  -1.03535414e-01,
                         -1.07879363e-01,  -1.13495007e-01,  -1.19809397e-01,
                         -1.26972005e-01,  -1.30477354e-01,  -1.37421086e-01,
                         -1.47221386e-01,  -1.55333921e-01,  -1.64206460e-01,
                         -1.68489248e-01,  -1.75380811e-01,  -1.85255185e-01,
                         -1.92903832e-01,  -1.99966148e-01,  -2.03538552e-01,
                         -2.05227792e-01,  -2.04253301e-01,  -2.02512309e-01,
                         -2.03619376e-01,  -2.08177060e-01,  -2.12815478e-01,
                         -2.20487177e-01,  -2.28662372e-01,  -2.27659047e-01,
                         -2.26875886e-01,  -2.27527753e-01,  -2.25590631e-01,
                         -2.24988773e-01,  -2.28114516e-01,  -2.31737569e-01,
                         -2.30103523e-01,  -2.27018431e-01,  -2.22482279e-01,
                         -2.16462478e-01,  -2.04686344e-01,  -1.92916200e-01,
                         -1.89312771e-01,  -1.83532283e-01,  -1.83441520e-01,
                         -1.81882545e-01,  -1.76109090e-01,  -1.76973999e-01,
                         -1.68442503e-01,  -1.59659296e-01,  -1.55539140e-01,
                         -1.48368448e-01,  -1.42877087e-01,  -1.37194633e-01,
                         -1.34047791e-01,  -1.32506549e-01,  -1.32911131e-01,
                         -1.33222371e-01,  -1.32559523e-01,  -1.34379968e-01,
                         -1.35435700e-01,  -1.41668364e-01,  -1.56058863e-01,
                         -1.70694262e-01,  -1.81531280e-01,  -1.89759359e-01,
                         -1.98798761e-01,  -2.08102956e-01,  -2.13433325e-01,
                         -2.18863934e-01,  -2.22668484e-01,  -2.20693111e-01,
                         -2.20782220e-01,  -2.18742430e-01,  -2.14496940e-01,
                         -2.13713437e-01,  -2.13283449e-01,  -2.16855884e-01,
                         -2.18909130e-01,  -2.17799470e-01,  -2.24345148e-01,
                         -2.30026066e-01,  -2.28278503e-01,  -2.30983853e-01,
                         -2.36393958e-01,  -2.46527910e-01,  -2.57119745e-01,
                         -2.56602496e-01,  -2.62344986e-01,  -2.62540698e-01,
                         -2.55665809e-01,  -2.54055470e-01,  -2.43881211e-01,
                         -2.42844552e-01,  -2.46523812e-01,  -2.48900324e-01,
                         -2.51805842e-01,  -2.54629344e-01,  -2.49526888e-01,
                         -2.12477088e-01,  -1.85015202e-01,  -1.27597392e-01,
                         -4.86315489e-02,  -6.03193156e-02,  -8.25465620e-02,
                         -9.33364406e-02,  -1.25824600e-01,  -1.08657695e-01,
                         -9.02548134e-02,  -9.21369269e-02,  -4.82649729e-02,
                         -7.35140825e-03,  -2.22153366e-02,  -2.54464634e-02,
                          8.31761118e-03,   2.40842663e-02,   1.74427740e-02,
                          1.07492842e-02,   1.36554595e-02,   4.10460755e-02,
                          1.14508420e-01,   2.02669412e-01,   2.45460659e-01,
                          2.48944744e-01,   2.58016348e-01,   3.16242397e-01,
                          3.83111209e-01,   3.92280668e-01,   3.78502518e-01,
                          3.68067682e-01,   3.50075603e-01,   3.32437307e-01,
                          3.19245398e-01,   3.10919762e-01,   3.06166470e-01,
                          2.97871560e-01,   2.89212972e-01,   2.84646124e-01,
                          2.81251073e-01,   2.81837195e-01,   2.83821225e-01,
                          2.90399939e-01,   2.98094273e-01,   3.02580595e-01,
                          3.14810395e-01,   3.20349306e-01,   3.20151299e-01,
                          3.23586881e-01,   3.19947571e-01,   3.13157260e-01,
                          3.04390103e-01,   2.96844482e-01,   2.93689817e-01,
                          2.97642171e-01,   3.06270391e-01,   3.09844702e-01,
                          3.15599650e-01,   3.18366945e-01,   3.14190090e-01,
                          3.07198554e-01,   2.93823957e-01,   2.84807682e-01,
                          2.81763375e-01,   2.77072608e-01,   2.73406923e-01,
                          2.70003915e-01,   2.65556812e-01,   2.62964606e-01,
                          2.61240095e-01,   2.58816242e-01,   2.61415035e-01,
                          2.71026760e-01,   2.82420099e-01,   2.90058583e-01,
                          2.91641623e-01,   2.93039382e-01,   2.93020189e-01,
                          2.83650815e-01,   2.70850629e-01,   2.57890940e-01,
                          2.46717423e-01,   2.42608204e-01,   2.35920876e-01,
                          2.26753592e-01,   2.21763909e-01,   2.16494769e-01,
                          2.12867111e-01,   2.14138806e-01,   2.16264293e-01,
                          2.17300624e-01,   2.23879457e-01,   2.29571745e-01,
                          2.24120125e-01,   2.13152245e-01,   1.99583441e-01,
                          1.88019231e-01,   1.78260028e-01,   1.69099823e-01,
                          1.63639486e-01,   1.55503660e-01,   1.45080015e-01,
                          1.35562524e-01,   1.27669498e-01,   1.19808272e-01,
                          1.15852997e-01,   1.17344193e-01,   1.14454992e-01,
                          1.16413862e-01,   1.18758179e-01,   1.17437467e-01,
                          1.22577131e-01,   1.05049342e-01,   6.64839670e-02,
                          4.76540104e-02,   4.63962816e-02,   3.16931680e-02,
                          7.14219594e-03,   4.76575457e-03,   1.85302217e-02,
                          3.81762534e-02,   3.17739099e-02,  -2.17118710e-02,
                         -6.05437532e-02,  -1.08648762e-01,  -1.79303110e-01,
                         -2.01004967e-01,  -2.20183089e-01,  -2.44861752e-01,
                         -2.50199258e-01,  -2.83844590e-01,  -2.99562216e-01,
                         -2.79119730e-01,  -2.85197228e-01,  -3.36392462e-01,
                         -4.20006573e-01,  -4.82682079e-01,  -4.97476757e-01,
                         -4.96239394e-01,  -5.04771948e-01,  -5.17865121e-01,
                         -5.20286381e-01,  -5.25341570e-01,  -5.28258741e-01,
                         -5.21942258e-01,  -5.22195458e-01,  -5.20928442e-01,
                         -5.21068096e-01,  -5.20254850e-01,  -5.14057934e-01,
                         -5.19182324e-01,  -5.22452891e-01,  -5.21667063e-01,
                         -5.23128927e-01,  -5.18353939e-01,  -5.18111765e-01,
                         -5.21586478e-01,  -5.25482893e-01,  -5.30095935e-01,
                         -5.28786182e-01,  -5.29520273e-01,  -5.29742479e-01,
                         -5.26063681e-01,  -5.24784684e-01,  -5.22533834e-01,
                         -5.22685468e-01,  -5.24875224e-01,  -5.26706040e-01,
                         -5.33791721e-01,  -5.39385736e-01,  -5.43598056e-01,
                         -5.53076625e-01,  -5.57267785e-01,  -5.56645572e-01,
                         -5.59541523e-01,  -5.57380140e-01,  -5.48880339e-01,
                         -5.40186882e-01,  -5.29149830e-01,  -5.17730772e-01,
                         -5.09084046e-01,  -5.01928389e-01,  -4.96542990e-01,
                         -4.92004335e-01,  -4.89254326e-01,  -4.93122876e-01,
                         -5.01447856e-01,  -5.08170307e-01,  -5.15090227e-01,
                         -5.20953834e-01,  -5.21716535e-01,  -5.21266520e-01,
                         -5.17774343e-01,  -5.09494960e-01,  -5.03605306e-01,
                         -5.00600815e-01,  -4.97812718e-01,  -4.95412201e-01,
                         -4.92858291e-01,  -4.90760177e-01,  -4.88097876e-01,
                         -4.83038187e-01,  -4.75952297e-01,  -4.67194825e-01,
                         -4.59566087e-01,  -4.56271350e-01,  -4.51594532e-01,
                         -4.44424510e-01,  -4.42547143e-01,  -4.42649126e-01,
                         -4.43850458e-01,  -4.50392693e-01,  -4.55869943e-01,
                         -4.61049169e-01,  -4.70097363e-01,  -4.78786230e-01,
                         -4.85504031e-01,  -4.89981383e-01,  -4.91761744e-01,
                         -4.87753510e-01,  -4.78771150e-01,  -4.73080546e-01,
                         -4.69663024e-01,  -4.67213124e-01,  -4.68204439e-01,
                         -4.69822258e-01,  -4.73579317e-01,  -4.77879882e-01,
                         -4.76419240e-01,  -4.71372753e-01,  -4.67361599e-01,
                         -4.66643870e-01,  -4.66570318e-01,  -4.64159518e-01,
                         -4.60118264e-01,  -4.51147795e-01,  -4.40089762e-01,
                         -4.33090597e-01,  -4.28387344e-01,  -4.29800987e-01,
                         -4.36485261e-01,  -4.41250324e-01,  -4.47555870e-01,
                         -4.52868760e-01,  -4.53703612e-01,  -4.56958085e-01,
                         -4.63186115e-01,  -4.69327420e-01,  -4.72169280e-01,
                         -4.70830619e-01,  -4.69789386e-01,  -4.69680279e-01,
                         -4.68949437e-01,  -4.66120303e-01,  -4.64844406e-01,
                         -4.67626899e-01,  -4.68418896e-01,  -4.70394939e-01,
                         -4.72793579e-01,  -4.69068468e-01,  -4.63885725e-01,
                         -4.54592139e-01,  -4.40691859e-01,  -4.27694023e-01,
                         -4.15672868e-01,  -4.09908503e-01,  -4.04929429e-01,
                         -3.95643204e-01,  -3.88847798e-01,  -3.80883038e-01,
                         -3.72941315e-01,  -3.66167516e-01,  -3.56240094e-01,
                         -3.50079000e-01,  -3.45415860e-01,  -3.37239087e-01,
                         -3.31298202e-01,  -3.29906940e-01,  -3.33479851e-01,
                         -3.41024250e-01,  -3.52365643e-01,  -3.66823375e-01,
                         -3.79550695e-01,  -3.87739927e-01,  -3.89082938e-01,
                         -3.84569526e-01,  -3.77505362e-01,  -3.72004330e-01,
                         -3.68822545e-01,  -3.62913668e-01,  -3.59174788e-01,
                         -3.57456177e-01,  -3.52310866e-01,  -3.50168437e-01,
                         -3.41951907e-01,  -3.22523743e-01,  -3.06314647e-01,
                         -2.94802487e-01,  -2.90196836e-01,  -2.90547162e-01,
                         -2.87228554e-01,  -2.87731498e-01,  -2.89490491e-01,
                         -2.85000592e-01,  -2.79055178e-01,  -2.68262833e-01,
                         -2.53151804e-01,  -2.39246443e-01,  -2.22507522e-01,
                         -2.07649857e-01,  -2.00467244e-01,  -1.93340674e-01,
                         -1.87297195e-01,  -1.86959371e-01,  -1.84988812e-01,
                         -1.80299744e-01,  -1.76941067e-01,  -1.75304458e-01,
                         -1.73542038e-01,  -1.70629278e-01,  -1.75806239e-01,
                         -1.77223042e-01,  -1.48397446e-01,  -9.89701822e-02,
                         -3.08337416e-02,   5.34941070e-02,   1.05368771e-01,
                          1.22293763e-01,   1.41151950e-01,   1.60892755e-01,
                          1.96104825e-01,   2.53116846e-01,   3.03362221e-01,
                          3.63100260e-01,   4.31885868e-01,   4.56058979e-01,
                          4.45757359e-01,   4.42905754e-01,   4.42802578e-01,
                          4.43698049e-01,   4.49316084e-01,   4.51615721e-01,
                          4.55595255e-01,   4.62790996e-01,   4.68102336e-01,
                          4.73624080e-01,   4.77369606e-01,   4.78660345e-01,
                          4.78728056e-01,   4.76914197e-01,   4.78225201e-01,
                          4.78991508e-01,   4.74719048e-01,   4.74038124e-01,
                          4.74439353e-01,   4.72227246e-01,   4.75574791e-01,
                          4.80305582e-01,   4.82430458e-01,   4.88284171e-01,
                          4.95738328e-01,   5.02572715e-01,   5.10554612e-01,
                          5.19035161e-01,   5.28722286e-01,   5.37640631e-01,
                          5.43029845e-01,   5.45331836e-01,   5.44759333e-01,
                          5.42614758e-01,   5.39412498e-01,   5.35683572e-01,
                          5.34489870e-01,   5.34690678e-01,   5.35942495e-01,
                          5.40949821e-01,   5.45519054e-01,   5.47891736e-01,
                          5.51866829e-01,   5.53619385e-01,   5.53038418e-01,
                          5.54829240e-01,   5.53919315e-01,   5.49638808e-01,
                          5.47383368e-01,   5.43585300e-01,   5.38502872e-01,
                          5.37791967e-01,   5.38151145e-01,   5.36746919e-01,
                          5.38087070e-01,   5.43063402e-01,   5.47826588e-01,
                          5.51807165e-01,   5.57400048e-01,   5.66888094e-01,
                          5.80184877e-01,   5.92756152e-01,   6.03133500e-01,
                          6.14492297e-01,   6.24649644e-01,   6.29599631e-01,
                          6.29512727e-01,   6.26924396e-01,   6.26728773e-01,
                          6.26714706e-01,   6.22182608e-01,   6.20133698e-01,
                          6.21062338e-01,   6.17088437e-01,   6.10993028e-01,
                          6.01965964e-01,   5.88170767e-01,   5.76992691e-01,
                          5.63625932e-01,   5.43821454e-01,   5.27121544e-01,
                          5.14407933e-01,   5.07662058e-01,   5.09810805e-01,
                          5.10321856e-01,   5.10423779e-01,   5.15870750e-01,
                          5.21067381e-01,   5.32029629e-01,   5.48144877e-01,
                          5.57346880e-01,   5.68419456e-01,   5.83859980e-01,
                          5.92452705e-01,   6.00351810e-01,   6.09081566e-01,
                          6.12950861e-01,   6.18199646e-01,   6.24064863e-01,
                          6.26298189e-01,   6.27368987e-01,   6.28100812e-01,
                          6.33127749e-01,   6.39847279e-01,   6.37896657e-01,
                          6.31643832e-01,   6.25763714e-01,   6.18130982e-01,
                          6.12316251e-01,   6.05636239e-01,   5.97039759e-01,
                          5.95343113e-01,   5.98349214e-01,   6.00009978e-01,
                          6.02487087e-01,   6.07383490e-01,   6.15012765e-01,
                          6.21734679e-01,   6.25969410e-01,   6.31757617e-01,
                          6.33170485e-01,   6.27866566e-01,   6.24597967e-01,
                          6.19547904e-01,   6.10164881e-01,   6.04672432e-01,
                          6.01159096e-01,   5.99162161e-01,   6.02100492e-01,
                          6.02712929e-01,   6.01126313e-01,   6.02935433e-01,
                          6.03464246e-01,   6.04729414e-01,   6.11427248e-01,
                          6.15953624e-01,   6.15597486e-01,   6.15736306e-01,
                          6.14721835e-01,   6.09776855e-01,   6.03921890e-01,
                          5.99096417e-01,   5.94948292e-01,   5.92135608e-01,
                          5.89338720e-01,   5.84026098e-01,   5.77174544e-01,
                          5.69192588e-01,   5.58867753e-01,   5.48960388e-01,
                          5.41193545e-01,   5.33648431e-01,   5.26694477e-01,
                          5.20087183e-01,   5.12247741e-01,   5.05180538e-01,
                          5.00605106e-01,   4.98084664e-01,   4.97602075e-01,
                          4.97369081e-01,   4.96038854e-01,   4.95226294e-01,
                          4.94591177e-01,   4.91925299e-01,   4.87039000e-01,
                          4.80597228e-01,   4.73947138e-01,   4.70470995e-01,
                          4.70187336e-01,   4.68728095e-01,   4.65379864e-01,
                          4.62747365e-01,   4.60648000e-01,   4.58560377e-01,
                          4.57075834e-01,   4.56784070e-01,   4.58919406e-01,
                          4.62004721e-01,   4.62592870e-01,   4.60541189e-01,
                          4.56305057e-01,   4.49939996e-01,   4.42442983e-01,
                          4.33395773e-01,   4.24128205e-01,   4.17090118e-01,
                          4.10858005e-01,   4.03696835e-01,   3.95666301e-01,
                          3.89202923e-01,   3.88241827e-01,   3.89845610e-01,
                          3.91404003e-01,   3.97273183e-01,   4.03367639e-01,
                          4.04463500e-01,   4.05803353e-01,   4.06508833e-01,
                          4.04729098e-01,   4.06887263e-01,   4.09401953e-01,
                          4.06050146e-01,   4.01386708e-01,   3.97748590e-01,
                          3.93084228e-01,   3.84562820e-01,   3.71263444e-01,
                          3.58720809e-01,   3.46085072e-01,   3.30799758e-01,
                          3.21285367e-01,   3.18922192e-01,   3.19634199e-01,
                          3.23509663e-01,   3.23790103e-01,   3.21380436e-01,
                          3.21859390e-01,   3.17563325e-01,   3.13517183e-01,
                          3.11128318e-01,   2.88046032e-01,   2.53118694e-01,
                          2.34175548e-01,   2.36807972e-01,   2.63677210e-01,
                          2.73105294e-01,   2.04284564e-01,   1.02465332e-01,
                          4.15359028e-02,   1.09753823e-02,  -1.18173836e-02,
                         -5.67199551e-02,  -1.54420629e-01,  -2.42116868e-01,
                         -2.75581688e-01,  -3.21002215e-01,  -3.86986852e-01,
                         -4.15135056e-01,  -4.18907464e-01,  -4.27211910e-01,
                         -4.29934204e-01,  -4.30527419e-01,  -4.34373111e-01,
                         -4.37025279e-01,  -4.40909296e-01,  -4.42069530e-01,
                         -4.39808041e-01,  -4.39128488e-01,  -4.34244096e-01,
                         -4.27902609e-01,  -4.27626073e-01,  -4.27068502e-01,
                         -4.26894158e-01,  -4.30051237e-01,  -4.28715169e-01,
                         -4.25999224e-01,  -4.27976251e-01,  -4.29524660e-01,
                         -4.32286322e-01,  -4.38552856e-01,  -4.42157060e-01,
                         -4.43268150e-01,  -4.44654197e-01,  -4.44818050e-01,
                         -4.45105553e-01,  -4.46614295e-01,  -4.49137360e-01,
                         -4.53223586e-01,  -4.57458824e-01,  -4.61047053e-01,
                         -4.63247478e-01,  -4.63405013e-01,  -4.65181857e-01,
                         -4.67660427e-01,  -4.66938108e-01,  -4.66818720e-01,
                         -4.67126042e-01,  -4.64128822e-01,  -4.64444816e-01,
                         -4.69508350e-01,  -4.72261071e-01,  -4.76235896e-01,
                         -4.83947068e-01,  -4.88853335e-01,  -4.92216498e-01,
                         -4.96484488e-01,  -4.96975034e-01,  -4.93867785e-01,
                         -4.89647895e-01,  -4.84069109e-01,  -4.80013669e-01,
                         -4.78243649e-01,  -4.76791680e-01,  -4.77758944e-01,
                         -4.80514169e-01,  -4.81708765e-01,  -4.83650625e-01,
                         -4.86717910e-01,  -4.87058491e-01,  -4.85273182e-01,
                         -4.83116776e-01,  -4.80876267e-01,  -4.80541259e-01,
                         -4.81520116e-01,  -4.81963992e-01,  -4.82639134e-01,
                         -4.82703537e-01,  -4.81742203e-01,  -4.82252449e-01,
                         -4.81878251e-01,  -4.77219790e-01,  -4.71281439e-01,
                         -4.64811742e-01,  -4.56255376e-01,  -4.51619714e-01,
                         -4.55681354e-01,  -4.63415861e-01,  -4.70877200e-01,
                         -4.79237020e-01,  -4.87058342e-01,  -4.93051529e-01,
                         -4.99925315e-01,  -5.07392764e-01,  -5.11746585e-01,
                         -5.13646960e-01,  -5.15896142e-01,  -5.16933322e-01,
                         -5.14203191e-01,  -5.08956850e-01,  -5.03759086e-01,
                         -4.99347419e-01,  -4.95601326e-01,  -4.93770629e-01,
                         -4.94139850e-01,  -4.93765831e-01,  -4.91523206e-01,
                         -4.89530027e-01,  -4.87574190e-01,  -4.85601366e-01,
                         -4.85654265e-01,  -4.86657143e-01,  -4.86443132e-01,
                         -4.84459579e-01,  -4.78983521e-01,  -4.71078157e-01,
                         -4.64539945e-01,  -4.58920002e-01,  -4.53766555e-01,
                         -4.51465756e-01,  -4.51492876e-01,  -4.54176813e-01,
                         -4.61472422e-01,  -4.70328152e-01,  -4.77638036e-01,
                         -4.83509898e-01,  -4.86483425e-01,  -4.86199498e-01,
                         -4.83048439e-01,  -4.74926442e-01,  -4.62601185e-01,
                         -4.47216988e-01,  -4.28165197e-01,  -4.13124174e-01,
                         -4.09746528e-01,  -4.12950516e-01,  -4.18202966e-01,
                         -4.26502138e-01,  -4.34401691e-01,  -4.39671427e-01,
                         -4.44943726e-01,  -4.51942891e-01,  -4.61541861e-01,
                         -4.72162992e-01,  -4.80142176e-01,  -4.84966248e-01,
                         -4.86018568e-01,  -4.82448786e-01,  -4.77531523e-01,
                         -4.72130328e-01,  -4.63960707e-01,  -4.55631793e-01,
                         -4.50282544e-01,  -4.46195066e-01,  -4.41210747e-01,
                         -4.35560763e-01,  -4.30205584e-01,  -4.25068736e-01,
                         -4.20674682e-01,  -4.17961776e-01,  -4.14839476e-01,
                         -4.10556614e-01,  -4.08852041e-01,  -4.08939928e-01,
                         -4.06715870e-01,  -4.03351009e-01,  -4.00911033e-01,
                         -4.00483668e-01,  -4.04027760e-01,  -4.08418685e-01,
                         -4.08094257e-01,  -4.03350234e-01,  -3.97038370e-01,
                         -3.90096307e-01,  -3.81806970e-01,  -3.71925563e-01,
                         -3.63671005e-01,  -3.59386832e-01,  -3.56786907e-01,
                         -3.54044348e-01,  -3.50759476e-01,  -3.45913142e-01,
                         -3.40489268e-01,  -3.35832953e-01,  -3.31026584e-01,
                         -3.27320755e-01,  -3.27750564e-01,  -3.30782354e-01,
                         -3.32584947e-01,  -3.33328933e-01,  -3.34146470e-01,
                         -3.33575070e-01,  -3.32354188e-01,  -3.32394063e-01,
                         -3.32196653e-01,  -3.31447005e-01,  -3.32220048e-01,
                         -3.33366841e-01,  -3.32960427e-01,  -3.31360549e-01,
                         -3.28090280e-01,  -3.22516143e-01,  -3.15344483e-01,
                         -3.06793422e-01,  -2.96382248e-01,  -2.84708172e-01,
                         -2.74563402e-01,  -2.67939478e-01,  -2.63179928e-01,
                         -2.59069592e-01,  -2.56452203e-01,  -2.54662812e-01,
                         -2.53322989e-01,  -2.53085315e-01,  -2.52399147e-01,
                         -2.50137091e-01,  -2.48099267e-01,  -2.47533694e-01,
                         -2.47723714e-01,  -2.48321518e-01,  -2.51092613e-01,
                         -2.57957608e-01,  -2.67602354e-01,  -2.77314812e-01,
                         -2.85269588e-01,  -2.89691210e-01,  -2.91147977e-01,
                         -2.91087896e-01,  -2.88971156e-01,  -2.85918295e-01,
                         -2.83826351e-01,  -2.80895561e-01,  -2.75984108e-01,
                         -2.70871371e-01,  -2.65447348e-01,  -2.58162886e-01,
                         -2.49521300e-01,  -2.40941212e-01,  -2.32937098e-01,
                         -2.26135299e-01,  -2.21755415e-01,  -2.18518466e-01,
                         -2.13478521e-01,  -2.06021577e-01,  -1.96770325e-01,
                         -1.86578691e-01,  -1.77767083e-01,  -1.71081752e-01,
                         -1.65043324e-01,  -1.59425586e-01,  -1.54619113e-01,
                         -1.51548609e-01,  -1.51617661e-01,  -1.53277799e-01,
                         -1.54996827e-01,  -1.57367930e-01,  -1.59537077e-01,
                         -1.61604404e-01,  -1.64473325e-01,  -1.65694296e-01,
                         -1.64606139e-01,  -1.63343042e-01,  -1.62583932e-01,
                         -1.63323954e-01,  -1.65704697e-01,  -1.67633533e-01,
                         -1.69585109e-01,  -1.72136486e-01,  -1.73048541e-01,
                         -1.71830103e-01,  -1.69612795e-01,  -1.67729631e-01,
                         -1.68196067e-01,  -1.70679733e-01,  -1.74348295e-01,
                         -1.79810256e-01,  -1.84845626e-01,  -1.86991170e-01,
                         -1.87483415e-01,  -1.86354071e-01,  -1.84444159e-01,
                         -1.84283301e-01,  -1.84820846e-01,  -1.85174271e-01,
                         -1.86793476e-01,  -1.90439507e-01,  -1.94843993e-01,
                         -1.97493792e-01,  -1.98359191e-01,  -1.99404612e-01,
                         -1.99965253e-01,  -1.98281080e-01,  -1.95797905e-01,
                         -1.92943349e-01,  -1.87748566e-01,  -1.81260332e-01,
                         -1.76168084e-01,  -1.72282293e-01,  -1.68536320e-01,
                         -1.65451571e-01,  -1.64080456e-01,  -1.64598152e-01,
                         -1.66330472e-01,  -1.67912692e-01,  -1.67583734e-01,
                         -1.64557755e-01,  -1.59809828e-01,  -1.54740825e-01,
                         -1.51072726e-01,  -1.49270490e-01,  -1.48640528e-01,
                         -1.50341019e-01,  -1.54383257e-01,  -1.59268782e-01,
                         -1.65772066e-01,  -1.72424406e-01,  -1.76884159e-01,
                         -1.79207370e-01,  -1.78379521e-01,  -1.75460488e-01,
                         -1.73415259e-01,  -1.73199981e-01,  -1.74330100e-01,
                         -1.77002981e-01,  -1.81399196e-01,  -1.86005026e-01,
                         -1.89991623e-01,  -1.92364097e-01,  -1.92910105e-01,
                         -1.90333053e-01,  -1.84630960e-01,  -1.80737779e-01,
                         -1.78420842e-01,  -1.75287679e-01,  -1.73275173e-01,
                         -1.70335099e-01,  -1.64176986e-01,  -1.58268288e-01,
                         -1.52422547e-01,  -1.45950124e-01,  -1.41696185e-01,
                         -1.37054414e-01,  -1.32545203e-01,  -1.30636767e-01,
                         -1.29602432e-01,  -1.29445598e-01,  -1.30522221e-01,
                         -1.31443664e-01,  -1.29325524e-01,  -1.26364306e-01,
                         -1.23738192e-01,  -1.20416269e-01,  -1.17125504e-01,
                         -1.11852974e-01,  -1.08076446e-01,  -1.05519548e-01,
                         -1.01949431e-01,  -1.00224853e-01,  -9.82888341e-02,
                         -9.74284783e-02,  -9.80471149e-02,  -9.57258195e-02,
                         -9.39301103e-02,  -9.26455557e-02,  -8.83640498e-02,
                         -9.06419009e-02,  -8.37090164e-02,  -3.69075835e-02,
                          1.53973391e-02,   2.65994035e-02,   2.10228190e-02,
                          3.82830575e-02,   7.68505037e-02,   1.25814781e-01,
                          1.70811966e-01,   1.98671848e-01,   2.34145030e-01,
                          2.82672107e-01,   3.12976658e-01,   3.28564256e-01,
                          3.58097374e-01,   4.01788086e-01,   4.21851397e-01,
                          4.05223489e-01,   3.93100351e-01,   4.12375659e-01,
                          4.43318516e-01,   4.69715565e-01,   4.90101606e-01,
                          4.94109631e-01,   4.87776399e-01,   4.85642195e-01,
                          4.84424889e-01,   4.82602447e-01,   4.85793203e-01,
                          4.91296440e-01,   4.95555550e-01,   5.03698409e-01,
                          5.10404289e-01,   5.15113652e-01,   5.21458089e-01,
                          5.23452342e-01,   5.24719357e-01,   5.24925828e-01,
                          5.22381485e-01,   5.20316005e-01,   5.18739045e-01,
                          5.18051267e-01,   5.17022610e-01,   5.14571846e-01,
                          5.09871244e-01,   5.06305695e-01,   5.02772331e-01,
                          4.99488533e-01,   4.98474240e-01,   4.96717602e-01,
                          4.95204657e-01,   4.93193090e-01,   4.91707653e-01,
                          4.89716709e-01,   4.86732751e-01,   4.83552009e-01,
                          4.79808360e-01,   4.80684072e-01,   4.82452184e-01,
                          4.85179573e-01,   4.89460051e-01,   4.91112739e-01,
                          4.90724921e-01,   4.87602919e-01,   4.85580355e-01,
                          4.85629767e-01,   4.84523386e-01,   4.81978983e-01,
                          4.80864286e-01,   4.80077922e-01,   4.76530552e-01,
                          4.70851272e-01,   4.60389674e-01,   4.50958759e-01,
                          4.44265872e-01,   4.40768242e-01,   4.40563142e-01,
                          4.39749509e-01,   4.41877246e-01,   4.42813963e-01,
                          4.44271773e-01,   4.46718782e-01,   4.46581542e-01,
                          4.47193533e-01,   4.44259465e-01,   4.41457987e-01,
                          4.39226151e-01,   4.36322719e-01,   4.36029047e-01,
                          4.37130541e-01,   4.38551694e-01,   4.40272033e-01,
                          4.42288488e-01,   4.43661243e-01,   4.44459409e-01,
                          4.42177504e-01,   4.36901540e-01,   4.29382294e-01,
                          4.22090113e-01,   4.17814612e-01,   4.11647469e-01,
                          4.09810632e-01,   4.10498708e-01,   4.12136734e-01,
                          4.17917043e-01,   4.23498183e-01,   4.32261646e-01,
                          4.39716697e-01,   4.43700761e-01,   4.45237398e-01,
                          4.41721708e-01,   4.38492686e-01,   4.32160556e-01,
                          4.25394833e-01,   4.20878679e-01,   4.18164283e-01,
                          4.17083293e-01,   4.15881574e-01,   4.14636225e-01,
                          4.15772945e-01,   4.22259450e-01,   4.31723982e-01,
                          4.40829426e-01,   4.44629192e-01,   4.45115149e-01,
                          4.45648223e-01,   4.44774568e-01,   4.46977258e-01,
                          4.45565820e-01,   4.44267154e-01,   4.44058597e-01,
                          4.42907423e-01,   4.42271441e-01,   4.40282315e-01,
                          4.42235082e-01,   4.44637686e-01,   4.43896770e-01,
                          4.43713725e-01,   4.42260593e-01,   4.40775424e-01,
                          4.38044220e-01,   4.35335249e-01,   4.31552023e-01,
                          4.29459959e-01,   4.28627193e-01,   4.29624975e-01,
                          4.31974888e-01,   4.33474034e-01,   4.33916777e-01,
                          4.34317201e-01,   4.34428722e-01,   4.33132261e-01,
                          4.28155780e-01,   4.24175680e-01,   4.19140935e-01,
                          4.15460825e-01,   4.10539806e-01,   4.07705575e-01,
                          4.07235593e-01,   4.07872766e-01,   4.07937407e-01,
                          4.06882048e-01,   4.07779306e-01,   4.08611804e-01,
                          4.09978926e-01,   4.08643991e-01,   4.06277627e-01,
                          4.07192469e-01,   4.02054220e-01,   3.99950773e-01,
                          3.96089703e-01,   3.95098448e-01,   3.95037264e-01,
                          3.91641736e-01,   3.88085783e-01,   3.83304000e-01,
                          3.76860827e-01,   3.72868389e-01,   3.67838055e-01,
                          3.67918700e-01,   3.69359881e-01,   3.71503323e-01,
                          3.72412682e-01,   3.73001248e-01,   3.74518067e-01,
                          3.72973770e-01,   3.67977023e-01,   3.65951657e-01,
                          3.63350391e-01,   3.61579448e-01,   3.62584054e-01,
                          3.67075533e-01,   3.75214666e-01,   3.83328974e-01,
                          3.88336748e-01,   3.97384882e-01,   4.01732326e-01,
                          4.09399658e-01,   4.11667824e-01,   4.15228218e-01,
                          4.20509547e-01,   4.26057845e-01,   4.30572420e-01,
                          4.31937963e-01,   4.34519708e-01,   4.38382566e-01,
                          4.38490480e-01,   4.40282255e-01,   4.37999636e-01,
                          4.33764994e-01,   4.25198406e-01,   4.11839515e-01,
                          4.01933789e-01,   3.93694103e-01,   3.86296153e-01,
                          3.85163933e-01,   3.83346021e-01,   3.82875562e-01,
                          3.78195137e-01,   3.74375880e-01,   3.67258668e-01,
                          3.61633539e-01,   3.52813601e-01,   3.46530408e-01,
                          3.40974391e-01,   3.37325394e-01,   3.32146704e-01,
                          3.24986815e-01,   3.15418929e-01,   3.09649080e-01,
                          2.99890757e-01,   2.94710696e-01,   2.91670799e-01,
                          2.91961879e-01,   2.97801882e-01,   2.98696935e-01,
                          3.05978596e-01,   3.11945587e-01,   3.19540381e-01,
                          3.13668519e-01,   2.56444782e-01,   1.90407336e-01,
                          1.36115998e-01,   9.67942700e-02,   5.40486574e-02,
                          2.41762176e-02,   1.66638661e-02,  -2.56755832e-03,
                         -2.41589304e-02,  -3.66633385e-02,  -5.58404550e-02,
                         -6.53787628e-02,  -1.03151619e-01,  -1.60397485e-01,
                         -2.01825812e-01,  -2.21085146e-01,  -2.34943911e-01,
                         -2.59506255e-01,  -2.75436521e-01,  -2.83670217e-01,
                         -2.84136087e-01,  -2.85195649e-01,  -2.82582045e-01,
                         -2.38540530e-01,  -2.06956506e-01,  -2.36913070e-01,
                         -2.75371611e-01,  -2.77735442e-01,  -2.75892735e-01,
                         -2.74039179e-01,  -2.76913792e-01,  -2.77539879e-01,
                         -2.80188024e-01,  -2.80962557e-01,  -2.86757797e-01,
                         -2.93237895e-01,  -2.95904964e-01,  -2.99508482e-01,
                         -3.04239243e-01,  -3.05595934e-01,  -3.09794217e-01,
                         -3.13228250e-01,  -3.11805099e-01,  -3.12871963e-01,
                         -3.15060139e-01,  -3.11804235e-01,  -3.02689165e-01,
                         -2.94481635e-01,  -2.89034218e-01,  -2.78145283e-01,
                         -2.71447510e-01,  -2.66535312e-01,  -2.62536675e-01,
                         -2.54214019e-01,  -2.55827487e-01,  -2.55038589e-01,
                         -2.56027222e-01,  -2.57740468e-01,  -2.61890322e-01,
                         -2.65909076e-01,  -2.70408869e-01,  -2.75898486e-01,
                         -2.77987391e-01,  -2.82992840e-01,  -2.90394932e-01,
                         -2.96528876e-01,  -2.99972147e-01,  -3.03857684e-01,
                         -3.07788700e-01,  -3.09671253e-01,  -3.14656913e-01,
                         -3.15011024e-01,  -3.15877765e-01,  -3.18664014e-01,
                         -3.15701544e-01,  -3.10567021e-01,  -3.14811707e-01,
                         -3.18831056e-01,  -3.26068848e-01,  -3.24259073e-01,
                         -3.22787881e-01,  -3.25924397e-01,  -3.26795429e-01,
                         -3.24264765e-01,  -3.20715606e-01,  -3.11892837e-01,
                         -3.01306695e-01,  -2.89230049e-01,  -2.77962923e-01,
                         -2.66421080e-01,  -2.50898570e-01,  -2.41300136e-01,
                         -2.37308964e-01,  -2.30195910e-01,  -2.27081016e-01,
                         -2.28039980e-01,  -2.31884420e-01,  -2.27490693e-01,
                         -2.26664037e-01,  -2.29008183e-01,  -2.31715590e-01,
                         -2.39930421e-01,  -2.48374373e-01,  -2.53246397e-01,
                         -2.58171201e-01,  -2.59751022e-01,  -2.64778227e-01,
                         -2.65577734e-01,  -2.62814522e-01,  -2.58517563e-01,
                         -2.55431503e-01,  -2.51008481e-01,  -2.45413959e-01,
                         -2.37832263e-01,  -2.28302225e-01,  -2.21060678e-01,
                         -2.15434179e-01,  -2.12211907e-01,  -2.13768214e-01,
                         -2.14802206e-01,  -2.15735570e-01,  -2.15294600e-01,
                         -2.13062003e-01,  -2.14718729e-01,  -2.15539575e-01,
                         -2.18571141e-01,  -2.17884347e-01,  -2.19021156e-01,
                         -2.17695460e-01,  -2.19830155e-01,  -2.20158398e-01,
                         -2.15640500e-01,  -2.13093773e-01,  -2.08625823e-01,
                         -2.08133087e-01,  -2.06394941e-01,  -2.10534245e-01,
                         -2.10273772e-01,  -2.04198480e-01,  -2.01268300e-01,
                         -2.01629415e-01,  -2.04066038e-01,  -2.02717274e-01,
                         -2.06285685e-01,  -2.12790683e-01,  -2.10863024e-01,
                         -2.11708561e-01,  -2.17764705e-01,  -2.22556517e-01,
                         -2.21486405e-01,  -2.19818890e-01,  -2.19802901e-01,
                         -2.17109531e-01,  -2.10655853e-01,  -2.05655366e-01,
                         -2.03704134e-01,  -2.04349667e-01,  -2.01347545e-01,
                         -2.00120330e-01,  -2.01271027e-01,  -2.06871256e-01,
                         -2.10718021e-01,  -2.19629169e-01,  -2.18758792e-01,
                         -2.23325402e-01,  -1.93059668e-01,  -9.94724631e-02,
                         -2.66079456e-02,   2.33688094e-02,   5.65232001e-02,
                          7.87978694e-02,   1.20310165e-01,   1.44620925e-01,
                          1.22688934e-01,   9.42452252e-02,   1.15540944e-01,
                          1.69363767e-01,   1.77777708e-01,   1.41960710e-01,
                          1.28639504e-01,   1.69300482e-01,   2.11657569e-01,
                          2.30982959e-01,   2.54596531e-01,   2.85541117e-01,
                          3.53662252e-01,   4.16941255e-01,   4.07829314e-01,
                          3.83194774e-01,   3.57445747e-01,   3.39084268e-01,
                          2.90565610e-01,   2.73914605e-01,   3.55764896e-01,
                          4.33985263e-01,   4.45043832e-01,   4.34958458e-01,
                          4.24516886e-01,   4.16533679e-01,   4.10086602e-01,
                          4.02636141e-01,   3.99484575e-01,   3.93798918e-01,
                          3.96904558e-01,   3.93586874e-01,   3.89962971e-01,
                          3.87345403e-01,   3.84965211e-01,   3.80968809e-01,
                          3.76066744e-01,   3.68678600e-01,   3.63883734e-01,
                          3.58943760e-01,   3.56261820e-01,   3.57427865e-01,
                          3.57314140e-01,   3.63799244e-01,   3.70058447e-01,
                          3.79309714e-01,   3.85881156e-01,   3.93206537e-01,
                          3.99388283e-01,   3.98363471e-01,   4.03054029e-01,
                          4.03351068e-01,   4.06067401e-01,   4.03625429e-01,
                          4.06486303e-01,   4.04874295e-01,   4.01396155e-01,
                          3.96456242e-01,   3.87794524e-01,   3.85015100e-01,
                          3.79754514e-01,   3.74001741e-01,   3.68728876e-01,
                          3.69323999e-01,   3.67395580e-01,   3.67578775e-01,
                          3.65495265e-01,   3.61190587e-01,   3.57461721e-01,
                          3.59720826e-01,   3.54928136e-01,   3.56624722e-01,
                          3.58786970e-01,   3.68143380e-01,   3.75589401e-01,
                          3.82657140e-01,   3.88050318e-01,   3.93818051e-01,
                          4.00498986e-01,   3.99118453e-01,   3.98983479e-01,
                          3.97322237e-01,   3.89714897e-01,   3.84466171e-01,
                          3.76524746e-01,   3.64679009e-01,   3.57416093e-01,
                          3.51050466e-01,   3.47423911e-01,   3.46073657e-01,
                          3.40995014e-01,   3.39437753e-01,   3.39515120e-01,
                          3.36153775e-01,   3.35546434e-01,   3.34799737e-01,
                          3.35346043e-01,   3.32590401e-01,   3.33002239e-01,
                          3.34026963e-01,   3.32765132e-01,   3.35235745e-01,
                          3.34272772e-01,   3.29559237e-01,   3.29580158e-01,
                          3.28291178e-01,   3.29990208e-01,   3.30223888e-01,
                          3.31860691e-01,   3.25764000e-01,   3.24527115e-01,
                          3.22345316e-01,   3.17589432e-01,   3.14549148e-01,
                          3.12943101e-01,   3.08034360e-01,   3.08509827e-01,
                          3.08466047e-01,   3.06979328e-01,   3.08816999e-01,
                          3.07073355e-01,   3.06154519e-01,   3.03944826e-01,
                          3.03695917e-01,   3.03987592e-01,   3.06176931e-01,
                          3.02696764e-01,   3.05191815e-01,   3.06384921e-01,
                          3.06878775e-01,   3.04416478e-01,   3.06272864e-01,
                          3.03982198e-01,   2.99793988e-01,   2.98788339e-01,
                          2.97458291e-01,   2.92656928e-01,   2.83112168e-01,
                          2.77293026e-01,   2.74239480e-01,   2.71042794e-01,
                          2.68649966e-01,   2.64134884e-01,   2.59456992e-01,
                          2.61079431e-01,   2.60935366e-01,   2.61695951e-01,
                          2.65029043e-01,   2.68442303e-01,   2.71354914e-01,
                          2.71527171e-01,   2.74926454e-01,   2.80116171e-01,
                          2.84625411e-01,   2.87162989e-01,   2.93034464e-01,
                          2.98117995e-01,   3.00034285e-01,   3.02035421e-01,
                          2.98426718e-01,   2.96465069e-01,   2.98470616e-01,
                          3.03990394e-01,   3.08356225e-01,   2.99377590e-01,
                          2.82802999e-01,   2.57309586e-01,   2.31318921e-01,
                          2.32946157e-01,   2.12686390e-01,   1.86059400e-01,
                          1.85534477e-01,   1.88750878e-01,   1.90821022e-01,
                          1.73818082e-01,   1.19862616e-01,   8.84485766e-02,
                          8.56885165e-02,   8.28397349e-02,   1.02647811e-01,
                          1.10733546e-01,   1.10807411e-01,   1.21689320e-01,
                          1.19709991e-01,   1.23549737e-01,   1.53700769e-01,
                          1.78356171e-01,   2.03008443e-01,   2.24122062e-01,
                          1.92973837e-01,   1.26929715e-01,   1.13435917e-01,
                          1.34227335e-01,   1.22240119e-01,   8.76872912e-02,
                          5.70221357e-02,   4.65659387e-02,   5.37326746e-02,
                          6.59712926e-02,   6.64386898e-02,   3.47817503e-02,
                          9.21788218e-04,  -3.31565104e-02,  -6.74550459e-02,
                         -6.65717125e-02,  -9.04316902e-02,  -1.48825511e-01,
                         -1.95063010e-01,  -2.17188373e-01,  -2.16579407e-01,
                         -2.09164858e-01,  -1.75685078e-01,  -1.49314001e-01,
                         -1.44216776e-01,  -1.11724332e-01,  -8.36055204e-02,
                         -9.33785513e-02,  -1.18958913e-01,  -1.36293784e-01,
                         -1.17516078e-01,  -1.12167433e-01,  -1.53497666e-01,
                         -1.89768001e-01,  -2.26845130e-01,  -2.49069721e-01,
                         -2.48058453e-01,  -2.36552581e-01,  -2.19120175e-01,
                         -2.06226647e-01,  -1.77581593e-01,  -1.62887752e-01,
                         -1.59744844e-01,  -1.33198053e-01,  -1.23090737e-01,
                         -1.35268718e-01,  -1.70128122e-01,  -2.06627235e-01,
                         -2.13241190e-01,  -2.32702225e-01,  -2.62219727e-01,
                         -2.67749667e-01,  -2.58825451e-01,  -2.62907296e-01,
                         -2.54469067e-01,  -2.40244001e-01,  -2.34630793e-01,
                         -2.03917667e-01,  -1.59742624e-01,  -1.17329627e-01,
                         -9.70855430e-02,  -9.94500816e-02,  -1.01733126e-01,
                         -9.96896327e-02,  -1.01752743e-01,  -8.84870142e-02,
                         -4.38242704e-02,  -2.37212945e-02,  -1.23062860e-02,
                         -1.33682750e-02,  -2.19966285e-02,   2.00193748e-02,
                          3.96986827e-02,   2.97145303e-02,   1.82465010e-03,
                         -2.67460644e-02,  -2.43693534e-02,  -4.99279983e-02,
                         -9.19753239e-02,  -1.04508363e-01,  -8.26698542e-02,
                         -4.17799838e-02,   4.19777213e-03,   2.18689796e-02,
                          3.55627351e-02,   7.52790496e-02,   1.07737988e-01,
                          1.50247157e-01,   1.97811663e-01,   2.20005065e-01,
                          2.26131558e-01,   2.58047193e-01,   2.90152192e-01,
                          2.91964531e-01,   2.91679204e-01,   2.92160928e-01,
                          2.96298385e-01,   2.99051225e-01,   3.07920933e-01,
                          3.12868118e-01,   3.13690662e-01,   3.20804805e-01,
                          3.20533276e-01,   3.22869450e-01,   3.28053564e-01,
                          3.33155394e-01,   3.36866289e-01,   3.40594023e-01,
                          3.40994418e-01,   3.35658342e-01,   3.34462672e-01,
                          3.31849664e-01,   3.27182740e-01,   3.15620035e-01,
                          3.04288149e-01,   2.93714911e-01,   2.84771562e-01,
                          2.81332701e-01,   2.76151597e-01,   2.73485333e-01,
                          2.72123128e-01,   2.73594499e-01,   2.74841219e-01,
                          2.74714530e-01,   2.74923146e-01,   2.80760169e-01,
                          2.86380768e-01,   2.84638435e-01,   2.83013582e-01,
                          2.83375680e-01,   2.82890588e-01,   2.83145040e-01,
                          2.83560812e-01,   2.81891137e-01,   2.82503873e-01,
                          2.80516922e-01,   2.77493685e-01,   2.75332749e-01,
                          2.74461925e-01,   2.74205893e-01,   2.71018028e-01,
                          2.72126257e-01,   2.70509958e-01,   2.68287808e-01,
                          2.67486781e-01,   2.66042560e-01,   2.67598540e-01,
                          2.67019689e-01,   2.69014448e-01,   2.70757020e-01,
                          2.71702617e-01,   2.75798798e-01,   2.79349953e-01,
                          2.79343486e-01,   2.75094211e-01,   2.72623211e-01,
                          2.69968808e-01,   2.64358073e-01,   2.59537816e-01,
                          2.53796607e-01,   2.50702232e-01,   2.47166842e-01,
                          2.40183160e-01,   2.36381516e-01,   2.29234561e-01,
                          2.24299148e-01,   2.19073012e-01,   2.11836010e-01,
                          2.09457248e-01,   2.03662440e-01,   2.00005487e-01,
                          1.94277287e-01,   1.91007167e-01,   1.91640034e-01,
                          1.89725563e-01,   1.89681754e-01,   1.90720662e-01,
                          1.93906680e-01,   1.95161149e-01,   1.96048081e-01,
                          1.95604369e-01,   1.97892755e-01,   2.01046199e-01,
                          2.03625068e-01,   2.09226981e-01,   2.11479053e-01,
                          2.16652885e-01,   2.23423779e-01,   2.28228182e-01,
                          2.29136109e-01,   2.29365900e-01,   2.29020327e-01,
                          2.27941930e-01,   2.30700836e-01,   2.27144480e-01,
                          2.25781888e-01,   2.27214530e-01,   2.22800657e-01,
                          2.22736642e-01,   2.20487043e-01,   2.09654838e-01,
                          2.04876468e-01,   2.00562522e-01,   1.90999508e-01,
                          1.84237182e-01,   1.78341940e-01,   1.76767543e-01,
                          1.73074365e-01,   1.69483393e-01,   1.68794647e-01,
                          1.64890170e-01,   1.62578523e-01,   1.61315277e-01,
                          1.61574006e-01,   1.59570247e-01,   1.55986592e-01,
                          1.52477145e-01,   1.50395870e-01,   1.49092078e-01,
                          1.45135134e-01,   1.45645157e-01,   1.49792090e-01,
                          1.51825964e-01,   1.52392894e-01,   1.53312564e-01,
                          1.55527517e-01,   1.57800034e-01,   1.55898497e-01,
                          1.55395284e-01,   1.54745221e-01,   1.51213720e-01,
                          1.49134010e-01,   1.46498874e-01,   1.43176988e-01,
                          1.36923537e-01,   1.35791302e-01,   1.34376869e-01,
                          1.27175406e-01,   1.23685353e-01,   1.21864974e-01,
                          1.23991422e-01,   1.21018417e-01,   1.13953069e-01,
                          1.12589948e-01,   1.11395292e-01,   1.09425388e-01,
                          1.07923262e-01,   1.07009962e-01,   1.05623797e-01,
                          1.06012732e-01,   1.02363549e-01,   9.53902528e-02,
                          9.44688991e-02,   9.73486900e-02,   9.94487777e-02,
                          1.04001030e-01,   1.09417379e-01,   1.07528381e-01,
                          1.07498273e-01,   1.08789288e-01,   1.09602869e-01,
                          1.12886682e-01,   1.16269633e-01,   1.21328220e-01,
                          1.26674891e-01,   1.36225656e-01,   1.27064377e-01,
                          8.54604691e-02,   4.96016406e-02,   2.48209145e-02,
                          2.48098373e-03,  -4.28532064e-02,  -1.30450994e-01,
                         -1.79228798e-01,  -1.94103330e-01,  -2.31057614e-01,
                         -2.71536112e-01,  -3.42935771e-01,  -3.99055243e-01,
                         -3.92248213e-01,  -3.99482787e-01,  -4.05662358e-01,
                         -3.83938104e-01,  -3.63315195e-01,  -3.26675564e-01,
                         -3.10076624e-01,  -3.29604328e-01,  -3.46526176e-01,
                         -3.78703564e-01,  -3.97937119e-01,  -3.81931067e-01,
                         -3.77510935e-01,  -3.93344253e-01,  -4.19493496e-01,
                         -4.41677123e-01,  -4.56375867e-01,  -4.64787096e-01,
                         -4.60776418e-01,  -4.53344852e-01,  -4.49125797e-01,
                         -4.46505010e-01,  -4.48635846e-01,  -4.47297156e-01,
                         -4.45603758e-01,  -4.48451102e-01,  -4.44937408e-01,
                         -4.43600535e-01,  -4.41920400e-01,  -4.39266145e-01,
                         -4.36963797e-01,  -4.31888759e-01,  -4.29769278e-01,
                         -4.33196455e-01,  -4.32694197e-01,  -4.30832714e-01,
                         -4.28734422e-01,  -4.26608443e-01,  -4.29548681e-01,
                         -4.28011119e-01,  -4.32642013e-01,  -4.34934139e-01,
                         -4.34642345e-01,  -4.41809475e-01,  -4.48447555e-01,
                         -4.50153798e-01,  -4.53866988e-01,  -4.56664205e-01,
                         -4.54402030e-01,  -4.57648516e-01,  -4.62214291e-01,
                         -4.62403804e-01,  -4.64813322e-01,  -4.66802597e-01,
                         -4.66882259e-01,  -4.67222869e-01,  -4.63840067e-01,
                         -4.59837645e-01,  -4.56580281e-01,  -4.52475369e-01,
                         -4.47212398e-01,  -4.44274247e-01,  -4.32282448e-01,
                         -4.27424818e-01,  -4.27667588e-01,  -4.25701052e-01,
                         -4.24479783e-01,  -4.20014858e-01,  -4.17830616e-01,
                         -4.20344502e-01,  -4.20504659e-01,  -4.19087350e-01,
                         -4.17881191e-01,  -4.15834814e-01,  -4.21806008e-01,
                         -4.24696594e-01,  -4.25386816e-01,  -4.29574728e-01,
                         -4.36110526e-01,  -4.33867633e-01,  -4.36796397e-01,
                         -4.36928988e-01,  -4.39369053e-01,  -4.35150802e-01,
                         -4.27608967e-01,  -4.29207265e-01,  -4.28660631e-01,
                         -4.32710648e-01,  -4.36076850e-01,  -4.44755346e-01,
                         -4.44023311e-01,  -4.35190111e-01,  -4.32929903e-01,
                         -4.30791914e-01,  -4.25383180e-01,  -4.26261067e-01,
                         -4.15764332e-01,  -4.09653097e-01,  -4.06595647e-01,
                         -4.00543392e-01,  -3.98584396e-01,  -3.93405646e-01,
                         -3.92048329e-01,  -3.93516034e-01,  -3.92252773e-01,
                         -3.89864534e-01,  -3.92532468e-01,  -3.94579023e-01,
                         -3.99108768e-01,  -3.99185270e-01,  -4.01728332e-01,
                         -4.02333319e-01,  -3.97744149e-01,  -3.99552822e-01,
                         -3.97116035e-01,  -3.91518325e-01,  -3.89152974e-01,
                         -3.87473971e-01,  -3.87176037e-01,  -3.87340337e-01,
                         -3.87705445e-01,  -3.85049075e-01,  -3.83635014e-01,
                         -3.81171286e-01,  -3.79807234e-01,  -3.79931062e-01,
                         -3.79621506e-01,  -3.78070742e-01,  -3.78448516e-01,
                         -3.78909975e-01,  -3.71395379e-01,  -3.69312704e-01,
                         -3.67029727e-01,  -3.65551144e-01,  -3.68776619e-01,
                         -3.69773239e-01,  -3.70593637e-01,  -3.74065727e-01,
                         -3.78745377e-01,  -3.77759755e-01,  -3.79121751e-01,
                         -3.83618146e-01,  -3.89911294e-01,  -3.94881278e-01,
                         -3.93056214e-01,  -3.93285245e-01,  -3.93301994e-01,
                         -3.92726690e-01,  -3.87800634e-01,  -3.81887853e-01,
                         -3.77099544e-01,  -3.71505857e-01,  -3.64424258e-01,
                         -3.63953471e-01,  -3.62173438e-01,  -3.62464309e-01,
                         -3.62447172e-01,  -3.64423186e-01,  -3.64183128e-01,
                         -3.63700241e-01,  -3.62896085e-01,  -3.62849176e-01,
                         -3.66917133e-01,  -3.53480369e-01,  -3.52630883e-01,
                         -3.49962741e-01,  -3.48708600e-01,  -3.43413979e-01,
                         -3.41023415e-01,  -3.40900719e-01,  -3.39815736e-01,
                         -3.38332534e-01,  -3.36013913e-01,  -3.32741618e-01,
                         -3.26044202e-01,  -3.22302669e-01,  -3.19543391e-01,
                         -3.15764099e-01,  -3.08172166e-01,  -2.75157690e-01,
                         -2.00097337e-01,  -1.68037921e-01,  -1.52349263e-01,
                         -1.44475505e-01,  -1.41749948e-01,  -1.52058437e-01,
                         -1.83521181e-01,  -1.81825817e-01,  -1.76037639e-01,
                         -2.11648136e-01,  -2.74533361e-01,  -2.98985630e-01,
                         -2.74658591e-01,  -2.35019386e-01,  -1.88222304e-01,
                         -1.53680414e-01,  -1.40449077e-01,  -1.32928953e-01,
                         -1.00198343e-01,  -4.90134172e-02,  -5.15599875e-03,
                          1.36965206e-02,   1.77930612e-02,   6.50223121e-02,
                          9.91367102e-02,   1.30153894e-01,   1.45698935e-01,
                          1.52111858e-01,   1.54598504e-01,   1.48242235e-01,
                          1.66756868e-01,   1.80882901e-01,   1.90499604e-01,
                          1.87338978e-01,   1.63304761e-01,   1.63952827e-01,
                          1.95237368e-01,   2.21296698e-01,   2.86444783e-01,
                          3.11746448e-01,   3.07305843e-01,   3.06514621e-01,
                          2.96252578e-01,   2.93309391e-01,   2.91149735e-01,
                          2.95504600e-01,   2.92084426e-01,   2.92116821e-01,
                          2.89012879e-01,   2.91314334e-01,   2.92589039e-01,
                          2.90147066e-01,   2.93392122e-01,   2.91646212e-01,
                          2.92174727e-01,   2.95574278e-01,   2.98591852e-01,
                          2.98788488e-01,   3.03101331e-01,   3.07564378e-01,
                          3.02899271e-01,   3.11890870e-01,   3.13271463e-01,
                          3.17650437e-01,   3.19083571e-01,   3.22288692e-01,
                          3.27816248e-01,   3.22468281e-01,   3.22125793e-01,
                          3.20769250e-01,   3.19701880e-01,   3.15731823e-01,
                          3.11340123e-01,   3.07793826e-01,   3.04568350e-01,
                          3.02069783e-01,   3.03990960e-01,   2.98656821e-01,
                          2.99226433e-01,   3.02116513e-01,   2.98089713e-01,
                          2.99665481e-01,   3.00320148e-01,   2.95624554e-01,
                          2.94437438e-01,   2.94085950e-01,   2.92207509e-01,
                          2.98316389e-01,   3.04289043e-01,   3.02379727e-01,
                          3.06893975e-01,   3.04634392e-01,   2.98844218e-01,
                          2.92905003e-01,   2.87037730e-01,   2.85278141e-01,
                          2.80499995e-01,   2.76460767e-01,   2.68599331e-01,
                          2.63217241e-01,   2.60678113e-01,   2.58799553e-01,
                          2.57682979e-01,   2.59238333e-01,   2.54242331e-01,
                          2.48611718e-01,   2.46641949e-01,   2.46367589e-01,
                          2.42988557e-01,   2.40262091e-01,   2.36756206e-01,
                          2.39166752e-01,   2.42199332e-01,   2.42043465e-01,
                          2.45416313e-01,   2.45563179e-01,   2.43132249e-01,
                          2.44892806e-01,   2.44790673e-01,   2.48635963e-01,
                          2.55212039e-01,   2.49427989e-01,   2.54750758e-01,
                          2.59718478e-01,   2.66752571e-01,   2.70967603e-01,
                          2.75505275e-01,   2.81399697e-01,   2.85169125e-01,
                          2.88322896e-01,   2.89995402e-01,   2.90220320e-01,
                          2.89120257e-01,   2.89518028e-01,   2.91739583e-01,
                          2.91507423e-01,   2.86974043e-01,   2.88224995e-01,
                          2.86425531e-01,   2.86315799e-01,   2.86865592e-01,
                          2.83784360e-01,   2.83267349e-01,   2.87983686e-01,
                          2.84166932e-01,   2.83787906e-01,   2.84341097e-01,
                          2.87329882e-01,   2.86009341e-01,   2.82109857e-01,
                          2.87648439e-01,   2.91001052e-01,   2.93484032e-01,
                          2.97775060e-01,   2.98466980e-01,   2.95851290e-01,
                          2.96553284e-01,   2.94790894e-01,   2.95693159e-01,
                          2.99579084e-01,   3.05104315e-01,   3.06017011e-01,
                          3.06404293e-01,   3.07357669e-01,   3.08016777e-01,
                          3.08298737e-01,   3.09979618e-01,   3.12986195e-01,
                          3.14543664e-01,   3.15009534e-01,   3.18467259e-01,
                          3.18815947e-01,   3.16774398e-01,   3.03903311e-01,
                          2.79472500e-01,   2.54430503e-01,   2.22681075e-01,
                          1.92161977e-01,   1.71682030e-01,   1.71982616e-01,
                          1.74074486e-01,   1.59646526e-01,   1.49749994e-01,
                          1.60761803e-01,   1.69412389e-01,   1.56248435e-01,
                          1.30003959e-01,   1.08225368e-01,   9.54567268e-02,
                          9.46577191e-02,   1.07177556e-01,   9.54528153e-02,
                          6.06546924e-02,   4.40026261e-02,   2.86595039e-02,
                          1.36316717e-02,  -3.44535825e-03,  -2.24250015e-02,
                          2.47121369e-03,   1.87463779e-02,  -6.26576785e-03,
                         -9.48017929e-03,  -4.69869561e-02,  -1.30537763e-01,
                         -1.56680211e-01,  -1.49409473e-01,  -1.67015582e-01,
                         -2.00714752e-01,  -2.22673967e-01,  -2.29105696e-01,
                         -2.31321350e-01,  -2.32029349e-01,  -2.33849660e-01,
                         -2.38148451e-01,  -2.33182549e-01,  -2.27372840e-01,
                         -2.28961349e-01,  -2.22599313e-01,  -2.15723202e-01,
                         -2.12429658e-01,  -2.07129702e-01,  -1.99152440e-01,
                         -1.92703187e-01,  -1.91122577e-01,  -1.87043086e-01,
                         -1.86425120e-01,  -1.89824894e-01,  -1.90466151e-01,
                         -1.94232836e-01,  -1.95426971e-01,  -1.99801549e-01,
                         -2.04875186e-01,  -2.02525944e-01,  -2.04468280e-01,
                         -2.07794145e-01,  -2.10677356e-01,  -2.11641371e-01,
                         -2.08895355e-01,  -2.07113266e-01,  -2.07049698e-01,
                         -2.06234694e-01,  -2.07682729e-01,  -2.05879480e-01,
                         -2.05079377e-01,  -2.08331630e-01,  -2.09569797e-01,
                         -2.11513191e-01,  -2.11514980e-01,  -2.14664072e-01,
                         -2.15571508e-01,  -2.11003795e-01,  -2.12065637e-01,
                         -2.12174326e-01,  -2.10602894e-01,  -2.05366075e-01,
                         -2.02608168e-01,  -2.02325448e-01,  -1.99785501e-01,
                         -1.91876963e-01,  -1.87344983e-01,  -1.85966387e-01,
                         -1.81797102e-01,  -1.79577693e-01,  -1.75600797e-01,
                         -1.80757850e-01,  -1.81879222e-01,  -1.79027468e-01,
                         -1.84499219e-01,  -1.88833326e-01,  -1.92178577e-01,
                         -1.95895761e-01,  -2.01234385e-01,  -2.04415828e-01,
                         -2.10324049e-01,  -2.12175503e-01,  -2.16569185e-01,
                         -2.23874986e-01,  -2.26077706e-01,  -2.30834410e-01,
                         -2.32136458e-01,  -2.31313735e-01,  -2.29291171e-01,
                         -2.30100527e-01,  -2.31258824e-01,  -2.35100955e-01,
                         -2.34098837e-01,  -2.25785092e-01,  -2.22037211e-01,
                         -2.21934035e-01,  -2.20085740e-01,  -2.17643395e-01,
                         -2.16373935e-01,  -2.19423145e-01,  -2.17695430e-01,
                         -2.17670485e-01,  -2.20066115e-01,  -2.17677355e-01,
                         -2.18861327e-01,  -2.22263515e-01,  -2.19800144e-01,
                         -2.19329998e-01,  -2.22261176e-01,  -2.25115299e-01,
                         -2.25614727e-01,  -2.33070642e-01,  -2.36231536e-01,
                         -2.39943355e-01,  -2.41970152e-01,  -2.48781458e-01,
                         -2.58171797e-01,  -2.68520743e-01,  -2.75919855e-01,
                         -2.77834564e-01,  -2.86760718e-01,  -2.95722693e-01,
                         -2.96532154e-01,  -3.01693112e-01,  -3.04118603e-01,
                         -3.08098257e-01,  -3.11113834e-01,  -3.11197996e-01,
                         -3.10127258e-01,  -3.05878222e-01,  -3.03363949e-01,
                         -3.05250883e-01,  -3.01053107e-01,  -3.03622812e-01,
                         -3.05582702e-01,  -3.05753618e-01,  -3.06214392e-01,
                         -3.09312552e-01,  -3.11011344e-01,  -3.11557561e-01,
                         -3.14370930e-01,  -3.25521052e-01,  -3.30919981e-01,
                         -3.33368689e-01,  -3.43625844e-01,  -3.50890875e-01,
                         -3.56717676e-01,  -3.56443793e-01,  -3.59575361e-01,
                         -3.60408962e-01,  -3.30856800e-01,  -2.79980779e-01,
                         -2.30553016e-01,  -1.91673383e-01,  -1.80910885e-01,
                         -1.91033646e-01,  -1.53442293e-01,  -9.22136381e-02,
                         -5.01820482e-02,  -4.41715717e-02,  -7.80975968e-02,
                         -8.56675655e-02,  -6.97899163e-02,  -4.25384380e-02,
                         -1.68427601e-02,  -3.36911343e-02,  -5.81294782e-02,
                         -6.01855963e-02,  -7.35831410e-02,  -8.25392529e-02,
                         -7.48340115e-02,  -6.52348101e-02,  -7.43565038e-02,
                         -9.66856107e-02,  -1.09503083e-01,  -1.03049837e-01,
                         -9.13072973e-02,  -8.96600932e-02,  -1.03270300e-01,
                         -9.24524665e-02,  -4.57009189e-02,  -1.15386518e-02,
                          1.43516008e-02,   4.13249843e-02,   7.03950450e-02,
                          1.03439167e-01,   1.10810176e-01,   1.38309151e-01,
                          1.47685841e-01,   1.25844553e-01,   1.15628608e-01,
                          1.21593319e-01,   9.89810601e-02,   6.38451353e-02,
                          4.86731716e-02,   2.94340476e-02,   1.27813406e-02,
                          6.76299562e-04,  -2.38095690e-02,  -1.58086866e-02,
                          7.03284591e-02,   1.26942113e-01,   1.14635147e-01,
                          1.13645472e-01,   1.08310387e-01,   1.12840064e-01,
                          6.68533966e-02,   3.12405266e-02,   3.82095575e-02,
                         -6.95700990e-03,  -4.38300073e-02,  -1.75082032e-02,
                          2.24156585e-02,   5.04041351e-02,   5.52721694e-02,
                          5.08860685e-02,   6.31218404e-02,   5.60776629e-02,
                          4.31910045e-02,   5.44056594e-02,   5.09523191e-02,
                          4.73673679e-02,   3.99912335e-02,   3.39731462e-02,
                          3.29776034e-02,   2.96302773e-02,   2.91339792e-02,
                          2.68141925e-02,   2.99035646e-02,   3.45486701e-02,
                          3.74982320e-02,   4.23207842e-02,   4.09843512e-02,
                          4.13528495e-02,   3.98575030e-02,   3.05325221e-02,
                          2.41772570e-02,   1.83336455e-02,   1.24158300e-02,
                          4.41179518e-03,   1.05106854e-03,  -1.45114656e-03,
                         -5.98514918e-03,  -6.57475926e-03,  -3.88253480e-03,
                         -3.98544502e-03,  -6.31633913e-04,  -1.97742856e-03,
                          1.32717506e-03,   5.32628456e-03,   6.95528416e-03,
                          1.31440554e-02,   1.08153261e-02,   1.45266037e-02,
                          1.65295675e-02,  -2.74449587e-02,  -8.50093812e-02,
                         -9.84472632e-02,  -4.44969796e-02,  -1.22493189e-02,
                         -2.04194430e-02,  -2.46169847e-02,  -4.59767692e-02,
                         -7.12171495e-02,  -9.63663980e-02,  -1.26379073e-01,
                         -1.23039573e-01,  -1.29721761e-01,  -1.22503318e-01,
                         -1.07864752e-01,  -1.34110138e-01,  -1.58172697e-01,
                         -1.48895368e-01,  -1.23156302e-01,  -9.49144065e-02,
                         -5.82856312e-02,  -1.64843425e-02,   2.32889107e-03,
                         -1.02201011e-03,  -4.17848080e-02,  -8.13319758e-02,
                         -7.90655762e-02,  -5.25375940e-02,  -2.82752123e-02,
                         -1.59276146e-02,  -2.27090195e-02,  -1.37086250e-02,
                         -1.10457409e-02,  -1.39378970e-02,  -7.39056501e-04,
                          8.86472780e-03,   4.45840620e-02,   1.05152190e-01,
                          1.37021005e-01,   1.18371062e-01,   5.33173680e-02,
                         -2.19607688e-02,  -7.22265318e-02,  -1.00815624e-01,
                         -1.14023544e-01,  -1.03451274e-01,  -9.13617238e-02,
                         -4.04085629e-02,   3.71962041e-02,   6.44466206e-02,
                          4.69907597e-02,   1.00731598e-02,  -1.36362389e-02,
                          9.01732314e-03,   3.55889536e-02,   2.34622005e-02,
                         -2.64922017e-03,  -1.29352016e-02,  -2.03973819e-02,
                         -3.49537730e-02,  -1.65216252e-02,   1.13934195e-02,
                          1.03303185e-02,   1.92834958e-02,   4.67625931e-02,
                          5.21413945e-02,   6.66960999e-02,   9.95697081e-02,
                          9.77721810e-02,   7.49406070e-02,   1.13850944e-02,
                         -8.69977251e-02,  -1.43611908e-01,  -1.73528165e-01,
                         -1.65511563e-01,  -1.27812728e-01,  -1.11064829e-01,
                         -1.16538778e-01,  -1.46214604e-01,  -1.95003271e-01,
                         -2.02011153e-01,  -2.03212693e-01,  -2.29569569e-01,
                         -2.19777137e-01,  -1.82753310e-01,  -1.64960653e-01,
                         -1.79740697e-01,  -2.18608931e-01,  -2.66013294e-01,
                         -3.00418168e-01,  -3.15481573e-01,  -3.54952008e-01,
                         -3.80870402e-01,  -3.82889241e-01,  -3.80316317e-01,
                         -3.70392770e-01,  -3.67322177e-01,  -3.63728285e-01,
                         -3.55677217e-01,  -3.54292959e-01,  -3.51024240e-01,
                         -3.39347273e-01,  -3.04124832e-01,  -2.54783094e-01,
                         -2.53923029e-01,  -2.96180248e-01,  -3.01463664e-01,
                         -2.93924659e-01,  -2.93906480e-01,  -2.89193392e-01,
                         -2.89114445e-01,  -2.89163888e-01,  -2.90391624e-01,
                         -2.89716452e-01,  -2.85369575e-01,  -2.84458280e-01,
                         -2.86445379e-01,  -2.84688830e-01,  -2.76271403e-01,
                         -2.74767011e-01,  -2.70612299e-01,  -2.66052574e-01,
                         -2.62559652e-01,  -2.55771458e-01,  -2.51711309e-01,
                         -2.44199604e-01,  -2.35942021e-01,  -2.26930261e-01,
                         -2.17909113e-01,  -2.10011780e-01,  -2.00342625e-01,
                         -1.94185361e-01,  -1.94002256e-01,  -1.91419169e-01,
                         -1.84527814e-01,  -1.83381975e-01,  -1.79695562e-01,
                         -1.76072448e-01,  -1.73099995e-01,  -1.66016489e-01,
                         -1.61459476e-01,  -1.54944733e-01,  -1.53839976e-01,
                         -1.50127351e-01,  -1.41918376e-01,  -1.34988114e-01,
                         -1.27364412e-01,  -1.24705076e-01,  -1.23590291e-01,
                         -1.19328842e-01,  -1.16386771e-01,  -1.12984441e-01,
                         -1.12980194e-01,  -1.15437753e-01,  -1.15178093e-01,
                         -1.21137127e-01,  -1.22896075e-01,  -1.22616023e-01,
                         -1.28448248e-01,  -1.28295422e-01,  -1.29167005e-01,
                         -1.25536710e-01,  -1.24146014e-01,  -1.26689285e-01,
                         -1.25839859e-01,  -1.27028555e-01,  -1.28365904e-01,
                         -1.28724575e-01,  -1.29141346e-01,  -1.30375952e-01,
                         -1.28367215e-01,  -1.26645416e-01,  -1.27984479e-01,
                         -1.29880562e-01,  -1.26503035e-01,  -1.21315069e-01,
                         -1.18030563e-01,  -1.09858133e-01,  -1.04628123e-01,
                         -9.58799422e-02,  -8.52757543e-02,  -7.98357651e-02,
                         -7.77561218e-02,  -7.85712078e-02,  -7.72250742e-02,
                         -7.89180398e-02,  -8.30514431e-02,  -8.67534950e-02,
                         -8.69759023e-02,  -8.76371041e-02,  -8.79848003e-02,
                         -8.50660279e-02,  -8.59079510e-02,  -8.42848346e-02,
                         -8.25161934e-02,  -8.68668482e-02,  -8.92746821e-02,
                         -8.82708579e-02,  -8.82155672e-02,  -9.00903121e-02,
                         -9.27318856e-02,  -9.31534469e-02,  -9.82157812e-02,
                         -1.04140207e-01,  -1.08525254e-01,  -1.14068963e-01,
                         -1.11147419e-01,  -1.11527167e-01,  -1.14202276e-01,
                         -1.12752572e-01,  -1.12725303e-01,  -1.12464659e-01,
                         -1.11224674e-01,  -1.10433556e-01,  -1.09966405e-01,
                         -1.04418263e-01,  -1.02523431e-01,  -1.03638880e-01,
                         -1.03460699e-01,  -1.01352878e-01,  -1.00248240e-01,
                         -1.02522492e-01,  -1.02753609e-01,  -1.02943242e-01,
                         -1.04669921e-01,  -1.08082570e-01,  -1.03886113e-01,
                         -1.06116436e-01,  -1.10165544e-01,  -1.05535671e-01,
                         -1.03868216e-01,  -9.58888009e-02,  -9.36670750e-02,
                         -9.21280980e-02,  -8.81071389e-02,  -8.89272839e-02,
                         -8.49478468e-02,  -8.62273425e-02,  -9.13069993e-02,
                         -9.20881033e-02,  -9.09076929e-02,  -9.18549523e-02,
                         -9.68299806e-02,  -9.86867473e-02,  -9.58894193e-02,
                         -9.48881432e-02,  -9.69431475e-02,  -9.70347002e-02,
                         -9.57103521e-02,  -1.00601166e-01,  -1.02553390e-01,
                         -1.05975658e-01,  -1.11781217e-01,  -1.14768185e-01,
                         -1.22072466e-01,  -1.24171525e-01,  -1.28624320e-01,
                         -1.32022113e-01,  -1.33216143e-01,  -1.36702597e-01,
                         -1.38104960e-01,  -1.34159148e-01,  -1.19974941e-01,
                         -8.91859382e-02,  -5.22246361e-02,  -4.89762314e-02,
                         -4.96636666e-02,  -5.44816442e-02,  -7.85634965e-02,
                         -8.42619166e-02,  -6.54318482e-02,  -3.12143527e-02,
                          1.33644743e-02,   5.47006987e-02,   4.46005091e-02,
                          1.32480655e-02,  -2.35636029e-02,  -4.35942523e-02,
                         -3.28831910e-03,   4.55692522e-02,   7.27145001e-02,
                          6.48315102e-02,   8.26543272e-02,   1.18104003e-01,
                          1.26838312e-01,   1.55731678e-01,   1.84145629e-01,
                          2.06447497e-01,   2.41449296e-01,   2.54444927e-01,
                          2.58403689e-01,   3.21761310e-01,   3.99473041e-01,
                          4.43233460e-01,   4.56676781e-01,   4.53363955e-01,
                          4.56246078e-01,   4.51195240e-01,   4.53941435e-01,
                          4.51432645e-01,   4.47583735e-01,   4.45959061e-01,
                          4.41070616e-01,   4.38976288e-01,   4.32324976e-01,
                          4.33244675e-01,   4.26683128e-01,   4.22125131e-01,
                          4.19636339e-01,   4.16232914e-01,   4.11766350e-01,
                          4.02406126e-01,   3.97362977e-01,   3.94825220e-01,
                          3.94196749e-01,   3.92982334e-01,   3.96101803e-01,
                          3.91682386e-01,   3.90008181e-01,   3.88162673e-01,
                          3.87353957e-01,   3.88541102e-01,   3.84416848e-01,
                          3.85289401e-01,   3.77737761e-01,   3.76441687e-01,
                          3.75581682e-01,   3.74029934e-01,   3.69281501e-01,
                          3.60201567e-01,   3.56216639e-01,   3.47713232e-01,
                          3.45245421e-01,   3.36721510e-01,   3.26744676e-01,
                          3.22469622e-01,   3.20550799e-01,   3.15513045e-01,
                          3.10072392e-01,   3.09666663e-01,   3.06607157e-01,
                          3.08489293e-01,   3.08419406e-01,   3.05495530e-01,
                          3.06188732e-01,   3.13504010e-01,   3.16259801e-01,
                          3.19086581e-01,   3.22937816e-01,   3.22146147e-01,
                          3.27102274e-01,   3.23707074e-01,   3.21611047e-01,
                          3.22612435e-01,   3.20121050e-01,   3.16461444e-01,
                          3.14026505e-01,   3.15196574e-01,   3.10786188e-01,
                          3.07831585e-01,   3.03645253e-01,   2.97498226e-01,
                          2.93680251e-01,   2.90278316e-01,   2.87651628e-01,
                          2.87214398e-01,   2.87485987e-01,   2.85996586e-01,
                          2.83820659e-01,   2.82506734e-01,   2.84241259e-01,
                          2.83736885e-01,   2.86039203e-01,   2.87506342e-01,
                          2.86250472e-01,   2.90450960e-01,   2.91245520e-01,
                          2.91926026e-01,   2.94260234e-01,   2.90882558e-01,
                          2.89838791e-01,   2.92142421e-01,   2.91788816e-01,
                          2.92259812e-01,   2.91149110e-01,   2.89915413e-01,
                          2.91527659e-01,   2.91599542e-01,   2.90271252e-01,
                          2.89388865e-01,   2.88367033e-01,   2.89329231e-01,
                          2.91072369e-01,   2.89123952e-01,   2.91333526e-01,
                          2.93122709e-01,   2.91261405e-01,   2.92936116e-01,
                          2.93776900e-01,   2.92801142e-01,   2.91262686e-01,
                          2.90090740e-01,   2.88096845e-01,   2.87564427e-01,
                          2.89329946e-01,   2.90125549e-01,   2.90584743e-01,
                          2.90395617e-01,   2.88669705e-01,   2.87343323e-01,
                          2.87653923e-01,   2.86732554e-01,   2.85379559e-01,
                          2.87161112e-01,   2.88736522e-01,   2.86291599e-01,
                          2.85682887e-01,   2.83608288e-01,   2.78490126e-01,
                          2.77901262e-01,   2.80794144e-01,   2.83025026e-01,
                          2.83106744e-01,   2.84264654e-01,   2.87251174e-01,
                          2.90385872e-01,   2.92638719e-01,   2.95607001e-01,
                          2.93138176e-01,   2.90594637e-01,   2.91005939e-01,
                          2.88091451e-01,   2.89111048e-01,   2.90201515e-01,
                          2.92528659e-01,   2.92779893e-01,   2.93812543e-01,
                          2.94951051e-01,   2.94126481e-01,   2.99555749e-01,
                          3.00262868e-01,   3.04634601e-01,   3.08987796e-01,
                          3.09691221e-01,   3.14804971e-01,   3.13803047e-01,
                          3.09340447e-01,   3.09647471e-01,   3.09952646e-01,
                          3.09144795e-01,   3.09699476e-01,   3.04370195e-01,
                          3.02248806e-01,   2.98811257e-01,   2.94479132e-01,
                          2.95906365e-01,   2.91627228e-01,   2.93310225e-01,
                          2.95764506e-01,   2.96302825e-01,   2.99435288e-01,
                          2.98405498e-01,   3.02534461e-01,   3.08876157e-01,
                          3.10401022e-01,   3.12426984e-01,   3.15472096e-01,
                          3.17868292e-01,   3.18564892e-01,   3.19266409e-01,
                          3.21800172e-01,   3.19973052e-01,   3.17439765e-01,
                          3.17125291e-01,   3.16151083e-01,   3.18339467e-01,
                          3.20516467e-01,   3.17780644e-01,   3.14543337e-01,
                          3.10139477e-01,   3.03420693e-01,   3.00674289e-01,
                          2.93229103e-01,   2.85147667e-01,   2.78720826e-01,
                          2.72497058e-01,   2.72636414e-01,   2.70139635e-01,
                          2.67875731e-01,   2.49748051e-01,   2.40979746e-01,
                          2.68719822e-01,   2.63044506e-01,   2.13359714e-01,
                          1.67761385e-01,   1.34146258e-01,   1.32451355e-01,
                          1.62596971e-01,   1.77980214e-01,   1.70563221e-01,
                          1.43627033e-01,   1.13978468e-01,   1.05192654e-01,
                          8.68840739e-02,   6.62108436e-02,   5.98453656e-02,
                          5.36013730e-02,   3.22418548e-02,  -3.54189449e-03,
                         -3.25464197e-02,  -9.17402208e-02,  -1.50195077e-01,
                         -1.36262223e-01,  -1.26710624e-01,  -1.80118784e-01,
                         -2.37423748e-01,  -2.55589098e-01,  -2.58560568e-01,
                         -2.59452909e-01,  -2.60535538e-01,  -2.71389008e-01,
                         -2.57264465e-01,  -2.20191449e-01,  -1.90303326e-01,
                         -1.68716550e-01,  -1.78298801e-01,  -2.04046384e-01,
                         -2.16780931e-01,  -2.45974481e-01,  -2.64932156e-01,
                         -2.39725858e-01,  -2.17480853e-01,  -2.13932127e-01,
                         -2.57417142e-01,  -3.41549963e-01,  -3.97052705e-01,
                         -4.43407685e-01,  -4.78775740e-01,  -4.83266443e-01,
                         -4.85370666e-01,  -4.87067461e-01,  -4.91202027e-01,
                         -4.95750040e-01,  -5.00857174e-01,  -5.07601678e-01,
                         -5.10974228e-01,  -5.17168820e-01,  -5.20714700e-01,
                         -5.20037711e-01,  -5.18762946e-01,  -5.18887877e-01,
                         -5.20372570e-01,  -5.20892203e-01,  -5.19394338e-01,
                         -5.17420173e-01,  -5.20112813e-01,  -5.18401444e-01,
                         -5.15321851e-01,  -5.18411219e-01,  -5.20393312e-01,
                         -5.22382319e-01,  -5.22556901e-01,  -5.21943867e-01,
                         -5.23180246e-01,  -5.19778311e-01,  -5.12917995e-01,
                         -5.13383806e-01,  -5.11428773e-01,  -5.05532265e-01,
                         -5.09519815e-01,  -5.08365035e-01,  -5.06403983e-01,
                         -5.08307815e-01,  -5.07808983e-01,  -5.11565149e-01,
                         -5.09914279e-01,  -5.09418428e-01,  -5.16260386e-01,
                         -5.24218917e-01,  -5.29040217e-01,  -5.29529512e-01,
                         -5.34294903e-01,  -5.40696740e-01,  -5.46253204e-01,
                         -5.47385633e-01,  -5.46064198e-01,  -5.48587918e-01,
                         -5.48978686e-01,  -5.45977414e-01,  -5.41691601e-01,
                         -5.39382279e-01,  -5.37898004e-01,  -5.34155011e-01,
                         -5.28554678e-01,  -5.24051070e-01,  -5.19541502e-01,
                         -5.13096631e-01,  -5.10149181e-01,  -5.06914556e-01,
                         -5.03392994e-01,  -5.00962138e-01,  -4.99802411e-01,
                         -4.98509169e-01,  -4.96783763e-01,  -5.00308812e-01,
                         -4.99538332e-01,  -5.01577973e-01,  -5.04012108e-01,
                         -5.00712633e-01,  -5.01731455e-01,  -4.98756558e-01,
                         -5.01673460e-01,  -5.03020525e-01,  -5.00544369e-01,
                         -5.05351007e-01,  -5.01520395e-01,  -5.01438320e-01,
                         -5.02866566e-01,  -4.98967797e-01,  -4.98738021e-01,
                         -4.95991439e-01,  -4.97952372e-01,  -5.00369191e-01,
                         -4.96484667e-01,  -4.97392505e-01,  -5.00841498e-01,
                         -4.97763962e-01,  -4.95892376e-01,  -4.95834559e-01,
                         -4.92801547e-01,  -4.91196245e-01,  -4.87358660e-01,
                         -4.86376703e-01,  -4.83201236e-01,  -4.78305757e-01,
                         -4.79256630e-01,  -4.77408081e-01,  -4.79937673e-01,
                         -4.81127948e-01,  -4.82911110e-01,  -4.70783979e-01,
                         -4.29191738e-01,  -4.14762169e-01,  -4.28048104e-01,
                         -4.23614800e-01,  -4.09860909e-01,  -4.03806478e-01,
                         -3.92537445e-01,  -3.57286334e-01,  -3.20449740e-01,
                         -2.91083246e-01,  -2.55566686e-01,  -2.27779999e-01,
                         -2.07492396e-01,  -1.93560660e-01,  -2.05193639e-01,
                         -2.07711339e-01,  -1.60233989e-01,  -1.05654359e-01,
                         -6.65141642e-02,  -3.97800840e-02,  -6.01691008e-02,
                         -1.14479102e-01,  -1.67592973e-01,  -2.11674437e-01,
                         -2.42035523e-01,  -2.71516562e-01,  -2.98970222e-01,
                         -3.19775641e-01,  -3.33672583e-01,  -3.10738087e-01,
                         -2.78342336e-01,  -2.77538955e-01,  -2.51708210e-01,
                         -1.83919221e-01,  -1.28268987e-01,  -9.73730609e-02,
                         -7.16411844e-02,  -4.23977971e-02,  -3.50418240e-02,
                         -5.73364422e-02,  -7.15044811e-02,  -6.56269491e-02,
                         -5.88655025e-02,  -4.99377213e-02,  -3.81161571e-02,
                         -6.24123141e-02,  -1.26807734e-01,  -1.59696624e-01,
                         -1.41814634e-01,  -1.24741308e-01,  -1.05958104e-01,
                         -6.83685765e-02,  -2.89430153e-02,   2.12140009e-03,
                          1.77874491e-02,   4.52882238e-02,   7.90656283e-02,
                          7.49903023e-02,   4.66526896e-02,   1.64180323e-02,
                          2.37083044e-02,   6.53267801e-02,   7.53858909e-02,
                          4.93050702e-02,   3.13049159e-03,  -2.00038310e-02,
                          2.08537914e-02,   8.05389434e-02,   1.16271257e-01,
                          1.13826491e-01,   6.10779971e-02,  -2.12828629e-02,
                         -9.96375233e-02,  -1.57666132e-01,  -1.67821318e-01,
                         -1.40673473e-01,  -1.21534787e-01,  -8.21889266e-02,
                         -2.67537329e-02,  -5.72008640e-03,   2.23416649e-02,
                          7.18894675e-02,   1.08672850e-01,   1.55029044e-01,
                          1.72978014e-01,   1.32506922e-01,   1.13620557e-01,
                          1.02372073e-01,   7.78833032e-02,   8.72214139e-02,
                          8.25890005e-02,   4.32277210e-02,  -1.26881190e-02,
                         -4.55977470e-02,   1.74449640e-03,   4.87164520e-02,
                          6.05142452e-02,   8.76193568e-02,   1.15368858e-01,
                          1.39384359e-01,   1.35658011e-01,   1.04704119e-01,
                          9.54194590e-02,   9.82625410e-02,   8.78560841e-02,
                          5.26515320e-02,   2.40349723e-03,  -3.95003185e-02,
                         -7.02536330e-02,  -8.87917280e-02,  -1.03412502e-01,
                         -1.20507516e-01,  -1.33781850e-01,  -1.45468146e-01,
                         -1.49735332e-01,  -1.45114541e-01,  -1.44179955e-01,
                         -1.35357961e-01,  -1.21468700e-01,  -1.22511119e-01,
                         -1.23006284e-01,  -1.18871585e-01,  -1.14612803e-01,
                         -1.08157314e-01,  -1.05341434e-01,  -9.95121077e-02,
                         -9.62470993e-02,  -9.30116177e-02,  -8.77174363e-02,
                         -8.85891244e-02,  -8.17820579e-02,  -7.62510523e-02,
                         -7.48137236e-02,  -6.82064146e-02,  -6.51711449e-02,
                         -6.18208386e-02,  -5.83500005e-02,  -5.26463650e-02,
                         -4.67685312e-02,  -4.59725112e-02,  -4.39854786e-02,
                         -4.22194526e-02,  -3.67112607e-02,  -3.14462036e-02,
                         -2.69540399e-02,  -1.69129521e-02,  -9.59772989e-03,
                         -4.30942560e-03,  -3.88527027e-04,   3.04452190e-03,
                          6.48813741e-03,   9.71855689e-03,   1.52747184e-02,
                          1.82617847e-02,   2.34176889e-02,   2.76754964e-02,
                          2.93417089e-02,   3.47142369e-02,   3.66452485e-02,
                          3.83875333e-02,   3.98546867e-02,   4.05218005e-02,
                          4.48901765e-02,   4.62329201e-02,   4.64721099e-02,
                          4.75077070e-02,   4.58390862e-02,   4.39834073e-02,
                          4.51100133e-02,   4.49406058e-02,   4.37997840e-02,
                          4.62603346e-02,   4.51295301e-02,   4.28150631e-02,
                          4.17693965e-02,   3.98641154e-02,   4.07091454e-02,
                          3.83573063e-02,   3.53602096e-02,   3.48240621e-02,
                          3.26513760e-02,   3.05928625e-02,   2.87957639e-02,
                          2.79699657e-02,   2.60488018e-02,   2.41748374e-02,
                          2.49992963e-02,   2.61775311e-02,   2.63037961e-02,
                          2.69510541e-02,   2.92159896e-02,   2.81230640e-02,
                          2.68217307e-02,   2.62436979e-02,   2.44611055e-02,
                          2.49888748e-02,   2.13500466e-02,   1.67130567e-02,
                          1.25208413e-02,   6.76049013e-03,   5.30965906e-03,
                          2.41306261e-03,  -6.50121365e-04,  -2.82744830e-03,
                         -5.50933182e-03,  -5.64903812e-03,  -6.91252761e-03,
                         -7.23050907e-03,  -8.27212259e-03,  -9.90350451e-03,
                         -9.44969803e-03,  -8.76264460e-03,  -7.90975709e-03,
                         -9.87968687e-03,  -1.16521847e-02,  -1.42754912e-02,
                         -1.49984797e-02,  -1.29335141e-02,  -1.62119307e-02,
                         -1.48188584e-02,  -1.38974246e-02,  -1.76676400e-02,
                         -1.60884019e-02,  -1.52282035e-02,  -1.16525814e-02,
                         -9.53506678e-03,  -1.08090593e-02,  -6.25168160e-03,
                         -5.58904232e-03,  -4.77630412e-03,   7.72307540e-05,
                          1.11670575e-04,   4.83537966e-04,   2.13274220e-03,
                          2.08924827e-03,   2.15866906e-03,   2.37871660e-03,
                          2.99106631e-03,   3.04958806e-03,   2.67655309e-03,
                          3.39675997e-03,   1.33424369e-03,  -1.97317195e-03,
                         -1.45560756e-04,   1.79289875e-03,   1.56673277e-03,
                          2.90013704e-04,  -1.99309108e-03,  -6.76154683e-04,
                         -2.41227870e-04,  -1.77075132e-03,  -1.56849669e-03,
                         -4.49931156e-03,  -8.09006859e-03,  -1.09024420e-02,
                         -1.60878990e-02,  -1.97160803e-02,  -2.39700507e-02,
                         -2.90604346e-02,  -2.97301207e-02,  -3.34878899e-02,
                         -3.95759754e-02,  -4.16713171e-02,  -4.58703712e-02,
                         -4.94827107e-02,  -5.22265397e-02,  -5.75817414e-02,
                         -6.28072470e-02,  -6.96156025e-02,  -7.42456242e-02,
                         -7.63976574e-02,  -8.09014291e-02,  -7.85884038e-02,
                         -5.00322878e-02,  -1.45016275e-02,  -1.76438573e-03,
                          3.33190598e-02,   8.91646147e-02,   1.22111864e-01,
                          1.75712287e-01,   2.34721452e-01,   2.62850314e-01,
                          2.99081713e-01,   3.23027641e-01,   3.09500366e-01,
                          2.90406287e-01,   3.02292168e-01,   3.37996900e-01,
                          3.35767180e-01,   3.01078916e-01,   2.68802166e-01,
                          2.17966750e-01,   1.73883364e-01,   1.87243372e-01,
                          2.32495174e-01,   2.62429953e-01,   2.88124830e-01,
                          3.00226331e-01,   2.70495206e-01,   2.57641375e-01,
                          2.90433526e-01,   3.39518607e-01,   3.94677401e-01,
                          4.13018942e-01,   4.01076227e-01,   3.99920434e-01,
                          3.94560248e-01,   3.89687687e-01,   3.83827507e-01,
                          3.70868713e-01,   3.65813106e-01,   3.58322889e-01,
                          3.50330770e-01,   3.44928384e-01,   3.39334816e-01,
                          3.38031411e-01,   3.32608759e-01,   3.30964148e-01,
                          3.32865804e-01,   3.30789238e-01,   3.32502842e-01,
                          3.31308126e-01,   3.28191757e-01,   3.26646775e-01,
                          3.24650317e-01,   3.25859249e-01,   3.23427737e-01,
                          3.18251252e-01,   3.13742459e-01,   3.08298230e-01,
                          3.04106116e-01,   2.98993260e-01,   2.94884801e-01,
                          2.89958537e-01,   2.83046275e-01,   2.77453870e-01,
                          2.70487815e-01,   2.66478211e-01,   2.63502777e-01,
                          2.58531660e-01,   2.56443024e-01,   2.53706127e-01,
                          2.52568483e-01,   2.53106505e-01,   2.52059251e-01,
                          2.54591525e-01,   2.56449014e-01,   2.54127055e-01,
                          2.52918690e-01,   2.52432823e-01,   2.47723639e-01,
                          2.43144527e-01,   2.42689356e-01,   2.37299070e-01,
                          2.31034473e-01,   2.28345007e-01,   2.23468870e-01,
                          2.20819965e-01,   2.17315674e-01,   2.13981226e-01,
                          2.13976592e-01,   2.11337790e-01,   2.13100642e-01,
                          2.15168431e-01,   2.12949380e-01,   2.14340732e-01,
                          2.14719191e-01,   2.17654690e-01,   2.21548200e-01,
                          2.19111770e-01,   2.19992489e-01,   2.20603555e-01,
                          2.17129931e-01,   2.15533048e-01,   2.10980371e-01,
                          2.04811841e-01,   2.01306239e-01,   1.98207498e-01,
                          1.94856241e-01,   1.89889029e-01,   1.85153380e-01,
                          1.83949068e-01,   1.83705226e-01,   1.83357701e-01,
                          1.85328871e-01,   1.86591581e-01,   1.85319558e-01,
                          1.85719937e-01,   1.86148360e-01,   1.86882317e-01,
                          1.92183167e-01,   1.95262402e-01,   1.94324166e-01,
                          1.95503727e-01,   1.94886610e-01,   1.93378329e-01,
                          1.94141060e-01,   1.91678971e-01,   1.90305576e-01,
                          1.91035151e-01,   1.87857777e-01,   1.86160803e-01,
                          1.84765145e-01,   1.82420835e-01,   1.83753461e-01,
                          1.83910087e-01,   1.85824186e-01,   1.89837530e-01,
                          1.89865008e-01,   1.92089751e-01,   1.95116162e-01,
                          1.96979731e-01,   2.01888934e-01,   2.04467446e-01,
                          2.04762295e-01,   2.05466285e-01,   2.05163673e-01,
                          2.04626217e-01,   2.02011690e-01,   1.98388427e-01,
                          1.96744055e-01,   1.95867658e-01,   1.94859996e-01,
                          1.94995761e-01,   1.96061090e-01,   1.96166322e-01,
                          1.98031127e-01,   2.00834855e-01,   2.00878605e-01,
                          2.01928407e-01,   2.03295335e-01,   2.03873724e-01,
                          2.05989808e-01,   2.06392139e-01,   2.06440434e-01,
                          2.07374781e-01,   2.07319111e-01,   2.07763970e-01,
                          2.06818759e-01,   2.05672473e-01,   2.06445590e-01,
                          2.06624314e-01,   2.07169265e-01,   2.07112417e-01,
                          2.05271602e-01,   2.04018414e-01,   2.03090891e-01,
                          2.01686814e-01,   2.00607494e-01,   2.00930506e-01,
                          2.02399939e-01,   2.05241323e-01,   2.08111405e-01,
                          2.08515465e-01,   2.08789453e-01,   2.09041312e-01,
                          2.09551513e-01,   2.10600942e-01,   2.09321409e-01,
                          2.09117085e-01,   2.07642823e-01,   2.03519598e-01,
                          2.01809764e-01,   1.98262274e-01,   1.96598843e-01,
                          1.97774947e-01,   1.96611658e-01,   1.99083000e-01,
                          2.01108515e-01,   2.02465504e-01,   2.05833465e-01,
                          2.04282477e-01,   2.04395339e-01,   2.05979317e-01,
                          2.04990536e-01,   2.06827462e-01,   2.07818717e-01,
                          2.07500353e-01,   2.07454294e-01,   2.06021413e-01,
                          2.04582736e-01,   2.05128059e-01,   2.07081094e-01,
                          2.07179442e-01,   2.08899096e-01,   2.09454000e-01,
                          2.08133087e-01,   2.11495042e-01,   2.11119652e-01,
                          2.10601956e-01,   2.13016599e-01,   2.13146210e-01,
                          2.19169617e-01,   2.21713498e-01,   2.22198546e-01,
                          2.28312343e-01,   2.27711275e-01,   2.31110245e-01,
                          2.34932229e-01,   2.28149414e-01,   2.31244206e-01,
                          2.31389582e-01,   2.00531498e-01,   1.54653415e-01,
                          1.15457430e-01,   7.87978843e-02,   4.02675197e-02,
                         -3.33668315e-03,  -5.95553219e-02,  -1.12145431e-01,
                         -1.32912740e-01,  -1.13914244e-01,  -9.67393294e-02,
                         -1.26584947e-01,  -1.61744863e-01,  -1.72935382e-01,
                         -1.89161003e-01,  -1.95857257e-01,  -2.03307584e-01,
                         -2.40951404e-01,  -2.53910363e-01,  -2.30780482e-01,
                         -2.46956021e-01,  -2.99861401e-01,  -3.34562033e-01,
                         -3.52346361e-01,  -3.60142767e-01,  -3.55924159e-01,
                         -3.51838380e-01,  -3.48947793e-01,  -3.46769959e-01,
                         -3.45537841e-01,  -3.43981504e-01,  -3.42323333e-01,
                         -3.38590771e-01,  -3.36905360e-01,  -3.33672136e-01,
                         -3.29230845e-01,  -3.28293025e-01,  -3.23986650e-01,
                         -3.21622312e-01,  -3.22122097e-01,  -3.19768906e-01,
                         -3.19200277e-01,  -3.18833202e-01,  -3.19365799e-01,
                         -3.21440220e-01,  -3.22449774e-01,  -3.24276954e-01,
                         -3.26150328e-01,  -3.27910572e-01,  -3.30624193e-01,
                         -3.33182901e-01,  -3.33007812e-01,  -3.32194090e-01,
                         -3.33149374e-01,  -3.34212929e-01,  -3.34370375e-01,
                         -3.31744015e-01,  -3.31196874e-01,  -3.29681188e-01,
                         -3.24898154e-01,  -3.24283600e-01,  -3.18919450e-01,
                         -3.13316405e-01,  -3.10721874e-01,  -3.03624362e-01,
                         -3.00935000e-01,  -2.95557499e-01,  -2.91866750e-01,
                         -2.93358326e-01,  -2.87704825e-01,  -2.86848128e-01,
                         -2.84975410e-01,  -2.82460928e-01,  -2.85761327e-01,
                         -2.82620966e-01,  -2.84288019e-01,  -2.85380900e-01,
                         -2.81852484e-01,  -2.83695519e-01,  -2.81412214e-01,
                         -2.79927462e-01,  -2.80072719e-01,  -2.80654252e-01,
                         -2.82673925e-01,  -2.80775517e-01,  -2.80162036e-01,
                         -2.77671546e-01,  -2.77433842e-01,  -2.77115017e-01,
                         -2.72353023e-01,  -2.73032516e-01,  -2.68785685e-01,
                         -2.65593261e-01,  -2.64130324e-01,  -2.56260306e-01,
                         -2.56273657e-01,  -2.51991421e-01,  -2.48202011e-01,
                         -2.53064603e-01,  -2.48504683e-01,  -2.47754171e-01,
                         -2.48595580e-01,  -2.42079422e-01,  -2.41924927e-01,
                         -2.40728825e-01,  -2.38006622e-01,  -2.39884958e-01,
                         -2.37462714e-01,  -2.35709459e-01,  -2.36850694e-01,
                         -2.32840121e-01,  -2.33394459e-01,  -2.34407231e-01,
                         -2.29307726e-01,  -2.31532231e-01,  -2.30883002e-01,
                         -2.28267044e-01,  -2.29545891e-01,  -2.23926499e-01,
                         -2.23840415e-01,  -2.23346815e-01,  -2.19880894e-01,
                         -2.23184630e-01,  -2.20365852e-01,  -2.19309792e-01,
                         -2.22714067e-01,  -2.24475861e-01,  -2.26168424e-01,
                         -2.28228956e-01,  -2.33163118e-01,  -2.32214019e-01,
                         -2.34053671e-01,  -2.34366596e-01,  -2.30779260e-01,
                         -2.37312511e-01,  -2.34176084e-01,  -2.36338556e-01,
                         -2.42466882e-01,  -2.35016197e-01,  -2.39917636e-01,
                         -2.38856599e-01,  -2.36611545e-01,  -2.41432756e-01,
                         -2.33931229e-01,  -2.36324221e-01,  -2.38828197e-01,
                         -2.38242179e-01,  -2.42612556e-01,  -2.43102998e-01,
                         -2.47179657e-01,  -2.49484807e-01,  -2.55088449e-01,
                         -2.55423099e-01,  -2.56336898e-01,  -2.59604841e-01,
                         -2.49262288e-01,  -2.54593223e-01,  -2.47084707e-01,
                         -2.47691169e-01,  -2.47615784e-01,  -1.48545280e-01,
                         -7.37376362e-02,  -6.22708276e-02,  -3.32274362e-02,
                         -2.99968533e-02,   1.04481634e-02,   7.55971372e-02,
                          1.38254270e-01,   2.51507759e-01,   3.11645448e-01,
                          3.35317105e-01,   3.73595715e-01,   3.68106037e-01,
                          3.64884168e-01,   3.66236538e-01,   3.56126606e-01,
                          3.56840253e-01,   3.50785583e-01,   3.48343611e-01,
                          3.47470313e-01,   3.41804415e-01,   3.40273380e-01,
                          3.39814752e-01,   3.41463387e-01,   3.41596812e-01,
                          3.44124794e-01,   3.46814275e-01,   3.49529922e-01,
                          3.51527631e-01,   3.48971605e-01,   3.53836536e-01,
                          3.56304705e-01,   3.56904268e-01,   3.58875245e-01,
                          3.55472744e-01,   3.59014481e-01,   3.56780440e-01,
                          3.52743387e-01,   3.53564411e-01,   3.45681548e-01,
                          3.45319718e-01,   3.43432218e-01,   3.39233905e-01,
                          3.43222618e-01,   3.38613093e-01,   3.39143962e-01,
                          3.41177881e-01,   3.36372852e-01,   3.38915229e-01,
                          3.35736394e-01,   3.31872821e-01,   3.32654089e-01,
                          3.28478843e-01,   3.27739716e-01,   3.24886560e-01,
                          3.21550727e-01,   3.22557747e-01,   3.16159815e-01,
                          3.11881423e-01,   3.12616855e-01,   3.08974832e-01,
                          3.09848130e-01,   3.10992002e-01,   3.07920218e-01,
                          3.09401661e-01,   3.08562249e-01,   3.05726200e-01,
                          3.04338962e-01,   3.01139385e-01,   3.03193927e-01,
                          3.03657025e-01,   2.99926579e-01,   3.01818013e-01,
                          3.03094417e-01,   3.04594070e-01,   3.07585418e-01,
                          3.08177412e-01,   3.08679342e-01,   3.06799084e-01,
                          3.06927204e-01,   3.08876455e-01,   3.09498876e-01,
                          3.12515020e-01,   3.13083768e-01,   3.13714355e-01,
                          3.14764649e-01,   3.12382430e-01,   3.13761145e-01,
                          3.14727306e-01,   3.14005613e-01,   3.14651281e-01,
                          3.13921690e-01,   3.16263199e-01,   3.15950572e-01,
                          3.12700242e-01,   3.14061910e-01,   3.13672870e-01,
                          3.12347859e-01,   3.11794221e-01,   3.12623382e-01,
                          3.14847469e-01,   3.11701626e-01,   3.11518639e-01,
                          3.11909527e-01,   3.07613909e-01,   3.10170770e-01,
                          3.10597986e-01,   3.09633911e-01,   3.12800258e-01,
                          3.10251802e-01,   3.13195825e-01,   3.17384273e-01,
                          3.13971251e-01,   3.14756632e-01,   3.14250141e-01,
                          3.14615548e-01,   3.17722023e-01,   3.15195501e-01,
                          3.14830482e-01,   3.14860493e-01,   3.13191414e-01,
                          3.14855933e-01,   3.15856546e-01,   3.16832513e-01,
                          3.18744212e-01,   3.20434332e-01,   3.20447654e-01,
                          3.20600986e-01,   3.21454167e-01,   3.17976743e-01,
                          3.16442996e-01,   3.15219581e-01,   3.11252832e-01,
                          3.11333716e-01,   3.08237463e-01,   3.03961694e-01,
                          3.02655250e-01,   2.98285663e-01,   2.96997488e-01,
                          2.94310331e-01,   2.88624525e-01,   2.87541300e-01,
                          2.84236938e-01,   2.83330321e-01,   2.86255985e-01,
                          2.85117626e-01,   2.85001874e-01,   2.86415160e-01,
                          2.89301842e-01,   2.95605958e-01,   2.99636096e-01,
                          3.01787823e-01,   3.02972049e-01,   3.03542554e-01,
                          3.05687785e-01,   3.05381119e-01,   3.04171652e-01,
                          3.05111378e-01,   3.04333240e-01,   3.02415758e-01,
                          3.02327037e-01,   3.00403446e-01,   2.97331393e-01,
                          2.95109600e-01,   2.92471945e-01,   2.91015804e-01,
                          2.90171593e-01,   2.88775980e-01,   2.86246985e-01,
                          2.83901930e-01,   2.82644838e-01,   2.79484242e-01,
                          2.74156660e-01,   2.69002646e-01,   2.64411271e-01,
                          2.60797292e-01,   2.57298559e-01,   2.53896147e-01,
                          2.50067115e-01,   2.45217368e-01,   2.42424905e-01,
                          2.44972408e-01,   2.45927438e-01,   2.14352250e-01,
                          1.67089805e-01,   1.81476131e-01,   2.32320547e-01,
                          2.40699649e-01,   2.28670374e-01,   2.08253279e-01,
                          1.61905438e-01,   1.26144990e-01,   1.02517925e-01,
                          6.95892423e-02,   4.22226824e-02,   2.38466896e-02,
                          3.22541036e-02,   6.11401722e-02,   5.25973290e-02,
                          1.08352667e-02,  -1.72523521e-02,  -2.82338820e-02,
                         -3.85978371e-02,  -6.51522353e-02,  -1.00780897e-01,
                         -1.22604415e-01,  -1.31145909e-01,  -1.23804100e-01,
                         -1.09033279e-01,  -1.04917794e-01,  -1.05991103e-01,
                         -1.07212253e-01,  -1.09016456e-01,  -1.01997606e-01,
                         -9.46289375e-02,  -9.52260122e-02,  -1.06009804e-01,
                         -1.30849436e-01,  -1.59687877e-01,  -1.80640101e-01,
                         -2.10048869e-01,  -2.74260521e-01,  -3.41674447e-01,
                         -3.75070274e-01,  -3.76924604e-01,  -3.71902317e-01,
                         -3.70846182e-01,  -3.68695796e-01,  -3.67481202e-01,
                         -3.67122948e-01,  -3.63418758e-01,  -3.59647036e-01,
                         -3.58416021e-01,  -3.55793446e-01,  -3.54517609e-01,
                         -3.53316903e-01,  -3.53251994e-01,  -3.54442924e-01,
                         -3.53452861e-01,  -3.49636137e-01,  -3.44958216e-01,
                         -3.42413962e-01,  -3.39984685e-01,  -3.39744717e-01,
                         -3.40963662e-01,  -3.41327131e-01,  -3.42258960e-01,
                         -3.43533784e-01,  -3.43694806e-01,  -3.37951481e-01,
                         -3.35463673e-01,  -3.33772928e-01,  -3.32016230e-01,
                         -3.32534850e-01,  -3.33687544e-01,  -3.30960304e-01,
                         -3.32086623e-01,  -3.31907064e-01,  -3.27676237e-01,
                         -3.28864068e-01,  -3.20379764e-01,  -3.18748355e-01,
                         -3.16175461e-01,  -3.11196774e-01,  -3.10522348e-01,
                         -3.08047622e-01,  -3.07685226e-01,  -3.06795418e-01,
                         -3.04058731e-01,  -3.05423945e-01,  -3.08233351e-01,
                         -3.07024926e-01,  -3.09206098e-01,  -3.11483294e-01,
                         -3.15118849e-01,  -3.16966832e-01,  -3.16536039e-01,
                         -3.18708122e-01,  -3.22141409e-01,  -3.25425088e-01,
                         -3.26008618e-01,  -3.27514499e-01,  -3.31022799e-01,
                         -3.34289759e-01,  -3.37500423e-01,  -3.38275433e-01,
                         -3.41002792e-01,  -3.41930956e-01,  -3.42475235e-01,
                         -3.42437506e-01,  -3.44126165e-01,  -3.45488310e-01,
                         -3.42478186e-01,  -3.40184867e-01,  -3.38251829e-01,
                         -3.35015923e-01,  -3.34971905e-01,  -3.34410131e-01,
                         -3.34463507e-01,  -3.35727453e-01,  -3.35628301e-01,
                         -3.36707622e-01,  -3.32154125e-01,  -3.37203979e-01,
                         -3.36417139e-01,  -3.36038232e-01,  -3.41208696e-01,
                         -3.43568236e-01,  -3.44826400e-01,  -3.46195787e-01,
                         -3.48329037e-01,  -3.50103855e-01,  -3.48525673e-01,
                         -3.39707911e-01,  -3.51367950e-01,  -3.60845745e-01,
                         -3.35764080e-01,  -3.25698912e-01,  -3.36642295e-01,
                         -3.10261846e-01,  -2.71131307e-01,  -2.38160729e-01,
                         -2.27425084e-01,  -2.24189997e-01,  -1.90072626e-01,
                         -1.84110343e-01,  -2.37803370e-01,  -2.54775107e-01,
                         -2.11370572e-01,  -1.97156355e-01,  -1.96389675e-01,
                         -1.82167798e-01,  -1.65806577e-01,  -1.48861185e-01,
                         -1.69698149e-01,  -1.97793737e-01,  -1.86263546e-01,
                         -1.58590123e-01,  -1.20269530e-01,  -8.39822516e-02,
                         -4.81800623e-02,   9.23495460e-03,   4.75099869e-02,
                          8.52744579e-02,   1.59090519e-01,   1.72250375e-01,
                          1.57399788e-01,   1.85219958e-01,   2.20313713e-01,
                          2.22454593e-01,   2.27617741e-01,   2.53040373e-01,
                          2.52640992e-01,   2.55068183e-01,   2.55176276e-01,
                          2.57153809e-01,   2.58743674e-01,   2.58609623e-01,
                          2.57996857e-01,   2.58366615e-01,   2.57267028e-01,
                          2.59937078e-01,   2.69381732e-01,   2.73138434e-01,
                          2.73982465e-01,   2.70076126e-01,   2.67518997e-01,
                          2.63502598e-01,   2.62462080e-01,   2.59050071e-01,
                          2.55277067e-01,   2.54694104e-01,   2.55635649e-01,
                          2.50026613e-01,   2.46626571e-01,   2.43179634e-01,
                          2.42667213e-01,   2.43372738e-01,   2.42071465e-01,
                          2.43224591e-01,   2.47132212e-01,   2.53114551e-01,
                          2.58631259e-01,   2.59716719e-01,   2.62591481e-01,
                          2.67412692e-01,   2.69361705e-01,   2.67690748e-01,
                          2.66563565e-01,   2.68255204e-01,   2.67639697e-01,
                          2.71986842e-01,   2.69604355e-01,   2.70526856e-01,
                          2.68199205e-01,   2.65613198e-01,   2.66179293e-01,
                          2.67086446e-01,   2.66302615e-01,   2.65990853e-01,
                          2.66996145e-01,   2.69588590e-01,   2.70499796e-01,
                          2.73715705e-01,   2.75415927e-01,   2.74070531e-01,
                          2.75312841e-01,   2.72316992e-01,   2.70707726e-01,
                          2.68341064e-01,   2.71229059e-01,   2.71856755e-01,
                          2.71646947e-01,   2.67046005e-01,   2.66275138e-01,
                          2.65651882e-01,   2.66941160e-01,   2.67745882e-01,
                          2.64991045e-01,   2.66462624e-01,   2.62451679e-01,
                          2.64874607e-01,   2.64131486e-01,   2.65850782e-01,
                          2.60671347e-01,   2.61567205e-01,   2.62996912e-01,
                          2.56630450e-01,   2.58314312e-01,   2.55847573e-01,
                          2.55791545e-01,   2.52734601e-01,   2.53312111e-01,
                          2.49665126e-01,   2.49262288e-01,   2.52543569e-01,
                          2.47235179e-01,   2.48217940e-01,   2.53398508e-01,
                          2.54952937e-01,   2.55393893e-01,   2.53386915e-01,
                          2.57627219e-01,   2.59500265e-01,   2.59302616e-01,
                          2.53129780e-01,   2.56441414e-01,   2.57109851e-01,
                          2.49084637e-01,   2.50126332e-01,   2.49836892e-01,
                          2.42818743e-01,   2.42445737e-01,   2.35419840e-01,
                          2.35055909e-01,   2.36661315e-01,   2.28433415e-01,
                          2.33666062e-01,   2.32125983e-01,   2.29378462e-01,
                          2.25900665e-01,   2.26524770e-01,   2.23266363e-01,
                          2.22468793e-01,   2.21418053e-01,   2.22610414e-01,
                          2.26253912e-01,   2.25174055e-01,   2.22731233e-01,
                          2.28088781e-01,   2.25534424e-01,   2.25405678e-01,
                          2.22998008e-01,   2.20694020e-01,   2.19798788e-01,
                          2.16183186e-01,   2.14874148e-01,   2.17211947e-01,
                          2.09395945e-01,   2.14123726e-01,   2.10960895e-01,
                          2.04430774e-01,   2.09537834e-01,   2.15245098e-01,
                          1.88390389e-01,   1.41494244e-01,   1.13948658e-01,
                          4.80104648e-02,   9.31494217e-03,   1.42806079e-02,
                          2.27817949e-02,   6.32449836e-02,   9.80761126e-02,
                          8.78131762e-02,   1.24362357e-01,   1.22392520e-01,
                          8.24153796e-02,   4.70329970e-02,   4.09824029e-02,
                          2.64271665e-02,  -9.65133868e-03,  -2.72325967e-02,
                         -6.30583465e-02,  -1.27543658e-01,  -1.76060066e-01,
                         -2.49315560e-01,  -3.65115821e-01,  -3.97719890e-01,
                         -3.98158401e-01,  -3.96823972e-01,  -3.98056209e-01,
                         -3.98108125e-01,  -3.99595916e-01,  -3.93860996e-01,
                         -3.90803874e-01,  -3.90912205e-01,  -3.88152212e-01,
                         -3.84640694e-01,  -3.82312179e-01,  -3.79698783e-01,
                         -3.73989850e-01,  -3.70091140e-01,  -3.69626999e-01,
                         -3.67177725e-01,  -3.63879025e-01,  -3.63495201e-01,
                         -3.64712328e-01,  -3.64002824e-01,  -3.61558199e-01,
                         -3.61591637e-01,  -3.67348731e-01,  -3.67402762e-01,
                         -3.67355078e-01,  -3.67093235e-01,  -3.66206616e-01,
                         -3.67188960e-01,  -3.65872353e-01,  -3.65760088e-01,
                         -3.63338679e-01,  -3.60286325e-01,  -3.60025316e-01,
                         -3.57545197e-01,  -3.53121698e-01,  -3.50139409e-01,
                         -3.48957717e-01,  -3.51756454e-01,  -3.48223627e-01,
                         -3.48107249e-01,  -3.48333061e-01,  -3.50580394e-01,
                         -3.51843417e-01,  -3.55187118e-01,  -3.56594443e-01,
                         -3.59846592e-01,  -3.59862626e-01,  -3.64125967e-01,
                         -3.62594008e-01,  -3.64581108e-01,  -3.60602677e-01,
                         -3.54166985e-01,  -3.52642804e-01,  -3.48711818e-01,
                         -3.44217092e-01,  -3.40958029e-01,  -3.40692043e-01,
                         -3.39163333e-01,  -3.38961482e-01,  -3.37091833e-01,
                         -3.36538076e-01,  -3.35564911e-01,  -3.38583916e-01,
                         -3.39016378e-01,  -3.43605101e-01,  -3.43700320e-01,
                         -3.46938640e-01,  -3.49079251e-01,  -3.46002162e-01,
                         -3.47486347e-01,  -3.46519828e-01,  -3.42114568e-01,
                         -3.43663037e-01,  -3.42723042e-01,  -3.37367177e-01,
                         -3.35676908e-01,  -3.31879348e-01,  -3.26011449e-01,
                         -3.23105037e-01,  -3.20006371e-01,  -3.19935650e-01,
                         -3.17839384e-01,  -3.16755295e-01,  -3.13221395e-01,
                         -3.13200057e-01,  -3.14625204e-01,  -3.14086378e-01,
                         -3.18522871e-01,  -3.21870774e-01,  -3.22485238e-01,
                         -3.27246875e-01,  -3.25540632e-01,  -3.19102079e-01,
                         -3.20788294e-01,  -3.19090515e-01,  -3.14099014e-01,
                         -3.12214255e-01,  -3.11950743e-01,  -3.11819732e-01,
                         -3.11682910e-01,  -3.11691910e-01,  -3.12506080e-01,
                         -3.11869889e-01,  -3.12477410e-01,  -3.08295071e-01,
                         -3.09452266e-01,  -3.06453705e-01,  -3.04372609e-01,
                         -3.02004963e-01,  -3.03843826e-01,  -3.00205827e-01,
                         -2.99470246e-01,  -2.99832314e-01,  -2.97281504e-01,
                         -2.94197083e-01,  -2.96279728e-01,  -2.97417194e-01,
                         -2.91533858e-01,  -2.94948131e-01,  -2.91678518e-01,
                         -2.90599167e-01,  -2.87124097e-01,  -2.91485727e-01,
                         -2.88330495e-01,  -2.87464917e-01,  -2.86748677e-01,
                         -2.87049055e-01,  -2.84451813e-01,  -2.83936977e-01,
                         -2.82364070e-01,  -2.78294623e-01,  -2.80400723e-01,
                         -2.79030621e-01,  -2.78719693e-01,  -2.77139217e-01,
                         -2.81649590e-01,  -2.79316336e-01,  -2.80800551e-01,
                         -2.82319844e-01,  -2.80417532e-01,  -2.81329066e-01,
                         -2.82392710e-01,  -2.77279913e-01,  -2.74798334e-01,
                         -2.75137097e-01,  -2.73802340e-01,  -2.73740888e-01,
                         -2.70285994e-01,  -2.67097443e-01,  -2.65627921e-01,
                         -2.62539387e-01,  -2.60951072e-01,  -2.58751690e-01,
                         -2.61667997e-01,  -2.60008901e-01,  -2.57227451e-01,
                         -2.57071614e-01,  -2.57566333e-01,  -2.55696833e-01,
                         -2.54502535e-01,  -2.51516819e-01,  -2.52406269e-01,
                         -2.57166207e-01,  -2.53816247e-01,  -2.56943583e-01,
                         -2.59375900e-01,  -2.59240896e-01,  -2.58392692e-01,
                         -2.63135731e-01,  -2.60289699e-01,  -2.62884408e-01,
                         -2.62968004e-01,  -2.63173580e-01,  -2.64020920e-01,
                         -2.65310287e-01,  -2.65772223e-01,  -2.64758587e-01,
                         -2.63264418e-01,  -2.64429301e-01,  -2.66392112e-01,
                         -2.61951119e-01,  -2.61675209e-01,  -2.59463459e-01,
                         -2.62075603e-01,  -2.60193139e-01,  -2.61068106e-01,
                         -2.62309670e-01,  -2.64816403e-01,  -2.65086919e-01,
                         -2.68526226e-01,  -2.69199580e-01,  -2.72980958e-01,
                         -2.77227640e-01,  -2.81243026e-01,  -2.85610825e-01,
                         -2.85179973e-01,  -2.86190927e-01,  -2.88207561e-01,
                         -2.92684227e-01,  -2.92519331e-01,  -2.93447047e-01,
                         -2.97468245e-01,  -2.97354788e-01,  -2.75933892e-01,
                         -2.34719992e-01,  -1.87922060e-01,  -1.63581237e-01,
                         -1.39913723e-01,  -8.41651037e-02,  -2.91937366e-02,
                          1.93467848e-02,   7.46212080e-02,   9.49146450e-02,
                          9.94009525e-02,   1.34069324e-01,   1.50475979e-01,
                          1.41603544e-01,   1.53793737e-01,   1.70176953e-01,
                          1.76841438e-01,   1.65095270e-01,   1.46277815e-01,
                          1.72568887e-01,   2.23595470e-01,   2.50036150e-01,
                          2.80100048e-01,   3.10730875e-01,   3.13913614e-01,
                          3.12618732e-01,   3.11408699e-01,   3.11041087e-01,
                          3.12682390e-01,   3.12472492e-01,   3.09515715e-01,
                          3.10198516e-01,   3.08358938e-01,   3.07584852e-01,
                          3.05362761e-01,   3.02657634e-01,   3.01893085e-01,
                          3.00236136e-01,   2.98769355e-01,   2.97875702e-01,
                          2.96425790e-01,   2.93634832e-01,   2.94683695e-01,
                          2.95670211e-01,   2.94502497e-01,   2.93538302e-01,
                          2.97846228e-01,   2.98436284e-01,   2.98965693e-01,
                          3.03006411e-01,   3.04284155e-01,   3.02238852e-01,
                          3.04670960e-01,   3.10083032e-01,   3.13004524e-01,
                          3.12172562e-01,   3.13842922e-01,   3.18134606e-01,
                          3.17084640e-01,   3.19409043e-01,   3.21864784e-01,
                          3.19095910e-01,   3.21538657e-01,   3.23548943e-01,
                          3.19620550e-01,   3.24348271e-01,   3.27932686e-01,
                          3.28532159e-01,   3.32286030e-01,   3.33531082e-01,
                          3.32813889e-01,   3.31550747e-01,   3.29486549e-01,
                          3.32699209e-01,   3.34185004e-01,   3.29955578e-01,
                          3.30254257e-01,   3.30503106e-01,   3.28973800e-01,
                          3.32489461e-01,   3.32128882e-01,   3.30625743e-01,
                          3.34242016e-01,   3.37494105e-01,   3.38647246e-01,
                          3.37591231e-01,   3.38486820e-01,   3.40855539e-01,
                          3.37800771e-01,   3.37805897e-01,   3.36206079e-01,
                          3.36609036e-01,   3.39614123e-01,   3.38628709e-01,
                          3.35929632e-01,   3.39277506e-01,   3.42826396e-01,
                          3.44069749e-01,   3.44224632e-01,   3.42596859e-01,
                          3.46646249e-01,   3.49239916e-01,   3.50576460e-01,
                          3.50198686e-01,   3.46507609e-01,   3.45104575e-01,
                          3.48014176e-01,   3.47866267e-01,   3.47266018e-01,
                          3.44525218e-01,   3.40798020e-01,   3.39319855e-01,
                          3.41365367e-01,   3.39799434e-01,   3.40732127e-01,
                          3.38609695e-01,   3.36120456e-01,   3.36433738e-01,
                          3.36530238e-01,   3.35713506e-01,   3.33717167e-01,
                          3.35918218e-01,   3.34306985e-01,   3.35642159e-01,
                          3.37702930e-01,   3.38431388e-01,   3.42009485e-01,
                          3.40492547e-01,   3.42869848e-01,   3.42580199e-01,
                          3.44758898e-01,   3.44211638e-01,   3.41041327e-01,
                          3.42330396e-01,   3.40985328e-01,   3.38645130e-01,
                          3.36889267e-01,   3.31291556e-01,   3.33473027e-01,
                          3.28438342e-01,   3.29019338e-01,   3.31155002e-01,
                          3.30780894e-01,   3.34450334e-01,   3.36556405e-01,
                          3.34968001e-01,   3.35195512e-01,   3.36828679e-01,
                          3.39413166e-01,   3.43129486e-01,   3.41081649e-01,
                          3.39860231e-01,   3.38758588e-01,   3.37458730e-01,
                          3.36126626e-01,   3.38705420e-01,   3.39728028e-01,
                          3.38620156e-01,   3.39980185e-01,   3.39901239e-01,
                          3.36043239e-01,   3.34438741e-01,   3.34241241e-01,
                          3.29463422e-01,   3.28974307e-01,   3.24123174e-01,
                          3.20254892e-01,   3.19481045e-01,   3.18016618e-01,
                          3.14808160e-01,   3.15391183e-01,   3.14912945e-01,
                          3.14649403e-01,   3.12148511e-01,   3.13424498e-01,
                          3.16707522e-01,   3.17004383e-01,   3.19965988e-01,
                          3.21073681e-01,   3.19526911e-01,   3.16867888e-01,
                          3.17812502e-01,   3.19757104e-01,   3.19889933e-01,
                          3.15280795e-01,   3.12104285e-01,   3.11141700e-01,
                          3.14086616e-01,   3.12327683e-01,   3.09303194e-01,
                          3.09372574e-01,   3.06543291e-01,   3.09029192e-01,
                          3.14371020e-01,   3.16519558e-01,   3.15063894e-01,
                          3.10620338e-01,   2.77467906e-01,   2.53100365e-01,
                          2.32266575e-01,   2.14553937e-01,   2.22211942e-01,
                          2.41759345e-01,   2.56202817e-01,   2.55760223e-01,
                          2.55212009e-01,   2.60834903e-01,   2.64741719e-01,
                          2.92326808e-01,   3.05774659e-01,   2.99488276e-01,
                          2.99037009e-01,   2.95728058e-01,   2.96634912e-01,
                          2.87890553e-01,   2.87744462e-01,   2.81588286e-01,
                          2.77368665e-01,   2.75967896e-01,   2.72392631e-01,
                          2.72068799e-01,   2.68191844e-01,   2.66218811e-01,
                          2.69033164e-01,   2.70708323e-01,   2.69295633e-01,
                          2.64277458e-01,   2.62797624e-01,   2.58794993e-01,
                          2.61404604e-01,   2.58151740e-01,   2.55897731e-01,
                          2.54445434e-01,   2.52276063e-01,   2.51856089e-01,
                          2.49769375e-01,   2.45715111e-01,   2.45541960e-01,
                          2.41033241e-01,   2.35647395e-01,   2.26450652e-01,
                          2.35159829e-01,   2.33515590e-01,   2.28344768e-01,
                          2.07826242e-01,   1.89838096e-01,   1.75281897e-01,
                          1.65076956e-01,   1.26110539e-01,   1.01667739e-01,
                          1.05978236e-01,   9.59527493e-02,   8.98722261e-02,
                          8.72048438e-02,   6.86636269e-02,   7.42176399e-02,
                          9.21627432e-02,   1.18202098e-01,   1.40494317e-01,
                          1.43306106e-01,   1.34428337e-01,   1.20173551e-01,
                          1.21203125e-01,   1.45803243e-01,   1.68422446e-01,
                          1.62283525e-01,   1.58861384e-01,   1.58241823e-01,
                          1.60805419e-01,   1.47808716e-01,   8.69720876e-02,
                          1.20269665e-02,  -4.18379754e-02,  -5.91625273e-02,
                         -4.43328023e-02,  -3.42607833e-02,  -6.27098829e-02,
                         -1.08585179e-01,  -1.29244030e-01,  -1.24700479e-01,
                         -1.19451396e-01,  -1.58676833e-01,  -1.98830605e-01,
                         -2.15627536e-01,  -2.12494567e-01,  -1.85498402e-01,
                         -1.59991756e-01,  -1.57946303e-01,  -1.45980746e-01,
                         -1.33975118e-01,  -1.37594104e-01,  -1.21627487e-01,
                         -6.30391687e-02,  -5.77932484e-02,  -1.04262829e-01,
                         -1.62015915e-01,  -1.77024513e-01,  -1.60453394e-01,
                         -1.54527977e-01,  -1.68291703e-01,  -2.04876274e-01,
                         -2.28383496e-01,  -2.07645148e-01,  -2.11925969e-01,
                         -2.35074386e-01,  -2.23006800e-01,  -1.79028779e-01,
                         -1.30501047e-01,  -1.23878576e-01,  -1.73400000e-01,
                         -2.15216964e-01,  -2.41056740e-01,  -2.68568188e-01,
                         -2.73081034e-01,  -2.67636955e-01,  -2.92965502e-01,
                         -3.35350275e-01,  -3.77405792e-01,  -3.92223984e-01,
                         -3.71899545e-01,  -3.48713070e-01,  -3.43744844e-01,
                         -3.55773568e-01,  -3.78605217e-01,  -3.85829061e-01,
                         -3.87742192e-01,  -3.94242018e-01,  -3.97134364e-01,
                         -4.35706913e-01,  -4.83238637e-01,  -4.74019885e-01,
                         -4.54341918e-01,  -4.36080724e-01,  -4.23269600e-01,
                         -4.40734982e-01,  -4.16915923e-01,  -3.86929750e-01,
                         -3.80784392e-01,  -3.59095067e-01,  -3.20408255e-01,
                         -2.99784780e-01,  -3.16184014e-01,  -3.32009792e-01,
                         -3.50757539e-01,  -3.86373311e-01,  -3.69599283e-01,
                         -3.30418140e-01,  -3.47184807e-01,  -3.98020029e-01,
                         -4.42875475e-01,  -4.77509797e-01,  -4.66351718e-01,
                         -4.26915824e-01,  -4.21027243e-01,  -4.40254062e-01,
                         -4.55556661e-01,  -4.55880046e-01,  -4.69486743e-01,
                         -5.03324747e-01,  -5.11888683e-01,  -5.05205572e-01,
                         -5.05712032e-01,  -5.03838062e-01,  -5.02822578e-01,
                         -5.05381107e-01,  -5.01349866e-01,  -4.96630818e-01,
                         -4.98245686e-01,  -4.98746574e-01,  -4.99332041e-01,
                         -5.00134766e-01,  -4.95133579e-01,  -4.92244571e-01,
                         -4.90567714e-01,  -4.87479866e-01,  -4.90229815e-01,
                         -4.90674466e-01,  -4.89073664e-01,  -4.85237360e-01,
                         -4.80154276e-01,  -4.80099529e-01,  -4.78016526e-01,
                         -4.73045319e-01,  -4.70839798e-01,  -4.66340244e-01,
                         -4.61028755e-01,  -4.58286434e-01,  -4.55944687e-01,
                         -4.51109290e-01,  -4.46568042e-01,  -4.47281271e-01,
                         -4.41255510e-01,  -4.37655866e-01,  -4.37057555e-01,
                         -4.31694090e-01,  -4.27388936e-01,  -4.26339746e-01,
                         -4.22227412e-01,  -4.20011848e-01,  -4.18409884e-01,
                         -4.20249403e-01,  -4.15459305e-01,  -4.13587362e-01,
                         -4.12760526e-01,  -4.08701003e-01,  -4.08520043e-01,
                         -4.07186687e-01,  -4.05567169e-01,  -4.05308783e-01,
                         -3.99564207e-01,  -4.00189757e-01,  -3.99274558e-01,
                         -3.95672023e-01,  -3.89972061e-01,  -3.83858025e-01,
                         -3.77864361e-01,  -3.74417603e-01,  -3.72973025e-01,
                         -3.69335622e-01,  -3.64529848e-01,  -3.60531986e-01,
                         -3.55032772e-01,  -3.54318976e-01,  -3.53695273e-01,
                         -3.49571884e-01,  -3.45186353e-01,  -3.44560742e-01,
                         -3.39300096e-01,  -3.35371852e-01,  -3.37651223e-01,
                         -3.37089926e-01,  -3.36686015e-01,  -3.33855093e-01,
                         -3.33873540e-01,  -3.34504396e-01,  -3.33559453e-01,
                         -3.33991259e-01,  -3.34615856e-01,  -3.34898055e-01,
                         -3.29981774e-01,  -3.25666070e-01,  -3.26001704e-01,
                         -3.21632355e-01,  -3.19041699e-01,  -3.16522896e-01,
                         -3.11677665e-01,  -3.05300862e-01,  -3.04487407e-01,
                         -3.05299848e-01,  -3.01912069e-01,  -3.00798237e-01,
                         -2.97491968e-01,  -2.95740575e-01,  -2.93246776e-01,
                         -2.84701973e-01,  -2.84461051e-01,  -2.85288006e-01,
                         -2.82214582e-01,  -2.79122800e-01,  -2.74681628e-01,
                         -2.73918778e-01,  -2.75662810e-01,  -2.73760051e-01,
                         -2.73107857e-01,  -2.74730027e-01,  -2.72400737e-01,
                         -2.69693583e-01,  -2.66681463e-01,  -2.63291419e-01,
                         -2.65418530e-01,  -2.63257533e-01,  -2.58444548e-01,
                         -2.53775030e-01,  -2.49161780e-01,  -2.51043588e-01,
                         -2.47778207e-01,  -2.45128050e-01,  -2.42695093e-01,
                         -2.35799581e-01,  -2.34908834e-01,  -2.32089669e-01,
                         -2.30879784e-01,  -2.31337428e-01,  -2.27890730e-01,
                         -2.28802487e-01,  -2.26862162e-01,  -2.24175170e-01,
                         -2.23655462e-01,  -2.23726064e-01,  -2.26951644e-01,
                         -2.26254702e-01,  -2.24402770e-01,  -2.24664241e-01,
                         -2.25054309e-01,  -2.26035386e-01,  -2.23957911e-01,
                         -2.19397172e-01,  -2.17227653e-01,  -2.16765627e-01,
                         -2.15563372e-01,  -2.11033940e-01,  -2.06692517e-01,
                         -2.06175372e-01,  -2.04567999e-01,  -1.99640289e-01,
                         -1.96338832e-01,  -1.92931131e-01,  -1.86346471e-01,
                         -1.84302121e-01,  -1.83635011e-01,  -1.76251411e-01,
                         -1.71913579e-01,  -1.68953434e-01,  -1.65629327e-01,
                         -1.64157122e-01,  -1.60044909e-01,  -1.59704104e-01,
                         -1.59125969e-01,  -1.55575559e-01,  -1.51397288e-01,
                         -1.46953002e-01,  -1.47936627e-01,  -1.46094471e-01,
                         -1.44629657e-01,  -1.44981191e-01,  -1.40561044e-01,
                         -1.37573689e-01,  -1.30668089e-01,  -1.23387672e-01,
                         -1.18983239e-01,  -1.14810869e-01,  -1.12886094e-01,
                         -1.06914669e-01,  -1.04112804e-01,  -1.01582550e-01,
                         -9.55415964e-02,  -9.48458910e-02,  -9.31224823e-02,
                         -9.28589255e-02,  -9.44651514e-02,  -9.33397934e-02,
                         -9.19762999e-02,  -8.96794200e-02,  -8.77467096e-02,
                         -8.48698765e-02,  -8.19457248e-02,  -7.81571642e-02,
                         -7.37244263e-02,  -7.28169754e-02,  -7.03901350e-02,
                         -6.62854984e-02,  -6.31880164e-02,  -6.19760230e-02,
                         -6.02124371e-02,  -5.55282868e-02,  -5.59709668e-02,
                         -5.67103624e-02,  -5.16236499e-02,  -5.02728969e-02,
                         -5.07290885e-02,  -4.89765219e-02,  -4.86121997e-02,
                         -4.53826673e-02,  -4.21202965e-02,  -4.29042317e-02,
                         -4.06764746e-02,  -3.80425118e-02,  -3.78236994e-02,
                         -3.80034298e-02,  -4.16065454e-02,  -4.21463661e-02,
                         -3.72228585e-02,  -3.47984321e-02,  -3.42270210e-02,
                         -3.39805782e-02,  -3.37886997e-02,  -3.20232473e-02,
                         -3.38901393e-02,  -3.84818017e-02,  -4.30038348e-02,
                         -4.65360619e-02,  -4.27257381e-02,  -4.51680459e-02,
                         -5.33943288e-02,  -5.31091988e-02,  -5.61087392e-02,
                         -5.42831868e-02,  -5.45026697e-02,  -6.09953590e-02,
                         -3.28061581e-02,   2.11467110e-02,   6.35349825e-02,
                          7.72850513e-02,   1.02431551e-01,   1.89368814e-01,
                          2.80817956e-01,   3.38441342e-01,   3.78281564e-01,
                          4.11106139e-01,   4.39956009e-01,   4.27501678e-01,
                          3.99974138e-01,   3.88910830e-01,   3.78063560e-01,
                          3.87154639e-01,   3.95134836e-01,   3.91573995e-01,
                          4.03702945e-01,   4.42294627e-01,   5.00464499e-01,
                          5.24006248e-01,   5.17291009e-01,   5.17796874e-01,
                          5.13567805e-01,   5.10194182e-01,   5.08501649e-01,
                          5.07775128e-01,   5.10159850e-01,   5.07061481e-01,
                          5.06624043e-01,   5.08228004e-01,   5.04382670e-01,
                          4.98554528e-01,   4.95883137e-01,   4.92967933e-01,
                          4.87588793e-01,   4.83107328e-01,   4.78660941e-01,
                          4.75833595e-01,   4.71138358e-01,   4.67490405e-01,
                          4.64121848e-01,   4.57754433e-01,   4.57597673e-01,
                          4.53221679e-01,   4.47954714e-01,   4.48106378e-01,
                          4.42117453e-01,   4.39650029e-01,   4.38990355e-01,
                          4.37019885e-01,   4.35445994e-01,   4.31031495e-01,
                          4.31116521e-01,   4.27465737e-01,   4.21868861e-01,
                          4.21024829e-01,   4.17384684e-01,   4.16207939e-01,
                          4.15226907e-01,   4.11511123e-01,   4.08663660e-01,
                          4.04338539e-01,   4.02554393e-01,   4.03087616e-01,
                          3.99940640e-01,   3.97795677e-01,   3.98632497e-01,
                          3.94042909e-01,   3.88003707e-01,   3.86468530e-01,
                          3.86628181e-01,   3.87469828e-01,   3.86723816e-01,
                          3.87534320e-01,   3.86327267e-01,   3.83395582e-01,
                          3.86637717e-01,   3.86299253e-01,   3.83366346e-01,
                          3.81760567e-01,   3.79250497e-01,   3.79195601e-01,
                          3.74568850e-01,   3.68507892e-01,   3.65094215e-01,
                          3.60122710e-01,   3.55327368e-01,   3.50292295e-01,
                          3.46790165e-01,   3.41634542e-01,   3.34924638e-01,
                          3.30992103e-01,   3.28577161e-01,   3.29374015e-01,
                          3.28619272e-01,   3.24856728e-01,   3.22201878e-01,
                          3.21162313e-01,   3.20463002e-01,   3.17097723e-01,
                          3.14190090e-01,   3.11769694e-01,   3.09784889e-01,
                          3.08099419e-01,   3.03344399e-01,   3.00062001e-01,
                          2.98823804e-01,   2.96375066e-01,   2.91809440e-01,
                          2.88559973e-01,   2.86145329e-01,   2.81624228e-01,
                          2.80826837e-01,   2.78762400e-01,   2.74551153e-01,
                          2.71121711e-01,   2.66782880e-01,   2.66614467e-01,
                          2.63882786e-01,   2.61508495e-01,   2.61311829e-01,
                          2.57391125e-01,   2.56936461e-01,   2.54485965e-01,
                          2.52544880e-01,   2.49820828e-01,   2.42101878e-01,
                          2.41861999e-01,   2.39396930e-01,   2.34261096e-01,
                          2.32076466e-01,   2.28505939e-01,   2.27262855e-01,
                          2.21486032e-01,   2.17159107e-01,   2.16925234e-01,
                          2.13037580e-01,   2.09920555e-01,   2.04978511e-01,
                          2.03697830e-01,   2.03465670e-01,   1.97060943e-01,
                          1.95925087e-01,   1.96180776e-01,   1.93091929e-01,
                          1.90514117e-01,   1.87726051e-01,   1.87883228e-01,
                          1.87628761e-01,   1.85622483e-01,   1.85716107e-01,
                          1.83019698e-01,   1.79667130e-01,   1.79876104e-01,
                          1.78440109e-01,   1.77128941e-01,   1.74537256e-01,
                          1.69252023e-01,   1.67705953e-01,   1.66119248e-01,
                          1.65580913e-01,   1.65022567e-01,   1.59384504e-01,
                          1.56446010e-01,   1.54150203e-01,   1.50376216e-01,
                          1.47558644e-01,   1.44463196e-01,   1.43769801e-01,
                          1.42659649e-01,   1.41367868e-01,   1.39254451e-01,
                          1.36228547e-01,   1.36079326e-01,   1.34370029e-01,
                          1.34470239e-01,   1.37254551e-01,   1.37080207e-01,
                          1.34926036e-01,   1.31822780e-01,   1.31366089e-01,
                          1.31185979e-01,   1.28710032e-01,   1.27655655e-01,
                          1.27661288e-01,   1.26909286e-01,   1.25685424e-01,
                          1.26108199e-01,   1.25403613e-01,   1.24270566e-01,
                          1.24605462e-01,   1.23953663e-01,   1.23535283e-01,
                          1.19938754e-01,   1.20054089e-01,   1.25532612e-01,
                          1.24554187e-01,   1.24152556e-01,   1.23814046e-01,
                          1.21007085e-01,   1.22054130e-01,   1.21681467e-01,
                          1.23399086e-01,   1.25019506e-01,   1.21875860e-01,
                          1.23351462e-01,   1.24924339e-01,   1.23691380e-01,
                          1.24750778e-01,   1.24305688e-01,   1.24166273e-01,
                          1.25545815e-01,   1.24219671e-01,   1.23965867e-01,
                          1.25847951e-01,   1.26036555e-01,   1.25645682e-01,
                          1.24800168e-01,   1.24075912e-01,   1.25101268e-01,
                          1.26246095e-01,   1.26626775e-01,   1.26404926e-01,
                          1.26096189e-01,   1.25670850e-01,   1.24840818e-01,
                          1.23854190e-01,   1.23194620e-01,   1.23555638e-01,
                          1.22268297e-01,   1.20633364e-01,   1.20996416e-01,
                          1.20727405e-01,   1.21088989e-01,   1.20316669e-01,
                          1.18362300e-01,   1.20340191e-01,   1.20812036e-01,
                          1.18760191e-01,   1.18600875e-01,   1.16161376e-01,
                          1.13758147e-01,   1.14799991e-01,   1.14221588e-01,
                          1.14021003e-01,   1.15770958e-01,   1.14461482e-01,
                          1.13272659e-01,   1.13288835e-01,   1.11962728e-01,
                          1.13061339e-01,   1.12893499e-01,   1.10544689e-01,
                          1.10545374e-01,   1.08069159e-01,   1.06435589e-01,
                          1.06886186e-01,   1.04265645e-01,   1.05127268e-01,
                          1.05176955e-01,   1.03049703e-01,   1.03735536e-01,
                          9.99847054e-02,   1.00461185e-01,   9.12097767e-02,
                          5.32065630e-02,   1.84211787e-02,  -2.59351525e-02,
                         -9.66862440e-02,  -1.45787507e-01,  -1.78064987e-01,
                         -2.14421138e-01,  -2.43680954e-01,  -2.83118933e-01,
                         -3.36967349e-01,  -3.96169901e-01,  -4.45706278e-01,
                         -4.65985417e-01,  -4.70353991e-01,  -4.58059043e-01,
                         -4.51419026e-01,  -4.89470452e-01,  -5.20196497e-01,
                         -5.16085386e-01,  -5.15524983e-01,  -5.13462365e-01,
                         -5.07861078e-01,  -5.06803572e-01,  -5.01615286e-01,
                         -4.98136848e-01,  -4.95940119e-01,  -4.93115962e-01,
                         -4.91643071e-01,  -4.88213360e-01,  -4.87188280e-01,
                         -4.84730184e-01,  -4.80074137e-01,  -4.78614867e-01,
                         -4.74158734e-01,  -4.71202850e-01,  -4.72267389e-01,
                         -4.69806135e-01,  -4.66882348e-01,  -4.64363128e-01,
                         -4.61929232e-01,  -4.61294532e-01,  -4.59361464e-01,
                         -4.55922514e-01,  -4.52497572e-01,  -4.51039881e-01,
                         -4.50655758e-01,  -4.47458178e-01,  -4.42367524e-01,
                         -4.37355608e-01,  -4.34319168e-01,  -4.32721138e-01,
                         -4.30013031e-01,  -4.27563936e-01,  -4.24932122e-01,
                         -4.22502518e-01,  -4.21121091e-01,  -4.18529242e-01,
                         -4.16438788e-01,  -4.14112300e-01,  -4.09656018e-01,
                         -4.05915439e-01,  -4.02662873e-01,  -4.00172532e-01,
                         -3.98157477e-01,  -3.94354373e-01,  -3.90725225e-01,
                         -3.86929840e-01,  -3.82607609e-01,  -3.80639076e-01,
                         -3.79633844e-01,  -3.77784401e-01,  -3.75115991e-01,
                         -3.70928645e-01,  -3.67042929e-01,  -3.65841299e-01,
                         -3.64919066e-01,  -3.62032533e-01,  -3.60113502e-01,
                         -3.58962178e-01,  -3.55537862e-01,  -3.51832867e-01,
                         -3.49643469e-01,  -3.48226428e-01,  -3.46317440e-01,
                         -3.43400955e-01,  -3.41301292e-01,  -3.39851558e-01,
                         -3.38195026e-01,  -3.36295813e-01,  -3.34488630e-01,
                         -3.34679514e-01,  -3.33681345e-01,  -3.29712868e-01,
                         -3.27230364e-01,  -3.23932469e-01,  -3.18192422e-01,
                         -3.14232618e-01,  -3.11581045e-01,  -3.08862656e-01,
                         -3.05878639e-01,  -3.01953465e-01,  -2.97490954e-01,
                         -2.92885125e-01,  -2.89190054e-01,  -2.86118686e-01,
                         -2.82985777e-01,  -2.80400068e-01,  -2.77713060e-01,
                         -2.75078237e-01,  -2.71932840e-01,  -2.67591268e-01,
                         -2.63908803e-01,  -2.61220783e-01,  -2.60341018e-01,
                         -2.60675311e-01,  -2.58698404e-01,  -2.56417572e-01,
                         -2.56395608e-01,  -2.57344723e-01,  -2.58653432e-01,
                         -2.59517431e-01,  -2.60266364e-01,  -2.59622812e-01,
                         -2.57454425e-01,  -2.57666379e-01,  -2.56351590e-01,
                         -2.50620306e-01,  -2.46996731e-01,  -2.45093271e-01,
                         -2.42255062e-01,  -2.40254432e-01,  -2.36882493e-01,
                         -2.32215658e-01,  -2.29826048e-01,  -2.28219673e-01,
                         -2.25176126e-01,  -2.22669244e-01,  -2.21265227e-01,
                         -2.19452366e-01,  -2.19032928e-01,  -2.19735920e-01,
                         -2.18962938e-01,  -2.18402445e-01,  -2.17189044e-01,
                         -2.14940682e-01,  -2.14385524e-01,  -2.12425560e-01,
                         -2.09775835e-01,  -2.09601626e-01,  -2.08539709e-01,
                         -2.07625538e-01,  -2.07092762e-01,  -2.05068976e-01,
                         -2.05220178e-01,  -2.03865871e-01,  -2.00158834e-01,
                         -2.00407669e-01,  -1.99363977e-01,  -1.97206318e-01,
                         -1.99607357e-01,  -2.00718895e-01,  -2.00800076e-01,
                         -2.01403260e-01,  -2.00223163e-01,  -2.02301338e-01,
                         -2.04770982e-01,  -2.04119131e-01,  -2.04319462e-01,
                         -2.03101829e-01,  -2.02134773e-01,  -2.01693162e-01,
                         -1.97192013e-01,  -1.94646150e-01,  -1.95546940e-01,
                         -1.95652738e-01,  -1.95909679e-01,  -1.94971338e-01,
                         -1.93092257e-01,  -1.90910831e-01,  -1.87037602e-01,
                         -1.85362712e-01,  -1.87637284e-01,  -1.87934816e-01,
                         -1.85409904e-01,  -1.85264021e-01,  -1.85319737e-01,
                         -1.84463874e-01,  -1.84844092e-01,  -1.82736158e-01,
                         -1.82211339e-01,  -1.84556857e-01,  -1.84534177e-01,
                         -1.85748592e-01,  -1.84128910e-01,  -1.80196613e-01,
                         -1.73904195e-01,  -1.44771218e-01,  -1.01996422e-01,
                         -6.65867701e-02,  -2.07248218e-02,   3.28392051e-02,
                          5.37769049e-02,   4.06215116e-02,   1.95751246e-02,
                         -1.13789588e-02,  -2.68020835e-02,   1.07885730e-02,
                          5.67779541e-02,   5.90109378e-02,   2.56772228e-02,
                          5.63870562e-05,   2.22010929e-02,   5.22252060e-02,
                          5.43018989e-02,   7.51261413e-02,   1.18663996e-01,
                          1.45179957e-01,   1.47328079e-01,   1.36078507e-01,
                          1.34481341e-01,   1.49870262e-01,   1.50641203e-01,
                          1.14333749e-01,   7.88935050e-02,   7.88479745e-02,
                          8.55026320e-02,   9.47521031e-02,   1.29350841e-01,
                          1.73407122e-01,   2.19108015e-01,   2.66288042e-01,
                          3.00032347e-01,   3.26639742e-01,   3.50871861e-01,
                          3.57774377e-01,   3.57480198e-01,   3.57051462e-01,
                          3.33770245e-01,   3.13150525e-01,   3.25053662e-01,
                          3.30897629e-01,   3.24452370e-01,   3.45437139e-01,
                          3.98674726e-01,   4.41503167e-01,   4.40477163e-01,
                          4.31613684e-01,   4.34851885e-01,   4.31924939e-01,
                          4.33297276e-01,   4.31672305e-01,   4.26342338e-01,
                          4.28741306e-01,   4.24053162e-01,   4.22927439e-01,
                          4.26519126e-01,   4.23977077e-01,   4.25653964e-01,
                          4.24986154e-01,   4.24490899e-01,   4.25657332e-01,
                          4.22460556e-01,   4.24618214e-01,   4.24007088e-01,
                          4.21070665e-01,   4.22103494e-01,   4.17488843e-01,
                          4.13826257e-01,   4.13405329e-01,   4.11962390e-01,
                          4.11969662e-01,   4.12519842e-01,   4.13601160e-01,
                          4.13763851e-01,   4.12986547e-01,   4.10195917e-01,
                          4.08249348e-01,   4.07465607e-01,   4.02992964e-01,
                          4.02138382e-01,   4.00264025e-01,   3.98770392e-01,
                          4.03543949e-01,   3.99186909e-01,   3.94390702e-01,
                          3.91634345e-01,   3.86668772e-01,   3.89984339e-01,
                          3.85728687e-01,   3.81991476e-01,   3.85026395e-01,
                          3.79774064e-01,   3.82369310e-01,   3.83931011e-01,
                          3.80218446e-01,   3.80583465e-01,   3.75094622e-01,
                          3.77136856e-01,   3.76139700e-01,   3.69077146e-01,
                          3.72024685e-01,   3.66337240e-01,   3.64808619e-01,
                          3.67762208e-01,   3.63156587e-01,   3.66084307e-01,
                          3.50248963e-01,   3.13745320e-01,   2.73436129e-01,
                          2.27495715e-01,   2.05002844e-01,   2.00280130e-01,
                          1.88342854e-01,   1.68232977e-01,   1.44084111e-01,
                          1.35012969e-01,   1.28933296e-01,   1.23305075e-01,
                          1.58191338e-01,   2.11390212e-01,   2.19521210e-01,
                          1.89416856e-01,   1.63748309e-01,   1.57020763e-01,
                          1.84876069e-01,   2.04948321e-01,   1.63100496e-01,
                          1.22537009e-01,   9.59714726e-02,   6.52282462e-02,
                          7.19064027e-02,   5.53719215e-02,   1.02729816e-02,
                         -6.80746092e-03,  -4.53797020e-02,  -7.24757165e-02,
                         -5.77058606e-02,  -5.81661463e-02,  -5.68865649e-02,
                         -5.63776754e-02,  -8.30920711e-02,  -1.25112683e-01,
                         -1.73654541e-01,  -2.03407526e-01,  -2.08223283e-01,
                         -2.05207154e-01,  -2.03877851e-01,  -2.01190621e-01,
                         -1.86877266e-01,  -1.66833296e-01,  -1.44315138e-01,
                         -1.41667739e-01,  -1.64579093e-01,  -1.80084839e-01,
                         -2.00809598e-01,  -2.15220362e-01,  -1.86065838e-01,
                         -1.44321889e-01,  -1.28933266e-01,  -1.40776873e-01,
                         -1.53994352e-01,  -1.75089389e-01,  -2.18623251e-01,
                         -2.47701541e-01,  -2.65719295e-01,  -2.85911471e-01,
                         -2.88680762e-01,  -2.78277099e-01,  -2.55977869e-01,
                         -2.40958393e-01,  -2.53221989e-01,  -2.80818969e-01,
                         -3.16034108e-01,  -3.44153345e-01,  -3.55562240e-01,
                         -3.43507916e-01,  -3.15186828e-01,  -2.84393549e-01,
                         -2.59040803e-01,  -2.88285851e-01,  -3.41043681e-01,
                         -3.48917127e-01,  -3.51101369e-01,  -3.39952201e-01,
                         -3.08522463e-01,  -2.97702014e-01,  -2.90109724e-01,
                         -3.08437049e-01,  -3.42051685e-01,  -3.41024727e-01,
                         -3.43041569e-01,  -3.47870141e-01,  -3.42355698e-01,
                         -3.46896380e-01,  -3.42612952e-01,  -3.38136613e-01,
                         -3.43078047e-01,  -3.40076059e-01,  -3.39130670e-01,
                         -3.38206261e-01,  -3.31726402e-01,  -3.33490789e-01,
                         -3.25229704e-01,  -2.89155364e-01,  -2.55550474e-01,
                         -2.38963798e-01,  -2.38317758e-01,  -2.51334280e-01,
                         -2.53718764e-01,  -2.57333010e-01,  -2.43583500e-01,
                         -1.99338987e-01,  -2.24863663e-01,  -2.92536050e-01,
                         -3.03543001e-01,  -3.13015401e-01,  -3.31986815e-01,
                         -3.31240505e-01,  -3.31351519e-01,  -3.27631682e-01,
                         -3.29172552e-01,  -3.28564435e-01,  -3.20247978e-01,
                         -3.24665099e-01,  -3.23814303e-01,  -3.20748299e-01,
                         -3.23822469e-01,  -3.20502400e-01,  -3.19446236e-01,
                         -3.19411784e-01,  -3.16738248e-01,  -3.07969213e-01,
                         -2.87268370e-01,  -2.61740625e-01,  -2.47657239e-01,
                         -2.38582820e-01,  -1.80751085e-01,  -1.10130951e-01,
                         -1.10033587e-01,  -1.23511553e-01,  -1.16202332e-01,
                         -1.34544253e-01,  -1.59083769e-01,  -1.67280525e-01,
                         -1.77065030e-01,  -2.06509739e-01,  -2.54941344e-01,
                         -2.93398291e-01,  -2.94078022e-01,  -2.61145264e-01,
                         -2.39170939e-01,  -2.61168838e-01,  -3.02825779e-01,
                         -3.18097234e-01,  -3.10382903e-01,  -3.05150837e-01,
                         -2.67721772e-01,  -2.21356168e-01,  -2.33888537e-01,
                         -2.49993488e-01,  -2.42878154e-01,  -2.52998948e-01,
                         -2.59458154e-01,  -2.49739587e-01,  -2.26059079e-01,
                         -2.01451525e-01,  -1.99611783e-01,  -2.12846279e-01,
                         -2.39657655e-01,  -2.64460444e-01,  -2.75033891e-01,
                         -2.66396910e-01,  -2.19940662e-01,  -1.83836564e-01,
                         -1.79837883e-01,  -1.75965518e-01,  -1.95010692e-01,
                         -2.19732255e-01,  -2.18804181e-01,  -2.25181639e-01,
                         -2.34749421e-01,  -2.23472983e-01,  -2.01550245e-01,
                         -1.69339240e-01,  -1.30041271e-01,  -1.12059072e-01,
                         -1.13799475e-01,  -1.23364799e-01,  -1.52224809e-01,
                         -1.65935040e-01,  -1.60759866e-01,  -1.81858003e-01,
                         -1.82340011e-01,  -1.45897359e-01,  -1.42146990e-01,
                         -1.64545968e-01,  -1.67295232e-01,  -1.39372841e-01,
                         -9.23757404e-02,  -5.19115217e-02,  -3.93984020e-02,
                         -5.45302480e-02,  -6.36878461e-02,  -5.73704019e-02,
                         -5.93363345e-02,  -7.87251592e-02,  -1.23816468e-01,
                         -1.80293694e-01,  -2.22082213e-01,  -2.38170311e-01,
                         -2.17867449e-01,  -1.88510060e-01,  -1.74986660e-01,
                         -1.59489661e-01,  -1.41985163e-01,  -1.32725656e-01,
                         -1.23506732e-01,  -1.06903128e-01,  -1.05290532e-01,
                         -1.33889928e-01,  -1.59916580e-01,  -1.80326268e-01,
                         -2.04645485e-01,  -2.06152439e-01,  -2.07401946e-01,
                         -2.29789883e-01,  -2.31385976e-01,  -2.02987522e-01,
                         -1.60788283e-01,  -1.11585088e-01,  -8.80952254e-02,
                         -9.12042782e-02,  -7.75236934e-02,  -4.58898731e-02,
                         -9.55538172e-03,   2.46954728e-02,   2.62492653e-02,
                          7.50420382e-03,  -1.91372575e-03,  -1.28502287e-02,
                         -1.19357053e-02,   8.61221342e-04,   2.41973510e-04,
                          7.22639728e-03,   2.36625932e-02,   2.62982864e-02,
                          2.71736234e-02,   3.05079594e-02,   2.91789006e-02,
                          2.06643902e-02,   6.70057116e-03,   1.71944182e-02,
                          6.07318170e-02,   9.91372615e-02,   1.18726738e-01,
                          1.31931514e-01,   1.37528270e-01,   1.40145615e-01,
                          1.51657239e-01,   1.68811858e-01,   1.73018485e-01,
                          1.49316087e-01,   1.27379790e-01,   1.47997618e-01,
                          1.77874312e-01,   1.72285751e-01,   1.55831337e-01,
                          1.44552901e-01,   1.24615021e-01,   1.18045151e-01,
                          1.45756751e-01,   1.82428300e-01,   2.09112346e-01,
                          2.50308037e-01,   3.16472948e-01,   3.53636652e-01,
                          3.26952487e-01,   2.86071032e-01,   2.82302678e-01,
                          3.15857708e-01,   3.56355697e-01,   3.66772056e-01,
                          3.50873888e-01,   3.38898212e-01,   3.37171942e-01,
                          3.49668086e-01,   3.79492044e-01,   4.09300089e-01,
                          4.28923458e-01,   4.39275920e-01,   4.41204220e-01,
                          4.41003442e-01,   4.37528074e-01,   4.29864317e-01,
                          4.28743333e-01,   4.31783438e-01,   4.32474673e-01,
                          4.33825374e-01,   4.30200726e-01,   4.23544645e-01,
                          4.24499720e-01,   4.26112920e-01,   4.24279839e-01,
                          4.24801201e-01,   4.24917042e-01,   4.24516708e-01,
                          4.25934851e-01,   4.26055610e-01,   4.26246107e-01,
                          4.27474469e-01,   4.25400883e-01,   4.21664536e-01,
                          4.20370668e-01,   4.19802099e-01,   4.18474287e-01,
                          4.18018758e-01,   4.20086145e-01,   4.21020806e-01,
                          4.17267054e-01,   4.15416390e-01,   4.17832106e-01,
                          4.17331815e-01,   4.15452242e-01,   4.15680587e-01,
                          4.15612012e-01,   4.16461259e-01,   4.17344183e-01,
                          4.16622370e-01,   4.16458756e-01,   4.15439487e-01,
                          4.13885385e-01,   4.13406581e-01,   4.12571639e-01,
                          4.14380461e-01,   4.15799767e-01,   4.09428090e-01,
                          4.03059423e-01,   4.00621653e-01,   3.96227509e-01,
                          3.92097384e-01,   3.89086723e-01,   3.85538995e-01,
                          3.85641634e-01,   3.86813909e-01,   3.85913193e-01,
                          3.85248899e-01,   3.81483346e-01,   3.78116548e-01,
                          3.80839109e-01,   3.82467330e-01,   3.80312741e-01,
                          3.78507435e-01,   3.73995841e-01,   3.68917137e-01,
                          3.68674189e-01,   3.69779468e-01,   3.69644523e-01,
                          3.67675453e-01,   3.65005314e-01,   3.65305454e-01,
                          3.64739686e-01,   3.61621290e-01,   3.59731913e-01,
                          3.56280893e-01,   3.53314310e-01,   3.54844123e-01,
                          3.54839146e-01,   3.53437394e-01,   3.53076369e-01,
                          3.51626664e-01,   3.50981534e-01,   3.51702988e-01,
                          3.49344522e-01,   3.46559554e-01,   3.42861533e-01,
                          3.37587982e-01,   3.36421847e-01,   3.33876580e-01,
                          3.29652190e-01,   3.30851674e-01,   3.30342978e-01,
                          3.24412197e-01,   3.23050261e-01,   3.21655035e-01,
                          3.15653682e-01,   3.11088711e-01,   3.07523280e-01,
                          3.06570858e-01,   3.08978021e-01,   3.08909953e-01,
                          3.07043225e-01,   3.05571198e-01,   3.01702499e-01,
                          2.98198283e-01,   2.94945329e-01,   2.91908532e-01,
                          2.91447401e-01,   2.87922859e-01,   2.83383042e-01,
                          2.83303410e-01,   2.82501429e-01,   2.79072464e-01,
                          2.79304117e-01,   2.79403239e-01,   2.79491812e-01,
                          2.80348688e-01,   2.78076231e-01,   2.75753766e-01,
                          2.74540573e-01,   2.71957934e-01,   2.69047767e-01,
                          2.68935919e-01,   2.66426176e-01,   2.66200334e-01,
                          2.67422616e-01,   2.64253020e-01,   2.62044430e-01,
                          2.63663739e-01,   2.65402555e-01,   2.66118526e-01,
                          2.65843272e-01,   2.65452772e-01,   2.63814390e-01,
                          2.60566771e-01,   2.59595543e-01,   2.60284781e-01,
                          2.59393424e-01,   2.55499423e-01,   2.52372622e-01,
                          2.52609819e-01,   2.51865625e-01,   2.50149965e-01,
                          2.47854605e-01,   2.49523461e-01,   2.48368010e-01,
                          2.45211467e-01,   2.43606627e-01,   2.43955895e-01,
                          2.44875774e-01,   2.44865909e-01,   2.46205658e-01,
                          2.44008765e-01,   2.43458778e-01,   2.44391814e-01,
                          2.46773943e-01,   2.44353384e-01,   2.44149774e-01,
                          2.43170947e-01,   2.38520384e-01,   2.36701682e-01,
                          2.37969980e-01,   2.39436269e-01,   2.37152040e-01,
                          2.31833756e-01,   2.26579726e-01,   2.27089614e-01,
                          2.25832105e-01,   2.24190474e-01,   2.21163377e-01,
                          2.18682930e-01,   2.18455985e-01,   2.14932919e-01,
                          2.14311719e-01,   2.12543815e-01,   2.12075636e-01,
                          2.08456859e-01,   2.09930629e-01,   2.09666863e-01,
                          2.11673036e-01,   2.13742390e-01,   2.14760572e-01,
                          2.16448307e-01,   2.14653313e-01,   2.21393734e-01,
                          2.17726976e-01,   2.17830002e-01,   2.15265661e-01,
                          2.16970235e-01,   2.20442638e-01,   2.20045835e-01,
                          2.18508467e-01,   2.14266643e-01,   2.13041216e-01,
                          2.12633982e-01,   2.09648579e-01,   2.07865313e-01,
                          2.06026211e-01,   2.08774000e-01,   2.07266688e-01,
                          1.88237727e-01,   1.64706707e-01,   1.43051669e-01,
                          1.24408714e-01,   1.08017713e-01,   9.44309309e-02,
                          9.62479413e-02,   7.75372908e-02,   6.17809221e-02,
                          4.45931666e-02,   4.26811054e-02,   5.19402139e-02,
                          5.37765957e-02,   5.84647581e-02,   7.41058514e-02,
                          1.07320376e-01,   1.32020339e-01,   1.29901543e-01,
                          1.10406041e-01,   7.89899603e-02,   4.66639213e-02,
                          3.30696553e-02,  -3.78452009e-03,  -5.52228615e-02,
                         -7.51096606e-02,  -9.70227569e-02,  -1.37747616e-01,
                         -1.91016346e-01,  -2.39224896e-01,  -2.83401042e-01,
                         -3.29740494e-01,  -3.36408257e-01,  -2.91847795e-01,
                         -2.56260395e-01,  -2.44312078e-01,  -2.33229399e-01,
                         -2.42653877e-01,  -2.51362473e-01,  -2.71205157e-01,
                         -3.12528938e-01,  -3.62939328e-01,  -4.08171266e-01,
                         -4.43978041e-01,  -4.53581661e-01,  -4.53884810e-01,
                         -4.54884768e-01,  -4.46212232e-01,  -4.25366282e-01,
                         -4.24813688e-01,  -4.04212534e-01,  -3.58695060e-01,
                         -3.08474094e-01,  -2.74572968e-01,  -2.87763506e-01,
                         -3.17901552e-01,  -3.70780170e-01,  -4.35994506e-01,
                         -4.56694692e-01,  -4.57247347e-01,  -4.44908381e-01,
                         -4.52656776e-01,  -4.50009048e-01,  -4.53074425e-01,
                         -4.56208289e-01,  -4.41719204e-01,  -4.50796902e-01,
                         -4.51966852e-01,  -4.50042367e-01,  -4.55897093e-01,
                         -4.44443464e-01,  -4.46389198e-01,  -4.46172774e-01,
                         -4.40311670e-01,  -4.43567008e-01,  -4.42385554e-01,
                         -4.39166933e-01,  -4.34062988e-01,  -4.40508276e-01,
                         -4.41357434e-01,  -4.34310257e-01,  -4.32734340e-01,
                         -4.26500976e-01,  -4.25843000e-01,  -4.31539387e-01,
                         -4.26549464e-01,  -4.28046912e-01,  -4.25563842e-01,
                         -4.27772254e-01,  -4.24144179e-01,  -4.18698430e-01,
                         -4.17511910e-01,  -4.25445259e-01,  -4.24170524e-01,
                         -4.28745478e-01,  -4.15985763e-01,  -4.14774388e-01,
                         -4.19481069e-01,  -4.12792534e-01,  -4.19633031e-01,
                         -4.20950294e-01,  -4.06701326e-01,  -4.14131999e-01,
                         -4.05605137e-01,  -4.04883772e-01,  -4.09499466e-01,
                         -3.96817625e-01,  -4.05241847e-01,  -4.13602382e-01,
                         -4.06005472e-01,  -4.14042354e-01,  -3.93891364e-01,
                         -4.04021531e-01,  -4.06966388e-01,  -4.03250635e-01,
                         -4.09939170e-01,  -4.05138403e-01,  -4.09932822e-01,
                         -4.04909909e-01,  -4.03451383e-01,  -4.02830601e-01,
                         -3.90970498e-01,  -3.94373447e-01,  -3.93544495e-01,
                         -3.89787287e-01,  -3.97308737e-01,  -3.86265427e-01,
                         -3.90222907e-01,  -3.91828775e-01,  -3.94159764e-01,
                         -3.95505577e-01,  -3.83655429e-01,  -3.97435993e-01,
                         -3.95282626e-01,  -3.98460001e-01,  -3.93547326e-01,
                         -3.84878725e-01,  -3.81654322e-01,  -3.69492829e-01,
                         -3.81920159e-01,  -3.70187491e-01,  -3.83294433e-01,
                         -3.60085040e-01,  -3.63402277e-01,  -3.61227632e-01,
                         -3.60586494e-01,  -3.71706069e-01,  -3.62456590e-01,
                         -3.63947690e-01,  -3.54809046e-01,  -3.59665215e-01,
                         -3.58143568e-01,  -3.47223312e-01,  -3.50144207e-01,
                         -3.44095677e-01,  -3.53429645e-01],
                         dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri10",
    rate = 41000,
    data = numpy.array([ -1.34146772e-03,  -9.18233360e-04,  -6.53477095e-04,
                         -1.04829669e-04,  -1.40391779e-03,  -3.51781637e-04,
                         -2.79837567e-03,  -1.97401480e-03,   2.47748976e-04,
                         -2.40196893e-03,  -2.89467396e-03,  -4.28136950e-03,
                         -9.70419438e-04,  -2.11784896e-03,  -9.18184815e-04,
                         -1.90011575e-03,  -2.47457903e-03,  -1.20252650e-03,
                          2.46913172e-03,  -3.66237829e-03,  -6.09348249e-03,
                          3.43592651e-03,   8.64224508e-04,   3.10227484e-03,
                         -3.68532492e-04,   1.36245997e-03,  -3.91950423e-04,
                         -2.50662537e-03,  -2.11786991e-03,  -6.62410384e-05,
                         -3.12305929e-04,   9.47950990e-04,   3.30449780e-04,
                          1.28732028e-03,  -7.59526505e-04,   1.59528083e-03,
                          1.66495936e-03,  -6.27307803e-04,  -9.53737937e-04,
                         -1.49692420e-03,  -2.61232816e-03,  -2.52684136e-03,
                         -1.38311961e-03,  -6.38729136e-04,  -1.99798029e-03,
                         -9.47493594e-04,  -2.44199205e-03,  -2.00937386e-03,
                         -1.45726139e-04,   8.06785130e-04,   3.18390841e-04,
                          8.49920092e-04,   1.14175351e-03,  -1.70564788e-04,
                         -1.22430187e-03,  -4.46896255e-03,  -3.33524821e-03,
                         -2.11749552e-03,  -2.96351383e-03,  -2.07585073e-03,
                         -2.13526515e-03,  -1.37013884e-03,  -6.57905621e-05,
                          4.56788065e-03,  -3.97250801e-03,  -2.04150332e-03,
                         -2.26809387e-03,  -1.11884845e-04,  -4.84285923e-03,
                          4.50225640e-03,  -1.39246183e-03,   9.20645136e-04,
                          1.86745950e-03,  -1.65148661e-03,  -3.37958219e-03,
                         -1.57934777e-03,  -5.47275180e-04,  -2.23651878e-03,
                          3.98312550e-04,  -1.33256905e-03,  -1.14257133e-03,
                         -7.37473893e-04,   8.12391809e-04,   1.02479558e-03,
                         -1.87876998e-04,   5.06944256e-03,  -1.32998393e-03,
                          4.58854018e-03,  -1.80272933e-03,  -5.17938694e-04,
                         -2.22457759e-03,  -3.56080593e-03,  -9.95559618e-03,
                          8.32940568e-04,   1.87187421e-03,   3.75961233e-03,
                          8.73629120e-04,   5.78760111e-04,   2.35270732e-03,
                          3.50761483e-03,   3.25757195e-03,  -5.95908100e-03,
                          5.67304145e-04,  -3.14949197e-03,   1.09237422e-04,
                         -3.05259763e-03,   1.65366277e-03,  -1.50889298e-03,
                          1.01557118e-03,   2.86562834e-03,   2.55351653e-03,
                         -4.06168867e-03,  -1.02183428e-02,   3.46465997e-04,
                         -1.59890542e-03,   4.39121667e-03,  -9.23399255e-03,
                          2.53911526e-03,  -1.00898731e-03,  -3.23251844e-03,
                         -6.14489941e-03,  -2.64154002e-03,  -4.80736140e-03,
                          5.36519848e-03,   1.18013425e-03,  -8.82188149e-04,
                          4.55869781e-03,   4.02473565e-03,   2.60068499e-03,
                          5.47679234e-03,  -3.93899949e-03,  -9.83802136e-04,
                          3.13275494e-03,   4.08033188e-03,   4.10048524e-03,
                          4.96792560e-03,  -4.72442480e-03,   8.21551774e-03,
                          3.75786563e-03,   2.51873978e-03,  -2.36971467e-03,
                         -2.44186725e-04,  -1.42599817e-03,   1.09881051e-02,
                         -1.98088284e-03,  -4.24194941e-03,   4.93609393e-03,
                          3.15640145e-03,   4.01921244e-03,  -1.45320492e-02,
                         -1.57222326e-03,  -2.50133034e-03,   4.42455243e-03,
                         -1.89273478e-03,   5.16228937e-03,  -2.25543889e-04,
                          2.98839412e-03,   2.12528533e-03,  -1.61867094e-04,
                         -2.69675464e-03,  -1.38489380e-02,   2.14845384e-03,
                         -2.89494428e-03,   7.34151434e-03,  -5.57690952e-03,
                          9.64872353e-03,   4.78370115e-03,   1.91337988e-02,
                          2.32882518e-03,  -4.76424024e-03,  -3.03517445e-03,
                         -4.94330889e-03,  -9.11932904e-03,  -8.58340587e-04,
                         -6.23315864e-04,  -5.90015156e-03,   6.12088572e-03,
                         -3.24726640e-03,   7.26267404e-04,  -4.34343843e-03,
                          2.89242831e-03,   5.96545683e-03,   2.28207256e-03,
                          3.34806251e-03,  -1.04966888e-03,   8.36977549e-03,
                          2.10441789e-03,  -2.83660390e-03,  -1.17545277e-02,
                          7.58877816e-03,  -4.07195976e-03,   9.97099560e-03,
                          1.01742232e-02,   2.28052697e-04,   8.96671414e-03,
                          7.43812462e-03,  -1.42642087e-03,  -5.77429484e-04,
                          1.57072209e-02,   3.28396983e-03,  -2.33208248e-03,
                         -1.80869643e-03,   7.74921058e-03,   3.78180342e-03,
                          3.38760065e-03,  -1.07833312e-03,   3.94637324e-03,
                          1.03667509e-02,   7.11592194e-03,   1.70453903e-04,
                         -5.83421532e-03,  -5.73998224e-03,  -1.21610388e-02,
                         -3.90105532e-03,  -9.89478198e-04,   2.21196422e-03,
                          1.88567268e-03,  -6.28867839e-03,   9.20084491e-03,
                          3.06246639e-03,  -9.86771099e-03,  -6.74661342e-03,
                         -1.32292053e-02,  -4.17412119e-03,  -5.05942805e-03,
                         -1.02866003e-02,  -1.53667293e-02,  -2.35298593e-02,
                          7.24597136e-04,  -3.10959341e-03,  -1.06669078e-02,
                         -2.94993701e-03,   6.47675619e-03,   2.69798841e-03,
                         -4.01160959e-03,   5.57827484e-03,   7.74564827e-03,
                          7.52743008e-03,   8.92444514e-03,   3.03986645e-03,
                         -1.66656717e-03,   2.57184054e-03,   2.58768350e-03,
                         -2.11028103e-03,   1.37033290e-03,  -6.12414267e-04,
                          6.72035385e-03,   9.42277070e-03,  -7.94618018e-03,
                          4.54668002e-03,   8.65061022e-03,  -6.12040050e-03,
                         -1.76206158e-04,   1.23063838e-02,   1.39894872e-03,
                          1.06200506e-03,   6.11619372e-03,   2.41847709e-03,
                         -6.83977921e-03,  -5.60494279e-03,   3.21925362e-03,
                         -9.60395299e-03,  -3.25558987e-03,  -8.44219141e-03,
                          9.85889602e-03,  -8.64127476e-04,  -2.94646504e-03,
                         -1.45776721e-03,   4.56268946e-03,   1.14163291e-02,
                         -5.52820228e-03,  -2.71844701e-03,  -4.31365846e-03,
                          4.38251207e-03,  -1.12950327e-02,  -1.78457855e-03,
                         -3.26733687e-03,  -2.90662196e-04,   4.79697250e-03,
                          2.03708862e-03,  -4.29568766e-03,  -9.10729077e-03,
                         -3.70008685e-03,   2.58220173e-03,   9.40880552e-03,
                         -3.10512329e-03,   3.98555101e-04,  -2.78774439e-03,
                         -3.90407001e-03,   5.97787602e-03,   1.13525975e-03,
                         -6.79383706e-03,   1.57955009e-02,   2.59272195e-03,
                          1.17791304e-02,   6.40357099e-03,   9.51215276e-04,
                          6.24674931e-03,  -1.48833599e-02,   1.73908030e-03,
                         -2.87966250e-04,   8.75909231e-04,  -7.86986947e-03,
                         -4.11455426e-03,  -6.01531425e-03,   8.69540125e-03,
                          8.42493493e-03,  -1.54077297e-03,  -9.01323103e-04,
                         -1.46977771e-02,   1.26401111e-02,   1.91671413e-03,
                          3.69327422e-03,   3.98917589e-03,  -9.12612770e-04,
                          2.56994157e-04,  -5.63666364e-03,  -4.91325138e-03,
                         -1.82119124e-02,  -1.23462472e-02,   2.65493640e-03,
                          1.16526159e-02,  -4.13358503e-04,  -4.78790095e-03,
                          4.72867349e-03,  -1.50909403e-03,   4.32514912e-03,
                         -1.57764982e-02,  -5.34973666e-03,  -5.86509053e-03,
                         -1.73442587e-02,  -3.66600300e-03,  -3.21207359e-03,
                         -1.32283382e-02,  -1.69410799e-02,  -9.41511989e-03,
                         -1.73715912e-02,   3.37719794e-05,  -1.16955144e-02,
                          7.80331669e-03,  -9.40497041e-01,  -9.41795170e-01,
                         -9.38047409e-01,  -9.35105801e-01,  -9.47837293e-01,
                         -9.24921274e-01,  -9.31190968e-01,  -9.26246762e-01,
                         -9.31369960e-01,  -9.36978936e-01,  -9.32150781e-01,
                         -9.41735983e-01,   6.61622407e-03,  -7.38631282e-03,
                         -6.01200853e-03,   1.61674432e-03,   2.15252885e-03,
                         -8.88501760e-03,  -1.03695299e-02,  -8.92628822e-03,
                         -1.21887540e-03,  -5.69681251e-05,  -1.31601919e-04,
                         -1.03127416e-02,  -6.26220414e-03,  -8.43761675e-03,
                         -2.00961307e-02,  -2.05395184e-02,  -9.55915451e-03,
                          2.05338211e-03,  -9.41152302e-06,  -2.76079867e-03,
                         -1.61296036e-03,   5.68952179e-03,  -8.59562401e-03,
                         -4.71000280e-03,   3.64981336e-03,  -1.85430562e-03,
                         -8.11317563e-03,  -6.24701940e-03,   1.97156146e-03,
                         -7.74392276e-04,   1.13943883e-03,   4.52612469e-04,
                         -6.45763520e-03,   1.58821307e-02,   5.97515935e-03,
                         -4.17412119e-03,  -1.75071647e-03,   6.10458525e-03,
                          5.09041408e-03,  -3.51867592e-03,  -3.08711804e-03,
                         -5.07482048e-03,  -2.74980022e-03,   8.28747638e-04,
                          5.33803832e-03,  -8.52110796e-03,  -1.48244444e-02,
                         -1.09216077e-02,  -8.83658137e-03,  -1.06734773e-02,
                         -2.25689425e-03,   1.36043632e-03,  -1.68266660e-03,
                         -7.50219636e-03,   3.02306004e-03,  -6.23572292e-03,
                         -7.45695457e-03,  -3.29993083e-03,  -1.14754040e-03,
                         -8.16584006e-03,   9.36892163e-03,  -3.49401729e-03,
                         -2.24265223e-03,  -1.03713176e-03,  -9.19762731e-01,
                         -9.35440123e-01,  -9.26634371e-01,  -9.44818079e-01,
                         -9.48894143e-01,  -9.39188004e-01,  -9.47525680e-01,
                         -9.38916922e-01,  -9.32013094e-01,  -9.36157346e-01,
                         -9.28469241e-01,  -9.50419962e-01,  -9.29625332e-01,
                         -9.36274588e-01,  -9.41756904e-01,  -9.16777015e-01,
                         -9.24879134e-01,  -9.46569085e-01,  -9.38534796e-01,
                         -9.34604824e-01,  -9.36802745e-01,  -9.35637653e-01,
                         -9.34872866e-01,  -9.46520090e-01,  -9.48193669e-01,
                         -9.32093561e-01,  -9.22692358e-01,  -9.38198566e-01,
                         -9.35794115e-01,  -9.32882905e-01,  -9.43300009e-01,
                         -9.42142904e-01,  -9.32456195e-01,  -9.48816538e-01,
                         -9.42851186e-01,  -9.44649756e-01,  -9.37186718e-01,
                         -9.32110131e-01,  -9.39552844e-01,  -9.40389335e-01,
                         -9.38581824e-01,  -9.31713223e-01,  -9.39457893e-01,
                         -9.28712964e-01,  -9.38767076e-01,  -9.23855603e-01,
                         -9.25404549e-01,  -9.34325159e-01,  -9.31796491e-01,
                         -9.33650672e-01,  -9.50056255e-01,  -9.34146225e-01,
                         -9.50039089e-01,  -9.51185644e-01,  -9.36533511e-01,
                         -9.35104370e-01,  -9.33623254e-01,  -9.31001008e-01,
                         -9.41540241e-01,  -9.42823529e-01,  -9.24585819e-01,
                         -9.33779299e-01,  -9.28669274e-01,  -9.21255171e-01,
                         -9.33809578e-01,  -9.43820894e-01,  -9.30449009e-01,
                         -9.49394703e-01,  -9.41940427e-01,  -9.39033449e-01,
                         -9.41875458e-01,  -9.48858798e-01,  -9.45438147e-01,
                         -9.27049220e-01,  -9.31763887e-01,  -9.27794099e-01,
                         -9.19467211e-01,  -9.33032215e-01,  -9.40461099e-01,
                         -9.35422719e-01,  -9.43840742e-01,  -9.40029442e-01,
                         -9.24588382e-01,  -9.27447021e-01,  -9.30424392e-01,
                         -9.41254497e-01,  -9.43286717e-01,  -9.31872129e-01,
                         -9.30325270e-01,  -9.38241482e-01,  -9.38221216e-01,
                         -9.38092351e-01,  -9.41188633e-01,  -9.41791654e-01,
                         -9.35519636e-01,  -9.38765526e-01,  -9.23394203e-01,
                         -9.28985953e-01,  -9.26669180e-01,  -9.37568069e-01,
                         -9.26474810e-01,  -9.33978796e-01,  -9.31466937e-01,
                         -9.38402057e-01,  -9.33772326e-01,  -9.36808050e-01,
                         -9.24143553e-01,  -9.30016637e-01,  -9.30726707e-01,
                         -9.39282954e-01,  -9.27034855e-01,  -9.24511850e-01,
                         -9.34029341e-01,  -9.38483536e-01,  -9.31733429e-01,
                         -9.36728120e-01,  -9.27241266e-01,  -9.33294952e-01,
                         -9.40747857e-01,  -9.32370007e-01,  -9.28924561e-01,
                         -9.28872406e-01,  -9.29856300e-01,  -9.37983572e-01,
                         -9.35779929e-01,  -9.29828346e-01,  -9.31688845e-01,
                         -9.32872474e-01,  -9.39533532e-01,  -9.36127186e-01,
                         -9.33279991e-01,  -9.35717940e-01,  -9.29612339e-01,
                         -9.30734336e-01,  -9.26890969e-01,  -9.28460002e-01,
                         -9.29953992e-01,  -9.35833454e-01,  -9.38408673e-01,
                         -9.37166333e-01,  -9.33944404e-01,  -9.42210793e-01,
                         -9.31645274e-01,  -9.37330425e-01,  -9.31602120e-01,
                         -9.32916224e-01,  -9.34737265e-01,  -9.36937451e-01,
                         -9.38187480e-01,  -9.41065192e-01,  -9.26883876e-01,
                         -9.35126662e-01,  -9.39741552e-01,  -9.36151385e-01,
                         -9.35976982e-01,  -9.29232538e-01,  -9.35467541e-01,
                         -9.23051119e-01,  -9.28271234e-01,  -9.42166984e-01,
                         -9.39657271e-01,  -9.38500404e-01,  -9.36995327e-01,
                         -9.34005141e-01,  -9.37905192e-01,  -9.27529454e-01,
                         -9.37813699e-01,  -9.46448207e-01,  -9.32037234e-01,
                         -9.35123026e-01,  -9.35678005e-01,  -9.45038199e-01,
                         -9.30734217e-01,  -9.37887311e-01,  -9.29153919e-01,
                         -9.38035250e-01,  -9.29744065e-01,  -9.31886554e-01,
                         -9.31103170e-01,  -9.26898837e-01,  -9.34103727e-01,
                         -9.36771810e-01,  -9.39902484e-01,  -9.27261353e-01,
                         -9.35396373e-01,  -9.35829937e-01,  -9.29064631e-01,
                         -9.34049606e-01,  -9.22451317e-01,  -9.38787043e-01,
                         -9.32286441e-01,  -9.25886154e-01,  -9.41915154e-01,
                         -9.33623910e-01,  -9.37779546e-01,  -9.36872125e-01,
                         -9.33680177e-01,  -9.15565133e-01,  -9.29749668e-01,
                         -9.29188132e-01,  -9.30406570e-01,  -9.29887474e-01,
                         -9.33081448e-01,  -9.34500158e-01,  -9.29906487e-01,
                         -9.33334768e-01,  -9.26887453e-01,  -9.33244705e-01,
                         -9.33142006e-01,  -9.35495257e-01,  -9.34976637e-01,
                         -9.38743114e-01,  -9.36878324e-01,  -9.33454514e-01,
                         -9.33613420e-01,  -9.28700089e-01,  -9.30428505e-01,
                         -9.31825221e-01,  -9.29812670e-01,  -9.36694622e-01,
                         -9.39549267e-01,  -9.35339928e-01,  -9.38450634e-01,
                         -9.42288995e-01,  -9.35937941e-01,  -9.39709723e-01,
                         -9.37057555e-01,  -9.32651103e-01,  -9.33542550e-01,
                         -9.39516485e-01,  -9.33566928e-01,  -9.40102398e-01,
                         -9.35454667e-01,  -9.34100091e-01,  -9.36300397e-01,
                         -9.28254426e-01,  -9.26217973e-01,  -9.31665242e-01,
                         -9.36361194e-01,  -9.35471416e-01,  -9.27488983e-01,
                         -9.25469398e-01,  -9.41819787e-01,  -9.34102654e-01,
                         -9.35813606e-01,  -9.44039404e-01,  -9.37051475e-01,
                         -9.33706641e-01,  -9.27833319e-01,  -9.39003944e-01,
                         -9.30682778e-01,  -9.38293397e-01,  -9.31821883e-01,
                         -9.26795244e-01,  -9.18072522e-01,  -9.26776350e-01,
                         -9.26002264e-01,  -9.44728494e-01,  -9.40602720e-01,
                         -9.34241891e-01,  -9.37812328e-01,  -9.32518363e-01,
                         -9.31058705e-01,  -9.28827405e-01,  -9.36325669e-01,
                         -9.35802400e-01,  -9.36702490e-01,  -9.34825838e-01,
                         -9.25755799e-01,  -9.42375898e-01,  -9.29578006e-01,
                         -9.33461607e-01,  -9.33743000e-01,  -9.48722720e-01,
                         -9.40961003e-01,  -9.28436935e-01,  -9.31164443e-01,
                         -9.36327696e-01,  -9.28227603e-01,  -9.58065391e-01,
                         -9.36167538e-01,  -9.34540629e-01,  -9.43613708e-01,
                         -9.29057717e-01,  -9.34877932e-01,  -9.34949696e-01,
                         -9.21461999e-01,  -9.30145919e-01,  -9.33793366e-01,
                         -9.35614467e-01,  -9.31531966e-01,  -9.25039589e-01,
                         -9.25816119e-01,  -9.32538211e-01,  -9.24336672e-01,
                         -9.29484546e-01,  -9.40121114e-01,  -9.27774847e-01,
                         -9.39552844e-01,  -9.37560081e-01,  -9.35378730e-01,
                         -9.41745043e-01,  -9.54680562e-01,  -9.45117235e-01,
                         -9.45487916e-01,  -9.35897470e-01,  -9.31751251e-01,
                         -9.39264297e-01,  -9.47215319e-01,  -9.45415616e-01,
                         -9.29911494e-01,  -9.36314285e-01,  -9.34728384e-01,
                         -9.15111899e-01,  -9.21521187e-01,  -9.30491924e-01,
                         -9.33036804e-01,  -9.27350461e-01,  -9.32860017e-01,
                         -9.30396914e-01,  -9.23338711e-01,  -9.40886915e-01,
                         -9.35155511e-01,  -9.35489953e-01,  -9.50523734e-01,
                         -9.38358247e-01,  -9.42613959e-01,  -9.24813390e-01,
                         -9.27364409e-01,  -9.28119361e-01,  -9.24817145e-01,
                         -9.38385308e-01,  -9.46122885e-01,  -9.39241469e-01,
                         -9.39059079e-01,  -9.25739586e-01,  -9.34160709e-01,
                         -9.32574272e-01,  -9.41947341e-01,  -9.40773904e-01,
                         -9.41130519e-01,  -9.43273723e-01,  -9.43365991e-01,
                         -9.42069173e-01,  -9.36694384e-01,  -9.38531756e-01,
                         -9.34711874e-01,  -9.38303828e-01,  -9.41752732e-01,
                         -9.43529129e-01,  -9.32682037e-01,  -9.34250653e-01,
                         -9.30684447e-01,  -9.45260823e-01,  -9.24347222e-01,
                         -9.40993249e-01,  -9.34659839e-01,  -9.36587512e-01,
                         -9.26805258e-01,  -9.36614990e-01,  -9.33036685e-01,
                         -9.32773113e-01,  -9.35402691e-01,  -9.21331882e-01,
                          1.62847061e-03,  -7.64081208e-03,  -6.36678422e-03,
                         -9.60109103e-03,   2.02472485e-03,  -1.33672031e-03,
                          7.24925660e-03,  -8.53329152e-03,  -1.23315898e-03,
                         -8.10284261e-03,  -1.37630142e-02,  -3.41643812e-03,
                         -1.07293716e-02,  -7.86192063e-03,  -9.88392159e-03,
                         -2.64584869e-02,  -1.83551311e-02,  -7.95992371e-03,
                         -6.96771452e-03,  -1.24740722e-02,  -7.91598484e-03,
                          4.70109005e-03,   2.24146014e-03,  -1.79991275e-02,
                         -1.86559523e-03,  -1.05287908e-02,  -4.48672520e-03,
                         -7.81536847e-03,  -2.08157171e-02,  -2.72145472e-03,
                          5.63406479e-03,   8.33363272e-04,  -5.10692922e-03,
                         -5.26027195e-03,  -1.77469086e-02,   3.19605041e-03,
                         -2.07196325e-02,  -7.76232313e-03,  -6.37913402e-03,
                         -5.61007159e-03,  -6.88086962e-03,  -1.05430949e-02,
                          1.32654998e-02,   2.01271512e-02,  -7.55964254e-04,
                         -6.09337864e-03,  -9.59178340e-03,  -7.78127089e-03,
                          1.06017059e-02,   2.47210474e-03,  -1.11888314e-03,
                          8.35969858e-03,   8.22156799e-05,  -3.23057780e-03,
                          9.58603108e-04,   1.33281713e-02,   2.19070862e-05,
                          2.41510896e-03,   8.40970129e-03,   6.80472469e-03,
                          9.09186341e-03,   1.51702305e-02,   1.26284752e-02,
                         -8.59569293e-03,   5.94769430e-04,  -2.18515727e-03,
                          2.25852290e-03,   3.60160531e-03,   7.03438564e-05,
                          1.43544711e-02,   1.12567078e-02,  -1.48114352e-03,
                         -2.74015311e-03,  -1.23490058e-02,   4.41499520e-03,
                          5.79611165e-03,  -6.76607387e-03,   3.41829553e-04,
                          1.00288922e-02,   1.38321314e-02,   1.55897439e-02,
                          1.08629689e-02,  -1.65242911e-03,   1.30460481e-03,
                          1.52108157e-02,   7.42498459e-03,   9.76938941e-03,
                          6.72581512e-03,  -3.35069606e-03,   5.31478645e-03,
                         -1.17769474e-02,   2.02137046e-03,  -8.53293110e-03,
                         -5.99139044e-03,   7.59027491e-04,  -6.26886403e-03,
                         -9.67443548e-03,   3.30225239e-03,   3.12544336e-03,
                         -8.61540996e-03,  -3.96401156e-03,   4.66695102e-03,
                         -2.93988796e-05,   7.26156519e-04,   9.71651729e-03,
                          5.46606397e-03,   7.26329745e-04,  -3.42522585e-03,
                          7.15645822e-03,   1.58960763e-02,   3.58699611e-03,
                          8.52866191e-03,   1.77696124e-02,   4.86345636e-03,
                          1.43487602e-02,   1.14714196e-02,   4.93445154e-03,
                         -5.28432056e-03,  -8.09833780e-03,   6.74178964e-03,
                          2.64057657e-03,   5.25967591e-03,   3.22700175e-03,
                          1.52320154e-02,  -1.21433316e-02,  -6.14770642e-03,
                         -3.60992877e-03,   2.74295290e-03,  -1.50010521e-02,
                         -2.93961773e-03,   8.74983985e-03,  -5.02313348e-03,
                         -1.15732001e-02,  -1.01995328e-02,  -6.77513890e-03,
                          5.64237405e-03,   3.41136497e-03,  -4.67183674e-03,
                         -2.19246210e-03,  -1.50858182e-02,  -2.14247834e-02,
                         -9.58716031e-03,  -9.74671263e-03,  -1.32062305e-02,
                         -1.18559822e-02,  -9.40944359e-04,  -4.00973856e-03,
                         -7.22618494e-03,  -9.12300893e-04,   3.95614514e-03,
                         -3.89703573e-03,   2.65298900e-03,  -5.46866283e-03,
                          5.36519161e-04,   2.70648510e-03,   2.77547748e-03,
                         -6.91188313e-03,  -1.47259142e-02,   9.75868199e-03,
                          1.37162274e-02,  -4.71241446e-03,   1.94943266e-03,
                          4.01729951e-03,  -7.01193092e-03,  -1.43796008e-03,
                          8.63744225e-03,  -1.90314429e-03,  -1.25601692e-02,
                         -3.71714262e-03,   1.24979892e-03,   4.49242210e-03,
                          7.14254891e-03,  -1.44998441e-04,  -4.86030988e-03,
                         -2.65048724e-03,  -1.18083488e-02,  -5.71796438e-03,
                          2.93588219e-03,  -1.00314915e-02,  -4.24280856e-03,
                          3.28864809e-03,  -2.02489109e-03,  -8.77898280e-03,
                          2.73249485e-03,  -7.46672647e-03,   7.75348686e-04,
                         -1.87639985e-03,   3.96377593e-03,  -4.06559044e-03,
                         -7.27192592e-03,  -1.48855220e-03,  -6.17743819e-04,
                         -1.25538139e-02,  -9.43067111e-03,   2.09348858e-03,
                          2.14555697e-03,   1.90164731e-03,  -1.83798443e-03,
                          6.77037751e-03,   3.34351615e-04,   1.80345364e-02,
                          5.58126858e-03,   4.46807547e-03,   5.77419112e-03,
                         -1.34150581e-02,   4.74656094e-03,  -1.27398334e-02,
                         -1.15979416e-02,   3.44592030e-03,   8.44862964e-03,
                          3.37337237e-03,   4.64297179e-03,   6.26559276e-03,
                          1.80459227e-02,   1.08946832e-02,   1.44196581e-03,
                          8.49875063e-03,  -1.75506182e-04,  -2.46857735e-03,
                         -4.88311797e-03,  -7.46490376e-04,  -4.69501922e-03,
                         -1.16453525e-02,  -1.25224609e-02,  -6.68224366e-03,
                          1.08897975e-02,  -4.47719591e-04,   2.98246159e-03,
                         -1.06509402e-02,   1.54624810e-04,  -1.42870098e-03,
                          4.14863089e-03,   4.01680730e-03,  -2.85697938e-03,
                          1.38766598e-02,   5.95673127e-03,   2.08551921e-02,
                          8.96582007e-03,   6.38691010e-03,   3.11034196e-03,
                         -1.78518845e-03,  -6.84039574e-03,   5.74545749e-03,
                         -4.61048167e-03,   1.32522976e-03,  -1.14026284e-02,
                         -2.80164671e-03,  -1.24850776e-02,  -8.25278927e-03,
                          3.87272376e-05,   4.03207494e-03,  -6.87262230e-03,
                          5.43927122e-03,  -5.90003375e-03,  -9.68099851e-03,
                         -9.18347668e-03,   2.23528524e-03,  -1.13620292e-02,
                         -1.08463289e-02,   2.93866126e-03,  -1.30662846e-03,
                         -2.22160369e-02,   6.99027348e-03,  -1.80035289e-02,
                         -7.62078762e-01,  -7.58910894e-01,  -7.58305490e-01,
                         -7.72293448e-01,  -7.75735795e-01,  -7.74461210e-01,
                         -7.67766714e-01,  -7.71758378e-01,  -7.64295220e-01,
                         -7.64749765e-01,  -7.69271672e-01,  -7.70664036e-01,
                         -7.62538671e-01,  -7.68563807e-01,  -7.59583950e-01,
                         -7.72894740e-01,  -7.65475988e-01,  -7.77371407e-01,
                         -7.66884565e-01,  -7.70351887e-01,  -7.65731931e-01,
                         -7.64278591e-01,  -7.56866813e-01,  -7.69429207e-01,
                         -7.69976020e-01,  -7.54097164e-01,  -7.60102332e-01,
                         -7.59649694e-01,  -7.63018489e-01,  -7.75711954e-01,
                         -7.61733949e-01,  -7.59064555e-01,  -7.38504529e-01,
                         -7.51494408e-01,  -7.49437392e-01,  -7.70247102e-01,
                         -7.49914646e-01,  -7.54157603e-01,  -7.62854218e-01,
                         -7.62797892e-01,  -7.63313115e-01,  -7.60139823e-01,
                         -7.58924842e-01,  -7.65671313e-01,  -7.57136106e-01,
                         -7.63251364e-01,  -7.68024981e-01,  -7.59770155e-01,
                         -7.57030368e-01,  -7.73626983e-01,  -7.72877455e-01,
                         -7.83396184e-01,  -7.83399880e-01,  -7.63738930e-01,
                         -7.71894753e-01,  -7.62963533e-01,  -7.54846752e-01,
                         -7.62710989e-01,  -7.53091037e-01,  -7.74830937e-01,
                         -7.57405818e-01,  -7.76307344e-01,  -7.68781066e-01,
                         -7.46501088e-01,  -7.66179860e-01,  -7.71396041e-01,
                         -7.70730853e-01,  -7.66611874e-01,  -7.57991672e-01,
                         -7.58292735e-01,  -7.60742247e-01,  -7.66710043e-01,
                         -7.52397418e-01,  -7.64805675e-01,  -7.69090474e-01,
                         -7.62809277e-01,  -7.64963150e-01,  -7.66251147e-01,
                         -7.54803061e-01,  -7.73596823e-01,  -9.26693261e-01,
                         -9.40195560e-01,  -9.28689301e-01,  -9.32614326e-01,
                         -7.66837180e-01,  -7.50220239e-01,  -7.52746701e-01,
                         -7.65543878e-01,  -7.56463885e-01,  -7.49027908e-01,
                         -7.62464583e-01,  -7.53178537e-01,  -7.56776154e-01,
                         -7.69426703e-01,  -7.53266156e-01,  -7.48056293e-01,
                         -7.56687343e-01,  -7.56428540e-01,  -7.57785320e-01,
                         -7.69921184e-01,  -9.21431959e-01,  -9.40504014e-01,
                         -9.32895720e-01,  -9.41382051e-01,  -9.37780976e-01,
                         -9.44944143e-01,  -9.37601566e-01,  -9.34405267e-01,
                         -9.40840423e-01,  -9.34268653e-01,  -9.16049421e-01,
                         -9.24953938e-01,  -7.52523959e-01,  -7.61442840e-01,
                         -7.46355057e-01,  -7.60854781e-01,  -7.54245698e-01,
                         -7.60300696e-01,  -7.70515025e-01,  -7.55039394e-01,
                         -7.62143075e-01,  -7.79634595e-01,  -7.72849858e-01,
                         -7.62741148e-01,  -7.69079030e-01,  -7.67170370e-01,
                         -7.56377697e-01,  -7.65297592e-01,  -9.26213443e-01,
                         -9.42176402e-01,  -9.39312220e-01,  -9.34176683e-01,
                         -9.38760638e-01,  -9.22911108e-01,  -9.24420953e-01,
                         -9.42759335e-01,  -7.58483410e-01,  -7.51118004e-01,
                         -7.52066016e-01,  -7.47025609e-01,  -7.48758435e-01,
                         -7.64151394e-01,  -7.55250692e-01,  -7.60032892e-01,
                         -7.35534847e-01,  -7.56640255e-01,  -7.48720288e-01,
                         -7.54467666e-01,  -7.68769741e-01,  -7.62120545e-01,
                         -7.68737853e-01,  -7.63064742e-01,  -9.28073287e-01,
                         -9.23533738e-01,  -9.41936135e-01,  -9.27342594e-01,
                         -9.37701702e-01,  -9.33941424e-01,  -9.39829707e-01,
                         -9.53251481e-01,  -9.39389586e-01,  -9.41049278e-01,
                         -9.31527078e-01,  -9.45599914e-01,  -9.20286655e-01,
                         -9.29949939e-01,  -9.10198152e-01,  -9.19014335e-01,
                         -7.68284202e-01,  -7.53755212e-01,  -7.63183892e-01,
                         -7.61666834e-01,  -7.63597608e-01,  -7.65461862e-01,
                         -7.71709621e-01,  -7.64884412e-01,  -7.60297716e-01,
                         -7.65145063e-01,  -7.63231099e-01,  -7.35445082e-01,
                         -7.44162798e-01,  -7.37153172e-01,  -7.49155045e-01,
                         -7.61445522e-01,  -7.63874829e-01,  -7.56989956e-01,
                         -7.39608109e-01,  -7.56851375e-01,  -7.56758869e-01,
                         -7.55613744e-01,  -7.44882166e-01,  -7.62510836e-01,
                         -7.67241538e-01,  -7.76244104e-01,  -7.78970063e-01,
                         -7.50964165e-01,  -7.66178489e-01,  -7.46831536e-01,
                         -7.51553774e-01,  -7.54895926e-01,  -7.50754714e-01,
                         -7.31573164e-01,  -7.54144311e-01,  -7.57438719e-01,
                         -7.64762163e-01,  -7.50743330e-01,  -7.58026123e-01,
                         -7.64457464e-01,  -7.58786440e-01,  -7.61092484e-01,
                         -7.43481100e-01,  -7.45194733e-01,  -7.49388576e-01,
                         -7.62288809e-01,  -7.45718002e-01,  -7.55338490e-01,
                          8.17444088e-05,  -9.13420133e-03,  -1.62439477e-02,
                         -2.45485492e-02,  -3.20831733e-03,   7.62889162e-03,
                          3.96146113e-03,   5.76405879e-03,  -7.53634572e-01,
                         -7.46774197e-01,  -7.47204244e-01,  -7.54303753e-01,
                         -7.51259089e-01,  -7.65231669e-01,  -7.75251746e-01,
                         -7.61701345e-01,  -7.62689531e-01,  -7.55840659e-01,
                         -7.57165432e-01,  -7.78284550e-01,  -7.94556677e-01,
                         -7.75727332e-01,  -7.75547147e-01,  -7.70576596e-01,
                         -7.87380099e-01,  -7.90483177e-01,  -7.58724272e-01,
                         -7.77081192e-01,  -7.76147604e-01,  -7.64550567e-01,
                         -7.75643408e-01,  -7.81602561e-01,  -7.55053401e-01,
                         -7.72693157e-01,  -7.79215634e-01,  -7.62404978e-01,
                         -7.76267827e-01,  -7.72363842e-01,  -7.52613485e-01,
                         -7.53103971e-01,  -7.55519867e-01,  -7.63052166e-01,
                         -7.64700770e-01,  -7.52159476e-01,  -7.69159436e-01,
                         -7.56425023e-01,  -7.65151858e-01,  -7.75053382e-01,
                         -7.80057788e-01,  -7.55095899e-01,  -7.61954546e-01,
                         -7.71619618e-01,  -7.60091066e-01,  -7.64073789e-01,
                         -7.76241004e-01,  -7.45878220e-01,  -7.49336064e-01,
                         -7.48939335e-01,  -7.57662117e-01,  -7.49133110e-01,
                         -7.50888944e-01,  -7.62003720e-01,  -7.62873650e-01,
                         -7.70861149e-01,  -1.51569592e-02,  -1.06604549e-03,
                          7.09325960e-03,  -2.52333451e-02,  -7.58800089e-01,
                         -7.78783321e-01,  -7.76644826e-01,  -7.58487761e-01,
                         -7.85740077e-01,  -7.52553225e-01,  -7.64438272e-01,
                         -7.39627779e-01,  -7.53431201e-01,  -7.58535862e-01,
                         -7.60801077e-01,  -7.73312569e-01,  -7.73693383e-01,
                         -7.34284401e-01,  -7.42107749e-01,  -7.49789596e-01,
                         -7.55561471e-01,  -7.62147903e-01,  -7.83738256e-01,
                         -7.81335354e-01,  -7.83762097e-01,  -7.81113803e-01,
                         -7.74700999e-01,  -7.73324549e-01,  -7.57589519e-01,
                         -7.78728426e-01,  -7.58241594e-01,  -7.64022350e-01,
                         -7.40258515e-01,  -7.44496524e-01,  -7.79651403e-01,
                         -7.36294448e-01,  -7.85596371e-01,  -7.83514380e-01,
                         -7.86129177e-01,  -7.60828793e-01,  -7.51258373e-01,
                         -7.51078367e-01,  -7.69105434e-01,  -7.58389771e-01,
                          7.86081795e-03,  -1.06840190e-02,  -2.47998466e-03,
                         -2.64756242e-03,  -2.08860114e-02,  -8.15062784e-03,
                          1.12721347e-03,  -2.74277269e-03,  -7.60898232e-01,
                         -7.76471198e-01,  -7.35381067e-01,  -7.40880013e-01,
                         -7.58853972e-01,  -7.52313495e-01,  -7.66868889e-01,
                         -7.68537998e-01,  -7.52333343e-01,  -7.71023154e-01,
                         -7.44168878e-01,  -7.64886737e-01,  -7.55540252e-01,
                         -7.55182862e-01,  -7.56765783e-01,  -7.69001901e-01,
                         -7.65896142e-01,  -7.70939291e-01,  -7.58235812e-01,
                         -7.66259074e-01,  -7.75740862e-01,  -7.69004285e-01,
                         -7.67540514e-01,  -7.65662313e-01,  -7.74107039e-01,
                         -7.61699080e-01,  -7.62092590e-01,  -7.47440457e-01,
                         -7.69032359e-01,  -7.41328478e-01,  -7.69764364e-01,
                         -7.63204217e-01,  -7.66011536e-01,  -7.59871900e-01,
                         -7.63199568e-01,  -7.84844816e-01,   7.47545203e-03,
                          1.36470608e-02,   1.49178244e-02,  -1.38514955e-02,
                         -7.52728164e-01,  -7.72090018e-01,  -7.77402401e-01,
                         -7.60687888e-01,  -7.70499229e-01,  -7.41818845e-01,
                         -7.54248381e-01,  -7.74462581e-01,  -7.36498475e-01,
                         -7.58097827e-01,  -7.71791339e-01,  -7.41770208e-01,
                         -7.71118701e-01,  -7.33354270e-01,  -7.48106062e-01,
                         -7.55117476e-01,  -7.38709748e-01,  -7.75188804e-01,
                         -7.68472612e-01,  -7.78881311e-01,  -7.50306964e-01,
                         -7.67219067e-01,  -7.47899532e-01,  -7.47979701e-01,
                         -7.41207778e-01,  -7.43950307e-01,  -7.63054848e-01,
                         -7.61515617e-01,  -7.54696310e-01,  -7.67542779e-01,
                         -7.65383780e-01,  -7.60605097e-01,  -7.60105550e-01,
                         -7.58998215e-01,  -7.54641056e-01,  -7.50255942e-01,
                         -7.28987336e-01,  -7.37350404e-01,  -7.59859145e-01,
                         -7.67281413e-01,  -7.53599167e-01,  -7.47709453e-01,
                         -7.52674997e-01,  -7.61026323e-01,  -7.59313643e-01,
                         -7.41222739e-01,  -7.59377003e-01,  -7.55833209e-01,
                         -7.65543282e-01,  -7.90866375e-01,  -7.55246580e-01,
                         -7.72938192e-01,  -9.34013128e-01,  -9.18685317e-01,
                         -9.28585529e-01,  -9.22366083e-01,  -9.32000756e-01,
                         -9.33403373e-01,  -9.36278582e-01,  -9.24191058e-01,
                         -9.18481112e-01,  -9.34299469e-01,  -9.15449560e-01,
                         -9.27831113e-01,  -7.44331837e-01,  -7.55465209e-01,
                         -7.49464214e-01,  -7.53565729e-01,  -7.60791600e-01,
                         -7.56992698e-01,  -7.66258776e-01,  -7.27347732e-01,
                         -7.63110518e-01,  -7.53347397e-01,  -7.78236508e-01,
                         -7.59382188e-01,  -7.57644355e-01,  -7.75644720e-01,
                         -7.48952329e-01,  -7.58351862e-01,  -7.48083591e-01,
                         -7.55317509e-01,  -7.56192207e-01,  -7.69763947e-01,
                         -7.57773638e-01,  -7.56229997e-01,  -7.58837581e-01,
                         -7.41386890e-01,  -9.43368793e-01,  -9.30314958e-01,
                         -9.27581072e-01,  -9.46377814e-01,  -9.04014289e-01,
                         -9.20443773e-01,  -9.26295221e-01,  -9.31222796e-01,
                         -9.47876573e-01,  -9.45302546e-01,  -9.46294427e-01,
                         -9.34341788e-01,  -7.61461079e-01,  -7.59056151e-01,
                         -7.77943254e-01,  -7.73837328e-01,  -9.35063124e-01,
                         -9.18567955e-01,  -9.58913684e-01,  -9.15957034e-01,
                         -9.27412391e-01,  -9.40077662e-01,  -9.37229991e-01,
                         -9.36052680e-01,  -9.22290027e-01,  -9.24149632e-01,
                         -9.27550912e-01,  -9.46374059e-01,  -9.21837866e-01,
                         -9.24528837e-01,  -9.24893677e-01,  -9.33668494e-01,
                         -9.27728653e-01,  -9.25072134e-01,  -9.28145289e-01,
                         -9.23421025e-01,  -9.25507545e-01,  -9.26340759e-01,
                         -9.09698248e-01,  -9.10681248e-01,  -7.53252745e-01,
                         -7.57204831e-01,  -7.63128102e-01,  -7.32200384e-01,
                         -7.59364486e-01,  -7.54769862e-01,  -7.59413958e-01,
                         -7.61651695e-01,  -7.67445147e-01,  -7.63453662e-01,
                         -7.56601810e-01,  -7.44677663e-01,  -7.61149406e-01,
                         -7.64722586e-01,  -7.67291367e-01,  -7.41469443e-01,
                         -7.47033060e-01,  -7.26634860e-01,  -7.46055722e-01,
                         -7.35251129e-01,  -9.42529261e-01,  -9.34792578e-01,
                         -9.48954284e-01,  -9.49564934e-01,  -9.58165646e-01,
                         -9.32738960e-01,  -9.32780325e-01,  -9.11347926e-01,
                         -9.37832415e-01,  -9.60334897e-01,  -9.36283886e-01,
                         -9.34733331e-01,  -9.27864850e-01,  -9.57128704e-01,
                         -9.33229089e-01,  -9.46884692e-01,  -7.72176802e-01,
                         -7.59826422e-01,  -7.60640204e-01,  -7.82535672e-01,
                         -7.67612100e-01,  -7.73148477e-01,  -7.59337425e-01,
                         -7.48075485e-01,  -6.22025412e-03,   1.08570857e-02,
                          1.55877136e-03,   2.34199993e-04,   6.03578705e-03,
                         -2.32863519e-02,  -1.15261767e-02,   1.47305438e-02,
                         -1.66025292e-02,  -1.05075771e-02,   4.41568810e-03,
                         -2.04036403e-02,  -7.84501910e-01,  -7.74309576e-01,
                         -7.61453569e-01,  -7.46624231e-01,  -3.66075449e-02,
                          4.67683040e-02,  -2.36020889e-02,  -1.51276439e-02,
                         -1.00340974e-02,  -2.03065928e-02,  -2.87028495e-02,
                         -1.13998624e-02,   1.51150793e-01,   1.53442144e-01,
                          1.46384314e-01,   1.49270415e-01,  -3.32017727e-02,
                         -2.95078270e-02,  -3.26915458e-02,  -1.96094681e-02,
                          1.51222214e-01,   1.28479615e-01,   1.39280245e-01,
                          1.73700586e-01,  -1.67839741e-03,  -8.34763225e-04,
                         -1.30197816e-02,  -1.15984539e-02,  -1.36297140e-02,
                         -1.43763435e-03,   1.80819407e-02,   1.32677658e-02,
                         -8.87323637e-03,   9.05030221e-03,  -6.05885824e-03,
                         -8.11447203e-03,   1.43573821e-01,   1.59846857e-01,
                          1.39797300e-01,   1.56449527e-01,   1.50718138e-01,
                          1.67794809e-01,   1.36510178e-01,   1.65177241e-01,
                          1.66810349e-01,   1.71549067e-01,   1.63568079e-01,
                          1.81163415e-01,   1.76788837e-01,   1.69337958e-01,
                          1.46115035e-01,   1.46210566e-01,   1.60386190e-01,
                          1.61714986e-01,   1.51011705e-01,   1.55071393e-01,
                          1.52690053e-01,   1.59042284e-01,   1.36085257e-01,
                          1.60503253e-01,   1.54427826e-01,   1.61343604e-01,
                          1.57018676e-01,   1.47924438e-01,   1.62712395e-01,
                          1.69311047e-01,   1.58466816e-01,   1.66489691e-01,
                          1.73434660e-01,   1.64093614e-01,   1.68906271e-01,
                          1.68730751e-01,   1.61870599e-01,   1.63123906e-01,
                          1.69475079e-01,   1.77085847e-01,   1.47275954e-01,
                          1.71539545e-01,   1.65438741e-01,   1.41205877e-01,
                          1.62443489e-01,   1.78442806e-01,   1.70711964e-01,
                          1.80334643e-01,   1.61619172e-01,   1.66119054e-01,
                          1.59416363e-01,   1.54358402e-01,   1.54396713e-01,
                          1.40827924e-01,   1.81072012e-01,   1.55277342e-01,
                          1.61154121e-01,   1.76852658e-01,   1.81525201e-01,
                          1.66352823e-01,   2.01620045e-03,  -3.53522575e-03,
                          7.20695301e-04,  -6.11055223e-03,   8.12339131e-03,
                          4.01266292e-03,   7.97979347e-03,   7.02904910e-03,
                         -4.28436371e-03,  -3.11850593e-03,   1.16019053e-02,
                          2.28480995e-03,   1.77165475e-02,  -8.46734829e-03,
                         -7.70927081e-03,   7.76410429e-03,   3.55386850e-03,
                         -5.97023871e-03,  -1.70790795e-02,  -2.72384435e-02,
                          1.68212906e-01,   1.57384589e-01,   1.44188300e-01,
                          1.51481852e-01,   1.46944895e-01,   1.48733586e-01,
                          1.70841172e-01,   1.56809300e-01,   1.55444086e-01,
                          1.41129956e-01,   1.74445972e-01,   1.57972991e-01,
                         -1.08493166e-02,  -2.50632735e-03,   1.36967180e-02,
                          1.42730800e-02,   1.20179188e-02,   3.61428806e-03,
                         -2.27531251e-02,  -1.45761482e-03,  -3.60063510e-04,
                         -2.14229543e-02,  -2.78080697e-03,   5.48666809e-03,
                         -9.04866587e-03,   4.20880085e-03,  -2.83983815e-02,
                          2.11041258e-03,  -1.14059616e-02,  -7.12057902e-03,
                         -6.90576388e-03,  -1.07448334e-02,   6.71912031e-03,
                          7.64101977e-03,   4.10984131e-03,   6.25368673e-03,
                         -3.68019636e-03,   5.84685663e-03,  -7.06645939e-03,
                         -4.45716694e-04,  -5.84574766e-04,  -1.73735600e-02,
                         -9.25268419e-03,   1.46125327e-03,  -1.63737626e-03,
                         -4.48177662e-03,   2.12150835e-03,   3.27171013e-03,
                          5.18549932e-03,  -1.11892335e-02,  -1.15251858e-02,
                         -1.49587486e-02,  -8.54779035e-03,   6.96749985e-03,
                         -5.04788896e-03,   2.07932270e-03,  -1.04458407e-02,
                         -2.22597760e-03,  -3.21418745e-03,  -1.65510215e-02,
                         -9.26210254e-04,  -1.40000973e-02,  -3.15707386e-03,
                          4.80789505e-03,  -1.39111523e-02,  -9.68336221e-03,
                          1.70410937e-03,   6.11011591e-03,   1.19660022e-02,
                          3.17071285e-03,   1.00248521e-02,   1.42450882e-02,
                          2.23230366e-02,   4.78411652e-03,   2.81248186e-02,
                         -5.88649139e-03,   1.24567538e-04,   1.86013263e-02,
                         -3.09683452e-03,   1.53147373e-02,   2.69499235e-02,
                          2.11447459e-02,   3.69877016e-05,   1.70274395e-02,
                          8.79237242e-03,   1.89311877e-02,   7.21634412e-03,
                          2.20778789e-02,   2.02161307e-03,   1.60913821e-02,
                          1.00543897e-03,   1.48943374e-02,   5.19536156e-03,
                         -1.31123716e-05,   3.09956297e-02,   4.19214740e-03,
                         -1.87942907e-02,   2.79915184e-02,  -4.10986925e-03,
                         -7.59078795e-03,  -1.44451344e-02,  -2.16421019e-02,
                          5.08218072e-03,  -7.58736441e-03,  -1.79839786e-03,
                          7.23429350e-03,  -2.44824681e-02,  -1.22090876e-02,
                          7.39014521e-03,   5.26513020e-03,  -3.10760443e-05,
                          1.65759791e-02,  -9.19190764e-01,  -9.40655291e-01,
                         -9.27598536e-01,  -9.29816127e-01,  -9.33696032e-01,
                         -9.35941458e-01,  -9.40273941e-01,  -9.48643565e-01,
                         -9.40725446e-01,  -9.51122761e-01,  -9.45772171e-01,
                         -9.47848499e-01,   3.77538591e-03,  -1.17227864e-02,
                         -4.72480617e-03,  -6.08441792e-03,  -9.16799437e-03,
                         -6.52395934e-03,  -1.52091729e-02,   1.52297290e-02,
                         -5.74022485e-03,  -8.00101366e-03,  -1.29155964e-02,
                         -1.50018632e-02,  -9.39804196e-01,  -9.25248563e-01,
                         -9.37103689e-01,  -9.31543231e-01,  -9.36997890e-01,
                         -9.29618597e-01,  -9.16384161e-01,  -9.35862422e-01,
                         -9.25273061e-01,  -9.36611772e-01,  -9.32176888e-01,
                         -9.22277629e-01,  -9.12744403e-01,  -9.49344158e-01,
                         -9.47490990e-01,  -9.21770036e-01,  -9.50781465e-01,
                         -9.59695637e-01,  -9.43017185e-01,  -9.33729947e-01,
                         -9.31296885e-01,  -9.39753115e-01,  -9.19833422e-01,
                         -9.30902541e-01,  -9.36173320e-01,  -9.25996363e-01,
                         -9.31826353e-01,  -9.48906124e-01,  -9.32965815e-01,
                         -9.17081118e-01,  -9.07420516e-01,  -9.32560325e-01,
                         -9.24966455e-01,  -9.47274983e-01,  -9.65700746e-01,
                         -9.50908005e-01,  -9.46756124e-01,  -9.29176927e-01,
                         -9.38745141e-01,  -9.30833697e-01,  -9.42505538e-01,
                         -9.51260924e-01,  -9.36387539e-01,  -9.38060522e-01,
                         -9.40250397e-01,  -9.36307371e-01,  -9.31286633e-01,
                         -9.34723794e-01,  -9.19514120e-01,  -9.40398037e-01,
                         -9.34307635e-01,  -9.55196321e-01,  -9.35378253e-01,
                         -9.39013243e-01,  -9.15538311e-01,  -9.39658165e-01,
                         -9.11479414e-01,  -9.48726714e-01,  -9.20585275e-01,
                         -9.45673466e-01,  -9.35282052e-01,  -9.37916815e-01,
                         -9.48410451e-01,  -9.46342528e-01,  -9.44654644e-01,
                         -9.37194169e-01,  -9.63524997e-01,  -9.39388514e-01,
                         -9.48276401e-01,  -9.39981639e-01,  -9.48074043e-01,
                         -9.34356213e-01,  -9.14584100e-01,  -9.48655069e-01,
                         -9.53625262e-01,  -9.57436025e-01,  -9.34315741e-01,
                         -9.42287862e-01,  -9.25205469e-01,  -9.47857380e-01,
                         -9.25185978e-01,  -9.40250337e-01,  -9.47046578e-01,
                         -9.43764210e-01,  -9.61796522e-01,  -9.34527755e-01,
                         -9.48111534e-01,  -9.44007039e-01,  -9.34340835e-01,
                         -9.42381322e-01,  -9.35593605e-01,  -9.36643243e-01,
                         -9.39066172e-01,  -9.29717183e-01,  -9.27176952e-01,
                         -9.14212048e-01,  -9.25561130e-01,  -9.24024940e-01,
                         -9.13059890e-01,  -9.23263133e-01,  -9.32523608e-01,
                         -9.35774446e-01,  -9.29028690e-01,  -9.51473057e-01,
                         -9.29396331e-01,  -9.36380386e-01,  -9.37342286e-01,
                         -9.60528314e-01,  -9.32928324e-01,  -9.60757256e-01,
                         -9.65912759e-01,  -9.53267753e-01,  -9.52569425e-01,
                         -9.46783543e-01,  -9.26605105e-01,  -9.45417166e-01,
                         -9.27665293e-01,  -9.36561227e-01,  -9.31295633e-01,
                         -9.12738919e-01,  -9.26286757e-01,  -9.29584861e-01,
                         -9.27116156e-01,  -9.24700081e-01,  -9.18729544e-01,
                         -9.24448609e-01,  -9.23900902e-01,  -9.38384175e-01,
                         -9.17460918e-01,  -9.27097321e-01,  -9.28138256e-01,
                         -9.28047001e-01,  -9.46050107e-01,  -9.39166188e-01,
                         -9.35929179e-01,  -9.33762312e-01,  -9.40143526e-01,
                         -9.34219956e-01,  -9.27821577e-01,  -9.41186666e-01,
                         -9.34890389e-01,  -9.40208197e-01,  -9.18072581e-01,
                         -9.46411192e-01,  -9.30550396e-01,  -9.50898468e-01,
                         -9.46875691e-01,  -9.15081561e-01,  -9.35132980e-01,
                         -9.22321856e-01,  -9.18900609e-01,  -9.40833807e-01,
                         -9.22995150e-01,  -9.41069305e-01,  -9.46709812e-01,
                         -9.13318574e-01,  -9.46339786e-01,  -9.25515354e-01,
                         -9.26467299e-01,  -9.34825718e-01,  -9.25058007e-01,
                         -9.30873692e-01,  -9.33677077e-01,  -9.33955133e-01,
                         -9.26780462e-01,  -9.49367225e-01,  -9.43277299e-01,
                         -9.42959726e-01,  -9.54141080e-01,  -9.27998424e-01,
                         -9.17713165e-01,  -9.29938197e-01,  -9.37668204e-01,
                         -9.26268816e-01,  -9.40606713e-01,  -9.37921345e-01,
                         -9.38771069e-01,  -9.41662014e-01,  -9.29038107e-01,
                         -9.40384507e-01,  -9.05997336e-01,  -9.35770810e-01,
                         -9.26538587e-01,  -9.45938826e-01,  -9.36530590e-01,
                         -9.35153961e-01,  -9.26943123e-01,  -9.11743283e-01,
                         -9.34168279e-01,  -9.27665055e-01,  -9.44653273e-01,
                         -9.43829179e-01,  -9.29705799e-01,  -9.31998312e-01,
                         -9.45798516e-01,  -9.41541255e-01,  -9.47733283e-01,
                         -9.38876629e-01,  -9.53233838e-01,  -9.35820818e-01,
                         -9.40103948e-01,  -9.39809442e-01,  -9.16457832e-01,
                         -9.47377205e-01,  -9.33918536e-01,  -9.57116008e-01,
                         -9.38773870e-01,  -9.30120111e-01,  -9.62130308e-01,
                         -9.48724389e-01,  -9.43217754e-01,  -9.61319923e-01,
                         -9.43705678e-01,  -9.31315482e-01,  -9.44275975e-01,
                         -9.53296602e-01,  -9.47036803e-01,  -9.45845306e-01,
                         -9.54157650e-01,  -9.29487228e-01,  -9.48150575e-01,
                         -9.34873641e-01,  -9.35443044e-01,  -9.27729547e-01,
                         -9.42832410e-01,  -9.24609005e-01,  -9.31962430e-01,
                         -9.42828298e-01,  -9.25591648e-01,  -9.41414177e-01,
                         -9.42327201e-01,  -9.35711920e-01,  -9.40731108e-01,
                         -9.36783671e-01,  -9.17861342e-01,  -9.49251235e-01,
                         -9.21576619e-01,  -9.44054723e-01,  -9.16005254e-01,
                         -9.34351265e-01,  -9.28597748e-01,  -9.41457212e-01,
                         -9.36260045e-01,  -9.24594343e-01,  -9.23709393e-01,
                         -9.59293127e-01,  -9.49398339e-01,  -9.32496786e-01,
                         -9.33008373e-01,  -9.41113591e-01,  -9.32625949e-01,
                         -9.19193149e-01,  -8.10731947e-03,   1.72386728e-02,
                          2.56223511e-03,  -3.89850489e-03,  -2.73426902e-03,
                          9.19683184e-03,  -1.44343302e-02,   1.15814398e-03,
                          1.20337890e-03,  -3.22699477e-03,   5.16465958e-03,
                         -1.53024355e-02,   2.04487573e-02,  -8.34803469e-03,
                         -4.02520690e-03,   2.39115045e-03,   1.54875061e-02,
                          1.00404595e-03,   9.76213312e-04,  -5.22941770e-03,
                          1.26598701e-02,   1.42441522e-02,  -2.57146638e-03,
                         -6.35457272e-03,  -9.19667259e-03,  -1.66189950e-02,
                          2.31484510e-02,  -1.55590000e-02,   2.00340468e-02,
                         -1.43160075e-02,  -3.89230903e-03,  -4.77960519e-03,
                         -1.29936747e-02,  -2.09280178e-02,  -2.35683096e-04,
                         -4.65938309e-03,   7.55605288e-03,  -1.25051411e-02,
                         -8.64803884e-03,  -7.37348432e-03,  -1.18233120e-05,
                          8.85938201e-03,  -8.43731221e-04,   7.34723220e-03,
                          4.65672137e-03,   5.00765769e-03,   1.26699335e-03,
                         -4.65306919e-03,  -9.14891779e-01,  -9.28546607e-01,
                         -9.31800306e-01,  -9.13987517e-01,  -9.39144671e-01,
                         -9.33744013e-01,  -9.35842454e-01,  -9.23429251e-01,
                         -9.35303509e-01,  -9.43103075e-01,  -9.33980107e-01,
                         -9.25044596e-01,  -9.48612154e-01,  -9.18879926e-01,
                         -9.28498149e-01,  -9.42240834e-01,  -9.41007197e-01,
                         -9.44921613e-01,  -9.52138186e-01,  -9.26554620e-01,
                         -9.44940627e-01,  -9.38660860e-01,  -9.52008665e-01,
                         -9.50124025e-01,  -9.28418875e-01,  -9.16829705e-01,
                         -9.27084684e-01,  -9.40903187e-01,  -9.41817820e-01,
                         -9.33545530e-01,  -9.36558664e-01,  -9.25024211e-01,
                         -9.32877660e-01,  -9.35528219e-01,  -9.40264404e-01,
                         -9.31097150e-01,  -9.39642191e-01,  -9.45342660e-01,
                         -9.38254654e-01,  -9.46025610e-01,  -9.45460975e-01,
                         -9.45126235e-01,  -9.33101654e-01,  -9.42420244e-01,
                         -9.32060182e-01,  -9.47673619e-01,  -9.42790866e-01,
                         -9.37520921e-01,  -9.38144326e-01,  -9.23253655e-01,
                         -9.36914086e-01,  -9.46969151e-01,  -9.20274019e-01,
                         -9.37471271e-01,  -9.31477368e-01,  -9.40777123e-01,
                         -9.23993707e-01,  -9.30551469e-01,  -9.17110980e-01,
                         -9.27929223e-01,  -9.28994596e-01,  -9.13918793e-01,
                         -9.42793489e-01,  -9.17560995e-01,  -9.41794634e-01,
                         -9.18624520e-01,  -9.38183129e-01,  -9.39179242e-01,
                         -9.38525438e-01,  -9.41522062e-01,  -9.40833926e-01,
                         -9.34385836e-01,  -9.32889998e-01,  -9.45164680e-01,
                         -9.36155140e-01,  -9.30861056e-01,  -9.44539547e-01,
                         -9.38109100e-01,  -9.36251760e-01,  -9.29229021e-01,
                         -9.26229119e-01,  -9.38847244e-01,  -9.34574783e-01,
                         -9.41808283e-01,  -9.37696040e-01,  -9.24860179e-01,
                         -9.20458555e-01,  -9.30276275e-01,  -9.31098282e-01,
                         -9.35539961e-01,  -9.31518614e-01,  -9.31992888e-01,
                         -9.27158415e-01,  -9.30833936e-01,  -9.25453484e-01,
                         -9.40936267e-01,  -9.43781495e-01,  -9.41206038e-01,
                         -9.34305668e-01,  -9.35237110e-01,  -9.33673382e-01,
                         -9.41728890e-01,  -9.33769882e-01,  -9.40904081e-01,
                         -9.24385309e-01,  -9.30603802e-01,  -9.34963465e-01,
                         -9.26829696e-01,  -9.23552334e-01,  -9.40879285e-01,
                         -9.30488586e-01,  -9.40175354e-01,  -9.24623251e-01,
                         -9.29174781e-01,  -9.10214007e-01,  -9.33431566e-01,
                         -9.24006343e-01,  -9.40268159e-01,  -9.23807502e-01,
                         -9.28350389e-01,  -9.40114498e-01,  -9.22352016e-01,
                         -9.39468324e-01,  -9.38644111e-01,  -9.20579076e-01,
                         -9.44606185e-01,  -9.26298499e-01,  -9.32659090e-01,
                         -9.45968211e-01,  -9.38563526e-01,  -9.35571551e-01,
                         -9.28028524e-01,  -9.42031026e-01,  -9.28816795e-01,
                         -9.32329416e-01,  -9.23351824e-01,  -9.29258108e-01,
                         -9.26665843e-01,  -9.26666200e-01,  -9.29632545e-01,
                         -9.32884753e-01,  -9.29536939e-01,  -9.33196902e-01,
                         -9.29524302e-01,  -9.29549575e-01,  -9.39211965e-01,
                         -9.27764893e-01,  -9.33825970e-01,  -9.31076527e-01,
                         -9.30280566e-01,  -9.25902486e-01,  -9.24499810e-01,
                         -9.27822709e-01,  -9.25031006e-01,  -9.26709771e-01,
                         -9.30062354e-01,  -9.27678049e-01,  -9.30846095e-01,
                         -9.22183514e-01,  -9.21995163e-01,  -9.23058093e-01,
                         -9.28331494e-01,  -9.28457558e-01,  -9.18914139e-01,
                         -9.21208382e-01,  -9.27684307e-01,  -9.28401828e-01,
                         -9.31259930e-01,  -9.20776904e-01,  -9.25769210e-01,
                         -9.24735904e-01,  -9.25185084e-01,  -9.27991509e-01,
                         -9.37269449e-01,  -9.23101425e-01,  -9.34698105e-01,
                         -9.19652820e-01,  -9.31040049e-01,  -9.21727419e-01,
                         -9.42245305e-01,  -9.22710419e-01,  -9.26581740e-01,
                         -9.32755828e-01,  -9.20169353e-01,  -9.31290090e-01,
                         -9.22372878e-01,  -9.31994557e-01,  -9.31360483e-01,
                         -9.18996334e-01,  -9.38121498e-01,  -9.26074743e-01,
                         -9.26326692e-01,  -9.37437415e-01,  -9.30224121e-01,
                         -9.37905490e-01,  -9.34580028e-01,  -9.35448229e-01,
                         -9.20655549e-01,  -9.26456809e-01,  -9.33742583e-01,
                         -9.30388808e-01,  -9.28562343e-01,  -9.32531714e-01,
                         -9.24645782e-01,  -9.35971200e-01,  -9.36363161e-01,
                         -9.38392758e-01,  -9.39381063e-01,  -9.38644469e-01,
                         -9.34980094e-01,  -9.38448846e-01,  -9.34954345e-01,
                         -9.38858330e-01,  -9.38483238e-01,  -9.37429786e-01,
                         -9.32351589e-01,  -9.38082039e-01,  -9.32298601e-01,
                         -9.34013605e-01,  -9.28621948e-01,  -9.33259785e-01,
                         -9.30592537e-01,  -9.29973662e-01,  -9.21053112e-01,
                         -9.25973475e-01,  -9.26792681e-01,  -9.35414851e-01,
                         -9.34231818e-01,  -9.36012864e-01,  -9.33120847e-01,
                         -9.31530178e-01,  -9.27583933e-01,  -9.25274014e-01,
                         -9.23298120e-01,  -9.28154111e-01,  -9.34064627e-01,
                         -9.34096098e-01,  -9.35226679e-01,  -9.27443087e-01,
                         -9.35463905e-01,  -9.27799582e-01,  -9.39333081e-01,
                         -9.23937619e-01,  -9.33970809e-01,  -9.34377968e-01,
                         -9.33878660e-01,  -9.33143437e-01,  -9.33939874e-01,
                         -9.30261195e-01,  -9.24740314e-01,  -9.38507259e-01,
                         -9.32626307e-01,  -9.32504058e-01,  -9.31580722e-01,
                         -9.32269335e-01,  -9.35772359e-01,  -9.37181294e-01,
                         -9.31972265e-01,  -9.33221519e-01,  -9.33602989e-01,
                         -9.33566391e-01,  -9.40478861e-01,  -9.30351973e-01,
                         -9.35077310e-01,  -9.34412897e-01,  -9.33852255e-01,
                         -9.30329382e-01,  -9.29282010e-01,  -9.28849816e-01,
                         -9.29511130e-01,  -9.39505398e-01,  -9.36864913e-01,
                         -9.43165660e-01,  -9.29656565e-01,  -9.36524510e-01,
                         -9.33496177e-01,  -9.28392410e-01,  -9.30924058e-01,
                         -9.27648902e-01,  -9.35461223e-01,  -9.34641182e-01,
                         -9.37399209e-01,  -9.30293322e-01,  -9.36452091e-01,
                         -9.39742565e-01,  -9.40787196e-01,  -9.40347135e-01,
                         -9.35263753e-01,  -9.32377696e-01,  -9.24673617e-01,
                         -9.42349374e-01,  -9.29589927e-01,  -9.41093385e-01,
                         -9.43139136e-01,  -9.36676562e-01,  -9.36443985e-01,
                         -9.26063240e-01,  -9.32234645e-01,  -9.35910642e-01,
                         -9.31593597e-01,  -9.21306610e-01,  -9.34254527e-01,
                         -9.31859076e-01,  -9.32756484e-01,  -9.44270849e-01,
                         -9.33291733e-01,  -9.36413765e-01,  -9.39405382e-01,
                         -9.35008883e-01,  -9.32350516e-01,  -9.37449634e-01,
                         -9.26840246e-01,  -9.30041373e-01,  -9.29869771e-01,
                         -9.27171350e-01,  -9.36572194e-01,  -9.27122712e-01,
                         -9.20478225e-01,  -9.22262251e-01,  -9.38855827e-01,
                         -9.16088223e-01,  -9.32245851e-01,  -9.35915768e-01,
                         -9.37587261e-01,  -9.30743217e-01,  -9.21977937e-01,
                         -9.35909748e-01,  -9.32262123e-01,  -9.30577636e-01,
                         -9.35497344e-01,  -9.47246253e-01,  -9.39340174e-01,
                         -9.30514693e-01,  -9.19028044e-01,  -9.29052234e-01,
                         -9.15676594e-01,  -9.30944145e-01,  -9.29336250e-01,
                         -9.42708015e-01,  -9.29062128e-01,  -9.42017376e-01,
                         -9.32875216e-01,  -9.35686231e-01,  -9.29415286e-01,
                         -9.26466048e-01,  -9.38638926e-01,  -9.38073516e-01,
                         -9.41831231e-01,  -9.35908854e-01,  -9.38821197e-01,
                         -9.21379566e-01,  -9.22802031e-01,  -9.23724353e-01,
                         -9.31136549e-01,  -9.34493423e-01,  -9.33570683e-01,
                         -9.36491132e-01,  -9.34439421e-01,  -9.29136336e-01,
                         -9.27944779e-01,  -9.32314277e-01,  -9.30226266e-01,
                         -9.21020389e-01,  -9.19650078e-01,  -9.08050716e-01,
                         -9.27913070e-01,  -9.30821836e-01,  -9.29073572e-01,
                         -9.37975824e-01,  -9.24303114e-01,  -9.16804016e-01,
                         -9.26967502e-01,  -9.23463285e-01,  -9.33635235e-01,
                         -9.33269560e-01,  -9.22196686e-01,  -9.28894341e-01,
                         -9.26105440e-01,  -9.32522595e-01,  -9.24534619e-01,
                         -9.22615886e-01,  -9.22640443e-01,  -9.22044039e-01,
                         -9.14628267e-01,  -9.22156990e-01,  -9.28001523e-01,
                         -9.25125122e-01,  -9.21344578e-01,  -9.23561394e-01,
                         -9.18965995e-01,  -9.34917748e-01,  -9.27403092e-01,
                         -9.33407247e-01,  -9.25058365e-01,  -9.35070813e-01,
                         -9.52911019e-01,  -9.41826344e-01,  -9.36822772e-01,
                         -9.30213273e-01,  -9.38755333e-01,  -9.49023366e-01,
                         -9.28288102e-01,  -9.24867630e-01,  -9.27478671e-01,
                         -9.29735422e-01,  -9.35463786e-01,  -9.24111664e-01,
                         -9.20520902e-01,  -9.33910906e-01,  -9.28149164e-01,
                         -9.30548489e-01,  -9.15501952e-01,  -9.15941536e-01,
                         -9.44501936e-01,  -9.28744674e-01,  -9.21923220e-01,
                         -9.23053920e-01,  -9.16647494e-01,  -9.12792623e-01,
                         -9.45165455e-01,  -9.29134429e-01,  -9.22591567e-01,
                         -9.27779794e-01,  -9.37867343e-01,  -9.44262624e-01,
                         -9.38834369e-01,  -9.40587163e-01,  -9.24543083e-01,
                         -9.13104787e-03,   1.57649931e-03,   8.40522407e-05,
                          1.44722604e-03,   6.89520175e-03,   5.28361369e-03,
                          2.20637838e-03,   4.49916534e-03,   9.55680478e-03,
                          4.88842651e-03,   3.57076502e-03,   6.39702147e-03,
                         -1.13272807e-02,   2.48539058e-04,  -4.79937065e-03,
                         -3.77448485e-03,   1.40146511e-02,  -2.37006112e-03,
                         -5.75241540e-03,  -8.78241286e-03,   2.05150340e-02,
                          1.99926514e-02,   6.24144729e-03,   9.26220696e-03,
                          1.00789433e-02,   1.16052395e-02,   2.93753168e-04,
                          1.30081587e-02,   1.82155650e-02,   4.20083106e-03,
                          1.36681851e-02,   7.74912070e-03,   2.05359980e-02,
                          7.01496657e-03,  -2.73107411e-03,  -2.73465016e-03,
                          1.06041040e-02,   1.22392066e-02,   1.74363982e-02,
                          1.01017309e-02,  -1.89434271e-03,   8.70236661e-03,
                          1.48082133e-02,   1.22490479e-02,  -2.87758349e-03,
                          5.64954011e-03,   5.42969303e-03,   5.67985373e-03,
                          1.06814541e-02,   1.79165248e-02,   2.10665911e-02,
                          1.28647964e-02,   1.29515585e-02,   3.50811373e-04,
                          1.12894336e-02,   4.23594052e-03,   4.86680353e-03,
                          7.53164350e-04,   1.96422637e-02,   1.48570444e-02,
                          6.69696368e-03,   1.68294441e-02,   1.62580311e-02,
                         -6.18804153e-03,   7.36575015e-03,  -3.13809833e-05,
                          8.03628284e-03,   2.42754910e-03,   4.27681627e-03,
                          4.18518204e-03,   1.40909478e-03,   1.46154575e-02,
                          1.15154134e-02,  -1.70207175e-03,   1.28787465e-03,
                         -4.59632976e-03,  -7.18452642e-03,   1.88932510e-03,
                         -3.50472494e-03,  -1.47306686e-02,   3.32059036e-03,
                          1.09749306e-02,   1.61464158e-02,   1.37584889e-02,
                          1.53513998e-02,   1.48340566e-02,   1.43658090e-02,
                          5.30944997e-03,  -2.19901814e-03,   3.62662424e-04,
                         -6.99141674e-05,   1.52856084e-02,   5.57261927e-04,
                         -6.26736041e-03,   3.49477981e-03,   7.08517851e-03,
                          8.46890081e-03,   2.82690115e-03,   1.56479031e-02,
                          9.79549624e-03,   2.75251688e-03,   9.47526190e-03,
                          4.86814836e-03,   1.52988946e-02,  -6.60643156e-04,
                         -2.59948615e-03,  -1.20306360e-02,  -5.07163955e-03,
                          6.53974013e-03,   9.99446213e-03,   2.58677569e-03,
                         -2.83525232e-03,   3.35942162e-03,   3.52076185e-03,
                         -5.13302209e-03,   3.00930999e-03,  -2.36398331e-03,
                         -6.08468801e-03,  -4.46685543e-03,  -1.21436641e-02,
                         -3.31704877e-03,  -1.12719201e-02,  -6.59863465e-03,
                          1.46086517e-04,  -3.44470056e-04,  -7.98095763e-03,
                          3.40792770e-03,  -1.21663685e-03,   1.15110548e-02,
                          3.77621758e-03,   1.44572218e-03,  -6.41901186e-03,
                         -9.92728490e-03,  -5.73575497e-03,   2.05316744e-03,
                         -7.79063394e-03,  -3.21504683e-03,   2.15106667e-03,
                         -1.72749255e-03,  -2.22601229e-03,   4.48472239e-03,
                          1.94858499e-02,   8.62286799e-03,   1.12131434e-02,
                          1.32927708e-02,   1.36761623e-03,   3.89156071e-03,
                         -1.03519615e-02,   2.19333521e-03,  -3.24665662e-03,
                          3.14150797e-03,  -2.33308738e-03,  -4.05693473e-03,
                         -5.01080416e-03,  -7.72916805e-03,  -7.89732113e-03,
                         -1.13744976e-03,  -1.65658048e-03,  -3.64231481e-03,
                         -6.41823560e-03,   3.73181421e-03,  -1.54150766e-03,
                         -9.07900045e-04,  -1.32063068e-02,  -3.19190603e-03,
                          1.07833873e-02,   9.97531344e-04,  -6.47839159e-03,
                          2.13586818e-03,  -2.79190252e-03,  -6.28894148e-03,
                         -2.18212185e-03,   3.62094119e-03,  -7.29774183e-04,
                          2.05965422e-04,   2.42878264e-03,   1.72046514e-03,
                         -3.80536681e-03,  -8.65319511e-04,  -5.26537979e-03,
                          8.96014390e-04,  -5.08081540e-03,  -4.10383986e-03,
                         -4.13535908e-03,   5.29427966e-03,  -7.54504744e-03,
                          1.31309312e-02,   7.86930788e-03,  -4.24661348e-03,
                         -4.56752023e-03,   1.11165186e-02,  -6.22827280e-03,
                          4.62883356e-04,  -5.08501520e-03,  -4.96482756e-03,
                          2.47402466e-03,  -4.11055516e-03,  -6.99856924e-03,
                         -2.39543361e-03,  -1.91787153e-03,  -1.49140684e-02,
                         -8.56509525e-03,  -8.90595466e-03,  -4.69420152e-03,
                         -4.17006016e-03,  -1.16108940e-03,   4.47678001e-04,
                         -4.93873470e-03,   3.96117661e-03,   5.05053625e-03,
                          8.49178527e-04,   2.61809421e-03,   5.09938877e-03,
                         -7.81184121e-04,  -4.56410344e-04,   1.53378013e-03,
                          7.46883312e-03,  -5.42091252e-03,  -1.83227379e-03,
                          1.23998681e-02,   7.90235237e-04,   7.63782486e-03,
                          2.27591814e-03,   1.87366223e-03,   1.77357299e-03,
                          7.94841908e-03,   5.42916637e-03,   4.81325900e-03,
                          5.59417298e-04,   2.28190608e-03,  -1.81169726e-03,
                          3.70583893e-03,  -3.62348463e-03,   2.67426553e-03,
                          7.50161428e-03,   2.41361209e-03,  -9.23001498e-04,
                         -2.98715342e-04,  -7.33378038e-05,   3.70040559e-03,
                         -3.39825964e-03,  -7.77328014e-03,  -2.72919610e-03,
                         -2.31206039e-04,  -2.10931757e-03,   7.66027253e-04,
                          7.68769626e-03,   1.04184449e-03,   1.04727102e-02,
                          2.08591707e-02,   6.98783388e-03,   2.44516623e-03,
                         -5.47761703e-03,   9.58150532e-03,   1.01747224e-02,
                          4.27749567e-03,   5.41338604e-03,  -2.97960639e-03,
                          3.61920870e-03,  -3.98579380e-03,   1.03284810e-02,
                         -1.79512671e-03,  -1.45989485e-04,  -7.53409695e-03,
                          2.62907916e-03,   2.01891013e-03,   7.21409160e-04,
                          2.53777765e-03,   3.82185448e-03,   1.42039149e-03,
                          2.99472152e-03,  -3.79971857e-03,   3.23511031e-03,
                          7.14248652e-03,  -6.21811952e-04,   1.66836224e-04,
                         -4.13278816e-03,  -2.45539565e-03,   5.83784713e-04,
                          7.30491476e-03,   1.19626345e-02,   1.79237314e-02,
                         -3.83137679e-03,   4.43333993e-03,  -1.47250830e-04,
                          4.69308579e-03,  -1.16127660e-03,  -1.65758538e-03,
                          9.12505295e-03,   1.05641913e-02,   7.60753173e-05,
                          4.86316532e-03,   5.69937006e-03,  -6.90692104e-03,
                          1.80814895e-05,   2.73569673e-03,  -7.23705208e-03,
                         -7.45435571e-03,  -1.01681454e-02,   1.55969305e-04,
                         -1.13259079e-02,   5.63755771e-03,   7.21127773e-03,
                         -8.07890482e-03,  -1.62614621e-02,   1.64243544e-03,
                         -5.93092944e-03,  -7.60588236e-03,  -4.12785355e-03,
                          8.37820303e-03,   1.18355369e-02,   5.69472648e-03,
                         -5.38723730e-03,  -1.38987256e-02,  -8.67348071e-03,
                          2.45375303e-03,   4.14685672e-03,   8.82291421e-03,
                          2.92457175e-03,   3.94523004e-03,  -4.21639672e-03,
                         -5.05830534e-03,  -8.34128447e-03,  -2.76666181e-03,
                         -8.14318471e-03,   3.70305288e-03,  -7.90457055e-03,
                         -1.37071693e-02,  -3.46025242e-03,  -1.37363048e-02,
                          1.41657970e-03,  -1.56201480e-03,  -5.67546673e-03,
                         -3.37815448e-03,   1.73796732e-02,   1.25305690e-02,
                          8.47770926e-03,  -5.71750011e-03,   2.19936483e-03,
                          3.56982928e-03,   6.57367148e-03,  -3.94462002e-03,
                         -1.28924828e-02,   7.18095712e-03,  -9.12398566e-03,
                          9.03559569e-03,  -8.27773940e-03,  -6.22421131e-03,
                          2.91069713e-03,   6.36873161e-03,   6.15472021e-03,
                          1.59041211e-02,   5.12923114e-03,   5.96973998e-03,
                          2.37525906e-03,  -1.88197184e-03,   1.13170929e-02,
                         -4.57273191e-03,  -1.31556457e-02,  -7.38622248e-03,
                         -3.64201679e-03,  -4.98320721e-03,   3.74450395e-03,
                         -9.83156916e-03,  -8.09225347e-03,  -1.58444308e-02,
                         -6.61572535e-03,  -1.66083574e-02,   2.15791375e-03,
                         -4.80864337e-03,  -4.40985290e-03,  -1.35893105e-02,
                          1.12135033e-03,  -4.92928829e-03,  -8.16200767e-03,
                         -8.28466937e-03,   1.73557352e-03,   4.48170770e-03,
                          4.86460002e-03,   6.22358080e-03,  -5.74189518e-03,
                          5.50413271e-03,   7.01313000e-03,  -5.73681528e-03,
                         -9.81293269e-04,   1.14957104e-03,   2.48284009e-03,
                          9.45764501e-03,  -4.81664814e-04,   8.06923723e-04,
                         -5.60145685e-03,   5.65961702e-03,  -5.40341297e-03,
                         -8.23861640e-03,  -1.39717455e-03,  -1.64442174e-02,
                         -4.97727469e-03,  -5.04370965e-03,  -9.99376178e-03,
                         -4.76002664e-04,  -9.13120713e-03,  -1.26815140e-02,
                         -5.03911506e-05,   6.27650833e-03,   6.41478412e-03,
                          2.69320630e-03,   1.13239400e-02,   2.55948375e-03,
                          7.46096019e-03,   7.09932356e-04,  -5.57469158e-03,
                          1.35621289e-02,  -4.25400119e-03,   9.50208213e-03,
                         -7.49632623e-03,  -1.42762400e-02,   3.02412035e-03,
                          3.97663843e-03,   1.69752128e-02,  -7.47884763e-03,
                         -2.23428034e-03,   9.04968474e-04,  -8.40680487e-03,
                         -1.24721183e-02,   1.33859711e-02,   9.59644001e-03,
                          6.42121583e-03,   4.86805104e-03,  -8.85916036e-03,
                         -5.21687372e-03,   1.01784365e-02,   8.94826464e-03,
                         -3.90236522e-03,  -4.38547833e-03,   5.31293626e-04,
                         -8.88002804e-04,   5.85739093e-04,  -4.23661992e-03,
                         -9.74373240e-03,  -8.28409474e-03,   9.00180917e-03,
                          5.81299420e-03,   8.88065188e-05,   1.37870491e-03,
                          1.69651362e-03,  -7.43877608e-04,  -9.10034683e-03,
                          2.09440337e-03,  -1.18718939e-02,   1.55506767e-02,
                          2.46059056e-02,   5.85359987e-03,   8.80717579e-03,
                          9.64344945e-03,   2.22308072e-03,   1.03661895e-03,
                          1.08435852e-02,  -3.66803352e-03,   1.81532884e-03,
                          1.36619546e-02,   1.57133136e-02,   1.73908789e-02,
                          2.44689197e-03,  -4.41303384e-03,   2.00309157e-02,
                          6.37399871e-03,   5.92968194e-03,  -1.31489504e-02,
                         -9.40569103e-01,  -9.37658966e-01,  -9.34490860e-01,
                         -9.52361822e-01,  -9.39094782e-01,  -9.31405962e-01,
                         -9.38052535e-01,  -9.54174936e-01,  -9.50944364e-01,
                         -9.29182470e-01,  -9.45629656e-01,  -9.39312220e-01,
                          1.05052413e-02,   4.01826948e-03,  -1.06533235e-02,
                          8.04894511e-03,   1.42231323e-02,  -1.76130198e-02,
                         -1.58907802e-04,  -7.65014021e-03,  -5.40059898e-03,
                          5.65592309e-05,   5.51562337e-03,  -5.18062757e-03,
                         -7.62813631e-03,  -1.56041523e-02,  -9.99379624e-03,
                         -8.44574627e-03,  -3.91253922e-03,  -7.30113767e-04,
                         -4.90519824e-03,   4.76650661e-03,   3.14073171e-04,
                          2.34916597e-03,  -1.29242595e-02,   3.48866009e-03,
                          1.25362456e-03,   8.70981626e-03,   5.74494433e-03,
                          1.17484080e-02,   1.61354449e-02,  -7.47467566e-04,
                          7.95656256e-03,   2.30041030e-03,   1.20904315e-02,
                         -1.75068877e-03,   7.44657265e-03,  -4.24204627e-04,
                          5.01922471e-03,   6.37727696e-03,   1.68183492e-03,
                          2.66964966e-03,  -1.29970983e-02,   1.75329875e-02,
                          1.48710515e-02,   1.40770187e-03,  -1.07696233e-02,
                          8.18220316e-04,   1.51513043e-04,   8.53536371e-03,
                          3.26324091e-03,  -1.11390708e-03,  -9.06254072e-03,
                         -1.62197258e-02,  -2.33752979e-03,  -8.58524255e-03,
                          9.03113931e-03,   5.46848960e-03,   1.55496513e-02,
                          1.62708592e-02,   5.44631947e-03,  -2.35280441e-03,
                          2.37644417e-03,   2.76512327e-03,  -4.77322191e-03,
                          1.26276230e-02,  -9.18789148e-01,  -9.34129000e-01,
                         -9.14371252e-01,  -9.32537436e-01,  -9.28443849e-01,
                         -9.22585189e-01,  -9.07944441e-01,  -9.32381451e-01,
                         -9.15030539e-01,  -9.14499819e-01,  -9.29957569e-01,
                         -9.21018958e-01,  -9.32996750e-01,  -9.39003289e-01,
                         -9.13906991e-01,  -9.30665135e-01,  -9.29422319e-01,
                         -9.42052662e-01,  -9.28340375e-01,  -9.22597587e-01,
                         -9.10009563e-01,  -9.47880208e-01,  -9.17931318e-01,
                         -9.37726080e-01,  -9.21252668e-01,  -9.25548017e-01,
                         -9.29445744e-01,  -9.31672335e-01,  -9.34136987e-01,
                         -9.24719453e-01,  -9.44390714e-01,  -9.47155654e-01,
                         -9.21131492e-01,  -9.13548410e-01,  -9.36871469e-01,
                         -9.34094310e-01,  -9.43002403e-01,  -9.28568363e-01,
                         -9.14728642e-01,  -9.23454404e-01,  -9.22475338e-01,
                         -9.25117910e-01,  -9.17369783e-01,  -9.24763441e-01,
                         -9.39700842e-01,  -9.36062455e-01,  -9.29011405e-01,
                         -9.23968971e-01,  -9.35179591e-01,  -9.33831275e-01,
                         -9.23407078e-01,  -9.33215857e-01,  -9.37644780e-01,
                         -9.40953910e-01,  -9.13897872e-01,  -9.17348623e-01,
                         -9.27549899e-01,  -9.29677367e-01,  -9.24654543e-01,
                         -9.33921993e-01,  -9.42632616e-01,  -9.28911924e-01,
                         -9.18686509e-01,  -9.30580616e-01,  -9.35087502e-01,
                         -9.33701575e-01,  -9.21846449e-01,  -9.25506055e-01,
                         -9.24528956e-01,  -9.20858085e-01,  -9.22196627e-01,
                         -9.27677631e-01,  -9.10649121e-01,  -9.16576862e-01,
                         -9.37627256e-01,  -9.22096729e-01,  -9.31028187e-01,
                         -9.36736166e-01,  -9.24990594e-01,  -9.27016556e-01,
                         -9.25668180e-01,  -9.32186425e-01,  -9.33726192e-01,
                         -9.13063288e-01,  -9.32809591e-01,  -9.29558098e-01,
                         -9.27642226e-01,  -9.46146071e-01,  -9.29512084e-01,
                         -9.39167500e-01,  -9.41220880e-01,  -9.27163005e-01,
                         -9.27120864e-01,  -9.20405805e-01,  -9.08548057e-01,
                         -9.39897358e-01,  -9.23992217e-01,  -9.19678748e-01,
                         -9.14406598e-01,  -9.07508314e-01,  -9.15807545e-01,
                         -9.23268080e-01,  -9.37029362e-01,  -9.40338671e-01,
                         -9.37598884e-01,  -9.33915555e-01,  -9.23678160e-01,
                         -9.44216609e-01,  -9.35771286e-01,  -9.27671850e-01,
                         -9.24887955e-01,  -9.23917294e-01,  -9.31557417e-01,
                         -9.26992416e-01,  -9.14547324e-01,  -9.22808230e-01,
                         -9.33838606e-01,  -9.40870583e-01,  -9.28088725e-01,
                         -9.34815288e-01,  -9.35639083e-01,  -9.32708681e-01,
                         -9.34588313e-01,  -9.34367299e-01,  -9.36681867e-01,
                         -9.36334550e-01,  -9.22633648e-01,  -9.32498753e-01,
                         -9.37603235e-01,  -9.28281009e-01,  -9.25722122e-01,
                         -9.28903580e-01,  -9.37612295e-01,  -9.15959179e-01,
                         -9.31690931e-01,  -9.28565919e-01,  -9.14751232e-01,
                         -9.25432861e-01,  -9.31202829e-01,  -9.22310889e-01,
                         -9.25593495e-01,  -9.35546577e-01,  -9.31873024e-01,
                         -9.32631850e-01,  -9.32152271e-01,  -9.31265593e-01,
                         -9.36219156e-01,  -9.31565404e-01,  -9.30165887e-01,
                         -9.42961156e-01,  -9.35189009e-01,  -9.40949917e-01,
                         -9.25705910e-01,  -9.20788586e-01,  -9.31459308e-01,
                         -9.42705095e-01,  -9.16234791e-01,  -9.29344893e-01,
                         -9.35164928e-01,  -9.30595815e-01,  -9.33638453e-01,
                         -9.21791494e-01,  -9.29015934e-01,  -9.16097701e-01,
                         -9.30725694e-01,  -9.26387131e-01,  -9.35177565e-01,
                         -9.26033616e-01,  -9.26043570e-01,  -9.25045311e-01,
                         -9.25764740e-01,  -9.30646062e-01,  -9.23543096e-01,
                         -9.28901494e-01,  -9.23455179e-01,  -9.39186990e-01,
                         -9.26028490e-01,  -9.26800251e-01,  -9.33118939e-01,
                         -9.28045928e-01,  -9.37400162e-01,  -9.33667302e-01,
                         -9.36447024e-01,  -9.30618763e-01,  -9.40903127e-01,
                         -9.35628414e-01,  -9.43156898e-01,  -9.38807130e-01,
                         -9.45043743e-01,  -9.39320624e-01,  -9.39509392e-01,
                         -9.36660707e-01,  -9.30569470e-01,  -9.26404297e-01,
                         -9.33101296e-01,  -9.21411872e-01,  -9.34788585e-01,
                         -9.31847095e-01,  -9.41095054e-01,  -9.35049951e-01,
                         -9.28090930e-01,  -9.29548621e-01,  -9.43956614e-01,
                         -9.34427083e-01,  -9.43713665e-01,  -9.39282238e-01,
                         -9.39186990e-01,  -9.33835506e-01,  -9.40140843e-01,
                         -9.46696281e-01,  -9.45379078e-01,  -9.34775710e-01,
                         -9.21236873e-01,  -9.25724685e-01,  -9.26233709e-01,
                         -9.26925719e-01,  -9.46464956e-01,  -9.35354769e-01,
                         -9.29392815e-01,  -9.23770845e-01,  -9.21468914e-01,
                         -9.40275908e-01,  -9.28721070e-01,  -9.22055244e-01,
                         -9.41612780e-01,  -9.25450087e-01,  -9.44830358e-01,
                         -9.34756517e-01,  -9.43881214e-01,  -9.24233794e-01,
                         -9.39890027e-01,  -9.27782297e-01,  -9.35001016e-01,
                         -9.24636364e-01,  -9.37217891e-01,  -9.31538343e-01,
                         -9.36060429e-01,  -9.35664058e-01,  -9.12503779e-01,
                         -9.16453779e-01,  -9.26168025e-01,  -9.32280898e-01,
                         -9.20960605e-01,  -9.19263363e-01,  -9.34737563e-01,
                         -9.38972235e-01,  -9.44606364e-01,  -9.35426295e-01,
                         -9.38797116e-01,  -9.41146255e-01,  -9.37090158e-01,
                         -9.28538859e-01,  -9.47676718e-01,  -9.35856402e-01,
                         -9.37970579e-01,  -9.31116343e-01,  -9.22389388e-01,
                         -9.36241090e-01,  -9.29538488e-01,  -9.26716566e-01,
                         -9.21073437e-01,  -9.21041429e-01,  -9.23394859e-01,
                         -9.20148730e-01,  -9.23726678e-01,  -9.22251821e-01,
                         -9.37947094e-01,  -9.33230758e-01,  -9.22288656e-01,
                         -9.24876511e-01,  -9.24201548e-01,  -9.18599367e-01,
                         -9.20881748e-01,  -9.31196868e-01,  -9.37698483e-01,
                         -9.27444518e-01,  -9.24305201e-01,  -9.20450151e-01,
                         -9.18638766e-01,  -9.16291833e-01,  -9.35208976e-01,
                         -9.33834732e-01,  -9.26041722e-01,  -9.18291330e-01,
                         -9.19621408e-01,  -9.13292885e-01,  -9.23531651e-01,
                         -9.18295681e-01,  -9.40266371e-01,  -9.24919963e-01,
                         -9.20969307e-01,  -9.21791196e-01,  -9.36439335e-01,
                         -9.16975498e-01,  -9.38752532e-01,  -9.32302356e-01,
                         -9.40632522e-01,  -9.27262783e-01,  -9.30807948e-01,
                         -9.38466251e-01,  -9.46550429e-01,  -9.34038758e-01,
                         -9.22854424e-01,  -9.20540631e-01,  -9.31052446e-01,
                         -9.33480442e-01,  -9.37897742e-01,  -9.10929739e-01,
                         -9.37914789e-01,  -9.18400645e-01,  -9.24991548e-01,
                         -9.08713162e-01,  -9.19507265e-01,  -9.33429539e-01,
                         -9.33040023e-01,  -9.28301990e-01,  -9.35531855e-01,
                         -9.29367125e-01,  -9.26007569e-01,  -9.39348221e-01,
                         -9.27657962e-01,  -9.38261986e-01,  -9.16977584e-01,
                         -9.29087877e-01,  -9.41196263e-01,  -9.32334781e-01,
                         -9.33988333e-01,  -9.17185187e-01,  -9.27952766e-01,
                         -9.18247879e-01,  -9.10802901e-01,  -9.20045376e-01,
                         -9.15188372e-01,  -9.06208217e-01,  -9.29389358e-01,
                         -9.13422644e-01,  -9.09318566e-01,  -9.37886953e-01,
                         -9.12644565e-01,  -9.10810232e-01,  -9.23400402e-01,
                         -9.16614413e-01,  -9.28344905e-01,  -9.21743989e-01,
                         -9.25859988e-01,  -9.12987471e-01,  -9.27745044e-01,
                         -9.22019541e-01,  -9.46425915e-01,  -9.27194297e-01,
                         -9.15018380e-01,  -9.26158428e-01,  -9.25204039e-01,
                         -9.14287090e-01,  -9.32625830e-01,  -9.39715922e-01,
                         -9.33349729e-01,  -9.37728405e-01,  -9.37535048e-01,
                         -9.23507988e-01,  -9.44831610e-01,  -9.35282350e-01,
                         -9.18698370e-01,  -9.33851480e-01,   1.59269441e-02,
                          2.49834335e-03,   1.79701170e-03,   1.15352068e-02,
                          4.85975557e-04,   6.39907317e-03,   1.53109329e-02,
                          4.55261953e-03,   9.51004587e-03,   2.06905883e-03,
                          7.29577336e-03,   4.98983962e-03,   1.23892026e-02,
                          7.84148928e-03,  -1.42741892e-02,  -4.20367252e-03,
                         -1.00412490e-02,   8.05073325e-03,  -2.56489217e-02,
                         -3.37642175e-03,   2.21075141e-03,   1.01421494e-02,
                          4.05789772e-03,  -4.24185209e-03,   1.11521902e-02,
                          1.78314396e-03,  -5.00400551e-03,  -1.59097146e-02,
                          1.22452294e-02,  -1.95277315e-02,  -6.70749787e-03,
                         -3.14214155e-02,  -1.80084836e-02,  -9.79186501e-04,
                          2.44073081e-03,   1.25867538e-02,  -6.99973327e-07,
                          4.61622002e-03,   7.70323444e-03,   7.41341058e-03,
                          1.01152109e-02,  -8.38118233e-03,  -7.41706276e-03,
                          2.99653038e-03,  -3.29990289e-03,  -1.28188822e-02,
                         -4.08152351e-03,   5.21678338e-03,   4.96987300e-03,
                         -3.93797364e-03,  -1.05308080e-02,   1.54659458e-04,
                         -1.67570845e-03,  -5.85283758e-03,   3.19726323e-03,
                         -5.83476294e-03,   9.45794303e-03,   8.31440836e-03,
                         -5.17831976e-03,  -1.69346351e-02,  -1.67563427e-02,
                         -3.17735923e-03,   1.48453261e-03,   1.45227136e-03,
                         -6.70502381e-03,  -1.09014399e-02,  -7.12272059e-03,
                          6.57243794e-03,   2.28655641e-04,  -7.91179854e-03,
                         -8.01875629e-03,   8.36195797e-03,   4.72929003e-03,
                          1.12527572e-02,   6.17831107e-03,   4.28193109e-03,
                         -4.56942571e-03,   3.12012760e-03,   3.22976010e-03,
                         -1.89498032e-03,  -9.79768578e-04,   5.48014650e-03,
                          2.48444802e-03,   4.67538508e-03,  -6.58178004e-03,
                         -1.64499898e-02,  -3.99957830e-03,   4.12769429e-03,
                          1.06795691e-02,   9.54402518e-03,   6.27172645e-03,
                          3.81808425e-03,   3.68371699e-03,  -1.20344125e-02,
                         -6.35015825e-03,   5.54610370e-03,   6.44822372e-03,
                          8.20658449e-03,   5.10592433e-03,  -2.72575160e-03,
                         -3.81966447e-03,  -7.02256896e-03,  -5.66313090e-03,
                          6.75710617e-03,   6.60065841e-03,  -4.00496321e-03,
                         -2.73436611e-03,  -7.48887612e-03,  -6.59247348e-03,
                         -1.02775702e-02,  -7.82475900e-03,  -2.99099297e-03,
                          8.14541616e-03,   6.80127367e-03,   3.93829960e-03,
                         -1.45629107e-04,  -2.29808874e-03,   1.96466572e-03,
                          1.46349182e-03,  -1.26748541e-02,   3.22682154e-03,
                         -2.54806224e-03,   6.33441232e-05,  -6.71775499e-03,
                         -7.77091691e-03,  -9.10275150e-03,  -6.84666773e-03,
                          6.78710779e-03,   6.92856498e-03,  -5.50837442e-03,
                         -7.45278224e-03,  -7.44465319e-03,  -2.87930225e-03,
                         -4.14168695e-03,  -8.59153550e-03,  -3.32161598e-03,
                         -3.29772686e-03,   1.53753925e-02,   8.63476004e-03,
                          5.23728365e-03,  -3.43421474e-03,  -4.16671950e-03,
                         -4.21465049e-03,  -8.58541534e-05,  -2.11849358e-04,
                         -5.17239422e-03,  -3.15812021e-03,   5.16573386e-03,
                          6.60608493e-05,  -4.77522518e-03,  -1.23905819e-02,
                         -5.01256436e-03,  -1.53032888e-03,  -4.11108881e-03,
                         -9.25774314e-03,   1.15492137e-03,   9.07511974e-04,
                         -3.07121268e-03,   7.52734661e-04,  -1.01300003e-03,
                          4.57941974e-03,   4.91517130e-03,  -2.34829262e-03,
                         -2.56159063e-03,  -7.58106448e-03,   4.52315155e-03,
                          4.84205503e-03,   5.21830795e-03,   2.06292537e-03,
                         -6.26388099e-03,   1.72122056e-03,  -2.81351851e-03,
                         -1.09445333e-04,  -4.84443910e-04,   8.67124181e-03,
                          3.23110464e-04,  -1.53109117e-03,  -1.34043512e-03,
                         -1.62222632e-03,   4.11641831e-03,   3.75867658e-03,
                          5.51294163e-03,   1.57144701e-03,  -1.12704025e-03,
                         -1.56324834e-03,  -6.68876478e-03,  -7.93270767e-04,
                         -4.54939716e-03,   4.31516237e-04,   1.15643220e-03,
                         -4.19391459e-03,  -8.11257306e-03,   3.99955735e-03,
                         -5.44814917e-04,   2.25116266e-03,   5.99728851e-03,
                          1.18459051e-03,  -5.24593284e-03,   3.49204219e-03,
                         -1.30695419e-03,  -2.13699779e-04,   3.68768140e-03,
                         -2.23140419e-03,   3.65574588e-03,   2.66634393e-03,
                          2.67186761e-03,   2.72499630e-03,   2.52027134e-03,
                          2.32601142e-03,   8.74114223e-04,   1.09616516e-03,
                         -6.44432846e-04,   1.37456052e-03,  -3.50261806e-03,
                         -4.22625197e-03,   2.27852399e-03,   1.76750892e-03,
                          4.46772203e-03,   1.46919547e-03,   5.97063394e-04,
                         -7.00333738e-04,   1.58252881e-03,   3.20530962e-03,
                          3.63563374e-03,   3.97716509e-03,   5.82729187e-03,
                         -1.63010627e-04,   4.26089711e-04,   1.39894173e-03,
                          3.19591188e-03,   9.81224002e-04,  -1.64031470e-03,
                         -5.53202769e-03,  -4.93758405e-03,  -2.08031386e-03,
                         -8.27105134e-04,  -4.51378837e-05,   5.87371178e-03,
                          5.17467409e-03,   1.16758328e-03,   3.36186099e-03,
                          6.72113034e-04,   1.47426163e-03,   3.42520513e-03,
                          3.80959455e-03,   1.69808674e-03,   9.87322768e-04,
                         -2.67078634e-03,  -1.58030412e-03,  -1.68266660e-03,
                         -3.05410149e-03,   2.61817739e-04,   3.49337282e-03,
                          6.12843956e-04,   5.92842756e-04,  -3.54524027e-03,
                          5.16867917e-03,  -3.14159808e-03,  -9.41866077e-04,
                         -4.58983611e-03,   1.03561124e-02,  -4.66960529e-03,
                         -2.40144227e-03,   7.99817219e-03,   4.81909467e-03,
                         -1.69728289e-03,  -3.37234675e-03,   7.21838849e-04,
                          1.01525243e-03,   1.05458952e-03,   2.42199772e-03,
                         -1.74592063e-03,  -5.38696721e-03,  -2.02647131e-03,
                         -5.94515773e-03,  -3.08907242e-03,  -1.14686124e-03,
                         -1.48596719e-03,   8.13237333e-04,   1.46452442e-03,
                         -2.03532836e-04,   1.43613049e-03,   3.63029051e-03,
                         -8.73649915e-05,  -5.92738111e-03,  -9.75485600e-04,
                          2.92851520e-03,   5.44234132e-03,   2.67168041e-03,
                         -1.92142685e-03,   8.43196176e-03,   6.09358680e-03,
                          3.20303632e-04,   2.97916285e-03,   5.04277414e-03,
                          5.28096594e-03,  -2.06299475e-03,  -1.93223136e-03,
                          2.83668004e-03,   6.23177923e-03,   4.11783205e-03,
                          7.96383899e-03,   2.14516185e-03,   3.14120320e-03,
                         -3.51650664e-03,  -1.11559115e-04,   1.17354339e-03,
                          3.08447052e-03,   3.40448320e-03,  -6.21698285e-03,
                          2.23793951e-03,  -1.59735989e-03,  -6.91450993e-03,
                          1.68634660e-03,  -4.44700010e-03,  -6.77920703e-04,
                         -7.45080039e-03,   4.74026101e-03,   5.18376706e-03,
                          1.11280652e-02,   4.00580186e-03,  -4.14759154e-03,
                         -7.73747743e-04,   5.59623819e-03,  -3.32168536e-03,
                         -5.16081322e-03,   3.07972333e-03,   1.70335395e-03,
                         -8.31762387e-04,   3.25549277e-03,   1.06412238e-02,
                         -1.61103369e-03,   4.72844439e-03,   2.42236513e-03,
                         -1.07928959e-03,   1.23593118e-03,   8.63212626e-03,
                          2.43039057e-03,  -1.56455825e-03,  -2.68756505e-03,
                         -1.55715656e-03,   9.50942840e-03,   3.22865811e-03,
                          9.05391295e-03,   4.31453856e-03,   2.26472551e-03,
                          2.13769078e-03,  -2.15158635e-03,   1.49170548e-04,
                          1.47168350e-03,  -8.05107920e-05,   4.11384739e-03,
                          2.99304433e-04,   1.09500776e-04,  -2.96002789e-03,
                          1.74802053e-03,   1.11410115e-02,   7.77969090e-03,
                          1.28004542e-02,   9.38707218e-03,   1.27519891e-02,
                         -2.37874500e-03,  -3.15935398e-03,   2.94934795e-03,
                         -4.39527794e-05,  -2.42221262e-03,   3.37561802e-03,
                         -4.08761576e-03,  -4.86607617e-03,  -2.16037408e-03,
                         -3.15155019e-03,  -1.29912971e-02,  -2.77304486e-03,
                         -2.05314648e-03,   2.39342364e-04,   3.35852057e-03,
                         -3.47587350e-03,  -3.64718679e-03,   5.69452590e-04,
                          5.59554528e-03,   2.82660313e-03,  -3.97932064e-03,
                         -7.77916424e-03,   1.72466494e-03,   3.04819667e-03,
                          1.02968852e-03,  -2.15762272e-03,  -1.89103681e-04,
                         -1.21411413e-03,   5.62910922e-03,  -3.79025150e-04,
                         -3.84694943e-03,  -6.52296841e-03,  -6.13787211e-03,
                         -4.78091510e-03,  -3.67581635e-03,  -2.85076257e-03,
                         -3.36903404e-03,   1.35604932e-03,  -1.18212532e-02,
                         -2.75153969e-03,   1.23122532e-03,   8.20597459e-04,
                         -8.55046511e-03,   8.10777012e-04,   4.12752107e-03,
                          4.29586787e-03,   3.07512144e-03,   2.96360394e-03,
                         -2.04714481e-03,  -2.21676705e-03,   3.74475331e-03,
                          1.07897213e-02,  -2.76257982e-03,  -5.23550250e-03,
                         -3.74757405e-03,  -6.87524211e-03,  -7.01537542e-03,
                         -9.99598671e-03,  -1.05766803e-02,  -5.70461620e-03,
                          1.55502197e-03,   5.27142314e-03,   8.00450682e-04,
                          4.01113834e-03,  -1.53712067e-03,   2.82902201e-03,
                         -1.65483402e-03,   8.14375281e-03,   4.86084353e-03,
                          1.32494625e-02,   4.83643450e-03,   4.56411019e-03,
                          2.84965383e-04,  -3.62135004e-03,   6.83491398e-03,
                          5.75620623e-04,   6.48945291e-03,  -4.92995372e-03,
                         -3.96370655e-03,  -5.86113310e-04,   2.41402793e-03,
                          2.72482284e-03,  -6.72011124e-03,  -8.10262840e-03,
                          5.64396102e-03,   1.42884659e-04,   4.43469128e-03,
                         -7.95520376e-03,  -2.19023740e-03,   4.56838636e-03,
                          2.87211523e-03,  -5.38182445e-04,   7.81697687e-03,
                         -1.57080952e-03,  -5.02948184e-04,  -1.16165429e-02,
                         -8.58229701e-04,   2.17252318e-03,   7.48268049e-03,
                          2.40599550e-03,   6.43543014e-03,  -1.19931072e-04,
                         -1.36772011e-04,  -4.41846717e-03,  -2.54929601e-03,
                         -6.79879962e-03,  -1.15742534e-02,  -1.24284904e-02,
                         -4.81150579e-03,   3.20944004e-03,  -5.15866466e-03,
                         -1.54265389e-02,  -1.16885155e-02,  -1.02550248e-02,
                          6.22188300e-03,  -6.24310365e-03,   1.15046510e-03,
                         -1.63578923e-04,   1.79906317e-03,  -5.91715891e-03,
                         -4.18408029e-03,   1.23239658e-03,  -1.02283359e-02,
                         -1.70026300e-03,   3.49011552e-03,  -9.15222801e-03,
                          2.76969746e-03,  -9.28188860e-03,  -1.35700777e-02,
                         -6.04694476e-03,   6.06972538e-03,  -8.99091479e-04,
                          1.68425369e-03,  -8.25572107e-03,  -4.91488026e-03,
                         -5.83792990e-03,  -8.45876895e-03,   1.25160778e-03,
                          2.91597797e-04,  -3.47660133e-03,  -5.08150831e-03,
                         -6.91906316e-04,   5.75343438e-04,   9.80587769e-03,
                         -8.64640344e-04,  -5.09684556e-04,   1.44646578e-02,
                          2.50267494e-03,  -4.59288526e-03,  -8.33628699e-03,
                         -3.80861037e-03,  -1.77900644e-03,  -9.24285688e-03,
                          3.34598334e-03,   2.71021365e-03,  -3.25450860e-03,
                         -4.22313996e-03,   6.50346605e-03,   1.45179741e-02,
                         -1.33653317e-04,  -4.23822086e-03,  -1.95195535e-04,
                         -6.20847242e-03,  -7.10399449e-03,  -5.55238267e-03,
                         -1.36175035e-02,  -1.49016008e-02,   5.29006589e-04,
                         -2.76808278e-03,  -8.02023918e-04,  -1.42550608e-02,
                         -6.85059058e-04,  -3.97787243e-03,  -7.31526874e-03,
                         -2.81656091e-03,   1.69800362e-03,   1.77037809e-03,
                         -9.56412405e-03,   3.00734187e-03,  -6.84357714e-03,
                         -3.64761660e-03,  -4.98663075e-03,   9.10374220e-04,
                         -3.85738676e-03,   4.93534561e-03,   1.47338153e-03,
                         -9.26248193e-01,  -9.40076768e-01,  -9.27115619e-01,
                         -9.25047815e-01,  -9.23257232e-01,  -9.33502495e-01,
                         -9.30483401e-01,  -9.31984782e-01,  -9.44221199e-01,
                         -9.33509052e-01,  -9.36145067e-01,  -9.27426338e-01,
                          2.02686642e-03,  -7.84725510e-03,   5.55820414e-04,
                          4.34603728e-03,  -5.79952146e-04,  -4.59583756e-03,
                          7.84986094e-03,   1.16347214e-02,   7.51266116e-03,
                          3.71706625e-03,  -8.72258283e-03,   9.30056674e-04,
                         -3.59543716e-04,  -8.30535660e-04,  -9.34996642e-03,
                         -2.25112122e-03,  -3.48960259e-03,   8.30551609e-03,
                          1.35495774e-02,  -1.22646485e-02,  -1.52307271e-03,
                          5.05424431e-03,   1.68303251e-02,   1.58832269e-03,
                          1.03241634e-02,  -1.32201333e-02,   1.41238058e-02,
                          1.44686364e-02,   3.60408635e-03,   7.49809342e-03,
                          2.35691480e-02,   1.10232495e-02,   1.79174393e-02,
                          2.67990679e-03,   2.25408748e-03,   1.11347041e-03,
                          1.82491299e-02,   1.88428387e-02,   8.02012160e-03,
                         -8.22777767e-03,  -1.70329853e-03,   3.01532564e-03,
                         -1.58950081e-03,  -7.33811827e-03,  -6.12906367e-03,
                         -1.39416531e-02,  -9.15675983e-03,  -5.83243417e-03,
                         -4.02806234e-03,  -1.03407549e-02,  -1.11333188e-03,
                         -1.77132757e-03,  -1.66391290e-03,   2.57557607e-03,
                          6.54079346e-03,  -5.59348008e-03,   1.34488512e-02,
                          1.79629996e-02,   1.46891410e-02,   6.50531659e-03,
                          2.00603344e-03,  -5.31970710e-03,   4.49957419e-03,
                         -2.10631685e-03,  -9.39813077e-01,  -9.37973678e-01,
                         -9.41518426e-01,  -9.41005468e-01,  -9.32615638e-01,
                         -9.32265878e-01,  -9.38219965e-01,  -9.36578095e-01,
                         -9.44709301e-01,  -9.37323809e-01,  -9.30073202e-01,
                         -9.28195119e-01,  -9.25872803e-01,  -9.34909225e-01,
                         -9.38022375e-01,  -9.31071520e-01,  -9.29176986e-01,
                         -9.39177454e-01,  -9.28478599e-01,  -9.26173031e-01,
                         -9.26555812e-01,  -9.20896947e-01,  -9.24348652e-01,
                         -9.28452730e-01,  -9.31183636e-01,  -9.22361672e-01,
                         -9.34501946e-01,  -9.28017974e-01,  -9.30596948e-01,
                         -9.29720998e-01,  -9.25540268e-01,  -9.34683025e-01,
                         -9.25027013e-01,  -9.37601209e-01,  -9.17408943e-01,
                         -9.35335577e-01,  -9.47150588e-01,  -9.29663539e-01,
                         -9.19090748e-01,  -9.24015939e-01,  -9.21185374e-01,
                         -9.28290367e-01,  -9.34153557e-01,  -9.34002280e-01,
                         -9.34848428e-01,  -9.30096924e-01,  -9.30870414e-01,
                         -9.27662432e-01,  -9.19101715e-01,  -9.36505020e-01,
                         -9.31069016e-01,  -9.31393087e-01,  -9.28462207e-01,
                         -9.25825179e-01,  -9.12111163e-01,  -9.32806909e-01,
                         -9.25203145e-01,  -9.36699629e-01,  -9.29371834e-01,
                         -9.29335594e-01,  -9.28441525e-01,  -9.36211467e-01,
                         -9.36257839e-01,  -9.36885357e-01,  -9.43222165e-01,
                         -9.39193904e-01,  -9.27599311e-01,  -9.27041233e-01,
                         -9.39574897e-01,  -9.43639100e-01,  -9.35622692e-01,
                         -9.31888998e-01,  -9.28947210e-01,  -9.38952386e-01,
                         -9.36514735e-01,  -9.38962042e-01,  -9.36142921e-01,
                         -9.29045618e-01,  -9.29644287e-01,  -9.26866829e-01,
                         -9.29587781e-01,  -9.27740335e-01,  -9.33409452e-01,
                         -9.40402865e-01,  -9.29761350e-01,  -9.31038022e-01,
                         -9.30936158e-01,  -9.26219046e-01,  -9.14397776e-01,
                         -9.21854675e-01,  -9.24178839e-01,  -9.30464208e-01,
                         -9.31671977e-01,  -9.25131857e-01,  -9.26630437e-01,
                         -9.28852081e-01,  -9.29820120e-01,  -9.33454394e-01,
                         -9.29053664e-01,  -9.23622489e-01,  -9.26290154e-01,
                         -9.31656241e-01,  -9.28129315e-01,  -9.21405673e-01,
                         -9.33954179e-01,  -9.36946332e-01,  -9.35666919e-01,
                         -9.36186433e-01,  -9.36339557e-01,  -9.35243964e-01,
                         -9.40147519e-01,  -9.40515757e-01,  -9.41828907e-01,
                         -9.37644780e-01,  -9.41470861e-01,  -9.24524665e-01,
                         -9.22616482e-01,  -9.32344317e-01,  -9.26110327e-01,
                         -9.37901497e-01,  -9.41109896e-01,  -9.44729447e-01,
                         -9.42809224e-01,  -9.33619618e-01,  -9.44119036e-01,
                         -9.32274759e-01,  -9.35732245e-01,  -9.33506727e-01,
                         -9.32131946e-01,  -9.26076531e-01,  -9.27224338e-01,
                         -9.36828554e-01,  -9.26421583e-01,  -9.21313286e-01,
                         -9.18730855e-01,  -9.31967974e-01,  -9.23910737e-01,
                         -9.29891944e-01,  -9.34227169e-01,  -9.28127587e-01,
                         -9.32644367e-01,  -9.26066279e-01,  -9.30186331e-01,
                         -9.37561631e-01,  -9.34367418e-01,  -9.20528889e-01,
                         -9.24333751e-01,  -9.30561125e-01,  -9.33212876e-01,
                         -9.31553781e-01,  -9.24190581e-01,  -9.19417143e-01,
                         -9.28958118e-01,  -9.21957374e-01,  -9.26952064e-01,
                         -9.39483404e-01,  -9.31709230e-01,  -9.22913134e-01,
                         -9.23511744e-01,  -9.32052672e-01,  -9.31722760e-01,
                         -9.38828170e-01,  -9.34620678e-01,  -9.48267639e-01,
                         -9.35671031e-01,  -9.24690008e-01,  -9.27022517e-01,
                         -9.32484984e-01,  -9.32245851e-01,  -9.42286313e-01,
                         -9.40403104e-01,  -9.42468464e-01,  -9.26510453e-01,
                         -9.29489493e-01,  -9.32126939e-01,  -9.31348622e-01,
                         -9.30150092e-01,  -9.25308287e-01,  -9.32156026e-01,
                         -9.41262364e-01,  -9.35730875e-01,  -9.31945443e-01,
                         -9.22277033e-01,  -9.29992139e-01,  -9.24575388e-01,
                         -9.23150122e-01,  -9.24090147e-01,  -9.25972462e-01,
                         -9.33699012e-01,  -9.40494716e-01,  -9.43995655e-01,
                         -9.22818899e-01,  -9.22213435e-01,  -9.21121836e-01,
                         -9.21855032e-01,  -9.28237677e-01,  -9.34475124e-01,
                         -9.30862188e-01,  -9.32789207e-01,  -9.34102833e-01,
                         -9.23278928e-01,  -9.25512254e-01,  -9.46521640e-01,
                         -9.50026453e-01,  -9.50918496e-01,  -9.38174307e-01,
                         -9.42663193e-01,  -9.37901616e-01,  -9.32664990e-01,
                         -9.32705104e-01,  -9.34036314e-01,  -9.24807549e-01,
                         -9.34228361e-01,  -9.34151173e-01,  -9.20377195e-01,
                         -9.32812154e-01,  -9.39896226e-01,  -9.30649281e-01,
                         -9.31836963e-01,  -9.38763320e-01,  -9.35920179e-01,
                         -9.38177705e-01,  -9.31579649e-01,  -9.31622207e-01,
                         -9.22353327e-01,  -9.36513782e-01,  -9.23010051e-01,
                         -9.29735661e-01,  -9.29803789e-01,  -9.28330541e-01,
                         -9.28849578e-01,  -9.27687407e-01,  -9.31188941e-01,
                         -9.27465081e-01,  -9.30178106e-01,  -9.28580999e-01,
                         -9.28057015e-01,  -9.30819631e-01,  -9.25049186e-01,
                         -9.42052245e-01,  -9.42846835e-01,  -9.36195195e-01,
                         -9.19971406e-01,  -9.28207159e-01,  -9.20980275e-01,
                         -9.27914262e-01,  -9.23279822e-01,  -9.31480825e-01,
                         -9.28051651e-01,  -9.37826872e-01,  -9.46495593e-01,
                         -9.25320148e-01,  -9.19681907e-01,  -9.32565212e-01,
                         -9.22495008e-01,  -9.24282610e-01,  -9.23528075e-01,
                         -9.24148738e-01,  -9.23640668e-01,  -9.20999706e-01,
                         -9.33999717e-01,  -9.26327467e-01,  -9.30984616e-01,
                         -9.20057774e-01,  -9.37086165e-01,  -9.30402696e-01,
                         -9.29777622e-01,  -9.31430340e-01,  -9.37439322e-01,
                         -9.22065556e-01,  -9.32142258e-01,  -9.38560724e-01,
                         -9.33723271e-01,  -9.24861073e-01,  -9.36428607e-01,
                         -9.41101789e-01,  -9.22204554e-01,  -9.30653930e-01,
                         -9.34968770e-01,  -9.23906326e-01,  -9.26327050e-01,
                         -9.26345825e-01,  -9.42190051e-01,  -9.44068789e-01,
                         -9.37658310e-01,  -9.44397688e-01,  -9.42770898e-01,
                         -9.28400099e-01,  -9.35905874e-01,  -9.27682221e-01,
                         -9.20542955e-01,  -9.40517128e-01,  -9.24215615e-01,
                         -9.48392153e-01,  -9.31726873e-01,  -9.17722464e-01,
                         -9.35263038e-01,  -9.31734502e-01,  -9.33699667e-01,
                         -9.36864734e-01,  -9.37504530e-01,  -9.37225521e-01,
                         -9.18670535e-01,  -9.21903849e-01,  -9.33610618e-01,
                         -9.16107893e-01,  -9.26384687e-01,  -9.29425895e-01,
                         -9.28804636e-01,  -9.24316704e-01,  -9.31643069e-01,
                         -9.26974237e-01,  -9.25386369e-01,  -9.20036972e-01,
                         -9.17652369e-01,  -9.34081674e-01,  -9.26195741e-01,
                         -9.13996577e-01,  -9.24072981e-01,  -9.13549721e-01,
                         -9.27202404e-01,  -9.36538279e-01,  -9.29126859e-01,
                         -9.31215346e-01,  -9.36046839e-01,  -9.37069416e-01,
                         -9.43150640e-01,  -9.44836617e-01,  -9.20762897e-01,
                         -9.31163132e-01,  -9.36796606e-01,  -9.45186079e-01,
                         -9.31339025e-01,  -9.29067969e-01,  -9.27037597e-01,
                         -9.23771083e-01,  -9.33635235e-01,  -9.35525000e-01,
                         -9.27039385e-01,  -9.31773365e-01,  -9.23312604e-01,
                         -9.24025655e-01,  -9.31184649e-01,  -9.23891962e-01,
                         -9.45122480e-01,  -9.28587556e-01,  -9.39089119e-01,
                         -9.36223924e-01,  -9.26653445e-01,  -9.38214898e-01,
                         -9.24373388e-01,  -9.25184608e-01,  -9.26424205e-01,
                         -9.35603619e-01,  -9.42031264e-01,  -9.30341482e-01,
                         -9.36791837e-01,  -9.42179620e-01,  -9.30558443e-01,
                         -9.33363020e-01,  -9.30771947e-01,  -9.15421069e-01,
                         -9.31332231e-01,  -9.35766697e-01,  -3.46922036e-03,
                          9.61642805e-03,  -1.04555711e-02,  -8.36786930e-04,
                         -1.04016177e-02,   6.95518451e-03,   1.25008719e-02,
                         -3.85697093e-03,  -1.15532540e-02,  -3.27067054e-03,
                          3.36644892e-03,  -1.71469909e-03,  -1.36804935e-02,
                         -1.68174338e-02,  -3.59624112e-03,  -1.56616606e-03,
                         -2.67944951e-03,   1.95730291e-02,   6.58589648e-03,
                          9.40520875e-03,  -3.47946351e-03,  -1.70213415e-03,
                          3.37304664e-03,   7.94940977e-04,   4.26390488e-03,
                          7.05205137e-03,  -1.18167978e-03,   1.38171963e-04,
                         -1.68184191e-03,   1.19482679e-03,  -2.78326042e-04,
                          8.57040379e-03,   3.81184695e-03,   3.79475649e-03,
                          3.88178881e-03,  -6.88582473e-03,   4.51652613e-03,
                         -2.99284351e-03,   1.41708564e-03,   1.04888510e-02,
                         -1.28691345e-02,   7.45192310e-03,   1.13815805e-02,
                          1.34456772e-02,  -8.04165378e-04,   2.96982750e-03,
                         -8.02741200e-03,   6.39771484e-03,   4.92311362e-03,
                         -6.89479988e-03,  -4.38817451e-03,   9.75210499e-03,
                         -1.72108058e-02,   8.93179141e-03,   1.04059011e-03,
                         -3.47470911e-03,   1.32106803e-02,   1.51649574e-02,
                          1.60036772e-03,   8.83132126e-03,   4.42927191e-03,
                          1.69841247e-03,   1.43524753e-02,   1.17648672e-02,
                          7.12565903e-04,   3.25696217e-03,  -1.83636276e-03,
                          1.98915089e-03,  -7.44358590e-03,  -1.99053017e-03,
                         -1.15973726e-02,   8.16201512e-03,   1.56990159e-03,
                         -3.54900345e-04,   4.51848749e-03,  -1.35287514e-03,
                         -2.28431099e-03,   9.46146343e-03,   8.51542503e-03,
                          4.69852611e-03,   7.68758543e-03,   1.10154664e-02,
                          6.18154788e-03,   4.75288136e-03,  -6.24437910e-03,
                          6.49571093e-03,   6.38851803e-03,   1.05686963e-03,
                         -5.90601470e-03,  -1.15331560e-02,  -1.65698933e-03,
                         -1.21744564e-02,  -7.84614647e-04,  -4.13822150e-03,
                          4.85387165e-03,  -5.63798007e-03,   1.08099654e-02,
                          1.75029226e-02,  -6.57746941e-03,   4.80171992e-03,
                         -1.11057628e-02,  -4.84570768e-03,  -8.59961566e-03,
                          5.77272149e-03,  -3.34157579e-04,   8.10842216e-03,
                         -2.63599562e-03,  -6.08271966e-03,  -2.16604937e-02,
                          7.97593314e-03,  -1.32342777e-03,   1.28872441e-02,
                          1.01823732e-02,   7.08157476e-03,   2.30147759e-03,
                          7.73993088e-03,   5.04833227e-03,   3.55281518e-04,
                          3.96912597e-04,   1.92828791e-03,   9.88463499e-03,
                         -6.56401739e-04,   7.32791005e-03,   4.53241030e-03,
                         -8.03019758e-03,   5.57094906e-03,  -2.34983116e-03,
                         -4.65610484e-03,  -2.16617621e-02,  -1.08638639e-03,
                          8.23147828e-04,   4.49865917e-03,   4.91159502e-04,
                         -1.13856548e-03,  -1.21728135e-02,  -7.75067322e-03,
                         -2.12926348e-03,  -2.04454584e-04,  -3.04550776e-04,
                          1.09624141e-03,   5.68171125e-03,  -5.03358431e-03,
                         -2.16225232e-03,   1.37194083e-03,  -5.05377259e-03,
                          1.22823901e-02,  -1.64957233e-02,   2.46972777e-03,
                          7.22303172e-04,   9.13156103e-03,   8.67380574e-03,
                          2.13978393e-03,   3.98235628e-03,   2.14130851e-03,
                         -9.42046288e-04,   1.07981078e-02,   5.84788201e-03,
                          5.37560787e-03,   7.28422729e-03,   1.39348265e-02,
                          5.52421715e-03,   1.28996279e-02,  -3.56834615e-03,
                          2.73739477e-03,  -7.25625642e-03,  -6.47266023e-03,
                          3.10334913e-03,   3.70613695e-03,  -7.64864311e-03,
                          2.15784460e-03,  -1.68684567e-03,  -2.28391588e-03,
                         -1.41377980e-02,   6.65899180e-03,  -1.10836830e-02,
                          2.79211043e-03,  -4.39656712e-03,   7.07778381e-03,
                         -6.73762464e-04,   3.27243074e-03,  -1.34362588e-02,
                         -3.89678613e-03,   5.01250208e-04,   1.12114865e-02,
                         -3.60229844e-03,  -1.29111810e-03,  -9.71908122e-03,
                          2.19611097e-02,   4.11709072e-03,   3.11324582e-03,
                          7.22470181e-03,   1.31550357e-02,   1.74316093e-02,
                         -4.18064272e-04,  -6.57989504e-03,   6.23807893e-04,
                         -7.34625473e-07,  -1.07304531e-03,   3.59328871e-04,
                          1.05979014e-02,   5.72723011e-03,   1.13740955e-02,
                          7.99640547e-03,  -1.12669368e-03,   1.20562371e-02,
                         -5.47354203e-03,  -4.37481934e-03,   1.18440753e-02,
                          1.40138892e-02,  -1.13425134e-02,  -3.62229953e-03,
                         -1.08843287e-02,   6.56608259e-03,   1.02993799e-03,
                          1.01674385e-02,   3.97910597e-04,   5.87749574e-03,
                         -6.37329184e-04,   2.77619134e-03,   6.22637384e-03,
                         -5.28003043e-03,   2.53838045e-03,   1.36677071e-03,
                          5.16380044e-03,  -1.60657670e-02,  -5.70221851e-03,
                         -1.10184951e-02,  -1.27691077e-03,  -1.59340203e-02,
                          8.27277731e-03,   1.08564962e-02,   1.80428871e-03,
                          3.65784578e-03,  -8.13707896e-03,   7.85219669e-03,
                         -9.30308923e-03,   7.37487758e-03,  -1.41286501e-03,
                          1.03484478e-03,   6.48170477e-03,  -2.63020862e-03,
                         -2.14988776e-02,  -8.69252533e-03,  -1.05967643e-02,
                          3.24799400e-03,  -5.21957641e-03,  -4.46402794e-03,
                         -5.59622422e-03,   1.81148248e-03,  -1.65610923e-03,
                          8.01811181e-03,  -1.12243847e-03,   8.39018542e-03,
                          7.63311237e-03,   1.06257336e-04,   1.37151321e-02,
                         -3.85175226e-03,   1.82836503e-02,   2.23643146e-02,
                         -4.99000587e-03,   1.52663141e-02,   1.15055796e-02,
                          2.23471615e-02,   2.30786130e-02,  -7.37373054e-01,
                         -7.44686604e-01,  -7.50273824e-01,  -7.47766256e-01,
                         -7.59818912e-01,  -7.60553539e-01,  -7.53979504e-01,
                         -7.57212222e-01,  -7.40716040e-01,  -7.63768673e-01,
                         -7.60302722e-01,  -7.62775421e-01,  -7.72332847e-01,
                         -7.75713623e-01,  -7.60457098e-01,  -7.55748630e-01,
                         -7.48707473e-01,  -7.71142066e-01,  -7.60603666e-01,
                         -7.49910891e-01,  -7.54242539e-01,  -7.60837793e-01,
                         -7.54975975e-01,  -7.33613074e-01,  -7.51056850e-01,
                         -7.62562037e-01,  -7.63992369e-01,  -7.57713437e-01,
                         -7.44515479e-01,  -7.53689885e-01,  -7.90493786e-01,
                         -7.51686990e-01,  -7.81213701e-01,  -7.60327816e-01,
                         -7.61888206e-01,  -7.44992316e-01,  -7.53599644e-01,
                         -7.58050501e-01,  -7.53148675e-01,  -7.56353915e-01,
                         -7.77707875e-01,  -7.49661386e-01,  -7.58407176e-01,
                         -7.69256949e-01,  -7.53976643e-01,  -7.67732620e-01,
                         -7.50588655e-01,  -7.63735831e-01,  -7.57985711e-01,
                         -7.45853603e-01,  -7.41475821e-01,  -7.48313010e-01,
                         -7.63965428e-01,  -7.42964864e-01,  -7.78513014e-01,
                         -7.39855468e-01,  -7.55750954e-01,  -7.59938776e-01,
                         -7.51067042e-01,  -7.44877219e-01,  -7.41850734e-01,
                         -7.43519366e-01,  -7.60087907e-01,  -7.36104727e-01,
                         -7.65233397e-01,  -7.60530233e-01,  -7.48450398e-01,
                         -7.78522491e-01,  -7.62523651e-01,  -7.57855594e-01,
                         -7.84540951e-01,  -7.65784621e-01,  -7.72481024e-01,
                         -7.64894545e-01,  -7.87686646e-01,  -7.45412171e-01,
                         -7.68679857e-01,  -7.40451217e-01,  -7.58654058e-01,
                         -7.72040427e-01,  -9.20898139e-01,  -9.08357322e-01,
                         -9.14727151e-01,  -9.19107854e-01,  -7.64380097e-01,
                         -7.60060966e-01,  -7.86039889e-01,  -7.28409231e-01,
                         -7.84178257e-01,  -7.50414431e-01,  -7.40697980e-01,
                         -7.57947564e-01,  -7.47031331e-01,  -7.60658562e-01,
                         -7.55114973e-01,  -7.54719853e-01,  -7.72591054e-01,
                         -7.50209212e-01,  -7.55535543e-01,  -7.69526184e-01,
                         -9.33533669e-01,  -9.20009077e-01,  -9.26467359e-01,
                         -9.36651051e-01,  -9.43141818e-01,  -9.37528908e-01,
                         -9.17026043e-01,  -9.38538313e-01,  -9.32431996e-01,
                         -9.46865797e-01,  -9.37978566e-01,  -9.24676180e-01,
                         -7.60205090e-01,  -7.41321743e-01,  -7.53470361e-01,
                         -7.60498405e-01,  -7.57539690e-01,  -7.44521439e-01,
                         -7.48174846e-01,  -7.74224758e-01,  -7.32580543e-01,
                         -7.67222643e-01,  -7.59786010e-01,  -7.74646819e-01,
                         -7.62086511e-01,  -7.67432630e-01,  -7.43654013e-01,
                         -7.48893619e-01,  -9.27456081e-01,  -9.26967680e-01,
                         -9.06568944e-01,  -9.07031178e-01,  -9.08172369e-01,
                         -9.33893740e-01,  -9.19882357e-01,  -9.30955350e-01,
                         -7.69801259e-01,  -7.53238261e-01,  -7.70500124e-01,
                         -7.56888449e-01,  -7.54943609e-01,  -7.64932215e-01,
                         -7.74217546e-01,  -7.83513308e-01,  -7.74469554e-01,
                         -7.48403311e-01,  -7.78559268e-01,  -7.51130760e-01,
                         -7.80406535e-01,  -7.39535451e-01,  -7.79286325e-01,
                         -7.64946640e-01,  -9.05685902e-01,  -9.53825057e-01,
                         -9.18484747e-01,  -8.94097984e-01,  -9.30879056e-01,
                         -9.12009001e-01,  -9.54717934e-01,  -9.24845219e-01,
                         -9.07429338e-01,  -9.37554896e-01,  -9.35538292e-01,
                         -9.34122026e-01,  -9.44147646e-01,  -9.33369219e-01,
                         -9.31232333e-01,  -9.12090361e-01,  -7.63163865e-01,
                         -7.64267683e-01,  -7.73635864e-01,  -7.84119308e-01,
                         -7.78286517e-01,  -7.71001160e-01,  -7.42759764e-01,
                         -7.64553845e-01,  -7.59917736e-01,  -7.65510023e-01,
                         -7.43375242e-01,  -7.31171548e-01,  -7.50739753e-01,
                         -7.34713614e-01,  -7.69770265e-01,  -7.53414392e-01,
                         -7.58757234e-01,  -7.55678773e-01,  -7.87020981e-01,
                         -7.60784507e-01,  -7.55808771e-01,  -7.77527392e-01,
                         -7.48251796e-01,  -7.75863826e-01,  -7.66409934e-01,
                         -7.52873242e-01,  -7.59770215e-01,  -7.45796680e-01,
                         -7.81203270e-01,  -7.79658437e-01,  -7.77073801e-01,
                         -7.72700727e-01,  -7.79266894e-01,  -7.61637509e-01,
                         -7.61936963e-01,  -7.40845561e-01,  -7.40770817e-01,
                         -7.52637386e-01,  -7.77351379e-01,  -7.73328900e-01,
                         -7.54816711e-01,  -7.47702122e-01,  -7.74428070e-01,
                         -7.63230741e-01,  -7.60708094e-01,  -7.48664737e-01,
                         -7.20124304e-01,  -7.70639896e-01,  -1.46005293e-02,
                         -8.23747367e-03,  -1.92223769e-03,  -1.16476668e-02,
                         -2.91516650e-02,  -2.71426719e-02,  -3.42661195e-04,
                         -1.39632691e-02,  -7.36772716e-01,  -7.67607987e-01,
                         -7.41225958e-01,  -7.67016649e-01,  -7.55475104e-01,
                         -7.61530161e-01,  -7.85564363e-01,  -7.65906513e-01,
                         -7.67741203e-01,  -7.84939826e-01,  -7.52148330e-01,
                         -7.56373346e-01,  -7.47315109e-01,  -7.67086387e-01,
                         -7.45141566e-01,  -7.53436267e-01,  -7.64262378e-01,
                         -7.29158580e-01,  -7.77757406e-01,  -7.64594913e-01,
                         -7.67482221e-01,  -7.59931147e-01,  -7.48693168e-01,
                         -7.49100983e-01,  -7.66662002e-01,  -7.79796422e-01,
                         -7.57607162e-01,  -7.77350307e-01,  -7.43114650e-01,
                         -7.71061361e-01,  -7.48072684e-01,  -7.64970839e-01,
                         -7.32004523e-01,  -7.26742983e-01,  -7.29794323e-01,
                         -7.33618915e-01,  -7.60057807e-01,  -7.62863159e-01,
                         -7.64804661e-01,  -7.43061304e-01,  -7.96504676e-01,
                         -7.78381586e-01,  -7.76792943e-01,  -7.65777349e-01,
                         -7.41025686e-01,  -7.31471062e-01,  -7.72487104e-01,
                         -7.43750274e-01,  -7.90163934e-01,  -7.72086859e-01,
                         -7.71559358e-01,  -7.50515759e-01,  -7.83304334e-01,
                         -7.48593390e-01,  -7.68522561e-01,  -7.86815047e-01,
                          2.95312367e-02,  -3.54831852e-02,  -8.46327376e-03,
                         -2.92064641e-02,  -7.64681518e-01,  -7.64079928e-01,
                         -7.60627449e-01,  -7.56570458e-01,  -7.63126433e-01,
                         -7.46252835e-01,  -7.56885290e-01,  -7.47273326e-01,
                         -7.68643975e-01,  -7.42891967e-01,  -7.31012344e-01,
                         -7.57213771e-01,  -7.62298524e-01,  -7.90619314e-01,
                         -7.77728498e-01,  -7.98172772e-01,  -7.64134526e-01,
                         -7.56014466e-01,  -7.56578982e-01,  -7.65302539e-01,
                         -7.76651263e-01,  -7.91986227e-01,  -7.90228963e-01,
                         -7.61976898e-01,  -7.65848339e-01,  -7.41070747e-01,
                         -7.63898194e-01,  -7.64421225e-01,  -7.57761359e-01,
                         -7.56444275e-01,  -7.90920019e-01,  -7.55132258e-01,
                         -7.54021347e-01,  -7.59114683e-01,  -7.99799323e-01,
                         -7.65014827e-01,  -7.94955313e-01,  -7.72353411e-01,
                         -7.55836487e-01,  -7.79587328e-01,  -1.89266335e-02,
                         -2.85831746e-02,  -3.18325758e-02,   2.45759933e-04,
                         -2.73692352e-03,  -8.23862385e-03,   7.08869239e-03,
                         -4.85752374e-02,  -7.55496860e-01,  -7.56301165e-01,
                         -7.69677579e-01,  -7.66461730e-01,  -7.53151774e-01,
                         -7.65288532e-01,  -7.82608986e-01,  -7.78958976e-01,
                         -7.71191776e-01,  -7.75986671e-01,  -7.50318050e-01,
                         -7.75813520e-01,  -7.36978650e-01,  -7.49715805e-01,
                         -7.37443507e-01,  -7.49425530e-01,  -7.46900558e-01,
                         -7.50039458e-01,  -7.71036208e-01,  -7.62716591e-01,
                         -7.76136935e-01,  -7.53279686e-01,  -7.34855354e-01,
                         -7.44511485e-01,  -7.73791850e-01,  -7.49614894e-01,
                         -7.57682860e-01,  -7.23975062e-01,  -7.45260596e-01,
                         -7.77903140e-01,  -7.82891572e-01,  -7.57543027e-01,
                         -7.71580398e-01,  -7.53276885e-01,  -7.44927943e-01,
                         -7.96699166e-01,   1.18717765e-02,  -2.54772902e-02,
                         -8.17965996e-03,  -1.30329700e-02,  -7.69056618e-01,
                         -7.49228895e-01,  -7.50499189e-01,  -7.51643717e-01,
                         -7.61751711e-01,  -7.35759676e-01,  -7.88888812e-01,
                         -7.70506740e-01,  -7.44534373e-01,  -7.56429136e-01,
                         -7.41634190e-01,  -7.56637037e-01,  -7.80603647e-01,
                         -7.62071788e-01,  -7.86877632e-01,  -7.81946242e-01,
                         -7.42258430e-01,  -7.78702915e-01,  -7.46076047e-01,
                         -7.39812255e-01,  -7.47689784e-01,  -7.33703136e-01,
                         -7.72258639e-01,  -7.66053796e-01,  -7.64788806e-01,
                         -7.82406211e-01,  -7.40928054e-01,  -7.54037201e-01,
                         -7.45577872e-01,  -7.50186801e-01,  -7.52225935e-01,
                         -7.42002010e-01,  -7.51629949e-01,  -7.44360685e-01,
                         -7.24163353e-01,  -7.62676299e-01,  -7.76476800e-01,
                         -7.61002660e-01,  -7.54812181e-01,  -7.83993006e-01,
                         -7.64212072e-01,  -7.87657082e-01,  -7.76597261e-01,
                         -7.45120287e-01,  -7.32657552e-01,  -7.71436930e-01,
                         -7.25736141e-01,  -7.68812358e-01,  -7.35872567e-01,
                         -7.41964996e-01,  -7.76129425e-01,  -7.50394464e-01,
                         -9.59010899e-01,  -9.42584157e-01,  -9.46108460e-01,
                         -9.44137335e-01,  -9.00919199e-01,  -9.29079890e-01,
                         -9.03870761e-01,  -9.21026587e-01,  -9.51740980e-01,
                         -9.00028050e-01,  -9.41340566e-01,  -9.26626384e-01,
                         -7.80838966e-01,  -7.93907106e-01,  -7.66884983e-01,
                         -7.92765677e-01,  -7.62598932e-01,  -7.74164557e-01,
                         -7.73621202e-01,  -7.30231225e-01,  -7.77267694e-01,
                         -7.58357227e-01,  -7.56297767e-01,  -7.53770292e-01,
                         -7.58383751e-01,  -7.82265007e-01,  -7.74868309e-01,
                         -7.94205070e-01,  -7.94957817e-01,  -7.81176150e-01,
                         -7.90190816e-01,  -7.68380105e-01,  -7.86921382e-01,
                         -7.62456834e-01,  -7.86964417e-01,  -7.69170046e-01,
                         -9.27350044e-01,  -9.51919377e-01,  -9.17727530e-01,
                         -9.09152687e-01,  -9.35220480e-01,  -9.18915689e-01,
                         -9.37715113e-01,  -9.63789165e-01,  -9.02359188e-01,
                         -9.64094222e-01,  -9.21128988e-01,  -9.75178003e-01,
                         -7.95708001e-01,  -7.82497048e-01,  -7.87372708e-01,
                         -7.58977652e-01,  -9.34073448e-01,  -9.34335053e-01,
                         -9.41418588e-01,  -9.21989322e-01,  -9.28161979e-01,
                         -9.31226671e-01,  -9.41293061e-01,  -9.50269282e-01,
                         -9.17447031e-01,  -9.68059719e-01,  -9.11797464e-01,
                         -9.66356933e-01,  -9.38004196e-01,  -9.51617897e-01,
                         -9.13618863e-01,  -9.17229891e-01,  -9.62969601e-01,
                         -9.38697219e-01,  -9.51654673e-01,  -9.20072079e-01,
                         -9.31117654e-01,  -9.47816253e-01,  -9.74471986e-01,
                         -9.68877733e-01,  -7.76403308e-01,  -7.81506360e-01,
                         -7.66750455e-01,  -7.58919656e-01,  -7.90439546e-01,
                         -7.91351736e-01,  -7.39816427e-01,  -7.54920125e-01,
                         -7.68193543e-01,  -7.67218888e-01,  -7.52564967e-01,
                         -7.71134257e-01,  -7.79287100e-01,  -7.80071735e-01,
                         -7.66677082e-01,  -7.74171889e-01,  -7.52163649e-01,
                         -7.60027647e-01,  -7.71027505e-01,  -7.31663883e-01,
                         -9.57787097e-01,  -9.47671831e-01,  -9.32001352e-01,
                         -9.36271012e-01,  -9.34473634e-01,  -9.34230566e-01,
                         -9.64535415e-01,  -9.23021674e-01,  -9.20811534e-01,
                         -9.13424969e-01,  -9.29399550e-01,  -9.39442158e-01,
                         -9.07495201e-01,  -9.18123841e-01,  -9.19310808e-01,
                         -9.25637186e-01,  -7.60691881e-01,  -7.74919689e-01,
                         -7.62837231e-01,  -7.73582578e-01,  -7.90352941e-01,
                         -7.67638624e-01,  -7.87201285e-01,  -7.80812144e-01,
                         -7.01065548e-03,  -3.94141814e-03,  -2.54458953e-02,
                         -4.81525511e-02,   7.00313598e-03,  -2.82271523e-02,
                         -2.51359306e-02,  -2.13338016e-03,  -3.02966405e-02,
                         -1.08603283e-03,  -1.09161539e-02,  -3.05926390e-02,
                         -7.70824969e-01,  -7.76060462e-01,  -7.67285228e-01,
                         -7.71273851e-01,   9.08073329e-04,  -4.02474478e-02,
                          6.73932955e-03,  -8.57818034e-03,  -1.98910516e-02,
                         -1.65568572e-02,  -2.46014982e-03,   1.29544968e-03,
                          1.76388130e-01,   1.58221468e-01,   1.38123259e-01,
                          1.67485759e-01,   5.17470902e-03,   1.09845912e-03,
                          1.00146160e-02,  -1.38907423e-02,   1.58598989e-01,
                          1.72371551e-01,   1.54559970e-01,   1.53069362e-01,
                          2.39901301e-02,  -1.14286728e-02,  -7.78678060e-03,
                         -1.50291203e-03,  -1.39085809e-02,  -1.76369157e-02,
                          5.96671132e-03,  -1.97723471e-02,   1.93925332e-02,
                         -2.24157590e-02,   2.14320533e-02,   3.28205712e-03,
                          1.61107585e-01,   1.62595436e-01,   1.82090431e-01,
                          1.72241285e-01,   2.01175109e-01,   1.60533816e-01,
                          1.83117986e-01,   1.70586690e-01,   1.36790648e-01,
                          1.47534385e-01,   1.64024293e-01,   1.61815897e-01,
                          1.71629548e-01,   1.93039656e-01,   1.61751404e-01,
                          1.78392708e-01,   1.52742028e-01,   2.12778121e-01,
                          1.59281880e-01,   1.49282217e-01,   1.84119597e-01,
                          1.66966960e-01,   2.00753167e-01,   1.79011971e-01,
                          1.77000254e-01,   1.73916668e-01,   1.88377410e-01,
                          1.94186002e-01,   1.73227072e-01,   1.71059847e-01,
                          1.77321881e-01,   1.93885371e-01,   2.15209991e-01,
                          1.73167467e-01,   1.86031178e-01,   2.08172902e-01,
                          2.02891082e-01,   1.89240664e-01,   1.63124174e-01,
                          1.57338679e-01,   1.72106549e-01,   1.89023122e-01,
                          1.99327379e-01,   1.79462671e-01,   1.69673309e-01,
                          1.89624816e-01,   1.52705401e-01,   1.47105470e-01,
                          1.86101586e-01,   1.51212916e-01,   1.49213269e-01,
                          1.69880301e-01,   1.64033189e-01,   1.87293857e-01,
                          1.47044718e-01,   1.52489945e-01,   1.81418598e-01,
                          1.78862050e-01,   1.79104790e-01,   2.05464020e-01,
                         -9.21423454e-03,   2.76531046e-03,  -2.52260681e-04,
                          1.19256256e-02,  -3.77655029e-03,  -1.87282991e-02,
                          4.74529043e-02,   5.48445759e-03,   1.28102880e-02,
                          5.11428863e-02,   3.19470167e-02,   1.14811705e-02,
                          2.48601418e-02,   3.95163968e-02,  -2.84766760e-02,
                          1.84030551e-02,  -1.16064660e-02,  -5.54247899e-03,
                         -4.64471467e-02,  -4.31944523e-03,   1.68081895e-02,
                          3.14037986e-02,  -3.53864953e-02,  -8.16618651e-03,
                         -1.29558137e-02,  -8.60579778e-03,   1.48736713e-02,
                          1.30646005e-02,   3.65388766e-02,   4.81033400e-02,
                          3.11914627e-02,   2.89360657e-02,  -6.92192558e-03,
                          9.09975730e-03,   1.61560215e-02,  -2.54776850e-02,
                         -1.89394485e-02,  -1.27717061e-02,  -2.16347203e-02,
                         -1.35105876e-02,   2.59840284e-02,  -1.55419726e-02,
                          2.81353923e-03,   2.61051254e-03,   2.48426851e-02,
                         -4.20418866e-02,   1.67848062e-04,   5.28982328e-03,
                         -1.44662168e-02,   1.20108221e-02,   3.84518225e-03,
                         -3.45012010e-03,  -8.70900601e-03,   1.42673207e-02,
                         -5.88536169e-03,   1.73594356e-02,   1.32447919e-02,
                          2.65746545e-02,   3.14539932e-02,   1.84546653e-02,
                          3.83702032e-02,   4.50337045e-02,   3.08725312e-02,
                          1.53820040e-02,  -7.09472876e-03,  -2.01469511e-02,
                         -5.82057610e-03,   2.44802646e-02,   2.07899007e-04,
                         -2.88245212e-02,  -4.25528357e-04,  -8.62819701e-03,
                         -2.73780227e-02,  -4.54947241e-02,  -3.36064119e-03,
                          1.34923737e-02,  -1.87009871e-02,  -1.30382022e-02,
                          1.82382632e-02,  -4.69657872e-03,   5.55300619e-03,
                         -1.95328053e-02,   2.10528425e-03,  -1.37901604e-02,
                         -6.39470015e-03,  -1.03408936e-02,   9.14950389e-03,
                          1.62365120e-02,   4.23999615e-02,   1.24452831e-02,
                         -9.34822202e-01,  -9.36176002e-01,  -9.46689606e-01,
                         -9.53313231e-01,  -9.11634386e-01,  -9.61737990e-01,
                         -9.31113780e-01,  -9.08158541e-01,  -9.42952394e-01,
                         -9.52646017e-01,  -9.86540914e-01,  -9.85344887e-01,
                         -5.47216758e-02,  -2.24805661e-02,  -1.73340086e-02,
                         -1.38184512e-02,  -4.68825288e-02,  -1.46471635e-02,
                         -4.13990989e-02,  -4.36715037e-02,  -2.89425384e-02,
                         -3.84011194e-02,  -2.78474558e-02,  -2.29377933e-02,
                         -9.41440225e-01,  -9.69103873e-01,  -9.50962305e-01,
                         -9.45577323e-01,  -9.33272839e-01,  -9.60998595e-01,
                         -9.23923910e-01,  -9.50752854e-01,  -9.66337442e-01,
                         -9.16666448e-01,  -9.59238112e-01,  -9.58685279e-01,
                         -9.61354077e-01,  -9.48686898e-01,  -9.61113036e-01,
                         -9.52897310e-01,  -9.67654109e-01,  -9.51778889e-01,
                         -9.70645845e-01,  -9.99983847e-01,  -9.75547135e-01,
                         -9.80706513e-01,  -9.53242719e-01,  -9.46183085e-01,
                         -9.38257694e-01,  -9.13574338e-01,  -9.26459730e-01,
                         -9.60341811e-01,  -9.18763399e-01,  -9.26862836e-01,
                         -9.27342951e-01,  -9.28209186e-01,  -9.22964692e-01,
                         -9.17750359e-01,  -9.49444830e-01,  -9.59624588e-01,
                         -9.48705018e-01,  -9.21945989e-01,  -9.74063814e-01,
                         -9.33099091e-01,  -9.33916092e-01,  -9.29586887e-01,
                         -9.26965773e-01,  -9.20168996e-01,  -9.14616883e-01,
                         -9.40237999e-01,  -9.68655765e-01,  -9.37236488e-01,
                         -9.40923154e-01,  -9.19872582e-01,  -9.09039676e-01,
                         -9.36535478e-01,  -9.28651989e-01,  -9.51494038e-01,
                         -9.18884933e-01,  -9.20467317e-01,  -9.50654149e-01,
                         -9.52924788e-01,  -9.22288120e-01,  -9.43288505e-01,
                         -9.44880724e-01,  -9.51258063e-01,  -9.42578375e-01,
                         -9.17441249e-01,  -9.65786874e-01,  -9.19815183e-01,
                         -9.19935644e-01,  -9.27488148e-01,  -9.50497031e-01,
                         -9.44132686e-01,  -9.70703363e-01,  -9.70466435e-01,
                         -9.36560988e-01,  -9.43836629e-01,  -9.38907027e-01,
                         -9.27673578e-01,  -9.29020464e-01,  -9.47623193e-01,
                         -9.25779700e-01,  -9.01223779e-01,  -9.31481183e-01,
                         -9.10968363e-01,  -9.23064053e-01,  -9.16287959e-01,
                         -9.37550426e-01,  -9.31796730e-01,  -9.42738414e-01,
                         -9.10872042e-01,  -9.59330499e-01,  -9.43016052e-01,
                         -9.45637643e-01,  -9.48693097e-01,  -9.56289887e-01,
                         -9.60347116e-01,  -9.29094374e-01,  -9.45827246e-01,
                         -9.74209547e-01,  -9.32927430e-01,  -9.58076358e-01,
                         -9.83094335e-01,  -9.83777046e-01,  -9.45743084e-01,
                         -9.38483655e-01,  -9.27776575e-01,  -9.27914381e-01,
                         -8.93696070e-01,  -9.69160378e-01,  -9.38789248e-01,
                         -9.68194246e-01,  -9.40814972e-01,  -9.56804633e-01,
                         -9.17178929e-01,  -9.44565713e-01,  -9.59639788e-01,
                         -9.49936509e-01,  -9.21550930e-01,  -9.46711779e-01,
                         -9.62685585e-01,  -9.18376207e-01,  -9.26024258e-01,
                         -9.46079969e-01,  -9.63078380e-01,  -9.32235658e-01,
                         -9.40692186e-01,  -9.55674350e-01,  -9.36827660e-01,
                         -9.42018509e-01,  -9.43240166e-01,  -8.93491924e-01,
                         -9.60580528e-01,  -9.42398310e-01,  -9.50678885e-01,
                         -9.69835579e-01,  -9.18619037e-01,  -9.12729979e-01,
                         -9.19627070e-01,  -9.21304643e-01,  -9.77627277e-01,
                         -9.30261314e-01,  -9.32544649e-01,  -9.55750763e-01,
                         -9.35942888e-01,  -9.71844554e-01,  -9.29660499e-01,
                         -9.19414461e-01,  -9.27192152e-01,  -9.44404364e-01,
                         -9.11968648e-01,  -9.10167813e-01,  -9.13654923e-01,
                         -9.37338293e-01,  -9.39135551e-01,  -9.36772466e-01,
                         -9.46458399e-01,  -9.16797876e-01,  -9.57502782e-01,
                         -9.42046463e-01,  -9.26126122e-01,  -9.22214806e-01,
                         -9.39873755e-01,  -9.54140306e-01,  -9.59553480e-01,
                         -9.27729189e-01,  -9.26944792e-01,  -9.33800936e-01,
                         -9.37822223e-01,  -9.56484795e-01,  -9.40725565e-01,
                         -9.84436512e-01,  -9.38799560e-01,  -9.33484852e-01,
                         -9.23944950e-01,  -9.17769253e-01,  -9.47293639e-01,
                         -9.28552270e-01,  -9.18653965e-01,  -9.46883142e-01,
                         -9.42713320e-01,  -9.34189260e-01,  -9.17302787e-01,
                         -9.42314923e-01,  -8.95005047e-01,  -9.14817572e-01,
                         -9.25485075e-01,  -9.13213670e-01,  -9.60445225e-01,
                         -9.17443812e-01,  -9.12513673e-01,  -9.16054249e-01,
                         -9.40053165e-01,  -9.25829887e-01,  -9.39191759e-01,
                         -9.17814493e-01,  -9.48197901e-01,  -9.41079319e-01,
                         -9.35352206e-01,  -9.77377236e-01,  -9.46506977e-01,
                         -9.71130967e-01,  -9.16675746e-01,  -9.39829946e-01,
                         -9.58549440e-01,  -9.31370735e-01,  -9.30703521e-01,
                         -9.45400238e-01,  -9.15501773e-01,  -9.25463021e-01,
                         -9.27460551e-01,  -9.44765151e-01,  -9.35192108e-01,
                         -9.37952638e-01,  -9.17562962e-01,  -9.36191857e-01,
                         -9.07366216e-01,  -9.40545738e-01,  -9.22231972e-01,
                         -9.11848962e-01,  -9.24615264e-01,  -9.44010019e-01,
                         -9.48365927e-01,  -9.11465347e-01,  -9.37267244e-01,
                         -9.60671484e-01,  -9.33741271e-01,  -9.42754030e-01,
                         -9.51736987e-01,  -9.60830152e-01,  -9.62939203e-01,
                         -9.45599914e-01,  -9.23991799e-01,  -9.49393511e-01,
                         -9.17872429e-01,  -9.57335770e-01,  -9.28228915e-01,
                         -9.67392743e-01,  -9.25873637e-01,  -9.33122277e-01,
                         -9.10205901e-01,  -9.03661311e-01,  -9.53345478e-01,
                         -9.39251125e-01,  -9.25103486e-01,  -9.14519370e-01,
                         -9.25673723e-01,  -9.09839690e-01,  -9.59340274e-01,
                         -9.39640880e-01,  -9.34459269e-01,  -9.56627548e-01,
                         -9.09009039e-01,  -9.31882322e-01,  -9.30719674e-01,
                          3.28345969e-02,  -3.50175169e-03,   1.25083153e-03,
                         -3.25028109e-03,  -1.85478795e-02,  -6.54380815e-03,
                         -2.78056636e-02,  -2.40992773e-02,  -8.12190818e-04,
                         -2.11889409e-02,  -2.46913787e-02,   3.95393465e-03,
                         -9.63220838e-03,  -2.37761475e-02,  -1.06391236e-02,
                         -1.41342636e-02,  -1.95805058e-02,  -1.55024203e-02,
                         -3.79616059e-02,  -5.36040962e-03,  -1.77903622e-02,
                          3.28595079e-02,  -5.18809166e-03,   1.55214164e-02,
                          1.79121308e-02,   1.16731571e-02,   2.43734871e-03,
                         -1.54682323e-02,   4.72951196e-02,  -5.36967581e-03,
                          2.41452754e-02,   2.93707140e-02,   1.15694506e-02,
                         -1.52223548e-02,   1.98528375e-02,   2.62138080e-02,
                          1.46268643e-02,   1.20253898e-02,  -1.47914072e-03,
                         -3.53545584e-02,  -1.43669592e-02,   2.63558608e-02,
                          3.39553058e-02,   3.56578045e-02,   2.17445605e-02,
                          1.47836171e-02,   4.67606038e-02,   1.07412152e-02,
                         -9.03888166e-01,  -9.23667014e-01,  -9.15194571e-01,
                         -9.34236705e-01,  -9.07595813e-01,  -9.39267635e-01,
                         -8.94765437e-01,  -8.81527126e-01,  -9.15089250e-01,
                         -9.09865618e-01,  -9.27087307e-01,  -9.46682215e-01,
                         -9.07265365e-01,  -9.51435685e-01,  -9.38121617e-01,
                         -9.05049682e-01,  -9.42652464e-01,  -9.42346632e-01,
                         -8.91296327e-01,  -9.19023454e-01,  -9.06603217e-01,
                         -8.97621810e-01,  -9.03838694e-01,  -9.22849774e-01,
                         -9.55771804e-01,  -9.07400191e-01,  -9.62299943e-01,
                         -9.44621146e-01,  -9.67095673e-01,  -9.82113183e-01,
                         -9.10338700e-01,  -9.37788963e-01,  -9.34026897e-01,
                         -9.46027756e-01,  -9.13284123e-01,  -8.88150811e-01,
                         -9.37546313e-01,  -9.34553385e-01,  -9.52922881e-01,
                         -9.43149328e-01,  -9.35225248e-01,  -9.60337996e-01,
                         -9.47721422e-01,  -9.63667274e-01,  -9.51152384e-01,
                         -9.24262226e-01,  -9.38202202e-01,  -9.58727479e-01,
                         -9.47757125e-01,  -9.40745771e-01,  -9.45087731e-01,
                         -9.16833580e-01,  -9.15022790e-01,  -9.13723528e-01,
                         -9.42798376e-01,  -9.50375617e-01,  -9.34414804e-01,
                         -9.42064881e-01,  -9.09140885e-01,  -9.24699426e-01,
                         -9.34634566e-01,  -9.04574811e-01,  -8.90576184e-01,
                         -9.25831854e-01,  -9.13121700e-01,  -9.10359561e-01,
                         -9.55833554e-01,  -9.10474420e-01,  -9.31837320e-01,
                         -9.67977226e-01,  -9.29378748e-01,  -9.03902054e-01,
                         -9.28878903e-01,  -9.18256044e-01,  -9.08001900e-01,
                         -9.43162084e-01,  -9.28625166e-01,  -9.44470644e-01,
                         -9.25716877e-01,  -9.11022484e-01,  -9.21751976e-01,
                         -9.15590763e-01,  -9.18778121e-01,  -9.07228410e-01,
                         -9.21458662e-01,  -9.40370202e-01,  -9.25622642e-01,
                         -9.26839590e-01,  -9.25757706e-01,  -9.26111162e-01,
                         -9.44484830e-01,  -9.32358027e-01,  -9.54560578e-01,
                         -9.16796446e-01,  -9.24146652e-01,  -9.08332348e-01,
                         -9.12725210e-01,  -9.32513416e-01,  -9.10463035e-01,
                         -9.34555054e-01,  -9.53327298e-01,  -9.23985779e-01,
                         -9.12376940e-01,  -9.38925683e-01,  -9.28906441e-01,
                         -9.00948644e-01,  -9.38073397e-01,  -9.04574633e-01,
                         -9.26447093e-01,  -9.49470639e-01,  -9.37640131e-01,
                         -9.21668470e-01,  -9.37343955e-01,  -9.28791165e-01,
                         -9.15866017e-01,  -9.22551870e-01,  -9.17237878e-01,
                         -9.27692473e-01,  -9.37609553e-01,  -9.46387231e-01,
                         -9.42533553e-01,  -9.21124756e-01,  -9.29153085e-01,
                         -9.24335122e-01,  -9.17519331e-01,  -9.25620198e-01,
                         -9.39756989e-01,  -9.31235015e-01,  -9.27516699e-01,
                         -9.35029089e-01,  -9.28955734e-01,  -9.36449766e-01,
                         -9.32949066e-01,  -9.22464788e-01,  -9.09440875e-01,
                         -9.27214324e-01,  -9.55078542e-01,  -9.33955252e-01,
                         -9.44359660e-01,  -9.32579279e-01,  -9.46545780e-01,
                         -9.40042734e-01,  -9.11111414e-01,  -9.22380924e-01,
                         -9.15688694e-01,  -9.22320426e-01,  -9.26661909e-01,
                         -9.16775346e-01,  -9.23214555e-01,  -9.36461389e-01,
                         -9.31446135e-01,  -9.38002765e-01,  -9.37029183e-01,
                         -9.39832389e-01,  -9.26035881e-01,  -9.27892685e-01,
                         -9.36281800e-01,  -9.21864450e-01,  -9.21450078e-01,
                         -9.27463770e-01,  -9.18855250e-01,  -9.25893962e-01,
                         -9.16030705e-01,  -9.30130303e-01,  -9.39715862e-01,
                         -9.30887043e-01,  -9.28776085e-01,  -9.33444083e-01,
                         -9.26113963e-01,  -9.30167854e-01,  -9.30106938e-01,
                         -9.09166038e-01,  -9.29118037e-01,  -9.20728981e-01,
                         -9.24212575e-01,  -9.27083910e-01,  -9.32624519e-01,
                         -9.31272924e-01,  -9.27438021e-01,  -9.20525968e-01,
                         -9.27180529e-01,  -9.33930874e-01,  -9.43540335e-01,
                         -9.32408154e-01,  -9.29466605e-01,  -9.26133454e-01,
                         -9.26613092e-01,  -9.21926796e-01,  -9.27308738e-01,
                         -9.23849463e-01,  -9.26315963e-01,  -9.26918566e-01,
                         -9.31743205e-01,  -9.30506229e-01,  -9.33744490e-01,
                         -9.42829013e-01,  -9.37122762e-01,  -9.37041104e-01,
                         -9.31224346e-01,  -9.24498498e-01,  -9.27691877e-01,
                         -9.34451461e-01,  -9.35635626e-01,  -9.25332129e-01,
                         -9.29759562e-01,  -9.37228441e-01,  -9.30209756e-01,
                         -9.28859949e-01,  -9.37665880e-01,  -9.33819652e-01,
                         -9.25972641e-01,  -9.24074411e-01,  -9.43839490e-01,
                         -9.32797134e-01,  -9.24108684e-01,  -9.37294960e-01,
                         -9.32264149e-01,  -9.28026259e-01,  -9.31027651e-01,
                         -9.28450644e-01,  -9.26493883e-01,  -9.30136383e-01,
                         -9.36423182e-01,  -9.35978591e-01,  -9.28587019e-01,
                         -9.23168242e-01,  -9.23441172e-01,  -9.31228340e-01,
                         -9.26142991e-01,  -9.22326922e-01,  -9.29891944e-01,
                         -9.35556829e-01,  -9.38715637e-01,  -9.22008395e-01,
                         -9.35196996e-01,  -9.12036002e-01,  -9.25761521e-01,
                         -9.36774254e-01,  -9.24243271e-01,  -9.26723480e-01,
                         -9.26200390e-01,  -9.23738062e-01,  -9.29659605e-01,
                         -9.31913376e-01,  -9.27956462e-01,  -9.30546463e-01,
                         -9.39633012e-01,  -9.33805764e-01,  -9.27102864e-01,
                         -9.29270983e-01,  -9.29180503e-01,  -9.35064673e-01,
                         -9.23108041e-01,  -9.26784813e-01,  -9.32304263e-01,
                         -9.35257733e-01,  -9.33767319e-01,  -9.24837232e-01,
                         -9.32961404e-01,  -9.38617051e-01,  -9.36422050e-01,
                         -9.35887992e-01,  -9.20288146e-01,  -9.37759697e-01,
                         -9.30351436e-01,  -9.30109501e-01,  -9.44489956e-01,
                         -9.37015533e-01,  -9.29140270e-01,  -9.35444057e-01,
                         -9.36625659e-01,  -9.28611338e-01,  -9.39095199e-01,
                         -9.29105639e-01,  -9.28667307e-01,  -9.41864252e-01,
                         -9.29829001e-01,  -9.37320113e-01,  -9.43338752e-01,
                         -9.29258406e-01,  -9.34772849e-01,  -9.24450874e-01,
                         -9.37145829e-01,  -9.33821201e-01,  -9.31780100e-01,
                         -9.35536623e-01,  -9.21199083e-01,  -9.20231044e-01,
                         -9.30938482e-01,  -9.40324068e-01,  -9.25787091e-01,
                         -9.38107669e-01,  -9.24251616e-01,  -9.28237021e-01,
                         -9.33647692e-01,  -9.28847253e-01,  -9.36295390e-01,
                         -9.32313681e-01,  -9.29846346e-01,  -9.40910518e-01,
                         -9.42734420e-01,  -9.32381213e-01,  -9.28968489e-01,
                         -9.37629044e-01,  -9.42066610e-01,  -9.35388148e-01,
                         -9.38852787e-01,  -9.21733856e-01,  -9.27852392e-01,
                         -9.25478876e-01,  -9.29790676e-01,  -9.31626499e-01,
                         -9.36435580e-01,  -9.31866169e-01,  -9.34173584e-01,
                         -9.32421029e-01,  -9.36064005e-01,  -9.48774636e-01,
                         -9.27412570e-01,  -9.24042642e-01,  -9.20091987e-01,
                         -9.18915927e-01,  -9.25764620e-01,  -9.21661198e-01,
                         -9.30610001e-01,  -9.38003302e-01,  -9.26602364e-01,
                         -9.25370216e-01,  -9.23289835e-01,  -9.20117617e-01,
                         -9.18803215e-01,  -9.22083557e-01,  -9.32910144e-01,
                         -9.29295242e-01,  -9.26917017e-01,  -9.30612445e-01,
                         -9.28753853e-01,  -9.24108684e-01,  -9.22550380e-01,
                         -9.40000594e-01,  -9.40676451e-01,  -9.35196638e-01,
                         -9.39163744e-01,  -9.36788976e-01,  -9.52832997e-01,
                         -9.37625945e-01,  -9.31322277e-01,  -9.37846601e-01,
                         -9.33888197e-01,  -9.32153106e-01,  -9.44327295e-01,
                         -9.37822580e-01,  -9.41098273e-01,  -9.31959748e-01,
                         -9.39684212e-01,  -9.34841275e-01,  -9.22025383e-01,
                         -9.20098960e-01,  -9.18896139e-01,  -9.22324419e-01,
                         -9.36218798e-01,  -9.27249491e-01,  -9.32163894e-01,
                         -9.42194819e-01,  -9.33040798e-01,  -9.25803423e-01,
                         -9.37143028e-01,  -9.26070511e-01,  -9.47249711e-01,
                         -9.34891701e-01,  -9.28841054e-01,  -9.25530434e-01,
                         -9.40283239e-01,  -9.40251768e-01,  -9.21859443e-01,
                         -9.26550388e-01,  -9.37776506e-01,  -9.34064269e-01,
                         -9.29283977e-01,  -9.34421539e-01,  -9.28353846e-01,
                         -9.27143037e-01,  -9.21451569e-01,  -9.34694409e-01,
                         -9.28447485e-01,  -9.34967458e-01,  -9.41181183e-01,
                         -9.20560598e-01,  -9.45172131e-01,  -9.38029110e-01,
                         -9.39383626e-01,  -9.43885088e-01,  -9.47773755e-01,
                         -9.30491924e-01,  -9.25062656e-01,  -9.34504390e-01,
                         -9.34400678e-01,  -9.34555709e-01,  -9.24953163e-01,
                         -9.23569024e-01,  -9.21349227e-01,  -9.43766952e-01,
                         -9.32876766e-01,  -9.18669581e-01,  -9.21720088e-01,
                         -9.26193655e-01,  -9.19996858e-01,  -9.29950118e-01,
                         -9.28921819e-01,  -9.27594543e-01,  -9.36745644e-01,
                         -9.34665918e-01,  -9.32599366e-01,  -9.24516201e-01,
                         -9.20005322e-01,  -9.15932178e-01,  -9.13969696e-01,
                         -9.33174968e-01,  -9.33377445e-01,  -9.34018373e-01,
                         -9.38228965e-01,  -9.23085988e-01,  -9.33065593e-01,
                         -9.06485558e-01,  -9.17542458e-01,  -9.29354668e-01,
                         -9.44694102e-01,  -9.22972620e-01,  -1.28283901e-02,
                          2.34617833e-02,   1.36605827e-02,   1.44138858e-02,
                         -6.28852565e-03,   1.60496328e-02,   6.96314080e-03,
                          1.98775455e-02,   6.25293795e-03,   1.32267242e-02,
                          5.49563626e-03,   8.64534266e-03,   8.09443649e-03,
                          8.44750647e-03,   6.81175245e-03,   9.00193397e-03,
                         -2.52099219e-03,   5.81056159e-03,   6.25924487e-03,
                          3.68435460e-04,   5.54961059e-03,  -4.02104203e-03,
                         -1.93234291e-02,   4.05513274e-04,   3.69239395e-04,
                         -2.32154131e-03,  -9.90345143e-03,   6.44430798e-03,
                         -6.08763332e-03,  -3.02031566e-03,   2.41102694e-04,
                          8.77240580e-03,  -7.58638745e-03,   1.43596344e-02,
                          1.01636611e-02,   1.31492421e-03,   2.86072865e-03,
                          1.36302132e-03,  -3.06268129e-03,   2.63603730e-03,
                         -8.07455927e-03,   3.73910501e-04,  -9.99796856e-03,
                         -1.47563247e-02,  -4.77506546e-06,   7.08741695e-03,
                         -1.25184199e-02,  -5.38170664e-03,   2.25557742e-04,
                          2.65807589e-03,   4.05586045e-03,   8.11023079e-03,
                         -3.71606834e-03,  -9.54604894e-03,  -5.86097362e-03,
                         -9.77959763e-03,  -2.05401555e-02,  -9.90164280e-03,
                         -8.13291408e-03,   3.28018586e-03,  -1.63956415e-02,
                         -1.21594378e-04,  -1.01305405e-02,  -2.15656720e-02,
                         -1.20652951e-02,  -7.54296826e-03,  -3.05315899e-03,
                          7.14568794e-03,  -1.61537214e-03,  -2.40257871e-03,
                         -8.96582659e-03,   1.80869848e-02,  -9.63137671e-03,
                          9.43137798e-03,   2.31490890e-03,   4.29200800e-03,
                         -1.46821141e-03,   3.12542939e-03,   9.88480169e-04,
                          7.27667334e-03,  -1.54070510e-02,   2.28127558e-03,
                          2.41684844e-03,   8.32713954e-03,   2.86027114e-03,
                         -4.06555599e-03,  -5.25571173e-03,  -3.12077209e-05,
                         -1.15896866e-03,   1.16871707e-02,  -8.58209562e-03,
                          6.78577693e-03,  -2.00381572e-03,   4.47133975e-03,
                         -1.07564693e-02,  -2.59572291e-03,  -9.07641556e-03,
                         -6.90016383e-03,  -4.39983141e-03,  -6.91810669e-03,
                         -1.07620552e-03,   9.08365753e-03,   5.59814414e-03,
                          4.53753211e-03,  -5.59422839e-03,  -6.45424612e-03,
                          8.26089829e-03,   2.09038379e-03,  -4.47799265e-03,
                         -5.10518253e-03,  -4.15351009e-03,   2.59816926e-03,
                          1.63001614e-03,  -3.80619167e-04,   1.76791777e-03,
                          2.99048703e-03,  -1.02776326e-02,  -2.94170366e-03,
                          9.33473348e-04,   2.42180377e-03,   5.92205161e-03,
                         -2.73825414e-03,  -2.51942570e-03,   9.67445597e-03,
                          3.98761639e-03,   1.23735191e-03,  -2.61914777e-03,
                         -3.27139813e-03,   6.10515359e-04,   7.94462801e-04,
                          2.29001464e-03,   9.23216995e-03,  -5.68717951e-04,
                          1.17724147e-02,  -1.18301727e-03,   1.54962316e-02,
                         -1.69060891e-03,  -7.59547995e-03,  -5.33571653e-03,
                         -4.08011675e-03,   9.00824089e-04,  -8.10867082e-03,
                         -1.44715533e-02,   4.95837536e-04,   4.26907511e-03,
                         -1.21585373e-03,   3.26520239e-04,   4.99530090e-03,
                         -5.43432264e-03,  -3.95492557e-03,  -6.07777853e-04,
                         -1.42676744e-03,  -3.64995888e-03,   1.03575261e-02,
                          5.53538930e-03,   7.53947534e-03,   1.44797526e-02,
                          2.63081165e-03,  -9.46653634e-03,  -5.82987675e-04,
                          4.89535695e-03,   1.35697110e-03,  -2.33128550e-03,
                         -9.01648775e-03,   7.93194515e-04,  -4.46172012e-03,
                          2.98978714e-03,   1.38305023e-03,   8.30237009e-03,
                          2.85353488e-03,  -5.94243407e-03,   1.60015293e-03,
                          1.99209643e-03,  -3.46841640e-03,   1.20023941e-03,
                          4.34046518e-03,   6.39477628e-04,  -4.89496197e-05,
                         -8.18051863e-03,   4.95414773e-04,   2.63823406e-03,
                          1.81279238e-03,  -1.14018726e-03,   6.39778376e-03,
                          3.28281941e-03,   4.34422866e-03,  -4.67849011e-03,
                         -3.40200216e-03,   6.09187502e-03,  -9.64528602e-03,
                          1.14975125e-03,  -7.26798270e-03,   4.03460488e-03,
                         -1.07179638e-02,  -9.53110028e-03,   2.53585796e-03,
                         -7.47320661e-03,  -1.25109004e-02,  -4.69005015e-03,
                          2.65173451e-03,  -6.35852979e-04,   9.16389865e-04,
                         -6.15155278e-03,  -2.15295167e-03,   4.91968961e-03,
                          1.03877427e-03,   6.72505284e-03,   1.11367833e-03,
                         -4.08543227e-03,  -5.38239302e-03,  -1.17311161e-02,
                          5.47427684e-04,   1.35382463e-03,  -2.21489579e-03,
                          5.40472288e-03,   4.53326292e-03,   1.21751009e-03,
                          7.27020716e-03,   1.57626369e-03,  -1.44062133e-03,
                         -4.77035297e-04,  -4.20354074e-03,   2.00667116e-03,
                         -3.45041812e-03,  -1.24250259e-02,  -1.19055696e-02,
                          1.80702622e-03,  -9.24922619e-03,  -4.96707996e-03,
                          2.21608090e-03,   4.45518456e-03,  -4.87099681e-03,
                         -1.17786592e-02,  -6.71385322e-04,  -3.67834605e-03,
                         -5.08979708e-03,  -4.29395528e-04,  -7.39287585e-03,
                         -4.55845520e-03,   5.88276982e-03,  -1.00992154e-02,
                         -4.90076281e-03,  -4.01467271e-03,   3.59348301e-03,
                          5.28593548e-03,  -9.12695937e-03,  -4.37619863e-03,
                          2.49543949e-03,  -7.83311762e-03,   5.24503877e-03,
                          5.46808774e-03,   1.91414985e-03,  -3.33219185e-03,
                         -1.68270129e-03,   1.53282378e-03,   5.04748709e-03,
                          1.65675371e-03,  -6.47489214e-04,   5.48591977e-03,
                          1.00189336e-02,   6.20245002e-03,  -1.39356370e-03,
                          1.10130059e-03,  -6.75665541e-03,  -3.78787448e-03,
                          2.22186092e-03,   5.28693339e-03,   1.07583264e-02,
                          6.35645771e-03,  -3.97893973e-03,   6.28356356e-03,
                          3.88632133e-03,  -2.23091198e-03,  -3.38378188e-04,
                         -4.52427426e-03,   9.51166078e-03,   1.09455455e-02,
                          4.05200012e-03,  -6.34869561e-03,  -9.82526224e-03,
                         -6.78730896e-03,  -2.61137867e-03,  -1.02954987e-03,
                         -6.08104281e-03,  -4.70800698e-03,  -5.72901126e-03,
                         -1.52358552e-04,  -1.02045024e-02,  -4.12013987e-03,
                          1.05312723e-03,  -4.24431264e-03,  -3.02006607e-03,
                         -1.10079264e-02,  -1.23132937e-04,  -7.35278334e-03,
                         -3.04462761e-03,  -8.50904209e-04,   5.45971561e-03,
                          1.55055185e-03,   7.65662035e-03,   8.05315189e-03,
                          9.22523264e-04,  -7.93277693e-04,  -6.47946610e-04,
                         -1.78680324e-03,  -1.86899805e-03,  -1.99836143e-03,
                         -7.27588311e-03,  -1.21712750e-02,  -4.96210391e-03,
                          4.49036364e-04,  -3.22452770e-03,  -5.18309465e-03,
                         -2.17160140e-03,  -1.16511257e-02,   1.57744193e-03,
                          8.75037350e-03,   1.15809552e-02,   1.03074396e-02,
                          3.52693698e-03,  -3.11702280e-03,  -6.76310062e-03,
                          1.38775609e-03,  -9.25619062e-03,  -3.20542045e-03,
                          3.17419879e-03,   6.14803191e-03,  -2.33386364e-03,
                         -1.98002369e-03,   4.79963375e-03,   7.91972037e-03,
                          1.02826636e-02,   4.53749066e-03,  -4.34804009e-03,
                          6.10681658e-04,   2.63675093e-03,  -3.98146221e-04,
                         -6.03552349e-03,   8.44636373e-03,   4.52787103e-03,
                          2.51589133e-03,  -1.02932123e-03,   1.61280786e-03,
                          8.17677658e-03,   2.86799856e-03,   7.43032084e-04,
                         -9.01549682e-03,  -3.18239070e-03,   4.42012353e-03,
                          1.91647152e-04,   2.64273188e-03,   2.88529019e-03,
                          8.35845061e-03,   4.37029405e-03,   7.16090063e-03,
                          1.07441749e-03,   5.54085011e-03,   2.04184302e-03,
                          1.53258815e-02,   4.56105394e-04,   4.79615480e-03,
                          2.30946834e-03,  -1.19214470e-03,  -2.58784299e-03,
                         -8.98434501e-03,  -2.71682511e-03,  -2.12292900e-04,
                          2.35134899e-03,   5.58653567e-03,  -5.70741598e-04,
                          1.47320132e-03,  -1.21363038e-02,  -1.06721679e-02,
                         -6.43848628e-03,  -1.02467639e-02,  -4.37678071e-03,
                         -5.17915795e-03,  -4.19286126e-03,  -3.04264552e-03,
                         -1.91838434e-03,  -4.60792426e-03,  -1.50804745e-03,
                          1.10659550e-03,   6.55124430e-03,   3.82484146e-03,
                         -5.76669909e-03,   2.26877979e-03,   2.04378346e-04,
                          4.48154099e-03,  -3.68203293e-03,   4.10164287e-03,
                         -1.01994574e-02,  -1.35269985e-02,   2.87824869e-03,
                         -5.94585063e-03,   4.36014077e-03,  -1.37056853e-03,
                          7.40149058e-04,  -4.20461502e-03,  -1.70176686e-03,
                         -1.07472036e-02,   1.08655266e-04,  -6.67537563e-03,
                         -9.74565279e-03,  -1.10112941e-02,   4.88158636e-04,
                         -2.07165768e-03,   6.91935420e-03,   2.85456050e-03,
                         -4.90704179e-03,  -2.59301998e-03,  -4.13775723e-03,
                          1.82350678e-03,  -4.52262489e-03,   2.30533094e-03,
                         -6.26597414e-03,   6.57568825e-03,  -7.29849050e-03,
                         -1.04285702e-02,   7.21161021e-03,  -2.20847130e-03,
                          6.29580987e-04,   1.28549198e-02,  -7.70983193e-03,
                         -7.02759367e-04,  -5.43515431e-03,  -2.30140844e-03,
                         -1.90848764e-03,  -8.93706572e-04,   1.58957224e-02,
                          1.87687797e-03,   1.26233958e-02,   4.08769865e-03,
                         -2.47676903e-03,  -1.50989788e-03,   5.19650523e-03,
                          5.94423572e-03,   2.85627227e-03,  -1.92935520e-03,
                         -6.61837263e-03,   1.08336470e-04,   1.01985214e-02,
                          2.97749951e-03,  -7.16696435e-04,  -4.11878852e-03,
                         -4.58674505e-03,  -5.00901602e-03,  -1.05951633e-02,
                         -5.68596646e-03,  -4.23668930e-03,  -1.52702990e-03,
                         -1.61279400e-03,  -4.10623755e-03,   2.04623700e-03,
                          1.42937955e-02,   4.83114645e-03,   1.07594905e-03,
                         -5.06669807e-04,   1.53149315e-03,   1.63452029e-02,
                          3.84434359e-03,  -2.95154494e-03,  -9.74547956e-03,
                          1.06185125e-02,  -1.04840065e-03,   2.54953862e-03,
                         -1.11289732e-02,  -2.08023074e-03,  -9.34376299e-01,
                         -9.18844402e-01,  -9.17723060e-01,  -9.17461097e-01,
                         -9.31657493e-01,  -9.25127506e-01,  -9.36017752e-01,
                         -9.42757785e-01,  -9.32143271e-01,  -9.42515314e-01,
                         -9.44403887e-01,  -9.49903369e-01,   7.48749683e-03,
                         -8.79175495e-03,  -1.63154770e-03,  -4.60166630e-04,
                         -6.30948320e-03,  -1.04027959e-02,  -1.28255214e-03,
                         -1.33900740e-03,  -7.24804355e-03,   4.16359399e-04,
                          8.52187723e-03,  -1.22306962e-02,  -3.15661635e-03,
                         -3.06373485e-03,  -1.46527570e-02,  -1.47340018e-02,
                         -9.44122672e-03,  -2.50717551e-02,  -1.01565504e-02,
                         -1.10751726e-02,  -1.29557783e-02,  -2.08231664e-04,
                         -2.75527523e-03,  -3.33890738e-03,   2.37928558e-04,
                          8.53413003e-05,  -1.03634864e-03,  -6.25025574e-03,
                          4.83718282e-03,   5.00266091e-04,  -2.41558021e-03,
                          1.00839334e-02,   6.10617222e-03,  -6.10869518e-03,
                         -3.68941401e-04,  -6.75735530e-03,   1.43132068e-03,
                         -5.44834975e-03,  -5.18551329e-03,  -2.04802845e-02,
                         -1.31004518e-02,   4.60325321e-03,  -4.29958990e-03,
                          2.61837151e-03,  -4.55670850e-03,  -1.74354631e-02,
                         -2.79280357e-03,  -2.06574611e-03,  -1.12965507e-02,
                         -8.80646892e-03,  -4.87407390e-03,   6.03487203e-03,
                         -1.64306606e-04,  -9.27159004e-03,  -3.72276315e-03,
                         -2.40576686e-03,   4.02901182e-03,  -8.04410782e-03,
                          1.61408307e-03,  -9.33442172e-03,   1.24534266e-03,
                         -3.48603353e-03,   6.96549704e-03,   4.09061642e-04,
                         -9.33750570e-01,  -9.35596585e-01,  -9.32005107e-01,
                         -9.39245999e-01,  -9.30807292e-01,  -9.36527073e-01,
                         -9.46164668e-01,  -9.37676489e-01,  -9.28455114e-01,
                         -9.30826902e-01,  -9.30640161e-01,  -9.33311760e-01,
                         -9.40525651e-01,  -9.38171506e-01,  -9.45994675e-01,
                         -9.28881168e-01,  -9.35770571e-01,  -9.33672190e-01,
                         -9.32672501e-01,  -9.49410260e-01,  -9.40317631e-01,
                         -9.40187752e-01,  -9.29668844e-01,  -9.42366719e-01,
                         -9.41163898e-01,  -9.48032379e-01,  -9.46520865e-01,
                         -9.36591506e-01,  -9.46116567e-01,  -9.42512393e-01,
                         -9.35700536e-01,  -9.39545929e-01,  -9.31495488e-01,
                         -9.38075483e-01,  -9.35283899e-01,  -9.37809885e-01,
                         -9.25074220e-01,  -9.32958364e-01,  -9.30241644e-01,
                         -9.29670691e-01,  -9.26455736e-01,  -9.35181677e-01,
                         -9.33287084e-01,  -9.47395980e-01,  -9.31821108e-01,
                         -9.39407706e-01,  -9.35918629e-01,  -9.40128088e-01,
                         -9.41293001e-01,  -9.45275009e-01,  -9.37185287e-01,
                         -9.37269688e-01,  -9.45417106e-01,  -9.39107835e-01,
                         -9.37932909e-01,  -9.42465186e-01,  -9.31872904e-01,
                         -9.27967846e-01,  -9.34697330e-01,  -9.28443611e-01,
                         -9.36717033e-01,  -9.25221145e-01,  -9.23812091e-01,
                         -9.37130392e-01,  -9.38130140e-01,  -9.40119684e-01,
                         -9.38152432e-01,  -9.39898252e-01,  -9.32351530e-01,
                         -9.38454926e-01,  -9.30364549e-01,  -9.33082163e-01,
                         -9.34111953e-01,  -9.32404280e-01,  -9.30433512e-01,
                         -9.36273813e-01,  -9.24652338e-01,  -9.39108074e-01,
                         -9.40193295e-01,  -9.37704921e-01,  -9.33576226e-01,
                         -9.26563442e-01,  -9.27125335e-01,  -9.24508691e-01,
                         -9.26689148e-01,  -9.39933836e-01,  -9.23461139e-01,
                         -9.31389689e-01,  -9.33893740e-01,  -9.39390182e-01,
                         -9.33228195e-01,  -9.27737653e-01,  -9.32526290e-01,
                         -9.34808433e-01,  -9.29160178e-01,  -9.31387007e-01,
                         -9.27579165e-01,  -9.32416797e-01,  -9.30699289e-01,
                         -9.39959705e-01,  -9.34253573e-01,  -9.33217227e-01,
                         -9.31464970e-01,  -9.33012962e-01,  -9.24123406e-01,
                         -9.34436083e-01,  -9.33543742e-01,  -9.29965436e-01,
                         -9.26007867e-01,  -9.32458162e-01,  -9.30177271e-01,
                         -9.41364825e-01,  -9.35982823e-01,  -9.34843898e-01,
                         -9.32480156e-01,  -9.28139150e-01,  -9.33689773e-01,
                         -9.31684315e-01,  -9.26988840e-01,  -9.29719388e-01,
                         -9.36372280e-01,  -9.28342521e-01,  -9.31621850e-01,
                         -9.30850983e-01,  -9.30568337e-01,  -9.20997620e-01,
                         -9.18521941e-01,  -9.36456978e-01,  -9.27148283e-01,
                         -9.31187749e-01,  -9.23940957e-01,  -9.33771431e-01,
                         -9.28692400e-01,  -9.36455548e-01,  -9.30654466e-01,
                         -9.27583098e-01,  -9.23140764e-01,  -9.27813590e-01,
                         -9.26189661e-01,  -9.32612538e-01,  -9.26274300e-01,
                         -9.30211306e-01,  -9.33621585e-01,  -9.29338694e-01,
                         -9.23783422e-01,  -9.32301044e-01,  -9.28371966e-01,
                         -9.24948335e-01,  -9.37525511e-01,  -9.29659426e-01,
                         -9.36006129e-01,  -9.34186816e-01,  -9.27997708e-01,
                         -9.37964618e-01,  -9.39006507e-01,  -9.34260547e-01,
                         -9.34433758e-01,  -9.33736265e-01,  -9.33064401e-01,
                         -9.33475912e-01,  -9.38452363e-01,  -9.37277794e-01,
                         -9.37156796e-01,  -9.35612798e-01,  -9.33160961e-01,
                         -9.30357099e-01,  -9.29499865e-01,  -9.32665110e-01,
                         -9.27894235e-01,  -9.33598757e-01,  -9.32732761e-01,
                         -9.36516106e-01,  -9.25694764e-01,  -9.33036804e-01,
                         -9.32328105e-01,  -9.34704542e-01,  -9.35812056e-01,
                         -9.26913679e-01,  -9.29398239e-01,  -9.23817217e-01,
                         -9.35630322e-01,  -9.39135671e-01,  -9.35602069e-01,
                         -9.41090941e-01,  -9.34308410e-01,  -9.40060496e-01,
                         -9.29902911e-01,  -9.36168432e-01,  -9.27700043e-01,
                         -9.48583126e-01,  -9.37822104e-01,  -9.35706377e-01,
                         -9.40263391e-01,  -9.32651103e-01,  -9.33751702e-01,
                         -9.37350929e-01,  -9.35755968e-01,  -9.40775931e-01,
                         -9.41211700e-01,  -9.38952923e-01,  -9.40186679e-01,
                         -9.43808019e-01,  -9.34022903e-01,  -9.34230685e-01,
                         -9.33599889e-01,  -9.35214937e-01,  -9.34118688e-01,
                         -9.33359385e-01,  -9.30852771e-01,  -9.39121068e-01,
                         -9.37670887e-01,  -9.31154132e-01,  -9.34858799e-01,
                         -9.39983964e-01,  -9.34933960e-01,  -9.29580986e-01,
                         -9.35187101e-01,  -9.37861502e-01,  -9.30891931e-01,
                         -9.28176343e-01,  -9.31718230e-01,  -9.33251917e-01,
                         -9.37146127e-01,  -9.34437513e-01,  -9.30362880e-01,
                         -9.26394045e-01,  -9.34821606e-01,  -9.35691953e-01,
                         -9.38913703e-01,  -9.33807254e-01,  -9.39074457e-01,
                         -9.37485695e-01,  -9.39398706e-01,  -9.41426694e-01,
                         -9.36812043e-01,  -9.26438630e-01,  -9.33847249e-01,
                         -9.27616954e-01,  -9.23339069e-01,  -9.30216908e-01,
                         -9.32837546e-01,  -9.34180796e-01,  -9.37040150e-01,
                         -9.42409396e-01,  -9.37528372e-01,  -9.35556054e-01,
                         -9.33634698e-01,  -9.35342789e-01,  -9.33962166e-01,
                         -9.33664620e-01,  -9.31818008e-01,  -9.25665140e-01,
                         -9.30001438e-01,  -9.31490362e-01,  -9.28500772e-01,
                         -9.26989019e-01,  -9.32990015e-01,  -9.28018153e-01,
                         -9.31815386e-01,  -9.33653891e-01,  -9.35074985e-01,
                         -9.26699519e-01,  -9.21829700e-01,  -9.26907420e-01,
                         -9.23931062e-01,  -9.33582366e-01,  -9.30215955e-01,
                         -9.28626955e-01,  -9.35353875e-01,  -9.27865803e-01,
                         -9.36516881e-01,  -9.34506714e-01,  -9.28889513e-01,
                         -9.32114959e-01,  -9.33143675e-01,  -9.30731118e-01,
                         -9.31404293e-01,  -9.32570279e-01,  -9.34130669e-01,
                         -9.36206818e-01,  -9.37329113e-01,  -9.34212089e-01,
                         -9.34775949e-01,  -9.36818004e-01,  -9.34541285e-01,
                         -9.25571561e-01,  -9.26134706e-01,  -9.29906011e-01,
                         -9.28588629e-01,  -9.26636159e-01,  -9.34389830e-01,
                         -9.28526521e-01,  -9.27645326e-01,  -9.29009795e-01,
                         -9.24002469e-01,  -9.29208934e-01,  -9.33851898e-01,
                         -9.34349716e-01,  -9.29629326e-01,  -9.33122516e-01,
                         -9.31905270e-01,  -9.22856569e-01,  -9.26460922e-01,
                         -9.17734087e-01,  -9.32617307e-01,  -9.31662142e-01,
                         -9.29843605e-01,  -9.31052446e-01,  -9.38015521e-01,
                         -9.29412901e-01,  -9.39136565e-01,  -9.38908458e-01,
                         -9.30866599e-01,  -9.31956768e-01,  -9.35901463e-01,
                         -9.39481556e-01,  -9.29716527e-01,  -9.35475409e-01,
                         -9.27623570e-01,  -9.32378471e-01,  -9.30570245e-01,
                         -9.31926787e-01,  -9.31275129e-01,  -9.32289660e-01,
                         -9.33239579e-01,  -9.23736691e-01,  -9.24283206e-01,
                         -9.29024756e-01,  -9.34965432e-01,  -9.36447084e-01,
                         -9.36015427e-01,  -9.25212502e-01,  -9.34347570e-01,
                         -9.36889470e-01,  -9.40963984e-01,  -9.25601780e-01,
                         -9.34181333e-01,  -9.29045141e-01,  -9.29044187e-01,
                         -9.27037120e-01,  -9.30853665e-01,  -9.28169549e-01,
                         -9.33033466e-01,  -9.23111141e-01,  -9.23542082e-01,
                         -9.26332951e-01,  -9.32443202e-01,  -9.39022481e-01,
                         -9.42428768e-01,  -9.43711996e-01,  -9.32320774e-01,
                         -9.31506872e-01,  -9.36984360e-01,  -9.32193816e-01,
                         -9.30374384e-01,  -9.30237651e-01,  -9.37252045e-01,
                         -9.31800306e-01,  -9.29274440e-01,  -9.30706739e-01,
                         -9.29877341e-01,  -9.28059757e-01,  -9.33011532e-01,
                         -9.36021745e-01,  -6.31311489e-03,  -5.74854854e-03,
                          5.13565610e-04,  -4.43079649e-03,   1.57099660e-03,
                          7.08774969e-05,  -5.69757482e-04,   3.54705588e-03,
                          8.60267202e-04,  -3.78105487e-03,   3.16455867e-03,
                         -1.05315493e-03,  -2.01653317e-03,   3.83216678e-03,
                          5.73000964e-03,   6.32519484e-04,   1.12197688e-02,
                         -2.01405201e-04,   2.63241259e-03,  -2.15573772e-03,
                         -5.25444339e-04,   1.29933143e-02,   2.34010792e-03,
                          4.79801930e-03,  -1.61955808e-03,  -2.22780020e-03,
                         -2.95602204e-03,   3.78492917e-03,   4.19561256e-04,
                         -3.09450581e-04,   4.83904034e-03,  -6.90927729e-03,
                          1.26026385e-03,   8.08434561e-05,   6.17522048e-04,
                          1.92694343e-03,  -1.16151222e-03,  -8.41204356e-03,
                          2.20930995e-03,   1.92552956e-03,  -5.26569132e-03,
                          1.57201535e-03,   3.42042325e-03,   5.77377528e-03,
                          5.84921276e-04,   2.19142251e-03,   2.51495559e-03,
                          1.94689608e-03,   5.62307308e-04,   8.44553206e-03,
                          1.25541259e-03,   2.01043440e-03,   1.73296768e-03,
                         -4.73066233e-03,  -1.08058555e-02,  -1.02831833e-02,
                         -5.94890723e-03,  -4.92853997e-03,  -1.00130560e-02,
                         -4.09978535e-03,   1.80198089e-03,  -3.99979996e-03,
                         -3.36049567e-03,  -6.68897294e-04,   4.46485967e-04,
                         -7.28285499e-03,  -9.81047284e-03,  -1.69678382e-03,
                         -2.01692805e-03,  -7.99265574e-04,  -1.20826485e-03,
                         -5.19608904e-04,   1.67318573e-03,  -2.42318283e-03,
                         -4.44300100e-03,   2.03250768e-03,   1.69678382e-03,
                         -2.33134790e-03,  -1.04862517e-02,  -8.26377422e-03,
                         -1.20974379e-02,  -4.67672292e-03,  -3.52673605e-03,
                         -9.89714451e-03,  -1.84067339e-03,   7.22670462e-04,
                         -3.92754358e-04,  -8.69246293e-03,  -1.03857676e-02,
                         -1.10048288e-03,  -4.12318250e-03,  -4.07852978e-03,
                          4.32295911e-03,   4.39300481e-03,  -5.18154213e-03,
                         -3.73581308e-03,  -3.93367000e-03,  -6.32942934e-03,
                         -3.21770110e-03,   1.97420202e-04,  -2.04855157e-03,
                         -1.15386094e-03,  -8.59712774e-04,  -2.30657146e-03,
                          1.03307050e-03,  -2.84566893e-03,  -1.25076913e-03,
                         -5.80036733e-03,  -1.12952827e-03,  -5.04098600e-04,
                         -3.06932768e-03,  -2.00051675e-03,  -3.71922855e-03,
                         -1.00462115e-03,  -6.04811590e-04,  -8.76401260e-04,
                         -7.23624136e-03,   1.82034646e-03,   1.30687794e-03,
                         -5.05262928e-04,  -2.51525361e-03,   8.10068008e-03,
                          3.51808686e-03,   4.94669750e-03,   2.57813348e-03,
                          7.72381760e-03,  -3.95143963e-03,   2.28865631e-03,
                          4.82522091e-03,   5.27316239e-03,   3.94823076e-03,
                          3.58335068e-03,   7.80208316e-03,   1.01347826e-02,
                          1.00905458e-02,   2.37645791e-03,   3.68129835e-03,
                          1.25288294e-04,  -3.33900447e-03,  -4.10080422e-04,
                         -3.31675773e-03,  -1.81895343e-03,  -2.74521211e-04,
                         -2.93105864e-03,  -3.98390880e-03,  -2.44102883e-03,
                          1.84167142e-03,  -4.28300518e-05,  -3.02295620e-03,
                          2.08266327e-04,   3.05013033e-03,   7.41562864e-04,
                         -1.54266495e-03,   1.03192707e-03,  -2.53230263e-03,
                         -2.23275553e-03,  -6.02254295e-04,  -1.10075308e-03,
                          5.95774327e-04,   1.45077438e-03,  -3.82358697e-03,
                         -2.11469573e-03,  -1.48435240e-03,  -1.93153135e-03,
                         -1.05238566e-03,   2.04299344e-03,   3.93255427e-03,
                          4.60702367e-03,  -1.98125723e-03,   4.38727345e-03,
                          4.08135029e-03,   1.39616954e-03,   7.53649510e-04,
                         -3.30813625e-03,  -4.58436087e-03,  -1.92248018e-03,
                         -1.66331686e-03,  -4.75127343e-03,  -1.30362762e-03,
                          2.79162545e-03,  -6.47058105e-03,  -1.78430136e-03,
                         -2.15598708e-03,   3.66844935e-03,  -5.13230823e-03,
                          3.84448236e-03,   2.58567365e-04,  -1.17717497e-03,
                          1.37708313e-03,  -2.68987287e-03,   9.47877578e-03,
                         -7.18117168e-04,   2.79518054e-03,   3.97163490e-03,
                          4.29277727e-03,  -6.80726161e-03,  -4.79731243e-04,
                          3.12908180e-03,   2.46653974e-04,  -3.43865016e-03,
                          4.07359516e-03,   4.46542772e-03,   2.23888899e-03,
                          2.38829525e-03,  -2.23483471e-03,  -1.10107195e-03,
                         -3.90475616e-03,  -4.64807265e-03,  -2.52719480e-03,
                         -1.35490578e-03,   4.26993426e-03,  -2.73438008e-03,
                         -1.36945282e-05,   1.64330180e-03,   2.69442610e-03,
                          1.69885607e-04,  -4.49174957e-04,  -4.12214984e-04,
                         -1.32987997e-03,  -4.19295114e-03,  -1.70000654e-03,
                         -5.33045642e-03,  -2.01666472e-03,   1.04368106e-03,
                         -1.10732322e-03,  -1.34586159e-03,  -2.46509816e-03,
                          5.25125535e-04,   2.28011119e-03,   2.33030831e-03,
                          1.31016993e-03,  -6.24105916e-04,  -1.69407402e-04,
                         -1.50569808e-03,  -3.72822426e-04,   9.26958746e-04,
                          1.98508278e-04,  -1.81345071e-03,  -3.65343108e-03,
                          3.83176492e-03,   3.22348112e-03,  -5.31457178e-03,
                         -3.74355447e-03,  -3.04152281e-03,  -1.67216698e-03,
                          1.19757815e-03,  -7.00504892e-03,  -5.24592586e-03,
                          5.72582334e-03,  -2.01170961e-03,   5.68715157e-03,
                          1.49974483e-04,   3.70084922e-06,   4.77137882e-03,
                          2.82354001e-03,  -8.70711403e-04,  -2.70640873e-03,
                         -5.40777901e-03,  -5.24182979e-04,  -5.24919713e-03,
                         -5.21347066e-03,  -3.99589119e-03,  -2.76257982e-03,
                         -4.70063271e-04,   3.18268873e-03,   5.40864537e-04,
                         -3.99670913e-04,  -4.43641003e-03,   6.02455286e-04,
                          2.23183376e-03,  -2.93681771e-03,   2.95915455e-03,
                         -8.77690327e-04,  -4.53665882e-04,  -5.77415631e-04,
                         -3.39178671e-03,  -2.15936219e-03,   2.99738976e-03,
                         -3.19082499e-03,  -1.00249355e-03,  -3.86521127e-03,
                         -1.22945814e-04,  -2.08759075e-03,   1.25027716e-03,
                          4.52279783e-05,   5.46396431e-03,   8.39191780e-04,
                         -1.27711170e-03,   5.85621281e-04,  -1.55976240e-03,
                         -7.16286199e-03,  -3.23258084e-03,  -6.05788809e-05,
                          8.18670786e-04,   9.37201898e-04,  -6.88289339e-03,
                         -1.57189753e-03,   4.76528658e-03,  -1.29120133e-03,
                         -3.27433669e-03,   1.17684924e-03,   1.04616210e-03,
                          3.95784341e-03,   4.12361231e-03,   2.10748101e-03,
                          1.24467735e-03,   2.43833289e-04,  -1.07079977e-03,
                         -3.02915182e-03,   2.98964849e-04,  -2.94602825e-03,
                         -1.03838618e-04,   5.28466015e-04,  -1.38386118e-03,
                         -9.80669516e-04,   5.60446456e-03,   2.28551007e-03,
                         -9.49607405e-04,   1.54692028e-03,   1.22278417e-03,
                         -3.75164906e-03,  -6.26330613e-04,   6.13444857e-03,
                         -6.50805421e-03,  -5.59625216e-03,  -1.13029056e-03,
                         -2.92207667e-04,  -2.60205730e-03,   2.04139249e-03,
                         -1.66850083e-03,   3.22472879e-05,  -6.06752117e-04,
                          2.93870992e-03,   2.69288750e-04,   4.67326446e-03,
                         -3.56219895e-03,  -2.82207075e-05,  -1.40011997e-03,
                         -2.24904204e-03,  -1.88211736e-03,  -2.95701320e-03,
                          3.61213955e-04,   2.77120125e-04,  -6.69028959e-04,
                          2.97547574e-03,   1.20110577e-03,   5.52226976e-03,
                          6.80167554e-03,   5.49870636e-03,  -1.50447141e-03,
                          2.91075255e-03,   1.82279292e-03,  -2.39973026e-03,
                         -3.33364028e-03,  -4.25103493e-03,  -6.71282737e-03,
                         -2.87051429e-04,  -1.13060244e-03,   6.42423052e-04,
                         -4.84983111e-03,  -3.77336913e-03,   2.56330939e-03,
                         -4.94630262e-03,  -1.86486065e-03,  -4.48038382e-03,
                          3.21267662e-03,  -3.07047809e-03,   2.46702490e-04,
                          6.36754651e-03,  -3.01757798e-04,  -5.30703133e-03,
                         -2.57555535e-03,   6.04735396e-04,  -1.12847483e-03,
                         -3.01816035e-03,   2.34262366e-03,  -2.15394958e-03,
                          2.47159204e-03,   3.59450863e-03,   3.17843340e-04,
                          2.36541079e-03,   7.69970648e-04,  -4.62980388e-04,
                         -1.54500056e-04,   1.35002681e-03,  -1.45044178e-03,
                         -4.68498375e-03,  -3.41449771e-03,  -2.11847271e-03,
                         -1.11099624e-03,   3.93827865e-03,   6.83451211e-03,
                          1.92263964e-04,  -1.95519882e-03,   3.08401324e-03,
                          3.94119648e-03,   3.18534998e-03,  -1.63395959e-03,
                          2.86544138e-03,  -1.01923046e-03,   8.03315081e-03,
                          9.71795805e-03,   2.44633760e-03,  -4.10383986e-03,
                          3.86072719e-03,   3.12257413e-04,  -4.53633303e-03,
                         -9.48041119e-03,  -1.02481917e-02,  -7.68748159e-03,
                         -2.84949434e-03,   8.41881521e-03,  -7.48082297e-03,
                          9.08891112e-03,  -9.11047868e-03,   7.72591773e-03,
                          2.47575017e-03,  -5.63234603e-03,  -4.62850090e-03,
                         -1.82242692e-02,  -5.60585083e-03,  -1.39462412e-03,
                          7.12329615e-03,  -2.19774991e-03,   9.40209068e-03,
                          8.01585242e-03,  -2.14165496e-03,   3.29401903e-03,
                          1.45180710e-03,   8.13423097e-03,   5.92686143e-03,
                          7.22265756e-03,   1.02113010e-02,   6.75390428e-03,
                          3.51537694e-03,  -1.14421382e-05,  -5.41100185e-03,
                         -1.60898436e-02,  -6.39702845e-03,  -1.08419634e-04,
                         -7.80048920e-03,  -1.49040474e-02,  -2.04363116e-03,
                         -8.76990380e-04,  -1.03249047e-02,   6.16922555e-03,
                          9.84826405e-03,   1.02318777e-03,   1.37864463e-02,
                          1.10639101e-02,   5.60249668e-03,   5.30348998e-03,
                         -5.77793317e-03,  -8.56626686e-03,  -1.32331001e-02,
                         -5.54718485e-04,  -1.13464985e-02,  -1.23074022e-03,
                          8.48077983e-03,   8.94441153e-04,   3.79731366e-03,
                          7.95325637e-03,   2.97745079e-04,  -9.87685937e-03,
                          1.07152748e-03,   7.24044815e-03,   3.43954423e-03,
                         -7.44702294e-04,   1.72205437e-02,   1.00543480e-02,
                          1.42902117e-02,  -4.24466608e-03,   5.38255228e-03,
                         -5.09812078e-03,   9.82704386e-03,   3.89020913e-03,
                         -4.33391612e-03,  -1.20076613e-04,  -8.03972781e-03,
                         -1.03073362e-02,   6.06318982e-03,  -1.04291039e-02,
                         -5.17020421e-03,  -3.16228543e-04,   4.12466563e-03,
                          1.31549798e-02,   1.83105264e-02,   1.57786403e-02,
                          5.78110060e-03,   1.82410628e-02,   1.56524442e-02,
                          1.39560476e-02,  -7.43023772e-03,   8.98462906e-03,
                          1.21163717e-02,   1.40425460e-02,   2.49352679e-03,
                          2.31564008e-02,   8.11171345e-03,   1.21242311e-02,
                          5.01838606e-03,  -8.71647708e-03,  -2.09108163e-02,
                         -1.76366176e-02,  -3.23102158e-03,  -6.77110534e-03,
                          8.63701943e-03,   1.26157645e-02,   5.16299624e-03,
                          3.52403112e-02,   1.92203801e-02,   1.31987943e-03,
                          2.37369407e-02,   6.86594844e-03,  -5.87653276e-03,
                         -8.70087650e-03,  -7.34431436e-04,  -4.36922675e-03,
                         -2.16670651e-02,  -1.19478097e-02,  -1.19734732e-02,
                         -9.63757280e-03,  -1.09828869e-02,   1.39526585e-02,
                          4.44878777e-03,   1.03328265e-02,  -1.69374840e-03,
                          1.60617344e-02,  -3.49444011e-03,  -1.84520110e-02,
                          2.23503280e-02,   2.03538034e-02,   2.87727639e-02,
                          2.34839190e-02,   2.50079259e-02,   4.44065174e-03,
                         -1.34708965e-02,  -1.05650369e-02,  -3.75869945e-02,
                          1.37284175e-02,  -5.04283654e-03,   5.17718308e-03,
                          7.12091196e-03,  -4.97591635e-03,   9.14411899e-03,
                          2.51754071e-03,   5.48829697e-03,  -9.46214020e-01,
                         -9.34569716e-01,  -9.47038591e-01,  -9.06114042e-01,
                         -9.23231721e-01,  -9.54277933e-01,  -9.53477979e-01,
                         -9.33930993e-01,  -9.29376066e-01,  -9.38577354e-01,
                         -9.42084908e-01,  -9.40243185e-01,  -4.22370154e-03,
                         -2.97013926e-03,  -6.61149097e-04,  -1.00661991e-02,
                         -1.09209701e-04,   8.07653461e-03,   2.62418762e-02,
                          2.02310318e-03,   1.49344439e-02,  -7.65915681e-03,
                         -2.47071106e-02,   4.97133529e-04,   2.47128848e-02,
                          1.43414419e-02,   2.87919817e-03,  -2.32124180e-02,
                          1.23264194e-02,  -2.47605797e-02,   7.95967411e-03,
                         -3.45856813e-03,  -9.37107671e-03,   1.05236834e-02,
                         -3.72431544e-03,  -2.91448515e-02,  -1.58750825e-02,
                          2.08945508e-04,  -5.08610334e-04,  -1.99488867e-02,
                          4.38218657e-03,   2.05858201e-02,  -2.42255367e-02,
                         -2.18144823e-02,  -6.04370143e-03,  -1.44941956e-02,
                          1.03615178e-02,  -3.34060453e-02,  -1.84175521e-02,
                         -3.33601125e-02,  -3.69962715e-02,  -3.92021574e-02,
                         -2.04642601e-02,  -2.12026704e-02,  -2.70252638e-02,
                         -7.89604557e-04,  -2.45164335e-02,  -9.18697697e-05,
                         -2.66934969e-02,   2.79204105e-03,  -3.70341055e-02,
                         -3.50376032e-02,  -9.42579936e-03,  -1.48590682e-02,
                         -1.60644297e-02,  -2.30294280e-02,  -1.53603600e-02,
                         -1.84802655e-02,  -1.07534342e-02,  -1.08058071e-02,
                         -8.53632018e-03,  -5.42405853e-03,  -7.14837015e-03,
                         -2.39681620e-02,  -3.56450602e-02,  -2.62778997e-03,
                         -9.36760485e-01,  -9.49937284e-01,  -9.47498679e-01,
                         -9.49716389e-01,  -9.37242031e-01,  -9.36135828e-01,
                         -9.25542593e-01,  -9.19346273e-01,  -9.33047533e-01,
                         -9.32448745e-01,  -9.38194931e-01,  -9.44748759e-01,
                         -9.40693736e-01,  -9.49123919e-01,  -9.32221889e-01,
                         -9.33476448e-01,  -9.33889747e-01,  -9.37855244e-01,
                         -9.19705868e-01,  -9.40690219e-01,  -9.58483875e-01,
                         -9.30305958e-01,  -9.45272684e-01,  -9.19576824e-01,
                         -9.03678119e-01,  -9.15127456e-01,  -9.18628514e-01,
                         -9.32816207e-01,  -9.59733784e-01,  -9.27784741e-01,
                         -9.37250793e-01,  -9.28462863e-01,  -9.21168566e-01,
                         -8.95788252e-01,  -9.18642819e-01,  -9.29461539e-01,
                         -9.41050351e-01,  -9.41353738e-01,  -9.19830799e-01,
                         -9.27915931e-01,  -9.32752907e-01,  -9.32693899e-01,
                         -9.19719636e-01,  -9.07288551e-01,  -9.31912422e-01,
                         -9.32860017e-01,  -9.25196052e-01,  -9.33926761e-01,
                         -9.31525052e-01,  -9.18152332e-01,  -9.21041250e-01,
                         -9.25509930e-01,  -9.11188781e-01,  -9.06508207e-01,
                         -9.20803964e-01,  -9.28308666e-01,  -9.43054438e-01,
                         -9.35831904e-01,  -9.39534009e-01,  -9.46331918e-01,
                         -9.44581985e-01,  -9.39500153e-01,  -9.61981356e-01,
                         -9.54514325e-01,  -9.33484554e-01,  -9.16847110e-01,
                         -9.21054006e-01,  -8.95778358e-01,  -9.25845325e-01,
                         -9.45254862e-01,  -9.27129984e-01,  -9.36457336e-01,
                         -9.32265997e-01,  -9.40129459e-01,  -9.39546287e-01,
                         -9.28166330e-01,  -9.15212750e-01,  -9.18639302e-01,
                         -9.18012798e-01,  -9.27392006e-01,  -9.14865851e-01,
                         -9.27575290e-01,  -9.32552338e-01,  -9.35986936e-01,
                         -9.14696097e-01,  -9.38757896e-01,  -9.34792459e-01,
                         -9.24118876e-01,  -9.42179084e-01,  -9.27884519e-01,
                         -9.11810279e-01,  -9.04510975e-01,  -8.98445189e-01,
                         -9.13283288e-01,  -9.04879808e-01,  -9.20732915e-01,
                         -9.27107334e-01,  -9.18488443e-01,  -9.22070980e-01,
                         -9.18089926e-01,  -9.37209666e-01,  -9.39825475e-01,
                         -9.47981775e-01,  -9.32031155e-01,  -9.23679590e-01,
                         -9.17862952e-01,  -9.20775831e-01,  -9.44539070e-01,
                         -9.18044090e-01,  -9.21340704e-01,  -9.17064428e-01,
                         -9.24181819e-01,  -9.36076522e-01,  -9.27341759e-01,
                         -9.54545319e-01,  -9.45321143e-01,  -9.46900666e-01,
                         -9.43493962e-01,  -9.53953505e-01,  -9.26586270e-01,
                         -9.54498589e-01,  -9.33667183e-01,  -9.53847945e-01,
                         -9.21266317e-01,  -9.06229317e-01,  -9.29915428e-01,
                         -9.34856236e-01,  -9.11353111e-01,  -9.31298971e-01,
                         -9.22186077e-01,  -9.33599293e-01,  -9.37192500e-01,
                         -9.29319143e-01,  -9.20844674e-01,  -9.27870810e-01,
                         -9.46054339e-01,  -9.33414161e-01,  -9.50785458e-01,
                         -9.32105541e-01,  -9.41324115e-01,  -9.32169676e-01,
                         -9.40629184e-01,  -9.39346015e-01,  -9.36444342e-01,
                         -9.18226123e-01,  -9.15260434e-01,  -9.29367900e-01,
                         -9.28484619e-01,  -9.41406310e-01,  -9.37629521e-01,
                         -9.40912724e-01,  -9.32194293e-01,  -9.35197055e-01,
                         -9.38964784e-01,  -9.37638462e-01,  -9.41271782e-01,
                         -9.04971182e-01,  -9.23410535e-01,  -9.30519342e-01,
                         -9.22384799e-01,  -9.27276611e-01,  -9.42434788e-01,
                         -9.35859501e-01,  -9.24176633e-01,  -9.38409686e-01,
                         -9.23365474e-01,  -9.23720539e-01,  -9.35151815e-01,
                         -9.25522566e-01,  -9.37265992e-01,  -9.41320479e-01,
                         -9.28972423e-01,  -9.27234590e-01,  -9.29198921e-01,
                         -9.27571118e-01,  -9.40201759e-01,  -9.01392877e-01,
                         -9.07045662e-01,  -9.13872957e-01,  -9.15842772e-01,
                         -9.26064849e-01,  -9.24873769e-01,  -9.29938257e-01,
                         -9.31238770e-01,  -9.09201205e-01,  -9.48229313e-01,
                         -9.03980553e-01,  -9.41327155e-01,  -9.22147989e-01,
                         -9.19323325e-01,  -9.40895915e-01,  -9.22900558e-01,
                         -9.37529802e-01,  -9.29770291e-01,  -9.44390833e-01,
                         -9.25258398e-01,  -9.40610826e-01,  -9.40489948e-01,
                         -9.18730855e-01,  -9.17901754e-01,  -9.44098294e-01,
                         -9.33982432e-01,  -9.24450934e-01,  -9.19157326e-01,
                         -9.33978856e-01,  -9.30960000e-01,  -9.37528372e-01,
                         -9.29122508e-01,  -9.20992017e-01,  -9.08744395e-01,
                         -9.20540392e-01,  -9.36002910e-01,  -9.38476980e-01,
                         -9.16591883e-01,  -9.20926154e-01,  -9.14561391e-01,
                         -9.23900247e-01,  -9.30761397e-01,  -9.19819295e-01,
                         -9.25852537e-01,  -9.16011453e-01,  -9.29563284e-01,
                         -9.34865952e-01,  -9.37577724e-01,  -9.44609404e-01,
                         -9.52312469e-01,  -9.35558677e-01,  -9.25598025e-01,
                         -9.55371082e-01,  -9.34830248e-01,  -9.25839126e-01,
                         -9.23257589e-01,  -9.25448775e-01,  -9.28827941e-01,
                         -9.20457900e-01,  -9.32887435e-01,  -9.17126656e-01,
                         -9.30532634e-01,  -9.27475572e-01,  -9.24733162e-01,
                         -9.16504920e-01,  -9.43721414e-01,  -9.29544032e-01,
                         -9.23882604e-01,  -9.38723266e-01,  -9.11188185e-01,
                         -9.15607810e-01,  -9.04499412e-01,  -9.52324688e-01,
                         -9.20515656e-01,  -9.17483211e-01,  -9.16736364e-01,
                         -9.34310019e-01,  -9.24311876e-01,  -9.38806236e-01,
                         -9.39167142e-01,  -9.41233754e-01,  -9.24820304e-01,
                         -9.05687869e-01,  -9.36441898e-01,  -9.33507383e-01,
                         -9.21448588e-01,  -9.29600835e-01,  -9.25902545e-01,
                         -9.32330191e-01,  -9.35294569e-01,  -9.41316366e-01,
                         -9.22483504e-01,  -9.23455298e-01,  -9.32583034e-01,
                         -9.26592231e-01,  -9.26898599e-01,  -9.49943483e-01,
                         -9.44021702e-01,  -9.23818767e-01,  -9.21734095e-01,
                         -9.28664625e-01,  -9.14177358e-01,  -9.23338592e-01,
                         -9.23241973e-01,  -9.41797972e-01,  -9.36014116e-01,
                         -9.45981026e-01,  -9.37480450e-01,  -9.39763725e-01,
                         -9.30039525e-01,  -9.30858612e-01,  -9.43637013e-01,
                         -9.33634162e-01,  -9.18784320e-01,  -9.46103334e-01,
                         -9.41598713e-01,  -9.24287796e-01,  -9.55066323e-01,
                         -9.28534031e-01,  -9.27316606e-01,  -9.21354830e-01,
                         -9.30251837e-01,  -9.36910748e-01,  -9.35859859e-01,
                         -9.07565594e-01,  -9.14614737e-01,  -9.16622102e-01,
                         -9.11580265e-01,  -9.28715467e-01,  -9.14186656e-01,
                         -9.15029466e-01,  -9.34852540e-01,  -9.19821262e-01,
                         -9.28807914e-01,  -9.26553130e-01,  -9.37940657e-01,
                         -9.35539365e-01,  -9.34962034e-01,  -9.25646722e-01,
                         -9.07224596e-01,  -9.48479652e-01,  -9.54865396e-01,
                         -9.28418815e-01,  -9.28510189e-01,  -9.42923367e-01,
                         -9.07742560e-01,  -9.09813881e-01,  -9.15179908e-01,
                         -9.37429249e-01,  -9.11921859e-01,  -9.10352886e-01,
                         -9.25256968e-01,  -9.20001268e-01,  -9.05399680e-01,
                         -9.06068981e-01,  -9.19321835e-01,  -9.31789219e-01,
                         -9.25597370e-01,  -9.00119603e-01,  -9.27491605e-01,
                         -9.28875268e-01,  -9.35368955e-01,  -9.30471420e-01,
                         -9.21072423e-01,  -9.15513039e-01,  -9.27056313e-01,
                         -9.21148419e-01,  -9.18437719e-01,  -9.28153634e-01,
                         -9.25746322e-01,  -9.35599267e-01,  -9.38714981e-01,
                         -9.27504838e-01,  -9.25439417e-01,  -9.27142620e-01,
                         -9.11927938e-01,  -9.34793770e-01,  -9.50525761e-01,
                         -9.55008030e-01,  -9.33021724e-01,  -9.41253185e-01,
                         -9.60451007e-01,  -9.30613935e-01,  -9.50545490e-01,
                         -9.17294741e-01,  -9.20011103e-01,  -9.53871965e-01,
                         -9.25075412e-01,  -1.51451286e-02,   7.81422481e-03,
                         -2.44651567e-02,  -4.66871122e-03,   7.30356341e-03,
                         -1.85249951e-02,   4.14407067e-03,  -2.97780782e-02,
                          1.75673212e-03,   1.52934194e-02,   3.38871591e-02,
                         -9.11797769e-03,  -7.86738843e-03,   3.85670061e-03,
                         -4.52328986e-03,   1.06494362e-03,  -1.09440209e-02,
                         -9.29425936e-03,  -1.42603833e-02,   1.21809496e-02,
                          6.68620784e-03,  -9.15829837e-03,  -6.22241618e-03,
                          8.56628083e-03,   2.56102229e-03,   1.66467372e-02,
                          1.78024489e-02,   1.00368969e-02,   2.03969870e-02,
                          2.90025007e-02,  -3.60990106e-03,   3.78718833e-03,
                          1.24683343e-02,  -4.73669870e-03,  -1.43648321e-02,
                         -1.49787012e-02,  -3.50597920e-03,   1.37307739e-03,
                          8.95720534e-03,  -2.46321317e-04,  -6.82121934e-03,
                         -2.32786871e-03,  -4.14301036e-03,  -1.16833169e-02,
                          1.28100661e-03,   5.63384965e-03,  -1.60917006e-02,
                         -4.33114404e-03,  -1.38338152e-02,  -1.36295827e-02,
                          3.09923245e-03,  -1.64441336e-02,  -2.73387413e-03,
                          3.09921859e-04,  -1.26969414e-02,   3.00422311e-03,
                         -8.78091622e-03,  -3.36051993e-02,  -4.28751670e-03,
                          1.16450619e-03,  -3.05781830e-02,   5.71041694e-03,
                          1.79403170e-03,   4.06965893e-03,   2.63861530e-02,
                         -1.54047494e-03,   4.75091301e-03,   4.50601242e-03,
                         -4.49861772e-03,  -5.84045984e-03,  -1.50521854e-02,
                         -2.18335483e-02,   1.10347886e-02,  -1.33641129e-02,
                         -7.40734674e-03,  -1.05136270e-02,   3.56896855e-02,
                          5.51414024e-03,   1.05143068e-02,   6.00956194e-03,
                          4.43050545e-03,  -6.42219977e-03,   4.43311816e-04,
                         -3.42444982e-03,  -3.56076425e-03,  -5.97582478e-03,
                          4.20927908e-03,  -2.11842431e-04,  -1.69166643e-02,
                         -1.79816559e-02,  -1.67560857e-02,   4.15558927e-03,
                          1.23688057e-02,  -8.23675934e-03,   1.43875704e-05,
                         -1.09526487e-02,   1.49680497e-02,   8.96179304e-03,
                          1.20122358e-02,  -1.90773364e-02,   5.10193920e-03,
                         -2.06918847e-02,   2.32183225e-02,   1.49231683e-02,
                         -3.53934243e-03,   4.09963308e-03,  -2.64742393e-05,
                         -3.92200612e-03,  -5.05172822e-04,   1.00695249e-02,
                         -6.73460960e-03,  -1.78394094e-03,   6.15932886e-03,
                         -5.70069358e-04,   1.07058771e-02,  -1.35049252e-02,
                          1.00843841e-02,  -9.17952694e-03,   9.65348445e-03,
                          2.65869964e-03,   2.87882406e-02,  -1.53415650e-02,
                          5.57342321e-02,  -3.35568041e-02,   1.12007726e-02,
                         -5.01732575e-03,  -1.76528078e-02,   1.38092060e-02,
                         -8.00351612e-03,  -1.61224436e-02,   5.73985744e-03,
                         -3.08720265e-02,  -9.75672738e-04,   1.99500727e-03,
                         -2.04540864e-02,   2.71022823e-02,  -1.80632211e-02,
                          4.53329086e-03,  -7.26624997e-03,  -1.99658107e-02,
                          5.03226789e-03,   1.56094125e-02,   3.12160375e-03,
                          3.36297601e-02,   1.17320456e-02,   1.09205889e-02,
                         -1.37602556e-02,   1.19505133e-02,   1.81020040e-03,
                         -5.09742089e-03,   2.00672448e-02,   3.88743007e-03,
                         -2.18745833e-03,   1.82781054e-03,   5.49201854e-04,
                          6.23240322e-03,   8.92251148e-04,   1.18077947e-02,
                         -4.40821005e-03,  -2.83631962e-03,  -9.55519034e-04,
                         -1.42376451e-02,   3.02554108e-03,  -3.98431066e-03,
                          1.09982444e-03,   5.90254227e-03,   6.86377240e-03,
                          1.64912604e-02,   5.57467062e-03,   8.60947836e-03,
                         -9.43805277e-03,  -1.68340121e-04,   6.33982476e-03,
                          4.51573590e-03,  -9.91810206e-03,  -8.90422240e-03,
                          5.17711369e-03,  -2.26736604e-03,   1.79015752e-03,
                          2.13249363e-02,   2.47496497e-02,  -1.14440098e-02,
                          9.50851385e-03,  -7.50099029e-03,   1.95562150e-02,
                         -5.32739330e-03,   1.06386244e-02,   4.42376221e-03,
                         -1.67845227e-02,   1.51638547e-02,  -2.57017743e-03,
                         -1.86987687e-02,  -5.30154258e-03,   4.69271140e-03,
                         -1.97227541e-02,   1.20192422e-02,  -1.09014951e-03,
                          1.34825055e-02,  -1.06865689e-02,  -3.84333864e-04,
                          5.47464378e-03,   3.77548975e-04,  -2.07587201e-02,
                          4.69255866e-03,  -8.40042811e-03,   3.61061492e-03,
                          1.16672944e-02,  -3.18427570e-03,   4.28880611e-03,
                         -5.86753665e-03,   4.68592625e-03,  -1.26041635e-03,
                         -3.95606924e-03,   9.50559601e-03,   6.05794368e-03,
                          8.94059986e-03,   5.22803864e-04,   2.30040476e-02,
                          1.70363113e-03,  -4.61906847e-03,   6.09951233e-03,
                         -5.18476497e-03,  -9.27584525e-03,   1.81847811e-02,
                          2.08406448e-02,  -5.43862628e-03,   1.76039413e-02,
                          2.45983806e-03,   3.91470268e-02,  -5.03537944e-03,
                         -1.85811729e-03,  -3.43411067e-03,   8.02058540e-03,
                          1.22225257e-02,  -6.25374867e-03,   1.34654008e-02,
                          8.91190779e-04,   1.57759301e-02,   5.77286026e-03,
                         -6.48169080e-03,   1.13828974e-02,  -3.94430105e-03,
                          2.73073111e-02,   1.45001486e-02,   1.66163966e-02,
                         -3.54464422e-03,  -1.38345221e-02,   2.95756273e-02,
                          3.42580117e-03,  -1.42936977e-02,  -5.59874019e-03,
                          7.44332932e-03,   8.90986342e-03,   1.62209664e-02,
                         -1.39957732e-02,   1.10486913e-02,  -6.95877429e-03,
                          2.00412143e-02,   1.27003510e-02,   4.50175721e-03,
                          1.49551313e-02,   1.06382780e-02,  -2.26718583e-03,
                         -1.63655281e-02,  -7.38945067e-01,  -7.58343518e-01,
                         -7.58812249e-01,  -7.71865249e-01,  -7.57236302e-01,
                         -7.39861250e-01,  -7.68958747e-01,  -7.76003659e-01,
                         -7.60561407e-01,  -7.74678588e-01,  -7.63245702e-01,
                         -7.75131166e-01,  -7.46360004e-01,  -7.43679881e-01,
                         -7.36893654e-01,  -7.54610538e-01,  -7.54195511e-01,
                         -7.73599505e-01,  -7.66268015e-01,  -7.42596209e-01,
                         -7.83796072e-01,  -7.73087800e-01,  -7.52763450e-01,
                         -7.57273018e-01,  -7.51915097e-01,  -7.58838534e-01,
                         -7.47788250e-01,  -7.49466181e-01,  -7.74514616e-01,
                         -7.52607584e-01,  -7.69239426e-01,  -7.58724391e-01,
                         -7.61160314e-01,  -7.67004013e-01,  -7.78457522e-01,
                         -7.46247232e-01,  -7.58453667e-01,  -7.62566030e-01,
                         -7.60818839e-01,  -7.64572740e-01,  -7.51722038e-01,
                         -7.42224753e-01,  -7.57634759e-01,  -7.39964187e-01,
                         -7.54632771e-01,  -7.42713451e-01,  -7.50407338e-01,
                         -7.56774843e-01,  -7.39568412e-01,  -7.56409228e-01,
                         -7.48520434e-01,  -7.36280143e-01,  -7.71105647e-01,
                         -7.44105279e-01,  -7.64679372e-01,  -7.61734903e-01,
                         -7.82623231e-01,  -7.59647131e-01,  -7.53805101e-01,
                         -7.80337751e-01,  -7.51291513e-01,  -7.68646955e-01,
                         -7.67727554e-01,  -7.64175415e-01,  -7.89028585e-01,
                         -7.47803450e-01,  -7.37596154e-01,  -7.52517760e-01,
                         -7.47337937e-01,  -7.43150771e-01,  -7.54447937e-01,
                         -7.50113904e-01,  -7.61426926e-01,  -7.35309780e-01,
                         -7.78759539e-01,  -7.17145622e-01,  -7.41618514e-01,
                         -7.19763875e-01,  -7.79221237e-01,  -7.56464541e-01,
                         -9.32634354e-01,  -9.03991520e-01,  -9.33802247e-01,
                         -9.22900081e-01,  -7.70436704e-01,  -7.29122400e-01,
                         -7.58184254e-01,  -7.57390082e-01,  -7.27793217e-01,
                         -7.36662626e-01,  -7.34048426e-01,  -7.36403465e-01,
                         -7.43087828e-01,  -7.42867351e-01,  -7.16978371e-01,
                         -7.49443412e-01,  -7.46148527e-01,  -7.60202229e-01,
                         -7.44555950e-01,  -7.39454806e-01,  -8.95548642e-01,
                         -9.27382469e-01,  -9.30751204e-01,  -9.38938320e-01,
                         -9.30182159e-01,  -9.20578480e-01,  -9.18025494e-01,
                         -9.30196643e-01,  -9.55395222e-01,  -9.50514197e-01,
                         -9.43457246e-01,  -9.28904533e-01,  -7.79481649e-01,
                         -7.63753772e-01,  -7.31601894e-01,  -7.61203110e-01,
                         -7.44659960e-01,  -7.49364793e-01,  -7.47095287e-01,
                         -7.72412062e-01,  -7.43207872e-01,  -7.56515086e-01,
                         -7.29366124e-01,  -7.54121304e-01,  -7.53564715e-01,
                         -7.46929348e-01,  -7.52367854e-01,  -7.42223084e-01,
                         -9.15202439e-01,  -9.09403622e-01,  -9.31535184e-01,
                         -9.34121490e-01,  -9.09281909e-01,  -9.20053899e-01,
                         -9.39346135e-01,  -9.39074039e-01,  -8.06143820e-01,
                         -7.58314788e-01,  -7.45364726e-01,  -7.38782525e-01,
                         -7.50586867e-01,  -7.64791250e-01,  -7.63366938e-01,
                         -7.71006227e-01,  -7.47434318e-01,  -7.66922653e-01,
                         -7.66613841e-01,  -7.64889359e-01,  -7.73083270e-01,
                         -7.45463550e-01,  -7.49950886e-01,  -7.31387556e-01,
                         -9.00636494e-01,  -8.89503241e-01,  -9.20186400e-01,
                         -9.06247854e-01,  -9.38016951e-01,  -8.94918799e-01,
                         -9.22043800e-01,  -9.09207284e-01,  -9.47087586e-01,
                         -9.32552636e-01,  -9.28795099e-01,  -9.31592703e-01,
                         -9.21795666e-01,  -9.33978558e-01,  -9.32165563e-01,
                         -9.41715479e-01,  -7.40529060e-01,  -7.60159492e-01,
                         -7.37882435e-01,  -7.41263628e-01,  -7.36994982e-01,
                         -7.59083867e-01,  -7.37407029e-01,  -7.41475761e-01,
                         -7.52650082e-01,  -7.11233079e-01,  -7.66982734e-01,
                         -7.19043612e-01,  -7.53033996e-01,  -7.54471242e-01,
                         -7.27122307e-01,  -7.69921601e-01,  -7.47078896e-01,
                         -7.55745828e-01,  -7.30125487e-01,  -7.61990786e-01,
                         -7.46884525e-01,  -7.53327131e-01,  -7.46073067e-01,
                         -7.12939501e-01,  -7.66132891e-01,  -7.39850163e-01,
                         -7.73079276e-01,  -7.81720877e-01,  -7.35908687e-01,
                         -7.50101745e-01,  -7.60115623e-01,  -7.54923999e-01,
                         -7.77524173e-01,  -7.43874907e-01,  -7.42223203e-01,
                         -7.54694045e-01,  -7.69702315e-01,  -7.39466608e-01,
                         -7.47794926e-01,  -7.26846516e-01,  -7.76729822e-01,
                         -7.64172852e-01,  -7.33540237e-01,  -7.92921901e-01,
                         -7.65435159e-01,  -7.95385242e-01,  -7.79428601e-01,
                         -7.59507358e-01,  -3.98236252e-02,  -2.95803044e-02,
                         -8.86831526e-03,   2.79618567e-03,   2.10424177e-02,
                          2.26749089e-02,   2.90681105e-02,  -5.62721025e-03,
                         -7.34374821e-01,  -7.72817552e-01,  -7.67287493e-01,
                         -7.68878460e-01,  -7.62501299e-01,  -7.60584176e-01,
                         -7.91461527e-01,  -7.60993719e-01,  -7.85010517e-01,
                         -7.75456488e-01,  -7.68196702e-01,  -7.76474357e-01,
                         -7.58564711e-01,  -7.76838422e-01,  -7.40769804e-01,
                         -7.67261505e-01,  -7.66784310e-01,  -7.65459716e-01,
                         -7.66029060e-01,  -7.85087407e-01,  -7.52649128e-01,
                         -7.75120139e-01,  -7.72096395e-01,  -7.63578594e-01,
                         -7.40699410e-01,  -7.62221158e-01,  -7.55758226e-01,
                         -7.46414363e-01,  -7.77878344e-01,  -7.45863676e-01,
                         -7.68921316e-01,  -7.64676869e-01,  -7.69629836e-01,
                         -7.46210039e-01,  -7.49012947e-01,  -7.39371717e-01,
                         -7.27736950e-01,  -7.60145485e-01,  -7.42380917e-01,
                         -7.49007881e-01,  -7.79153228e-01,  -7.54173636e-01,
                         -7.77965844e-01,  -7.78503716e-01,  -7.50832677e-01,
                         -7.63686001e-01,  -7.52382815e-01,  -7.72676408e-01,
                         -7.97967076e-01,  -7.66447544e-01,  -7.72373021e-01,
                         -7.58105218e-01,  -7.78605580e-01,  -7.55105436e-01,
                         -7.54666090e-01,  -7.55879164e-01,  -1.09272348e-02,
                         -1.64571069e-02,  -1.53351817e-02,  -2.56897695e-02,
                         -7.34384179e-01,  -7.54307926e-01,  -7.64428496e-01,
                         -7.54362583e-01,  -7.68724144e-01,  -7.63105869e-01,
                         -7.76543617e-01,  -7.70571768e-01,  -7.54282475e-01,
                         -7.59120584e-01,  -7.64628828e-01,  -7.58761048e-01,
                         -7.59045124e-01,  -7.60699391e-01,  -7.91379631e-01,
                         -7.71490395e-01,  -7.44821966e-01,  -7.30827630e-01,
                         -7.31755316e-01,  -7.70825386e-01,  -7.56624579e-01,
                         -7.63735771e-01,  -7.31606722e-01,  -7.54982352e-01,
                         -7.35703170e-01,  -7.78690457e-01,  -7.88318932e-01,
                         -7.65694618e-01,  -7.79101074e-01,  -7.53369391e-01,
                         -7.50435054e-01,  -7.62594759e-01,  -7.87102520e-01,
                         -7.54156351e-01,  -7.76032984e-01,  -7.63811529e-01,
                         -7.67264366e-01,  -7.83358335e-01,  -7.53380537e-01,
                         -7.28611350e-01,  -2.44742837e-02,  -9.38995555e-03,
                         -2.09042672e-02,   1.00156618e-02,  -1.74998529e-02,
                          2.61752610e-03,  -2.97460938e-03,  -2.33683605e-02,
                         -7.59936512e-01,  -7.71219373e-01,  -7.60500610e-01,
                         -7.61974394e-01,  -7.46283710e-01,  -7.69372404e-01,
                         -7.33446777e-01,  -7.71718979e-01,  -7.56622314e-01,
                         -7.74334371e-01,  -7.77844131e-01,  -7.58045495e-01,
                         -7.85832286e-01,  -7.34228134e-01,  -7.55610228e-01,
                         -7.44781613e-01,  -7.64522731e-01,  -7.62192905e-01,
                         -7.49525011e-01,  -7.78460681e-01,  -7.38175154e-01,
                         -7.73798585e-01,  -7.68559694e-01,  -7.49026835e-01,
                         -7.65231609e-01,  -7.69407451e-01,  -7.60278881e-01,
                         -7.69427061e-01,  -7.70231485e-01,  -7.85679698e-01,
                         -7.76954234e-01,  -7.56446958e-01,  -7.72330761e-01,
                         -7.52393961e-01,  -7.38053024e-01,  -7.50030041e-01,
                         -1.97196770e-02,  -7.82362930e-03,  -1.09500159e-02,
                         -3.18777561e-02,  -7.32601404e-01,  -7.70146966e-01,
                         -7.87153602e-01,  -7.51565039e-01,  -7.66435981e-01,
                         -7.76415586e-01,  -7.75222123e-01,  -7.93945491e-01,
                         -7.66822338e-01,  -7.54711449e-01,  -7.48061419e-01,
                         -7.47335255e-01,  -7.78168976e-01,  -7.44554818e-01,
                         -7.81592250e-01,  -7.75358140e-01,  -7.84345806e-01,
                         -7.71108627e-01,  -7.70821810e-01,  -7.91214108e-01,
                         -7.66589820e-01,  -7.59437740e-01,  -7.49480963e-01,
                         -7.55821109e-01,  -7.21129060e-01,  -7.49872386e-01,
                         -7.63744473e-01,  -7.80900419e-01,  -7.49281943e-01,
                         -7.64771342e-01,  -7.41446376e-01,  -7.42321670e-01,
                         -7.54094422e-01,  -7.61413991e-01,  -7.46784091e-01,
                         -7.51286030e-01,  -7.75884092e-01,  -7.80296087e-01,
                         -7.83351719e-01,  -7.85877407e-01,  -7.70366728e-01,
                         -7.39570796e-01,  -7.47996390e-01,  -7.60413945e-01,
                         -7.70981610e-01,  -7.53764987e-01,  -7.59513676e-01,
                         -7.64699757e-01,  -7.50514388e-01,  -7.68526852e-01,
                         -7.75762498e-01,  -7.80449927e-01,  -9.39754009e-01,
                         -9.66700137e-01,  -9.38959897e-01,  -9.22699869e-01,
                         -9.17541564e-01,  -9.29904759e-01,  -9.34023261e-01,
                         -9.37285423e-01,  -9.34455693e-01,  -9.31868374e-01,
                         -9.05311644e-01,  -9.18855965e-01,  -7.31971562e-01,
                         -7.40588546e-01,  -7.70278633e-01,  -7.66406775e-01,
                         -7.57390141e-01,  -7.56130278e-01,  -7.55707979e-01,
                         -7.55699694e-01,  -7.57463098e-01,  -7.57139742e-01,
                         -7.54095137e-01,  -7.60083854e-01,  -7.60538936e-01,
                         -7.57951558e-01,  -7.45649397e-01,  -7.45074272e-01,
                         -7.40732372e-01,  -7.57515430e-01,  -7.53080904e-01,
                         -7.76626825e-01,  -7.60115981e-01,  -7.65860319e-01,
                         -7.31783569e-01,  -7.35413730e-01,  -9.20236349e-01,
                         -9.30409849e-01,  -9.48240042e-01,  -9.62347090e-01,
                         -9.45471525e-01,  -9.46980476e-01,  -9.44913089e-01,
                         -9.48413491e-01,  -9.27085936e-01,  -9.22010839e-01,
                         -9.44764078e-01,  -9.21159923e-01,  -7.47287154e-01,
                         -7.47397900e-01,  -7.54893184e-01,  -7.68732071e-01,
                         -9.67661321e-01,  -9.17443395e-01,  -9.28516686e-01,
                         -9.27655935e-01,  -9.26241636e-01,  -9.37473178e-01,
                         -9.37150717e-01,  -9.11192298e-01,  -9.11389112e-01,
                         -9.14132059e-01,  -9.11579072e-01,  -9.23981905e-01,
                         -9.17462826e-01,  -9.33233738e-01,  -9.40595269e-01,
                         -9.44648504e-01,  -9.57190514e-01,  -9.38295603e-01,
                         -9.29984212e-01,  -9.08751488e-01,  -9.13427293e-01,
                         -9.27947819e-01,  -9.18982148e-01,  -9.07182276e-01,
                         -7.45602727e-01,  -7.49565959e-01,  -7.49469042e-01,
                         -7.44050205e-01,  -7.56413162e-01,  -7.55657852e-01,
                         -7.44742990e-01,  -7.52652109e-01,  -7.79977381e-01,
                         -7.67371237e-01,  -7.66316772e-01,  -7.90926695e-01,
                         -7.54370451e-01,  -7.65288174e-01,  -7.54620552e-01,
                         -7.55881190e-01,  -7.71397412e-01,  -7.50904024e-01,
                         -7.53464520e-01,  -7.36778557e-01,  -8.76148164e-01,
                         -9.18969333e-01,  -9.22178328e-01,  -9.17883337e-01,
                         -9.36030865e-01,  -9.33484435e-01,  -9.44671035e-01,
                         -9.45227027e-01,  -9.25780952e-01,  -9.21523690e-01,
                         -9.51468289e-01,  -9.47918117e-01,  -9.63283062e-01,
                         -9.60718334e-01,  -9.51246858e-01,  -9.54117835e-01,
                         -7.75601327e-01,  -7.85778105e-01,  -7.47147739e-01,
                         -7.52589226e-01,  -7.55028963e-01,  -7.78111219e-01,
                         -7.47753978e-01,  -7.26079702e-01,  -3.19374260e-03,
                         -2.56474800e-02,   1.40844826e-02,   2.06309650e-02,
                         -1.25062782e-02,  -1.88126490e-02,  -6.13725511e-03,
                          1.67418644e-02,   1.08025363e-02,   2.43099146e-02,
                         -1.99198071e-02,  -7.47418357e-03,  -7.50331163e-01,
                         -7.67358840e-01,  -7.71557748e-01,  -7.64529586e-01,
                         -1.41739473e-02,  -3.73755954e-03,  -8.17745551e-03,
                          1.10785197e-02,  -3.39547433e-02,  -1.39213679e-02,
                         -1.90697610e-02,  -2.55963746e-02,   1.73835039e-01,
                          1.60840958e-01,   1.87557653e-01,   1.90615818e-01,
                         -5.34336083e-04,  -2.24566907e-02,   4.48935851e-03,
                         -1.03855524e-02,   1.46372527e-01,   1.84550032e-01,
                          1.80403426e-01,   1.92869306e-01,  -1.64204044e-03,
                          3.28331161e-03,  -2.62276959e-02,   1.08308741e-03,
                          1.39252348e-02,   1.66750904e-02,   4.07737568e-02,
                         -8.89500510e-03,  -6.68287417e-03,   1.25135407e-02,
                         -6.14194712e-03,   1.25058275e-02,   1.61086187e-01,
                          1.70802146e-01,   1.38710499e-01,   1.67384326e-01,
                          1.64153889e-01,   1.61526561e-01,   1.79641038e-01,
                          1.91330045e-01,   2.08308414e-01,   1.91138670e-01,
                          2.04310626e-01,   1.93232372e-01,   1.66932419e-01,
                          1.87733680e-01,   1.82421982e-01,   1.81885809e-01,
                          1.86296895e-01,   1.65445969e-01,   1.84934586e-01,
                          1.67704299e-01,   1.62796795e-01,   1.88531861e-01,
                          1.69471636e-01,   1.69091359e-01,   1.87312871e-01,
                          1.61523923e-01,   1.90212116e-01,   1.83144704e-01,
                          1.59994513e-01,   1.75144285e-01,   1.76620185e-01,
                          1.57375664e-01,   1.67319626e-01,   1.77341893e-01,
                          1.94078073e-01,   1.98629424e-01,   1.66708142e-01,
                          1.80443481e-01,   1.79082349e-01,   1.88383684e-01,
                          1.84173137e-01,   1.98024452e-01,   1.94415137e-01,
                          1.68453112e-01,   1.89720601e-01,   1.80128023e-01,
                          1.78221107e-01,   1.72588781e-01,   1.63540721e-01,
                          1.71003267e-01,   1.74873561e-01,   1.62935153e-01,
                          1.59802750e-01,   1.52009115e-01,   1.73214495e-01,
                          1.47061512e-01,   1.36722416e-01,   1.33186623e-01,
                          1.47865683e-01,   1.75285131e-01,  -5.01393666e-03,
                         -4.36934456e-03,   6.76833326e-03,   1.99365783e-02,
                         -7.07795005e-03,   3.65844816e-02,   9.50588007e-03,
                          1.69235468e-02,  -2.82089255e-04,   1.80968747e-03,
                          1.20582469e-02,   1.63661391e-02,   3.02316677e-02,
                         -9.10561997e-03,  -1.83634192e-03,   3.97202978e-03,
                          6.79367781e-03,   1.31062455e-02,  -2.15291698e-03,
                          2.04186030e-02,   1.87997475e-01,   1.78522438e-01,
                          1.52757108e-01,   1.71276689e-01,   1.66428715e-01,
                          1.69858322e-01,   1.76731154e-01,   1.83354005e-01,
                          1.81725457e-01,   1.65856004e-01,   1.64660111e-01,
                          1.70354962e-01,  -4.79797740e-03,  -9.93428519e-04,
                          7.31484592e-03,  -1.78666469e-05,   3.53578711e-03,
                         -1.02130333e-02,  -2.87002930e-03,  -2.60583851e-02,
                         -6.78031612e-03,  -8.97196028e-03,  -2.12671645e-02,
                         -3.37484176e-04,  -4.22027800e-03,   4.44998685e-03,
                         -1.49346585e-03,   4.73820278e-03,  -5.56896720e-03,
                         -1.85505468e-02,  -6.81514153e-03,  -5.54451672e-03,
                          4.11171978e-03,  -1.67037547e-02,  -6.30618446e-03,
                         -3.95726860e-02,  -8.77910014e-03,  -1.24150114e-02,
                         -2.09435690e-02,  -4.23781201e-03,  -8.23640637e-03,
                         -1.39484797e-02,  -5.89552196e-03,  -9.09771305e-03,
                         -7.40030501e-03,  -1.18390163e-02,  -1.02110235e-02,
                         -8.15418363e-03,  -1.92207133e-03,  -7.32949702e-03,
                          2.66041839e-03,   1.30091915e-02,   1.97301339e-02,
                          1.01729482e-02,   4.43896046e-03,   1.06031336e-02,
                          6.55401684e-03,  -1.25857973e-02,   1.21372323e-02,
                          2.61894390e-02,   9.18286666e-03,   8.81296955e-03,
                          2.45659947e-02,  -5.07132756e-03,  -7.84284063e-03,
                         -3.22497124e-03,   1.46278692e-02,   2.32874881e-03,
                         -1.82198209e-03,  -2.83731759e-04,  -1.47599424e-03,
                         -1.30331842e-02,  -6.17267657e-03,  -8.21335521e-03,
                         -2.86636166e-02,  -1.37732020e-02,   4.59060539e-03,
                         -1.51690040e-02,   8.37490335e-03,  -2.00737733e-02,
                          1.02606732e-02,  -3.24303890e-03,   1.98818203e-02,
                          6.27557980e-03,   1.75379850e-02,   1.28156589e-02,
                          2.72929035e-02,  -8.42227309e-04,  -2.06071604e-02,
                          6.16502576e-03,   1.64832212e-02,  -7.43541494e-03,
                          4.44106758e-03,   1.14539202e-04,  -4.94473660e-03,
                          7.21447961e-03,   9.32159368e-03,  -3.66002880e-03,
                         -3.05436482e-03,  -5.75329585e-04,   3.61975282e-02,
                          3.14301898e-04,   1.39134042e-02,   1.77596062e-02,
                          2.58148499e-02,   4.55774134e-03,   1.97404046e-02,
                         -2.95816418e-02,   1.11173093e-02,   1.13247018e-02,
                          3.34422314e-03,  -1.39211528e-02,  -9.48080122e-01,
                         -9.25903261e-01,  -9.29054141e-01,  -9.56526399e-01,
                         -9.16483223e-01,  -9.56538260e-01,  -9.30603027e-01,
                         -9.21904445e-01,  -9.26599562e-01,  -9.64691520e-01,
                         -9.30633008e-01,  -9.29204941e-01,   1.46521050e-02,
                         -1.04157971e-02,   2.23643277e-02,   9.60578956e-03,
                         -2.55894312e-03,   3.80123556e-02,   2.77495496e-02,
                          2.00531483e-02,   8.20231531e-03,  -8.50030966e-03,
                         -1.81250821e-03,  -2.91478587e-03,  -9.18069839e-01,
                         -9.20129955e-01,  -9.46949661e-01,  -9.31603551e-01,
                         -8.97646606e-01,  -9.20429647e-01,  -9.20678973e-01,
                         -9.19719696e-01,  -9.49454606e-01,  -9.16827619e-01,
                         -9.35559452e-01,  -9.51718986e-01,  -9.30953681e-01,
                         -9.43101406e-01,  -9.38551188e-01,  -9.11999941e-01,
                         -9.45907176e-01,  -9.32108581e-01,  -9.34057474e-01,
                         -9.47213352e-01,  -9.27132010e-01,  -9.38388646e-01,
                         -9.23716664e-01,  -9.11592245e-01,  -9.23519671e-01,
                         -9.19794083e-01,  -9.21138942e-01,  -9.28373635e-01,
                         -9.17486548e-01,  -9.36242640e-01,  -9.13243711e-01,
                         -9.32944834e-01,  -9.38242137e-01,  -9.38512623e-01,
                         -9.21786904e-01,  -9.30543959e-01,  -9.26304102e-01,
                         -9.34553027e-01,  -9.12075937e-01,  -9.30867314e-01,
                         -9.23723638e-01,  -9.00399566e-01,  -9.39346671e-01,
                         -9.28641558e-01,  -9.22459543e-01,  -9.16081190e-01,
                         -9.09721136e-01,  -9.11788344e-01,  -9.20613468e-01,
                         -9.48497653e-01,  -9.41570103e-01,  -9.33676600e-01,
                         -9.43240583e-01,  -9.19788182e-01,  -9.03855979e-01,
                         -9.35375512e-01,  -9.33470547e-01,  -9.38385665e-01,
                         -9.25530314e-01,  -9.23574686e-01,  -9.14941370e-01,
                         -8.99865091e-01,  -8.97483110e-01,  -8.99591625e-01,
                         -9.22473788e-01,  -9.21215236e-01,  -9.36318278e-01,
                         -9.36073780e-01,  -9.33340073e-01,  -9.35669005e-01,
                         -9.13152337e-01,  -9.30056810e-01,  -9.14801240e-01,
                         -9.29637909e-01,  -9.30413842e-01,  -9.40949321e-01,
                         -9.33955908e-01,  -9.24941599e-01,  -9.32507992e-01,
                         -9.09864604e-01,  -9.10483301e-01,  -9.32577074e-01,
                         -9.23390031e-01,  -9.25520837e-01,  -9.17602479e-01,
                         -9.23256516e-01,  -9.19712424e-01,  -9.37500536e-01,
                         -9.22082961e-01,  -9.45515752e-01,  -9.36914265e-01,
                         -9.29895222e-01,  -9.26640987e-01,  -9.27688837e-01,
                         -9.43494618e-01,  -9.19033945e-01,  -9.15745497e-01,
                         -9.27254856e-01,  -9.26590145e-01,  -9.30284262e-01,
                         -9.41721439e-01,  -9.31007087e-01,  -9.45171118e-01,
                         -9.22369957e-01,  -9.36294615e-01,  -9.36061203e-01,
                         -9.13293719e-01,  -9.31104481e-01,  -9.48965549e-01,
                         -9.52033341e-01,  -9.45709467e-01,  -9.32530582e-01,
                         -9.44956243e-01,  -9.38634455e-01,  -9.28076744e-01,
                         -9.41542804e-01,  -9.24126387e-01,  -9.36289191e-01,
                         -9.30472553e-01,  -9.48514462e-01,  -9.50163484e-01,
                         -9.11671877e-01,  -9.22678471e-01,  -9.33631718e-01,
                         -9.40116584e-01,  -9.43744242e-01,  -9.62153792e-01,
                         -9.45196211e-01,  -9.37933326e-01,  -9.31006908e-01,
                         -9.42610860e-01,  -9.29327786e-01,  -9.35063481e-01,
                         -9.26620245e-01,  -9.46611762e-01,  -9.41204131e-01,
                         -9.52715755e-01,  -9.32312906e-01,  -9.39388812e-01,
                         -9.38818097e-01,  -9.39725816e-01,  -9.38800573e-01,
                         -9.36092138e-01,  -9.31660473e-01,  -9.38106120e-01,
                         -9.10480320e-01,  -9.22329128e-01,  -9.24208999e-01,
                         -9.24622774e-01,  -9.23166394e-01,  -9.31663871e-01,
                         -9.50389564e-01,  -9.44033086e-01,  -9.31859255e-01,
                         -9.53101754e-01,  -9.41660106e-01,  -9.28920209e-01,
                         -9.44002628e-01,  -9.30384815e-01,  -9.34885144e-01,
                         -9.17997777e-01,  -9.38287079e-01,  -9.15775299e-01,
                         -9.23791230e-01,  -9.47588384e-01,  -9.31883037e-01,
                         -9.16284978e-01,  -9.02996004e-01,  -9.08136189e-01,
                         -9.24374998e-01,  -9.17617500e-01,  -9.20709014e-01,
                         -9.22007620e-01,  -9.22424674e-01,  -9.40269589e-01,
                         -9.28005457e-01,  -9.44705546e-01,  -9.44487274e-01,
                         -9.63986993e-01,  -9.21061814e-01,  -9.26080346e-01,
                         -9.24120784e-01,  -9.42241609e-01,  -9.27994907e-01,
                         -9.07289982e-01,  -9.49083567e-01,  -9.45823133e-01,
                         -8.90059471e-01,  -9.08130467e-01,  -9.14270043e-01,
                         -9.07024682e-01,  -9.41321373e-01,  -9.28160012e-01,
                         -9.31930006e-01,  -9.18002903e-01,  -9.28583920e-01,
                         -9.47690845e-01,  -9.36627507e-01,  -9.32998180e-01,
                         -9.29582775e-01,  -9.14825559e-01,  -9.11204755e-01,
                         -9.52004790e-01,  -9.18251157e-01,  -9.48050320e-01,
                         -9.23826337e-01,  -9.58715200e-01,  -9.35625911e-01,
                         -9.59194422e-01,  -9.33343291e-01,  -9.37501192e-01,
                         -9.30078268e-01,  -9.44498360e-01,  -9.31173086e-01,
                         -9.44451272e-01,  -9.40861404e-01,  -9.28918719e-01,
                         -9.46416378e-01,  -9.48670745e-01,  -9.22712207e-01,
                         -9.38805103e-01,  -9.33996379e-01,  -9.43149686e-01,
                         -9.56431270e-01,  -9.31596279e-01,  -9.25891936e-01,
                         -9.33265209e-01,  -9.56130624e-01,  -9.43495631e-01,
                         -9.37229872e-01,  -9.36571062e-01,  -9.27931011e-01,
                         -9.59299207e-01,  -9.37422335e-01,  -9.51885343e-01,
                         -9.37226534e-01,  -9.35764074e-01,  -9.60667789e-01,
                         -9.52314019e-01,  -9.17417169e-01,  -9.36204731e-01,
                         -9.32165325e-01,  -9.44565237e-01,  -9.53804374e-01,
                         -9.54432964e-01,  -9.42831397e-01,  -9.44793582e-01,
                         -9.37711775e-01,  -9.58706737e-01,  -9.31857288e-01,
                         -9.36290562e-01,  -9.32899177e-01,  -1.01188002e-02,
                         -3.99966864e-03,   1.01798158e-02,  -4.91436746e-04,
                          5.76138357e-03,  -2.58882158e-02,   2.52059009e-02,
                          1.08993538e-02,   1.17254546e-02,  -2.31119408e-03,
                         -2.49569607e-03,  -1.08764144e-02,  -8.99402704e-03,
                         -1.66782166e-03,   1.86877288e-02,  -1.19008636e-03,
                          4.90374304e-03,   5.79781691e-03,  -3.26888938e-03,
                         -2.87269754e-03,  -8.93100165e-03,  -1.33402441e-02,
                         -1.11168446e-02,  -2.31968798e-02,  -3.88724310e-03,
                         -1.74496491e-02,  -2.39501558e-02,  -2.66976822e-02,
                         -2.57714521e-02,  -2.08211634e-02,   1.07896524e-02,
                          3.93573521e-03,   4.47640568e-03,   1.50488932e-02,
                          6.21540286e-03,   5.01395727e-04,  -9.36565734e-03,
                          2.23030224e-02,  -4.14911611e-03,   1.07290177e-02,
                         -6.58017211e-03,  -5.11794165e-03,  -1.16467103e-02,
                         -1.33374445e-02,  -1.09767599e-03,  -2.13604141e-02,
                         -1.28963506e-02,   6.93230017e-04,  -9.51825440e-01,
                         -9.23439741e-01,  -9.38117087e-01,  -9.17625070e-01,
                         -9.24747765e-01,  -9.18732285e-01,  -9.47458386e-01,
                         -9.29199219e-01,  -9.33446646e-01,  -9.23032403e-01,
                         -9.48127389e-01,  -9.21522737e-01,  -9.43223536e-01,
                         -9.41070318e-01,  -9.30113614e-01,  -9.38312352e-01,
                         -9.23330665e-01,  -9.37223434e-01,  -9.29598629e-01,
                         -9.24997330e-01,  -9.41124558e-01,  -9.35545743e-01,
                         -9.36517775e-01,  -9.06435311e-01,  -9.36897516e-01,
                         -9.22736645e-01,  -9.37657535e-01,  -9.26352501e-01,
                         -9.18350935e-01,  -9.27985907e-01,  -9.26273882e-01,
                         -9.22790170e-01,  -9.27639067e-01,  -9.08292472e-01,
                         -9.51857865e-01,  -9.20505822e-01,  -9.40437376e-01,
                         -9.34697747e-01,  -9.38132286e-01,  -9.36562896e-01,
                         -9.26559448e-01,  -9.34915781e-01,  -9.29229736e-01,
                         -9.22412097e-01,  -9.25043702e-01,  -9.40502465e-01,
                         -9.33730185e-01,  -9.33373749e-01,  -9.12720740e-01,
                         -9.45866823e-01,  -9.33153331e-01,  -9.54968452e-01,
                         -9.35826838e-01,  -9.15067375e-01,  -9.59585309e-01,
                         -9.44394946e-01,  -9.36750948e-01,  -9.22674239e-01,
                         -9.50738013e-01,  -9.27315593e-01,  -9.42125320e-01,
                         -9.32742357e-01,  -9.33325887e-01,  -9.27681327e-01,
                         -9.19784844e-01,  -9.42077935e-01,  -9.29931581e-01,
                         -9.30154920e-01,  -9.45013583e-01,  -9.38310921e-01,
                         -9.20875967e-01,  -9.19243634e-01,  -9.12872851e-01,
                         -9.27226841e-01,  -9.31995809e-01,  -9.20932829e-01,
                         -9.29536879e-01,  -9.19778407e-01,  -9.28008854e-01,
                         -9.39325392e-01,  -9.30374384e-01,  -9.21482742e-01,
                         -9.38304901e-01,  -9.25561130e-01,  -9.18753445e-01,
                         -9.22773957e-01,  -9.19577181e-01,  -9.29110050e-01,
                         -9.35762048e-01,  -9.02922690e-01,  -9.26216364e-01,
                         -9.20593143e-01,  -9.30852413e-01,  -9.35701847e-01,
                         -9.14742053e-01,  -9.26686168e-01,  -9.22846556e-01,
                         -9.37063396e-01,  -9.28589642e-01,  -9.10227537e-01,
                         -9.33066308e-01,  -9.31994021e-01,  -9.34137642e-01,
                         -9.40038621e-01,  -9.28609014e-01,  -9.39227164e-01,
                         -9.09559071e-01,  -9.32430685e-01,  -9.16517138e-01,
                         -9.07649100e-01,  -9.21313047e-01,  -9.26681995e-01,
                         -9.17606115e-01,  -9.12790716e-01,  -9.30797875e-01,
                         -9.25321460e-01,  -9.14339125e-01,  -9.30479169e-01,
                         -9.24800575e-01,  -9.40628231e-01,  -9.19460714e-01,
                         -9.20299530e-01,  -9.14351702e-01,  -9.27858889e-01,
                         -9.34355676e-01,  -9.20875490e-01,  -9.31277215e-01,
                         -9.09980118e-01,  -9.29360867e-01,  -9.19433832e-01,
                         -9.20334101e-01,  -9.27576125e-01,  -9.42852497e-01,
                         -9.23044145e-01,  -9.37036157e-01,  -9.40838873e-01,
                         -9.26323593e-01,  -9.45115030e-01,  -9.24467385e-01,
                         -9.33855891e-01,  -9.34514344e-01,  -9.26945448e-01,
                         -9.21088278e-01,  -9.28668082e-01,  -9.32442129e-01,
                         -9.26662326e-01,  -9.30336475e-01,  -9.33156192e-01,
                         -9.13976848e-01,  -9.18152690e-01,  -9.13285494e-01,
                         -9.32956636e-01,  -9.04825568e-01,  -9.36941206e-01,
                         -9.17406499e-01,  -9.29074109e-01,  -9.22299743e-01,
                         -9.14637506e-01,  -9.33179855e-01,  -9.11978126e-01,
                         -9.17781234e-01,  -9.30693746e-01,  -9.15983379e-01,
                         -9.32003558e-01,  -9.40438390e-01,  -9.20917690e-01,
                         -9.19331908e-01,  -9.14875984e-01,  -9.25398827e-01,
                         -9.35680330e-01,  -9.19237554e-01,  -9.37316477e-01,
                         -9.38237488e-01,  -9.30416286e-01,  -9.27290201e-01,
                         -9.19457316e-01,  -9.23506558e-01,  -9.34256852e-01,
                         -9.27006066e-01,  -9.46278214e-01,  -9.31451678e-01,
                         -9.19707239e-01,  -9.33323622e-01,  -9.11620975e-01,
                         -9.41761017e-01,  -9.14898217e-01,  -9.46516097e-01,
                         -9.31327939e-01,  -9.19463873e-01,  -9.23808575e-01,
                         -9.30964887e-01,  -9.29276049e-01,  -9.29420531e-01,
                         -9.23029125e-01,  -9.19475794e-01,  -9.25700426e-01,
                         -9.24178064e-01,  -9.22788739e-01,  -9.46332872e-01,
                         -9.31169569e-01,  -9.20314491e-01,  -9.24148142e-01,
                         -9.26232874e-01,  -9.35139954e-01,  -9.28909421e-01,
                         -9.30063963e-01,  -9.30082262e-01,  -9.31673765e-01,
                         -9.38743711e-01,  -9.35562015e-01,  -9.15526927e-01,
                         -9.35744107e-01,  -9.28315878e-01,  -9.27548587e-01,
                         -9.21907008e-01,  -9.30247664e-01,  -9.15748894e-01,
                         -9.21956778e-01,  -9.34237599e-01,  -9.24406588e-01,
                         -9.33043301e-01,  -9.33622062e-01,  -9.23207581e-01,
                         -9.37353730e-01,  -9.18180406e-01,  -9.34553504e-01,
                         -9.13369536e-01,  -9.27243590e-01,  -9.34474885e-01,
                         -9.25751925e-01,  -9.17500734e-01,  -9.32257354e-01,
                         -9.14578795e-01,  -9.27330434e-01,  -9.18686271e-01,
                         -9.34286952e-01,  -9.26158309e-01,  -9.22124505e-01,
                         -9.28052425e-01,  -9.20810699e-01,  -9.21152055e-01,
                         -9.27689970e-01,  -9.21272218e-01,  -9.19541717e-01,
                         -9.32821751e-01,  -9.38836277e-01,  -9.28114951e-01,
                         -9.25503492e-01,  -9.32014048e-01,  -9.28909838e-01,
                         -9.27227616e-01,  -9.22928572e-01,  -9.26057100e-01,
                         -9.26636994e-01,  -9.21229899e-01,  -9.24165905e-01,
                         -9.30494606e-01,  -9.34852779e-01,  -9.21535373e-01,
                         -9.38630819e-01,  -9.26525176e-01,  -9.33377743e-01,
                         -9.26642299e-01,  -9.31483567e-01,  -9.32512641e-01,
                         -9.29060817e-01,  -9.31597590e-01,  -9.38885868e-01,
                         -9.28943276e-01,  -9.22558904e-01,  -9.29774880e-01,
                         -9.31620181e-01,  -9.29035127e-01,  -9.31892216e-01,
                         -9.32039797e-01,  -9.35351014e-01,  -9.34888601e-01,
                         -9.34939265e-01,  -9.33785737e-01,  -9.41902757e-01,
                         -9.34121788e-01,  -9.34909761e-01,  -9.35925603e-01,
                         -9.37352300e-01,  -9.27578151e-01,  -9.37030792e-01,
                         -9.39013362e-01,  -9.33405817e-01,  -9.35320199e-01,
                         -9.40484822e-01,  -9.30739641e-01,  -9.31253850e-01,
                         -9.32063341e-01,  -9.38457727e-01,  -9.34932053e-01,
                         -9.45852876e-01,  -9.35121596e-01,  -9.34193015e-01,
                         -9.39875960e-01,  -9.36421156e-01,  -9.34615374e-01,
                         -9.12849128e-01,  -9.40566897e-01,  -9.34581339e-01,
                         -9.46682870e-01,  -9.40308750e-01,  -9.37242866e-01,
                         -9.31195855e-01,  -9.47756886e-01,  -9.39265430e-01,
                         -9.34027016e-01,  -9.39118028e-01,  -9.39229369e-01,
                         -9.45007801e-01,  -9.35301661e-01,  -9.37590599e-01,
                         -9.39051151e-01,  -9.49525535e-01,  -9.43669975e-01,
                         -9.34580982e-01,  -9.42521691e-01,  -9.24658537e-01,
                         -9.38275516e-01,  -9.29484487e-01,  -9.40589964e-01,
                         -9.42369223e-01,  -9.30873394e-01,  -9.40217376e-01,
                         -9.28122640e-01,  -9.34775054e-01,  -9.32820916e-01,
                         -9.29146469e-01,  -9.37839746e-01,  -9.25550461e-01,
                         -9.39706326e-01,  -9.28246975e-01,  -9.37981784e-01,
                         -9.24355447e-01,  -9.28849220e-01,  -9.42337215e-01,
                         -9.30641651e-01,  -9.41500425e-01,  -9.39389288e-01,
                         -9.40806508e-01,  -9.40169334e-01,  -9.29597318e-01,
                         -9.33113635e-01,  -9.28177893e-01,  -9.32009637e-01,
                         -9.28375840e-01,  -9.32265222e-01,  -9.38138366e-01,
                         -9.35665369e-01,  -9.34749901e-01,  -9.45201755e-01,
                         -9.24298048e-01,  -9.40367162e-01,  -9.31831658e-01,
                         -9.40358877e-01,  -9.41818237e-01,  -9.30833578e-01,
                         -9.31735396e-01,  -9.42602754e-01,  -9.25343215e-01,
                         -9.40661788e-01,  -9.21014249e-01,  -9.39472198e-01,
                         -9.20039296e-01,  -9.43240464e-01,  -9.30833995e-01,
                         -9.39822853e-01,  -9.07687306e-01,  -9.44823742e-01,
                         -9.36250389e-01,  -9.22921121e-01,  -9.49098885e-01,
                         -9.22672629e-01,  -9.41148579e-01,  -9.24139082e-01,
                         -9.23473120e-01,  -9.40738678e-01,  -9.34234917e-01,
                         -9.28959429e-01,  -9.21098590e-01,  -9.31431234e-01,
                         -9.14407194e-01,  -9.34381485e-01,  -9.25161600e-01,
                         -9.29108322e-01,  -9.39312637e-01,  -9.39832151e-01,
                         -9.27732706e-01,  -9.42987859e-01,  -9.28448021e-01,
                         -9.39009249e-01,  -9.35849190e-01,  -9.33197439e-01,
                         -9.51151907e-01,  -9.28218663e-01,  -9.39410150e-01,
                         -9.29919004e-01,  -9.12453055e-01,  -9.30049121e-01,
                         -9.33908999e-01,  -9.32905495e-01,  -9.20990407e-01,
                         -9.35921073e-01,  -9.39810395e-01,  -9.27090764e-01,
                         -9.27585840e-01,  -9.40133095e-01,  -9.37543213e-01,
                         -9.32423472e-01,  -9.23109114e-01,  -9.44977522e-01,
                         -9.37651694e-01,  -9.33765411e-01,  -9.44736004e-01,
                         -9.29494679e-01,  -9.53965247e-01,  -9.29079056e-01,
                         -9.32316244e-01,  -9.48648870e-01,  -9.41015005e-01,
                         -9.18729424e-01,  -9.35008705e-01,  -9.40300107e-01,
                         -9.22613144e-01,  -8.49268679e-03,  -3.37234669e-05,
                         -8.47954582e-03,  -1.55932158e-02,   6.86506834e-03,
                          1.02935582e-02,  -1.67865388e-03,  -2.21642535e-02,
                         -9.24242049e-05,  -1.41828461e-02,  -7.99269043e-03,
                         -2.22737761e-03,  -1.74943439e-03,   3.53113678e-03,
                         -8.57411884e-03,   8.00612848e-03,   4.75810701e-03,
                          1.95540115e-02,   6.06464501e-03,   1.15767969e-02,
                         -3.63826030e-03,  -8.91696010e-03,   4.77626454e-03,
                         -1.32571347e-02,  -3.33926082e-03,  -1.69762392e-02,
                         -5.72900474e-03,  -1.44299157e-02,  -1.84902735e-02,
                         -4.64047678e-03,  -1.00291139e-02,   2.99519976e-03,
                         -1.56010194e-02,   7.81990122e-03,   2.55153445e-03,
                          1.07420543e-02,  -1.51149118e-02,  -1.11126658e-02,
                          1.18679442e-02,   2.09130626e-02,  -4.98405285e-03,
                          3.30476114e-03,  -9.77627095e-03,   4.60481970e-03,
                         -1.77600496e-02,  -1.45257153e-02,   2.28954703e-02,
                          1.56729929e-02,  -5.54877892e-03,   1.38154011e-02,
                          2.71061137e-02,   1.87712535e-02,   2.56214775e-02,
                          1.12669505e-02,   1.10885478e-03,   3.44230956e-03,
                          1.15689859e-02,   2.20956355e-02,   1.18434587e-02,
                         -1.29896344e-03,  -1.97888147e-02,   1.34318434e-02,
                          3.68076470e-03,  -6.81036618e-03,   5.05708577e-03,
                         -4.25642682e-03,   3.05797555e-03,   1.07311942e-02,
                         -4.85681696e-03,  -1.02051266e-03,   6.69453805e-03,
                          1.34455450e-02,   1.81290321e-03,   1.79825574e-02,
                         -6.32940838e-03,  -1.70895439e-02,   1.55364966e-03,
                         -2.40231194e-02,  -4.39630402e-03,   1.09551370e-03,
                         -9.01219808e-03,  -6.92045595e-03,   6.85433275e-04,
                          1.30825711e-03,  -1.87249109e-03,   1.21668046e-02,
                          1.32321222e-02,  -8.01739749e-04,   4.47325921e-03,
                          6.11541048e-03,  -6.50081178e-03,  -1.82719377e-03,
                          2.14491226e-03,   9.20297951e-03,  -2.11500209e-02,
                          7.28288293e-03,   1.09721720e-02,  -1.91133609e-03,
                          8.56587198e-04,  -8.35758448e-03,  -2.58902810e-03,
                         -1.34493294e-03,   1.61598139e-02,  -5.68623003e-03,
                          4.02238639e-03,   1.23820566e-02,   1.39452573e-02,
                          3.83432925e-04,   3.60230543e-03,   7.67397415e-03,
                          8.19430407e-03,   6.08543633e-03,  -6.57413574e-03,
                         -2.97169178e-03,  -4.09433106e-03,  -6.87391823e-03,
                          6.55662268e-03,  -7.79990666e-03,   4.52626322e-04,
                          7.03500910e-03,  -5.38874138e-03,   6.45882729e-03,
                          7.25727482e-03,   1.04983868e-02,   2.88434746e-03,
                          1.13536092e-02,  -5.36546868e-04,  -8.96492566e-04,
                          1.13741783e-02,   1.09533770e-02,   5.04890084e-03,
                          1.27392439e-02,   9.50251892e-03,  -6.13752566e-03,
                         -4.51131444e-03,   7.09249731e-03,  -4.96373279e-03,
                          1.44826211e-02,   4.60161781e-03,   3.91669059e-03,
                          1.18470900e-02,  -6.33945735e-03,  -1.00749657e-02,
                          3.25997686e-03,   3.55761801e-03,   5.06520132e-03,
                         -1.48382699e-02,  -1.18791712e-02,   9.25425719e-03,
                          8.07302073e-03,   8.02127179e-03,   4.14985092e-03,
                          7.55857537e-03,   8.50190409e-04,  -6.14469172e-03,
                         -2.91987299e-03,  -6.18111109e-04,   1.19845138e-03,
                         -1.15760826e-02,   4.01201844e-03,   7.66860275e-03,
                         -3.91293410e-03,   1.48439184e-02,   4.25012037e-03,
                          3.64223844e-03,  -9.41570196e-03,  -7.36981820e-05,
                          3.81940790e-03,   4.92513692e-03,  -6.16815116e-04,
                          2.52280645e-02,   1.64103620e-02,   1.28586004e-02,
                          8.00610799e-03,  -8.75271577e-03,  -5.66295069e-03,
                         -8.75832234e-03,  -7.69198639e-03,  -1.57731713e-03,
                          3.22824228e-03,   8.40740092e-03,   4.96253371e-03,
                         -4.24197700e-04,   8.05399031e-04,  -7.08760414e-03,
                         -1.91518180e-02,  -1.04490845e-02,   7.49664498e-04,
                          9.14517976e-03,   1.33745503e-02,  -1.99628226e-03,
                         -5.05068863e-04,   1.34098949e-03,   1.73879613e-03,
                          1.23163499e-02,   1.42611871e-02,   1.81733593e-02,
                          1.52523424e-02,   6.79929135e-03,   1.08643901e-02,
                          9.76629090e-04,  -5.06822289e-05,  -1.70728210e-02,
                          1.13008264e-03,  -7.12109217e-03,  -6.09391928e-03,
                         -9.50100180e-03,  -3.92294163e-03,  -5.81261993e-04,
                          9.72288568e-03,   1.67342629e-02,   1.23237511e-02,
                         -4.18602768e-03,  -7.42720906e-03,   1.84398890e-02,
                          3.86315980e-03,  -3.01834050e-04,  -4.52425331e-03,
                          3.35025252e-03,   8.64919648e-03,   2.99185934e-03,
                         -1.09882641e-03,  -1.01981265e-03,   6.99838204e-03,
                          1.81481261e-02,  -7.93057960e-03,  -2.11058669e-02,
                         -4.92060464e-03,  -4.59695366e-05,  -7.57703790e-04,
                         -3.13459849e-03,   7.29661901e-03,   8.23317654e-03,
                          4.31724155e-04,   4.65442752e-03,   5.36082545e-04,
                         -8.90557375e-03,   2.04300042e-03,   2.08090292e-03,
                         -7.81292189e-03,  -6.26057526e-03,  -7.77752837e-03,
                         -1.32004579e-03,   2.95868330e-03,  -5.83684212e-03,
                         -7.79718999e-03,   1.19147939e-04,  -1.30037023e-02,
                         -8.65090825e-03,  -3.31338262e-03,   3.24018358e-04,
                         -6.84837298e-03,  -8.31680559e-03,   1.12488482e-03,
                         -4.04103613e-03,  -2.27283424e-04,   1.63045275e-04,
                         -3.77219100e-03,   1.66877103e-03,  -3.61977005e-03,
                          4.77851694e-03,   1.10427234e-02,   1.70771945e-02,
                         -5.72799286e-03,  -1.73912186e-03,   1.90391357e-03,
                         -1.13923848e-02,   2.84956372e-03,  -5.77037223e-03,
                         -7.51979975e-03,  -1.52466667e-03,  -3.08686169e-03,
                         -1.68171024e-03,  -1.53089436e-02,  -1.94878120e-03,
                          1.22709069e-02,  -9.97928437e-03,  -5.51231764e-03,
                         -9.89701971e-03,  -2.22007278e-03,  -8.22764635e-03,
                          5.11929998e-03,  -2.74920417e-03,   8.61008093e-03,
                         -6.07442390e-03,   7.21486099e-03,  -3.11861676e-03,
                          8.50234088e-03,   6.19564438e-03,  -1.44336578e-02,
                         -3.72067007e-04,  -1.10547757e-02,   4.77028359e-03,
                         -3.29916831e-03,   8.23466631e-04,  -7.94529356e-03,
                          4.12686961e-03,   6.60137925e-03,  -7.56200589e-03,
                          6.69551501e-03,  -2.45093927e-03,  -4.43463586e-03,
                          2.66659353e-03,  -8.44132528e-03,  -1.30105084e-02,
                         -1.28309065e-02,   1.23896671e-03,   8.19871109e-03,
                          9.65748332e-04,  -2.92071141e-03,   9.00809560e-03,
                         -1.32886821e-03,  -1.29083395e-02,  -1.09170889e-03,
                          1.04122208e-02,   5.57193998e-03,   1.24780992e-02,
                          3.18566174e-03,   8.39623529e-03,   1.18625378e-02,
                          8.25140998e-03,   1.14170229e-02,   4.91294637e-03,
                         -7.39665283e-03,   3.41781741e-03,  -3.74900876e-03,
                          1.27866343e-02,  -7.55951088e-03,  -1.35868080e-02,
                          4.67116479e-03,   3.98480939e-03,   1.53733545e-03,
                          1.87143066e-03,  -6.97695976e-03,   8.95252044e-04,
                          4.71225521e-03,   8.37540254e-03,   3.05904984e-03,
                          9.05375276e-03,   1.79029889e-02,  -1.30591458e-02,
                          6.98502688e-03,  -1.77226320e-03,  -7.23471632e-03,
                         -1.51187312e-04,   9.72392596e-03,   4.65970859e-03,
                          1.37232542e-02,   1.80859945e-03,  -6.88143773e-03,
                         -2.61777546e-03,  -9.26594250e-03,   9.44467820e-03,
                          3.18753999e-03,  -1.31116929e-02,  -8.81461892e-03,
                         -3.73134296e-03,   2.04705470e-03,  -2.91697611e-03,
                         -1.93042103e-02,  -2.32206937e-02,  -2.25595031e-02,
                         -1.06932083e-02,  -1.51013080e-02,  -4.77099046e-03,
                          9.52056609e-03,  -4.07013716e-03,   5.56421280e-03,
                         -6.92844717e-03,   1.51488092e-03,  -5.13397856e-03,
                          3.14538204e-03,   1.79477036e-02,   4.41913260e-03,
                          7.47164013e-03,   1.01040872e-02,   9.36558098e-03,
                          5.51496493e-03,  -3.51112173e-03,  -1.34505974e-02,
                          1.37216952e-02,   1.86114591e-02,   3.72169586e-03,
                          6.75341906e-03,   1.30845048e-02,   2.52654050e-02,
                          6.81939675e-03,   6.22550026e-03,   1.64150465e-02,
                          1.25705712e-02,   2.02514902e-02,  -3.24741891e-03,
                          1.45755308e-02,  -6.97138766e-03,   8.99447687e-03,
                          6.60031894e-03,  -1.65654849e-02,  -1.52973142e-02,
                         -2.78880596e-02,  -6.60219695e-03,  -5.08656772e-03,
                         -3.52602894e-03,  -1.78462565e-02,   3.42215574e-03,
                         -3.80852725e-03,  -8.76214169e-03,   4.98575065e-03,
                         -1.55248614e-02,  -2.03304272e-02,  -7.33143045e-03,
                         -4.31348523e-03,  -2.91850767e-03,   1.00660045e-02,
                          1.09580895e-02,   5.63161820e-03,   6.81017246e-03,
                          7.01456424e-03,  -1.22320829e-02,  -9.22357664e-03,
                          4.81823506e-03,  -4.73251275e-04,  -1.20775336e-02,
                          5.06471610e-03,   3.41968844e-03,  -1.85088196e-03,
                         -3.27274273e-03,  -3.98562057e-03,   1.26101924e-02,
                         -5.85066807e-03,  -5.57903713e-03,   5.18080080e-03,
                         -3.51689477e-03,   6.28106855e-03,   9.84415505e-03,
                          2.48952094e-03,   4.85158432e-03,   1.10945916e-02,
                          3.49417678e-03,   1.35341231e-02,   5.00512822e-03,
                         -2.99637788e-03,   9.46762413e-03,   1.66516658e-02,
                          1.00609036e-02,  -6.94172573e-04,   9.01322439e-03,
                          1.32703848e-04,   7.13548670e-03,   1.80261850e-03,
                         -9.17744078e-03,   2.82445755e-02,  -7.86804652e-04,
                         -1.93079677e-03,  -2.39561358e-03,   5.80121251e-03,
                          2.95921694e-03,  -8.63708835e-03,   1.48971444e-02,
                          9.10235662e-03,  -2.20592786e-02,   8.22295435e-03,
                         -6.81547401e-03,   1.22692501e-02,   5.98581834e-03,
                          1.48095712e-02,   1.65188161e-03,  -1.84573955e-03,
                         -6.09550625e-03,  -9.00076449e-01,  -9.18653250e-01,
                         -9.24169481e-01,  -9.10332441e-01,  -9.16718662e-01,
                         -9.27419424e-01,  -9.40206945e-01,  -9.27578628e-01,
                         -9.39104199e-01,  -9.41485941e-01,  -9.37136292e-01,
                         -9.33996975e-01,  -3.14686517e-03,   8.46043881e-03,
                         -7.37390714e-04,   3.06438631e-03,   1.08874822e-02,
                          3.65006295e-03,  -4.85313684e-03,  -1.53916515e-03,
                         -9.58158821e-03,   4.69391030e-04,  -9.35427751e-03,
                         -9.90751293e-03,  -2.25145724e-02,   1.07852444e-02,
                         -1.08020920e-02,   3.39582702e-03,  -8.46856181e-03,
                          6.19105622e-03,   2.38067866e-03,   1.65927429e-02,
                          2.10241359e-02,  -1.54832716e-03,  -4.96924948e-03,
                          1.72171611e-02,   8.65345169e-03,  -2.99438206e-03,
                         -6.13311771e-03,   7.10428599e-03,   9.80103388e-03,
                         -4.55530157e-04,   1.20775690e-02,   6.31313585e-03,
                         -1.05907628e-02,  -3.68291326e-03,   7.27001971e-05,
                          4.07283287e-03,   2.17317957e-02,   1.22693749e-02,
                         -8.06452474e-04,  -5.27024455e-03,   6.66186819e-03,
                         -6.36668038e-03,   2.42607016e-02,  -4.69414610e-03,
                          9.71129816e-03,  -2.74895458e-04,  -3.14128632e-03,
                          3.41368676e-03,  -1.64554380e-02,   1.40520688e-02,
                          3.88104026e-03,  -2.85347248e-03,   2.91107828e-03,
                          2.45036203e-02,   3.96734476e-03,   5.11618843e-03,
                         -3.77827734e-02,  -4.00731247e-03,   1.57636497e-02,
                          1.12135662e-02,  -3.93324718e-03,   3.82031593e-03,
                          1.41489841e-02,  -6.63142977e-03,  -9.36748147e-01,
                         -9.42258000e-01,  -9.29652870e-01,  -9.31917369e-01,
                         -9.44129050e-01,  -9.45162594e-01,  -9.25374687e-01,
                         -9.33565855e-01,  -9.32423472e-01,  -9.25258577e-01,
                         -9.34300363e-01,  -9.24594939e-01,  -9.09784138e-01,
                         -9.19184387e-01,  -9.31133866e-01,  -9.26998019e-01,
                         -9.16611791e-01,  -9.41714704e-01,  -9.31739271e-01,
                         -9.12706375e-01,  -9.33945298e-01,  -9.36511338e-01,
                         -9.27938402e-01,  -9.59715486e-01,  -9.22377110e-01,
                         -9.26072955e-01,  -9.37088013e-01,  -9.31599796e-01,
                         -9.48791146e-01,  -9.39746976e-01,  -9.41586077e-01,
                         -9.44316447e-01,  -9.29447472e-01,  -9.31637704e-01,
                         -9.41934347e-01,  -9.28376377e-01,  -9.15820420e-01,
                         -9.30052936e-01,  -9.39281821e-01,  -9.37503994e-01,
                         -9.38418686e-01,  -9.43100572e-01,  -9.30497944e-01,
                         -9.32768106e-01,  -9.60971713e-01,  -9.16664481e-01,
                         -9.27735865e-01,  -9.39233899e-01,  -9.21925187e-01,
                         -8.97471488e-01,  -9.18134451e-01,  -9.17346954e-01,
                         -9.18823659e-01,  -9.19911146e-01,  -9.28211093e-01,
                         -9.32062447e-01,  -9.22624648e-01,  -9.41261470e-01,
                         -9.24446523e-01,  -9.18638289e-01,  -9.27959383e-01,
                         -9.38464284e-01,  -9.20669973e-01,  -9.27729785e-01,
                         -9.27580059e-01,  -9.27061737e-01,  -9.27902997e-01,
                         -9.47705925e-01,  -9.40429926e-01,  -9.18330908e-01,
                         -9.24896121e-01,  -9.19265449e-01,  -9.39398944e-01,
                         -9.33326960e-01,  -9.29682612e-01,  -9.42670941e-01,
                         -9.38770950e-01,  -9.40499365e-01,  -9.19622600e-01,
                         -9.39153194e-01,  -9.26713049e-01,  -9.40884233e-01,
                         -9.33839500e-01,  -9.31127429e-01,  -9.33024943e-01,
                         -9.21063364e-01,  -9.23971653e-01,  -9.35344219e-01,
                         -9.27008092e-01,  -9.33829069e-01,  -9.36385036e-01,
                         -9.52099919e-01,  -9.38270450e-01,  -9.45905626e-01,
                         -9.38396811e-01,  -9.26956832e-01,  -9.24975038e-01,
                         -9.28293407e-01,  -9.26131487e-01,  -9.40694213e-01,
                         -9.43829060e-01,  -9.27282095e-01,  -9.31731343e-01,
                         -9.35935676e-01,  -9.31101263e-01,  -9.30446684e-01,
                         -9.38283503e-01,  -9.42831993e-01,  -9.35110927e-01,
                         -9.43243146e-01,  -9.53357935e-01,  -9.38821733e-01,
                         -9.45751190e-01,  -9.60801959e-01,  -9.38506722e-01,
                         -9.35885370e-01,  -9.40298080e-01,  -9.32748139e-01,
                         -9.26170170e-01,  -9.35202718e-01,  -9.44506705e-01,
                         -9.28525686e-01,  -9.42576289e-01,  -9.32218790e-01,
                         -9.46088493e-01,  -9.32721436e-01,  -9.23956275e-01,
                         -9.30264533e-01,  -9.38318968e-01,  -9.40971851e-01,
                         -9.44077909e-01,  -9.40052688e-01,  -9.31077421e-01,
                         -9.40218389e-01,  -9.36338246e-01,  -9.47070837e-01,
                         -9.48092997e-01,  -9.35730755e-01,  -9.20045197e-01,
                         -9.31392908e-01,  -9.47007895e-01,  -9.27363157e-01,
                         -9.29244041e-01,  -9.29472566e-01,  -9.33435977e-01,
                         -9.44324315e-01,  -9.31537151e-01,  -9.26855266e-01,
                         -9.42777336e-01,  -9.19441342e-01,  -9.27596152e-01,
                         -9.19276059e-01,  -9.24254596e-01,  -9.20112371e-01,
                         -9.29104924e-01,  -9.03060436e-01,  -9.25366879e-01,
                         -9.20928955e-01,  -9.47837055e-01,  -9.42730308e-01,
                         -9.37224627e-01,  -9.44737434e-01,  -9.20445621e-01,
                         -9.40462351e-01,  -9.35939908e-01,  -9.23688173e-01,
                         -9.36406314e-01,  -9.11677003e-01,  -9.34646547e-01,
                         -9.27754164e-01,  -9.17442143e-01,  -9.21499848e-01,
                         -9.16844666e-01,  -9.24370408e-01,  -9.20828581e-01,
                         -9.36730444e-01,  -9.27050352e-01,  -9.34376717e-01,
                         -9.35775936e-01,  -9.32604313e-01,  -9.26525116e-01,
                         -9.39717293e-01,  -9.17988479e-01,  -9.11177576e-01,
                         -9.19560134e-01,  -9.22214746e-01,  -9.31771219e-01,
                         -9.30248857e-01,  -9.27680016e-01,  -9.14572179e-01,
                         -9.14812922e-01,  -9.07243192e-01,  -9.33900058e-01,
                         -9.37048256e-01,  -9.38317120e-01,  -9.37804580e-01,
                         -9.27788377e-01,  -9.38863754e-01,  -9.16984797e-01,
                         -9.27006066e-01,  -9.31595683e-01,  -9.45629776e-01,
                         -9.28708911e-01,  -9.36487675e-01,  -9.34918642e-01,
                         -9.26201940e-01,  -9.31203485e-01,  -9.33827937e-01,
                         -9.32618439e-01,  -9.25774455e-01,  -9.20716107e-01,
                         -9.01262760e-01,  -9.30345535e-01,  -9.19752717e-01,
                         -9.38404918e-01,  -9.31209922e-01,  -9.22567308e-01,
                         -9.20936644e-01,  -9.20981884e-01,  -9.23995376e-01,
                         -9.21913445e-01,  -9.18453336e-01,  -9.27348137e-01,
                         -9.43314314e-01,  -9.47293937e-01,  -9.24288690e-01,
                         -9.26263332e-01,  -9.11835134e-01,  -9.13862228e-01,
                         -9.31446016e-01,  -9.28329885e-01,  -9.18157518e-01,
                         -9.21181798e-01,  -9.06290948e-01,  -9.19325352e-01,
                         -9.24280465e-01,  -9.36217129e-01,  -9.28838313e-01,
                         -9.15878356e-01,  -9.19903219e-01,  -9.19502616e-01,
                         -9.08981502e-01,  -9.37630296e-01,  -9.39425111e-01,
                         -9.28138971e-01,  -9.33371902e-01,  -9.32972372e-01,
                         -9.30018485e-01,  -9.31003213e-01,  -9.26369071e-01,
                         -9.23890948e-01,  -9.23578382e-01,  -9.31319237e-01,
                         -9.35686231e-01,  -9.33435619e-01,  -9.21789587e-01,
                         -9.38565254e-01,  -9.18725431e-01,  -9.13269222e-01,
                         -9.23709512e-01,  -9.37129259e-01,  -9.32158232e-01,
                         -9.34297562e-01,  -9.40413654e-01,  -9.38380420e-01,
                         -9.21767473e-01,  -9.42195475e-01,  -9.18775022e-01,
                         -9.34452057e-01,  -9.24139261e-01,  -9.31350946e-01,
                         -9.21155512e-01,  -9.22331393e-01,  -9.39226508e-01,
                         -9.27636743e-01,  -9.45917070e-01,  -9.28630650e-01,
                         -9.27995086e-01,  -9.05468583e-01,  -9.24722135e-01,
                         -9.28216934e-01,  -9.33548629e-01,  -9.37025368e-01,
                         -9.30137455e-01,  -9.25588965e-01,  -9.35467899e-01,
                         -9.35753644e-01,  -9.44862068e-01,  -9.29517448e-01,
                         -9.38507974e-01,  -9.35956776e-01,  -9.43612158e-01,
                         -9.36061144e-01,  -9.49067235e-01,  -9.41909492e-01,
                         -9.47624981e-01,  -9.33438301e-01,  -9.62042689e-01,
                         -9.39213097e-01,  -9.46978152e-01,  -9.41041470e-01,
                         -9.29840386e-01,  -9.27951276e-01,  -9.37932670e-01,
                         -9.44591641e-01,  -9.12718475e-01,  -9.25186694e-01,
                         -9.38647985e-01,  -9.40062821e-01,  -9.45957005e-01,
                         -9.28032041e-01,  -9.42991555e-01,  -9.42310154e-01,
                         -9.29299295e-01,  -9.36763585e-01,  -9.30566013e-01,
                         -9.21916962e-01,  -9.35398996e-01,  -9.32123184e-01,
                         -9.32600319e-01,  -9.33075726e-01,  -9.20273125e-01,
                         -9.28453565e-01,  -9.41125333e-01,  -9.32223320e-01,
                         -9.36387897e-01,  -9.38003421e-01,  -9.27924812e-01,
                         -9.43523884e-01,  -9.41982269e-01,  -9.19819057e-01,
                         -9.26598132e-01,  -9.39854860e-01,  -9.40386057e-01,
                         -9.31058109e-01,  -9.28887069e-01,  -9.47015524e-01,
                         -9.31113541e-01,  -9.45717037e-01,  -9.33651328e-01,
                         -9.28658605e-01,  -9.33677375e-01,  -9.32485104e-01,
                         -9.52748835e-01,  -9.21449900e-01,  -9.39082325e-01,
                         -9.58961606e-01,  -9.32300389e-01,  -9.37435031e-01,
                         -9.16372120e-01,  -9.35891569e-01,  -9.39118922e-01,
                         -9.31204379e-01,  -9.39624667e-01,  -9.49112296e-01,
                         -9.30886924e-01,  -9.39719081e-01,  -9.39845443e-01,
                         -9.28407788e-01,  -9.33137715e-01,  -9.48162556e-01,
                         -9.39874172e-01,  -9.46021080e-01,  -9.25451756e-01,
                         -2.61356868e-02,   1.04832510e-02,  -2.08007824e-03,
                          9.74456407e-03,  -2.85421330e-02,  -1.12450719e-02,
                         -8.81475769e-03,   8.96825921e-03,  -1.23974285e-03,
                         -5.77370590e-03,   2.11229082e-03,  -6.63879653e-03,
                          1.00639258e-02,  -1.43740075e-02,  -1.95401441e-02,
                         -2.82272208e-03,  -2.25750897e-02,  -9.57538560e-03,
                          6.52599009e-03,   3.28911934e-03,   7.05587678e-03,
                          1.08662331e-02,   8.34009238e-03,  -3.84398317e-03,
                         -4.55197500e-04,   4.54254961e-03,  -3.52180144e-03,
                          9.57951602e-03,   9.12185106e-03,  -1.27361184e-02,
                         -4.94256709e-03,   2.25541112e-03,   4.98390011e-03,
                         -8.59852787e-03,  -1.88543019e-03,   9.76346340e-03,
                         -1.11800991e-02,   1.34939477e-02,  -9.06888209e-03,
                          4.38039145e-03,   1.86366175e-04,  -7.22285174e-03,
                          5.91504481e-03,  -9.97269992e-03,   7.84597360e-03,
                         -4.63939551e-03,  -1.19779091e-02,   1.74056962e-02,
                         -7.20704347e-03,   3.06293089e-03,   4.50930465e-03,
                          1.29843531e-02,   3.25537496e-03,  -7.88596924e-03,
                          1.26602864e-02,   2.12138146e-02,   1.13043338e-02,
                          1.49312764e-02,   1.12785110e-02,   9.01133195e-03,
                          5.25767310e-03,   3.35848588e-03,   7.05699250e-03,
                          1.05126081e-02,   1.52715817e-02,   2.29570530e-02,
                          1.00469878e-02,   1.20036136e-02,  -6.74933719e-04,
                          2.09039003e-02,   1.58762967e-03,   7.97337573e-03,
                          3.34093813e-03,   1.54319173e-03,  -1.86775476e-02,
                         -1.58660524e-02,  -7.08848424e-03,   2.27026995e-02,
                         -1.75501611e-02,   6.69828756e-03,  -6.84872642e-03,
                          1.23750847e-02,   1.25845019e-02,  -1.72664702e-04,
                          2.93155760e-03,   1.31736854e-02,  -1.18975788e-02,
                          9.34845593e-05,   9.35751386e-03,  -7.36581255e-03,
                          9.99107957e-03,  -9.29717720e-03,   2.38049845e-03,
                          1.72805402e-03,  -2.62479600e-03,   2.65583321e-02,
                         -1.49236675e-02,   9.22414474e-03,   3.10524809e-03,
                          6.76068198e-03,   8.83213896e-03,  -5.80827473e-03,
                          6.31294167e-03,   1.77211277e-02,   1.41147748e-02,
                         -3.13326088e-03,   5.15210163e-03,  -5.43692149e-03,
                         -7.69115472e-03,   3.92617797e-03,  -8.63610487e-03,
                          1.48189894e-03,  -5.87989390e-03,   5.51572070e-04,
                         -3.02777975e-03,   6.45097485e-03,   1.67369866e-03,
                          4.35176212e-03,   2.30282219e-03,   1.30286522e-03,
                          8.12987855e-04,  -9.80882347e-03,   3.39137763e-03,
                          1.36744289e-04,   1.39736505e-02,  -7.14383787e-03,
                         -5.88823110e-03,   2.77649611e-03,   3.47021827e-03,
                          1.58945154e-02,  -3.91999632e-03,   5.62581047e-03,
                         -3.48222861e-03,   5.76227764e-03,   5.45932772e-03,
                         -3.48963053e-03,  -1.76080987e-02,   5.62931038e-03,
                         -1.47222131e-02,   4.98627033e-03,   4.64581302e-04,
                          1.06331911e-02,   4.29738592e-03,  -3.65393702e-03,
                         -1.88258171e-04,   1.01163127e-02,  -6.89834822e-03,
                          5.07601956e-03,  -4.79718763e-03,   5.52201318e-03,
                          9.15039796e-03,  -5.69945993e-03,   1.06404268e-03,
                          5.50427847e-03,  -1.43503956e-02,   3.25510465e-03,
                         -1.44042031e-04,   9.14053619e-03,   9.42281913e-03,
                         -7.45484745e-03,   3.06595955e-03,   6.70612557e-03,
                         -1.47117618e-02,   1.10008777e-03,  -4.51606140e-03,
                          4.75202175e-03,  -3.67466593e-03,  -1.53564792e-02,
                         -2.36545247e-03,   9.16729448e-04,  -5.01781097e-03,
                          3.04728188e-03,   8.95515375e-04,  -1.22343283e-02,
                          6.61855971e-04,   9.77620133e-04,  -7.20080594e-03,
                          3.25331674e-03,  -5.59152570e-03,  -5.64396102e-03,
                         -1.82817783e-03,   1.46711641e-03,  -1.25812301e-02,
                          1.80663392e-02,  -1.63266696e-02,   1.10082654e-02,
                         -7.76036875e-03,   7.62059586e-03,  -1.34551227e-02,
                         -6.48454623e-03,   1.06264548e-02,  -2.20706454e-03,
                          8.68446473e-03,  -8.74467660e-04,   5.04463864e-03,
                          3.64214135e-03,  -3.79454158e-03,  -1.97259407e-03,
                         -1.57746265e-03,   1.00605087e-02,   1.75287179e-03,
                         -1.91850914e-03,   9.27114673e-03,  -6.30041817e-03,
                         -1.09857006e-03,  -5.81485871e-03,   2.43422319e-03,
                          1.98091753e-03,   8.19999352e-03,   7.48564629e-03,
                          6.68059383e-03,   1.56511262e-03,   6.75051531e-04,
                         -2.96071405e-03,  -7.79673283e-05,   6.44315733e-03,
                          1.81347155e-03,  -3.43862246e-03,  -5.45942457e-03,
                          6.33166078e-03,  -2.34206929e-03,   1.00045595e-02,
                         -7.08518550e-04,  -5.49974572e-03,  -7.61969481e-03,
                          4.59664175e-03,  -1.42078649e-03,  -3.95308202e-03,
                          1.80551538e-03,  -3.35549889e-03,   4.04559635e-03,
                         -2.08704337e-03,   6.39280118e-03,   1.43309496e-03,
                          6.72161521e-04,   3.90300964e-04,  -4.34852531e-03,
                         -1.24412570e-02,  -1.24235568e-03,   1.69365131e-03,
                          5.40486816e-03,   1.40746613e-03,   6.59458758e-03,
                         -4.15590097e-04,  -2.47096829e-03,  -7.60732393e-04,
                          2.48701219e-03,  -6.65443856e-03,   5.46015939e-03,
                         -7.34230445e-04,   4.70744539e-03,  -7.88423605e-03,
                          1.61749282e-04,   5.91535680e-03,   6.88272668e-03,
                         -1.36942510e-03,   2.63972417e-03,  -3.19700688e-03,
                         -3.09669599e-03,   1.31499348e-03,   1.63641293e-03,
                          2.61292420e-03,  -1.75809045e-03,  -9.31775372e-04,
                          3.68040433e-04,   4.44482360e-03,  -6.18124977e-05,
                         -1.00496074e-03,  -2.72712391e-03,  -2.82253511e-03,
                         -9.68208653e-04,   1.34065689e-03,   1.80116307e-03,
                          9.01718158e-05,   2.81342841e-03,  -3.53733264e-03,
                          3.21742403e-03,  -4.96106455e-03,   5.50982950e-04,
                          9.58589197e-04,   1.90780847e-03,  -1.56520971e-03,
                         -2.07822770e-03,  -1.46301354e-05,   1.66978291e-03,
                         -3.15452344e-04,  -1.06111111e-03,  -8.39329697e-03,
                          6.24663150e-03,  -4.94172145e-03,   4.27579740e-04,
                         -5.56178717e-03,  -9.91855282e-04,   7.02218793e-04,
                         -5.69446338e-03,   1.66531280e-03,  -1.17429195e-03,
                         -7.14638096e-04,  -2.43226881e-03,   6.40205340e-04,
                         -4.39063471e-04,   2.34787678e-03,   4.76834306e-04,
                          2.22161834e-04,   2.93802377e-03,  -2.14596582e-03,
                         -1.19639997e-04,   1.41587283e-03,  -2.39409599e-03,
                         -2.96523259e-03,   7.59337982e-03,  -3.27490503e-04,
                          2.36802362e-03,   1.21911790e-03,  -1.88119564e-04,
                          6.39208732e-03,  -6.69722038e-04,   5.49685583e-03,
                         -2.21159006e-03,  -1.43161870e-03,   1.37174677e-03,
                         -1.36889832e-03,  -1.57743494e-03,   2.30007077e-04,
                          1.08710708e-04,   5.39691932e-03,   9.67681932e-04,
                         -3.26902093e-03,   1.27519888e-04,   2.61105993e-03,
                          9.10984119e-04,   2.61527370e-03,   3.75691627e-04,
                         -1.06468715e-03,   2.96541280e-03,   2.26130197e-03,
                          2.95228651e-03,  -2.82457261e-03,  -2.11702427e-03,
                          2.34830659e-03,   1.13451120e-03,   5.29572787e-03,
                          5.87374670e-04,   1.99544383e-03,  -2.32490944e-03,
                          3.58141703e-03,  -2.17986945e-03,   1.27700088e-03,
                         -4.50942229e-04,   6.80900819e-04,  -4.95277578e-03,
                          4.76918183e-03,  -5.84870018e-03,   4.54769190e-03,
                         -2.36365758e-03,  -3.65499733e-03,   7.99848419e-03,
                         -1.44467561e-03,   5.31355990e-03,  -1.45439210e-03,
                         -1.23936858e-03,   1.26953679e-03,  -1.29568530e-03,
                         -9.05405090e-04,   1.62524101e-03,  -4.04509716e-03,
                          6.53747376e-03,  -2.76020286e-03,  -3.37703177e-03,
                          2.24552141e-03,  -3.83685878e-03,   3.73518234e-03,
                          1.93733210e-03,   1.21227070e-03,   5.13780443e-03,
                         -2.37001968e-03,  -1.92527325e-04,   1.38087408e-03,
                          5.43532777e-04,   1.64760556e-03,  -6.26931479e-03,
                          4.59366851e-03,  -7.45055778e-03,  -1.90446107e-03,
                          2.43937247e-04,  -6.92706089e-03,  -3.51704727e-03,
                          1.40577520e-03,  -3.71042686e-03,   6.97068777e-03,
                         -7.74651486e-03,   1.84291892e-03,  -1.29704364e-03,
                          2.52142176e-03,   1.28005026e-03,  -9.26986453e-04,
                          2.74728448e-03,  -2.88449298e-03,   3.66247538e-03,
                         -2.26105237e-03,   3.66168516e-03,   2.95024202e-03,
                         -2.87233014e-03,  -2.22853501e-03,   2.29473429e-04,
                         -2.79356586e-03,   1.50105474e-03,  -1.37975835e-03,
                          2.08393834e-03,  -2.03110088e-04,   1.41797273e-03,
                         -1.34077470e-03,   2.66305194e-03,  -7.59691466e-03,
                          5.54886879e-03,  -1.97233079e-04,  -5.44594508e-03,
                          2.30543502e-03,  -4.20686742e-03,   5.57396375e-03,
                         -2.47191079e-03,   1.97707117e-03,   7.26010278e-03,
                          1.76339911e-03,   3.86581407e-03,  -4.14122920e-03,
                          4.66225902e-03,   1.88111945e-03,   4.99883527e-03,
                         -2.30526854e-03,   3.62024817e-04,  -7.44603900e-03,
                         -5.01153176e-04,  -2.74590537e-04,   1.81248051e-03,
                          2.41521979e-03,  -2.50013149e-03,   3.41528771e-03,
                         -6.89508379e-05,   7.44176283e-03,  -4.95511806e-04,
                          5.29725943e-03,   8.29062983e-03,  -5.58853149e-03,
                          6.82417862e-03,  -1.21574625e-02,   5.41058580e-05,
                          1.25045737e-03,  -1.25905106e-04,  -9.90448403e-04,
                         -1.08314981e-03,  -4.87528648e-03,   9.84606086e-05,
                          1.15024333e-04,  -3.43421474e-03,   3.92312882e-03,
                         -5.27190091e-03,   7.06119230e-03,  -4.69051441e-03,
                          1.82264042e-03,  -1.34288147e-03,   4.89817793e-03,
                          4.10021516e-03,   5.30674728e-03,  -4.22042329e-03,
                          7.37854373e-03,  -1.37983384e-02,   9.05971974e-03,
                         -9.66726895e-03,   9.16133448e-03,  -8.41511413e-03,
                          2.56016990e-03,   1.85400760e-03,  -1.64281037e-02,
                          4.30205697e-03,  -2.79701711e-03,  -3.25705903e-03,
                          8.41837842e-03,  -1.21926488e-02,  -7.03956233e-03,
                          1.63391791e-03,  -6.66779373e-03,   1.48588396e-03,
                         -9.34006996e-04,  -9.40320606e-04,   6.71794231e-04,
                         -6.45457208e-03,   1.07935886e-03,  -1.55887532e-03,
                          3.57389054e-03,   2.21815309e-03,   8.37115478e-03,
                          5.29639330e-03,  -6.14755414e-03,   4.19007521e-03,
                          4.59366152e-03,   3.03099537e-03,   7.46779377e-03,
                         -4.04288666e-03,   1.29411905e-03,   6.22849446e-03,
                         -4.96344175e-03,   5.21309627e-03,  -4.61435597e-03,
                          4.85053810e-04,   1.51873421e-04,  -1.81900198e-03,
                          1.06089618e-02,  -9.01205291e-04,   4.18482861e-03,
                          1.80080964e-03,  -4.32049856e-03,  -1.11753172e-04,
                         -9.08668619e-03,   6.86379289e-03,  -1.40227387e-02,
                          5.60373720e-03,  -1.05258385e-02,   4.20546765e-03,
                         -9.15539451e-03,   3.52181541e-03,  -1.49753541e-02,
                          3.12854815e-03,  -1.06767137e-02,  -3.29062319e-03,
                         -6.23288157e-04,  -8.16708058e-03,   1.18368473e-02,
                         -1.29495971e-02,  -2.13718484e-03,   7.69042003e-04,
                          2.66003725e-03,  -9.06489044e-03,   1.19541585e-03,
                         -2.85544083e-03,   3.00321123e-03,   2.12620711e-03,
                         -6.10692101e-03,   1.65464822e-02,  -1.32468911e-02,
                          1.46266082e-02,  -3.79482564e-03,   6.12625666e-03,
                         -1.65455672e-03,   4.07473184e-03,   1.03479829e-02,
                         -1.65351853e-02,  -9.25878704e-01,  -9.40345883e-01,
                         -9.34472859e-01,  -9.31926906e-01,  -9.32167411e-01,
                         -9.32966053e-01,  -9.30137455e-01,  -9.39177036e-01,
                         -9.37604010e-01,  -9.21730876e-01,  -9.38666403e-01,
                         -9.24289942e-01,   1.24103890e-03,  -8.98223836e-03,
                          3.38633242e-03,   4.20352677e-03,   4.30081622e-04,
                         -1.89263781e-03,   6.01819763e-03,  -9.05542355e-03,
                          1.51769603e-02,  -1.23120733e-02,   8.93271994e-03,
                          5.37647447e-03,   4.86051780e-04,   1.55915730e-02,
                         -9.23833810e-03,   6.73747202e-03,   6.67376770e-03,
                         -7.22754328e-03,   8.12170096e-03,   4.29535517e-03,
                          8.08039506e-04,  -1.09295845e-02,   9.96907521e-03,
                         -2.05682516e-02,   2.71832920e-03,  -2.19004322e-03,
                          3.29921697e-03,   6.44321990e-05,   1.21988161e-02,
                         -3.61589598e-03,   1.04467832e-02,  -5.53836906e-03,
                          5.74825052e-03,  -1.08453110e-02,   9.31805931e-03,
                         -7.73844076e-03,  -8.39482891e-05,   7.04700593e-03,
                         -2.26874724e-02,   8.88588466e-03,  -8.61188304e-03,
                          6.24673534e-03,   4.38084872e-03,  -9.83375218e-03,
                          1.42579228e-02,   9.09035932e-03,  -1.33089256e-02,
                          1.33507233e-02,  -8.89589172e-03,  -3.59883322e-03,
                          9.84083489e-03,  -1.26950005e-02,   2.37211259e-03,
                         -1.31329000e-02,  -5.09952754e-03,   6.23060809e-03,
                          1.08964369e-03,   9.91895515e-03,   9.68488678e-03,
                         -6.26883656e-03,   9.38289973e-04,  -2.36585434e-03,
                          4.23369510e-03,  -1.20815327e-02,  -9.27977145e-01,
                         -9.45858657e-01,  -9.31882441e-01,  -9.47573364e-01,
                         -9.36853409e-01,  -9.40576673e-01,  -9.35988903e-01,
                         -9.24744666e-01,  -9.36342299e-01,  -9.28769231e-01,
                         -9.53515053e-01,  -9.39604521e-01,  -9.34279263e-01,
                         -9.49497700e-01,  -9.16635275e-01,  -9.56353545e-01,
                         -9.26209152e-01,  -9.39080358e-01,  -9.28760529e-01,
                         -9.31917965e-01,  -9.31260049e-01,  -9.31770682e-01,
                         -9.26372528e-01,  -9.31287766e-01,  -9.29366171e-01,
                         -9.33721423e-01,  -9.37607348e-01,  -9.49309528e-01,
                         -9.46449637e-01,  -9.53137159e-01,  -9.43718612e-01,
                         -9.34777737e-01,  -9.33639228e-01,  -9.61485803e-01,
                         -9.39712703e-01,  -9.26318347e-01,  -9.34139669e-01,
                         -9.37071383e-01,  -9.28754866e-01,  -9.48263347e-01,
                         -9.31193054e-01,  -9.47654366e-01,  -9.28661942e-01,
                         -9.57682252e-01,  -9.34853315e-01,  -9.32758808e-01,
                         -9.34875727e-01,  -9.45142508e-01,  -9.27039921e-01,
                         -9.39854085e-01,  -9.28709328e-01,  -9.33592081e-01,
                         -9.33833480e-01,  -9.23674226e-01,  -9.29702818e-01,
                         -9.20792460e-01,  -9.27090347e-01,  -9.41987693e-01,
                         -9.24006164e-01,  -9.23330247e-01,  -9.08112109e-01,
                         -9.27570939e-01,  -9.28956747e-01,  -9.29868519e-01,
                         -9.20755625e-01,  -9.18779969e-01,  -9.11859930e-01,
                         -9.27691400e-01,  -9.32408750e-01,  -9.29197550e-01,
                         -9.18714941e-01,  -9.29472208e-01,  -9.21099365e-01,
                         -9.32961404e-01,  -9.16436017e-01,  -9.31214035e-01,
                         -9.23709869e-01,  -9.23714399e-01,  -9.15316224e-01,
                         -9.23367858e-01,  -9.19071019e-01,  -9.20829654e-01,
                         -9.28162277e-01,  -9.18492317e-01,  -9.33440745e-01,
                         -9.27638888e-01,  -9.19616938e-01,  -9.38903153e-01,
                         -9.16602135e-01,  -9.33298707e-01,  -9.21997845e-01,
                         -9.24703360e-01,  -9.07591641e-01,  -9.20431435e-01,
                         -9.18522835e-01,  -9.15838122e-01,  -9.24956739e-01,
                         -9.37378764e-01,  -9.20845091e-01,  -9.36879337e-01,
                         -9.21040416e-01,  -9.20794904e-01,  -9.18796778e-01,
                         -9.26014662e-01,  -9.14717138e-01,  -9.34177816e-01,
                         -9.35680330e-01,  -9.29502547e-01,  -9.19825852e-01,
                         -9.35224831e-01,  -9.15666640e-01,  -9.14998829e-01,
                         -9.22623813e-01,  -9.19011354e-01,  -9.22882855e-01,
                         -9.34339404e-01,  -9.29732144e-01,  -9.46886420e-01,
                         -9.29734707e-01,  -9.26662683e-01,  -9.33325112e-01,
                         -9.27703798e-01,  -9.33398962e-01,  -9.41033959e-01,
                         -9.38370347e-01,  -9.24147248e-01,  -9.41023886e-01,
                         -9.10859525e-01,  -9.38951850e-01,  -9.19738710e-01,
                         -9.21228111e-01,  -9.25506234e-01,  -9.22912359e-01,
                         -9.15873468e-01,  -9.39576209e-01,  -9.19267774e-01,
                         -9.22980011e-01,  -9.23497438e-01,  -9.27919447e-01,
                         -9.50152516e-01,  -9.22379911e-01,  -9.31522608e-01,
                         -9.31686759e-01,  -9.33680236e-01,  -9.21253920e-01,
                         -9.17092502e-01,  -9.16541576e-01,  -9.22987282e-01,
                         -9.38149571e-01,  -9.31591570e-01,  -9.31149244e-01,
                         -9.50878382e-01,  -9.41424370e-01,  -9.47716534e-01,
                         -9.41814244e-01,  -9.37400162e-01,  -9.39622462e-01,
                         -9.35779035e-01,  -9.31093693e-01,  -9.19719934e-01,
                         -9.22138751e-01,  -9.34251666e-01,  -9.24203098e-01,
                         -9.22183573e-01,  -9.17040884e-01,  -9.16660130e-01,
                         -9.32225645e-01,  -9.16708887e-01,  -9.05702293e-01,
                         -9.12020802e-01,  -9.14144516e-01,  -9.19875145e-01,
                         -9.30779457e-01,  -9.28689241e-01,  -9.24506605e-01,
                         -9.09846604e-01,  -9.25221145e-01,  -9.27931249e-01,
                         -9.26687300e-01,  -9.24343765e-01,  -9.03995156e-01,
                         -9.27039683e-01,  -9.29737926e-01,  -9.27372456e-01,
                         -9.26611066e-01,  -9.12849545e-01,  -9.05370414e-01,
                         -9.41623330e-01,  -9.24569607e-01,  -9.26669240e-01,
                         -9.18193996e-01,  -9.29359555e-01,  -9.30384696e-01,
                         -9.35989022e-01,  -9.26067531e-01,  -9.36577082e-01,
                         -9.25022721e-01,  -9.24133003e-01,  -9.33978021e-01,
                         -9.22771275e-01,  -9.33616519e-01,  -9.22381938e-01,
                         -9.36638415e-01,  -9.23817277e-01,  -9.25658822e-01,
                         -9.37918901e-01,  -9.25573528e-01,  -9.06038284e-01,
                         -9.23307657e-01,  -9.20902431e-01,  -9.19560730e-01,
                         -9.13955986e-01,  -9.44067121e-01,  -9.23856735e-01,
                         -9.16082442e-01,  -9.16927516e-01,  -9.15249407e-01,
                         -9.20842230e-01,  -9.26030576e-01,  -9.15301979e-01,
                         -9.16878402e-01,  -9.16626692e-01,  -9.29529250e-01,
                         -9.15114760e-01,  -9.13370728e-01,  -9.16672528e-01,
                         -9.30894673e-01,  -9.14246380e-01,  -9.27261531e-01,
                         -9.31519628e-01,  -9.37560737e-01,  -9.44393516e-01,
                         -9.51688528e-01,  -9.23025191e-01,  -9.29088175e-01,
                         -9.36472952e-01,  -9.21907961e-01,  -9.30091262e-01,
                         -9.22212362e-01,  -9.22684252e-01,  -9.28584695e-01,
                         -9.09644842e-01,  -9.37921345e-01,  -9.32835639e-01,
                         -9.37629580e-01,  -9.24302399e-01,  -9.23261344e-01,
                         -9.46702480e-01,  -9.18620646e-01,  -9.59074140e-01,
                         -9.31273341e-01,  -9.29470181e-01,  -8.93995583e-01,
                         -9.23309982e-01,  -9.24614906e-01,  -9.32828963e-01,
                         -9.25816774e-01,  -9.14634585e-01,  -9.18291390e-01,
                         -9.48392153e-01,  -9.38379407e-01,  -9.26657200e-01,
                         -9.54565704e-01,  -9.24178183e-01,  -9.29467261e-01,
                         -9.19921994e-01,  -9.22891378e-01,  -9.38936949e-01,
                         -9.25052583e-01,  -9.27038372e-01,  -9.31615412e-01,
                         -9.28112149e-01,  -9.12232995e-01,  -9.45313096e-01,
                         -9.46491241e-01,  -9.24940407e-01,  -9.22476590e-01,
                         -9.26179349e-01,  -9.57879782e-01,  -9.24136162e-01,
                         -9.13138688e-01,  -9.22412992e-01,  -9.25560117e-01,
                         -9.35100377e-01,  -9.25552011e-01,  -9.23746288e-01,
                         -9.26058650e-01,  -9.30198610e-01,  -9.18247044e-01,
                         -9.31141198e-01,  -9.50926602e-01,  -9.52603221e-01,
                         -9.41983223e-01,  -9.21541989e-01,  -8.99004400e-01,
                         -9.24960613e-01,  -9.29810286e-01,  -9.17871475e-01,
                         -9.26503599e-01,  -9.35219705e-01,  -9.39559579e-01,
                         -9.35671210e-01,  -9.20610189e-01,  -9.27657723e-01,
                         -9.10879314e-01,  -9.38619077e-01,  -9.42679405e-01,
                         -9.22172427e-01,  -9.23976898e-01,  -9.21227992e-01,
                         -9.28741336e-01,  -9.34516788e-01,  -9.18687999e-01,
                         -9.35761392e-01,  -9.32986140e-01,  -9.17347848e-01,
                         -9.12049592e-01,  -9.22064602e-01,  -9.30244446e-01,
                         -9.20683980e-01,  -9.23032522e-01,  -9.20740604e-01,
                         -9.31576967e-01,  -9.28846002e-01,  -9.45626676e-01,
                         -9.31802511e-01,  -9.15467739e-01,  -9.38038647e-01,
                         -9.20626581e-01,  -9.16477323e-01,  -9.25754488e-01,
                         -9.54442084e-01,  -9.49797690e-01,  -9.32741404e-01,
                         -9.23839271e-01,  -9.44934070e-01,  -9.22233760e-01,
                         -9.15331662e-01,  -9.35630679e-01,  -9.31011081e-01,
                         -9.33138371e-01,  -9.46887791e-01,  -9.45986927e-01,
                         -9.20589685e-01,  -9.44715858e-01,  -9.32590127e-01,
                         -9.24557328e-01,  -9.28857327e-01,  -9.24267828e-01,
                         -9.03510749e-01,  -9.21879292e-01,  -9.18823779e-01,
                         -9.06192482e-01,  -9.23070312e-01,  -9.33741271e-01,
                         -9.17452157e-01,  -9.33440387e-01,  -9.43542123e-01,
                         -9.35088396e-01,  -9.25535262e-01,  -9.20984387e-01,
                         -9.24771190e-01,  -9.29442585e-01,  -9.09246206e-01,
                         -2.97850221e-02,   8.21585022e-03,   6.47299318e-03,
                         -1.58259738e-02,   5.35869086e-03,   1.45279467e-02,
                         -5.06267825e-05,  -8.11914355e-03,  -1.20712137e-02,
                         -4.05393355e-03,  -7.52487965e-03,   1.49317896e-02,
                          4.68592625e-03,   5.14923944e-04,   6.49224594e-03,
                          7.32176937e-03,   1.88597143e-02,  -7.81573635e-03,
                          3.68611491e-03,   3.10322433e-03,   9.36779194e-03,
                          8.75104591e-03,   1.95293110e-02,   1.62236914e-02,
                         -7.10452814e-03,   4.95983113e-04,  -1.99147686e-02,
                         -6.49279309e-03,  -2.56766169e-03,  -5.39721036e-03,
                         -8.46461800e-04,   9.13407654e-03,   5.43924328e-03,
                         -1.00957919e-02,   7.51605723e-03,   1.13028502e-02,
                          1.96707342e-02,   1.78872992e-03,   2.94420011e-02,
                          1.45817334e-02,   1.55303292e-02,   1.77175868e-02,
                          1.42222103e-02,   1.24252960e-02,  -1.08118020e-02,
                         -6.21317793e-03,   9.97708738e-03,   9.59065370e-03,
                          6.11726101e-03,   2.42561474e-02,   2.69208904e-02,
                          1.56777538e-02,  -5.55002596e-04,   9.36930906e-03,
                          2.16736700e-02,   4.24180366e-03,  -2.16293847e-03,
                          2.99603697e-02,   2.52143014e-02,   1.25340894e-02,
                          9.20146797e-03,   3.57131101e-02,   1.92445125e-02,
                          1.08169373e-02,  -6.10735035e-03,   9.82138794e-04,
                          6.15640404e-03,   1.07121635e-02,   6.51243422e-03,
                         -8.28931946e-03,  -8.87183659e-03,  -7.07319559e-05,
                          7.52466498e-03,   7.07757613e-03,  -9.71946213e-03,
                         -3.30754044e-03,   6.94542658e-03,  -1.36545254e-02,
                          1.59343728e-03,  -2.02384945e-02,  -4.21215547e-03,
                          7.88601022e-03,  -1.18390853e-02,  -7.42955832e-03,
                         -2.73807663e-02,   1.22523052e-03,   1.27629535e-02,
                          1.63855162e-02,   5.35694417e-04,   4.07440634e-03,
                         -9.00648069e-03,   9.98694263e-03,   1.07866584e-03,
                          5.15705021e-03,  -2.76974606e-04,  -2.23547919e-03,
                         -1.14955511e-02,   3.15467594e-03,   1.27360492e-03,
                         -2.24870797e-02,   4.12713969e-04,  -6.28153270e-04,
                         -1.81277636e-02,  -1.60984858e-03,  -1.02931424e-03,
                         -2.20027398e-02,  -1.90870464e-02,  -2.78165042e-02,
                         -1.06921000e-02,  -1.01236242e-03,  -5.88852214e-03,
                         -6.48112223e-03,  -2.95319431e-03,   2.62796320e-03,
                          4.02853359e-03,   6.63206726e-03,   2.76124920e-03,
                         -7.55829830e-03,  -1.85804802e-03,   2.90317740e-03,
                         -1.77862179e-02,  -1.01650264e-02,   2.34440472e-02,
                          1.63284503e-02,   8.54562130e-03,   6.81308983e-03,
                         -6.33240212e-03,  -2.11401656e-03,   1.76434859e-03,
                         -1.26225979e-03,   1.23107843e-02,   1.71729233e-02,
                          1.11272056e-02,   1.47887319e-02,   6.98350230e-03,
                          1.33052869e-02,   1.37606859e-02,   2.44923923e-02,
                          4.73846588e-03,   2.59243101e-02,   2.31849458e-02,
                         -1.07999509e-02,  -3.22190225e-02,  -1.52166020e-02,
                          1.33191692e-02,  -1.82058208e-03,  -6.60360372e-03,
                         -1.15566980e-02,  -1.97007833e-03,  -1.29769100e-02,
                         -1.25073800e-02,  -6.05880981e-03,   6.84150448e-03,
                          3.62516195e-03,   9.16874316e-03,   1.40140625e-02,
                          4.60682949e-03,   6.82545407e-03,  -4.27856954e-04,
                         -5.30711468e-03,   1.68223828e-02,   1.01484424e-02,
                         -4.16278280e-03,  -2.63480842e-02,  -1.22518549e-02,
                         -1.88610926e-02,   5.84585173e-03,  -1.30161569e-02,
                         -8.58973991e-03,  -2.91983765e-02,  -4.24018223e-03,
                         -1.38248755e-02,  -8.51922948e-03,   5.41841728e-04,
                          7.35292863e-03,   7.01399613e-03,   8.58973339e-03,
                         -9.27896425e-03,   1.60760451e-02,   8.21169186e-03,
                          2.19019572e-03,   2.48810020e-03,   1.64142847e-02,
                         -5.70659153e-03,  -1.60759334e-02,   6.83769991e-04,
                         -1.22883646e-02,  -2.19120760e-03,  -6.10351795e-03,
                         -7.43061909e-03,  -9.01018828e-03,   1.34354196e-02,
                          2.11021164e-03,  -4.17253422e-03,   1.15156770e-02,
                          5.47219766e-03,   5.67907095e-03,  -6.24590367e-03,
                          4.39871568e-03,   1.03210025e-02,   2.46382994e-03,
                         -1.11858929e-02,   1.64048448e-02,  -1.94950756e-02,
                         -8.76276474e-03,   3.00728646e-03,   1.13810608e-02,
                         -1.63759515e-02,   1.04012573e-02,  -1.35193402e-02,
                         -3.27685243e-03,  -1.62468739e-02,  -1.82283930e-02,
                         -2.09006499e-02,   7.58958235e-03,  -1.43578807e-02,
                         -1.18549075e-02,  -1.46969454e-02,  -2.45585777e-02,
                         -1.92211643e-02,  -1.17421569e-03,  -2.28455216e-02,
                         -1.43886795e-02,  -1.47685707e-02,  -2.98129721e-03,
                          1.82459480e-03,  -1.11334566e-02,  -6.96569122e-03,
                          1.53117292e-02,   1.09387049e-02,   1.41455876e-02,
                          5.09861950e-03,   1.99289341e-03,  -2.43653506e-02,
                         -5.10360952e-03,   8.51077493e-04,  -1.24668088e-02,
                         -2.76685674e-02,  -9.65004694e-03,   8.39733053e-03,
                          1.41035132e-02,  -1.05975894e-02,   1.46090670e-03,
                          1.22784674e-02,   1.95343643e-02,  -8.27166066e-03,
                         -1.93026313e-03,  -1.06799300e-03,   1.66858044e-02,
                         -2.26571243e-02,  -3.21346661e-03,   1.95589531e-02,
                          2.21194215e-02,   1.73528381e-02,  -7.64776999e-03,
                         -3.61140491e-03,  -1.74801908e-02,  -7.43208826e-03,
                          1.32972617e-02,  -1.04852747e-02,   2.56494479e-03,
                          2.68798694e-02,   3.53159406e-03,  -1.70904510e-02,
                         -7.32239962e-01,  -7.51010835e-01,  -7.71179438e-01,
                         -7.72038162e-01,  -7.48858571e-01,  -7.57327139e-01,
                         -7.42888451e-01,  -7.50734389e-01,  -7.67063379e-01,
                         -7.78052628e-01,  -7.43920565e-01,  -7.47129738e-01,
                         -7.66816378e-01,  -7.57744372e-01,  -7.62460947e-01,
                         -7.77224422e-01,  -7.47399271e-01,  -7.92436242e-01,
                         -7.60316372e-01,  -7.76503861e-01,  -7.83647597e-01,
                         -7.46152401e-01,  -7.57115662e-01,  -7.41460741e-01,
                         -7.55197406e-01,  -7.51481175e-01,  -7.43157804e-01,
                         -7.59762824e-01,  -7.55665481e-01,  -7.46190429e-01,
                         -7.64358222e-01,  -7.72865951e-01,  -7.80313194e-01,
                         -7.51234889e-01,  -7.61146843e-01,  -7.51386285e-01,
                         -7.39299297e-01,  -7.60366857e-01,  -7.49263585e-01,
                         -7.64316618e-01,  -7.65734434e-01,  -7.71406412e-01,
                         -7.56502450e-01,  -7.66653657e-01,  -7.66477525e-01,
                         -7.56456614e-01,  -7.63123035e-01,  -7.50478685e-01,
                         -7.65893757e-01,  -7.59824038e-01,  -7.70306349e-01,
                         -7.70441771e-01,  -7.87321210e-01,  -7.58185685e-01,
                         -7.73856401e-01,  -7.58571148e-01,  -7.82153666e-01,
                         -7.87611246e-01,  -7.60336220e-01,  -7.64363468e-01,
                         -7.40888059e-01,  -7.48901784e-01,  -7.58698463e-01,
                         -7.70820677e-01,  -7.69663990e-01,  -7.81552494e-01,
                         -7.56163061e-01,  -7.56564200e-01,  -7.71404088e-01,
                         -7.66754508e-01,  -7.61896133e-01,  -7.58836687e-01,
                         -7.83489585e-01,  -7.64772832e-01,  -7.58334100e-01,
                         -7.75144160e-01,  -7.60947645e-01,  -7.70665944e-01,
                         -7.46693075e-01,  -7.83960164e-01,  -9.44950342e-01,
                         -9.48564172e-01,  -9.52430129e-01,  -9.54203784e-01,
                         -7.61026382e-01,  -7.79890597e-01,  -7.85432339e-01,
                         -7.64218032e-01,  -7.62613416e-01,  -7.62387395e-01,
                         -7.66728103e-01,  -8.01867127e-01,  -8.08744609e-01,
                         -7.88874209e-01,  -7.81315148e-01,  -7.94444799e-01,
                         -7.96622455e-01,  -7.61414111e-01,  -7.64981210e-01,
                         -7.58971214e-01,  -9.29693639e-01,  -9.33558702e-01,
                         -9.55406189e-01,  -9.42381084e-01,  -9.80079770e-01,
                         -9.38708961e-01,  -9.43814993e-01,  -9.46400106e-01,
                         -9.36710894e-01,  -9.23827410e-01,  -9.58631814e-01,
                         -9.27331209e-01,  -7.43239522e-01,  -7.60433495e-01,
                         -7.62001693e-01,  -7.45925546e-01,  -7.18880236e-01,
                         -7.43895650e-01,  -7.44943023e-01,  -7.47435749e-01,
                         -7.37963736e-01,  -7.51019716e-01,  -7.55100965e-01,
                         -7.73940623e-01,  -7.63411164e-01,  -7.51894176e-01,
                         -7.66468108e-01,  -7.41332471e-01,  -9.17100668e-01,
                         -9.28398132e-01,  -9.12095070e-01,  -9.34247017e-01,
                         -9.32144284e-01,  -9.17947829e-01,  -9.20586407e-01,
                         -9.47545528e-01,  -7.83959270e-01,  -7.81980574e-01,
                         -7.86454022e-01,  -7.61722147e-01,  -7.58965492e-01,
                         -7.84605742e-01,  -7.71127880e-01,  -7.90906847e-01,
                         -7.48580277e-01,  -7.51572669e-01,  -7.25355089e-01,
                         -7.54065096e-01,  -7.53881335e-01,  -7.69860089e-01,
                         -7.67516255e-01,  -7.52489507e-01,  -9.22293603e-01,
                         -9.50414777e-01,  -9.47163224e-01,  -9.49461699e-01,
                         -9.16456163e-01,  -9.14605737e-01,  -9.50936258e-01,
                         -9.15390551e-01,  -9.51300085e-01,  -9.36447024e-01,
                         -9.23974454e-01,  -8.83255780e-01,  -8.92466903e-01,
                         -9.05552387e-01,  -8.98153901e-01,  -9.06767607e-01,
                         -7.70229936e-01,  -7.52933502e-01,  -7.63757765e-01,
                         -7.59773493e-01,  -7.67661870e-01,  -7.64358819e-01,
                         -7.52055466e-01,  -7.69770861e-01,  -7.76082873e-01,
                         -7.75567651e-01,  -7.60170937e-01,  -7.73318112e-01,
                         -7.43130744e-01,  -7.36914515e-01,  -7.44037986e-01,
                         -7.39353240e-01,  -7.47725308e-01,  -7.38360584e-01,
                         -7.58897305e-01,  -7.47125804e-01,  -7.71029890e-01,
                         -7.56405771e-01,  -7.91096449e-01,  -7.79247224e-01,
                         -7.28200495e-01,  -7.95982718e-01,  -7.36463487e-01,
                         -7.35586226e-01,  -7.59257197e-01,  -7.47550309e-01,
                         -7.59153485e-01,  -7.37912476e-01,  -7.53242373e-01,
                         -7.23935246e-01,  -7.48591959e-01,  -7.61008263e-01,
                         -7.57951558e-01,  -7.42625177e-01,  -7.57375181e-01,
                         -7.41943419e-01,  -7.36012638e-01,  -7.41214514e-01,
                         -7.63926804e-01,  -7.51609743e-01,  -7.89302468e-01,
                         -7.66579151e-01,  -7.59746730e-01,  -7.72685468e-01,
                         -4.02929336e-02,  -7.44259451e-03,   3.37514244e-02,
                         -8.04251991e-03,  -8.39073968e-04,   2.42152177e-02,
                          3.31550129e-02,   5.46567515e-02,  -7.51783907e-01,
                         -7.20439494e-01,  -7.26067603e-01,  -7.41702735e-01,
                         -7.22088993e-01,  -7.72405267e-01,  -7.68127561e-01,
                         -7.56788313e-01,  -7.55755365e-01,  -7.41053462e-01,
                         -7.45843530e-01,  -7.57385910e-01,  -7.47951150e-01,
                         -7.39637375e-01,  -7.66187012e-01,  -8.00071716e-01,
                         -7.57978380e-01,  -7.82212615e-01,  -7.19151199e-01,
                         -7.72676885e-01,  -7.38800287e-01,  -7.50240624e-01,
                         -7.45007694e-01,  -7.53441334e-01,  -7.54809439e-01,
                         -7.61326730e-01,  -7.67568886e-01,  -7.37186849e-01,
                         -7.56695390e-01,  -7.61621356e-01,  -7.68492103e-01,
                         -7.53232121e-01,  -7.74509728e-01,  -7.37146735e-01,
                         -7.39902794e-01,  -7.64501274e-01,  -7.44260013e-01,
                         -7.64525354e-01,  -7.24153996e-01,  -7.74334371e-01,
                         -7.61935890e-01,  -7.42497444e-01,  -7.70971775e-01,
                         -7.37348676e-01,  -7.54555106e-01,  -7.57049084e-01,
                         -7.76002944e-01,  -7.36910582e-01,  -7.45062947e-01,
                         -7.83658803e-01,  -7.79898524e-01,  -7.52781093e-01,
                         -7.55626142e-01,  -7.56984890e-01,  -7.50282109e-01,
                         -7.83134043e-01,   1.74366552e-02,  -2.96232253e-02,
                         -5.95115963e-03,  -1.38061077e-04,  -7.53754795e-01,
                         -7.40312636e-01,  -7.68814206e-01,  -7.57384419e-01,
                         -7.53536642e-01,  -7.66576648e-01,  -7.32024550e-01,
                         -7.51800835e-01,  -7.60296226e-01,  -7.38231003e-01,
                         -7.67007530e-01,  -7.45532930e-01,  -7.68142402e-01,
                         -7.63653278e-01,  -7.69957602e-01,  -7.65920401e-01,
                         -7.49135435e-01,  -7.82399893e-01,  -7.62355745e-01,
                         -7.51869142e-01,  -7.56015956e-01,  -7.29613245e-01,
                         -7.23716378e-01,  -7.39136815e-01,  -7.60514140e-01,
                         -7.76781023e-01,  -7.31649280e-01,  -7.43029356e-01,
                         -7.97139168e-01,  -7.72187710e-01,  -7.83190072e-01,
                         -7.86910295e-01,  -7.31188774e-01,  -7.46703565e-01,
                         -7.50790417e-01,  -7.54043639e-01,  -7.34670937e-01,
                         -7.36168683e-01,  -7.13094115e-01,  -7.40495682e-01,
                          1.09101171e-02,  -1.81629218e-03,  -1.95624516e-03,
                         -1.17069501e-02,   2.60774437e-02,   4.53306735e-02,
                         -7.42965564e-03,  -1.20832166e-02,  -7.42042780e-01,
                         -7.89923787e-01,  -7.96540439e-01,  -7.69910872e-01,
                         -7.79990792e-01,  -7.53112793e-01,  -7.08739519e-01,
                         -7.46571183e-01,  -7.24962533e-01,  -7.41564572e-01,
                         -7.57355809e-01,  -7.40890801e-01,  -7.19023287e-01,
                         -7.14499354e-01,  -7.19682574e-01,  -7.47027397e-01,
                         -7.29726017e-01,  -7.25193322e-01,  -7.18789518e-01,
                         -7.45367646e-01,  -7.32573867e-01,  -7.50364065e-01,
                         -7.37848043e-01,  -7.73011863e-01,  -7.76533186e-01,
                         -7.56930709e-01,  -7.58736670e-01,  -7.43402004e-01,
                         -7.50004411e-01,  -7.65777230e-01,  -7.42036104e-01,
                         -7.25469530e-01,  -7.45393157e-01,  -7.37775385e-01,
                         -7.55065918e-01,  -7.61026442e-01,   1.98061056e-02,
                          5.27871354e-03,   4.65001306e-03,  -2.64888555e-02,
                         -7.72347331e-01,  -7.40361333e-01,  -7.67167807e-01,
                         -7.39141762e-01,  -7.66089678e-01,  -7.65283167e-01,
                         -7.39965320e-01,  -7.45887816e-01,  -7.38490760e-01,
                         -7.69130945e-01,  -7.64774442e-01,  -7.71005392e-01,
                         -7.82883048e-01,  -7.67464519e-01,  -7.53605843e-01,
                         -7.69060612e-01,  -7.82728076e-01,  -7.69137442e-01,
                         -7.51358747e-01,  -7.58846164e-01,  -7.79552400e-01,
                         -7.55269885e-01,  -7.50453711e-01,  -7.24317670e-01,
                         -7.76130736e-01,  -7.66922712e-01,  -7.79210031e-01,
                         -7.82609105e-01,  -7.68993795e-01,  -7.50974953e-01,
                         -7.45076776e-01,  -7.73636639e-01,  -7.59110868e-01,
                         -7.88653135e-01,  -7.83391595e-01,  -7.70576358e-01,
                         -7.49695659e-01,  -7.68976152e-01,  -7.74519205e-01,
                         -7.64658630e-01,  -7.81531870e-01,  -7.50410557e-01,
                         -7.67595768e-01,  -7.76173532e-01,  -7.70800948e-01,
                         -7.64209986e-01,  -7.93336451e-01,  -7.53004730e-01,
                         -7.34625280e-01,  -7.34243393e-01,  -7.42852211e-01,
                         -7.62052417e-01,  -9.39981282e-01,  -9.37798798e-01,
                         -9.39168274e-01,  -9.08080339e-01,  -9.24988925e-01,
                         -9.31106329e-01,  -9.40738320e-01,  -9.67773318e-01,
                         -9.69277620e-01,  -9.39361453e-01,  -9.13561642e-01,
                         -9.00455713e-01,  -7.47164845e-01,  -7.63227165e-01,
                         -7.51010835e-01,  -7.51984835e-01,  -7.88308561e-01,
                         -7.62628078e-01,  -7.81882584e-01,  -7.61173010e-01,
                         -7.86387801e-01,  -7.74139404e-01,  -7.97797918e-01,
                         -7.63193607e-01,  -7.75665581e-01,  -7.47144997e-01,
                         -7.72413671e-01,  -7.61811972e-01,  -7.29139268e-01,
                         -7.59656847e-01,  -7.73674011e-01,  -7.95977354e-01,
                         -7.99926639e-01,  -7.76392519e-01,  -7.85947561e-01,
                         -7.71053672e-01,  -9.38458800e-01,  -8.86529267e-01,
                         -9.41358626e-01,  -9.50782776e-01,  -9.16757464e-01,
                         -9.42173779e-01,  -9.48447287e-01,  -9.27116096e-01,
                         -9.11503434e-01,  -9.15430009e-01,  -9.31353092e-01,
                         -9.20446038e-01,  -7.68255234e-01,  -7.53035665e-01,
                         -7.54824102e-01,  -7.58299470e-01,  -9.39817548e-01,
                         -9.68904495e-01,  -9.60972488e-01,  -9.33371544e-01,
                         -9.20296252e-01,  -9.63052630e-01,  -9.42149341e-01,
                         -9.48281825e-01,  -9.41576719e-01,  -9.67181742e-01,
                         -9.66968298e-01,  -9.67511714e-01,  -9.55111563e-01,
                         -9.38236594e-01,  -9.14208829e-01,  -9.22980607e-01,
                         -9.37689841e-01,  -9.38941956e-01,  -9.20910597e-01,
                         -9.28503513e-01,  -9.52050328e-01,  -9.23106730e-01,
                         -9.54857409e-01,  -9.23909068e-01,  -7.61646152e-01,
                         -7.65405238e-01,  -7.73536146e-01,  -7.47213483e-01,
                         -7.43782222e-01,  -7.68097222e-01,  -7.42195904e-01,
                         -7.48832822e-01,  -7.45724082e-01,  -7.52989888e-01,
                         -7.38998950e-01,  -7.85420656e-01,  -7.61372566e-01,
                         -7.54708648e-01,  -7.78838217e-01,  -7.36378610e-01,
                         -7.72375882e-01,  -7.66836107e-01,  -7.65474677e-01,
                         -7.56080210e-01,  -9.49243009e-01,  -9.37066972e-01,
                         -9.17632997e-01,  -9.24594223e-01,  -9.45366204e-01,
                         -9.20688272e-01,  -9.34554398e-01,  -9.30791557e-01,
                         -9.40019250e-01,  -9.41329122e-01,  -9.45732236e-01,
                         -9.32882190e-01,  -9.80379462e-01,  -9.51011539e-01,
                         -9.38828945e-01,  -9.30918872e-01,  -7.40238488e-01,
                         -7.37364829e-01,  -7.51469910e-01,  -7.20995009e-01,
                         -7.39804864e-01,  -7.20427215e-01,  -7.75175512e-01,
                         -7.35190809e-01,  -3.17963236e-03,  -1.08681815e-02,
                         -3.92068028e-02,   8.78969673e-03,  -1.89370234e-02,
                         -3.52540612e-02,  -2.92011332e-02,   6.68093388e-04,
                         -4.30364395e-03,   9.83545673e-04,   2.63950042e-02,
                         -1.00993679e-03,  -7.30767429e-01,  -7.47403264e-01,
                         -7.64621317e-01,  -7.68552065e-01,   6.83205156e-03,
                          6.55636936e-02,  -5.77153638e-03,   8.00260063e-03,
                          1.52657251e-03,   1.09477835e-02,  -7.05457386e-03,
                          8.78269039e-03,   1.17921859e-01,   1.63242236e-01,
                          1.67408064e-01,   2.25203186e-01,   4.01909500e-02,
                          2.30980804e-03,  -1.75711252e-02,   2.13199742e-02,
                          1.43035635e-01,   1.82739958e-01,   1.60087034e-01,
                          1.41259223e-01,  -1.38499076e-03,   1.20665981e-02,
                          2.15349086e-02,  -1.09289195e-02,  -7.60812778e-03,
                         -7.46428687e-03,   8.86875205e-03,   3.27293314e-02,
                         -2.96349986e-03,  -3.26647833e-02,  -4.38319845e-03,
                         -1.59821026e-02,   1.52778700e-01,   1.79098576e-01,
                          1.80810541e-01,   1.72694460e-01,   1.82843953e-01,
                          1.69985458e-01,   1.82766736e-01,   2.15983778e-01,
                          1.91663504e-01,   1.99161097e-01,   1.97453380e-01,
                          1.93206146e-01,   1.86555102e-01,   1.81193635e-01,
                          1.80874184e-01,   1.89574957e-01,   1.87409386e-01,
                          1.72676846e-01,   1.81265905e-01,   1.86331272e-01,
                          1.94494978e-01,   2.03748688e-01,   1.78092599e-01,
                          1.56551808e-01,   1.72835052e-01,   1.82828933e-01,
                          1.54889241e-01,   1.74763381e-01,   1.67553023e-01,
                          1.76888332e-01,   1.58765256e-01,   1.56391084e-01,
                          1.79462060e-01,   1.81158319e-01,   1.69566944e-01,
                          1.82951301e-01,   1.52164355e-01,   1.66168287e-01,
                          1.79028004e-01,   1.43754452e-01,   1.94156617e-01,
                          1.95695713e-01,   1.90000877e-01,   2.21557453e-01,
                          1.50655940e-01,   1.76995143e-01,   1.96687371e-01,
                          1.65599391e-01,   2.07638621e-01,   2.03581050e-01,
                          1.56238630e-01,   1.72892973e-01,   1.68477207e-01,
                          1.52752057e-01,   1.98750794e-01,   1.63670182e-01,
                          1.99565977e-01,   1.81933686e-01,   1.65691316e-01,
                          1.54369682e-01,  -3.90987087e-04,   1.31634418e-02,
                          2.72019347e-03,  -2.49853055e-03,   9.52400360e-03,
                          1.31010544e-02,  -1.68289114e-02,  -1.01429047e-02,
                          5.06122317e-03,  -1.12116812e-02,   7.50013115e-03,
                          2.79997718e-02,   7.27880793e-03,   1.71369612e-02,
                         -7.72550190e-03,   2.19592582e-02,   2.24292390e-02,
                          2.50908211e-02,   1.44844996e-02,   1.38270445e-02,
                          1.84028819e-01,   1.80845097e-01,   1.78446576e-01,
                          1.76236674e-01,   1.55394658e-01,   1.53369233e-01,
                          1.76898807e-01,   1.30238757e-01,   1.28060937e-01,
                          1.59176305e-01,   1.73844486e-01,   1.59055665e-01,
                          1.28160266e-03,   5.74597716e-03,  -1.89719032e-02,
                         -1.20449886e-02,  -1.39890574e-02,  -2.56121978e-02,
                         -6.61634188e-03,  -2.32908153e-03,  -3.07668769e-03,
                          9.29963775e-03,  -1.22156227e-02,   5.81727037e-03,
                         -2.21020468e-02,  -4.45860922e-02,  -3.55529711e-02,
                         -3.24132480e-02,  -3.06749586e-02,  -1.06112976e-02,
                          2.72562895e-02,  -2.12510787e-02,   1.37420911e-02,
                         -2.34867400e-03,  -2.61858366e-02,  -2.04543979e-03,
                          1.72680095e-02,   2.52843462e-02,   1.94276012e-02,
                          5.66687994e-03,   1.31911016e-03,   1.01461485e-02,
                         -5.55100339e-03,   6.11751061e-03,  -2.92399023e-02,
                         -2.76610535e-02,   1.51254879e-02,  -2.64340430e-03,
                         -3.30485962e-02,  -2.72324495e-02,  -3.10504716e-03,
                          6.11353957e-04,   1.11604091e-02,  -2.85270321e-03,
                          1.58862071e-03,   1.15848770e-02,  -3.81223485e-03,
                         -4.02973266e-03,  -3.19488049e-02,   3.90583044e-03,
                          5.27781993e-03,  -7.22070318e-03,  -1.50454976e-02,
                          9.25434008e-03,  -1.26794418e-02,   3.47799412e-03,
                         -2.06663795e-02,  -1.17148096e-02,  -1.26420241e-02,
                         -5.60919149e-03,   2.92380657e-02,   2.39418056e-02,
                          3.59222218e-02,   3.93852256e-02,   2.33490858e-02,
                          4.15040664e-02,   2.22429000e-02,   5.12283742e-02,
                          2.54794732e-02,  -7.28940452e-03,  -1.02750268e-02,
                          4.39510494e-03,  -2.23979205e-02,  -9.33390856e-03,
                         -3.51601094e-02,  -9.35353618e-03,   1.15203410e-02,
                          5.33796195e-03,   9.87123232e-03,   1.63738523e-02,
                         -1.26597527e-02,   1.23825285e-03,   1.12141960e-03,
                         -7.01846648e-03,   2.36457232e-02,   3.53515637e-03,
                          4.31179069e-02,   1.22268433e-02,   1.08992569e-02,
                          3.05779334e-02,   2.03076266e-02,  -2.13295110e-02,
                         -1.51508609e-02,   2.15379018e-02,   2.69963220e-02,
                          1.89851616e-02,  -3.28128081e-04,  -3.24253365e-02,
                         -1.03391602e-03,  -1.32226832e-02,   1.34413177e-02,
                         -3.80143034e-03,  -9.41745520e-01,  -9.50854301e-01,
                         -9.66599047e-01,  -9.57105875e-01,  -9.38189387e-01,
                         -9.20528114e-01,  -9.49313760e-01,  -9.42384779e-01,
                         -9.45467770e-01,  -9.17784095e-01,  -9.52506542e-01,
                         -9.33085442e-01,  -1.86519325e-03,   4.18678299e-03,
                         -2.35861838e-02,  -4.93291300e-03,   6.13912661e-03,
                         -3.39133618e-03,   3.55159603e-02,  -1.44392718e-03,
                         -1.76511519e-02,  -8.15586094e-03,   1.02268318e-02,
                          4.22383333e-03,  -9.05015588e-01,  -9.67879295e-01,
                         -9.42011416e-01,  -9.21593189e-01,  -9.22851682e-01,
                         -9.28713441e-01,  -9.57120061e-01,  -9.42888081e-01,
                         -9.16155398e-01,  -9.27166343e-01,  -9.42201674e-01,
                         -9.45419431e-01,  -9.70126867e-01,  -9.20117617e-01,
                         -9.29523945e-01,  -9.41510856e-01,  -8.99330139e-01,
                         -9.05209720e-01,  -8.98784399e-01,  -9.20501053e-01,
                         -9.39915419e-01,  -9.20626998e-01,  -9.38355446e-01,
                         -9.23679173e-01,  -9.10840690e-01,  -9.41644371e-01,
                         -9.35329258e-01,  -9.44902241e-01,  -9.25934255e-01,
                         -9.10692215e-01,  -9.29381430e-01,  -9.02048826e-01,
                         -9.19550478e-01,  -9.08418000e-01,  -9.50464785e-01,
                         -9.31496143e-01,  -9.30823624e-01,  -9.04890835e-01,
                         -9.42745507e-01,  -8.99144530e-01,  -8.99939179e-01,
                         -8.81929278e-01,  -9.20095921e-01,  -9.09908593e-01,
                         -9.07199800e-01,  -9.06917155e-01,  -9.11011636e-01,
                         -8.93961251e-01,  -9.09143865e-01,  -9.38367784e-01,
                         -8.97874534e-01,  -9.35665905e-01,  -9.61326122e-01,
                         -9.24380422e-01,  -9.08538640e-01,  -8.90307486e-01,
                         -9.25723016e-01,  -9.13636267e-01,  -9.31081295e-01,
                         -9.31983829e-01,  -9.18346286e-01,  -9.09085929e-01,
                         -9.33679283e-01,  -9.21907783e-01,  -8.93641591e-01,
                         -9.01805401e-01,  -9.17215347e-01,  -9.50273156e-01,
                         -9.53028917e-01,  -9.17945981e-01,  -9.58941817e-01,
                         -9.46459651e-01,  -9.15681303e-01,  -9.30130064e-01,
                         -9.51803863e-01,  -9.40313160e-01,  -9.60451782e-01,
                         -9.32235062e-01,  -9.56301868e-01,  -9.21594083e-01,
                         -8.99733484e-01,  -9.14057791e-01,  -8.92621398e-01,
                         -9.19912696e-01,  -9.08747554e-01,  -9.16266441e-01,
                         -9.09360528e-01,  -8.92725110e-01,  -9.08754647e-01,
                         -9.21210408e-01,  -9.04772460e-01,  -9.25598145e-01,
                         -9.04848814e-01,  -9.26842272e-01,  -9.25566435e-01,
                         -9.04839396e-01,  -9.22369361e-01,  -9.47336972e-01,
                         -8.97588253e-01,  -8.91226292e-01,  -9.20328438e-01,
                         -9.03382957e-01,  -9.19753611e-01,  -8.90705585e-01,
                         -9.04145658e-01,  -9.37121391e-01,  -9.35190976e-01,
                         -9.08259571e-01,  -9.15837884e-01,  -9.04678643e-01,
                         -9.08178806e-01,  -9.14478958e-01,  -9.18136954e-01,
                         -9.25950468e-01,  -9.03439820e-01,  -9.19582129e-01,
                         -9.37387526e-01,  -9.39976633e-01,  -9.20492768e-01,
                         -9.35866535e-01,  -9.50764596e-01,  -9.36958611e-01,
                         -9.32805598e-01,  -9.42464292e-01,  -9.03555751e-01,
                         -9.09842610e-01,  -9.25504088e-01,  -9.52482998e-01,
                         -9.51491773e-01,  -9.25629497e-01,  -9.10082817e-01,
                         -9.14428949e-01,  -9.02441800e-01,  -9.33760643e-01,
                         -9.24171031e-01,  -9.23145652e-01,  -9.19192851e-01,
                         -9.20163393e-01,  -9.22158539e-01,  -9.18829203e-01,
                         -9.18176949e-01,  -9.07842517e-01,  -9.11139727e-01,
                         -9.39031661e-01,  -9.59730566e-01,  -9.35062706e-01,
                         -9.34348822e-01,  -9.38558936e-01,  -9.34689879e-01,
                         -9.19866562e-01,  -9.17410910e-01,  -9.21430588e-01,
                         -9.26716983e-01,  -9.61398959e-01,  -9.43338513e-01,
                         -9.69112396e-01,  -9.50451374e-01,  -9.39242005e-01,
                         -9.49367642e-01,  -9.52199161e-01,  -9.47457969e-01,
                         -9.25727665e-01,  -9.41526532e-01,  -9.39411581e-01,
                         -9.42035675e-01,  -9.39218760e-01,  -9.36771095e-01,
                         -9.34697092e-01,  -9.82460082e-01,  -9.67600644e-01,
                         -9.23127353e-01,  -9.46735978e-01,  -9.36412394e-01,
                         -9.27735686e-01,  -9.29087222e-01,  -9.41721678e-01,
                         -9.01366711e-01,  -9.12767589e-01,  -8.95675898e-01,
                         -9.02999341e-01,  -9.13802266e-01,  -9.14035201e-01,
                         -9.47923481e-01,  -9.30031776e-01,  -9.61138844e-01,
                         -9.66593564e-01,  -9.46155012e-01,  -9.54818189e-01,
                         -9.65569794e-01,  -9.47862267e-01,  -9.34545159e-01,
                         -9.66268122e-01,  -9.32052195e-01,  -9.30580318e-01,
                         -9.32553649e-01,  -9.33795452e-01,  -9.49817836e-01,
                         -9.47947502e-01,  -9.28493619e-01,  -9.50975597e-01,
                         -9.11747515e-01,  -9.46683407e-01,  -9.15108740e-01,
                         -8.78475249e-01,  -9.09690142e-01,  -9.43147659e-01,
                         -9.35307443e-01,  -9.44615722e-01,  -8.98685396e-01,
                         -8.99789512e-01,  -9.04182017e-01,  -9.04895723e-01,
                         -9.31642950e-01,  -9.52400506e-01,  -9.26842988e-01,
                         -9.21460509e-01,  -9.50444341e-01,  -9.74247336e-01,
                         -9.51092839e-01,  -9.20781851e-01,  -9.40871954e-01,
                         -9.51171994e-01,  -9.23241675e-01,  -9.05103981e-01,
                         -9.32946980e-01,  -9.23720300e-01,  -9.24417317e-01,
                         -9.44581330e-01,  -9.40907300e-01,  -9.31107223e-01,
                         -9.17481720e-01,  -9.46805716e-01,  -9.10856187e-01,
                         -9.28825915e-01,  -9.42193508e-01,  -9.45383728e-01,
                         -9.40113127e-01,  -9.36770439e-01,  -9.35161173e-01,
                         -9.07040596e-01,  -9.59952891e-01,  -9.29455042e-01,
                         -9.37892437e-01,  -9.57744837e-01,  -9.30299997e-01,
                         -9.09603536e-01,  -9.04730678e-01,  -9.20863926e-01,
                         -9.15333271e-01,  -8.95166934e-01,  -9.39224601e-01,
                         -9.10835087e-01,  -5.20215482e-02,   8.54858756e-03,
                         -2.75674928e-02,  -2.44419109e-02,  -2.53554601e-02,
                         -2.04834789e-02,  -1.76132843e-02,  -1.75246992e-03,
                          8.39118287e-03,   1.56927085e-03,  -1.95589121e-02,
                         -1.11919502e-03,   7.08770147e-03,   2.54746769e-02,
                          3.75735275e-02,   1.23135224e-02,  -2.08946411e-02,
                         -4.21884330e-03,   9.61741153e-03,   1.16991671e-02,
                          3.92924957e-02,   1.61408994e-03,   2.15219408e-02,
                         -7.23362155e-03,  -1.48957793e-03,   1.10446783e-02,
                          3.43301930e-02,   1.45364227e-02,  -7.16564769e-04,
                         -2.60086041e-02,   4.87028994e-03,   1.94696467e-02,
                         -5.45230042e-03,   2.42669173e-02,  -5.50390407e-03,
                         -2.47479249e-02,   1.73180960e-02,   1.36257987e-02,
                          1.19626138e-03,   6.21269317e-03,   2.76732026e-05,
                         -1.75225362e-02,   5.75845875e-03,  -1.35516496e-02,
                         -8.48691352e-03,  -2.75673270e-02,  -1.12849493e-02,
                         -4.84717824e-02,  -9.20337796e-01,  -9.56735075e-01,
                         -9.14187968e-01,  -9.23499703e-01,  -9.47731733e-01,
                         -9.17285860e-01,  -9.31223452e-01,  -9.26315546e-01,
                         -9.31257248e-01,  -9.20948923e-01,  -9.49561059e-01,
                         -9.40988898e-01,  -9.23969507e-01,  -9.27771866e-01,
                         -9.35629010e-01,  -9.21723843e-01,  -9.24705327e-01,
                         -9.67318118e-01,  -9.23001230e-01,  -9.30391133e-01,
                         -9.29174662e-01,  -9.37095463e-01,  -9.41038847e-01,
                         -9.54206228e-01,  -9.32038903e-01,  -9.37944889e-01,
                         -9.08352137e-01,  -9.15609658e-01,  -9.12562430e-01,
                         -9.39209402e-01,  -9.47653532e-01,  -9.43718612e-01,
                         -9.52857733e-01,  -9.34570253e-01,  -9.76895094e-01,
                         -9.38175201e-01,  -9.46910501e-01,  -9.33132708e-01,
                         -9.45677698e-01,  -9.47653651e-01,  -9.52745497e-01,
                         -9.47906375e-01,  -9.42638695e-01,  -9.36303973e-01,
                         -9.56474841e-01,  -9.46836770e-01,  -9.36896980e-01,
                         -9.44948673e-01,  -9.43567395e-01,  -9.31676328e-01,
                         -9.46493566e-01,  -9.40203071e-01,  -9.34862077e-01,
                         -9.41405773e-01,  -9.33322430e-01,  -9.38607097e-01,
                         -9.37528491e-01,  -9.43952799e-01,  -9.36515749e-01,
                         -9.26580429e-01,  -9.39118922e-01,  -9.31959987e-01,
                         -9.43089545e-01,  -9.62261379e-01,  -9.33413029e-01,
                         -9.61059093e-01,  -9.44751978e-01,  -9.52293515e-01,
                         -9.67294514e-01,  -9.47212100e-01,  -9.37692046e-01,
                         -9.53304827e-01,  -9.54183459e-01,  -9.52357173e-01,
                         -9.58898604e-01,  -9.55597818e-01,  -8.99267733e-01,
                         -9.36481237e-01,  -9.26322639e-01,  -9.31583643e-01,
                         -9.37373817e-01,  -9.30876613e-01,  -9.58931506e-01,
                         -9.44990933e-01,  -9.47360277e-01,  -9.65203941e-01,
                         -9.46457624e-01,  -9.26028669e-01,  -9.52620208e-01,
                         -9.55446780e-01,  -9.45449769e-01,  -9.34757769e-01,
                         -9.60570991e-01,  -9.37440455e-01,  -9.12750781e-01,
                         -9.39238667e-01,  -9.23992634e-01,  -9.29919064e-01,
                         -9.32295382e-01,  -9.16861415e-01,  -9.27548528e-01,
                         -9.36149478e-01,  -9.34422791e-01,  -9.44035113e-01,
                         -9.34551477e-01,  -9.20715511e-01,  -9.11231458e-01,
                         -9.42578018e-01,  -9.31281865e-01,  -9.34897661e-01,
                         -9.49409008e-01,  -9.52941656e-01,  -9.43392754e-01,
                         -9.22702491e-01,  -9.60422277e-01,  -9.53152895e-01,
                         -9.50613916e-01,  -9.59881604e-01,  -9.68177497e-01,
                         -9.11690354e-01,  -9.25540566e-01,  -9.50089633e-01,
                         -9.70202386e-01,  -9.49455023e-01,  -9.70030725e-01,
                         -9.46776211e-01,  -9.42899168e-01,  -9.44848537e-01,
                         -9.40487802e-01,  -9.39121068e-01,  -9.28204000e-01,
                         -9.48261023e-01,  -9.38201010e-01,  -9.38883185e-01,
                         -9.40247118e-01,  -9.54372406e-01,  -9.36861157e-01,
                         -9.39275265e-01,  -9.30549681e-01,  -9.28359866e-01,
                         -9.52371240e-01,  -9.68819559e-01,  -9.38093781e-01,
                         -9.49569345e-01,  -9.13442075e-01,  -9.44747865e-01,
                         -9.53253150e-01,  -9.26414490e-01,  -9.27215397e-01,
                         -9.27110136e-01,  -9.43336070e-01,  -9.42316771e-01,
                         -9.31480587e-01,  -9.19648170e-01,  -9.29495096e-01,
                         -9.35480833e-01,  -9.06208277e-01,  -9.06908214e-01,
                         -9.33651090e-01,  -9.26125109e-01,  -9.23985958e-01,
                         -9.16449785e-01,  -9.32939768e-01,  -9.45690870e-01,
                         -9.26550448e-01,  -9.16709542e-01,  -9.19266701e-01,
                         -9.23076570e-01,  -9.34226513e-01,  -9.26461399e-01,
                         -9.12742138e-01,  -8.92796695e-01,  -9.25457716e-01,
                         -9.26140487e-01,  -9.55321193e-01,  -9.47969615e-01,
                         -9.27152574e-01,  -9.32461739e-01,  -9.34497178e-01,
                         -9.46358860e-01,  -9.51558352e-01,  -9.46411848e-01,
                         -9.43026125e-01,  -9.45360959e-01,  -9.42373335e-01,
                         -9.35396016e-01,  -9.23506200e-01,  -9.26597595e-01,
                         -9.33028936e-01,  -9.31191087e-01,  -9.48114634e-01,
                         -9.38089371e-01,  -9.13613081e-01,  -9.21899021e-01,
                         -9.15276051e-01,  -9.41363394e-01,  -9.47017610e-01,
                         -9.44924295e-01,  -9.36436474e-01,  -9.27030087e-01,
                         -9.26410913e-01,  -9.35612440e-01,  -9.47738528e-01,
                         -9.38419998e-01,  -9.26517606e-01,  -9.32386339e-01,
                         -9.37062979e-01,  -9.35471654e-01,  -9.39869285e-01,
                         -9.43365991e-01,  -9.47329879e-01,  -9.46785450e-01,
                         -9.40803945e-01,  -9.44788039e-01,  -9.48248684e-01,
                         -9.38485980e-01,  -9.31536913e-01,  -9.29324329e-01,
                         -9.42481577e-01,  -9.40083206e-01,  -9.39783454e-01,
                         -9.22787189e-01,  -9.47138369e-01,  -9.45086062e-01,
                         -9.44438279e-01,  -9.38377321e-01,  -9.34143543e-01,
                         -9.34091330e-01,  -9.36596692e-01,  -9.33468223e-01,
                         -9.41829920e-01,  -9.41797614e-01,  -9.36600685e-01,
                         -9.25738335e-01,  -9.40022349e-01,  -9.32360053e-01,
                         -9.42098439e-01,  -9.45106268e-01,  -9.36718345e-01,
                         -9.43115711e-01,  -9.23742235e-01,  -9.44293916e-01,
                         -9.36038733e-01,  -9.39094841e-01,  -9.39618826e-01,
                         -9.29820240e-01,  -9.24193859e-01,  -9.34690535e-01,
                         -9.40705180e-01,  -9.29519951e-01,  -9.29909289e-01,
                         -9.35544848e-01,  -9.28299725e-01,  -9.21324968e-01,
                         -9.37570751e-01,  -9.31211233e-01,  -9.26363945e-01,
                         -9.28886116e-01,  -9.35000122e-01,  -9.39490318e-01,
                         -9.33736384e-01,  -9.35340047e-01,  -9.39814746e-01,
                         -9.33504045e-01,  -9.30461228e-01,  -9.33136940e-01,
                         -9.38450277e-01,  -9.35323060e-01,  -9.40183461e-01,
                         -9.38333750e-01,  -9.35905218e-01,  -9.36653495e-01,
                         -9.37562287e-01,  -9.38300610e-01,  -9.31512296e-01,
                         -9.34021592e-01,  -9.35334027e-01,  -9.35905099e-01,
                         -9.39784706e-01,  -9.29944932e-01,  -9.37038481e-01,
                         -9.36216712e-01,  -9.32660341e-01,  -9.26861405e-01,
                         -9.30463672e-01,  -9.24681902e-01,  -9.24860418e-01,
                         -9.30492043e-01,  -9.32386100e-01,  -9.37374115e-01,
                         -9.29084718e-01,  -9.31645572e-01,  -9.40592945e-01,
                         -9.36572313e-01,  -9.36151624e-01,  -9.34186816e-01,
                         -9.32267427e-01,  -9.36949551e-01,  -9.36728299e-01,
                         -9.40462649e-01,  -9.37352061e-01,  -9.28424954e-01,
                         -9.32676315e-01,  -9.28189695e-01,  -9.21516359e-01,
                         -9.41634834e-01,  -9.39088643e-01,  -9.30313945e-01,
                         -9.34319437e-01,  -9.31522727e-01,  -9.27850485e-01,
                         -9.38588917e-01,  -9.23702657e-01,  -9.28225279e-01,
                         -9.35072243e-01,  -9.27709699e-01,  -9.39762414e-01,
                         -9.34712827e-01,  -9.35231686e-01,  -9.39906120e-01,
                         -9.31924582e-01,  -9.31202054e-01,  -9.35596585e-01,
                         -9.32640910e-01,  -9.31799173e-01,  -9.36239541e-01,
                         -9.34007704e-01,  -9.25675333e-01,  -9.35141444e-01,
                         -9.35985506e-01,  -9.35296237e-01,  -9.34080660e-01,
                         -9.30037558e-01,  -9.27898169e-01,  -9.28919077e-01,
                         -9.31185186e-01,  -9.31067646e-01,  -9.33486879e-01,
                         -9.29228485e-01,  -9.31349337e-01,  -9.28889632e-01,
                         -9.32392657e-01,  -9.27979827e-01,  -9.31818783e-01,
                         -9.24762547e-01,  -9.35587049e-01,  -9.36632633e-01,
                         -9.27346170e-01,  -9.35679793e-01,  -9.35066700e-01,
                         -9.35122132e-01,  -9.42471802e-01,  -9.43330944e-01,
                         -9.34794664e-01,  -9.40607488e-01,  -9.39999163e-01,
                         -9.35837448e-01,  -9.34692860e-01,  -9.37470019e-01,
                         -9.28577542e-01,  -9.31868494e-01,  -9.32941079e-01,
                         -9.29502070e-01,  -9.33912039e-01,  -9.35525417e-01,
                         -9.37202573e-01,  -9.34356570e-01,  -9.44092214e-01,
                         -9.40546155e-01,  -9.38388169e-01,  -9.32254255e-01,
                         -9.34066176e-01,  -9.32661235e-01,  -9.37006533e-01,
                         -9.33944166e-01,  -9.44747448e-01,  -9.31821704e-01,
                         -9.39294219e-01,  -9.45689857e-01,  -9.38516259e-01,
                         -9.34964418e-01,  -9.27719533e-01,  -9.31710899e-01,
                         -9.30617452e-01,  -9.37874556e-01,  -9.33422983e-01,
                         -9.39158976e-01,  -9.40325141e-01,  -9.36388314e-01,
                         -9.34029758e-01,  -9.38439667e-01,  -9.30876136e-01,
                         -9.28066134e-01,  -9.30218458e-01,  -9.31353867e-01,
                         -9.31942880e-01,  -9.37113225e-01,  -9.29980636e-01,
                         -9.34931815e-01,  -9.31086957e-01,  -9.27412748e-01,
                         -9.27390337e-01,  -9.39752102e-01,  -9.37171876e-01,
                         -9.29856956e-01,  -9.32578266e-01,  -9.39516544e-01,
                         -9.29712951e-01,  -9.33290839e-01,  -9.35308874e-01,
                         -9.35342252e-01,  -9.32546139e-01,  -9.24842656e-01,
                         -9.30489600e-01,  -9.28716719e-01,  -9.37955081e-01,
                         -9.38724518e-01,  -9.28720355e-01,  -9.34596181e-01,
                         -9.40520883e-01,  -9.32159424e-01,  -9.33497548e-01,
                         -9.35563207e-01,  -9.41335022e-01,  -9.37703907e-01,
                         -9.22423303e-01,  -9.31935787e-01,  -9.37082291e-01,
                          3.06823960e-04,   5.91621641e-03,   1.62686280e-03,
                          7.75171258e-03,   7.25290179e-03,  -1.42108451e-03,
                          3.66684841e-03,   1.24333974e-03,   1.02997955e-03,
                         -3.72227794e-03,  -1.46737977e-04,  -4.90555866e-03,
                         -3.62793403e-03,  -9.52635333e-03,   7.69882649e-03,
                          7.75598164e-04,   9.24296770e-03,   7.24326167e-03,
                         -5.41126495e-03,   1.09611668e-04,  -2.87404891e-05,
                          7.00860424e-03,   1.08810503e-03,  -4.06312337e-03,
                          7.96076190e-03,   5.99823799e-03,   6.47604931e-03,
                          6.86788186e-03,   5.88062825e-03,   7.60718540e-04,
                          1.02151055e-02,  -1.32005964e-03,   2.63390946e-03,
                          4.62158443e-03,  -9.75173060e-03,   2.13610381e-03,
                         -7.73668056e-03,   2.72534275e-03,   4.95477172e-04,
                          2.60424032e-03,   4.79215616e-03,  -2.47475225e-03,
                         -5.36362547e-03,   3.09672352e-04,   1.26108865e-03,
                         -5.57126105e-03,  -3.00761219e-03,   2.50848965e-03,
                          2.86544836e-03,  -1.67619355e-03,  -6.37415145e-03,
                         -5.07495226e-03,   4.12975252e-03,  -5.42315096e-03,
                         -2.60467711e-03,  -4.20604274e-03,  -3.44963488e-03,
                         -1.01201311e-02,  -1.64304879e-02,  -1.33357048e-02,
                         -1.51072268e-03,  -1.23249367e-03,   4.37936606e-03,
                         -3.34436167e-03,  -1.38839083e-02,  -3.18901613e-03,
                         -6.27961336e-03,  -6.11079484e-03,  -1.33696711e-02,
                         -6.70951465e-03,  -8.09203833e-04,  -9.26591456e-03,
                         -5.40150737e-04,  -1.10712359e-02,  -4.62273485e-04,
                         -1.80458673e-03,  -4.79907962e-03,  -1.25877385e-03,
                         -1.32168829e-03,  -4.14581737e-03,  -4.47705016e-03,
                         -5.73795848e-03,   2.08307221e-03,  -5.34323603e-03,
                         -1.63380709e-03,   5.55751103e-05,   2.90994160e-03,
                          2.69751693e-03,  -4.40666499e-03,  -2.96223164e-03,
                         -1.91771906e-04,   1.75630243e-03,  -3.04245827e-06,
                          1.80029671e-03,   1.27366732e-03,  -2.89804209e-03,
                         -2.27038772e-03,  -7.30449893e-03,  -4.28936724e-03,
                         -6.75693946e-03,   7.92598526e-04,  -9.22520459e-03,
                         -1.23043321e-02,  -4.10799123e-03,  -2.98735453e-03,
                         -4.73911036e-03,  -2.06796383e-03,  -3.90697410e-03,
                          6.04645291e-04,   3.28064337e-03,  -1.14026351e-03,
                          3.65396473e-03,   1.47261226e-03,  -9.31186310e-04,
                         -2.83919577e-03,  -7.70712225e-03,  -1.25059662e-02,
                         -1.01927342e-02,  -1.29292696e-03,   1.11512677e-03,
                          4.81673144e-03,  -7.23967189e-03,   2.34524324e-03,
                          1.12236221e-03,  -4.35176212e-03,  -5.89130819e-03,
                         -5.36034023e-03,  -3.00937239e-03,  -5.52163227e-03,
                          1.54692726e-03,  -2.48922990e-03,  -1.52609439e-03,
                         -1.39444391e-03,  -2.21809070e-03,   3.09808902e-03,
                         -3.00287176e-03,  -3.49371252e-03,   5.30423829e-03,
                          7.90477789e-04,   3.30319488e-03,   8.86367226e-04,
                         -1.34398346e-03,  -1.15089407e-02,   2.34551355e-03,
                         -3.58113297e-03,   9.27291403e-05,  -2.44520791e-03,
                         -4.14432026e-03,  -2.39877403e-03,  -3.22461082e-03,
                         -7.90218636e-03,  -3.17665911e-03,  -5.42478636e-03,
                          1.06043881e-03,   1.55671302e-03,   5.03101340e-03,
                         -6.03770651e-03,   2.64312699e-03,  -1.52962888e-03,
                         -5.68366563e-03,  -5.49897645e-03,  -3.30839283e-03,
                          2.40907259e-03,   4.88695037e-03,   3.12368991e-03,
                          8.51313118e-04,   8.14865984e-04,  -3.86343687e-04,
                         -2.03620852e-03,  -1.58905040e-03,  -5.60248271e-03,
                         -1.14494842e-03,  -3.11231706e-03,  -1.54012849e-03,
                          6.77539560e-04,   1.33778070e-04,  -3.92051600e-03,
                          2.32294132e-03,  -3.47732892e-03,  -1.21746853e-03,
                         -9.10173228e-04,   2.87400046e-03,   2.35705287e-03,
                          3.57030053e-03,   1.96919823e-03,  -4.42743534e-04,
                         -3.30198905e-03,  -2.04604981e-03,  -2.87330034e-03,
                         -2.69559037e-04,  -5.53687243e-03,   3.25175724e-03,
                          1.60426262e-03,  -6.73491461e-03,   2.58012937e-04,
                          3.72985983e-03,   1.68464868e-03,  -5.93667501e-04,
                         -1.16577442e-03,  -1.19075854e-03,  -4.70361294e-04,
                         -1.50744454e-03,  -1.52910210e-03,  -1.33168884e-03,
                         -1.72035431e-03,   1.29529717e-03,  -8.68729257e-05,
                          1.04337611e-04,  -1.36049872e-03,  -4.47668973e-03,
                         -1.19377335e-03,   5.75294907e-05,   8.24332936e-04,
                          2.13375431e-03,  -4.39838972e-03,  -2.38199532e-03,
                          4.35920525e-03,  -1.45541783e-03,  -3.04523041e-03,
                         -3.88013246e-03,   4.62439097e-03,   1.04527986e-02,
                          4.45555896e-03,  -1.61160890e-03,  -1.00537657e-03,
                         -2.37224437e-03,   1.11531396e-03,  -3.33422940e-04,
                         -7.44390476e-04,  -4.71113250e-03,  -4.97062830e-03,
                         -3.03728133e-03,  -4.11747862e-03,  -5.49246185e-03,
                         -2.31857505e-03,  -2.71345698e-03,  -4.18272195e-03,
                         -7.55167985e-03,  -8.18559900e-04,   2.12156377e-03,
                         -9.47056978e-04,  -1.44430145e-04,   5.51038422e-04,
                          1.17007131e-03,  -2.15383875e-03,  -4.28528525e-03,
                         -2.79744691e-03,  -1.26885064e-03,  -3.71324760e-03,
                          6.65487547e-04,  -4.11914894e-03,  -2.41076364e-03,
                         -2.25539715e-03,   1.43148017e-03,  -1.34369929e-03,
                         -4.37256694e-03,  -1.12406712e-03,  -1.73885154e-03,
                         -1.69473246e-03,  -5.18663600e-03,   3.31753399e-03,
                         -4.21113655e-04,  -4.82953899e-03,  -1.01333263e-03,
                         -2.12419033e-03,   6.83773449e-03,   8.52416456e-03,
                          1.08047118e-02,   5.73451398e-03,   2.43881787e-03,
                         -1.44272821e-03,   5.86730102e-03,  -1.62665488e-03,
                         -8.85008834e-04,   7.20957294e-03,  -4.40775293e-05,
                         -2.10726634e-03,  -1.72781828e-03,  -3.00725165e-04,
                         -1.14985453e-02,   1.91127369e-03,   3.20359075e-04,
                         -6.53820857e-03,   2.06469954e-03,   2.70560477e-03,
                          1.22849271e-02,  -2.85431114e-03,  -1.03758499e-02,
                         -2.11343431e-04,  -4.95595671e-03,  -7.13568041e-03,
                          6.43771701e-03,  -6.82855170e-05,  -4.36824933e-03,
                         -8.64383881e-04,   8.22958630e-03,  -1.22536920e-04,
                         -1.15422346e-02,   1.96368853e-03,  -7.97123369e-03,
                         -1.27334157e-02,  -5.20654023e-03,  -2.80412089e-04,
                         -1.56832836e-03,  -4.19221651e-05,  -2.53115897e-03,
                         -4.96596424e-03,  -3.35685723e-03,   3.85229988e-03,
                          2.58468278e-03,   4.47458308e-03,  -8.61376058e-03,
                          9.01341811e-03,  -1.03255082e-03,   4.74782893e-03,
                          7.16453884e-03,   1.56825762e-02,   1.07303830e-02,
                          9.36251041e-03,  -7.56850652e-03,  -5.28883236e-03,
                         -8.01535323e-03,   4.64509241e-03,   6.14903029e-03,
                          9.92763136e-03,   2.27844779e-04,   5.57559263e-03,
                          8.33661325e-05,  -1.05575453e-02,   2.02125963e-03,
                         -8.48283153e-03,   8.44474882e-03,  -2.74463696e-03,
                         -6.42375229e-03,  -5.86294895e-03,  -1.46489730e-02,
                          1.74903238e-04,  -1.17221968e-02,  -1.04613439e-03,
                          1.99642102e-03,   1.27971480e-02,   1.35488505e-03,
                         -5.06921392e-03,  -1.61769595e-02,  -8.27434286e-03,
                         -6.17406284e-03,   6.24417793e-03,   1.23066397e-03,
                          7.74003472e-03,   2.30162311e-03,   1.05319098e-02,
                          1.05438372e-02,   7.86451215e-04,   1.47041185e-02,
                          1.35098593e-02,   1.95827447e-02,   7.70428102e-04,
                          5.36225317e-03,   9.60171409e-03,   1.81490611e-02,
                         -1.20949850e-03,   9.74100921e-03,  -1.78847346e-03,
                         -1.85384061e-02,  -5.24578709e-03,   2.80613080e-04,
                         -2.24247687e-02,   6.12501614e-03,  -1.17759081e-03,
                          6.52991934e-04,  -1.25877447e-02,   1.44905709e-02,
                          7.88210146e-03,  -8.37100856e-03,   9.83584486e-03,
                          1.92042184e-03,  -1.73617993e-02,  -9.28809168e-04,
                         -3.58231808e-03,  -2.56911007e-05,   2.30494281e-03,
                         -2.58665923e-02,   1.17937811e-02,  -1.84118631e-03,
                         -4.44968184e-03,   1.41631840e-02,  -1.71833951e-02,
                          6.99258829e-03,  -7.00754393e-03,   8.06247350e-03,
                         -3.11002322e-03,   8.38866085e-03,   8.95940233e-03,
                          7.75570457e-04,  -7.45782070e-03,   1.93264093e-02,
                          1.73053443e-02,   3.02912351e-02,   1.72773097e-02,
                          1.60415042e-02,   2.40821745e-02,   3.46431363e-04,
                          2.79575102e-02,   2.04403303e-03,   8.76097754e-03,
                          1.37425764e-02,   4.37072339e-03,   4.45098476e-03,
                         -6.45203516e-03,  -3.51378997e-03,   8.29713047e-03,
                         -6.29584445e-03,  -1.72444247e-02,   3.75670148e-03,
                          5.26867853e-03,   1.16719445e-02,   1.01588583e-02,
                         -8.36183957e-04,   3.82192363e-03,   6.28744485e-03,
                          7.72035914e-03,   2.22204113e-03,   5.85046737e-03,
                          2.57299654e-02,   3.22155729e-02,   1.21511836e-02,
                          6.25978550e-03,   2.40139570e-02,   1.46064265e-02,
                          3.03780800e-03,  -7.84614647e-04,   2.11335123e-02,
                          8.61681008e-04,  -1.75465997e-02,   6.92198798e-03,
                          1.58330910e-02,   2.71476489e-02,   1.71018876e-02,
                          1.25238812e-02,  -5.93868492e-04,   1.24797621e-03,
                         -2.49673566e-03,  -6.57175155e-03,  -8.21007043e-03,
                         -2.92944396e-03,   3.06288921e-03,   8.28855019e-03,
                          5.67231374e-03,  -2.32268199e-02,   2.74501136e-03,
                          8.05003941e-03,   1.15560889e-02,   3.35471630e-02,
                          1.25586996e-02,  -2.38727638e-03,  -1.15756253e-02,
                         -5.68480231e-03,   3.41550261e-03,  -5.83535200e-03,
                         -1.62666664e-02,  -1.70341693e-02,  -1.68389808e-02,
                         -1.51262647e-02,  -1.32708289e-02,  -3.28892516e-03,
                         -4.63778758e-03,  -1.88171549e-03,  -7.53537938e-03,
                         -9.12667811e-01,  -9.43146884e-01,  -9.53300714e-01,
                         -9.13158655e-01,  -9.09209907e-01,  -9.31925893e-01,
                         -9.40715373e-01,  -9.27798271e-01,  -9.40873802e-01,
                         -9.25021172e-01,  -9.25683320e-01,  -9.45879698e-01,
                         -1.28740827e-02,   2.79778638e-03,  -1.04123459e-03,
                          1.44488914e-02,  -7.65715400e-03,  -4.59169317e-03,
                         -2.63514323e-03,   2.81448872e-03,   1.74840167e-03,
                          1.56563940e-03,   3.23955156e-02,   8.13479885e-04,
                         -5.72239980e-03,   2.10671173e-03,   1.14885718e-02,
                          1.98877193e-02,   1.05244108e-03,   1.45317027e-02,
                         -3.29930015e-04,  -8.43274500e-03,   4.76957671e-03,
                         -2.12291311e-02,  -1.93171147e-02,  -7.28176022e-03,
                         -1.37528749e-02,  -1.63888710e-03,  -1.63145759e-03,
                         -2.35975217e-02,   8.53056833e-03,  -1.44632095e-02,
                          1.87645387e-02,   1.05002858e-02,   1.41150802e-02,
                          5.62409870e-03,   1.25818336e-02,  -6.27079105e-04,
                          1.78359095e-02,  -8.34551174e-03,  -4.29525832e-03,
                         -6.03167713e-03,   9.78968106e-03,   1.38651961e-02,
                          2.76509281e-02,   8.96075368e-03,  -9.21091437e-03,
                          8.25979654e-03,  -1.20744500e-02,   3.09658162e-02,
                          2.51500425e-03,   2.10297145e-02,  -5.51586598e-03,
                         -8.72002542e-03,  -1.58205058e-03,  -5.50683588e-03,
                          5.37759019e-03,  -1.01724835e-02,   5.63707261e-04,
                          1.57534257e-02,   8.19405448e-03,   1.47855852e-03,
                          6.30853372e-03,  -4.62538935e-03,  -7.10996194e-03,
                         -4.86900751e-03,  -9.14190114e-01,  -9.20248508e-01,
                         -9.23832715e-01,  -9.23690736e-01,  -9.19239938e-01,
                         -9.34340835e-01,  -9.14761841e-01,  -9.38036203e-01,
                         -9.29298818e-01,  -9.52657580e-01,  -9.12468672e-01,
                         -9.27652597e-01,  -9.35402870e-01,  -9.25676882e-01,
                         -9.38745677e-01,  -9.52231944e-01,  -9.49118912e-01,
                         -9.40788209e-01,  -9.38383281e-01,  -9.39920068e-01,
                         -9.59187567e-01,  -9.51672852e-01,  -9.39190149e-01,
                         -9.71275210e-01,  -9.60857332e-01,  -9.47604418e-01,
                         -9.45299745e-01,  -9.40825284e-01,  -9.51840520e-01,
                         -9.36594725e-01,  -9.42916930e-01,  -9.36448455e-01,
                         -9.32894826e-01,  -9.59075034e-01,  -9.27515090e-01,
                         -9.41928148e-01,  -9.43665087e-01,  -9.39693749e-01,
                         -9.21240211e-01,  -9.33160841e-01,  -9.33783412e-01,
                         -9.41197395e-01,  -9.39193130e-01,  -9.20309961e-01,
                         -9.24499691e-01,  -9.08843040e-01,  -9.02783990e-01,
                         -9.21044290e-01,  -9.33696032e-01,  -9.20940995e-01,
                         -9.32928443e-01,  -9.39546824e-01,  -9.28459585e-01,
                         -9.29429829e-01,  -9.27214146e-01,  -9.24231291e-01,
                         -9.22614336e-01,  -9.65630531e-01,  -9.47780609e-01,
                         -9.52025950e-01,  -9.47659016e-01,  -9.53356564e-01,
                         -9.52372015e-01,  -9.46251631e-01,  -9.36035395e-01,
                         -9.24980521e-01,  -9.21688080e-01,  -9.30071831e-01,
                         -9.43123937e-01,  -9.34451938e-01,  -9.13998425e-01,
                         -9.45369720e-01,  -9.31011200e-01,  -9.28853989e-01,
                         -9.66197848e-01,  -9.49215055e-01,  -9.33962464e-01,
                         -9.22192514e-01,  -9.07898366e-01,  -9.00554359e-01,
                         -9.27006602e-01,  -9.25200284e-01,  -9.44024146e-01,
                         -9.34394181e-01,  -9.27026629e-01,  -9.20027137e-01,
                         -9.35696721e-01,  -9.26749825e-01,  -9.42509055e-01,
                         -9.43412602e-01,  -9.31869805e-01,  -9.44641769e-01,
                         -9.41808403e-01,  -9.47898746e-01,  -9.47353721e-01,
                         -9.34290588e-01,  -9.32852149e-01,  -9.29176509e-01,
                         -9.52241957e-01,  -9.36701238e-01,  -9.30928946e-01,
                         -9.30821598e-01,  -9.35329020e-01,  -9.37280655e-01,
                         -9.32146013e-01,  -9.43446755e-01,  -9.30028260e-01,
                         -9.36744750e-01,  -9.37619865e-01,  -9.44736481e-01,
                         -9.25520241e-01,  -9.32070196e-01,  -9.56163883e-01,
                         -9.39880192e-01,  -9.46510434e-01,  -9.32712793e-01,
                         -9.52003121e-01,  -9.61965382e-01,  -9.48647797e-01,
                         -9.35724258e-01,  -9.40292239e-01,  -9.30883229e-01,
                         -9.33380425e-01,  -9.46341634e-01,  -9.33211565e-01,
                         -9.34685111e-01,  -9.31845307e-01,  -9.27456677e-01,
                         -9.26529586e-01,  -9.28806126e-01,  -9.38999712e-01,
                         -9.48077500e-01,  -9.25086021e-01,  -9.25162256e-01,
                         -9.16625321e-01,  -9.15025711e-01,  -9.29183006e-01,
                         -9.48133051e-01,  -9.49102283e-01,  -9.41095471e-01,
                         -9.49184597e-01,  -9.41360712e-01,  -9.30766463e-01,
                         -9.39743757e-01,  -9.27917778e-01,  -9.31222677e-01,
                         -9.21753407e-01,  -9.27041113e-01,  -9.28811133e-01,
                         -9.32300508e-01,  -9.36548889e-01,  -9.12248015e-01,
                         -9.30795550e-01,  -9.33791697e-01,  -9.29884195e-01,
                         -9.21297193e-01,  -9.54791486e-01,  -9.16693807e-01,
                         -9.14113104e-01,  -9.35899913e-01,  -9.32291210e-01,
                         -9.28634286e-01,  -9.36665118e-01,  -9.10571039e-01,
                         -9.39500630e-01,  -9.60970402e-01,  -9.50639427e-01,
                         -9.41491783e-01,  -9.31215048e-01,  -9.48323965e-01,
                         -9.29958880e-01,  -9.49208736e-01,  -9.17164326e-01,
                         -9.55610931e-01,  -9.24401224e-01,  -9.16367471e-01,
                         -9.17857707e-01,  -9.31720674e-01,  -9.08103406e-01,
                         -9.24577713e-01,  -9.20101464e-01,  -9.36301053e-01,
                         -9.29111838e-01,  -9.20761108e-01,  -9.25803185e-01,
                         -9.43917990e-01,  -9.25712466e-01,  -9.26413059e-01,
                         -9.20541167e-01,  -9.33687031e-01,  -9.46302831e-01,
                         -9.44870949e-01,  -9.51022863e-01,  -9.44011033e-01,
                         -9.42928016e-01,  -9.37166989e-01,  -9.42790508e-01,
                         -9.34350491e-01,  -9.43924308e-01,  -9.43753123e-01,
                         -9.42577183e-01,  -9.56853747e-01,  -9.36121643e-01,
                         -9.36513841e-01,  -9.54821706e-01,  -9.49644089e-01,
                         -9.32777405e-01,  -9.39697623e-01,  -9.51626301e-01,
                         -9.30409551e-01,  -9.17488396e-01,  -9.36347544e-01,
                         -9.28346813e-01,  -9.33351040e-01,  -9.43053186e-01,
                         -9.48694766e-01,  -9.42333102e-01,  -9.34691310e-01,
                         -9.24565792e-01,  -9.22873676e-01,  -9.10885155e-01,
                         -9.16574180e-01,  -9.42473233e-01,  -9.47564721e-01,
                         -9.20521796e-01,  -9.32545662e-01,  -9.31611001e-01,
                         -9.29854631e-01,  -9.38252330e-01,  -9.35056388e-01,
                         -9.28874195e-01,  -9.33464468e-01,  -9.17353570e-01,
                         -9.33246493e-01,  -9.41971958e-01,  -9.40430641e-01,
                         -9.38663721e-01,  -9.51139629e-01,  -9.67190921e-01,
                         -9.47607875e-01,  -9.54190254e-01,  -9.60485518e-01,
                         -9.59112525e-01,  -9.48786139e-01,  -9.42820907e-01,
                         -9.35289443e-01,  -9.36306834e-01,  -9.47105348e-01,
                         -9.48313773e-01,  -9.20535147e-01,  -9.29644644e-01,
                         -9.44332063e-01,  -9.36567545e-01,  -9.47785079e-01,
                         -9.52354968e-01,  -9.48459625e-01,  -9.52673316e-01,
                         -9.48038995e-01,  -9.40438032e-01,  -9.41793859e-01,
                         -9.40299451e-01,  -9.28541064e-01,  -9.35400009e-01,
                         -9.39283371e-01,  -9.40112591e-01,  -9.43564296e-01,
                         -9.37786937e-01,  -9.30463970e-01,  -9.29162264e-01,
                         -9.24188137e-01,  -9.23523188e-01,  -9.18454528e-01,
                         -9.16256964e-01,  -9.24689054e-01,  -9.38880980e-01,
                         -9.41007674e-01,  -9.28429425e-01,  -9.30892229e-01,
                         -9.33726192e-01,  -9.19901013e-01,  -9.25875187e-01,
                         -9.42786753e-01,  -9.43783045e-01,  -9.40659583e-01,
                         -9.48227644e-01,  -9.43317115e-01,  -9.30680096e-01,
                         -9.17816877e-01,  -9.21067297e-01,  -9.24638748e-01,
                         -9.14686143e-01,  -9.44449246e-01,  -9.82477784e-01,
                         -9.33802128e-01,  -8.93920779e-01,  -9.33474123e-01,
                         -9.42623317e-01,  -9.12710845e-01,  -9.29663002e-01,
                         -9.31801260e-01,  -9.30525839e-01,  -9.37667727e-01,
                         -9.46643293e-01,  -9.27840710e-01,  -9.34909999e-01,
                         -9.41600919e-01,  -9.30315733e-01,  -9.33315098e-01,
                         -9.43505824e-01,  -9.39750195e-01,  -9.43309128e-01,
                         -9.49813664e-01,  -9.46853399e-01,  -9.29762185e-01,
                         -9.29151952e-01,  -9.35451984e-01,  -9.35540974e-01,
                         -9.39909756e-01,  -9.37138796e-01,  -9.26334321e-01,
                         -9.38382626e-01,  -9.41776693e-01,  -9.37740743e-01,
                         -9.44030881e-01,  -9.45991457e-01,  -9.42215443e-01,
                         -9.47899938e-01,  -9.45578218e-01,  -9.46454763e-01,
                         -9.43635046e-01,  -9.38201904e-01,  -9.35515761e-01,
                         -9.33260798e-01,  -9.26616549e-01,  -9.27848279e-01,
                         -9.27027524e-01,  -9.30730224e-01,  -9.36549664e-01,
                         -9.45608258e-01,  -9.46566105e-01,  -9.44853544e-01,
                         -9.36666429e-01,  -9.36746836e-01,  -9.44810629e-01,
                         -9.47752893e-01,  -9.32684839e-01,  -9.31499779e-01,
                         -9.38118279e-01,  -9.42553759e-01,  -9.34933603e-01,
                         -9.44058180e-01,  -9.47014749e-01,  -9.40175354e-01,
                         -9.36458886e-01,  -9.40334380e-01,  -9.40274715e-01,
                         -9.47093487e-01,  -9.28432047e-01,  -9.59016800e-01,
                         -9.51022983e-01,  -8.98902833e-01,  -9.47814345e-01,
                         -9.29572582e-01,  -9.18718815e-01,  -2.19657663e-02,
                          1.43527379e-02,  -1.30601991e-02,  -1.94847770e-02,
                          1.03108841e-03,   5.94476284e-03,  -1.04826204e-02,
                         -1.74721032e-02,  -5.48361894e-03,  -1.65783837e-02,
                         -1.64773241e-02,  -1.03719626e-02,   2.62346538e-03,
                          1.77809864e-03,  -7.22547807e-03,  -5.29630296e-03,
                         -4.56901686e-03,  -9.32051893e-03,   2.00814730e-03,
                          1.72880944e-03,  -3.32299527e-03,  -3.27705347e-04,
                          1.50549714e-03,   2.00476521e-03,   1.13584399e-02,
                          1.14087686e-02,   1.18091737e-03,  -1.66075956e-03,
                          1.86996840e-04,  -2.18747207e-03,  -2.12235376e-03,
                         -9.74141061e-03,  -9.60087590e-03,  -1.42588723e-03,
                         -4.85732965e-03,  -3.40597332e-03,   3.10864387e-04,
                         -6.77124411e-03,  -5.47830993e-03,  -5.52107766e-03,
                         -6.39869180e-03,   7.15587579e-04,   5.13374293e-03,
                          1.52083416e-03,  -1.00646466e-02,  -8.14030878e-03,
                          1.46273640e-04,  -9.91694536e-03,  -1.04355281e-02,
                         -9.20780282e-03,  -1.03088534e-02,   6.06168574e-03,
                          5.37025102e-04,  -1.22287415e-03,   1.40562411e-02,
                         -2.70511978e-03,  -6.01332542e-03,   7.51288328e-03,
                         -7.80450879e-03,  -7.78992008e-03,  -6.35215407e-03,
                         -5.85851353e-03,   1.92764343e-03,  -5.25091588e-03,
                          5.15760435e-03,  -2.91088410e-03,  -4.80671693e-03,
                          7.39952922e-03,   3.69519391e-03,  -1.33922221e-02,
                         -1.16798517e-04,   5.63490298e-03,   4.17666463e-03,
                          3.71771073e-03,  -1.22765618e-04,  -1.40344654e-03,
                          2.49498221e-03,   3.44818644e-03,  -5.39603207e-05,
                         -2.92333821e-03,   4.74976283e-03,   1.35629193e-03,
                         -3.20763118e-03,  -4.13391786e-03,  -5.65603422e-03,
                          6.45694206e-04,   2.43174890e-03,  -3.63443489e-03,
                          7.19364674e-04,  -2.58964486e-03,  -2.83162086e-03,
                          3.03664361e-03,   4.24927473e-03,   6.19675312e-03,
                          7.25546619e-03,   2.50349962e-03,   3.53008334e-04,
                         -3.65979318e-03,  -2.04684678e-03,  -4.77545382e-03,
                         -6.58394210e-03,  -3.22631560e-03,  -2.32213736e-03,
                         -1.57536974e-03,  -4.09588347e-06,  -6.11420488e-03,
                         -4.68512252e-03,  -2.96969572e-03,   1.23637472e-03,
                          2.99527589e-03,  -7.35173002e-04,  -4.73286631e-03,
                         -2.81577092e-03,  -1.50860881e-03,  -1.77178497e-03,
                         -6.31434843e-03,  -4.18646436e-04,  -6.34652656e-03,
                         -1.06201200e-02,  -5.86111238e-03,  -6.08420977e-03,
                         -2.99359183e-03,   6.53999625e-03,  -6.52040401e-03,
                          1.94459525e-03,  -1.56892440e-03,  -1.36468466e-03,
                         -1.65342016e-03,  -7.38215458e-04,  -2.51165678e-04,
                         -1.74037623e-03,   3.82118905e-03,   2.56267167e-03,
                          3.81622696e-03,  -1.19139615e-03,   4.24637785e-03,
                          1.94916234e-03,  -4.37111175e-03,  -3.99390236e-03,
                         -2.96959188e-03,  -4.95601911e-03,  -3.19458125e-03,
                         -1.19773753e-03,  -1.54745393e-03,  -3.76309128e-03,
                         -1.14480290e-03,   1.12827387e-04,   5.78503706e-04,
                         -4.12824855e-04,  -6.19569980e-03,  -5.40416129e-03,
                         -9.98792588e-04,   1.97108326e-04,   4.23886534e-03,
                          3.25609581e-03,  -1.11566049e-04,   1.80886278e-03,
                         -5.12609200e-04,  -1.36349257e-03,   7.09793763e-04,
                          1.06432673e-03,   2.52388208e-03,   3.66556621e-03,
                          4.13463870e-03,   4.93161008e-03,   1.19518023e-03,
                          8.67551134e-04,   1.76908216e-03,   3.64842732e-03,
                          6.43965090e-03,   5.62698161e-03,   3.90517898e-03,
                          5.65536181e-03,   2.62666726e-03,   3.85774020e-03,
                          5.05245617e-03,   1.85852626e-03,   1.84960675e-03,
                          3.26731615e-03,  -1.34198752e-03,   2.29539978e-03,
                          9.88999964e-04,  -3.31527460e-03,  -1.16765255e-03,
                          4.44552366e-04,  -1.01089315e-03,   6.19972637e-03,
                         -1.15858065e-03,   2.61213421e-03,   4.70782677e-03,
                          7.16114300e-04,   3.40760872e-03,   9.90878092e-04,
                          4.87045618e-03,  -1.52458355e-03,   7.63156684e-03,
                         -3.67319677e-04,   3.79025150e-05,   1.59867667e-03,
                          4.71338462e-05,   1.90830056e-03,   3.23362043e-03,
                         -1.46704016e-03,   1.64446607e-03,   3.73827352e-04,
                         -1.17720268e-03,   2.49169709e-04,  -4.33477544e-04,
                         -1.90142554e-03,   4.73521563e-04,  -8.90761090e-04,
                         -6.48431713e-04,  -6.23911852e-04,  -2.14088568e-03,
                         -2.22579739e-03,  -9.10589064e-04,  -4.94798005e-04,
                          9.65907762e-04,  -9.35254444e-04,  -3.07982718e-03,
                         -3.56859574e-03,  -3.82247125e-03,  -3.42460908e-03,
                         -3.00917146e-03,  -3.30435229e-03,  -1.56264543e-03,
                         -3.60872992e-03,  -3.62103828e-03,  -2.28529517e-03,
                         -4.61294921e-03,  -4.83969878e-03,  -4.02300991e-03,
                         -3.43786017e-03,  -4.04182611e-05,   1.65103615e-04,
                         -4.74159169e-04,  -1.28593412e-03,  -2.00473052e-03,
                         -1.40148518e-03,  -1.31608150e-03,  -2.44913739e-03,
                         -2.02733069e-03,  -2.19601044e-03,  -8.68070871e-04,
                         -1.48150395e-03,  -3.80085519e-04,   9.60730715e-04,
                         -3.24593566e-04,  -2.09021746e-04,   2.53797858e-03,
                         -8.13826395e-04,  -1.30437606e-03,  -8.96457932e-04,
                          4.61150747e-04,  -2.86553148e-03,   1.25590467e-03,
                          3.88455391e-03,   1.50574662e-03,   1.34583388e-03,
                          1.59474718e-03,   1.23861316e-03,  -1.79252774e-03,
                          1.71839987e-04,  -7.57669157e-04,  -1.29910896e-03,
                         -7.84184958e-04,  -3.91257374e-04,  -3.69669069e-05,
                          7.68508355e-04,   7.49317987e-04,  -7.45596364e-04,
                          2.34934618e-04,   1.62156101e-03,  -7.31541426e-04,
                         -6.26753375e-04,   1.97170710e-04,   2.86490074e-04,
                          8.26654665e-04,   1.12480866e-05,  -3.03663686e-03,
                         -1.68746943e-03,  -1.89531292e-03,   6.64496445e-04,
                         -1.72335515e-03,  -5.78704698e-04,   2.23013572e-03,
                          2.91519496e-03,   3.50377546e-03,   2.74483790e-03,
                          2.83571682e-03,  -1.17795810e-03,  -3.28372046e-03,
                          1.48352073e-03,  -1.63093791e-03,  -2.54055671e-03,
                         -2.89818062e-03,   1.06950378e-04,   2.11359374e-03,
                          2.55553331e-03,   3.30011779e-03,   2.58954102e-03,
                          5.39090368e-04,   3.10350861e-03,   7.69582577e-04,
                         -1.09642849e-03,   9.28545836e-04,   6.14133023e-04,
                          8.90123541e-04,  -1.08570023e-03,  -7.60046300e-04,
                         -1.71734649e-03,  -1.51131174e-03,  -2.50139972e-04,
                          1.19554054e-03,   2.90105678e-03,   2.23194467e-04,
                          5.58592554e-04,   1.63650990e-03,  -5.04459022e-04,
                         -5.79834334e-04,  -4.07280517e-04,   2.10960885e-03,
                          5.12082479e-04,   6.91836991e-04,   3.78449936e-03,
                          3.59280384e-04,   5.76778024e-04,   2.48731719e-03,
                          6.70699228e-04,   9.40064201e-04,   2.42932336e-04,
                          9.05876397e-04,   6.34670677e-03,   9.72734240e-04,
                         -9.99929267e-04,   1.54396097e-04,   1.44226383e-03,
                          1.50217049e-04,   6.81018631e-04,   1.83998037e-03,
                         -1.83281431e-03,   1.09352462e-03,  -4.45044425e-04,
                         -7.79652502e-04,   3.92054353e-05,  -1.40470790e-03,
                          2.55705114e-03,   3.88686196e-04,  -2.45412043e-03,
                         -4.14113922e-04,  -1.13513495e-04,   3.38785700e-03,
                          2.56633793e-04,  -1.08574179e-03,  -9.40992846e-04,
                          1.34688034e-03,  -7.05268176e-04,  -4.00307123e-03,
                          1.20019086e-03,  -3.92446620e-03,   2.14760134e-04,
                         -2.22581113e-03,  -3.73885548e-03,  -7.85055477e-03,
                         -7.40296626e-03,  -1.55058643e-03,  -4.88199526e-03,
                         -2.81070475e-04,  -4.83601866e-03,   2.59787124e-03,
                          2.21559568e-03,  -1.28641934e-03,   3.37117561e-03,
                         -4.63804416e-03,   1.70385989e-03,  -3.09443640e-05,
                          2.68639368e-03,  -2.02166848e-03,   4.35420824e-03,
                          5.89010247e-04,  -3.79371690e-04,   3.52393603e-03,
                         -9.78541910e-04,   8.98731116e-04,  -6.15352823e-04,
                          1.56095438e-03,   4.09255689e-03,  -1.53945619e-03,
                          8.03991407e-03,   2.65747984e-03,   4.86612460e-03,
                          3.55957914e-03,   5.18374611e-03,   7.93395520e-05,
                         -6.36317360e-04,   5.87921450e-03,  -3.39498860e-03,
                          8.50180723e-03,   7.09128450e-04,   3.07586999e-03,
                          4.17635962e-03,   2.81416997e-03,   6.15851115e-03,
                         -6.40854007e-03,  -4.22417978e-03,  -5.60486689e-03,
                          2.19912920e-03,  -2.55208206e-03,  -5.14466548e-04,
                          2.32497882e-03,  -9.20879375e-03,  -2.20151315e-03,
                          1.19154865e-03,   2.28177450e-04,  -4.22428362e-03,
                          1.69857196e-03,  -1.86413294e-03,  -4.10358328e-03,
                         -7.85772037e-03,  -8.38656072e-03,  -3.77084641e-03,
                         -1.21417653e-03,  -3.24816746e-03,   3.25529883e-03,
                          3.21424287e-03,   1.33362249e-03,  -3.46161076e-04,
                         -3.92235955e-03,   5.99308172e-03,   2.61970214e-03,
                          4.51488327e-03,  -2.48704688e-03,   5.81095694e-04,
                         -1.00895818e-02,  -3.38086416e-03,   6.71153143e-03,
                         -8.40311777e-03,  -5.15725790e-03,  -6.48207869e-03,
                         -1.62818644e-03,   3.05694994e-03,  -7.69588118e-03,
                         -3.24610900e-03,  -2.08047312e-03,  -5.32825245e-03,
                         -2.02091305e-05,  -1.18160353e-03,  -5.57162846e-03,
                         -4.77488525e-03,  -1.92513457e-03,   3.90816620e-03,
                         -4.82255314e-03,   3.10618361e-03,   3.02514620e-03,
                          9.50483419e-03,   5.61124273e-03,  -1.47787237e-03,
                         -1.31720433e-03,   3.83695588e-03,   3.13500734e-03,
                          2.65641278e-03,  -2.50814995e-03,   2.39053369e-03,
                         -5.07100206e-03,  -8.30342341e-03,   1.02484412e-03,
                         -1.15095021e-03,  -3.32982163e-03,  -5.97092509e-03,
                         -1.28658079e-02,   7.95832928e-03,  -1.36607769e-03,
                          1.50532380e-03,  -4.45785979e-03,  -2.02763570e-03,
                         -7.73630617e-03,  -1.67329668e-03,  -4.64214012e-03,
                         -7.63179548e-03,   6.65854837e-04,  -5.55182807e-04,
                          7.63572473e-03,  -3.53289023e-03,   1.26936147e-02,
                         -6.28472771e-03,   8.31041578e-03,   3.29300039e-03,
                          3.19764460e-03,  -2.56186770e-03,  -9.61396028e-04,
                          5.32379607e-03,   6.20719697e-03,   7.50061637e-03,
                          6.82141352e-03,   2.38756044e-03,  -1.39959319e-03,
                         -7.73046399e-03,  -2.69358046e-04,   2.26479489e-03,
                         -4.34853230e-03,   1.68820401e-03,  -2.02834257e-03,
                          1.12336711e-03,  -1.00412769e-02,   3.58609506e-03,
                         -1.01509094e-02,  -8.17401148e-03,   4.33174009e-03,
                          5.70884394e-03,  -2.32051546e-03,   6.23588217e-03,
                          2.99824914e-03,  -2.18614144e-03,   9.69883054e-03,
                         -8.30767117e-03,  -9.61971295e-04,  -1.09932749e-02,
                         -4.16187523e-03,   6.96078409e-04,  -5.54058701e-03,
                         -2.30838734e-04,   1.59880705e-02,   1.18773693e-04,
                          1.22119009e-03,   8.77270382e-03,   1.42824156e-02,
                          4.50038491e-03,   2.03267951e-02,  -1.21186310e-02,
                         -3.01660085e-03,  -4.34165029e-03,   1.23795271e-02,
                          4.40541049e-03,   3.90976015e-03,   8.23981594e-03,
                          5.89940976e-03,   1.12013202e-02,   1.42907526e-03,
                         -1.07079977e-03,   6.72733271e-03,   7.22506223e-03,
                          7.19202496e-03,   7.01307459e-03,   5.31165395e-03,
                         -9.37908143e-03,  -2.94141960e-03,  -4.15494479e-03,
                         -9.29852128e-01,  -9.38370645e-01,  -9.28167522e-01,
                         -9.28960085e-01,  -9.27274227e-01,  -9.23244357e-01,
                         -9.33291912e-01,  -9.22745526e-01,  -9.35546279e-01,
                         -9.41929579e-01,  -9.36559319e-01,  -9.29100871e-01,
                          4.60560946e-03,  -2.70821759e-03,   1.53039331e-02,
                          8.82405788e-03,   6.75524864e-03,  -2.44086236e-03,
                          2.43556756e-03,   3.74640967e-03,  -4.17850818e-03,
                          5.59126213e-03,   7.83439260e-03,  -6.04786677e-03,
                         -1.36957061e-03,  -1.22001749e-02,   4.06437088e-03,
                          9.94242821e-03,   7.23253330e-03,  -1.49868452e-03,
                          5.39030042e-03,  -8.19837209e-03,   4.06824518e-03,
                         -1.08753471e-02,  -2.55502667e-02,  -1.22532761e-02,
                         -1.06988428e-02,  -8.81695375e-03,  -1.04205580e-02,
                         -1.43274218e-02,   2.74779741e-03,  -5.49813127e-03,
                          9.55950096e-03,   6.20706566e-03,  -1.31013803e-02,
                          1.53003773e-03,   7.63943978e-03,   7.34167360e-03,
                         -9.85633861e-03,  -4.86141164e-03,   2.93385849e-04,
                          1.01411585e-02,   2.90859700e-03,   2.79317074e-03,
                         -3.85788572e-03,  -1.14578288e-02,  -1.29401647e-02,
                         -1.19057838e-02,  -2.12578084e-02,  -2.89234463e-02,
                         -1.15602743e-02,  -2.26612352e-02,  -9.71900485e-03,
                         -3.70534696e-03,  -1.34748337e-03,   8.34681466e-03,
                          2.67118146e-03,   1.14789177e-02,   7.35245040e-03,
                         -4.18089237e-03,   1.29977493e-02,   4.81607299e-03,
                          2.43073218e-02,   1.46995299e-02,   9.09334701e-03,
                         -2.51596607e-02,  -9.29460883e-01,  -9.37416255e-01,
                         -9.47501838e-01,  -9.35191214e-01,  -9.41950083e-01,
                         -9.31633830e-01,  -9.38582122e-01,  -9.14685786e-01,
                         -9.33285952e-01,  -9.29925442e-01,  -9.18218970e-01,
                         -9.36600029e-01,  -9.29020822e-01,  -9.39583123e-01,
                         -9.26975608e-01,  -9.24447060e-01,  -9.28992152e-01,
                         -9.42988873e-01,  -9.15119410e-01,  -9.30271387e-01,
                         -9.39298809e-01,  -9.22125638e-01,  -9.21140671e-01,
                         -9.33513284e-01,  -9.52003777e-01,  -9.32124317e-01,
                         -9.19101298e-01,  -9.47431028e-01,  -9.50152278e-01,
                         -9.55803871e-01,  -9.59243000e-01,  -9.45137322e-01,
                         -9.51682091e-01,  -9.48564172e-01,  -9.69020665e-01,
                         -9.42198157e-01,  -9.14673686e-01,  -9.24781263e-01,
                         -9.31888103e-01,  -9.29394305e-01,  -9.37270880e-01,
                         -9.34368968e-01,  -9.16571975e-01,  -9.56670463e-01,
                         -9.30929959e-01,  -9.19530749e-01,  -9.38571393e-01,
                         -9.38430130e-01,  -9.26908016e-01,  -9.33508039e-01,
                         -9.17114079e-01,  -9.35986459e-01,  -9.14067626e-01,
                         -9.38015819e-01,  -9.22442794e-01,  -9.25820172e-01,
                         -9.44005251e-01,  -9.29395556e-01,  -9.23613608e-01,
                         -9.25871789e-01,  -9.17981327e-01,  -9.32771862e-01,
                         -9.18505430e-01,  -9.11994755e-01,  -9.22135830e-01,
                         -9.28406060e-01,  -9.45282042e-01,  -9.39492166e-01,
                         -9.38961685e-01,  -9.49734151e-01,  -9.33709204e-01,
                         -9.38158989e-01,  -9.26107883e-01,  -9.28126812e-01,
                         -9.21719730e-01,  -9.19872999e-01,  -9.34298813e-01,
                         -9.20945585e-01,  -9.28298116e-01,  -9.18329120e-01,
                         -9.36170757e-01,  -9.23437953e-01,  -9.30729091e-01,
                         -9.33937311e-01,  -9.21043515e-01,  -9.23109233e-01,
                         -9.39183116e-01,  -9.32198465e-01,  -9.36968088e-01,
                         -9.47614193e-01,  -9.45045829e-01,  -9.20985818e-01,
                         -9.27646458e-01,  -9.17848229e-01,  -9.22118187e-01,
                         -9.29212034e-01,  -9.33647990e-01,  -9.25858974e-01,
                         -9.40347314e-01,  -9.45745111e-01,  -9.28466380e-01,
                         -9.19434607e-01,  -9.26042497e-01,  -9.35053170e-01,
                         -9.46596563e-01,  -9.26693320e-01,  -9.26684558e-01,
                         -9.16844726e-01,  -9.08503771e-01,  -9.27682579e-01,
                         -9.24069881e-01,  -9.19625401e-01,  -9.10423219e-01,
                         -9.19468105e-01,  -9.29967940e-01,  -9.33056414e-01,
                         -9.47169423e-01,  -9.38588202e-01,  -9.24575508e-01,
                         -9.11356866e-01,  -9.21171308e-01,  -9.23208833e-01,
                         -9.39123034e-01,  -9.37741280e-01,  -9.37958062e-01,
                         -9.38274086e-01,  -9.28394079e-01,  -9.33505952e-01,
                         -9.39704955e-01,  -9.34842467e-01,  -9.27772403e-01,
                         -9.23779964e-01,  -9.19855475e-01,  -9.30274904e-01,
                         -9.19181287e-01,  -9.36186433e-01,  -9.34029579e-01,
                         -9.50078547e-01,  -9.25066769e-01,  -9.45092618e-01,
                         -9.18265820e-01,  -9.27711427e-01,  -9.30233538e-01,
                         -9.40319419e-01,  -9.18020606e-01,  -9.25307870e-01,
                         -9.48313355e-01,  -9.23412323e-01,  -9.39939737e-01,
                         -9.29393411e-01,  -9.40352798e-01,  -9.42986548e-01,
                         -9.46419060e-01,  -9.48955178e-01,  -9.33584034e-01,
                         -9.45420980e-01,  -9.37312782e-01,  -9.43366885e-01,
                         -9.37387645e-01,  -9.53455925e-01,  -9.33952272e-01,
                         -9.43542302e-01,  -9.34947014e-01,  -9.46416736e-01,
                         -9.32064772e-01,  -9.43155885e-01,  -9.36657250e-01,
                         -9.46557343e-01,  -9.44335520e-01,  -9.38848019e-01,
                         -9.16813195e-01,  -9.39428091e-01,  -9.30129826e-01,
                         -9.37982202e-01,  -9.51110363e-01,  -9.34441388e-01,
                         -9.28082943e-01,  -9.30196404e-01,  -9.42958713e-01,
                         -9.49211180e-01,  -9.27970469e-01,  -9.45587277e-01,
                         -9.46141601e-01,  -9.34509814e-01,  -9.35454905e-01,
                         -9.35329497e-01,  -9.50701535e-01,  -9.53939736e-01,
                         -9.57076728e-01,  -9.35830235e-01,  -9.30775940e-01,
                         -9.43255365e-01,  -9.46597695e-01,  -9.15720463e-01,
                         -9.23039377e-01,  -9.22815025e-01,  -9.39474463e-01,
                         -9.32509422e-01,  -9.48198795e-01,  -9.52953398e-01,
                         -9.23734426e-01,  -9.44735110e-01,  -9.41445351e-01,
                         -9.30876017e-01,  -9.29711282e-01,  -9.28175926e-01,
                         -9.37387407e-01,  -9.39606071e-01,  -9.58102882e-01,
                         -9.50100303e-01,  -9.29607153e-01,  -9.35820401e-01,
                         -9.36448455e-01,  -9.39172506e-01,  -9.41067517e-01,
                         -9.26109791e-01,  -9.39657748e-01,  -9.41865027e-01,
                         -9.35675979e-01,  -9.39474344e-01,  -9.28130269e-01,
                         -9.35385704e-01,  -9.32142258e-01,  -9.38886404e-01,
                         -9.27752435e-01,  -9.30878937e-01,  -9.41858292e-01,
                         -9.43711996e-01,  -9.33363676e-01,  -9.21896279e-01,
                         -9.23374593e-01,  -9.34583008e-01,  -9.36114371e-01,
                         -9.40278351e-01,  -9.39592659e-01,  -9.41731334e-01,
                         -9.43599880e-01,  -9.38843250e-01,  -9.38831508e-01,
                         -9.40810382e-01,  -9.49971735e-01,  -9.43610072e-01,
                         -9.27606463e-01,  -9.35061038e-01,  -9.22089458e-01,
                         -9.21582103e-01,  -9.34935153e-01,  -9.17011440e-01,
                         -9.28445756e-01,  -9.32504773e-01,  -9.42867458e-01,
                         -9.24480975e-01,  -9.26580489e-01,  -9.30718720e-01,
                         -9.22803521e-01,  -9.41560745e-01,  -9.30432260e-01,
                         -9.23186600e-01,  -9.32052433e-01,  -9.45499718e-01,
                         -9.54287052e-01,  -9.48001862e-01,  -9.43125367e-01,
                         -9.34338391e-01,  -9.53978896e-01,  -9.30595934e-01,
                         -9.48247254e-01,  -9.40110683e-01,  -9.45306778e-01,
                         -9.41133201e-01,  -9.38559413e-01,  -9.24981773e-01,
                         -9.38462615e-01,  -9.17794406e-01,  -9.29312587e-01,
                         -9.30959761e-01,  -9.46191490e-01,  -9.35728252e-01,
                         -9.41325784e-01,  -9.24253225e-01,  -9.50673103e-01,
                         -9.46546555e-01,  -9.38156009e-01,  -9.24936593e-01,
                         -9.35323179e-01,  -9.38350022e-01,  -9.50922072e-01,
                         -9.39358234e-01,  -9.46511745e-01,  -9.31724668e-01,
                         -9.34704661e-01,  -9.27847624e-01,  -9.26522136e-01,
                         -9.36675191e-01,  -9.40228224e-01,  -9.30124462e-01,
                         -9.25883174e-01,  -9.26342845e-01,  -9.51563299e-01,
                         -9.34412241e-01,  -9.51186836e-01,  -9.46311176e-01,
                         -9.56734419e-01,  -9.52484787e-01,  -9.57536042e-01,
                         -9.22358871e-01,  -9.44553733e-01,  -9.42052305e-01,
                         -9.29182410e-01,  -9.39169168e-01,  -9.50679243e-01,
                         -9.50595140e-01,  -9.37513828e-01,  -9.52783048e-01,
                         -9.53879178e-01,  -9.34397459e-01,  -9.58530426e-01,
                         -9.32730734e-01,  -9.47146595e-01,  -9.33972001e-01,
                         -9.19759452e-01,  -9.26214933e-01,  -9.39581335e-01,
                         -9.33329999e-01,  -9.43829834e-01,  -9.10886288e-01,
                         -9.24152613e-01,  -9.22761261e-01,  -9.34298575e-01,
                         -9.13702905e-01,  -9.22403574e-01,  -9.32099819e-01,
                         -9.16120946e-01,  -9.20524955e-01,  -9.26895857e-01,
                         -9.23746765e-01,  -9.42007005e-01,  -9.26063538e-01,
                         -9.33087885e-01,  -9.36223924e-01,  -9.37402427e-01,
                         -9.29536819e-01,  -9.43676829e-01,  -9.20048058e-01,
                         -9.45028543e-01,  -9.22138512e-01,  -9.37306046e-01,
                         -9.15811598e-01,  -9.46107566e-01,  -9.36342537e-01,
                         -9.34663832e-01,  -9.24312174e-01,  -9.43209887e-01,
                         -9.28048790e-01,  -9.34185028e-01,  -9.24207807e-01,
                         -9.26607966e-01,  -9.49519992e-01,  -9.35907960e-01,
                         -9.56130207e-01,  -9.45420980e-01,  -9.23072159e-01,
                         -9.34879184e-01,  -9.03413594e-01,  -7.25412881e-03,
                          1.13426177e-02,   7.55991973e-03,   6.59808051e-03,
                          1.90893952e-02,   6.35785097e-03,   1.14436904e-02,
                         -1.67266037e-02,  -1.16505846e-02,  -1.74863599e-02,
                         -1.53228873e-02,   1.09178303e-02,  -1.79017894e-02,
                         -1.37076536e-02,   6.77813264e-03,   1.18212746e-02,
                         -1.39428454e-03,   1.78365130e-02,  -3.71921487e-04,
                          5.19099552e-03,   4.26776521e-03,   9.28768981e-03,
                         -8.27666465e-03,  -1.51914312e-03,  -2.15337928e-02,
                          3.10960039e-03,   8.94150115e-04,   6.13830891e-03,
                         -2.44528404e-03,   1.40350126e-02,   3.81992082e-03,
                         -1.67433619e-02,  -1.28169898e-02,  -2.23191688e-03,
                         -1.55898966e-02,  -1.14731519e-02,  -3.57187376e-03,
                         -1.93873905e-02,  -6.88389828e-03,  -1.78439561e-02,
                         -1.35706253e-02,  -7.26466998e-03,  -6.21902756e-03,
                          7.76230218e-03,  -4.25655162e-03,   1.28311627e-02,
                          1.44925732e-02,   8.31198227e-03,  -2.23702472e-03,
                          1.09962001e-02,   1.96205992e-02,  -1.31030846e-02,
                         -1.67913898e-03,   1.85345311e-03,  -2.16894713e-03,
                         -2.04515569e-02,  -2.49001314e-03,   5.65525796e-03,
                          2.08371668e-03,   1.15387207e-02,  -2.73642456e-03,
                         -1.37581211e-02,   1.49403485e-02,  -1.19081407e-03,
                          1.47534278e-03,   2.02894537e-03,   1.85006689e-02,
                          5.60662709e-03,  -7.58932577e-03,  -1.00389067e-02,
                         -1.90161273e-03,  -4.06067702e-04,   3.01393960e-03,
                         -1.12836044e-02,  -2.78255902e-02,   3.91621934e-03,
                         -2.69087777e-03,  -1.52642904e-02,  -7.19801988e-03,
                         -2.95671518e-03,  -5.51243545e-03,   1.01372774e-03,
                         -2.80022598e-03,   5.32222306e-03,   3.69552663e-03,
                          7.26714404e-03,   2.80441879e-03,  -1.32169174e-02,
                         -7.44438963e-03,   1.03096021e-02,   1.15418322e-02,
                          1.85640343e-02,   1.35150570e-02,   1.20140789e-02,
                          2.14617644e-02,   3.54512921e-03,  -7.47087784e-03,
                          1.13418130e-02,   5.74760558e-03,   1.26745561e-02,
                          1.65373683e-02,   1.44704590e-02,   1.32277496e-02,
                          1.40615841e-02,   6.59530796e-03,   2.22042426e-02,
                          3.52661274e-02,  -5.34462230e-03,   1.50240608e-03,
                          2.21660491e-02,   2.92030256e-03,   3.95110883e-02,
                          3.39102708e-02,   9.18552163e-04,   3.39944469e-04,
                          3.52099054e-02,   2.05569975e-02,   1.13199130e-02,
                          8.02181195e-03,   7.90572073e-03,   1.56212216e-02,
                         -1.01498216e-02,   2.15614662e-02,  -3.83279053e-03,
                          3.72952712e-03,  -9.54949390e-03,   1.06005138e-02,
                         -1.68395489e-02,   2.27148971e-03,  -1.09866913e-02,
                          8.89311265e-03,   5.48215630e-03,   6.99704420e-03,
                          1.74548533e-02,   7.62345130e-03,   9.28840321e-03,
                         -1.27702160e-03,  -1.26754707e-02,  -4.65738680e-03,
                         -1.65671073e-02,   2.61975899e-02,   1.73086636e-02,
                          8.90833233e-03,   6.10341411e-03,   2.06288369e-03,
                         -2.51338519e-02,  -1.61596406e-02,  -6.21041283e-03,
                         -1.40544248e-03,   8.90431181e-03,   2.12526461e-03,
                         -2.20305868e-03,  -1.66910160e-02,  -4.24524816e-03,
                         -1.69874653e-02,  -1.74429826e-02,   4.92971111e-03,
                         -1.21492222e-02,  -6.53841626e-03,  -9.02199745e-03,
                         -3.20620369e-03,  -1.66788120e-02,  -6.88660098e-03,
                          1.32653955e-02,  -1.08479438e-02,  -1.76277547e-03,
                          2.55242153e-03,   2.06673029e-03,   1.02680130e-02,
                         -9.90461558e-03,  -1.21861892e-02,  -4.17413516e-03,
                          1.20876320e-02,   3.76133085e-03,   1.27349822e-02,
                          1.88101828e-02,  -6.96307840e-03,  -3.69120203e-03,
                          6.38810918e-03,  -9.92271770e-03,   1.37578854e-02,
                         -2.29515992e-02,   3.09440191e-03,  -1.68275051e-02,
                         -1.39903883e-02,  -1.46287773e-02,  -9.32600116e-04,
                         -1.05773732e-02,   1.10552122e-03,  -1.23015670e-02,
                         -1.60225220e-02,  -8.77061021e-03,  -8.88985582e-03,
                          3.61186941e-03,  -1.95311625e-02,  -2.13392768e-02,
                          4.87615960e-03,  -2.04173420e-02,   5.66460006e-03,
                          2.01133522e-03,  -3.68816638e-03,  -2.65152324e-02,
                          1.18689695e-02,  -2.95028985e-02,   3.26728146e-03,
                         -1.63298789e-02,  -2.23062020e-02,  -2.73492411e-02,
                         -1.93398204e-02,   3.23983002e-03,  -1.52197415e-02,
                         -7.97806773e-03,   1.58672035e-02,  -7.71640893e-03,
                         -1.98086146e-02,  -2.47918069e-03,  -2.44678110e-02,
                          3.46756401e-03,   8.00431985e-03,  -6.86583063e-03,
                          8.63408763e-03,  -3.54485912e-03,   4.10872558e-03,
                         -4.46730619e-03,  -1.27348853e-02,   3.40510695e-03,
                          2.35444703e-03,   2.97635179e-02,   1.73364679e-04,
                          9.27689951e-03,   1.62137114e-02,  -1.42837670e-02,
                          5.40859019e-03,  -4.10712138e-02,   5.51495841e-03,
                         -3.46666988e-04,   6.46315888e-03,  -5.90132957e-04,
                         -5.37224673e-03,   2.03851368e-02,  -6.41750812e-04,
                         -1.50645906e-02,   1.13124633e-02,  -1.60788856e-02,
                          7.96622317e-03,  -1.90857775e-03,  -1.48291225e-02,
                         -5.45951491e-03,  -1.19036008e-02,   2.33293977e-02,
                          2.82362313e-03,   6.57390011e-03,  -3.15246508e-02,
                          4.27056104e-02,  -1.02878129e-02,  -5.73126366e-03,
                          8.93102214e-03,   1.99687015e-02,  -3.33202295e-02,
                         -1.25212758e-03,  -1.19222645e-02,   2.81766150e-02,
                         -1.27557460e-02,   1.07956333e-02,  -7.64749408e-01,
                         -7.51459122e-01,  -7.63118923e-01,  -7.57595301e-01,
                         -7.45720267e-01,  -7.48515844e-01,  -7.51421928e-01,
                         -7.68829346e-01,  -7.39762843e-01,  -7.44201243e-01,
                         -7.68537760e-01,  -7.40443170e-01,  -7.46294081e-01,
                         -7.61413813e-01,  -7.44852543e-01,  -7.56873965e-01,
                         -7.31612444e-01,  -7.72323668e-01,  -7.58489966e-01,
                         -7.55033016e-01,  -7.36783385e-01,  -7.49741077e-01,
                         -7.54494905e-01,  -7.63899088e-01,  -7.45913208e-01,
                         -7.29911208e-01,  -7.36346126e-01,  -7.35618353e-01,
                         -7.50077426e-01,  -7.15813696e-01,  -7.51426399e-01,
                         -7.49107957e-01,  -7.39354610e-01,  -7.45345116e-01,
                         -7.24317074e-01,  -7.92118907e-01,  -7.49511957e-01,
                         -7.59859502e-01,  -7.50728667e-01,  -7.47999966e-01,
                         -7.59858072e-01,  -7.63157487e-01,  -7.34642744e-01,
                         -7.51209259e-01,  -7.68966317e-01,  -7.35574067e-01,
                         -7.81121552e-01,  -7.57612050e-01,  -7.30232000e-01,
                         -7.86846101e-01,  -7.46224105e-01,  -7.71523416e-01,
                         -7.54608870e-01,  -7.38553941e-01,  -7.48727202e-01,
                         -7.55616844e-01,  -7.55802810e-01,  -7.45695055e-01,
                         -7.38386154e-01,  -7.64015973e-01,  -7.82034278e-01,
                         -7.67976582e-01,  -7.62015581e-01,  -7.52146244e-01,
                         -7.42606342e-01,  -7.56539226e-01,  -7.55559504e-01,
                         -7.70155609e-01,  -7.47302592e-01,  -7.31107235e-01,
                         -7.93632984e-01,  -7.53619194e-01,  -7.77130425e-01,
                         -7.62420297e-01,  -7.57173181e-01,  -7.55905390e-01,
                         -7.74217904e-01,  -7.59287834e-01,  -7.71158159e-01,
                         -7.51665711e-01,  -9.35588300e-01,  -9.40091431e-01,
                         -9.03648376e-01,  -9.54903662e-01,  -7.40638971e-01,
                         -7.67578721e-01,  -7.31412113e-01,  -7.78209150e-01,
                         -7.50328541e-01,  -7.65978098e-01,  -7.69506216e-01,
                         -7.47432411e-01,  -7.65803218e-01,  -7.44080007e-01,
                         -7.90452063e-01,  -7.66064107e-01,  -7.57525742e-01,
                         -7.59352088e-01,  -7.57632613e-01,  -7.86487639e-01,
                         -9.49769258e-01,  -9.26240742e-01,  -9.14500535e-01,
                         -9.40080106e-01,  -9.16617453e-01,  -9.62625086e-01,
                         -9.17370021e-01,  -9.23207939e-01,  -9.36345100e-01,
                         -9.38596129e-01,  -9.41666782e-01,  -9.34699893e-01,
                         -7.79776454e-01,  -7.64054179e-01,  -7.48194456e-01,
                         -7.59672165e-01,  -7.43377149e-01,  -7.54683971e-01,
                         -7.67087340e-01,  -7.51506329e-01,  -7.68542051e-01,
                         -7.35025585e-01,  -7.69495487e-01,  -7.59878337e-01,
                         -7.45741248e-01,  -7.53056407e-01,  -7.32714236e-01,
                         -7.62300134e-01,  -9.22389090e-01,  -9.15742993e-01,
                         -9.29499805e-01,  -9.49504912e-01,  -9.24457014e-01,
                         -9.22709584e-01,  -9.19128358e-01,  -9.33102071e-01,
                         -7.49953747e-01,  -7.43272901e-01,  -7.69408762e-01,
                         -7.45949149e-01,  -7.70026743e-01,  -7.74277747e-01,
                         -7.51570463e-01,  -7.67421603e-01,  -7.40400910e-01,
                         -7.71533132e-01,  -7.53757954e-01,  -7.45538652e-01,
                         -7.85314918e-01,  -7.49801934e-01,  -7.57884324e-01,
                         -7.71995008e-01,  -9.31773543e-01,  -9.25909519e-01,
                         -9.25707579e-01,  -9.27317798e-01,  -9.37466800e-01,
                         -9.28511202e-01,  -9.18181598e-01,  -9.36510324e-01,
                         -9.22215819e-01,  -9.40057933e-01,  -9.35727656e-01,
                         -9.54652190e-01,  -9.22899902e-01,  -9.34493184e-01,
                         -9.22786713e-01,  -9.23401237e-01,  -7.59696007e-01,
                         -7.67167032e-01,  -7.40535975e-01,  -7.33309805e-01,
                         -7.58037508e-01,  -7.44535506e-01,  -7.70824969e-01,
                         -7.48849809e-01,  -7.57943094e-01,  -7.47233868e-01,
                         -7.61078000e-01,  -7.53175437e-01,  -7.77648151e-01,
                         -7.66536832e-01,  -7.77757049e-01,  -7.60263324e-01,
                         -7.61063099e-01,  -7.50411689e-01,  -7.63440073e-01,
                         -7.49045789e-01,  -7.79810488e-01,  -7.49367416e-01,
                         -7.80920446e-01,  -7.77312338e-01,  -7.68707097e-01,
                         -7.62432337e-01,  -7.56804049e-01,  -7.81710565e-01,
                         -7.38620102e-01,  -7.75823355e-01,  -7.57214129e-01,
                         -7.48316348e-01,  -7.60758221e-01,  -7.52777040e-01,
                         -7.52493620e-01,  -7.69973218e-01,  -7.62705207e-01,
                         -7.78354347e-01,  -7.45824158e-01,  -7.73097277e-01,
                         -7.68234968e-01,  -7.56530762e-01,  -7.59660363e-01,
                         -7.71582425e-01,  -7.73470938e-01,  -7.45346725e-01,
                         -7.68937945e-01,  -7.42767096e-01,   3.46507586e-04,
                         -1.35443592e-02,   1.71167050e-02,  -9.72623378e-03,
                         -1.12992954e-02,   1.68396253e-03,  -3.70802358e-02,
                          1.16227865e-02,  -7.67887414e-01,  -7.52166867e-01,
                         -7.68276453e-01,  -7.70273030e-01,  -7.73636460e-01,
                         -7.53728628e-01,  -7.64250278e-01,  -7.52707422e-01,
                         -7.63692617e-01,  -7.63233900e-01,  -7.66256511e-01,
                         -7.47083604e-01,  -7.78119206e-01,  -7.55960763e-01,
                         -7.20719039e-01,  -7.58847356e-01,  -7.35437274e-01,
                         -7.66679168e-01,  -7.92556345e-01,  -7.56239891e-01,
                         -7.90334582e-01,  -7.85588861e-01,  -7.53791213e-01,
                         -7.74041295e-01,  -7.41103947e-01,  -7.76448309e-01,
                         -7.41973281e-01,  -7.65633821e-01,  -7.55050361e-01,
                         -7.90016115e-01,  -7.56464601e-01,  -7.81431198e-01,
                         -7.69154966e-01,  -7.57408202e-01,  -7.69887865e-01,
                         -7.36167192e-01,  -7.57675886e-01,  -7.59418130e-01,
                         -7.74258912e-01,  -7.75489807e-01,  -7.55453706e-01,
                         -7.49918580e-01,  -7.17582703e-01,  -7.80961275e-01,
                         -7.55197406e-01,  -7.71385968e-01,  -7.77517319e-01,
                         -7.54238546e-01,  -7.75201976e-01,  -7.38286734e-01,
                         -7.62789190e-01,  -7.53413439e-01,  -7.67883718e-01,
                         -7.83374608e-01,  -7.40900993e-01,  -7.65659928e-01,
                          2.66921185e-02,  -6.04833104e-03,   3.65705579e-03,
                          6.32933201e-03,  -7.71590889e-01,  -7.23970056e-01,
                         -7.66800404e-01,  -7.31500328e-01,  -7.84311354e-01,
                         -7.11753786e-01,  -7.41043150e-01,  -7.27655053e-01,
                         -7.37892866e-01,  -7.66514182e-01,  -7.41983294e-01,
                         -7.56670654e-01,  -7.34951556e-01,  -7.74301291e-01,
                         -7.61813879e-01,  -7.56411254e-01,  -7.74450600e-01,
                         -7.56005526e-01,  -7.44444966e-01,  -7.28301823e-01,
                         -7.57318974e-01,  -7.31181443e-01,  -7.86046982e-01,
                         -7.58344054e-01,  -7.47955203e-01,  -7.49734879e-01,
                         -7.45395243e-01,  -7.55653143e-01,  -7.44993508e-01,
                         -7.67352283e-01,  -7.39880681e-01,  -7.77807236e-01,
                         -7.44408727e-01,  -7.80588448e-01,  -7.67213881e-01,
                         -7.55893588e-01,  -7.79466748e-01,  -7.22684622e-01,
                         -7.61944950e-01,  -7.26872683e-01,  -9.45246778e-03,
                         -4.57546921e-05,   2.37354860e-02,  -2.02976335e-02,
                          1.62910130e-02,  -7.63047859e-03,   6.49392279e-03,
                          1.39356721e-02,  -7.61365592e-01,  -7.51922488e-01,
                         -7.71852076e-01,  -7.65338957e-01,  -7.21748710e-01,
                         -7.72301793e-01,  -7.31593132e-01,  -7.73674786e-01,
                         -7.59531736e-01,  -7.62372196e-01,  -7.74471641e-01,
                         -7.52329051e-01,  -7.81623602e-01,  -7.57273436e-01,
                         -7.56511807e-01,  -7.37218022e-01,  -7.57842660e-01,
                         -7.54043877e-01,  -7.64721572e-01,  -7.89606452e-01,
                         -7.64467776e-01,  -7.57056534e-01,  -7.65393674e-01,
                         -7.47129977e-01,  -7.45996237e-01,  -7.75174856e-01,
                         -7.56853402e-01,  -7.53128588e-01,  -7.62318969e-01,
                         -7.38235235e-01,  -7.50737846e-01,  -7.52271473e-01,
                         -7.61714220e-01,  -7.49502480e-01,  -7.39321232e-01,
                         -7.53883839e-01,  -1.03960941e-02,   1.21844839e-02,
                         -1.16473557e-02,   6.22109277e-03,  -7.33357668e-01,
                         -7.69434214e-01,  -7.51925588e-01,  -7.97800541e-01,
                         -7.28869319e-01,  -7.75402248e-01,  -7.57017612e-01,
                         -7.65996993e-01,  -7.56898463e-01,  -7.59436250e-01,
                         -7.62081146e-01,  -7.65974224e-01,  -7.56702185e-01,
                         -7.79202223e-01,  -7.32682943e-01,  -7.70344496e-01,
                         -7.50594735e-01,  -7.73015201e-01,  -7.86180973e-01,
                         -7.60603964e-01,  -7.54114389e-01,  -7.56815970e-01,
                         -7.40913093e-01,  -7.55115747e-01,  -7.71851599e-01,
                         -7.41099298e-01,  -7.68227100e-01,  -7.48302400e-01,
                         -7.65844226e-01,  -7.43178546e-01,  -7.50326991e-01,
                         -7.43970454e-01,  -7.49379098e-01,  -7.56539643e-01,
                         -7.38803446e-01,  -7.89495409e-01,  -7.63147771e-01,
                         -7.54777849e-01,  -7.58929133e-01,  -7.57441163e-01,
                         -7.55968690e-01,  -7.57285297e-01,  -7.73761332e-01,
                         -7.33576894e-01,  -7.24975765e-01,  -7.58459270e-01,
                         -7.61852264e-01,  -7.33521700e-01,  -7.70831168e-01,
                         -7.35867441e-01,  -7.45394289e-01,  -7.64013588e-01,
                         -9.15004611e-01,  -9.42908168e-01,  -9.22269225e-01,
                         -9.19262171e-01,  -9.44116712e-01,  -9.39377606e-01,
                         -9.47991014e-01,  -9.16993260e-01,  -9.52201784e-01,
                         -9.58128154e-01,  -9.11584377e-01,  -9.32700038e-01,
                         -7.39718199e-01,  -7.52315521e-01,  -7.45381355e-01,
                         -7.89718688e-01,  -7.32084632e-01,  -7.47278035e-01,
                         -7.76110768e-01,  -7.48314202e-01,  -7.54849494e-01,
                         -7.60830462e-01,  -7.41683245e-01,  -7.43086278e-01,
                         -7.51033485e-01,  -7.26710141e-01,  -7.49994218e-01,
                         -7.72198617e-01,  -7.48460710e-01,  -7.57992685e-01,
                         -7.52537131e-01,  -7.44188070e-01,  -7.55675018e-01,
                         -7.35615432e-01,  -7.68670261e-01,  -7.69166172e-01,
                         -9.19880450e-01,  -9.21831965e-01,  -9.18031991e-01,
                         -9.00922656e-01,  -9.31458294e-01,  -9.35509920e-01,
                         -9.05546129e-01,  -9.37882304e-01,  -9.24562037e-01,
                         -9.37682748e-01,  -9.26828802e-01,  -8.94127011e-01,
                         -7.74685621e-01,  -7.45763242e-01,  -7.57940412e-01,
                         -7.63822615e-01,  -9.04710174e-01,  -9.47649658e-01,
                         -9.24325407e-01,  -9.29106474e-01,  -9.32807028e-01,
                         -9.13363874e-01,  -9.22501981e-01,  -9.16209877e-01,
                         -9.31951106e-01,  -9.44183230e-01,  -9.12924111e-01,
                         -9.19213533e-01,  -9.21568155e-01,  -9.35194314e-01,
                         -9.09107149e-01,  -9.43129182e-01,  -9.43271101e-01,
                         -9.50582743e-01,  -9.37016428e-01,  -9.34099853e-01,
                         -9.38470483e-01,  -9.15707886e-01,  -9.13206339e-01,
                         -9.27593768e-01,  -7.43199825e-01,  -7.39838839e-01,
                         -7.67135084e-01,  -7.61754930e-01,  -7.57007420e-01,
                         -7.66440332e-01,  -7.33394563e-01,  -7.27237642e-01,
                         -7.58717775e-01,  -7.27887511e-01,  -7.81253159e-01,
                         -7.60286331e-01,  -7.61900187e-01,  -7.66965389e-01,
                         -7.33769059e-01,  -7.44612873e-01,  -7.50255227e-01,
                         -7.23165274e-01,  -7.52234638e-01,  -7.62897968e-01,
                         -9.13772225e-01,  -9.45598841e-01,  -9.15601611e-01,
                         -9.32868123e-01,  -9.20517623e-01,  -9.28374469e-01,
                         -9.42087233e-01,  -9.48879063e-01,  -9.53260124e-01,
                         -9.32273686e-01,  -8.95984054e-01,  -9.24959600e-01,
                         -8.91899109e-01,  -9.32832658e-01,  -9.11651313e-01,
                         -9.15120125e-01,  -7.15454638e-01,  -7.51341522e-01,
                         -7.42620587e-01,  -7.34981179e-01,  -7.54283011e-01,
                         -7.57748187e-01,  -7.45832026e-01,  -7.61009872e-01,
                         -1.25468075e-02,  -3.99553101e-04,   2.83158403e-02,
                         -1.06026903e-02,   1.90521162e-02,  -1.46140298e-02,
                         -7.45790428e-04,  -1.82086080e-02,   2.35184170e-02,
                          3.04682442e-04,   1.65715218e-02,  -2.25962549e-02,
                         -7.58576572e-01,  -7.77601898e-01,  -7.70642698e-01,
                         -7.65837371e-01,  -7.76223280e-03,  -8.47723160e-04,
                          1.18457042e-02,   1.12076541e-02,  -4.25757054e-04,
                         -7.38326344e-04,  -3.24551240e-02,   1.59261320e-02,
                          1.69288948e-01,   1.57972082e-01,   1.61381438e-01,
                          1.58424541e-01,  -4.01899517e-02,  -9.13782604e-03,
                         -1.22761186e-02,  -2.00044475e-02,   1.65008500e-01,
                          1.72701553e-01,   1.98304519e-01,   1.61296859e-01,
                          8.82784929e-03,   2.51836963e-02,   1.82030490e-03,
                         -2.04596594e-02,   1.26129370e-02,   7.02611730e-03,
                          5.05861733e-03,   8.75451806e-05,  -2.18982361e-02,
                         -5.79743553e-03,  -1.90197099e-02,   2.04881988e-02,
                          1.80327728e-01,   1.81746468e-01,   1.74708635e-01,
                          1.71849892e-01,   1.51797175e-01,   1.56456307e-01,
                          1.50600061e-01,   1.71821967e-01,   1.72708735e-01,
                          1.56802207e-01,   1.86145529e-01,   1.53992504e-01,
                          1.82425380e-01,   1.68644533e-01,   1.61623597e-01,
                          1.78644150e-01,   1.62422523e-01,   1.76495120e-01,
                          1.83463946e-01,   1.35134712e-01,   1.75047144e-01,
                          1.14438199e-01,   1.53702423e-01,   1.64770722e-01,
                          1.48688287e-01,   1.73470140e-01,   1.61827371e-01,
                          1.62504151e-01,   1.37767941e-01,   1.60391778e-01,
                          1.63554057e-01,   1.55100897e-01,   1.70511708e-01,
                          1.30860046e-01,   1.51397333e-01,   1.77897081e-01,
                          1.64867312e-01,   1.87584266e-01,   1.69879854e-01,
                          1.57776207e-01,   1.76944196e-01,   1.52777985e-01,
                          1.40794516e-01,   1.65968552e-01,   1.50376692e-01,
                          1.73252255e-01,   1.95781440e-01,   1.61726490e-01,
                          1.58833593e-01,   1.41849011e-01,   1.76171988e-01,
                          1.71733901e-01,   1.72381192e-01,   1.77682146e-01,
                          1.68596491e-01,   1.44344211e-01,   1.69398725e-01,
                          1.65215269e-01,   1.41489536e-01,   1.73444495e-01,
                          5.03134588e-03,  -1.80913303e-02,  -1.39499214e-02,
                         -4.67460975e-02,  -4.64747660e-03,  -1.05105499e-02,
                         -9.71582346e-03,  -1.14915175e-02,  -4.35643457e-02,
                         -2.13192198e-02,  -2.04777196e-02,  -1.66295636e-02,
                         -2.81141177e-02,  -1.22532547e-02,   6.84483850e-04,
                          1.90963950e-02,  -1.92038727e-03,   8.82145856e-03,
                         -4.77398466e-03,  -6.29569869e-03,   1.82385370e-01,
                          1.65836677e-01,   1.74723938e-01,   1.79060206e-01,
                          1.64628401e-01,   1.71165541e-01,   1.66142255e-01,
                          1.39024898e-01,   1.81775168e-01,   1.30396515e-01,
                          1.47635624e-01,   1.63096428e-01,  -7.78192235e-03,
                          2.78696814e-03,  -2.04133708e-03,  -9.42251459e-03,
                         -1.38368998e-02,  -5.14342496e-03,   2.88930279e-03,
                         -2.66766082e-03,  -2.58532036e-02,  -9.13768075e-03,
                          1.73827633e-03,   8.68639909e-03,   1.41716255e-02,
                         -5.07584633e-03,   1.10396883e-02,   1.16214082e-02,
                         -1.15914200e-03,   2.88106943e-03,   2.29747817e-02,
                         -6.23460719e-03,   2.55019008e-03,  -7.39191240e-03,
                          4.69833892e-03,  -1.34114129e-02,  -2.21676435e-02,
                          4.85193077e-03,   7.87049998e-03,   4.86322067e-04,
                          1.56456511e-02,  -2.96261907e-02,   4.83279629e-03,
                         -1.00540360e-02,   1.62905771e-02,   2.49210605e-03,
                         -5.80656296e-03,   1.40540092e-03,   1.09799411e-02,
                          1.10565289e-03,  -1.30508784e-02,  -1.23539753e-03,
                         -1.16389282e-02,   2.37025041e-02,   5.05328784e-03,
                          5.75646991e-03,  -1.12497145e-02,  -6.37862133e-03,
                         -8.42623785e-03,  -1.74170416e-02,  -6.47900859e-03,
                         -3.90632264e-03,   1.74434669e-02,   1.12658283e-02,
                          1.57495390e-03,  -4.36671078e-03,  -1.69112515e-02,
                          1.37464507e-02,   1.18683735e-02,   1.68989021e-02,
                          3.30684856e-02,   1.98186021e-02,  -1.44541031e-03,
                          6.49012486e-03,   4.93481173e-04,   9.49520059e-03,
                         -2.15208605e-02,  -1.58749789e-03,   1.70949213e-02,
                         -1.10563142e-02,   1.93804875e-02,  -1.51932398e-02,
                         -2.51666061e-03,  -1.31679811e-02,   1.59893313e-03,
                          6.60899561e-04,  -4.99678403e-03,   2.14674398e-02,
                          1.57639123e-02,   3.07775997e-02,  -1.27128186e-02,
                          1.88345220e-02,   9.56450496e-03,  -9.48348828e-03,
                          8.87694396e-03,  -2.88005825e-02,   1.26761775e-02,
                          2.93353968e-03,   1.13054703e-03,   9.35736112e-03,
                         -1.48424422e-02,  -1.59182325e-02,  -1.55851971e-02,
                         -9.73501429e-03,  -8.65399186e-03,   1.88935343e-02,
                          2.57140398e-02,   1.17435427e-02,   1.78823783e-03,
                          1.19576305e-02,   4.85633174e-03,   1.43227987e-02,
                         -9.28599894e-01,  -9.34427559e-01,  -9.30396140e-01,
                         -9.19616044e-01,  -9.11303282e-01,  -9.44518924e-01,
                         -9.35207605e-01,  -9.39322770e-01,  -9.52147901e-01,
                         -9.84021544e-01,  -9.41068232e-01,  -9.44567561e-01,
                         -1.63502749e-02,   1.04821632e-02,  -9.45307780e-03,
                         -1.17985008e-03,  -2.70701181e-02,   2.10224800e-02,
                         -3.84342181e-03,  -1.44502916e-03,  -4.18844633e-03,
                          1.93589199e-02,  -6.82933489e-03,   2.17597652e-02,
                         -9.32591677e-01,  -9.21066284e-01,  -9.34126675e-01,
                         -9.50325608e-01,  -9.21609700e-01,  -9.35320258e-01,
                         -9.61656272e-01,  -9.31998312e-01,  -9.26998854e-01,
                         -9.68731582e-01,  -9.17210162e-01,  -9.41179097e-01,
                         -9.01918650e-01,  -9.41608906e-01,  -9.39538062e-01,
                         -9.49558139e-01,  -9.30567801e-01,  -9.34226513e-01,
                         -9.19035017e-01,  -9.44279075e-01,  -9.41057563e-01,
                         -9.27228391e-01,  -9.51605320e-01,  -9.26324606e-01,
                         -9.55724895e-01,  -9.46435571e-01,  -9.24761653e-01,
                         -9.06960607e-01,  -9.37497199e-01,  -9.27708805e-01,
                         -9.45932567e-01,  -9.18898165e-01,  -9.16482747e-01,
                         -9.29035425e-01,  -9.13675308e-01,  -9.26571369e-01,
                         -9.11383450e-01,  -9.14094985e-01,  -9.32389975e-01,
                         -9.35426295e-01,  -9.39984620e-01,  -9.55255747e-01,
                         -9.39210534e-01,  -9.15070534e-01,  -9.38830495e-01,
                         -9.46501195e-01,  -9.48982954e-01,  -9.34698761e-01,
                         -9.50736642e-01,  -9.31258738e-01,  -9.10328209e-01,
                         -9.29210246e-01,  -9.18358445e-01,  -9.49666739e-01,
                         -9.44495618e-01,  -9.47642028e-01,  -9.28264439e-01,
                         -9.24477339e-01,  -9.17354524e-01,  -9.31867182e-01,
                         -9.22179639e-01,  -9.32401299e-01,  -9.31441784e-01,
                         -9.37776506e-01,  -9.34458911e-01,  -9.42535579e-01,
                         -9.24233139e-01,  -9.03848946e-01,  -9.24483001e-01,
                         -9.24494267e-01,  -9.37115431e-01,  -9.44557905e-01,
                         -9.23851371e-01,  -9.79628921e-01,  -9.02917743e-01,
                         -9.43386853e-01,  -9.40350533e-01,  -9.44837391e-01,
                         -9.33917582e-01,  -9.64933157e-01,  -9.30677474e-01,
                         -9.65215147e-01,  -9.43126142e-01,  -9.33587313e-01,
                         -9.48877096e-01,  -9.27495778e-01,  -9.21574235e-01,
                         -9.29753840e-01,  -9.27987874e-01,  -9.33339179e-01,
                         -9.23509598e-01,  -9.16717231e-01,  -9.42739487e-01,
                         -9.37199593e-01,  -9.39108312e-01,  -9.29218292e-01,
                         -9.22230899e-01,  -9.19489026e-01,  -9.45655406e-01,
                         -9.30339694e-01,  -9.12703872e-01,  -9.47791278e-01,
                         -9.05542612e-01,  -9.40482378e-01,  -9.21350002e-01,
                         -9.32534277e-01,  -9.19747412e-01,  -9.31283116e-01,
                         -9.28388655e-01,  -9.45798397e-01,  -9.19155955e-01,
                         -9.31834102e-01,  -9.17784870e-01,  -9.24278021e-01,
                         -9.30505157e-01,  -9.29180861e-01,  -9.24020231e-01,
                         -9.24030304e-01,  -9.30119157e-01,  -9.26199079e-01,
                         -9.25272465e-01,  -9.34204996e-01,  -9.14184034e-01,
                         -9.10672486e-01,  -9.08220291e-01,  -9.32084262e-01,
                         -9.24416482e-01,  -9.50382710e-01,  -9.21615481e-01,
                         -9.23249781e-01,  -9.27176178e-01,  -9.30553675e-01,
                         -9.18121815e-01,  -9.20858502e-01,  -9.25831258e-01,
                         -9.22403455e-01,  -9.27179337e-01,  -9.24468696e-01,
                         -9.20336664e-01,  -9.32567418e-01,  -9.37951624e-01,
                         -9.38404381e-01,  -9.39054191e-01,  -9.14283752e-01,
                         -9.27116454e-01,  -9.15539503e-01,  -9.27241504e-01,
                         -9.09038782e-01,  -9.25121069e-01,  -9.20735240e-01,
                         -9.01697159e-01,  -9.48749542e-01,  -9.08276379e-01,
                         -9.47255492e-01,  -9.43007410e-01,  -9.39084113e-01,
                         -9.29293215e-01,  -9.08996046e-01,  -9.21334743e-01,
                         -9.22687769e-01,  -9.16755617e-01,  -9.29486394e-01,
                         -9.27895546e-01,  -9.45888102e-01,  -9.33411360e-01,
                         -9.31335449e-01,  -9.05185282e-01,  -9.27599847e-01,
                         -9.09122944e-01,  -9.45459247e-01,  -8.95393431e-01,
                         -8.85970354e-01,  -9.39623356e-01,  -9.05183911e-01,
                         -9.22158241e-01,  -9.19310570e-01,  -9.41887021e-01,
                         -9.27028596e-01,  -9.21236694e-01,  -8.96811724e-01,
                         -9.31644738e-01,  -9.07694817e-01,  -9.23988104e-01,
                         -9.30524230e-01,  -9.04796779e-01,  -9.21741962e-01,
                         -9.07481372e-01,  -9.22036171e-01,  -9.29523051e-01,
                         -9.17891443e-01,  -9.21451032e-01,  -9.24929976e-01,
                         -9.18299735e-01,  -9.14708555e-01,  -9.39433932e-01,
                         -9.28257346e-01,  -9.18151140e-01,  -9.47335899e-01,
                         -9.23001289e-01,  -9.20247257e-01,  -9.44612145e-01,
                         -9.21395659e-01,  -9.31649029e-01,  -9.17797804e-01,
                         -9.37500179e-01,  -9.27059114e-01,  -9.36436892e-01,
                         -9.26907957e-01,  -9.50147748e-01,  -9.49290276e-01,
                         -9.31029618e-01,  -9.28749025e-01,  -9.18419600e-01,
                         -9.28339541e-01,  -9.34173584e-01,  -9.23298478e-01,
                         -9.42540586e-01,  -9.31977153e-01,  -9.51338649e-01,
                         -9.27430272e-01,  -9.39451814e-01,  -9.41262066e-01,
                         -9.25407767e-01,  -9.39813435e-01,  -9.42937315e-01,
                         -9.46155250e-01,  -9.43296015e-01,  -9.49700892e-01,
                         -9.40135300e-01,  -9.23810005e-01,  -9.24944341e-01,
                         -9.22582448e-01,  -9.26476717e-01,  -9.18412983e-01,
                         -9.27372396e-01,  -9.46065128e-01,  -8.92722189e-01,
                         -9.25717175e-01,  -9.12831783e-01,  -9.42645013e-01,
                         -9.42562759e-01,  -9.23488438e-01,  -9.48170066e-01,
                         -9.35069799e-01,  -9.13366914e-01,  -9.39403236e-01,
                         -9.25672114e-01,  -9.55787361e-01,  -9.41122413e-01,
                         -9.22703505e-01,  -9.42779064e-01,  -9.24814105e-01,
                         -1.80769078e-02,   7.48390704e-03,  -7.20660668e-04,
                          9.40046832e-03,   1.52859483e-02,  -5.42439846e-03,
                          4.08780947e-03,   9.14927479e-03,   1.62043124e-02,
                          3.62454506e-04,   1.02469716e-02,  -2.89987167e-03,
                          1.93881877e-02,   1.35646863e-02,   2.99314279e-02,
                          1.24860685e-02,   2.09419546e-03,  -9.48829763e-03,
                         -3.08335479e-03,   1.00783063e-02,  -2.07517557e-02,
                          2.40136385e-02,  -1.30971875e-02,  -3.32551100e-03,
                         -9.12183095e-05,  -4.19356814e-03,   8.66203103e-03,
                         -6.08243560e-03,   3.24963662e-03,  -1.19261527e-02,
                         -7.89287128e-03,  -6.73794327e-03,   2.72516813e-02,
                         -5.82987705e-05,  -3.42034688e-03,   1.19952001e-02,
                         -3.59789073e-03,   5.93160186e-03,   2.70157680e-02,
                          3.98549577e-03,   1.94419734e-02,   2.09295768e-02,
                          1.93941128e-03,   9.59962141e-03,   2.11311560e-02,
                          8.28164071e-03,   1.90321505e-02,  -1.29003283e-02,
                         -9.35156584e-01,  -9.48409677e-01,  -9.38114405e-01,
                         -9.17605758e-01,  -9.36704159e-01,  -9.41577196e-01,
                         -9.34186220e-01,  -9.32500005e-01,  -9.34135020e-01,
                         -9.35750425e-01,  -9.41677868e-01,  -9.36656237e-01,
                         -9.42179203e-01,  -9.55248415e-01,  -9.60947990e-01,
                         -9.32533026e-01,  -9.40915763e-01,  -9.36764896e-01,
                         -9.61380124e-01,  -9.31834221e-01,  -9.39358473e-01,
                         -9.23913658e-01,  -9.10885274e-01,  -9.16121602e-01,
                         -9.40650821e-01,  -9.35773492e-01,  -9.43206251e-01,
                         -9.57807779e-01,  -9.66908276e-01,  -9.38252330e-01,
                         -9.39266860e-01,  -9.07568455e-01,  -9.26353455e-01,
                         -9.36445355e-01,  -9.55477417e-01,  -9.39493179e-01,
                         -9.32599902e-01,  -9.37082052e-01,  -9.63300049e-01,
                         -9.46223676e-01,  -9.69754636e-01,  -9.42528248e-01,
                         -9.40970659e-01,  -9.49497700e-01,  -9.44588065e-01,
                         -9.35163379e-01,  -9.28207695e-01,  -9.31384027e-01,
                         -9.35130417e-01,  -9.23495650e-01,  -9.52489674e-01,
                         -9.35197890e-01,  -9.27674055e-01,  -9.26058054e-01,
                         -9.31061447e-01,  -9.38699424e-01,  -9.43279207e-01,
                         -9.37180877e-01,  -9.38990176e-01,  -9.55304742e-01,
                         -9.51020956e-01,  -9.07153428e-01,  -9.28833127e-01,
                         -9.21415746e-01,  -9.28963602e-01,  -9.13246751e-01,
                         -9.29234385e-01,  -9.30683672e-01,  -9.25106108e-01,
                         -9.51789975e-01,  -9.30110633e-01,  -9.29061711e-01,
                         -9.37470257e-01,  -9.36522603e-01,  -9.40120220e-01,
                         -9.36612785e-01,  -9.17091548e-01,  -9.35165584e-01,
                         -9.34515715e-01,  -9.25017476e-01,  -9.22657311e-01,
                         -9.24749792e-01,  -9.39277828e-01,  -9.49301660e-01,
                         -9.40369725e-01,  -9.32851255e-01,  -9.32177722e-01,
                         -9.41887915e-01,  -9.17754054e-01,  -9.43181813e-01,
                         -9.44523692e-01,  -9.38554406e-01,  -9.37118948e-01,
                         -9.38236356e-01,  -9.56631541e-01,  -9.50894117e-01,
                         -9.40926850e-01,  -9.47714329e-01,  -9.46703792e-01,
                         -9.48219061e-01,  -9.38617408e-01,  -9.42812264e-01,
                         -9.50076759e-01,  -9.39498484e-01,  -9.17021513e-01,
                         -9.26484227e-01,  -9.35548365e-01,  -9.35456991e-01,
                         -9.40949321e-01,  -9.37837541e-01,  -9.56885219e-01,
                         -9.43876326e-01,  -9.51921463e-01,  -9.43233967e-01,
                         -9.36831892e-01,  -9.51340973e-01,  -9.57143784e-01,
                         -9.50821579e-01,  -9.58430111e-01,  -9.57084358e-01,
                         -9.25948203e-01,  -9.32699382e-01,  -9.33478475e-01,
                         -9.31645393e-01,  -9.12424028e-01,  -9.10051763e-01,
                         -9.28045571e-01,  -9.43078935e-01,  -9.46590602e-01,
                         -9.60139394e-01,  -9.50919151e-01,  -9.55257416e-01,
                         -9.45430160e-01,  -9.28338349e-01,  -9.50843453e-01,
                         -9.55759406e-01,  -9.51379776e-01,  -9.51892197e-01,
                         -9.33502197e-01,  -9.36828911e-01,  -9.48456168e-01,
                         -9.35598373e-01,  -9.42687154e-01,  -9.38786507e-01,
                         -9.30927396e-01,  -9.33335185e-01,  -9.25971985e-01,
                         -9.30746734e-01,  -9.44451392e-01,  -9.44998384e-01,
                         -9.43530679e-01,  -9.36264038e-01,  -9.45155740e-01,
                         -9.45012927e-01,  -9.20277774e-01,  -9.33032334e-01,
                         -9.35817599e-01,  -9.41883147e-01,  -9.41596031e-01,
                         -9.46753800e-01,  -9.33650672e-01,  -9.38494205e-01,
                         -9.29509223e-01,  -9.34547842e-01,  -9.42091346e-01,
                         -9.39786494e-01,  -9.38067973e-01,  -9.26727295e-01,
                         -9.40468192e-01,  -9.44390357e-01,  -9.39135134e-01,
                         -9.34215724e-01,  -9.37662423e-01,  -9.37251270e-01,
                         -9.28830922e-01,  -9.27636862e-01,  -9.29056406e-01,
                         -9.33320463e-01,  -9.29850817e-01,  -9.31485832e-01,
                         -9.36596572e-01,  -9.33008194e-01,  -9.37728643e-01,
                         -9.26762998e-01,  -9.30761516e-01,  -9.35751498e-01,
                         -9.30835664e-01,  -9.37225997e-01,  -9.26125288e-01,
                         -9.29816723e-01,  -9.26479518e-01,  -9.42203581e-01,
                         -9.46687639e-01,  -9.35895145e-01,  -9.42639470e-01,
                         -9.36273575e-01,  -9.40239012e-01,  -9.39879477e-01,
                         -9.33731377e-01,  -9.30617213e-01,  -9.29279327e-01,
                         -9.34575438e-01,  -9.40334380e-01,  -9.32544589e-01,
                         -9.28085625e-01,  -9.38489437e-01,  -9.30002451e-01,
                         -9.36111987e-01,  -9.32756662e-01,  -9.42143142e-01,
                         -9.45305407e-01,  -9.39378381e-01,  -9.42960620e-01,
                         -9.36838984e-01,  -9.42625940e-01,  -9.44815874e-01,
                         -9.50771153e-01,  -9.44586992e-01,  -9.33843493e-01,
                         -9.33866322e-01,  -9.37248707e-01,  -9.44696903e-01,
                         -9.42916274e-01,  -9.41864729e-01,  -9.47754264e-01,
                         -9.46792841e-01,  -9.43961382e-01,  -9.54099417e-01,
                         -9.31688607e-01,  -9.19960499e-01,  -9.42920268e-01,
                         -9.29395974e-01,  -9.41562533e-01,  -9.34832692e-01,
                         -9.56241310e-01,  -9.27411437e-01,  -9.29504335e-01,
                         -9.47832286e-01,  -9.35919940e-01,  -9.34150100e-01,
                         -9.29855287e-01,  -9.30730700e-01,  -9.36564863e-01,
                         -9.33264196e-01,  -9.35380161e-01,  -9.30775046e-01,
                         -9.40689743e-01,  -9.44756746e-01,  -9.43974793e-01,
                         -9.41057444e-01,  -9.41903055e-01,  -9.38022494e-01,
                         -9.34666514e-01,  -9.36650574e-01,  -9.42853034e-01,
                         -9.40197110e-01,  -9.44646180e-01,  -9.39202785e-01,
                         -9.41280127e-01,  -9.43898737e-01,  -9.45110261e-01,
                         -9.32468593e-01,  -9.37106907e-01,  -9.30877626e-01,
                         -9.29726362e-01,  -9.33983862e-01,  -9.36321139e-01,
                         -9.21315074e-01,  -9.36476409e-01,  -9.34433401e-01,
                         -9.20632184e-01,  -9.21466410e-01,  -9.31917250e-01,
                         -9.32333231e-01,  -9.41763043e-01,  -9.33928430e-01,
                         -9.51352000e-01,  -9.36183095e-01,  -9.42661107e-01,
                         -9.40640628e-01,  -9.47376788e-01,  -9.50556576e-01,
                         -9.38312888e-01,  -9.36815023e-01,  -9.42625403e-01,
                         -9.30322289e-01,  -9.42474246e-01,  -9.41516638e-01,
                         -9.44755971e-01,  -9.43612814e-01,  -9.43608940e-01,
                         -9.36867714e-01,  -9.40379918e-01,  -9.30687964e-01,
                         -9.35457230e-01,  -9.29160297e-01,  -9.28233445e-01,
                         -9.25098956e-01,  -9.42029834e-01,  -9.24484730e-01,
                         -9.35814500e-01,  -9.33406591e-01,  -9.32728767e-01,
                         -9.31472838e-01,  -9.26201701e-01,  -9.18844044e-01,
                         -9.37830627e-01,  -9.29530859e-01,  -9.22305703e-01,
                         -9.33726847e-01,  -9.33385432e-01,  -9.35443342e-01,
                         -9.31306303e-01,  -9.25313830e-01,  -9.43451941e-01,
                         -9.17652071e-01,  -9.33842480e-01,  -9.07451868e-01,
                         -9.31975245e-01,  -9.28049743e-01,  -9.17955041e-01,
                         -9.18294013e-01,  -9.17254329e-01,  -9.22355473e-01,
                         -9.19489980e-01,  -9.29190338e-01,  -9.42199469e-01,
                         -9.31205630e-01,  -9.32722211e-01,  -9.32300031e-01,
                         -9.37412918e-01,  -9.37364280e-01,  -9.35095608e-01,
                         -9.32280779e-01,  -9.32387233e-01,  -9.20374572e-01,
                         -9.31493044e-01,  -9.22051132e-01,  -9.48914587e-01,
                         -9.11630571e-01,  -9.29332376e-01,  -9.16781664e-01,
                         -9.20071006e-01,  -9.27574158e-01,  -9.21922147e-01,
                         -9.35346782e-01,  -9.28520083e-01,  -9.46449459e-01,
                         -9.47055221e-01,  -9.19754684e-01,  -9.38536644e-01,
                         -9.23605204e-01,  -9.23715711e-01,  -9.24142241e-01,
                         -9.35670435e-01,  -9.23152804e-01,  -9.23956513e-01,
                         -9.52109098e-01,  -9.29814875e-01,  -9.26104486e-01,
                         -9.15686786e-01,  -9.15879190e-01,  -9.34441149e-01,
                         -9.32469726e-01,  -9.34476078e-01,  -9.21656132e-01,
                         -9.19780493e-01,  -9.28551972e-01,  -9.23356056e-01,
                         -9.12722349e-01,  -9.34714377e-01,  -9.10240173e-01,
                         -9.06586528e-01,  -9.23209310e-01,  -9.16316509e-01,
                         -9.29197788e-01,  -9.37520385e-01,  -9.19400334e-01,
                         -9.48799670e-01,  -9.11524534e-01,  -9.38490987e-01,
                         -9.37381208e-01,  -9.47125971e-01,  -9.40137327e-01,
                         -9.29276526e-01,  -9.48292851e-01,  -9.38488424e-01,
                         -9.25923944e-01,  -9.54326868e-01,  -9.42413032e-01,
                         -9.17619050e-01,  -9.26440895e-01,  -9.22982454e-01,
                         -9.33156431e-01,  -9.40167129e-01,  -9.20897782e-01,
                         -9.14746106e-01,  -9.52657998e-01,  -9.48310792e-01,
                         -9.34856772e-01,  -9.45739865e-01,  -9.53287184e-01,
                         -9.27188396e-01,  -9.27864790e-01,  -9.55302536e-01,
                         -9.43714201e-01,  -9.53782260e-01,  -9.27684367e-01,
                         -9.31463540e-01,  -9.39878166e-01,  -9.37693238e-01,
                         -9.44427550e-01,  -9.44825530e-01,  -9.35887814e-01,
                         -9.18475330e-01,  -9.27170813e-01,  -9.27969456e-01,
                         -9.39575016e-01,  -9.47645009e-01,  -9.57645595e-01,
                         -9.33892846e-01,  -9.31111932e-01,  -9.17358398e-01,
                         -9.23777282e-01,  -9.32653666e-01,  -9.15074289e-01,
                         -9.07041967e-01,  -9.14108336e-01,   1.36706873e-03,
                         -1.01944050e-02,  -5.97865926e-03,   3.02748866e-02,
                          2.39611063e-02,   1.02244830e-02,   1.59425791e-02,
                          1.34901013e-02,   1.37810400e-02,   9.27172881e-03,
                          1.27067892e-02,  -8.89693107e-03,   2.69882753e-02,
                         -6.50667492e-03,   2.48947535e-02,   5.67435799e-03,
                          1.03880269e-02,   5.23039466e-03,   6.06132532e-03,
                         -3.47929029e-03,  -4.11698688e-03,  -3.21978028e-03,
                         -9.63899307e-03,  -2.50078295e-03,  -1.34636266e-02,
                         -1.77451912e-02,  -1.07597688e-03,  -5.03351539e-03,
                         -6.87554013e-04,  -2.88028623e-05,  -9.24525503e-03,
                         -1.44673679e-02,  -4.63897269e-03,  -7.21329451e-03,
                         -2.46713702e-02,  -1.18331462e-02,   2.68958160e-03,
                         -9.68751311e-03,  -1.62799656e-02,   4.29236796e-03,
                         -4.51904163e-03,   1.46679273e-02,  -1.64290741e-02,
                          1.67673547e-02,  -1.24665943e-03,   1.74450055e-02,
                          1.18962685e-02,   2.32194318e-03,  -1.35730095e-02,
                          1.15048522e-02,  -1.20712966e-02,   7.19993934e-03,
                          1.80497475e-03,  -1.16611049e-02,  -7.34090433e-03,
                         -1.03513859e-02,  -1.03392368e-02,   6.58159982e-03,
                         -1.99663583e-02,  -1.11788101e-02,  -7.51529494e-03,
                         -6.33232621e-03,  -4.86137718e-03,  -4.52352548e-03,
                         -9.43459384e-03,  -2.90712784e-03,   2.55646207e-03,
                         -1.13192620e-03,  -6.31231116e-03,  -1.56231001e-02,
                          6.50792243e-03,  -1.51435835e-02,   5.98563813e-03,
                          9.17109940e-03,   5.19024674e-03,  -1.03349676e-02,
                         -1.96491666e-02,   2.05205847e-03,  -2.28640810e-02,
                          1.66026747e-03,  -1.73143949e-02,  -1.86829735e-02,
                          6.86811050e-03,  -1.26389749e-02,  -2.40608770e-02,
                         -1.42111843e-02,  -1.26855476e-02,  -7.37407338e-03,
                         -4.32469184e-03,  -6.59171818e-03,  -6.67829998e-04,
                         -8.39939620e-03,  -1.37245571e-02,  -8.22517206e-04,
                         -2.92120362e-03,  -1.23418467e-02,  -1.00634545e-02,
                         -1.23059815e-02,  -5.41357277e-03,   6.12212624e-03,
                          1.40720559e-02,   1.41061954e-02,   6.85214298e-03,
                         -2.68516690e-03,   1.10093812e-02,  -7.30840070e-03,
                          5.30701084e-03,   2.97020865e-03,  -6.07275357e-03,
                          1.47439959e-02,  -3.64199583e-03,   1.58501547e-02,
                         -6.18325954e-04,   1.15637193e-02,   8.54440127e-03,
                          6.32001087e-03,  -3.40810092e-03,  -9.30787157e-03,
                         -1.37140024e-02,   1.69723434e-03,   9.88605618e-03,
                         -3.64804617e-03,  -2.50866283e-02,  -1.12227211e-02,
                          1.18293415e-03,   9.86339338e-03,  -6.15045102e-03,
                          8.76144879e-03,   1.24437930e-02,   1.43974810e-03,
                          8.91368184e-03,  -3.51812132e-03,  -4.44891950e-04,
                         -1.72786471e-02,   2.02952768e-03,  -7.04252860e-03,
                         -1.05632627e-02,   1.59362447e-03,   4.85095370e-04,
                         -1.74300224e-02,  -4.56085987e-03,  -1.00107556e-02,
                         -4.00314061e-03,   4.73536132e-03,  -1.07230442e-02,
                         -6.33200025e-03,  -6.66788360e-03,   3.12416814e-04,
                         -8.45944788e-03,   2.05349992e-03,   5.85414050e-03,
                          9.87880025e-03,   8.80559499e-04,   7.36822432e-04,
                         -4.42944525e-04,   7.77027244e-03,  -2.62427633e-03,
                          1.60670211e-03,   1.35190494e-03,  -1.40669686e-03,
                         -2.45463313e-03,  -1.19096646e-03,  -3.30292457e-03,
                          9.40719154e-03,   7.15386588e-03,   6.38443604e-03,
                          1.15582300e-02,   1.72552783e-02,   4.23831074e-03,
                          7.18941912e-03,   2.88317632e-03,   4.06626286e-03,
                          8.52096273e-05,   1.52192917e-03,  -3.30785220e-03,
                          9.36640520e-03,   7.44560920e-03,   5.03293285e-03,
                         -1.88542326e-04,   5.02598891e-03,  -1.11045921e-02,
                         -1.53653161e-03,  -8.66396539e-03,   2.23738514e-02,
                         -1.11460015e-02,  -1.97456386e-02,   9.13066044e-03,
                          6.30826363e-03,   1.66143794e-02,   1.54732019e-02,
                         -2.37058802e-03,   6.19213050e-03,   1.12787262e-02,
                         -4.93486738e-03,   1.00912731e-02,   2.64278060e-04,
                          3.66472080e-03,  -3.62072652e-03,   5.98330982e-03,
                          7.48881372e-04,  -3.81610211e-04,   2.10539511e-04,
                          4.49676020e-03,  -6.17498439e-03,  -1.33229874e-03,
                         -7.40024261e-03,  -5.53258229e-03,  -6.67895144e-03,
                         -8.51512048e-03,  -9.33698565e-03,  -7.04045640e-03,
                         -8.38438421e-03,  -1.11642350e-02,  -2.53827660e-03,
                          3.13732214e-03,   1.46890437e-04,   1.66558995e-04,
                         -6.98397355e-03,  -8.04827269e-03,  -2.32801423e-03,
                         -1.01268264e-02,  -4.64909105e-03,  -7.74051994e-03,
                         -1.03436233e-02,  -6.79617282e-03,  -5.82185853e-03,
                         -8.36990681e-03,  -1.83372910e-03,   3.47094587e-03,
                          2.69750319e-03,   1.01187034e-03,   5.40311495e-03,
                         -5.59022243e-04,   1.06677320e-03,  -3.47838250e-05,
                          2.76132557e-03,   2.74070748e-03,   5.42597147e-03,
                         -6.81309681e-03,   2.57748901e-03,   2.33046757e-03,
                         -7.47097470e-03,  -1.70424096e-02,  -2.38662083e-02,
                         -1.28900018e-02,  -1.21388268e-02,  -2.83971569e-03,
                          3.39343608e-03,   7.94719905e-03,   9.02080629e-03,
                         -5.62262256e-03,  -1.53393960e-02,  -1.11242533e-02,
                         -9.21449717e-03,  -9.62825119e-03,  -1.33190788e-02,
                         -1.33290170e-02,  -6.35461416e-03,   8.06858577e-03,
                         -2.72754650e-03,  -1.49679254e-03,  -1.45763075e-02,
                          2.05482380e-03,   2.46658130e-03,  -8.17513384e-04,
                          5.36123430e-03,  -7.14790600e-04,   1.68909393e-02,
                         -9.61513841e-04,   3.19327135e-03,  -2.66524893e-03,
                          1.15365302e-03,  -5.36142150e-03,  -1.08875930e-02,
                         -8.57732724e-03,  -1.00067286e-02,  -1.14526236e-02,
                         -1.00773424e-02,  -1.32270008e-02,  -1.35891853e-04,
                         -1.62987541e-02,  -3.18097672e-03,   2.15536352e-06,
                          1.20889414e-02,   6.90132147e-05,   5.71717415e-03,
                          4.27867379e-03,   6.16864301e-03,  -1.36679774e-02,
                         -9.48275346e-03,  -3.48474458e-03,  -1.35503886e-02,
                         -7.51595339e-03,  -1.74246933e-02,  -1.79063566e-02,
                         -1.76788867e-02,  -2.69622169e-02,  -2.16649584e-02,
                         -2.15246584e-02,  -1.48203624e-02,  -2.08894704e-02,
                         -5.19789103e-03,   1.59898854e-03,  -1.03645120e-02,
                          5.79821877e-03,  -1.01299034e-02,   1.68581083e-02,
                          4.02616337e-03,   4.84145898e-03,   1.46634015e-03,
                          1.20612262e-02,   1.70561671e-02,   1.16615696e-02,
                          4.69951704e-03,  -6.95336901e-04,  -2.20210920e-03,
                         -5.25436737e-03,  -8.53804592e-03,  -1.78150982e-02,
                         -6.70331204e-03,   4.70353663e-03,  -8.80804192e-03,
                          4.48952522e-03,  -9.47944063e-05,   1.19056869e-02,
                          1.04762726e-02,  -1.67727396e-02,  -1.10873971e-02,
                         -6.96271099e-03,   4.71432041e-03,  -1.79954618e-02,
                         -1.76171027e-02,  -1.86903961e-02,  -1.25191966e-02,
                         -8.73286743e-03,  -6.78474456e-03,   8.52199551e-03,
                          6.87199179e-03,   1.97037635e-03,   1.40219217e-03,
                          2.36268025e-02,   2.51997188e-02,   2.32063606e-02,
                          1.44378440e-02,   2.80788895e-02,   3.43481153e-02,
                          1.38472468e-02,   2.42529046e-02,   2.91897822e-02,
                          1.42358290e-02,   2.32318379e-02,   8.13210290e-03,
                          2.21863133e-03,   5.50233806e-03,   1.46149443e-02,
                          2.17813756e-02,   1.38571847e-03,  -5.14890673e-03,
                         -1.01169366e-02,  -8.02977569e-03,   1.77225564e-02,
                         -1.52443936e-02,   4.78057517e-03,  -1.20965438e-02,
                         -4.13856795e-03,  -3.02026025e-03,  -8.93193018e-03,
                          1.60108157e-03,   2.00989380e-04,  -1.43696903e-03,
                          3.56982928e-03,   7.98240583e-03,  -6.53321156e-03,
                         -1.62839442e-02,  -1.05736312e-02,  -1.47608295e-02,
                          4.89128195e-03,  -9.75561887e-03,  -6.31687813e-04,
                          6.99427212e-03,   4.16278280e-03,   1.07827634e-02,
                         -1.14196353e-02,  -9.08392132e-04,  -5.22339484e-03,
                         -3.41061666e-03,  -3.74515541e-03,  -1.12399710e-02,
                         -9.42489877e-03,  -3.67289875e-03,   1.76570415e-02,
                         -8.06871708e-03,  -4.78772772e-03,  -1.70551073e-02,
                         -5.00079663e-03,   3.61837709e-04,   6.32203417e-03,
                          4.83905431e-03,   7.61894649e-03,   5.59269683e-03,
                          9.43268836e-03,  -1.18947646e-03,  -1.36968773e-02,
                         -1.10343313e-02,  -1.12090129e-02,  -9.50788986e-03,
                         -9.44264000e-04,   9.96715575e-03,  -2.93304771e-03,
                         -1.13125183e-02,   2.27896422e-02,   1.89429354e-02,
                          1.57730542e-02,   1.83493923e-02,  -9.17917304e-03,
                         -1.39645096e-02,  -2.08270065e-02,  -1.29208565e-02,
                          1.47365872e-03,  -8.10963474e-03,  -2.44318619e-02,
                          1.34783126e-02,   1.19303381e-02,   4.51394776e-03,
                         -3.05521040e-04,  -2.25523990e-02,  -1.45064965e-02,
                          8.37819534e-05,   1.70797296e-02,   8.64431728e-03,
                         -9.98953450e-03,   1.71249378e-02,   3.66810290e-03,
                         -6.66761352e-03,  -7.51927309e-03,  -1.76555999e-02,
                          1.05398102e-02,  -5.33058122e-03,   7.59809278e-03,
                          5.29531902e-03,   4.09997255e-03,   9.77865513e-03,
                         -7.65271159e-03,  -1.20675815e-02,   6.83860108e-03,
                         -2.41251979e-02,   4.28885454e-03,   2.65382067e-03,
                          1.34731494e-02,   2.71464905e-05,  -1.08522484e-02,
                          2.19986364e-02,  -8.67613475e-04,  -1.61477402e-02,
                          1.15553814e-03,   5.86179830e-03,   7.77116651e-03,
                          8.60613026e-03,   1.94877349e-02,  -6.82151737e-03,
                         -7.61494739e-03,  -2.70852959e-03,  -1.47536425e-02,
                         -4.02354375e-02,  -7.95277115e-03,   3.21847037e-03,
                          2.33573336e-02,  -2.06115819e-03,  -9.23005939e-01,
                         -9.35286224e-01,  -9.41747069e-01,  -9.35397208e-01,
                         -9.10350859e-01,  -9.41173553e-01,  -9.23614562e-01,
                         -9.22232211e-01,  -9.20724034e-01,  -9.36720312e-01,
                         -9.42241073e-01,  -9.31652129e-01,  -7.47055886e-03,
                          1.77279059e-02,   5.90428198e-03,   2.07717773e-02,
                         -1.00596910e-02,  -1.21519323e-02,   1.41463783e-02,
                         -1.10253841e-02,   1.86699796e-02,   1.52900098e-02,
                          9.60134715e-03,  -1.19858515e-02,   1.40176732e-02,
                          2.75981463e-02,   1.94792245e-02,   8.44666176e-03,
                          1.05029615e-02,   2.35215928e-02,   7.84330536e-03,
                          1.34226745e-02,   2.50145514e-03,   1.02338595e-02,
                          1.77472010e-02,   8.83816089e-03,   2.47343071e-02,
                          1.05583426e-02,   1.30871106e-02,   3.03028915e-02,
                          4.43081744e-03,  -3.62021625e-02,  -5.75691322e-03,
                         -6.64021727e-03,   1.18588516e-02,  -1.10521559e-02,
                          2.94207106e-03,   6.04284881e-03,   1.62246395e-02,
                          4.24298877e-03,   1.76640972e-02,  -1.15599553e-03,
                          1.50127783e-02,   2.70248624e-03,   1.07963746e-02,
                          8.68557394e-03,   1.30490272e-03,  -1.21173216e-02,
                          9.08366498e-03,  -1.28534511e-02,  -2.56377924e-02,
                         -1.46351326e-02,   4.50722547e-03,  -2.34910082e-02,
                         -1.43784089e-02,  -1.42018702e-02,  -5.27417427e-03,
                         -1.58881191e-02,  -7.12029496e-03,   7.17469910e-03,
                          1.39216380e-03,   4.43339559e-05,   1.43144066e-02,
                          3.28703318e-04,  -1.04428055e-02,  -1.86998006e-02,
                         -9.53735590e-01,  -9.44313407e-01,  -9.21813786e-01,
                         -9.49183822e-01,  -9.27295148e-01,  -9.20160353e-01,
                         -9.41435456e-01,  -9.58649457e-01,  -9.25150275e-01,
                         -9.32238400e-01,  -9.29737568e-01,  -9.22806859e-01,
                         -9.24984813e-01,  -9.33801770e-01,  -9.47321892e-01,
                         -9.28274095e-01,  -9.28601682e-01,  -9.42875564e-01,
                         -9.15767014e-01,  -9.20984328e-01,  -9.33229089e-01,
                         -9.26421404e-01,  -9.26833749e-01,  -9.50287998e-01,
                         -9.30479169e-01,  -9.32468951e-01,  -9.38993633e-01,
                         -9.39585567e-01,  -9.28970575e-01,  -9.35434401e-01,
                         -9.08555567e-01,  -9.33425128e-01,  -9.30405557e-01,
                         -9.26297724e-01,  -9.38486099e-01,  -9.33043897e-01,
                         -9.31865036e-01,  -9.30390716e-01,  -9.07896280e-01,
                         -9.19844568e-01,  -9.20053065e-01,  -9.04989719e-01,
                         -9.40001369e-01,  -9.25447166e-01,  -9.32947099e-01,
                         -9.25133407e-01,  -9.12761807e-01,  -9.29386973e-01,
                         -9.22147512e-01,  -9.19427752e-01,  -9.19230282e-01,
                         -9.34926629e-01,  -9.19594705e-01,  -9.37319577e-01,
                         -9.20453548e-01,  -9.36483622e-01,  -9.26378727e-01,
                         -9.26038206e-01,  -9.28439319e-01,  -9.22477663e-01,
                         -9.47927475e-01,  -9.55024421e-01,  -9.46310043e-01,
                         -9.43571389e-01,  -9.26863134e-01,  -9.25818026e-01,
                         -9.43005383e-01,  -9.46594059e-01,  -9.29290950e-01,
                         -9.53202128e-01,  -9.24056530e-01,  -9.11099911e-01,
                         -9.28003311e-01,  -9.37308788e-01,  -9.34757292e-01,
                         -9.21881616e-01,  -9.27123904e-01,  -9.07938421e-01,
                         -9.24362898e-01,  -9.17651594e-01,  -9.39552844e-01,
                         -9.22457635e-01,  -9.15680230e-01,  -9.37423706e-01,
                         -9.34734464e-01,  -9.20767009e-01,  -9.22883749e-01,
                         -9.26108658e-01,  -9.10399020e-01,  -9.20383692e-01,
                         -9.29245234e-01,  -9.11733091e-01,  -9.35902238e-01,
                         -9.31763589e-01,  -9.31939363e-01,  -9.12288845e-01,
                         -9.29937541e-01,  -9.27289248e-01,  -9.26081896e-01,
                         -9.28432584e-01,  -9.22495663e-01,  -9.22179401e-01,
                         -9.33481216e-01,  -9.30635333e-01,  -9.37445760e-01,
                         -9.38322425e-01,  -9.42193389e-01,  -9.37944531e-01,
                         -9.45072472e-01,  -9.44570482e-01,  -9.36427057e-01,
                         -9.25596654e-01,  -9.28462148e-01,  -9.21775222e-01,
                         -9.30779457e-01,  -9.16266739e-01,  -9.24325407e-01,
                         -9.06013489e-01,  -9.24093127e-01,  -9.08307672e-01,
                         -9.15276289e-01,  -9.31032598e-01,  -9.22927618e-01,
                         -9.38289046e-01,  -9.30666387e-01,  -9.23605442e-01,
                         -9.19617295e-01,  -9.25096095e-01,  -9.09938753e-01,
                         -9.41334009e-01,  -9.33910787e-01,  -9.43077147e-01,
                         -9.40022111e-01,  -9.32323217e-01,  -9.31371391e-01,
                         -9.39323604e-01,  -9.40019906e-01,  -9.48283732e-01,
                         -9.44175839e-01,  -9.32425559e-01,  -9.34079349e-01,
                         -9.24170732e-01,  -9.28730845e-01,  -9.24007595e-01,
                         -9.20139730e-01,  -9.29759979e-01,  -9.15148497e-01,
                         -9.30268526e-01,  -9.30429637e-01,  -9.28220212e-01,
                         -9.29727435e-01,  -9.30279672e-01,  -9.22766328e-01,
                         -9.44024324e-01,  -9.39798534e-01,  -9.41032946e-01,
                         -9.32560205e-01,  -9.34476078e-01,  -9.42106307e-01,
                         -9.35282886e-01,  -9.45723593e-01,  -9.38313425e-01,
                         -9.33368921e-01,  -9.37528372e-01,  -9.44185913e-01,
                         -9.27156627e-01,  -9.33246613e-01,  -9.44820642e-01,
                         -9.40203428e-01,  -9.34172392e-01,  -9.40162957e-01,
                         -9.41973269e-01,  -9.47953641e-01,  -9.32162464e-01,
                         -9.46347952e-01,  -9.35662031e-01,  -9.31186080e-01,
                         -9.35168922e-01,  -9.41355169e-01,  -9.36931252e-01,
                         -9.35575545e-01,  -9.34160948e-01,  -9.33116853e-01,
                         -9.41075861e-01,  -9.43716943e-01,  -9.48266566e-01,
                         -9.41095471e-01,  -9.25102234e-01,  -9.26400900e-01,
                         -9.28133011e-01,  -9.41336751e-01,  -9.41719770e-01,
                         -9.37195182e-01,  -9.38337088e-01,  -9.36580837e-01,
                         -9.36416388e-01,  -9.31235313e-01,  -9.34101880e-01,
                         -9.28377390e-01,  -9.44043875e-01,  -9.41160917e-01,
                         -9.36531603e-01,  -9.31675851e-01,  -9.40224171e-01,
                         -9.26809371e-01,  -9.41953301e-01,  -9.29263115e-01,
                         -9.28073287e-01,  -9.39907312e-01,  -9.31598246e-01,
                         -9.39381957e-01,  -9.32387352e-01,  -9.33444738e-01,
                         -9.26091850e-01,  -9.28972661e-01,  -9.28306997e-01,
                         -9.32156801e-01,  -9.34853137e-01,  -9.34696317e-01,
                         -9.34551060e-01,  -9.29664731e-01,  -9.32163656e-01,
                         -9.37428474e-01,  -9.44076657e-01,  -9.42827344e-01,
                         -9.34318304e-01,  -9.35034215e-01,  -9.33645546e-01,
                         -9.38423693e-01,  -9.30251837e-01,  -9.41383004e-01,
                         -9.35680866e-01,  -9.34168041e-01,  -9.37250793e-01,
                         -9.41119313e-01,  -9.36551034e-01,  -9.35193896e-01,
                         -9.32409823e-01,  -9.27456081e-01,  -9.37123835e-01,
                         -9.33917880e-01,  -9.31706131e-01,  -9.37583268e-01,
                         -9.32236969e-01,  -9.36062336e-01,  -9.38268185e-01,
                         -9.36029196e-01,  -9.40085113e-01,  -9.33583438e-01,
                         -9.38734591e-01,  -9.33192670e-01,  -9.25824285e-01,
                         -9.29111838e-01,  -9.30708826e-01,  -9.34466481e-01,
                         -9.29283381e-01,  -9.36366141e-01,  -9.37811017e-01,
                         -9.30674791e-01,  -9.38635111e-01,  -9.32968259e-01,
                         -9.32351828e-01,  -9.37944412e-01,  -9.28708255e-01,
                         -9.21358764e-01,  -9.32651579e-01,  -9.34816420e-01,
                         -9.35308278e-01,  -9.36248958e-01,  -9.39342022e-01,
                         -9.28463161e-01,  -9.42183077e-01,  -9.39029455e-01,
                         -9.30662453e-01,  -9.29586530e-01,  -9.36230898e-01,
                         -9.30059195e-01,  -9.40210283e-01,  -9.37753916e-01,
                         -9.33095872e-01,  -9.34683263e-01,  -9.31008101e-01,
                         -9.33758676e-01,  -9.32951510e-01,  -9.33867216e-01,
                         -9.40816283e-01,  -9.32064652e-01,  -9.32648361e-01,
                         -9.27668869e-01,  -9.29479182e-01,  -9.30086732e-01,
                         -9.29515004e-01,  -9.33419228e-01,  -9.30702746e-01,
                         -9.39608693e-01,  -9.34680581e-01,  -9.32148695e-01,
                         -9.26808834e-01,  -9.33325768e-01,  -9.39691544e-01,
                         -9.37531054e-01,  -9.30103779e-01,  -9.37467396e-01,
                         -9.26408708e-01,  -9.26036596e-01,  -9.27981079e-01,
                         -9.35992062e-01,  -9.39715922e-01,  -9.37012196e-01,
                         -9.40579176e-01,  -9.29292858e-01,  -9.41480041e-01,
                         -9.36024189e-01,  -9.42007065e-01,  -9.37041342e-01,
                         -9.33974683e-01,  -9.41380441e-01,  -9.36027050e-01,
                         -9.33585584e-01,  -9.36355174e-01,  -9.30379629e-01,
                         -9.36444342e-01,  -9.25106168e-01,  -9.33671415e-01,
                         -9.23450589e-01,  -9.30688322e-01,  -9.34704721e-01,
                         -9.40177441e-01,  -9.31163669e-01,  -9.33952272e-01,
                         -9.37548220e-01,  -9.28722501e-01,  -9.37635958e-01,
                         -9.30691421e-01,  -9.28920567e-01,  -9.29984331e-01,
                         -9.42090571e-01,  -9.31260586e-01,  -9.39725935e-01,
                         -9.33234632e-01,  -9.33450699e-01,  -9.34214950e-01,
                         -9.32021201e-01,  -9.22983944e-01,  -9.23979461e-01,
                         -9.35821474e-01,  -9.30186749e-01,  -9.25108075e-01,
                         -9.29641902e-01,  -9.39502478e-01,  -9.29912031e-01,
                         -9.38419461e-01,  -9.36227441e-01,  -9.28080559e-01,
                         -9.25153315e-01,  -9.26806748e-01,  -9.32413161e-01,
                         -9.36070323e-01,  -9.28059161e-01,  -9.30911422e-01,
                         -9.40936685e-01,  -9.32908833e-01,  -9.37887311e-01,
                         -9.37438786e-01,  -8.49839021e-03,  -5.16590709e-03,
                         -7.85941165e-03,  -2.62389518e-03,  -6.04839355e-04,
                          4.32453211e-03,   1.28896965e-03,  -5.04115270e-03,
                          6.88800076e-03,  -3.10960738e-03,  -9.59521346e-03,
                          5.50953858e-03,   9.67638288e-03,   1.02929622e-02,
                          8.39177892e-03,   1.53800080e-04,  -2.58911122e-03,
                          9.49727278e-03,   1.36552320e-03,   3.89738916e-03,
                          3.71714262e-03,   8.65882263e-03,   1.03290975e-02,
                          1.18242821e-03,   7.58845266e-03,   9.44180880e-04,
                          4.00150521e-03,   5.14483871e-03,  -4.13653767e-03,
                          5.21548046e-03,   9.77255683e-03,  -3.54650838e-04,
                         -4.60500689e-03,  -1.38435324e-04,  -2.95629934e-03,
                          2.81637395e-03,   1.12343638e-03,  -1.08827837e-03,
                          2.92156404e-03,   4.43262607e-03,   6.65702345e-03,
                          4.88796213e-04,   2.73779663e-03,   3.97548126e-03,
                         -8.94981727e-04,  -4.54352703e-03,  -9.85864643e-03,
                          2.93343584e-03,   3.74393561e-03,  -2.40159454e-03,
                         -4.77090725e-05,  -5.15671726e-03,  -4.99853026e-03,
                         -9.40159149e-03,  -7.37960404e-03,  -3.05471127e-03,
                          5.07468870e-03,   7.62469880e-03,  -1.13973673e-03,
                         -2.85637635e-03,   4.21519112e-03,  -4.22635581e-03,
                          3.40823247e-03,   2.76074326e-03,  -5.68905054e-03,
                         -1.82810851e-04,  -4.20735264e-03,  -4.07491205e-03,
                          1.43013557e-03,   4.57021594e-03,   1.21705956e-03,
                         -4.91512939e-04,  -3.15218791e-03,  -3.72114149e-03,
                          5.26400749e-04,   2.96158018e-04,   3.50710214e-03,
                          6.19549165e-03,  -3.76902381e-03,   1.21077371e-03,
                          5.25397202e-03,  -2.37974990e-03,  -9.51645616e-03,
                         -7.65393116e-03,  -6.10154262e-03,  -9.67532955e-03,
                          6.32632431e-03,   4.45414521e-03,  -7.51270307e-03,
                          2.43788934e-03,   1.28786778e-03,  -5.31010143e-03,
                         -5.22200204e-03,  -7.35349720e-03,  -7.91834760e-03,
                         -1.00122383e-02,  -1.44364787e-02,   8.29945225e-03,
                         -7.42312009e-03,  -4.06678254e-03,  -5.39989909e-03,
                         -5.66949276e-03,  -3.17382463e-03,  -5.57722803e-03,
                         -2.81865406e-03,  -7.83781614e-03,  -4.57914919e-03,
                         -2.12522293e-03,  -5.57433115e-03,  -3.16169648e-03,
                         -4.53905668e-03,  -6.75011985e-03,  -4.82541509e-03,
                         -2.51897541e-03,  -4.21454618e-03,  -8.29638168e-03,
                         -6.93598017e-03,   4.15988592e-03,   3.82280396e-03,
                         -8.88767187e-03,  -4.81063267e-03,  -6.70208549e-03,
                         -4.19803808e-04,  -2.31273961e-03,  -1.22698396e-03,
                          5.42213209e-03,   7.01726705e-04,  -9.13749333e-04,
                         -2.10858998e-03,  -7.84441421e-04,  -8.18733871e-03,
                         -4.40317875e-04,   5.83570544e-03,  -4.62449528e-03,
                          2.22636573e-03,   2.04175990e-03,  -2.54045962e-03,
                         -1.76632381e-03,  -7.40798423e-03,   3.95876495e-03,
                          3.58180515e-03,   1.59441447e-03,   1.38185825e-03,
                         -7.08275998e-04,  -4.90341743e-04,   7.79957394e-04,
                          1.74251781e-03,  -1.29488832e-03,  -9.32717929e-04,
                         -6.86990563e-03,  -5.74698905e-04,   2.50731828e-03,
                          1.96491528e-04,   7.29455380e-04,  -1.03200329e-02,
                         -4.42426791e-03,  -5.10682538e-03,  -9.25422274e-03,
                          1.42930401e-03,   2.81371945e-03,  -1.06441684e-03,
                         -2.70574354e-03,  -2.93563283e-03,  -5.25203161e-03,
                         -8.68666172e-03,  -4.52889682e-04,  -4.20778245e-03,
                         -2.73398502e-04,  -1.63998897e-03,   1.15277292e-03,
                          1.80857861e-03,  -8.49376060e-03,  -6.34921575e-03,
                         -7.52471329e-04,   5.06385637e-04,  -7.49900122e-04,
                         -2.73493445e-03,  -1.34329044e-03,  -8.75694386e-04,
                         -1.22943730e-03,   9.91848297e-04,   1.12047023e-03,
                         -4.14978154e-03,  -8.79069499e-04,  -2.11683029e-04,
                         -5.42929803e-04,   7.68688566e-04,   1.97149915e-04,
                          1.73514383e-03,  -1.80080265e-03,  -8.18913337e-04,
                          3.08885053e-03,   1.91962486e-03,  -1.28675892e-03,
                         -1.01532170e-03,   2.13058013e-03,   1.03626552e-03,
                          4.82226169e-04,   1.00914668e-03,  -3.63101810e-03,
                         -3.52322211e-04,   2.52305740e-03,  -1.62657176e-04,
                          1.08150730e-03,   2.06564902e-03,  -3.16866150e-04,
                          7.29912776e-04,   3.10720247e-03,   1.70906459e-03,
                         -5.25291893e-04,   1.12387992e-03,   1.85976678e-03,
                         -1.46602141e-03,   8.04234704e-04,   1.59216207e-03,
                         -7.90242164e-04,   1.07287895e-03,   8.94066936e-04,
                         -5.25333453e-04,  -4.49777901e-04,  -9.75402421e-04,
                          3.05852992e-03,   4.83388407e-03,   5.71805425e-03,
                         -2.44779978e-03,  -4.30353312e-03,  -8.93332326e-05,
                         -5.66735864e-04,   1.01585535e-03,   5.78573032e-04,
                          8.34028644e-04,   1.13067182e-03,   2.79116095e-04,
                         -2.26419885e-03,  -6.44044776e-04,  -1.62535196e-03,
                         -6.38742989e-04,  -1.35055347e-03,  -7.17957795e-04,
                         -8.52241763e-04,  -2.72840587e-03,  -3.81599809e-03,
                         -3.39790620e-03,  -3.66215664e-03,  -1.31220056e-03,
                         -1.64126419e-03,  -1.55978312e-03,  -3.50044179e-03,
                         -1.17357809e-03,  -1.72855984e-03,  -2.63081864e-03,
                         -9.70100693e-04,  -1.84720196e-03,  -3.39270849e-03,
                         -6.00520289e-03,  -2.50329869e-03,  -8.36031511e-04,
                         -1.92420592e-03,  -1.23268773e-03,  -5.14099200e-04,
                          1.45976315e-03,   2.28593271e-04,   2.02223682e-03,
                         -6.38084603e-04,   3.81776539e-04,  -2.50426889e-03,
                          2.86049303e-03,  -4.63222939e-04,  -1.03873271e-03,
                         -1.93017989e-03,   6.67289423e-04,   1.65491714e-04,
                          3.01734940e-03,   1.93712418e-03,   1.53793150e-03,
                          4.61875694e-03,   3.20891337e-03,   1.64986483e-03,
                          6.87050866e-03,   9.41845337e-06,   7.33980956e-03,
                          3.84405954e-03,   8.15850776e-03,   1.69734529e-03,
                          6.36532204e-04,   2.62128934e-03,   1.92269508e-03,
                          6.29381370e-03,   2.17160140e-03,  -3.85247311e-03,
                         -5.10832202e-03,  -2.56155588e-04,  -5.56426123e-03,
                         -2.35477276e-03,  -5.29034296e-04,  -2.55192252e-04,
                          4.73715598e-03,  -4.36915737e-03,   3.24412691e-03,
                         -6.24122564e-03,  -8.34194943e-04,  -1.61215634e-04,
                          1.95681350e-03,   2.53738952e-03,   2.17799121e-03,
                          2.30215001e-03,  -5.96523518e-03,  -5.43068418e-05,
                         -1.25302153e-03,  -1.90179294e-03,   1.51823519e-03,
                         -5.05734177e-04,   7.18738185e-03,  -7.28768576e-03,
                         -7.89964979e-04,   1.61167129e-03,   5.52431447e-03,
                         -1.81781687e-03,  -1.29337749e-03,  -5.38972556e-04,
                          3.86038749e-03,   6.08664239e-03,   7.05483044e-03,
                          7.63687538e-03,   3.20142158e-03,   8.99476092e-03,
                          7.78704416e-03,   3.03072506e-03,   1.76650402e-03,
                         -3.81938019e-03,   2.68482044e-03,   3.55886552e-03,
                          1.17719434e-02,  -1.76994153e-03,  -2.52194144e-03,
                          6.62302272e-03,  -3.15563218e-03,   2.65123555e-04,
                          4.53970814e-03,  -1.23360809e-02,  -2.24729558e-03,
                          3.10287089e-03,   1.49264804e-03,  -4.17016400e-03,
                         -6.74280152e-03,  -5.40577620e-03,  -5.09249326e-03,
                         -7.37861963e-04,   4.87964571e-04,  -5.09408722e-03,
                          4.43591131e-03,   2.31603161e-03,   6.71279291e-03,
                          1.45452376e-03,   6.33069035e-03,  -5.25989756e-03,
                          2.30661314e-03,   7.38917477e-03,   1.03158886e-02,
                         -4.24004346e-03,  -3.73812788e-03,   6.85698027e-03,
                         -1.49113720e-03,   2.95069255e-03,  -5.13016013e-03,
                          3.57634388e-03,  -4.45230864e-03,  -1.13686407e-02,
                          4.21954319e-03,  -3.90766701e-03,   8.65967479e-03,
                          3.96396266e-03,   9.20871738e-03,  -6.44794665e-03,
                         -2.78184656e-03,  -2.77587934e-03,  -8.77840724e-03,
                          2.82990909e-03,  -1.73711206e-03,   8.07760190e-03,
                         -9.39186756e-03,  -3.96342902e-03,   4.05918015e-03,
                         -1.21871876e-02,  -1.35548385e-02,  -4.02366836e-03,
                         -1.18646864e-03,  -1.10520869e-02,   5.64067632e-05,
                         -1.94720030e-02,   9.21816390e-04,  -1.16700807e-03,
                          8.36344808e-03,   5.11269551e-03,   3.96311749e-03,
                          1.32093495e-02,  -2.72278534e-03,   9.07119736e-03,
                          9.34734009e-03,  -1.26266177e-03,   2.79110554e-03,
                          3.36075900e-03,   3.01384949e-03,   1.44240935e-03,
                          2.81652639e-04,  -3.01376637e-03,   7.51444232e-03,
                          3.61545244e-03,   1.10249955e-03,   7.06117833e-03,
                          1.01750409e-02,   1.88163226e-03,   6.62917038e-03,
                          6.13006158e-03,  -4.63765580e-03,   4.62308805e-03,
                         -7.40384683e-03,   4.05422458e-03,   3.57319764e-03,
                         -1.92575832e-03,  -8.68255273e-03,   3.68452095e-03,
                          1.96804781e-03,  -6.46397658e-03,  -1.09244348e-03,
                         -1.12642897e-02,  -1.52395284e-02,  -8.99571087e-03,
                         -6.51470013e-03,   6.68079476e-04,   1.70290342e-03,
                         -4.32756776e-03,   7.16033205e-03,  -9.10217594e-03,
                          1.62489456e-03,  -1.23366492e-03,  -1.58174559e-02,
                          3.49710137e-03,  -1.26641328e-02,   1.10992207e-03,
                         -3.04539688e-03,   8.93924199e-03,   2.17290297e-02,
                         -1.48585625e-03,  -3.65510141e-03,  -1.86994066e-03,
                         -4.27179877e-03,  -6.44918019e-03,  -1.62994545e-02,
                          5.32568840e-04,  -9.57785291e-04,   1.69458694e-03,
                          8.42982065e-03,  -7.01837614e-03,   1.18349344e-02,
                          7.57603301e-03,   7.47225014e-03,  -6.44272799e-03,
                          9.01814457e-03,   6.46103779e-03,   1.22001059e-02,
                         -5.77468984e-03,  -8.91828386e-04,   1.86298601e-02,
                         -1.04584955e-02,   9.61813983e-03,  -1.03144185e-03,
                          1.51474299e-02,   7.54767377e-03,   2.81895208e-03,
                         -6.62047928e-03,  -4.58023744e-03,   7.24484865e-03,
                         -4.75365762e-03,  -1.39691457e-02,  -1.67848207e-02,
                         -1.47172026e-02,  -2.29938962e-02,  -7.56394630e-03,
                         -9.31106601e-03,  -2.43849643e-02,  -1.31004788e-02,
                         -1.18734948e-02,  -6.62893476e-03,   2.95332610e-03,
                          1.64552638e-03,   3.82238114e-03,   7.18671654e-04,
                          3.87029815e-03,  -1.03653995e-02,  -1.30190328e-02,
                         -9.69248265e-03,   5.78223029e-03,   9.24372301e-03,
                         -3.65349348e-03,   8.18386674e-03,   2.96161487e-03,
                         -1.24324963e-03,  -3.24084889e-03,   1.70450436e-03,
                          2.00692751e-03,  -5.17432753e-04,  -6.79789856e-03,
                         -2.05666036e-03,  -3.57114617e-03,  -4.09588357e-03,
                         -5.34128165e-04,  -5.57543291e-03,   6.78793935e-04,
                          2.19364720e-03,   1.30636096e-02,   4.05782880e-03,
                         -2.43751984e-02,   6.54531876e-03,   1.24086076e-02,
                          1.49054471e-02,   1.33111645e-02,   8.03423114e-03,
                          6.63734833e-03,   1.56093016e-02,   1.27415452e-02,
                         -9.54458676e-03,   1.01739187e-02,  -6.92846067e-03,
                          7.40144867e-03,   4.05460596e-03,   5.81492810e-03,
                         -1.05924951e-02,  -1.00731151e-02,   2.56634480e-03,
                         -1.60509429e-03,   1.20834110e-03,   1.64194480e-02,
                          4.20749141e-03,  -4.38079354e-04,   8.96360166e-03,
                          3.35494452e-03,  -1.04569783e-03,  -9.35326517e-03,
                         -1.34246703e-02,  -1.50679308e-03,   3.47109837e-03,
                          5.52658737e-03,   6.08359987e-04,  -1.38426516e-02,
                         -1.61846932e-02,   1.04381272e-03,  -9.42908406e-01,
                         -9.09636438e-01,  -9.22850132e-01,  -9.21471536e-01,
                         -9.30805385e-01,  -9.28843856e-01,  -9.30747330e-01,
                         -9.13582325e-01,  -9.18997347e-01,  -9.30618763e-01,
                         -9.18113232e-01,  -9.22254562e-01,   2.80124485e-03,
                          4.70451405e-03,   1.78417861e-02,   6.41879020e-03,
                         -1.12968348e-02,  -5.73585182e-03,  -8.67026486e-03,
                          1.61507411e-03,   6.27519144e-03,   1.37664173e-02,
                          4.53628460e-03,  -5.85517287e-03,   1.50362588e-03,
                          9.40061454e-03,   1.62458955e-03,  -6.84817880e-03,
                          9.27651767e-03,   7.90066179e-03,   1.15752649e-02,
                          1.90504326e-03,   2.84098391e-03,  -5.52902697e-03,
                          9.09535622e-04,  -8.62434413e-03,   8.94039229e-04,
                         -4.35762526e-03,  -3.33303749e-03,   3.80308670e-03,
                         -1.21418135e-02,   5.38174156e-03,   3.85366497e-04,
                          1.36190066e-02,   1.70044731e-02,   1.95462555e-02,
                          1.93009677e-03,   4.46563587e-03,   6.21486222e-04,
                          1.75722837e-02,   2.52363249e-03,   7.46782124e-03,
                          1.46271558e-02,   1.17352195e-02,  -3.63911968e-03,
                          1.10003930e-02,   2.66788946e-03,  -7.71603454e-03,
                          1.86115000e-02,   1.35449208e-02,  -1.89240905e-03,
                         -1.76476446e-04,  -6.01857854e-03,   1.06659168e-02,
                          1.57973859e-02,   1.33752916e-02,   1.79428868e-02,
                          3.65893380e-03,   2.06485409e-02,   1.49092940e-03,
                          5.39873494e-03,   5.47226006e-03,   1.02347052e-02,
                          4.49472293e-03,  -2.19569844e-03,  -2.80746841e-03,
                         -9.19151008e-01,  -9.27631080e-01,  -9.27101970e-01,
                         -9.30616140e-01,  -9.32594657e-01,  -9.21710014e-01,
                         -9.23439562e-01,  -9.18060124e-01,  -9.13650334e-01,
                         -9.23675716e-01,  -9.08591807e-01,  -9.20177460e-01,
                         -9.24716830e-01,  -9.43556845e-01,  -9.37912464e-01,
                         -9.30648267e-01,  -9.30731654e-01,  -9.37719345e-01,
                         -9.23645556e-01,  -9.46156502e-01,  -9.31326449e-01,
                         -9.25824344e-01,  -9.35193777e-01,  -9.24616635e-01,
                         -9.28403795e-01,  -9.40058708e-01,  -9.51370716e-01,
                         -9.19671178e-01,  -9.48159754e-01,  -9.62864935e-01,
                         -9.44421530e-01,  -9.23950315e-01,  -9.33374107e-01,
                         -9.25034583e-01,  -9.31484699e-01,  -9.36478496e-01,
                         -9.16824222e-01,  -9.33033228e-01,  -9.27376151e-01,
                         -9.40928936e-01,  -9.30126071e-01,  -9.30288792e-01,
                         -9.27689135e-01,  -9.18119907e-01,  -9.35810983e-01,
                         -9.26085711e-01,  -9.28467572e-01,  -9.37938988e-01,
                         -9.44825590e-01,  -9.35902655e-01,  -9.38787937e-01,
                         -9.38338637e-01,  -9.33385968e-01,  -9.34923768e-01,
                         -9.29105818e-01,  -9.29892838e-01,  -9.44142222e-01,
                         -9.36078429e-01,  -9.37002420e-01,  -9.34217155e-01,
                         -9.36273038e-01,  -9.29530501e-01,  -9.26555812e-01,
                         -9.28379714e-01,  -9.24367368e-01,  -9.20538247e-01,
                         -9.38073516e-01,  -9.25076962e-01,  -9.17773128e-01,
                         -9.34154093e-01,  -9.38943386e-01,  -9.34515715e-01,
                         -9.33338046e-01,  -9.34060931e-01,  -9.36044931e-01,
                         -9.42258477e-01,  -9.36967611e-01,  -9.28419769e-01,
                         -9.23155367e-01,  -9.13732946e-01,  -9.11040485e-01,
                         -9.22492266e-01,  -9.13869202e-01,  -9.20626938e-01,
                         -9.16593313e-01,  -9.35423493e-01,  -9.34603930e-01,
                         -9.38481450e-01,  -9.26161885e-01,  -9.34030890e-01,
                         -9.31674302e-01,  -9.36219811e-01,  -9.26979244e-01,
                         -9.34942722e-01,  -9.32792962e-01,  -9.23055351e-01,
                         -9.35967088e-01,  -9.40329134e-01,  -9.22487557e-01,
                         -9.31754827e-01,  -9.29716885e-01,  -9.22400117e-01,
                         -9.24395084e-01,  -9.20421839e-01,  -9.12489355e-01,
                         -9.16942954e-01,  -9.25537407e-01,  -9.35009599e-01,
                         -9.15875793e-01,  -9.34874654e-01,  -9.25383806e-01,
                         -9.24653411e-01,  -9.31263685e-01,  -9.29196537e-01,
                         -9.29898202e-01,  -9.38019514e-01,  -9.35918629e-01,
                         -9.36756134e-01,  -9.35842693e-01,  -9.28679168e-01,
                         -9.27183390e-01,  -9.24214661e-01,  -9.21917558e-01,
                         -9.24661338e-01,  -9.28788602e-01,  -9.17299807e-01,
                         -9.17178273e-01,  -9.25556660e-01,  -9.25324023e-01,
                         -9.30244982e-01,  -9.12627518e-01,  -9.27632272e-01,
                         -9.27630484e-01,  -9.32622433e-01,  -9.30322051e-01,
                         -9.29715693e-01,  -9.34053063e-01,  -9.34355557e-01,
                         -9.32855487e-01,  -9.28806484e-01,  -9.29547250e-01,
                         -9.29047048e-01,  -9.31710124e-01,  -9.26649034e-01,
                         -9.33068395e-01,  -9.36013341e-01,  -9.31977570e-01,
                         -9.30427849e-01,  -9.28729534e-01,  -9.28286076e-01,
                         -9.31089163e-01,  -9.42587793e-01,  -9.38949943e-01,
                         -9.36978936e-01,  -9.36346292e-01,  -9.35352564e-01,
                         -9.30068791e-01,  -9.33655322e-01,  -9.31501985e-01,
                         -9.37252700e-01,  -9.36599374e-01,  -9.39634204e-01,
                         -9.32487130e-01,  -9.36815679e-01,  -9.34443831e-01,
                         -9.34503019e-01,  -9.22142208e-01,  -9.24460769e-01,
                         -9.23703969e-01,  -9.33219612e-01,  -9.25096869e-01,
                         -9.38113868e-01,  -9.20795679e-01,  -9.38026011e-01,
                         -9.31187987e-01,  -9.27547872e-01,  -9.35658813e-01,
                         -9.33520019e-01,  -9.28397357e-01,  -9.32317019e-01,
                         -9.26615059e-01,  -9.25312102e-01,  -9.28796291e-01,
                         -9.37514842e-01,  -9.40247536e-01,  -9.42822874e-01,
                         -9.30382729e-01,  -9.33480322e-01,  -9.19775903e-01,
                         -9.27811146e-01,  -9.26505983e-01,  -9.46684837e-01,
                         -9.35800076e-01,  -9.23282206e-01,  -9.36957717e-01,
                         -9.19245541e-01,  -9.38111961e-01,  -9.33292687e-01,
                         -9.33814883e-01,  -9.29324269e-01,  -9.27486241e-01,
                         -9.23045874e-01,  -9.28613484e-01,  -9.32577610e-01,
                         -9.25280571e-01,  -9.28064287e-01,  -9.28554177e-01,
                         -9.28662479e-01,  -9.33985531e-01,  -9.30855215e-01,
                         -9.19695616e-01,  -9.31007683e-01,  -9.45103824e-01,
                         -9.41676736e-01,  -9.40399349e-01,  -9.41436231e-01,
                         -9.35596824e-01,  -9.39060688e-01,  -9.39659834e-01,
                         -9.39135671e-01,  -9.36801493e-01,  -9.36586380e-01,
                         -9.29189920e-01,  -9.24599290e-01,  -9.31297958e-01,
                         -9.29118514e-01,  -9.26732361e-01,  -9.25646722e-01,
                         -9.28327560e-01,  -9.29202080e-01,  -9.30675566e-01,
                         -9.28681076e-01,  -9.39743340e-01,  -9.33366656e-01,
                         -9.27137494e-01,  -9.20944154e-01,  -9.26829159e-01,
                         -9.31792080e-01,  -9.23078775e-01,  -9.30020630e-01,
                         -9.38601315e-01,  -9.38247383e-01,  -9.33022618e-01,
                         -9.25055563e-01,  -9.28838193e-01,  -9.33706462e-01,
                         -9.40643072e-01,  -9.39594209e-01,  -9.31961298e-01,
                         -9.21813846e-01,  -9.27368820e-01,  -9.26367164e-01,
                         -9.25475776e-01,  -9.26785350e-01,  -9.33447957e-01,
                         -9.27010000e-01,  -9.28833425e-01,  -9.25606251e-01,
                         -9.35068905e-01,  -9.24140096e-01,  -9.28121090e-01,
                         -9.31696475e-01,  -9.34021711e-01,  -9.36530054e-01,
                         -9.32437658e-01,  -9.22121704e-01,  -9.34353769e-01,
                         -9.48779404e-01,  -9.46048379e-01,  -9.40797210e-01,
                         -9.33575392e-01,  -9.29988384e-01,  -9.34765518e-01,
                         -9.39335585e-01,  -9.26612020e-01,  -9.24074709e-01,
                         -9.26286578e-01,  -9.49105978e-01,  -9.26064134e-01,
                         -9.38750148e-01,  -9.24310863e-01,  -9.32264924e-01,
                         -9.25388932e-01,  -9.24095392e-01,  -9.24648106e-01,
                         -9.30335939e-01,  -9.31177080e-01,  -9.35583532e-01,
                         -9.29452538e-01,  -9.36238527e-01,  -9.31930006e-01,
                         -9.36886668e-01,  -9.38697755e-01,  -9.38437641e-01,
                         -9.28767502e-01,  -9.34860528e-01,  -9.28826809e-01,
                         -9.35421050e-01,  -9.33364928e-01,  -9.29828703e-01,
                         -9.42915916e-01,  -9.28880632e-01,  -9.40453351e-01,
                         -9.31853175e-01,  -9.28932667e-01,  -9.28925395e-01,
                         -9.26156282e-01,  -9.16610658e-01,  -9.16101396e-01,
                         -9.22324538e-01,  -9.31099057e-01,  -9.44412351e-01,
                         -9.42759931e-01,  -9.27879512e-01,  -9.28225696e-01,
                         -9.36404765e-01,  -9.27614331e-01,  -9.33864236e-01,
                         -9.35854733e-01,  -9.38738167e-01,  -9.31230783e-01,
                         -9.36090827e-01,  -9.29853201e-01,  -9.29969966e-01,
                         -9.34527755e-01,  -9.31457996e-01,  -9.29250836e-01,
                         -9.29591537e-01,  -9.30655062e-01,  -9.38725412e-01,
                         -9.34307456e-01,  -9.31915522e-01,  -9.27217424e-01,
                         -9.25465703e-01,  -9.31063652e-01,  -9.36671078e-01,
                         -9.32535589e-01,  -9.39352691e-01,  -9.41122234e-01,
                         -9.44672942e-01,  -9.49155867e-01,  -9.38521564e-01,
                         -9.34836566e-01,  -9.42336559e-01,  -9.46098804e-01,
                         -9.24987674e-01,  -9.30467665e-01,  -9.26952422e-01,
                         -9.15350318e-01,  -9.09928322e-01,  -9.21060026e-01,
                         -9.25744653e-01,  -9.28098381e-01,  -9.22794104e-01,
                         -9.26147580e-01,  -9.28122520e-01,  -9.30448592e-01,
                         -9.29989934e-01,  -9.32524920e-01,  -9.42016184e-01,
                         -9.31152821e-01,  -9.35586751e-01,  -9.38824058e-01,
                         -9.25491810e-01,   1.14540104e-02,   1.07251166e-03,
                          5.13124792e-03,  -1.41520752e-03,   6.25514193e-03,
                          1.08193839e-02,  -2.92762113e-03,  -6.56960299e-03,
                         -7.47699058e-03,  -1.50117255e-03,  -2.84090079e-03,
                          5.78959705e-03,   3.28017195e-04,  -4.12137387e-03,
                         -5.13769360e-03,  -4.39827889e-03,  -7.96320848e-03,
                          2.61541223e-03,  -7.87503272e-03,   7.38648605e-03,
                         -1.06772203e-02,   8.95357411e-03,   3.78615572e-03,
                         -9.88071319e-04,   9.11383983e-03,  -8.95396899e-03,
                          3.48104374e-03,   5.77837694e-03,  -8.42314679e-03,
                         -1.50146363e-02,  -6.40561525e-03,  -1.94947422e-03,
                         -1.41048161e-02,  -1.08254962e-02,  -1.10525098e-02,
                         -1.80515572e-02,  -1.60069484e-02,  -6.73774909e-03,
                         -3.24874953e-03,  -8.47500004e-03,   1.19850680e-03,
                          1.40170008e-03,  -1.66727472e-02,  -4.53683920e-03,
                         -1.36855803e-02,  -3.37870186e-03,  -8.31270299e-04,
                         -9.30399727e-03,   9.60045960e-03,   5.83619764e-03,
                         -2.17733299e-03,   4.68022283e-03,   1.50327245e-02,
                         -3.57583119e-03,  -7.70630455e-03,  -5.50774345e-03,
                          2.60448293e-03,  -1.38566305e-03,  -3.00257374e-03,
                         -6.31672563e-03,   3.41336103e-03,  -1.17312069e-03,
                          1.90837681e-03,   7.66799320e-03,  -9.43919551e-03,
                         -8.97914730e-03,  -6.38220459e-03,  -1.45481415e-02,
                          3.06323566e-03,  -3.60170938e-03,  -6.61796378e-03,
                         -1.89736439e-03,   2.07055570e-03,  -4.90151113e-03,
                         -1.64797138e-02,  -1.00278109e-02,  -1.29670957e-02,
                         -2.02521682e-03,   4.57345945e-04,  -8.24991334e-03,
                         -8.78125522e-03,  -9.05557536e-03,  -3.61291575e-03,
                         -1.37355141e-02,  -4.82763303e-03,  -4.49165935e-03,
                         -7.13792630e-03,   7.52675766e-03,  -2.41632876e-03,
                         -6.49027061e-03,  -2.75090220e-03,   1.05183120e-04,
                          9.58905928e-03,  -1.12665351e-02,  -8.41173867e-04,
                          2.69671320e-03,  -4.05066274e-03,  -2.20936537e-03,
                          1.28540059e-03,  -1.92744937e-03,  -2.68298388e-03,
                          1.97669002e-03,   4.72513167e-03,   1.37664657e-03,
                          6.39373669e-04,   3.64293158e-03,  -2.32347474e-03,
                          6.41781278e-03,   6.90085674e-03,  -7.79622002e-03,
                         -2.74318852e-03,  -5.71686262e-03,  -9.45221819e-03,
                          1.55719812e-04,   3.26028164e-03,   4.26290696e-03,
                          6.73429808e-04,  -9.20230709e-03,  -7.75629375e-03,
                          9.46287706e-04,  -8.11101403e-03,  -7.68887438e-03,
                         -9.02238581e-03,  -2.23389342e-02,  -8.88712518e-03,
                         -2.38049147e-03,  -6.44111307e-03,   2.58554914e-03,
                         -4.18863352e-03,  -3.88483121e-03,  -6.47844747e-03,
                          1.62176194e-03,  -7.13222940e-03,  -2.98905931e-03,
                          5.54003939e-03,  -8.59375950e-03,   6.32928335e-04,
                          1.71173282e-03,   1.96129060e-03,  -1.11734113e-02,
                         -2.35530635e-04,  -1.47389714e-02,  -2.94120488e-04,
                         -6.96586445e-03,  -8.59814696e-03,   8.74107331e-03,
                         -1.21856555e-02,   5.32121817e-03,  -3.51216132e-03,
                          1.81980594e-03,  -1.07052259e-03,  -1.69166224e-03,
                          1.91947934e-03,  -1.55791198e-03,   4.54676338e-03,
                          1.39983580e-03,   4.80485940e-03,   1.10703902e-02,
                          2.81254831e-03,  -5.83691802e-03,   4.56081843e-03,
                          8.92348180e-04,   5.92417922e-03,  -7.71469716e-03,
                          1.29864039e-02,   4.95970622e-03,   2.14817654e-03,
                         -3.53923161e-03,   1.19051188e-02,  -7.99783971e-03,
                         -6.54501421e-03,   6.60665333e-03,   1.52453501e-03,
                          4.36799973e-03,  -1.55133498e-03,  -2.71943794e-03,
                         -7.27313897e-03,   2.54734838e-03,   4.16963035e-03,
                         -4.83524939e-03,  -5.46221761e-03,   6.07355079e-03,
                          5.42726042e-03,  -5.63218631e-03,   4.08694323e-04,
                         -8.23338423e-03,  -4.36184555e-03,   6.79172343e-03,
                         -1.79640180e-03,   4.99666622e-03,   8.02389812e-03,
                          2.32425099e-03,   2.49056052e-03,  -3.96782300e-03,
                          1.31794577e-03,  -2.38266075e-03,   4.01334930e-03,
                          7.39580719e-04,   2.94608390e-03,   1.10507635e-02,
                          1.27014669e-03,   5.48651582e-03,   9.31333937e-03,
                         -1.76970661e-02,  -4.04082146e-03,   1.16990982e-02,
                          1.15155522e-02,  -2.77508254e-04,   2.04580720e-03,
                         -1.08369731e-03,   1.00615835e-02,  -1.78597844e-03,
                          1.80621538e-03,   8.76139291e-03,   2.56197853e-03,
                         -7.74951559e-03,  -1.52984366e-03,   4.67690313e-03,
                         -7.49681843e-03,  -1.93294522e-03,   5.74816018e-03,
                          3.97997908e-03,   1.69898081e-03,   8.28477321e-04,
                          1.83689641e-03,  -2.42743129e-03,   9.78814252e-03,
                          7.88569171e-03,  -5.14190691e-03,   6.53214427e-03,
                         -4.49230429e-05,  -2.90881889e-03,   2.32588663e-03,
                         -3.75430356e-03,  -2.22882605e-04,  -6.58220984e-03,
                          6.35216106e-03,  -8.71750934e-04,   5.39774401e-03,
                         -7.58694834e-04,   7.62485107e-03,  -1.32967209e-04,
                         -1.04964117e-03,  -7.71064963e-03,   5.25132462e-04,
                          5.58076287e-03,   6.72764494e-04,  -3.03179235e-03,
                          9.04195104e-03,  -4.91937809e-03,  -1.55870197e-03,
                          7.61266751e-03,   3.47525673e-03,  -6.80541107e-03,
                          4.25098650e-03,  -1.71079226e-02,  -1.56980660e-02,
                         -1.06924670e-02,  -9.34956479e-04,  -9.91520565e-03,
                          1.42778619e-03,  -8.69942084e-03,   1.96108269e-03,
                         -1.53592171e-03,  -7.45515168e-01,  -7.69090533e-01,
                         -7.52889276e-01,  -7.55659819e-01,  -7.60477424e-01,
                         -7.68230498e-01,  -7.64126837e-01,  -7.70540476e-01,
                         -7.64365315e-01,  -7.66430378e-01,  -7.55261719e-01,
                         -7.70413399e-01,  -7.57617295e-01,  -7.58525133e-01,
                         -7.59019494e-01,  -7.63701916e-01,  -7.63912916e-01,
                         -7.65177965e-01,  -7.65875697e-01,  -7.72159159e-01,
                         -7.78209090e-01,  -7.65956283e-01,  -7.63983905e-01,
                         -7.71103680e-01,  -7.56823361e-01,  -7.58467257e-01,
                         -7.51711726e-01,  -7.56620228e-01,  -7.59902358e-01,
                         -7.46653378e-01,  -7.51609325e-01,  -7.61589706e-01,
                         -7.63923287e-01,  -7.65039980e-01,  -7.57566631e-01,
                         -7.59392142e-01,  -7.57396877e-01,  -7.61665106e-01,
                         -7.64725029e-01,  -7.70016849e-01,  -7.66151190e-01,
                         -7.60898650e-01,  -7.57846951e-01,  -7.62256980e-01,
                         -7.60790110e-01,  -7.75976002e-01,  -7.49961436e-01,
                         -7.57742524e-01,  -7.55527377e-01,  -7.70329773e-01,
                         -7.57636130e-01,  -7.53594697e-01,  -7.63046026e-01,
                         -7.62485445e-01,  -7.48906255e-01,  -7.65855610e-01,
                         -7.53384829e-01,  -7.54176617e-01,  -7.49986947e-01,
                         -7.59139001e-01,  -7.59026170e-01,  -7.54824162e-01,
                         -7.59763777e-01,  -7.71053016e-01,  -7.67858088e-01,
                         -7.63995469e-01,  -7.62498736e-01,  -7.67975807e-01,
                         -7.46320963e-01,  -7.55615592e-01,  -7.56462753e-01,
                         -7.63965428e-01,  -7.74791241e-01,  -7.64296174e-01,
                         -7.47709930e-01,  -7.58725822e-01,  -7.50668526e-01,
                         -7.73145497e-01,  -7.52092302e-01,  -7.61241436e-01,
                         -9.31394875e-01,  -9.33937848e-01,  -9.29780543e-01,
                         -9.27316368e-01,  -7.69417822e-01,  -7.72782028e-01,
                         -7.68205523e-01,  -7.66251504e-01,  -7.61278868e-01,
                         -7.67723918e-01,  -7.67280579e-01,  -7.65318930e-01,
                         -7.70242631e-01,  -7.71286011e-01,  -7.57192373e-01,
                         -7.58984268e-01,  -7.61479080e-01,  -7.52289593e-01,
                         -7.55404472e-01,  -7.62569010e-01,  -9.24036086e-01,
                         -9.34469104e-01,  -9.27145362e-01,  -9.25660491e-01,
                         -9.31378484e-01,  -9.37153578e-01,  -9.27817166e-01,
                         -9.35218275e-01,  -9.39518034e-01,  -9.36797500e-01,
                         -9.42885518e-01,  -9.45192754e-01,  -7.56892145e-01,
                         -7.59015441e-01,  -7.58090079e-01,  -7.63925672e-01,
                         -7.69052744e-01,  -7.60673165e-01,  -7.45455921e-01,
                         -7.49120712e-01,  -7.62119353e-01,  -7.53271043e-01,
                         -7.59635985e-01,  -7.51158774e-01,  -7.49432683e-01,
                         -7.57442892e-01,  -7.60951459e-01,  -7.62222469e-01,
                         -9.29820776e-01,  -9.37411606e-01,  -9.20853674e-01,
                         -9.40011144e-01,  -9.27624524e-01,  -9.19821501e-01,
                         -9.26867366e-01,  -9.38499629e-01,  -7.58229733e-01,
                         -7.61852264e-01,  -7.63656020e-01,  -7.57714987e-01,
                         -7.41506338e-01,  -7.46090531e-01,  -7.51313090e-01,
                         -7.63726056e-01,  -7.54244745e-01,  -7.66506314e-01,
                         -7.62096882e-01,  -7.61319816e-01,  -7.70330608e-01,
                         -7.54323542e-01,  -7.52193928e-01,  -7.61815488e-01,
                         -9.13512409e-01,  -9.24774408e-01,  -9.36615109e-01,
                         -9.12261963e-01,  -9.22886848e-01,  -9.27449048e-01,
                         -9.24039066e-01,  -9.19912279e-01,  -9.20300126e-01,
                         -9.37327683e-01,  -9.17948723e-01,  -9.42344606e-01,
                         -9.33449268e-01,  -9.43668962e-01,  -9.31410491e-01,
                         -9.27028179e-01,  -7.71620750e-01,  -7.64478683e-01,
                         -7.60407329e-01,  -7.45330632e-01,  -7.54594743e-01,
                         -7.38097787e-01,  -7.48381436e-01,  -7.41117775e-01,
                         -7.60793865e-01,  -7.49188721e-01,  -7.59283960e-01,
                         -7.60404587e-01,  -7.62880445e-01,  -7.59495735e-01,
                         -7.61041045e-01,  -7.60318935e-01,  -7.64677882e-01,
                         -7.52430499e-01,  -7.59031236e-01,  -7.61057377e-01,
                         -7.47230649e-01,  -7.65413105e-01,  -7.63032973e-01,
                         -7.61603713e-01,  -7.57058740e-01,  -7.46987045e-01,
                         -7.69224405e-01,  -7.64737725e-01,  -7.57906497e-01,
                         -7.63017535e-01,  -7.53534079e-01,  -7.56450832e-01,
                         -7.54934311e-01,  -7.61880517e-01,  -7.65418231e-01,
                         -7.49003887e-01,  -7.58520365e-01,  -7.57604480e-01,
                         -7.60814428e-01,  -7.63232291e-01,  -7.68745303e-01,
                         -7.80494690e-01,  -7.55449831e-01,  -7.55616844e-01,
                         -7.54781425e-01,  -7.61589348e-01,  -7.64513195e-01,
                         -7.60950029e-01,   4.82754968e-03,   6.86775008e-03,
                         -2.58211163e-03,   1.73719518e-03,  -8.03615805e-03,
                          6.05484564e-03,  -4.52473853e-03,  -2.33567925e-03,
                         -7.53789246e-01,  -7.60745466e-01,  -7.61433363e-01,
                         -7.62368321e-01,  -7.68494427e-01,  -7.73327112e-01,
                         -7.48191416e-01,  -7.57184088e-01,  -7.48445213e-01,
                         -7.63592482e-01,  -7.66889751e-01,  -7.44467616e-01,
                         -7.78231084e-01,  -7.40091801e-01,  -7.64815152e-01,
                         -7.70229876e-01,  -7.53325522e-01,  -7.68759310e-01,
                         -7.39691377e-01,  -7.53289640e-01,  -7.53492057e-01,
                         -7.55199850e-01,  -7.51341343e-01,  -7.49564528e-01,
                         -7.50737965e-01,  -7.61190951e-01,  -7.46036828e-01,
                         -7.44704187e-01,  -7.76278257e-01,  -7.64761508e-01,
                         -7.66269267e-01,  -7.48074532e-01,  -7.58319259e-01,
                         -7.46894419e-01,  -7.55836427e-01,  -7.58957028e-01,
                         -7.45009601e-01,  -7.79873908e-01,  -7.53791749e-01,
                         -7.65148461e-01,  -7.70524025e-01,  -7.63043404e-01,
                         -7.59400725e-01,  -7.70938575e-01,  -7.65418470e-01,
                         -7.63995767e-01,  -7.70052433e-01,  -7.61512518e-01,
                         -7.63431251e-01,  -7.53492713e-01,  -7.72794485e-01,
                         -7.61781871e-01,  -7.58262813e-01,  -7.72884667e-01,
                         -7.51225412e-01,  -7.56710172e-01,  -1.76866706e-02,
                          2.05707196e-02,  -1.30963000e-02,  -1.03958240e-02,
                         -7.64685810e-01,  -7.78764963e-01,  -7.62054801e-01,
                         -7.56062269e-01,  -7.81431139e-01,  -7.66397893e-01,
                         -7.81111836e-01,  -7.67225325e-01,  -7.67134011e-01,
                         -7.73116052e-01,  -7.67638505e-01,  -7.67409921e-01,
                         -7.77935863e-01,  -7.77092576e-01,  -7.76770175e-01,
                         -7.64305890e-01,  -7.71618903e-01,  -7.53740072e-01,
                         -7.74485648e-01,  -7.62281537e-01,  -7.67447233e-01,
                         -7.60727704e-01,  -7.50483274e-01,  -7.75741875e-01,
                         -7.59547830e-01,  -7.67448366e-01,  -7.77072847e-01,
                         -7.71952927e-01,  -7.59911180e-01,  -7.66663432e-01,
                         -7.65232444e-01,  -7.61363506e-01,  -7.67416418e-01,
                         -7.64604509e-01,  -7.64104068e-01,  -7.53929913e-01,
                         -7.52178788e-01,  -7.64454126e-01,  -7.65302658e-01,
                         -7.56910205e-01,  -4.18029763e-02,  -7.27253594e-03,
                         -1.82888482e-03,   3.32145672e-03,   7.75681343e-04,
                          1.30915106e-03,  -4.19837749e-03,  -5.71014686e-03,
                         -7.53794611e-01,  -7.58640945e-01,  -7.53266335e-01,
                         -7.88188577e-01,  -7.82634079e-01,  -7.78564155e-01,
                         -7.88955033e-01,  -7.65911400e-01,  -7.72964597e-01,
                         -7.88740635e-01,  -7.43552506e-01,  -7.79654443e-01,
                         -7.39254236e-01,  -7.58298695e-01,  -7.68609881e-01,
                         -7.46325850e-01,  -7.67936766e-01,  -7.74642467e-01,
                         -7.50154734e-01,  -7.65353203e-01,  -7.63756871e-01,
                         -7.67208278e-01,  -7.66146064e-01,  -7.64244199e-01,
                         -7.73212314e-01,  -7.58932889e-01,  -7.74826467e-01,
                         -7.49939144e-01,  -7.65338242e-01,  -7.47398615e-01,
                         -7.67213404e-01,  -7.56781757e-01,  -7.54300714e-01,
                         -7.64411688e-01,  -7.38363862e-01,  -7.67966509e-01,
                         -2.20295461e-03,   3.50256945e-04,   3.81484767e-03,
                          4.49687801e-03,  -7.52861440e-01,  -7.53582418e-01,
                         -7.56026983e-01,  -7.51864552e-01,  -7.56618142e-01,
                         -7.50014305e-01,  -7.67659426e-01,  -7.57200181e-01,
                         -7.48963773e-01,  -7.67989457e-01,  -7.61864781e-01,
                         -7.59726882e-01,  -7.75725186e-01,  -7.54516959e-01,
                         -7.53557861e-01,  -7.59358823e-01,  -7.52816975e-01,
                         -7.78057814e-01,  -7.49226451e-01,  -7.67452061e-01,
                         -7.54556477e-01,  -7.46045589e-01,  -7.57955790e-01,
                         -7.64584661e-01,  -7.71457374e-01,  -7.73836076e-01,
                         -7.54188716e-01,  -7.51871169e-01,  -7.63294101e-01,
                         -7.56375313e-01,  -7.59203494e-01,  -7.72926390e-01,
                         -7.42442310e-01,  -7.67660201e-01,  -7.62865782e-01,
                         -7.49220490e-01,  -7.65904665e-01,  -7.63115108e-01,
                         -7.49977529e-01,  -7.57423937e-01,  -7.59720743e-01,
                         -7.67604709e-01,  -7.59075224e-01,  -7.73016453e-01,
                         -7.70244002e-01,  -7.57587016e-01,  -7.68878520e-01,
                         -7.56645739e-01,  -7.80117214e-01,  -7.58832932e-01,
                         -7.57271349e-01,  -7.49612272e-01,  -9.20863509e-01,
                         -9.12585199e-01,  -9.29821014e-01,  -9.19590414e-01,
                         -9.18411672e-01,  -9.22398329e-01,  -9.07185376e-01,
                         -9.39063251e-01,  -9.21643198e-01,  -9.14947867e-01,
                         -9.30371821e-01,  -9.13342118e-01,  -7.67968655e-01,
                         -7.56018877e-01,  -7.41964817e-01,  -7.61804402e-01,
                         -7.53374517e-01,  -7.65179753e-01,  -7.70335793e-01,
                         -7.72489846e-01,  -7.53171206e-01,  -7.59818256e-01,
                         -7.77968466e-01,  -7.61107564e-01,  -7.56139398e-01,
                         -7.55038202e-01,  -7.54709125e-01,  -7.51329780e-01,
                         -7.47701108e-01,  -7.45837927e-01,  -7.68609226e-01,
                         -7.48332500e-01,  -7.59108305e-01,  -7.55324721e-01,
                         -7.58717895e-01,  -7.92024612e-01,  -9.34190333e-01,
                         -9.50098395e-01,  -9.33667719e-01,  -9.33616161e-01,
                         -9.40789640e-01,  -9.31115568e-01,  -9.46340859e-01,
                         -9.16474521e-01,  -9.36811030e-01,  -9.25224245e-01,
                         -9.06999171e-01,  -9.20633197e-01,  -7.22540021e-01,
                         -7.54403949e-01,  -7.49618590e-01,  -7.98758209e-01,
                         -9.53986108e-01,  -9.30087328e-01,  -9.33179140e-01,
                         -9.37233984e-01,  -9.39181447e-01,  -9.28905189e-01,
                         -9.30544257e-01,  -9.43078160e-01,  -9.26500499e-01,
                         -9.43289638e-01,  -9.30159390e-01,  -9.27954733e-01,
                         -9.40169156e-01,  -9.47220325e-01,  -9.37668979e-01,
                         -9.26429451e-01,  -9.38991725e-01,  -8.97031307e-01,
                         -9.55144107e-01,  -9.19525981e-01,  -9.34719265e-01,
                         -9.47514415e-01,  -9.26037431e-01,  -9.23007369e-01,
                         -7.52242744e-01,  -7.55803347e-01,  -7.70003498e-01,
                         -7.55014956e-01,  -7.63237834e-01,  -7.50162423e-01,
                         -7.46154249e-01,  -7.72181809e-01,  -7.62000263e-01,
                         -7.50213861e-01,  -7.71475852e-01,  -7.47438312e-01,
                         -7.71418154e-01,  -7.57522643e-01,  -7.64279306e-01,
                         -7.72849917e-01,  -7.67324686e-01,  -7.55485594e-01,
                         -7.70632148e-01,  -7.82249570e-01,  -9.35688674e-01,
                         -9.53515947e-01,  -9.26138043e-01,  -9.50525880e-01,
                         -9.51903760e-01,  -9.46197867e-01,  -9.24793661e-01,
                         -9.18162644e-01,  -9.07859385e-01,  -9.24185574e-01,
                         -9.36210692e-01,  -8.96013260e-01,  -9.58431959e-01,
                         -9.20846403e-01,  -9.37601328e-01,  -9.31204140e-01,
                         -7.57940590e-01,  -7.47465372e-01,  -7.54762948e-01,
                         -7.65158415e-01,  -7.69892871e-01,  -7.61846542e-01,
                         -7.75320113e-01,  -7.56004572e-01,  -5.10600135e-02,
                         -4.44513559e-03,  -4.41773271e-04,  -3.14448122e-03,
                          7.28431763e-03,  -8.37981701e-03,  -3.82271386e-03,
                         -3.12327407e-03,  -1.50910439e-02,   1.30127813e-03,
                         -7.15819048e-03,  -2.31877598e-03,  -7.52838254e-01,
                         -7.69746363e-01,  -7.63880253e-01,  -7.45211720e-01,
                         -3.65519826e-03,  -8.90588574e-03,  -5.45055373e-03,
                         -1.76133390e-03,   1.94445660e-03,   2.31959391e-03,
                          6.51435368e-03,  -2.03364994e-02,   1.59684420e-01,
                          1.82293206e-01,   1.68909132e-01,   1.83318898e-01,
                          2.02869456e-02,   1.56240426e-02,   1.26846256e-02,
                          7.46466126e-03,   1.85655847e-01,   1.78214669e-01,
                          1.71626776e-01,   1.95716068e-01,  -1.00484705e-02,
                         -1.43535491e-02,   1.21076880e-02,  -1.84231661e-02,
                          1.60168801e-02,   2.44783312e-02,   7.14448234e-03,
                          2.24335566e-02,   1.41169513e-02,   1.54698957e-02,
                          1.03308028e-02,  -9.88244545e-03,   1.60718232e-01,
                          1.81635261e-01,   1.63590372e-01,   1.88537255e-01,
                          1.72907993e-01,   1.74783498e-01,   1.61843121e-01,
                          1.50947466e-01,   1.66541383e-01,   1.58481032e-01,
                          1.66111574e-01,   1.62156522e-01,   1.93342358e-01,
                          1.78688586e-01,   1.74729586e-01,   1.60896912e-01,
                          1.79557845e-01,   1.72750279e-01,   1.89061880e-01,
                          1.81028143e-01,   2.01267138e-01,   2.02874959e-01,
                          1.75844878e-01,   2.08713204e-01,   1.70597255e-01,
                          1.79998904e-01,   1.74989760e-01,   1.78483471e-01,
                          1.59706727e-01,   1.73873827e-01,   1.66347325e-01,
                          1.65343434e-01,   1.73233762e-01,   1.74124211e-01,
                          1.96527362e-01,   1.61472291e-01,   1.72482967e-01,
                          1.81083575e-01,   1.84739888e-01,   1.58392385e-01,
                          1.62064791e-01,   1.55563280e-01,   1.84746623e-01,
                          1.85623229e-01,   1.82407096e-01,   1.73587799e-01,
                          1.52241901e-01,   1.58823073e-01,   1.88591912e-01,
                          1.76986173e-01,   1.77102879e-01,   1.92319766e-01,
                          1.72752708e-01,   1.42558098e-01,   1.66559249e-01,
                          1.66526809e-01,   1.73060998e-01,   1.68304026e-01,
                          1.87999621e-01,   1.58136442e-01,  -6.28063222e-03,
                         -1.24507234e-03,   1.93242542e-03,  -1.52861215e-02,
                         -4.64877253e-03,   1.91057585e-02,  -7.10756378e-03,
                          2.30389088e-02,   9.18087829e-03,   1.12005440e-03,
                         -6.04564184e-03,  -3.68301710e-03,   6.57123188e-03,
                         -1.20420782e-02,   2.51336172e-02,  -7.50764366e-03,
                         -2.67292093e-03,  -1.77763291e-02,  -7.37419818e-03,
                          1.11552952e-02,   5.05420240e-03,  -7.87656475e-03,
                          8.94852169e-03,  -1.14208758e-02,  -1.73401274e-02,
                          6.98656542e-03,  -2.92783659e-02,  -1.44620379e-02,
                         -2.69846935e-02,   6.03491347e-03,  -1.12187425e-02,
                         -3.09819984e-03,  -1.56569891e-02,  -9.40509140e-03,
                         -1.10518932e-02,  -1.94378290e-02,   1.66003185e-03,
                         -2.97759636e-03,   2.76969047e-03,   8.89565609e-03,
                          8.44429806e-03,   1.42876618e-02,  -7.76755565e-04,
                         -7.86181632e-03,  -1.18623236e-02,   4.17227764e-03,
                          1.00102490e-02,   2.81901304e-02,   4.97648446e-03,
                          7.17064459e-03,  -1.16038462e-02,  -1.16199730e-02,
                         -9.95204784e-03,   2.49334658e-03,   2.85986927e-03,
                          1.35226119e-02,   2.21372466e-03,   3.39926332e-02,
                          6.36691577e-04,   3.43175442e-03,  -4.22079070e-03,
                         -4.25101444e-03,  -2.68052854e-02,  -9.84883300e-05,
                          2.56186984e-02,   3.57703702e-03,  -2.89098825e-02,
                         -1.38700893e-02,   7.18722213e-03,  -8.91463179e-03,
                          9.36543569e-03,  -3.31742726e-02,  -1.38030024e-02,
                         -2.72636139e-03,  -2.63599362e-02,  -1.09523507e-02,
                         -3.28566991e-02,  -3.57737648e-03,  -1.08106378e-02,
                          6.07271912e-03,   6.97818678e-03,  -2.15116497e-02,
                         -1.15006585e-02,   1.13614686e-02,   7.65763223e-03,
                          5.89519599e-03,   9.22354870e-03,   2.86267605e-03,
                          5.15519991e-04,  -9.14072338e-03,  -9.51074064e-01,
                         -9.56158280e-01,  -9.48468149e-01,  -9.19137478e-01,
                         -9.16205406e-01,  -9.60028887e-01,  -9.55711722e-01,
                         -9.28032219e-01,  -9.45629120e-01,  -9.36581492e-01,
                         -9.34845448e-01,  -9.08326864e-01,   3.19761690e-03,
                          1.02128051e-02,   9.81366076e-03,   1.03594186e-02,
                         -6.27668854e-03,   1.05326585e-02,   1.70772706e-04,
                          1.22804223e-02,  -8.91606603e-03,  -2.56651882e-02,
                          3.10986787e-02,   8.86077527e-03,  -9.45684314e-01,
                         -9.36944902e-01,  -9.52851355e-01,  -9.24284220e-01,
                         -9.38334286e-01,  -9.42360699e-01,  -9.29408193e-01,
                         -9.16943610e-01,  -9.17312384e-01,  -8.99634600e-01,
                         -9.26755726e-01,  -9.25315797e-01,  -9.30788457e-01,
                         -9.39888716e-01,  -9.04783666e-01,  -9.38603103e-01,
                         -9.24900293e-01,  -9.46882546e-01,  -9.18199241e-01,
                         -9.43774939e-01,  -9.02583122e-01,  -9.25661266e-01,
                         -9.12336648e-01,  -9.44160819e-01,  -9.20074046e-01,
                         -9.28385675e-01,  -9.44253743e-01,  -9.51529622e-01,
                         -9.25821960e-01,  -9.29694474e-01,  -9.37739253e-01,
                         -9.10216331e-01,  -9.47030842e-01,  -9.31732535e-01,
                         -9.45144534e-01,  -9.40911949e-01,  -9.42772865e-01,
                         -9.29282248e-01,  -9.41358745e-01,  -9.38987553e-01,
                         -9.27911997e-01,  -9.43225265e-01,  -9.22573984e-01,
                         -9.41517174e-01,  -9.35384929e-01,  -9.16594684e-01,
                         -9.15209889e-01,  -9.26087677e-01,  -9.32182610e-01,
                         -9.51112986e-01,  -9.15140331e-01,  -9.22306120e-01,
                         -9.14505959e-01,  -9.39305902e-01,  -9.25809979e-01,
                         -9.41204846e-01,  -9.25350368e-01,  -9.34088767e-01,
                         -9.32236612e-01,  -9.20277596e-01,  -9.15497899e-01,
                         -9.18578744e-01,  -9.19238687e-01,  -9.19340789e-01,
                         -9.32271421e-01,  -9.24911141e-01,  -9.36784983e-01,
                         -9.07740533e-01,  -9.16999996e-01,  -9.05238450e-01,
                         -9.23943937e-01,  -9.24277782e-01,  -9.38583016e-01,
                         -9.30252075e-01,  -9.39154327e-01,  -9.41035628e-01,
                         -9.16000783e-01,  -9.28390861e-01,  -9.27439630e-01,
                         -9.26465333e-01,  -9.37706769e-01,  -9.23539996e-01,
                         -9.50955749e-01,  -9.32735980e-01,  -9.32062447e-01,
                         -9.27642643e-01,  -9.39078569e-01,  -9.51460540e-01,
                         -9.54400241e-01,  -9.44138765e-01,  -9.43048120e-01,
                         -9.36764479e-01,  -9.35152531e-01,  -9.44186807e-01,
                         -9.37068522e-01,  -9.13842797e-01,  -9.36967731e-01,
                         -9.15311217e-01,  -9.21281278e-01,  -9.22891498e-01,
                         -9.06450152e-01,  -9.12059128e-01,  -9.26231265e-01,
                         -9.35474098e-01,  -9.24657166e-01,  -9.34009612e-01,
                         -9.25012112e-01,  -9.37285960e-01,  -9.22811389e-01,
                         -9.38306034e-01,  -9.37396169e-01,  -9.23390925e-01,
                         -9.43740785e-01,  -9.12373841e-01,  -9.32685256e-01,
                         -9.35120463e-01,  -9.32917893e-01,  -9.43184376e-01,
                         -9.39646423e-01,  -9.30136085e-01,  -9.25868154e-01,
                         -9.28881347e-01,  -9.28241789e-01,  -9.49206293e-01,
                         -9.32893872e-01,  -9.20668364e-01,  -9.21498239e-01,
                         -9.43176150e-01,  -9.24894154e-01,  -9.38577235e-01,
                         -9.34884846e-01,  -9.32233632e-01,  -9.18339372e-01,
                         -9.36548591e-01,  -9.17369664e-01,  -9.21760619e-01,
                         -9.30887818e-01,  -9.35654521e-01,  -9.40641522e-01,
                         -9.33021605e-01,  -9.33003187e-01,  -9.34935272e-01,
                         -9.20147896e-01,  -9.33014631e-01,  -9.28017378e-01,
                         -9.33572590e-01,  -9.26129580e-01,  -9.17446554e-01,
                         -9.23744738e-01,  -9.22951818e-01,  -9.17039812e-01,
                         -9.34589088e-01,  -9.30138171e-01,  -9.37750459e-01,
                         -9.23234701e-01,  -9.25651968e-01,  -9.42804039e-01,
                         -9.37142015e-01,  -9.47334766e-01,  -9.39111054e-01,
                         -9.38250601e-01,  -9.44867194e-01,  -9.47262883e-01,
                         -9.38848257e-01,  -9.49325383e-01,  -9.27011728e-01,
                         -9.50609803e-01,  -9.30857539e-01,  -9.33591008e-01,
                         -9.41828907e-01,  -9.30661380e-01,  -9.36115563e-01,
                         -9.31408167e-01,  -9.40829039e-01,  -9.27368939e-01,
                         -9.19300973e-01,  -9.29075360e-01,  -9.38096225e-01,
                         -9.27473366e-01,  -9.50641632e-01,  -9.46599007e-01,
                         -9.28816020e-01,  -9.27169144e-01,  -9.28915441e-01,
                         -9.40075338e-01,  -9.21791017e-01,  -9.33954060e-01,
                         -9.28507328e-01,  -9.32131588e-01,  -9.48363543e-01,
                         -9.30186033e-01,  -9.25844789e-01,  -9.28305686e-01,
                         -9.42359030e-01,  -9.40304399e-01,  -9.48816895e-01,
                         -9.34452593e-01,  -9.25520658e-01,  -9.28156495e-01,
                         -9.35424864e-01,  -9.19503033e-01,  -9.36576426e-01,
                         -9.38030005e-01,  -9.39517021e-01,  -9.27822530e-01,
                         -9.28392947e-01,  -9.29272711e-01,  -9.34669733e-01,
                         -9.18158352e-01,  -9.19208288e-01,  -9.22936797e-01,
                         -9.14976180e-01,  -9.21128750e-01,  -9.21433330e-01,
                         -9.22535837e-01,  -9.30087388e-01,  -9.27386642e-01,
                         -9.12563264e-01,  -9.29144442e-01,  -9.28844154e-01,
                         -9.21602607e-01,  -9.18338239e-01,  -9.34042096e-01,
                         -9.16844428e-01,  -9.16269898e-01,  -9.22341108e-01,
                         -9.27204490e-01,  -9.19120014e-01,  -9.25592363e-01,
                         -9.25305486e-01,  -9.36885238e-01,  -9.43391263e-01,
                         -9.29374397e-01,  -9.35163498e-01,  -9.23393965e-01,
                         -9.30803537e-01,  -9.34983432e-01,  -9.31538045e-01,
                         -9.18700814e-01,  -9.25036192e-01,  -9.25486684e-01,
                         -9.28826809e-01,  -9.18259680e-01,  -9.38793719e-01,
                         -9.38116968e-01,  -9.45424378e-01,  -9.22816634e-01,
                         -9.34665143e-01,  -9.21152890e-01,  -9.48903680e-01,
                         -9.41154718e-01,  -9.39182818e-01,  -1.36536453e-02,
                          6.90177176e-03,  -1.43986112e-02,  -7.66401505e-03,
                         -8.79513007e-03,  -2.62019434e-03,  -1.11372061e-02,
                          9.57612006e-04,  -6.33274904e-03,   1.99352414e-03,
                          1.27296876e-02,   3.66009830e-04,   1.96266291e-03,
                          1.32624852e-03,  -7.79454270e-03,   1.59952436e-02,
                          8.71120300e-03,   8.45811050e-03,  -3.28600756e-03,
                         -1.16487136e-02,   5.75538166e-03,  -1.25645353e-02,
                         -8.95016361e-03,  -1.14216385e-02,  -1.34282885e-02,
                          7.44759850e-03,  -1.87040493e-03,   3.13005201e-03,
                         -4.88011725e-03,  -1.71951565e-03,   6.36207126e-03,
                         -1.17900250e-02,   2.29061972e-02,  -4.42112854e-04,
                         -5.16036991e-03,  -4.02360596e-03,  -2.45650653e-02,
                          1.53531181e-03,  -1.77517459e-02,  -2.82292324e-03,
                         -1.78939458e-02,   7.08279433e-03,  -2.65024463e-03,
                          6.81043556e-03,   9.81631503e-03,   7.88051449e-03,
                         -4.40729549e-03,   1.09279770e-02,  -9.29579437e-01,
                         -9.35818732e-01,  -9.28094029e-01,  -9.11131442e-01,
                         -9.31375265e-01,  -9.24489081e-01,  -9.34157550e-01,
                         -9.33004379e-01,  -9.37965393e-01,  -9.34241593e-01,
                         -9.31265354e-01,  -9.28557456e-01,  -9.19931054e-01,
                         -9.18306053e-01,  -9.22180712e-01,  -9.32535589e-01,
                         -9.26853955e-01,  -9.24620390e-01,  -9.35279906e-01,
                         -9.38829064e-01,  -9.30792093e-01,  -9.20739532e-01,
                         -9.29305732e-01,  -9.12051678e-01,  -9.23937321e-01,
                         -9.35462236e-01,  -9.31278706e-01,  -9.20811594e-01,
                         -9.34560716e-01,  -9.22459483e-01,  -9.31643367e-01,
                         -9.35185134e-01,  -9.39023018e-01,  -9.24636781e-01,
                         -9.35635507e-01,  -9.45054710e-01,  -9.27463770e-01,
                         -9.32054460e-01,  -9.49760854e-01,  -9.30101633e-01,
                         -9.33125257e-01,  -9.37498868e-01,  -9.35040414e-01,
                         -9.65353966e-01,  -9.28706765e-01,  -9.27508414e-01,
                         -9.45680559e-01,  -9.39247668e-01,  -9.37160015e-01,
                         -9.11970615e-01,  -9.22966957e-01,  -9.37069714e-01,
                         -9.35441494e-01,  -9.32060659e-01,  -9.45199192e-01,
                         -9.27130282e-01,  -9.41594481e-01,  -9.21103597e-01,
                         -9.45132017e-01,  -9.34866309e-01,  -9.31603909e-01,
                         -9.38970983e-01,  -9.30517972e-01,  -9.20195460e-01,
                         -9.22565162e-01,  -9.30573523e-01,  -9.20415342e-01,
                         -9.19544876e-01,  -9.24594223e-01,  -9.12720919e-01,
                         -9.27444994e-01,  -9.39268768e-01,  -9.27022994e-01,
                         -9.20967400e-01,  -9.34086323e-01,  -9.21357512e-01,
                         -9.29828644e-01,  -9.51281786e-01,  -9.33900356e-01,
                         -9.37758565e-01,  -9.33539331e-01,  -9.55102742e-01,
                         -9.25241888e-01,  -9.36679065e-01,  -9.19853866e-01,
                         -9.40293312e-01,  -9.38395739e-01,  -9.26013172e-01,
                         -9.35483038e-01,  -9.29842532e-01,  -9.47387218e-01,
                         -9.30472970e-01,  -9.38656867e-01,  -9.20798719e-01,
                         -9.30586755e-01,  -9.33703542e-01,  -9.43287075e-01,
                         -9.52460706e-01,  -9.39146459e-01,  -9.43181932e-01,
                         -9.45670366e-01,  -9.29331303e-01,  -9.41839099e-01,
                         -9.38320994e-01,  -9.43937182e-01,  -9.35555816e-01,
                         -9.19198096e-01,  -9.35897350e-01,  -9.35755968e-01,
                         -9.34733033e-01,  -9.39847350e-01,  -9.55339491e-01,
                         -9.37727213e-01,  -9.47148025e-01,  -9.27825034e-01,
                         -9.35803771e-01,  -9.33123946e-01,  -9.28412497e-01,
                         -9.47517037e-01,  -9.23511565e-01,  -9.34297800e-01,
                         -9.32253242e-01,  -9.30641830e-01,  -9.42991436e-01,
                         -9.41205740e-01,  -9.28416491e-01,  -9.44481552e-01,
                         -9.50488269e-01,  -9.37108457e-01,  -9.49014366e-01,
                         -9.45987284e-01,  -9.43962038e-01,  -9.42562103e-01,
                         -9.41487134e-01,  -9.41464424e-01,  -9.39471245e-01,
                         -9.15999711e-01,  -9.32353199e-01,  -9.34469223e-01,
                         -9.22440648e-01,  -9.28489387e-01,  -9.41590905e-01,
                         -9.31504905e-01,  -9.40976381e-01,  -9.28772330e-01,
                         -9.21689928e-01,  -9.41945016e-01,  -9.31197941e-01,
                         -9.38024342e-01,  -9.32396293e-01,  -9.34045613e-01,
                         -9.37525511e-01,  -9.25036550e-01,  -9.40356314e-01,
                         -9.38560843e-01,  -9.31175351e-01,  -9.28384066e-01,
                         -9.34457481e-01,  -9.28474069e-01,  -9.34300125e-01,
                         -9.25216913e-01,  -9.27772582e-01,  -9.34540987e-01,
                         -9.36715782e-01,  -9.43334937e-01,  -9.39371228e-01,
                         -9.25594032e-01,  -9.30343688e-01,  -9.30822730e-01,
                         -9.31621313e-01,  -9.33594882e-01,  -9.37311947e-01,
                         -9.33640540e-01,  -9.28304493e-01,  -9.24858630e-01,
                         -9.25885856e-01,  -9.38672602e-01,  -9.28175688e-01,
                         -9.33442414e-01,  -9.33365107e-01,  -9.33987856e-01,
                         -9.35186863e-01,  -9.23752189e-01,  -9.29840267e-01,
                         -9.29699302e-01,  -9.36250150e-01,  -9.29812491e-01,
                         -9.37117219e-01,  -9.32083845e-01,  -9.40132022e-01,
                         -9.31676090e-01,  -9.37893391e-01,  -9.34907436e-01,
                         -9.29554284e-01,  -9.35172141e-01,  -9.34997916e-01,
                         -9.41714346e-01,  -9.44337368e-01,  -9.34851110e-01,
                         -9.30931687e-01,  -9.44080770e-01,  -9.41446543e-01,
                         -9.37056541e-01,  -9.34328496e-01,  -9.35801506e-01,
                         -9.33602870e-01,  -9.36514854e-01,  -9.28796172e-01,
                         -9.22941864e-01,  -9.25088882e-01,  -9.31585610e-01,
                         -9.31172550e-01,  -9.25546229e-01,  -9.29824948e-01,
                         -9.29060757e-01,  -9.30657148e-01,  -9.30852771e-01,
                         -9.46115136e-01,  -9.33903694e-01,  -9.21847224e-01,
                         -9.31154013e-01,  -9.25840616e-01,  -9.35934722e-01,
                         -9.31571186e-01,  -9.34095323e-01,  -9.30217803e-01,
                         -9.36305940e-01,  -9.32308733e-01,  -9.37880099e-01,
                         -9.33500767e-01,  -9.33875084e-01,  -9.29699183e-01,
                         -9.38165665e-01,  -9.26691413e-01,  -9.45143521e-01,
                         -9.27884758e-01,  -9.32173669e-01,  -9.52087939e-01,
                         -9.32465613e-01,  -9.34216321e-01,  -9.29109037e-01,
                         -9.29547489e-01,  -9.29460764e-01,  -9.30195451e-01,
                         -9.30446804e-01,  -9.33055520e-01,  -9.32407200e-01,
                         -9.40001488e-01,  -9.38611269e-01,  -9.38437402e-01,
                         -9.32949722e-01,  -9.24988091e-01,  -9.32596326e-01,
                         -9.43639338e-01,  -9.37383533e-01,  -9.31713820e-01,
                         -9.32424128e-01,  -9.31774676e-01,  -9.34972525e-01,
                         -9.35508370e-01,  -9.40655470e-01,  -9.39855993e-01,
                         -9.38664377e-01,  -9.35177565e-01,  -9.39447463e-01,
                         -9.39025760e-01,  -9.39235270e-01,  -9.38310444e-01,
                         -9.39838707e-01,  -9.34433103e-01,  -9.36887085e-01,
                         -9.35711384e-01,  -9.23954487e-01,  -9.27196085e-01,
                         -9.35815752e-01,  -9.33598459e-01,  -9.36081946e-01,
                         -9.38550830e-01,  -9.39918518e-01,  -9.29854751e-01,
                         -9.27028954e-01,  -9.39911783e-01,  -9.37603235e-01,
                         -9.30829704e-01,  -9.35349584e-01,  -9.35404539e-01,
                         -9.40377712e-01,  -9.30749059e-01,  -9.38812912e-01,
                         -9.35962081e-01,  -9.37001646e-01,  -9.34645116e-01,
                         -9.37235296e-01,  -9.41404402e-01,  -9.30015564e-01,
                         -9.30330813e-01,  -9.38605189e-01,  -9.29621041e-01,
                         -9.31517839e-01,  -9.31899846e-01,  -9.30135429e-01,
                         -9.42113638e-01,  -9.24744606e-01,  -9.35410440e-01,
                         -9.32454944e-01,  -9.22278821e-01,  -9.19691443e-01,
                         -9.30489063e-01,  -9.33362484e-01,  -9.29610014e-01,
                         -9.25566435e-01,  -9.34259534e-01,  -9.35820937e-01,
                         -9.28124964e-01,  -9.26752448e-01,  -9.25623238e-01,
                         -9.26490724e-01,  -9.41551983e-01,  -9.36797738e-01,
                         -9.36389685e-01,  -9.45698202e-01,  -9.46049809e-01,
                         -9.25744414e-01,  -9.28030014e-01,  -9.22556996e-01,
                         -9.25563037e-01,  -9.37557638e-01,  -9.38514292e-01,
                         -9.33869302e-01,  -9.36852157e-01,  -9.33685899e-01,
                         -9.32188511e-01,  -9.38003957e-01,  -9.23993170e-01,
                         -9.25910950e-01,  -9.36494589e-01,  -9.30217147e-01,
                         -9.29970264e-01,  -9.36973035e-01,  -9.42026913e-01,
                         -9.31369483e-01,  -9.23198581e-01,  -9.26306486e-01,
                         -9.34067786e-01,  -9.24021959e-01,  -9.29274440e-01,
                         -9.22524571e-01,  -9.36642468e-01,  -9.27470088e-01,
                         -9.22164619e-01,  -9.36767459e-01,  -9.29505348e-01,
                         -9.16458726e-01,  -9.22428787e-01,  -9.43871856e-01,
                         -9.30251420e-01,  -9.47901726e-01,  -9.29559290e-01,
                         -9.45102155e-01,  -9.38461840e-01,  -9.32461500e-01,
                         -9.24412310e-01,  -9.33251143e-01,  -9.36279774e-01,
                         -9.32659566e-01,  -9.29453433e-01,  -9.30612445e-01,
                         -9.32444990e-01,  -9.41586912e-01,  -9.42623079e-01,
                         -9.46336567e-01,  -9.43572462e-01,  -9.36454892e-01,
                         -9.36492264e-01,  -9.19557214e-01,  -9.17544365e-01,
                         -9.28881228e-01,  -9.26233888e-01,  -9.32511389e-01,
                         -9.24615979e-01,  -9.30961311e-01,  -9.29956794e-01,
                         -9.21877265e-01,  -9.21731234e-01,  -9.40513313e-01,
                         -9.49875057e-01,  -9.43708539e-01,  -9.46523070e-01,
                         -9.43427861e-01,  -9.44567025e-01,  -9.31398451e-01,
                         -9.39893723e-01,  -9.28778410e-01,  -9.33484197e-01,
                         -9.42349613e-01,  -9.28300023e-01,  -9.15222645e-01,
                         -9.14280832e-01,  -9.10038054e-01,  -9.31181192e-01,
                         -9.33923125e-01,  -9.29992318e-01,  -9.46742654e-01,
                         -9.38431561e-01,  -9.25588369e-01,  -9.38144922e-01,
                         -9.41475391e-01,  -9.26655889e-01,  -9.17226613e-01,
                         -9.24126387e-01,  -9.31471050e-01,  -9.37161446e-01,
                         -9.34848130e-01,  -9.45133984e-01,  -9.41789985e-01,
                         -9.45491016e-01,  -9.34523880e-01,  -9.30388272e-01,
                         -9.49254870e-01,  -9.32673752e-01,  -9.25558209e-01,
                         -9.38466489e-01,  -9.36672211e-01,  -9.30031538e-01,
                         -9.27613080e-01,  -9.39680815e-01,  -9.26240623e-01,
                         -9.26008224e-01,  -7.26481527e-03,   1.40037909e-02,
                          4.14235890e-03,  -1.05145003e-03,  -4.46395157e-03,
                          1.92095488e-02,   3.46014136e-03,  -1.37011884e-02,
                         -4.89629246e-03,   1.40158914e-03,  -2.78991356e-04,
                         -9.07550100e-03,  -5.01203770e-03,  -4.90168459e-04,
                          6.31303200e-03,   9.23941936e-03,   9.29313712e-03,
                          6.56213891e-03,  -7.66460411e-03,   7.13584712e-04,
                          2.82920222e-03,   6.51114481e-03,   2.69039953e-03,
                          9.69095062e-03,   9.15219262e-03,   8.68075714e-03,
                          1.13196010e-02,   2.01420374e-02,   9.11715999e-03,
                         -2.44526332e-03,   1.71874426e-02,   6.97182445e-03,
                          1.30590075e-03,   2.38033477e-02,   1.08325174e-02,
                          4.57716035e-03,   2.09624972e-02,   1.76634528e-02,
                          1.27772922e-02,   1.39434682e-03,   5.02509484e-03,
                          1.14356587e-02,   1.44239273e-02,   3.58250504e-03,
                          6.63238578e-03,   7.81107182e-03,   1.03693008e-02,
                          1.14069320e-02,   1.04710469e-02,   1.36499163e-02,
                          1.03880269e-02,   2.70323455e-03,   6.84344536e-03,
                          5.24361106e-03,   5.77712944e-03,   1.12394718e-02,
                          6.36882847e-03,   1.61803346e-02,   2.58549768e-02,
                          2.73805996e-03,   5.90733159e-03,   9.26966406e-03,
                          2.18517818e-02,   6.18727924e-03,   9.89314541e-03,
                          1.07163284e-02,   1.99114694e-03,  -2.32815300e-03,
                          1.17505428e-04,  -6.76257419e-04,   5.50550502e-03,
                         -9.60535277e-03,  -2.96709687e-03,  -3.15618672e-04,
                         -1.82759576e-03,   8.91201198e-03,  -1.38326371e-02,
                         -1.26212612e-02,   2.92378850e-03,  -6.34137727e-03,
                          3.42016661e-04,   3.04918084e-03,  -6.22462714e-03,
                         -1.05388397e-02,   3.97192594e-03,   8.06250796e-03,
                         -5.87979006e-03,  -4.27355897e-03,   2.38113594e-03,
                         -6.61855984e-06,  -1.58337299e-02,  -6.12837030e-04,
                          3.24123004e-03,   8.17999244e-03,  -1.70490635e-03,
                         -1.41204032e-03,  -8.36788304e-03,   6.41626073e-04,
                          1.41014066e-02,   1.46984006e-03,  -1.83649434e-04,
                          2.49495442e-05,  -2.77989893e-03,   7.31640542e-03,
                          1.10130059e-03,   2.46818922e-03,   7.22072413e-03,
                          1.42904057e-03,   1.08250109e-02,  -1.32870944e-02,
                          1.60861630e-02,   1.40205771e-02,   1.10159516e-02,
                          9.75843240e-03,   2.73848977e-03,   1.36941532e-02,
                          3.43056931e-03,  -8.96159909e-04,   4.96832747e-03,
                          1.17010800e-02,   7.34704500e-03,   7.65337655e-03,
                         -1.35275046e-03,   2.18091602e-03,   4.46000835e-03,
                         -6.60275808e-04,   1.08423794e-03,  -8.21006368e-04,
                          1.69342197e-02,   4.65627818e-04,   7.57829240e-03,
                          9.73143801e-03,   3.56641947e-03,   1.21630414e-03,
                         -5.60122123e-03,  -1.43545819e-03,   4.24635690e-03,
                         -4.91880288e-04,   1.27013284e-03,   6.81295816e-04,
                          1.08088355e-03,   1.12198098e-02,   7.21249744e-05,
                         -6.40110346e-03,  -3.04875127e-03,  -2.87453411e-04,
                         -2.94166221e-03,   9.90524655e-04,   5.93840750e-03,
                         -1.05615577e-03,   1.19978900e-03,   3.05246585e-03,
                          3.24432785e-03,   5.24807442e-03,  -6.91795431e-04,
                          3.77010484e-03,   7.03315204e-03,   7.29826139e-03,
                         -3.63290310e-03,   1.13898830e-03,   9.23819258e-04,
                          6.61530253e-03,   5.02385432e-03,   1.45316543e-03,
                         -2.64781900e-03,  -6.53200550e-03,  -3.03213205e-03,
                          1.60185783e-03,   1.71742961e-03,   2.51245382e-03,
                         -4.99654841e-03,   1.13681215e-03,   1.27508806e-03,
                          9.29721259e-03,  -3.43194843e-04,  -1.43190846e-02,
                          1.84587464e-02,   3.93858366e-03,   8.09385441e-03,
                          1.17926800e-03,   4.14224807e-03,   5.56603540e-04,
                         -4.83432086e-04,   1.85668969e-03,   5.44886291e-03,
                         -2.43221340e-03,  -2.03122548e-03,  -5.42233977e-03,
                         -2.23305356e-03,   8.49892385e-04,   5.68998605e-03,
                          1.02896080e-03,   1.52215781e-02,   8.58658645e-03,
                          3.66541394e-03,  -1.84257235e-03,   2.28801189e-04,
                          7.60594476e-03,   5.13740210e-03,  -4.53753909e-03,
                         -6.25902973e-03,  -8.45347438e-03,  -2.17138650e-03,
                         -1.78559730e-03,  -4.52225748e-03,  -2.20773672e-03,
                         -1.13926893e-02,  -1.67629477e-02,  -9.51622054e-03,
                         -9.45700705e-03,  -1.00331195e-02,  -2.35827942e-03,
                          7.78633694e-05,  -4.71944176e-03,  -7.99795054e-03,
                         -4.37258091e-03,  -3.04851565e-03,   4.50221472e-04,
                          1.83801912e-03,   8.17498192e-03,   2.62112287e-03,
                         -6.27982803e-03,  -1.01707308e-02,  -1.51275331e-03,
                         -4.94476408e-03,  -2.63536494e-04,   9.60845780e-03,
                         -1.55687926e-03,   1.55184779e-03,   4.97448165e-03,
                          8.16731621e-03,   3.22767417e-03,   5.67941740e-03,
                         -1.20674714e-03,  -5.00631332e-03,  -6.01713732e-03,
                          4.24050773e-03,  -3.75108095e-03,   6.50084624e-03,
                         -5.76848723e-03,  -1.44155417e-02,   3.93019104e-03,
                         -1.49004227e-05,   4.32562723e-04,  -4.16141748e-03,
                         -6.63781259e-03,   4.45051352e-03,   1.07854800e-02,
                          4.08751145e-03,  -1.27518503e-03,  -6.96789473e-03,
                         -1.23419641e-02,   2.25772592e-03,   1.93796284e-03,
                         -1.06321927e-02,  -1.61883037e-03,   6.09877770e-06,
                         -3.13026685e-04,  -8.56808294e-03,  -2.66999635e-03,
                         -1.16223295e-04,  -1.40217133e-03,  -7.92771752e-05,
                          1.39011932e-03,  -5.46281366e-03,  -1.35584839e-03,
                         -7.25335255e-03,  -1.37060396e-02,  -9.76053905e-03,
                         -5.81090152e-03,   2.08638492e-03,   9.17790458e-03,
                         -3.67675885e-03,   1.77987968e-03,  -9.63804405e-03,
                         -2.29590549e-03,  -6.83495542e-03,  -2.33960897e-03,
                          4.90057573e-04,   9.12420079e-03,   6.29966985e-03,
                          7.48667214e-03,  -3.33908065e-05,   2.31081294e-03,
                         -1.02498066e-02,  -2.27979245e-03,   7.33795203e-03,
                          8.87517701e-04,   3.73115577e-03,  -4.51794680e-04,
                          3.28082358e-03,  -4.53384500e-03,  -4.94541542e-04,
                          3.37522291e-03,  -7.76079856e-03,  -8.73302016e-03,
                         -2.33638613e-03,  -1.09003177e-02,  -4.61680256e-03,
                         -2.26430973e-04,  -1.61386817e-03,   1.72157399e-03,
                         -1.54836872e-03,   9.45742242e-03,   8.60987988e-04,
                         -5.00530144e-03,   6.52921246e-03,   1.92677707e-03,
                         -9.60536674e-03,  -3.27272178e-03,  -2.00957502e-03,
                         -1.07225934e-02,   5.31677576e-03,   6.99622650e-03,
                          3.68681503e-03,   1.16551518e-02,  -2.40673005e-04,
                         -9.17674787e-03,  -1.18178921e-02,  -8.34828429e-03,
                         -1.66785624e-03,  -1.76598970e-02,   5.50906756e-04,
                          1.62235033e-02,   1.92967406e-03,  -7.28866970e-03,
                          3.53327137e-04,  -4.92309977e-04,   1.79895922e-03,
                          1.21731805e-02,   1.16924243e-02,   5.70402713e-03,
                          1.22224074e-02,   2.14042068e-02,   6.10062107e-03,
                          4.18234058e-03,  -9.51977621e-04,   2.77936552e-03,
                          3.78874782e-03,   3.03227076e-04,   1.30668459e-02,
                          4.80357744e-03,   1.04668189e-03,   1.67341512e-02,
                          8.72534048e-03,   3.20887868e-03,   1.37952203e-02,
                          8.14454351e-03,  -5.04664844e-03,   3.33928177e-03,
                          8.73972196e-03,  -1.44820323e-03,  -6.38729136e-04,
                          4.96666413e-03,   7.63708353e-03,  -2.27288273e-03,
                          8.71472992e-03,  -6.64662104e-03,  -5.23832301e-03,
                          1.40279508e-03,  -6.87962922e-04,   1.64943375e-02,
                          1.51517959e-02,   6.24871720e-03,   1.04146609e-02,
                          8.92700255e-03,   5.95157500e-04,  -1.65662821e-02,
                         -2.32381443e-03,   4.09726956e-04,  -6.89064851e-04,
                          8.77171941e-03,   1.09276371e-02,  -5.24878129e-03,
                         -5.06995525e-03,  -9.22456011e-03,   1.47711765e-02,
                          8.10991880e-03,   5.49991243e-03,   6.42131967e-03,
                         -7.88847078e-03,   1.92149612e-03,   4.84764110e-03,
                          1.10040661e-02,   2.96970969e-03,   2.68461951e-03,
                         -4.38264385e-03,   1.04779629e-02,   1.07142143e-02,
                          1.42340409e-02,   8.03231169e-03,  -4.34898306e-03,
                          4.53001261e-03,  -2.13332460e-04,  -1.10703278e-02,
                          3.65139358e-03,  -7.92279723e-04,  -1.17829703e-02,
                          1.39465043e-02,  -4.86551458e-03,  -1.64056141e-02,
                         -3.73812788e-03,  -7.98839331e-03,  -5.55873755e-03,
                         -1.41365640e-02,   3.29726259e-03,  -3.66043788e-03,
                         -2.75640562e-02,   7.27341627e-04,  -3.03189643e-03,
                         -1.16807949e-02,  -4.48903302e-03,   1.53468531e-02,
                         -7.25505734e-03,  -4.64259740e-03,   6.82306988e-03,
                          1.06313545e-02,   2.09470894e-02,   1.06545640e-02,
                         -3.22219217e-03,  -2.00418988e-03,   6.45349780e-03,
                          7.54937157e-03,  -1.60723575e-04,  -4.49926220e-03,
                          2.03041546e-02,   1.77840907e-02,   1.09092854e-02,
                         -7.37387268e-03,  -2.87273224e-03,   2.47550756e-03,
                          6.70126732e-03,   1.24027655e-02,   5.19602699e-03,
                          9.25344694e-03,  -5.11817727e-03,   6.28338335e-03,
                          7.07525434e-03,  -9.36980126e-04,   9.67285503e-03,
                          6.61895471e-03,   5.78621512e-05,  -5.36131067e-03,
                          1.94885745e-03,  -1.11623220e-02,  -5.30612376e-03,
                          2.10480602e-03,   1.23873865e-02,   3.78010538e-03,
                         -6.62151910e-03,  -2.80730892e-03,  -4.40666499e-03,
                         -1.34195909e-02,  -5.09774662e-04,  -2.98884464e-03,
                         -1.12841455e-02,   3.77773540e-03,   1.26541452e-02,
                          4.65828786e-03,   4.89471946e-03,   1.38271553e-02,
                          3.10239964e-03,   3.00724413e-02,   1.56440567e-02,
                          1.50703639e-02,   1.06878439e-02,  -8.21094401e-03,
                         -1.30315488e-02,  -9.26515281e-01,  -9.35450375e-01,
                         -9.23032880e-01,  -9.27037358e-01,  -9.37709868e-01,
                         -9.40641761e-01,  -9.48498964e-01,  -9.45864201e-01,
                         -9.52664554e-01,  -9.29023683e-01,  -9.41053689e-01,
                         -9.33557630e-01,  -1.06809204e-02,   7.78171467e-03,
                          6.28800597e-03,   1.59262642e-02,   5.59963426e-03,
                          2.45669782e-02,   2.21299957e-02,   4.93860990e-03,
                          1.06266560e-02,  -3.67924687e-03,  -2.05257814e-03,
                         -8.74800328e-03,  -1.58846546e-02,  -1.94371156e-02,
                         -1.87075157e-02,  -2.84907855e-02,  -1.90258992e-03,
                         -9.28391237e-03,  -2.33361963e-02,  -9.63573623e-03,
                         -2.03385926e-03,   1.24850431e-02,   4.84881923e-03,
                         -1.03648799e-02,   1.31939081e-02,  -2.15382427e-02,
                         -8.71516671e-03,  -1.68662593e-02,   1.24641759e-02,
                         -6.03277236e-03,  -7.43280211e-03,  -7.61328440e-04,
                         -1.85690597e-02,  -3.15107196e-03,   1.15153790e-02,
                          3.16072605e-03,   7.93319254e-04,   1.05061010e-02,
                          5.12355519e-03,   1.19353766e-02,   8.17196723e-03,
                         -7.64655008e-04,   6.21850742e-03,  -9.37021745e-04,
                         -8.62051826e-03,  -1.79881845e-02,  -2.93557309e-02,
                          1.51965600e-02,   1.31090451e-03,   6.58046314e-03,
                          1.59071982e-02,  -1.11713801e-02,   2.38240440e-03,
                          1.35165062e-02,   1.64856818e-02,  -2.11849358e-04,
                          3.65573214e-04,   1.02919992e-02,   1.14352219e-02,
                          7.35031581e-03,   1.25009483e-02,  -2.60716565e-02,
                         -2.31412575e-02,  -1.03085348e-02,  -9.11661029e-01,
                         -9.24512148e-01,  -9.54148650e-01,  -9.33567405e-01,
                         -9.48394060e-01,  -9.26333070e-01,  -9.38479245e-01,
                         -9.47723210e-01,  -9.33649123e-01,  -9.33160424e-01,
                         -9.28963065e-01,  -9.39980626e-01,  -9.46118414e-01,
                         -9.33495402e-01,  -9.23085332e-01,  -9.43507731e-01,
                         -9.35197949e-01,  -9.55669105e-01,  -9.07247722e-01,
                         -9.52950597e-01,  -9.34588194e-01,  -9.41159010e-01,
                         -9.53026593e-01,  -9.31680083e-01,  -9.10493135e-01,
                         -9.18983877e-01,  -9.28533673e-01,  -9.32028711e-01,
                         -9.35360432e-01,  -9.43289042e-01,  -9.59600627e-01,
                         -9.24485147e-01,  -9.47594345e-01,  -9.66854393e-01,
                         -9.43285286e-01,  -9.34449255e-01,  -9.44330513e-01,
                         -9.28924441e-01,  -9.16161895e-01,  -9.46360707e-01,
                         -9.45300877e-01,  -9.61265385e-01,  -9.32075262e-01,
                         -9.48437214e-01,  -9.55221593e-01,  -9.55672920e-01,
                         -9.41799402e-01,  -9.32088375e-01,  -9.41455781e-01,
                         -9.45736349e-01,  -9.55236912e-01,  -9.34784591e-01,
                         -9.34125364e-01,  -9.46388364e-01,  -9.45405245e-01,
                         -9.23676372e-01,  -9.15767670e-01,  -9.18440223e-01,
                         -9.34705079e-01,  -9.42828774e-01,  -9.18542564e-01,
                         -9.33802545e-01,  -9.38818336e-01,  -9.53138232e-01,
                         -9.40975428e-01,  -9.32086349e-01,  -9.41672742e-01,
                         -9.30994391e-01,  -9.57767785e-01,  -9.34273303e-01,
                         -9.48276281e-01,  -9.44229245e-01,  -9.66761351e-01,
                         -9.42257583e-01,  -9.39051986e-01,  -9.24075603e-01,
                         -9.34123456e-01,  -9.32708800e-01,  -9.29790914e-01,
                         -9.30155039e-01,  -9.47741389e-01,  -9.31728542e-01,
                         -9.45741653e-01,  -9.20189798e-01,  -9.52401400e-01,
                         -9.37334418e-01,  -9.35709059e-01,  -9.50308859e-01,
                         -9.36095834e-01,  -9.36712444e-01,  -9.16393876e-01,
                         -9.28339779e-01,  -9.08199608e-01,  -9.32424784e-01,
                         -9.36680734e-01,  -9.28224325e-01,  -9.18747783e-01,
                         -9.20807600e-01,  -9.30566788e-01,  -9.46579516e-01,
                         -9.26856041e-01,  -9.43506062e-01,  -9.54460025e-01,
                         -9.50876832e-01,  -9.39126253e-01,  -9.45064366e-01,
                         -9.32101786e-01,  -9.42375779e-01,  -9.33516383e-01,
                         -9.40625548e-01,  -9.39859986e-01,  -9.27728534e-01,
                         -9.17213619e-01,  -9.29428518e-01,  -9.36091840e-01,
                         -9.40221608e-01,  -9.50243890e-01,  -9.41450238e-01,
                         -9.35330510e-01,  -9.46390808e-01,  -9.35944796e-01,
                         -9.38787401e-01,  -9.23215568e-01,  -9.45534170e-01,
                         -9.49773252e-01,  -9.28341866e-01,  -9.34296250e-01,
                         -9.47572947e-01,  -9.53250110e-01,  -9.53891039e-01,
                         -9.16493356e-01,  -9.33346152e-01,  -9.41721141e-01,
                         -9.36081171e-01,  -9.27321255e-01,  -9.37900841e-01,
                         -9.42085624e-01,  -9.26652730e-01,  -9.41348970e-01,
                         -9.34472203e-01,  -9.34353590e-01,  -9.36335683e-01,
                         -9.49303448e-01,  -9.52973247e-01,  -9.54420984e-01,
                         -9.46527064e-01,  -9.45959449e-01,  -9.54493701e-01,
                         -9.51110661e-01,  -9.42354620e-01,  -9.46194410e-01,
                         -9.43160951e-01,  -9.44962561e-01,  -9.21204686e-01,
                         -9.45461571e-01,  -9.36566234e-01,  -9.27127182e-01,
                         -9.40108180e-01,  -9.32197809e-01,  -9.38155115e-01,
                         -9.38576937e-01,  -9.32771981e-01,  -9.33631778e-01,
                         -9.37589884e-01,  -9.33190167e-01,  -9.52479243e-01,
                         -9.44506288e-01,  -9.34173942e-01,  -9.24793184e-01,
                         -9.32009220e-01,  -9.50402677e-01,  -9.33437288e-01,
                         -9.24625039e-01,  -9.35441136e-01,  -9.08413649e-01,
                         -9.41334426e-01,  -9.42207456e-01,  -9.40268695e-01,
                         -9.37715352e-01,  -9.31036711e-01,  -9.21557903e-01,
                         -9.23229039e-01,  -9.26994979e-01,  -9.28952575e-01,
                         -9.28222358e-01,  -9.30095136e-01,  -9.43638027e-01,
                         -9.39842463e-01,  -9.30548131e-01,  -9.33198810e-01,
                         -9.42022085e-01,  -9.43390727e-01,  -9.48304772e-01,
                         -9.48214233e-01,  -9.37601089e-01,  -9.28766906e-01,
                         -9.46270466e-01,  -9.21881676e-01,  -9.10249770e-01,
                         -9.18900967e-01,  -9.16839123e-01,  -9.22298610e-01,
                         -9.35167491e-01,  -9.31359172e-01,  -9.31528747e-01,
                         -9.31164443e-01,  -9.19737041e-01,  -9.23943400e-01,
                         -9.12582695e-01,  -9.18637991e-01,  -9.31651235e-01,
                         -9.31059003e-01,  -9.15578008e-01,  -9.37656105e-01,
                         -9.36318815e-01,  -9.20364559e-01,  -9.33953464e-01,
                         -9.49130476e-01,  -9.20917451e-01,  -9.28305387e-01,
                         -9.34588432e-01,  -9.34074700e-01,  -9.21390653e-01,
                         -9.25454080e-01,  -9.24496174e-01,  -9.34953570e-01,
                         -9.16120470e-01,  -9.17194068e-01,  -9.26039755e-01,
                         -9.30230558e-01,  -9.38881397e-01,  -9.27908182e-01,
                         -9.19333637e-01,  -9.37623978e-01,  -9.19902861e-01,
                         -9.40989375e-01,  -9.30791795e-01,  -9.13608551e-01,
                         -9.43319976e-01,  -9.35289681e-01,  -9.34119821e-01,
                         -9.25478876e-01,  -9.42098260e-01,  -9.04822052e-01,
                         -9.22924697e-01,  -9.15143371e-01,  -9.43535328e-01,
                         -9.44331288e-01,  -9.37364161e-01,  -9.29686546e-01,
                         -9.39011037e-01,  -9.22920883e-01,  -9.44013834e-01,
                         -9.28036273e-01,  -9.28315997e-01,  -9.42103922e-01,
                         -9.38867331e-01,  -9.29011583e-01,  -9.48524892e-01,
                         -9.27796304e-01,  -9.28062379e-01,  -9.20618892e-01,
                         -9.25768375e-01,  -9.30480540e-01,  -9.22820449e-01,
                         -9.10365164e-01,  -9.11860406e-01,  -9.25300181e-01,
                         -9.32605684e-01,  -9.33033347e-01,  -9.33391929e-01,
                         -9.29912567e-01,  -9.41418588e-01,  -9.44155514e-01,
                         -9.31246400e-01,  -9.46653366e-01,  -9.41189766e-01,
                         -9.34168637e-01,  -9.32812154e-01,  -9.56527948e-01,
                         -9.26342010e-01,  -9.25952077e-01,  -9.40461636e-01,
                         -9.25331771e-01,  -9.40051138e-01,  -9.15378869e-01,
                         -9.42358851e-01,  -9.33340728e-01,  -9.37907398e-01,
                         -9.32649374e-01,  -9.41749752e-01,  -9.33242381e-01,
                         -9.38489854e-01,  -9.22727406e-01,  -9.42742586e-01,
                         -9.25114810e-01,  -9.46857631e-01,  -9.36547935e-01,
                         -8.97330284e-01,  -9.18366730e-01,  -9.29216981e-01,
                         -9.49791551e-01,  -9.64863002e-01,  -9.40743327e-01,
                         -9.58335757e-01,  -9.54898477e-01,  -9.40323710e-01,
                         -9.25706029e-01,  -9.30756867e-01,  -9.15353894e-01,
                         -9.32646453e-01,  -9.21624660e-01,  -9.30230439e-01,
                         -9.21597421e-01,  -9.23610032e-01,  -9.42034364e-01,
                         -9.35822487e-01,  -9.22702849e-01,  -9.54622328e-01,
                         -9.17726755e-01,  -9.51639175e-01,  -9.60731089e-01,
                         -9.54179347e-01,  -9.27080214e-01,  -9.32389319e-01,
                         -9.23726797e-01,  -9.44411337e-01,  -9.51841116e-01,
                         -9.59397674e-01,  -9.62970257e-01,  -9.49326754e-01,
                         -9.29690719e-01,  -9.55171108e-01,  -9.44021881e-01,
                         -9.37966049e-01,  -9.24266398e-01,  -9.52844739e-01,
                         -9.42699134e-01,  -9.57276225e-01,  -9.57294405e-01,
                         -9.73903120e-01,  -9.33887839e-01,  -9.35568213e-01,
                         -9.34082687e-01,  -9.36199844e-01,  -9.22063172e-01,
                         -9.18874323e-01,  -9.30321395e-01,  -9.06809211e-01,
                         -9.08277512e-01,  -9.35591161e-01,  -9.34094012e-01,
                         -9.43443835e-01,  -9.34095562e-01,  -9.37925100e-01,
                         -9.32274640e-01,  -9.08441842e-01,  -9.37069833e-01,
                         -9.24605012e-01,  -9.35463011e-01,  -9.44120049e-01,
                         -9.13313448e-01,  -9.39546406e-01,  -8.82262647e-01,
                         -6.52685622e-03,   2.26758923e-02,  -1.77669176e-03,
                          7.33709987e-03,  -1.68485586e-02,  -7.61830900e-03,
                          2.70480081e-03,  -3.28439957e-04,  -1.43876607e-02,
                         -5.49388991e-04,  -2.25065611e-02,  -1.70002244e-02,
                         -2.90057510e-02,  -1.27655454e-02,   1.67611043e-03,
                         -2.31344718e-02,  -1.73714124e-02,   1.02018407e-02,
                         -6.87352335e-03,  -4.45605814e-03,  -3.09597645e-02,
                         -4.21501091e-03,  -2.80789798e-03,   4.65048430e-03,
                          2.23279721e-03,  -1.36241913e-02,   3.47879808e-03,
                          5.40728727e-03,  -3.05572315e-03,  -7.99540710e-03,
                          2.26900727e-02,   1.39597971e-02,   5.73097263e-03,
                          1.07040824e-02,  -7.89034925e-03,  -1.21658416e-02,
                          2.97464263e-02,   1.42875649e-02,  -1.73451658e-02,
                          8.83432198e-03,   5.86940115e-03,   1.05346953e-02,
                          1.33007197e-02,  -1.10723998e-03,   1.76546164e-02,
                          2.24416163e-02,   1.29121309e-02,  -4.98071918e-03,
                         -4.14881809e-03,  -2.81773638e-02,  -6.35177270e-03,
                          5.14989113e-03,  -6.08491655e-06,   1.19618028e-02,
                          1.71096493e-02,   1.14621948e-02,  -2.11852812e-03,
                         -5.17904712e-03,   1.32019548e-02,   6.37340266e-03,
                          2.61765765e-03,   2.46546958e-02,   4.47414641e-04,
                         -9.64235421e-03,   1.33405076e-02,   6.78094663e-03,
                          2.09146485e-04,   3.71455052e-03,  -1.07941292e-02,
                         -1.37892114e-02,  -3.08188563e-03,   7.94994365e-03,
                         -7.13109272e-03,  -2.18936894e-02,  -2.02744026e-02,
                         -7.25295022e-03,  -3.80642735e-03,   2.39286921e-04,
                         -3.08986939e-03,  -1.35507835e-02,  -2.14257054e-02,
                         -1.25266816e-02,  -1.64546613e-02,   6.86863018e-03,
                          2.30135564e-02,  -1.29775060e-02,  -1.50497872e-02,
                          1.74783338e-02,   1.18519347e-02,  -2.77916994e-02,
                          5.44122560e-03,   1.77575126e-02,   8.56520608e-03,
                         -6.68670656e-03,  -1.08951190e-03,   3.00922012e-03,
                          6.48056809e-03,  -1.98415411e-03,   5.66306151e-03,
                          2.27665971e-03,  -7.67163816e-04,  -1.22645861e-02,
                         -1.16538629e-03,  -8.66500475e-03,  -2.55304528e-03,
                          1.02035317e-03,  -8.47811904e-03,   1.03392508e-02,
                          3.23687075e-03,  -1.79922953e-03,   2.71355882e-02,
                          4.07750048e-02,   1.42172212e-02,   7.59438472e-03,
                          1.49729289e-02,   4.74017765e-03,   1.79593135e-02,
                          1.10019380e-02,  -9.10724886e-03,  -9.74170212e-03,
                          7.66248349e-03,   1.19834533e-02,   3.49459960e-03,
                          1.80787165e-02,   1.72821898e-02,   5.87712880e-03,
                         -2.30922597e-03,  -6.27439469e-03,  -1.73709057e-02,
                         -1.81242153e-02,  -8.10583681e-03,  -5.69995912e-03,
                          1.94930714e-02,  -3.61378212e-03,   2.04932084e-03,
                          1.14374952e-02,  -5.35375657e-05,   1.59843210e-02,
                          7.42512289e-04,   2.75734055e-04,   9.73480660e-03,
                         -2.59453082e-03,  -1.12051042e-02,  -5.48972469e-03,
                         -2.02458836e-02,   6.61599543e-03,  -1.39532890e-02,
                         -1.30381882e-02,  -8.65483750e-03,  -3.72760743e-03,
                          9.07166116e-03,   1.26459403e-02,   7.37961102e-03,
                          1.06424773e-02,   8.98273010e-03,  -6.28055586e-03,
                         -4.39992128e-03,   3.76796350e-03,  -5.36442921e-03,
                          1.36855873e-03,   1.09599745e-02,   1.15147140e-02,
                         -5.60887950e-03,  -1.67461345e-03,  -2.43646163e-03,
                         -3.71624157e-03,   9.53699835e-03,  -1.03435956e-03,
                         -1.73865613e-02,  -1.08487615e-02,  -1.32691383e-03,
                         -7.99014699e-03,  -8.69189482e-03,  -3.63591098e-04,
                         -8.16773251e-03,  -3.82972741e-03,  -1.13061219e-02,
                         -1.70658354e-03,   1.21878526e-04,  -2.46331003e-03,
                         -5.19098155e-03,  -5.20731648e-03,  -4.69127670e-03,
                         -2.45054415e-03,  -1.41713407e-03,   4.52776020e-03,
                          6.06482523e-03,  -2.88245548e-03,  -1.56102721e-02,
                         -5.96894277e-03,  -2.44436227e-03,  -2.42485316e-03,
                         -8.55700055e-05,  -2.80758622e-03,  -1.98145816e-03,
                         -1.51399169e-02,  -8.01168662e-03,  -8.02894402e-03,
                         -1.37264084e-04,  -1.31010753e-03,  -2.67682970e-03,
                         -6.72654295e-03,  -5.84448641e-03,  -5.37649496e-03,
                         -4.70632967e-03,  -1.60272408e-03,  -4.46035468e-04,
                         -3.84311704e-03,  -2.30697356e-03,   1.94752682e-03,
                          5.34582790e-03,   1.28056584e-02,   5.39271254e-03,
                          8.72773863e-03,  -2.63179583e-03,  -4.10751300e-03,
                          2.33862479e-03,  -2.10664250e-04,   3.18848237e-04,
                         -2.88496446e-03,  -5.16659999e-03,  -2.64932984e-03,
                          1.65603298e-03,   3.12104938e-04,  -2.55615014e-04,
                         -2.81173736e-03,  -4.08342946e-03,  -2.22137570e-03,
                         -2.49172491e-03,  -1.13426871e-03,   2.24612444e-03,
                          2.55247694e-03,   4.65765735e-03,   1.51508884e-03,
                         -1.62425695e-03,  -2.09040451e-03,  -1.60700013e-03,
                         -2.47146026e-03,  -6.07105612e-04,  -1.72160869e-03,
                         -2.34293542e-03,   2.22350331e-03,   2.09081336e-03,
                         -2.19686981e-03,   2.63099879e-04,   3.90391069e-05,
                         -5.67179406e-04,  -2.13942345e-04,  -4.38619929e-04,
                          5.23067196e-04,   9.99936135e-04,  -3.27919493e-03,
                         -1.23113522e-03,   9.85694118e-04,   1.73122113e-04,
                          1.14862155e-03,   8.50758690e-04,  -2.38925149e-03,
                          6.60525344e-04,   4.47975984e-03,   2.20800703e-03,
                          1.96983595e-03,   4.45853220e-03,   4.14274726e-03,
                         -1.24654861e-03,   1.51291271e-04,  -2.04132311e-03,
                         -2.05748505e-03,  -3.67908768e-04,  -2.75472086e-03,
                          1.29384873e-03,   4.90464363e-03,   1.88148674e-03,
                         -4.58392431e-04,   1.35718597e-04,   6.18802756e-03,
                         -2.20651692e-03,   5.37655782e-04,  -1.43351068e-03,
                         -4.42625722e-04,   4.51094704e-04,  -7.88918464e-04,
                         -4.79727052e-03,  -1.06295319e-02,  -8.39220919e-03,
                         -1.27907307e-03,  -1.06831873e-03,  -4.86897305e-03,
                         -6.35735167e-04,  -1.87789672e-03,  -1.78514689e-03,
                         -2.33670510e-03,  -2.28429027e-03,   2.55511055e-04,
                         -2.11940147e-03,  -4.82025207e-04,   3.14710778e-05,
                         -2.47970060e-03,  -1.03977229e-03,  -1.33226404e-03,
                         -3.42820608e-03,  -1.22873043e-03,  -3.29673581e-04,
                         -7.12288031e-03,  -1.94228045e-03,   2.31076451e-03,
                         -1.17676600e-03,   1.32387830e-03,  -6.55116141e-03,
                         -1.83563505e-03,  -4.11510840e-03,  -4.78587020e-03,
                          1.18526968e-03,   3.61549389e-03,  -5.19268634e-03,
                          1.09647703e-03,   6.94404729e-03,  -3.97967407e-03,
                          2.19397293e-03,   3.47524276e-03,  -4.20849631e-03,
                         -4.75011620e-04,   7.45301787e-03,   5.96259441e-03,
                          4.29343525e-03,   2.53103417e-03,   6.99072407e-05,
                          8.39898712e-05,   5.98067604e-03,  -7.83237629e-03,
                          7.17980647e-03,  -8.98850989e-03,   1.07301748e-03,
                         -5.48432581e-04,  -3.12524918e-03,   4.66225902e-03,
                         -5.13733970e-03,  -1.57249358e-03,   8.42740155e-06,
                          3.87565535e-03,   9.09542572e-03,   1.49189057e-02,
                          3.27388616e-03,   5.37257968e-03,   1.28713241e-02,
                          3.33267706e-03,   4.79232229e-04,   1.42968586e-02,
                          6.91656805e-06,   2.24485598e-03,   7.64219090e-03,
                          7.81677570e-03,   1.14352076e-06,   7.91068282e-03,
                         -7.64932251e-04,   1.12857181e-03,   4.89677768e-03,
                          1.18706468e-03,   1.05957594e-02,  -1.29961490e-03,
                         -3.28124617e-03,   5.04866522e-03,   1.41872806e-04,
                         -1.50221901e-03,   3.48211778e-03,   3.52717959e-03,
                         -1.43327506e-03,   4.05659480e-03,   2.91140401e-03,
                          4.08192584e-03,   7.46853510e-03,   3.29376268e-03,
                          4.83887410e-03,   3.30269593e-03,   1.96801312e-03,
                          4.00038232e-04,  -7.70057971e-03,   5.28531848e-03,
                          2.33378727e-03,  -2.57249200e-03,  -1.38500948e-02,
                         -6.44572871e-03,  -1.93695794e-03,   1.00941700e-03,
                         -6.89583225e-03,   4.47663432e-03,  -6.01561926e-03,
                         -9.43281967e-03,  -3.11522781e-05,  -1.34337358e-02,
                         -1.16900466e-02,  -2.16546794e-03,   1.84253287e-02,
                          4.29219473e-03,  -4.65648598e-04,   4.65438608e-03,
                         -4.93761897e-03,   2.30713977e-05,   7.64478324e-03,
                         -3.46130575e-03,   4.93887346e-03,  -3.46424436e-04,
                         -1.19246345e-03,  -3.34771606e-03,   1.10086957e-02,
                         -4.64180019e-03,  -8.87553673e-03,  -1.25810085e-02,
                         -5.80654200e-03,   5.22473967e-03,   1.82312354e-02,
                          6.24424720e-04,  -7.59211183e-03,  -2.18608603e-03,
                         -6.32942235e-03,  -8.15252680e-03,  -9.66909248e-03,
                          6.52915740e-04,   4.86500189e-03,   4.40550735e-03,
                         -4.35717450e-03,   9.11878131e-04,  -2.71191145e-03,
                          1.09814038e-03,   1.44942303e-03,   8.74184258e-03,
                          3.46536702e-03,  -7.44050849e-05,  -8.61687993e-04,
                          6.42017601e-03,   5.40001690e-03,   7.07406225e-03,
                          5.68572374e-04,  -9.62965097e-03,   2.00660876e-03,
                          1.07271466e-02,   5.94623899e-03,   8.85480084e-03,
                         -3.96401156e-03,   7.84988923e-04,   2.30224011e-03,
                         -1.60552468e-02,  -3.85306915e-03,  -4.70691174e-03,
                         -5.22485049e-03,   5.18121663e-03,  -5.17165242e-03,
                         -3.16181430e-03,   1.10563841e-02,   2.26223070e-04,
                         -1.16089126e-02,  -7.93220196e-03,  -3.06729693e-03,
                         -1.50560797e-03,   6.28896244e-03,   1.61817893e-02,
                         -1.25737246e-02,  -3.43841454e-03,  -6.51873369e-03,
                         -2.34165345e-03,   3.89619009e-03,   1.39476964e-03,
                         -3.03641497e-03,  -4.86728176e-03,  -3.79072293e-03,
                         -9.32422653e-03,  -1.92634333e-02,  -1.13720158e-02,
                         -1.07423523e-02,  -6.56629028e-03,  -4.27500065e-03,
                          9.84674692e-03,   1.13931540e-02,   2.29451270e-03,
                         -9.25132539e-03,   2.78574834e-03,  -1.04193799e-02,
                         -1.88798681e-02,  -1.79876853e-02,  -4.07414977e-03,
                          5.73099358e-03,  -3.40793445e-03,  -1.21390484e-02,
                         -1.30808388e-03,  -1.59532521e-02,   1.93795585e-03,
                         -3.59579758e-03,   8.56125634e-03,   1.13291861e-02,
                          1.47095723e-02,   1.06698601e-02,   1.66044217e-02,
                         -6.35148864e-03,   6.61211438e-04,   5.24117844e-03,
                         -2.10441090e-03,  -4.14890843e-03,  -7.65427062e-03,
                          3.11706448e-03,  -5.03894873e-03,  -9.61026642e-03,
                          1.26238458e-03,  -3.54039576e-03,  -1.40610780e-03,
                          9.81078483e-04,   1.52517261e-03,  -7.16026966e-03,
                          1.07803103e-02,   3.49057303e-03,   2.18910770e-03,
                         -4.83536045e-04,  -3.48373945e-03,   6.29805494e-03,
                          6.70655537e-03,  -5.68656251e-03,  -1.04421610e-02,
                         -3.08453292e-03,  -1.02781244e-02,  -7.61382468e-03,
                          8.55737459e-03,  -8.50640878e-04,   1.14913440e-04,
                         -5.33550186e-03,   5.11432393e-03,   3.18689551e-03,
                         -7.26930611e-03,  -1.32769626e-02,  -1.43443597e-02,
                         -1.12992395e-02,  -1.55405933e-02,  -1.17121544e-02,
                          1.04376767e-02,   3.33996792e-03,   2.31226836e-03,
                         -2.05369410e-03,   9.32071358e-03,  -9.43315215e-03,
                         -1.87037792e-02,  -6.76802127e-03,   6.88663544e-03,
                         -8.35249107e-03,  -5.88815473e-03,   4.53516888e-03,
                         -2.94058793e-03,   1.09792408e-02,   1.14784883e-02,
                         -2.05392484e-02,  -9.52644050e-01,  -9.26614046e-01,
                         -9.28835988e-01,  -9.37433422e-01,  -9.37501729e-01,
                         -9.25541759e-01,  -9.20952320e-01,  -9.29309905e-01,
                         -9.20705378e-01,  -9.30530846e-01,  -9.47272003e-01,
                         -9.27363157e-01,  -5.54339355e-03,  -1.21137663e-03,
                          1.31623056e-02,   9.70793702e-03,   4.19438584e-03,
                          1.14247287e-02,   1.26219052e-03,   8.39294400e-03,
                          1.64356921e-02,  -7.15467706e-03,  -5.79029042e-03,
                         -2.07680427e-02,  -7.21630931e-04,  -6.04447769e-03,
                         -9.06526484e-03,  -1.81063283e-02,  -5.03036194e-03,
                         -2.89206114e-03,  -9.77156498e-03,  -2.24940591e-02,
                         -1.13325128e-02,  -1.98877673e-03,  -4.69446473e-04,
                         -5.56770572e-03,  -1.04448562e-02,  -1.86293125e-02,
                          6.75439602e-04,  -1.84840783e-02,  -1.13862650e-02,
                         -1.94862182e-03,  -2.47902842e-03,  -5.91848232e-03,
                         -8.76352788e-05,  -1.52483648e-02,  -2.21824320e-03,
                         -1.47688687e-02,  -6.78956136e-03,  -9.18556284e-03,
                         -5.22381067e-03,  -1.88488886e-02,   2.17909319e-03,
                         -1.46400258e-02,  -3.24357941e-04,   6.37481629e-04,
                         -4.29523038e-03,   4.04139655e-03,   1.24979755e-02,
                          1.94730505e-03,  -2.27369349e-02,  -1.40503086e-02,
                          3.23752221e-03,  -5.35062375e-03,   1.87406000e-02,
                          1.22487294e-02,   4.38032905e-03,  -2.16205399e-02,
                         -1.05248615e-02,   6.26437319e-03,  -4.83578304e-03,
                          3.47056473e-03,  -7.50995148e-03,  -1.21811647e-02,
                         -1.29877627e-02,  -1.83465444e-02,  -9.17755842e-01,
                         -9.37449753e-01,  -9.33073461e-01,  -9.33370113e-01,
                         -9.37385798e-01,  -9.42901611e-01,  -9.43308651e-01,
                         -9.37719762e-01,  -9.41603124e-01,  -9.41708028e-01,
                         -9.37218785e-01,  -9.42681313e-01,  -9.36617076e-01,
                         -9.43215191e-01,  -9.32491243e-01,  -9.39881742e-01,
                         -9.24368978e-01,  -9.43791032e-01,  -9.31992769e-01,
                         -9.41910505e-01,  -9.28214669e-01,  -9.35450792e-01,
                         -9.28851485e-01,  -9.45038080e-01,  -9.37424481e-01,
                         -9.45989370e-01,  -9.42311049e-01,  -9.31618333e-01,
                         -9.45552707e-01,  -9.51033831e-01,  -9.34380829e-01,
                         -9.35083508e-01,  -9.26576853e-01,  -9.25559640e-01,
                         -9.39240038e-01,  -9.48462129e-01,  -9.43857014e-01,
                         -9.28890169e-01,  -9.35920179e-01,  -9.37153220e-01,
                         -9.40930486e-01,  -9.33801591e-01,  -9.33634043e-01,
                         -9.48652208e-01,  -9.39808309e-01,  -9.20536995e-01,
                         -9.23495770e-01,  -9.20772135e-01,  -9.26914930e-01,
                         -9.28355873e-01,  -9.18356121e-01,  -9.23800707e-01,
                         -9.20754135e-01,  -9.41293776e-01,  -9.46588516e-01,
                         -9.30780768e-01,  -9.35213029e-01,  -9.21791613e-01,
                         -9.38782275e-01,  -9.28940654e-01,  -9.29162383e-01,
                         -9.16949153e-01,  -9.27309096e-01,  -9.39764500e-01,
                         -9.28334951e-01,  -9.36221480e-01,  -9.37344193e-01,
                         -9.30911958e-01,  -9.24061298e-01,  -9.44212437e-01,
                         -9.33831632e-01,  -9.39827263e-01,  -9.26267505e-01,
                         -9.25627232e-01,  -9.34049964e-01,  -9.26518261e-01,
                         -9.28931117e-01,  -9.17233884e-01,  -9.28793132e-01,
                         -9.19702232e-01,  -9.32199895e-01,  -9.26046669e-01,
                         -9.39739883e-01,  -9.24448133e-01,  -9.30156469e-01,
                         -9.21290755e-01,  -9.30063784e-01,  -9.33854997e-01,
                         -9.19138908e-01,  -9.30249095e-01,  -9.41183865e-01,
                         -9.37163889e-01,  -9.33812678e-01,  -9.45096314e-01,
                         -9.31612253e-01,  -9.24274921e-01,  -9.37720776e-01,
                         -9.43238258e-01,  -9.38256145e-01,  -9.38103080e-01,
                         -9.37723756e-01,  -9.40581739e-01,  -9.37971830e-01,
                         -9.39534187e-01,  -9.30952013e-01,  -9.34771180e-01,
                         -9.34304535e-01,  -9.26168740e-01,  -9.36806738e-01,
                         -9.30919647e-01,  -9.36193764e-01,  -9.29255545e-01,
                         -9.47525382e-01,  -9.37514424e-01,  -9.40388918e-01,
                         -9.30207372e-01,  -9.26632285e-01,  -9.48745906e-01,
                         -9.34088111e-01,  -9.39578772e-01,  -9.31063652e-01,
                         -9.39890504e-01,  -9.35020208e-01,  -9.40492570e-01,
                         -9.43121493e-01,  -9.39087987e-01,  -9.34440851e-01,
                         -9.32182491e-01,  -9.35477853e-01,  -9.31322277e-01,
                         -9.34546947e-01,  -9.17515755e-01,  -9.33173835e-01,
                         -9.39411998e-01,  -9.35921311e-01,  -9.33206201e-01,
                         -9.27672923e-01,  -9.29213285e-01,  -9.38504517e-01,
                         -9.43461180e-01,  -9.39945817e-01,  -9.31293070e-01,
                         -9.36735094e-01,  -9.38628614e-01,  -9.42333519e-01,
                         -9.36704040e-01,  -9.34651732e-01,  -9.37267125e-01,
                         -9.39650953e-01,  -9.33304667e-01,  -9.31706131e-01,
                         -9.32120442e-01,  -9.43642914e-01,  -9.39340234e-01,
                         -9.44492280e-01,  -9.38380003e-01,  -9.31015074e-01,
                         -9.33114290e-01,  -9.37979698e-01,  -9.34846103e-01,
                         -9.41530526e-01,  -9.32074428e-01,  -9.33002532e-01,
                         -9.32160020e-01,  -9.33370233e-01,  -9.29773390e-01,
                         -9.30985391e-01,  -9.30313528e-01,  -9.33322310e-01,
                         -9.38788295e-01,  -9.36967373e-01,  -9.31097627e-01,
                         -9.31932688e-01,  -9.29871798e-01,  -9.29872215e-01,
                         -9.34029579e-01,  -9.33781862e-01,  -9.29703295e-01,
                         -9.34936285e-01,  -9.30662811e-01,  -9.29438412e-01,
                         -9.26352978e-01,  -9.35315728e-01,  -9.38977420e-01,
                         -9.33446646e-01,  -9.38024938e-01,  -9.42359388e-01,
                         -9.33845937e-01,  -9.35788691e-01,  -9.36301410e-01,
                         -9.44315434e-01,  -9.37123835e-01,  -9.34677720e-01,
                         -9.39354360e-01,  -9.34423745e-01,  -9.34158981e-01,
                         -9.42065656e-01,  -9.43893850e-01,  -9.33160186e-01,
                         -9.30217147e-01,  -9.28240240e-01,  -9.32440639e-01,
                         -9.35497582e-01,  -9.35634196e-01,  -9.33002412e-01,
                         -9.30492938e-01,  -9.35657918e-01,  -9.34806883e-01,
                         -9.36970413e-01,  -9.29952502e-01,  -9.28166211e-01,
                         -9.34441149e-01,  -9.33370471e-01,  -9.30388808e-01,
                         -9.38878059e-01,  -9.42928255e-01,  -9.38423574e-01,
                         -9.39203739e-01,  -9.38834488e-01,  -9.34478641e-01,
                         -9.33794498e-01,  -9.33654428e-01,  -9.37177956e-01,
                         -9.34365630e-01,  -9.35609579e-01,  -9.25168991e-01,
                         -9.39044833e-01,  -9.35578287e-01,  -9.38703656e-01,
                         -9.41794634e-01,  -9.37568963e-01,  -9.34890509e-01,
                         -9.27667975e-01,  -9.34419632e-01,  -9.32729542e-01,
                         -9.37732518e-01,  -9.30005908e-01,  -9.36682165e-01,
                         -9.33887601e-01,  -9.34297800e-01,  -9.36173141e-01,
                         -9.34168696e-01,  -9.33030248e-01,  -9.36723471e-01,
                         -9.34615731e-01,  -9.31493044e-01,  -9.37540770e-01,
                         -9.32909369e-01,  -9.30636406e-01,  -9.38777626e-01,
                         -9.45110261e-01,  -9.36895072e-01,  -9.30644512e-01,
                         -9.32305157e-01,  -9.31239426e-01,  -9.28794622e-01,
                         -9.31623340e-01,  -9.35961664e-01,  -9.32846367e-01,
                         -9.23249125e-01,  -9.32243168e-01,  -9.34924960e-01,
                         -9.39935744e-01,  -9.36273992e-01,  -9.35989916e-01,
                         -9.38997269e-01,  -9.30598855e-01,  -9.33354020e-01,
                         -9.35315847e-01,  -9.35248852e-01,  -9.37006533e-01,
                         -9.38588202e-01,  -9.34592307e-01,  -9.30236578e-01,
                         -9.29320157e-01,  -9.33541775e-01,  -9.23797309e-01,
                         -9.33512628e-01,  -9.28879201e-01,  -9.30751622e-01,
                         -9.32755709e-01,  -9.32025254e-01,  -9.41060364e-01,
                         -9.29323137e-01,  -9.32971716e-01,  -9.35996473e-01,
                         -9.33955908e-01,  -9.31497335e-01,  -9.30320859e-01,
                         -9.24009144e-01,  -9.35340226e-01,  -9.31190729e-01,
                         -9.31042135e-01,  -9.29585516e-01,  -9.39896822e-01,
                         -9.33968365e-01,  -9.26781237e-01,  -9.34238493e-01,
                         -9.34110820e-01,  -9.35030103e-01,  -9.33563411e-01,
                         -9.35376406e-01,  -9.31215167e-01,  -9.31632161e-01,
                         -9.31181788e-01,  -9.32391226e-01,  -9.43983436e-01,
                         -9.40644979e-01,  -9.38944280e-01,  -9.32202458e-01,
                         -9.37147677e-01,  -9.35871303e-01,  -9.36177015e-01,
                         -9.39395130e-01,  -9.35778797e-01,  -9.23813879e-01,
                         -9.28406656e-01,  -9.29702163e-01,  -9.37932789e-01,
                         -9.31223869e-01,  -9.26651895e-01,  -9.28628683e-01,
                         -9.26981151e-01,  -9.29243803e-01,  -9.34499800e-01,
                         -9.39972222e-01,  -9.28388894e-01,  -9.31087852e-01,
                         -9.26823080e-01,  -9.34107482e-01,  -9.37120080e-01,
                         -9.27096426e-01,  -9.33241367e-01,  -9.37546015e-01,
                         -9.39835608e-01,  -9.40114915e-01,  -9.30365622e-01,
                         -9.35683966e-01,  -9.23512995e-01,  -9.24278796e-01,
                         -9.27807093e-01,  -9.27252173e-01,  -9.26847696e-01,
                         -9.25389469e-01,  -9.31117654e-01,  -9.24959421e-01,
                         -9.31380153e-01,  -9.30937231e-01,  -9.29800749e-01,
                         -9.20294225e-01,  -9.26498950e-01,  -9.21316683e-01,
                         -9.33038533e-01,  -9.17538345e-01,  -9.29813921e-01,
                         -9.19176579e-01,  -9.22041535e-01,  -9.32518065e-01,
                         -9.35367405e-01,  -9.27562654e-01,  -9.33769882e-01,
                         -9.25314665e-01,  -9.25785720e-01,  -9.27420497e-01,
                          8.75299983e-03,   6.07260130e-03,   1.04927942e-02,
                          7.31492229e-03,   7.23396102e-03,   1.81998480e-02,
                          1.18484972e-02,   1.05687939e-02,  -8.97134375e-03,
                          6.56796061e-03,  -3.08015989e-03,  -2.57597119e-03,
                          7.36575015e-03,   1.06095932e-02,  -3.78463796e-04,
                          4.92530363e-03,   2.13006046e-03,   6.70697819e-03,
                          6.26744330e-03,  -2.63655698e-03,   5.22575155e-03,
                          8.96181446e-03,  -1.04146334e-03,   1.34742097e-03,
                         -3.80803505e-03,  -3.92944925e-03,   5.23121934e-03,
                         -5.37669612e-03,  -8.16141907e-03,  -4.26734245e-04,
                         -4.06818278e-03,  -6.29172754e-03,  -1.71122688e-03,
                         -3.73539026e-03,  -8.11497122e-03,   6.92480151e-03,
                         -9.87877254e-04,   1.87005149e-03,  -6.35577179e-03,
                         -2.13257619e-03,  -1.17302360e-03,  -1.50950709e-02,
                          5.32638107e-04,  -1.74475636e-03,  -5.22325630e-04,
                          1.03941467e-02,   8.49567354e-03,  -1.24384568e-03,
                         -3.52633395e-03,  -3.70023912e-03,   1.07838651e-02,
                          1.54121651e-03,  -6.53097313e-03,   7.56701687e-03,
                          1.44769875e-02,   6.39205240e-03,   7.03457277e-03,
                         -1.40606624e-03,   1.87282369e-03,  -5.27814543e-03,
                         -1.14305643e-02,  -9.18378879e-04,   1.68839106e-04,
                         -2.15114979e-03,   2.72423378e-03,  -6.32728776e-03,
                          2.53054919e-03,  -8.42418615e-03,   1.57814880e-03,
                          6.76146534e-04,  -3.34602501e-03,   5.02310554e-03,
                          1.56338699e-03,  -5.22396341e-03,  -4.76397015e-03,
                         -7.89403636e-03,  -3.50496755e-03,  -6.99693337e-03,
                         -1.15093635e-02,  -6.12789206e-03,   5.33861341e-03,
                          9.22959880e-04,  -4.45586396e-03,  -6.46983273e-04,
                         -8.12423043e-03,  -4.58384119e-03,  -5.94239915e-03,
                          1.78057968e-03,  -3.05715075e-04,   2.24298495e-03,
                         -2.34310189e-03,   3.55860894e-03,  -5.08008758e-03,
                         -6.93653477e-03,  -1.13918923e-03,  -3.05297179e-03,
                         -4.21510078e-03,  -9.28223506e-03,  -6.48206472e-03,
                         -3.43544129e-03,  -1.32869498e-03,  -3.71089135e-03,
                         -1.53075857e-03,   3.76632786e-03,  -3.07209278e-03,
                          8.76629259e-03,  -2.13690079e-03,  -2.65948288e-03,
                          3.46945599e-03,  -5.40042575e-03,  -8.95210449e-03,
                         -1.14238425e-03,  -2.91656028e-03,  -3.96431610e-03,
                         -3.48092569e-03,  -9.90894064e-03,   2.63672322e-03,
                         -3.11615644e-03,  -5.90020698e-03,   1.58755342e-04,
                          1.82948774e-03,  -2.93609011e-03,  -3.06365150e-03,
                          4.90657054e-03,  -5.06087672e-04,   1.77866686e-03,
                         -4.58534528e-03,  -9.52064246e-03,  -8.07730388e-03,
                          1.97080604e-04,  -7.09932356e-04,  -4.05297708e-03,
                          2.32515900e-04,  -6.17261417e-03,  -5.56060206e-03,
                         -3.97758791e-03,  -4.17052419e-04,  -4.31093480e-03,
                         -6.12722710e-03,   3.43396515e-03,  -6.59766467e-03,
                         -7.57616479e-03,  -1.66825822e-03,  -3.76946031e-04,
                         -4.20864159e-03,  -7.12911738e-03,  -7.05344416e-03,
                         -6.42492378e-04,  -6.79556979e-03,  -1.67023336e-05,
                          1.84877508e-03,  -7.38843344e-03,  -2.59520300e-03,
                         -3.06678424e-03,  -1.11764669e-02,  -5.30801553e-05,
                         -3.84224369e-03,  -1.09902746e-03,  -5.34963980e-03,
                         -6.79882010e-03,  -1.53655307e-02,  -1.28885193e-04,
                         -2.27185711e-03,  -5.65462001e-03,  -6.25135098e-03,
                         -1.07172709e-02,  -1.17042130e-02,  -4.62458516e-03,
                         -1.29713863e-02,  -7.54206721e-03,  -4.12474899e-03,
                          1.97817315e-03,  -2.70788488e-03,   4.67575248e-03,
                         -1.54541631e-04,  -1.03105383e-03,  -1.86946243e-03,
                          2.77592801e-03,   4.82129166e-04,  -5.70679258e-04,
                         -1.58016421e-02,  -6.83485856e-03,  -5.07588079e-03,
                         -7.02823838e-03,  -7.62826065e-03,  -7.34278280e-03,
                          6.87517272e-03,  -2.48336676e-03,   6.11508498e-03,
                         -9.49988549e-04,  -9.48359884e-05,   1.72347296e-03,
                          1.47090736e-03,   2.46491097e-03,  -5.14806807e-03,
                          5.58934268e-03,   8.90202541e-03,  -7.41059706e-03,
                          4.28372575e-03,   3.31092929e-03,  -4.64647822e-03,
                         -4.30639554e-03,   1.19278918e-03,  -1.89732970e-03,
                         -3.36701021e-04,   6.45825872e-04,  -5.69103286e-03,
                          3.42556555e-03,   5.49181737e-03,   3.53763753e-04,
                          3.80197796e-03,  -2.45118886e-03,  -3.87006928e-03,
                         -1.81898812e-03,  -5.06267836e-03,  -6.21339306e-03,
                         -5.67797571e-03,   2.37043551e-03,  -4.06490464e-04,
                         -1.63334270e-03,  -1.39816559e-03,   1.49695878e-03,
                         -3.16244480e-03,   5.32058720e-03,  -3.02998349e-03,
                          1.43680268e-03,   2.42038304e-03,  -3.06358933e-03,
                         -6.22437056e-03,  -7.60768447e-03,   2.54004379e-03,
                         -3.39355378e-04,  -2.14875862e-03,  -6.56376779e-03,
                          1.41654501e-03,  -9.05120978e-04,  -2.51175370e-03,
                          9.56994575e-03,  -2.25361623e-03,  -7.25664431e-03,
                          4.93369624e-03,  -9.82248969e-03,  -7.05275103e-04,
                         -3.68633680e-03,  -1.10048074e-02,  -1.92295155e-03,
                         -7.72110792e-03,  -8.89251661e-03,  -2.61397078e-03,
                         -2.39792847e-04,  -8.10726453e-03,  -3.60999117e-03,
                         -5.69180911e-03,  -2.07046571e-04,  -4.09993110e-03,
                         -4.68068710e-03,  -4.03856905e-03,   7.65710510e-03,
                         -5.35700703e-03,   7.61392200e-03,  -1.40680082e-03,
                         -1.17174152e-03,  -7.52543425e-03,  -2.92121735e-03,
                         -7.49222994e-01,  -7.68169761e-01,  -7.56811678e-01,
                         -7.65831172e-01,  -7.58761287e-01,  -7.66465485e-01,
                         -7.55598843e-01,  -7.48852313e-01,  -7.66476512e-01,
                         -7.52420545e-01,  -7.66696811e-01,  -7.63671935e-01,
                         -7.66201437e-01,  -7.76719034e-01,  -7.64908433e-01,
                         -7.72561908e-01,  -7.46718943e-01,  -7.68729627e-01,
                         -7.49862671e-01,  -7.63505220e-01,  -7.60972798e-01,
                         -7.59801924e-01,  -7.61896729e-01,  -7.49103606e-01,
                         -7.57973492e-01,  -7.55409181e-01,  -7.70364523e-01,
                         -7.57646143e-01,  -7.59945095e-01,  -7.57461548e-01,
                         -7.59615362e-01,  -7.73408771e-01,  -7.49503434e-01,
                         -7.64515281e-01,  -7.49560714e-01,  -7.46891677e-01,
                         -7.63348520e-01,  -7.45918155e-01,  -7.57401526e-01,
                         -7.60443926e-01,  -7.59651959e-01,  -7.62694776e-01,
                         -7.66625285e-01,  -7.51915634e-01,  -7.54601538e-01,
                         -7.63607264e-01,  -7.41780937e-01,  -7.61565685e-01,
                         -7.44029105e-01,  -7.49442518e-01,  -7.62742579e-01,
                         -7.54104316e-01,  -7.53225684e-01,  -7.48579383e-01,
                         -7.62944698e-01,  -7.63696074e-01,  -7.58116424e-01,
                         -7.61327028e-01,  -7.43601143e-01,  -7.54631221e-01,
                         -7.50497520e-01,  -7.55586922e-01,  -7.38103032e-01,
                         -7.51053929e-01,  -7.52583385e-01,  -7.34868407e-01,
                         -7.60562658e-01,  -7.49303997e-01,  -7.72509694e-01,
                         -7.54994810e-01,  -7.67038405e-01,  -7.46841848e-01,
                         -7.48968780e-01,  -7.68354595e-01,  -7.47566760e-01,
                         -7.62562156e-01,  -7.50185132e-01,  -7.57918894e-01,
                         -7.49758542e-01,  -7.54302502e-01,  -9.42100704e-01,
                         -9.11134899e-01,  -9.35058594e-01,  -9.06391501e-01,
                         -7.76168704e-01,  -7.60024190e-01,  -7.57341921e-01,
                         -7.73868203e-01,  -7.48050272e-01,  -7.64685988e-01,
                         -7.67986059e-01,  -7.65197098e-01,  -7.51451552e-01,
                         -7.54420817e-01,  -7.57566154e-01,  -7.53209412e-01,
                         -7.59676218e-01,  -7.58788347e-01,  -7.51341224e-01,
                         -7.58682072e-01,  -9.21327174e-01,  -9.33979630e-01,
                         -9.07211542e-01,  -9.28566277e-01,  -9.32242036e-01,
                         -9.18856204e-01,  -9.26790476e-01,  -9.21169341e-01,
                         -9.30523753e-01,  -9.37976360e-01,  -9.15713906e-01,
                         -9.29120421e-01,  -7.59332418e-01,  -7.62952864e-01,
                         -7.61599600e-01,  -7.47588396e-01,  -7.60448337e-01,
                         -7.48525977e-01,  -7.76207387e-01,  -7.52581179e-01,
                         -7.67416418e-01,  -7.60245621e-01,  -7.43933916e-01,
                         -7.67326415e-01,  -7.50958502e-01,  -7.57640243e-01,
                         -7.48459518e-01,  -7.37284303e-01,  -9.27278876e-01,
                         -9.41857278e-01,  -9.09529686e-01,  -9.29759443e-01,
                         -9.31700587e-01,  -9.24871922e-01,  -9.15165067e-01,
                         -9.32524920e-01,  -7.52533317e-01,  -7.58106411e-01,
                         -7.42608130e-01,  -7.61937857e-01,  -7.55887687e-01,
                         -7.42750704e-01,  -7.82810986e-01,  -7.50394702e-01,
                         -7.54733980e-01,  -7.73284614e-01,  -7.49233663e-01,
                         -7.61485398e-01,  -7.54236341e-01,  -7.49219418e-01,
                         -7.33792007e-01,  -7.77730405e-01,  -9.16601658e-01,
                         -9.23208773e-01,  -9.21314478e-01,  -9.23013508e-01,
                         -9.38611269e-01,  -9.18248057e-01,  -9.27813888e-01,
                         -9.29374993e-01,  -9.22655046e-01,  -9.27732289e-01,
                         -9.22750056e-01,  -8.98846865e-01,  -9.48991060e-01,
                         -9.10018921e-01,  -9.44782138e-01,  -9.26575959e-01,
                         -7.71472752e-01,  -7.77282834e-01,  -7.68750429e-01,
                         -7.72626102e-01,  -7.41290987e-01,  -7.60481119e-01,
                         -7.69585013e-01,  -7.48701930e-01,  -7.64495730e-01,
                         -7.41411984e-01,  -7.55978644e-01,  -7.65104711e-01,
                         -7.42442250e-01,  -7.58197248e-01,  -7.56328940e-01,
                         -7.47624278e-01,  -7.54497349e-01,  -7.48093367e-01,
                         -7.59778619e-01,  -7.54770458e-01,  -7.53161967e-01,
                         -7.60489464e-01,  -7.60702252e-01,  -7.57897079e-01,
                         -7.46774495e-01,  -7.68376708e-01,  -7.46697843e-01,
                         -7.69084454e-01,  -7.58515239e-01,  -7.68881440e-01,
                         -7.58852482e-01,  -7.45991409e-01,  -7.51168668e-01,
                         -7.58524001e-01,  -7.41711497e-01,  -7.56405890e-01,
                         -7.43130803e-01,  -7.44155228e-01,  -7.61472881e-01,
                         -7.49585688e-01,  -7.80358970e-01,  -7.49374568e-01,
                         -7.65603721e-01,  -7.55631983e-01,  -7.60167480e-01,
                         -7.58067131e-01,  -7.60395110e-01,  -7.44391501e-01,
                         -1.29859401e-02,   1.93601120e-02,  -2.10521072e-02,
                         -2.16015941e-03,  -1.94485728e-02,  -2.82849511e-03,
                          3.44583020e-03,  -1.12965994e-04,  -7.50428259e-01,
                         -7.67484188e-01,  -7.48979032e-01,  -7.64897287e-01,
                         -7.51239657e-01,  -7.62263060e-01,  -7.44858742e-01,
                         -7.67818570e-01,  -7.54130304e-01,  -7.59161711e-01,
                         -7.62575090e-01,  -7.46301889e-01,  -7.53805220e-01,
                         -7.60049760e-01,  -7.64270008e-01,  -7.61873126e-01,
                         -7.59261787e-01,  -7.75821388e-01,  -7.66673505e-01,
                         -7.70969987e-01,  -7.37586796e-01,  -7.59644687e-01,
                         -7.46715486e-01,  -7.46313572e-01,  -7.52989233e-01,
                         -7.45883405e-01,  -7.68920064e-01,  -7.48799026e-01,
                         -7.71469831e-01,  -7.52685905e-01,  -7.63000131e-01,
                         -7.58973360e-01,  -7.65313387e-01,  -7.60540366e-01,
                         -7.32807040e-01,  -7.59532750e-01,  -7.52244234e-01,
                         -7.71891177e-01,  -7.64085293e-01,  -7.52152085e-01,
                         -7.46780217e-01,  -7.61340380e-01,  -7.53489733e-01,
                         -7.53527224e-01,  -7.45521605e-01,  -7.55984366e-01,
                         -7.63984025e-01,  -7.57219076e-01,  -7.57025301e-01,
                         -7.60544062e-01,  -7.54175603e-01,  -7.51838207e-01,
                         -7.70303726e-01,  -7.51960456e-01,  -7.66104937e-01,
                         -7.49289989e-01,  -1.42059308e-02,   4.92079882e-03,
                         -6.38341007e-04,  -3.90824210e-03,  -7.53433883e-01,
                         -7.54196107e-01,  -7.49112606e-01,  -7.47716606e-01,
                         -7.66611576e-01,  -7.49419749e-01,  -7.75365174e-01,
                         -7.55879045e-01,  -7.54226148e-01,  -7.61256218e-01,
                         -7.52244174e-01,  -7.46171594e-01,  -7.45113850e-01,
                         -7.56367803e-01,  -7.43860662e-01,  -7.44390666e-01,
                         -7.61518002e-01,  -7.45229781e-01,  -7.59490311e-01,
                         -7.49008179e-01,  -7.49102652e-01,  -7.49464154e-01,
                         -7.59972453e-01,  -7.47662723e-01,  -7.49695837e-01,
                         -7.57600248e-01,  -7.61620283e-01,  -7.67853737e-01,
                         -7.64670670e-01,  -7.61113107e-01,  -7.49608815e-01,
                         -7.54802406e-01,  -7.46070206e-01,  -7.50298798e-01,
                         -7.48784125e-01,  -7.60958731e-01,  -7.46058166e-01,
                         -7.66799629e-01,  -7.65740752e-01,  -7.56779909e-01,
                         -1.58440489e-02,   1.18261119e-02,  -1.27386826e-03,
                          1.07752229e-03,   5.31924982e-03,  -6.33579839e-05,
                          4.89059603e-03,  -1.78458540e-05,  -7.53860772e-01,
                         -7.60596037e-01,  -7.39613712e-01,  -7.63083279e-01,
                         -7.57012069e-01,  -7.60986626e-01,  -7.74124920e-01,
                         -7.41200089e-01,  -7.63454854e-01,  -7.58457482e-01,
                         -7.58802891e-01,  -7.72048235e-01,  -7.59384513e-01,
                         -7.72610009e-01,  -7.50448704e-01,  -7.76955545e-01,
                         -7.53501832e-01,  -7.60970414e-01,  -7.67187834e-01,
                         -7.44418681e-01,  -7.65258968e-01,  -7.50679910e-01,
                         -7.58556545e-01,  -7.54739940e-01,  -7.52601266e-01,
                         -7.61063457e-01,  -7.78760970e-01,  -7.56004512e-01,
                         -7.63243139e-01,  -7.59251595e-01,  -7.63595641e-01,
                         -7.65948713e-01,  -7.58565247e-01,  -7.44394660e-01,
                         -7.70170391e-01,  -7.50851154e-01,  -1.39154703e-03,
                         -8.41086544e-03,   2.30680709e-03,  -1.44585520e-02,
                         -7.54154623e-01,  -7.69998252e-01,  -7.58550644e-01,
                         -7.40596473e-01,  -7.78463125e-01,  -7.62014508e-01,
                         -7.50062585e-01,  -7.79487610e-01,  -7.49310255e-01,
                         -7.60870695e-01,  -7.54392207e-01,  -7.73272753e-01,
                         -7.59884179e-01,  -7.68393695e-01,  -7.52048135e-01,
                         -7.63562858e-01,  -7.60976970e-01,  -7.53751993e-01,
                         -7.61149049e-01,  -7.56299019e-01,  -7.54890025e-01,
                         -7.45347321e-01,  -7.60897219e-01,  -7.59945750e-01,
                         -7.44957030e-01,  -7.47008741e-01,  -7.56292522e-01,
                         -7.58392513e-01,  -7.54027188e-01,  -7.64875650e-01,
                         -7.38912404e-01,  -7.61011183e-01,  -7.67381668e-01,
                         -7.54965127e-01,  -7.64470339e-01,  -7.49920368e-01,
                         -7.55500317e-01,  -7.74300933e-01,  -7.70747423e-01,
                         -7.63961613e-01,  -7.62415528e-01,  -7.62526631e-01,
                         -7.41828859e-01,  -7.62282133e-01,  -7.54817843e-01,
                         -7.61731267e-01,  -7.67432451e-01,  -7.43690729e-01,
                         -7.46076226e-01,  -7.55936682e-01,  -7.49375641e-01,
                         -7.56558776e-01,  -9.21445906e-01,  -9.13555384e-01,
                         -9.38801587e-01,  -9.06727672e-01,  -9.20314431e-01,
                         -8.95929039e-01,  -9.20098186e-01,  -9.22452509e-01,
                         -9.12224531e-01,  -9.31588948e-01,  -9.29215431e-01,
                         -9.06407833e-01,  -7.66313136e-01,  -7.53931999e-01,
                         -7.32453883e-01,  -7.71866441e-01,  -7.67297089e-01,
                         -7.40718901e-01,  -7.56794870e-01,  -7.47075260e-01,
                         -7.55512357e-01,  -7.73621798e-01,  -7.49925137e-01,
                         -7.53765464e-01,  -7.55236268e-01,  -7.77729809e-01,
                         -7.67216682e-01,  -7.62972713e-01,  -7.54504085e-01,
                         -7.40474761e-01,  -7.61426866e-01,  -7.63411283e-01,
                         -7.39930630e-01,  -7.50714183e-01,  -7.65380144e-01,
                         -7.51015902e-01,  -8.97181273e-01,  -9.33280170e-01,
                         -8.94246817e-01,  -9.25239563e-01,  -9.09659564e-01,
                         -9.15367961e-01,  -9.58254576e-01,  -9.23697889e-01,
                         -9.34313416e-01,  -9.28343952e-01,  -9.40701067e-01,
                         -9.29118097e-01,  -7.54116058e-01,  -7.58855283e-01,
                         -7.45602369e-01,  -7.60304213e-01,  -9.25253093e-01,
                         -9.38268423e-01,  -9.12839353e-01,  -9.37965810e-01,
                         -9.23771381e-01,  -9.10539150e-01,  -9.44122672e-01,
                         -9.16877329e-01,  -9.30082679e-01,  -9.01745439e-01,
                         -9.29155707e-01,  -9.24168050e-01,  -9.17811036e-01,
                         -9.19839263e-01,  -9.41233873e-01,  -9.45404470e-01,
                         -9.45879161e-01,  -9.39473450e-01,  -9.36905861e-01,
                         -9.56691742e-01,  -9.52067077e-01,  -9.34847891e-01,
                         -9.32187855e-01,  -9.41200733e-01,  -7.48360693e-01,
                         -7.67051101e-01,  -7.60566235e-01,  -7.47500241e-01,
                         -7.72944033e-01,  -7.76550114e-01,  -7.82712042e-01,
                         -7.60364473e-01,  -7.52691686e-01,  -7.53622890e-01,
                         -7.39403903e-01,  -7.60641575e-01,  -7.91078150e-01,
                         -7.56042838e-01,  -7.57090688e-01,  -7.41747200e-01,
                         -7.47102618e-01,  -7.53778756e-01,  -7.32893527e-01,
                         -7.48001575e-01,  -8.96002769e-01,  -9.34272289e-01,
                         -9.33444858e-01,  -9.13145363e-01,  -9.22019541e-01,
                         -9.23085272e-01,  -9.19936419e-01,  -9.21376824e-01,
                         -9.12951767e-01,  -9.15672243e-01,  -9.41418529e-01,
                         -9.25144136e-01,  -9.44136024e-01,  -9.23227310e-01,
                         -9.21727419e-01,  -9.19942796e-01,  -7.82161474e-01,
                         -7.42595077e-01,  -7.59518862e-01,  -7.45374799e-01,
                         -7.57585347e-01,  -7.52555132e-01,  -7.56259203e-01,
                         -7.55417347e-01,   2.30461098e-02,   1.89432185e-02,
                          1.92152876e-02,   3.40514779e-02,   2.80720908e-02,
                         -1.08156763e-02,   5.26047964e-03,   9.58913565e-03,
                          1.01718605e-02,   3.30232456e-02,   1.38980262e-02,
                          1.81965902e-02,  -7.68213570e-01,  -7.60505795e-01,
                         -7.48543620e-01,  -7.62209892e-01,  -1.76659264e-02,
                          3.49381636e-03,  -2.08124463e-02,   3.47242225e-03,
                          3.60003905e-03,  -3.67001779e-02,  -7.84593914e-03,
                         -1.57792624e-02,   1.91615447e-01,   1.86787963e-01,
                          2.07177937e-01,   1.78552940e-01,   3.91769549e-03,
                          7.58743379e-04,   2.56330939e-03,  -3.18245293e-04,
                          1.55402943e-01,   1.70169845e-01,   1.52589500e-01,
                          1.61227509e-01,  -2.85792593e-02,  -2.22537257e-02,
                          4.05653240e-03,  -3.73315029e-02,  -3.63911092e-02,
                          1.23728951e-03,   3.09325842e-04,  -7.19680684e-03,
                         -3.01568545e-02,  -1.43432366e-02,  -1.32973865e-02,
                         -5.32334577e-03,   1.66543290e-01,   1.89245820e-01,
                          1.52265862e-01,   1.56816766e-01,   1.67378485e-01,
                          1.76442608e-01,   1.57858387e-01,   1.83224261e-01,
                          1.72211424e-01,   1.66055679e-01,   1.63166523e-01,
                          1.71274930e-01,   1.63282558e-01,   1.57626152e-01,
                          1.64391056e-01,   1.71270356e-01,   1.67970672e-01,
                          1.32811964e-01,   1.72024265e-01,   1.52177945e-01,
                          1.72608539e-01,   1.69276223e-01,   1.49196446e-01,
                          1.40866518e-01,   1.62584424e-01,   1.60159692e-01,
                          1.82646066e-01,   1.74306870e-01,   1.89343944e-01,
                          1.55958712e-01,   1.88778147e-01,   1.86515629e-01,
                          1.86099067e-01,   1.61280900e-01,   2.08735630e-01,
                          1.54466480e-01,   1.65904269e-01,   1.59129858e-01,
                          1.63668215e-01,   1.38484493e-01,   1.81955308e-01,
                          1.92561164e-01,   1.59365922e-01,   1.79054171e-01,
                          1.61418810e-01,   1.75418586e-01,   1.66237012e-01,
                          1.63010061e-01,   1.71369180e-01,   1.86094791e-01,
                          1.66905493e-01,   1.80433020e-01,   1.59550890e-01,
                          1.70429170e-01,   1.87227294e-01,   1.92376852e-01,
                          1.78286403e-01,   1.82621554e-01,   1.86373666e-01,
                          1.72785997e-01,  -3.30573693e-02,  -4.40694466e-02,
                         -1.04358541e-02,  -4.05568369e-02,  -3.05014625e-02,
                         -2.46778019e-02,  -1.05363317e-02,  -3.28194201e-02,
                          7.94315897e-03,  -2.37179026e-02,  -8.59724544e-03,
                         -5.05505502e-03,   1.12013128e-02,   1.03031918e-02,
                          2.14949884e-02,  -3.29413973e-02,   1.88722508e-03,
                          1.53752537e-02,  -1.14983786e-02,   2.50628423e-02,
                          1.78262994e-01,   1.82072222e-01,   1.78183526e-01,
                          1.42704859e-01,   1.67070419e-01,   1.66922137e-01,
                          1.44193009e-01,   1.70892447e-01,   1.82135507e-01,
                          1.77912176e-01,   1.77575469e-01,   1.46784991e-01,
                         -7.87370186e-03,  -2.78879628e-02,  -2.54856069e-02,
                         -1.67618934e-02,  -4.30079550e-03,   1.57380830e-02,
                          4.34057601e-03,  -2.97699496e-02,   1.61180291e-02,
                         -6.62765931e-03,   9.05109849e-03,   6.03168411e-03,
                          2.05144715e-02,  -1.96274603e-03,  -1.86179052e-04,
                          2.73312218e-02,   3.07825748e-02,   9.10815690e-03,
                          8.38709436e-03,   1.93439366e-03,   1.41753191e-02,
                          1.30930217e-02,   1.88530539e-03,  -2.55282363e-03,
                         -6.38530217e-03,   2.34810840e-02,   2.57641822e-02,
                         -1.82533991e-02,  -2.48071309e-02,   3.01771681e-04,
                          2.47153379e-02,   1.54852746e-02,   9.94475652e-03,
                         -6.83456054e-03,   1.18966084e-02,   1.64837353e-02,
                          6.02518348e-03,   1.94156040e-02,   1.09266387e-02,
                         -1.11520654e-02,  -3.26311635e-03,  -1.62172737e-03,
                         -1.52386343e-02,  -2.30984967e-02,  -2.49027573e-02,
                         -3.39230639e-04,  -7.80708669e-03,   1.17288781e-02,
                         -1.46771241e-02,  -1.76634733e-02,   2.89506260e-02,
                          3.86690572e-02,   1.10598216e-02,  -1.78754833e-02,
                          7.52702821e-03,   9.04629566e-03,   2.90415753e-02,
                         -1.34445541e-02,   1.26467925e-02,  -1.06715234e-02,
                          1.88077912e-02,   1.44974384e-02,   2.50949454e-03,
                          1.57151837e-02,   2.03421470e-02,   2.38315072e-02,
                          4.13073692e-03,   7.34932488e-03,   9.86821018e-03,
                          1.33858053e-02,  -3.33446497e-03,   2.72715371e-02,
                          4.89906501e-03,   8.00099969e-03,   1.11163454e-02,
                         -1.79543085e-02,  -2.39257123e-02,   1.37624880e-02,
                         -6.27690367e-03,   4.96175047e-03,  -2.20940895e-02,
                         -3.34324092e-02,   1.55261569e-02,  -1.38465054e-02,
                         -3.14840041e-02,  -1.42180175e-02,  -8.31464364e-04,
                          7.24587450e-03,   8.98984075e-03,   2.59089302e-02,
                          1.77805629e-02,  -1.46167390e-02,   1.51688447e-02,
                         -1.99061874e-02,  -1.54270662e-03,  -3.92556842e-03,
                          2.93943053e-03,  -3.00393207e-03,   4.98155085e-03,
                         -4.20638220e-03,  -9.07867432e-01,  -9.47539449e-01,
                         -9.34020996e-01,  -9.45040166e-01,  -9.20521259e-01,
                         -9.32288527e-01,  -9.32665110e-01,  -9.34935272e-01,
                         -9.50059235e-01,  -9.51084852e-01,  -9.65993822e-01,
                         -9.33385074e-01,   1.03409346e-02,   4.71254960e-02,
                          5.34754666e-03,   1.12110153e-02,  -2.08300282e-03,
                         -3.93115403e-03,  -6.01123227e-03,  -1.60635565e-03,
                          3.89463780e-03,   8.11490137e-03,   2.40016412e-02,
                         -8.08809511e-03,  -9.18925166e-01,  -9.48864102e-01,
                         -9.39134777e-01,  -9.22990084e-01,  -9.31706131e-01,
                         -9.21973050e-01,  -9.10953641e-01,  -9.13731754e-01,
                         -9.26913977e-01,  -9.60097194e-01,  -9.46246207e-01,
                         -9.28282082e-01,  -9.47055995e-01,  -9.31043029e-01,
                         -9.18618381e-01,  -9.39698994e-01,  -9.29930091e-01,
                         -9.34088349e-01,  -9.49111700e-01,  -9.37570274e-01,
                         -9.26958025e-01,  -9.61543679e-01,  -9.14105773e-01,
                         -9.44926322e-01,  -9.08580124e-01,  -9.27771211e-01,
                         -9.48227942e-01,  -9.55749094e-01,  -9.97154891e-01,
                         -9.47382212e-01,  -9.52870369e-01,  -9.54520881e-01,
                         -9.35170710e-01,  -9.26131368e-01,  -9.39860523e-01,
                         -9.26498055e-01,  -9.39030349e-01,  -9.30706263e-01,
                         -9.33498621e-01,  -9.18440163e-01,  -9.37604427e-01,
                         -9.25339282e-01,  -9.33188140e-01,  -9.23072159e-01,
                         -8.86946976e-01,  -9.36715364e-01,  -9.31015193e-01,
                         -9.20788050e-01,  -9.16910172e-01,  -9.20807838e-01,
                         -9.35419202e-01,  -9.39257741e-01,  -9.21118677e-01,
                         -8.75587881e-01,  -9.09437716e-01,  -9.15797532e-01,
                         -9.39216077e-01,  -9.52200353e-01,  -9.52414036e-01,
                         -9.48961794e-01,  -9.19868171e-01,  -9.26206946e-01,
                         -9.59980190e-01,  -9.58236694e-01,  -9.51033592e-01,
                         -9.41350222e-01,  -9.38822746e-01,  -9.42830861e-01,
                         -9.43394959e-01,  -8.96803975e-01,  -9.32272315e-01,
                         -9.31474030e-01,  -9.25642908e-01,  -9.53339279e-01,
                         -9.71407950e-01,  -9.53662515e-01,  -9.33940172e-01,
                         -9.50550616e-01,  -9.70206380e-01,  -9.42357719e-01,
                         -9.27377462e-01,  -9.68493104e-01,  -9.64422107e-01,
                         -9.21820700e-01,  -9.76727128e-01,  -9.41117764e-01,
                         -9.28474009e-01,  -9.27565277e-01,  -9.49960887e-01,
                         -9.22871649e-01,  -9.31891322e-01,  -9.46054339e-01,
                         -9.65943158e-01,  -9.28986609e-01,  -9.12099838e-01,
                         -9.45950568e-01,  -9.38826084e-01,  -9.34521437e-01,
                         -9.87458527e-01,  -9.70526993e-01,  -9.69079018e-01,
                         -9.53366697e-01,  -9.38430130e-01,  -9.25676227e-01,
                         -9.41404283e-01,  -9.26071763e-01,  -9.50735688e-01,
                         -9.26742435e-01,  -9.34543848e-01,  -9.25318718e-01,
                         -9.17796791e-01,  -9.15068448e-01,  -9.51602221e-01,
                         -9.32361841e-01,  -9.55363989e-01,  -9.39385712e-01,
                         -9.41868901e-01,  -9.51042712e-01,  -9.66825545e-01,
                         -9.51532364e-01,  -9.44079220e-01,  -9.74736333e-01,
                         -9.45865512e-01,  -9.81812119e-01,  -9.33773637e-01,
                         -9.49761748e-01,  -9.56811845e-01,  -9.83344734e-01,
                         -9.96754587e-01,  -9.28625882e-01,  -9.41464603e-01,
                         -9.49010611e-01,  -9.31983113e-01,  -9.48508501e-01,
                         -9.32084382e-01,  -9.42194045e-01,  -9.45956349e-01,
                         -9.42598343e-01,  -9.49736893e-01,  -9.33446765e-01,
                         -9.13230717e-01,  -9.33096647e-01,  -9.38181400e-01,
                         -9.25273955e-01,  -9.29795980e-01,  -9.04236495e-01,
                         -9.16964293e-01,  -9.25876796e-01,  -9.10714090e-01,
                         -9.37851250e-01,  -9.21580851e-01,  -9.14415240e-01,
                         -9.31024551e-01,  -9.23708916e-01,  -8.86096418e-01,
                         -9.39368665e-01,  -9.20684099e-01,  -9.30231154e-01,
                         -8.91527772e-01,  -9.62079167e-01,  -9.48548436e-01,
                         -9.21745241e-01,  -9.11931634e-01,  -8.98136675e-01,
                         -9.26868856e-01,  -9.28525865e-01,  -9.48068142e-01,
                         -9.22006786e-01,  -8.95691395e-01,  -9.03286934e-01,
                         -9.09877717e-01,  -9.27630484e-01,  -9.44653392e-01,
                         -9.30938900e-01,  -9.13682640e-01,  -9.41534400e-01,
                         -9.35379803e-01,  -9.23321962e-01,  -9.02231991e-01,
                         -9.47688699e-01,  -9.38449264e-01,  -9.38321233e-01,
                         -9.39475656e-01,  -9.28184271e-01,  -9.34053957e-01,
                         -9.26432014e-01,  -9.54224944e-01,  -9.17849422e-01,
                         -8.91568184e-01,  -9.04153526e-01,  -9.15705264e-01,
                         -9.37298417e-01,  -9.53663766e-01,  -9.37692940e-01,
                         -9.40483928e-01,  -9.52704906e-01,  -9.47021186e-01,
                         -9.30890143e-01,  -9.22972679e-01,  -9.35606122e-01,
                         -9.29276347e-01,  -9.24567163e-01,  -9.24267828e-01,
                         -9.02039886e-01,  -9.54294562e-01,  -9.26776707e-01,
                         -9.06976581e-01,  -9.31066751e-01,  -9.19698000e-01,
                         -9.12009358e-01,  -9.02860641e-01,  -8.97416174e-01,
                         -9.11839128e-01,  -9.24052596e-01,  -9.06212926e-01,
                         -9.37141240e-01,  -9.34830189e-01,  -9.38642800e-01,
                         -9.38558280e-01,  -9.10960615e-01,  -9.34241354e-01,
                         -9.51165259e-01,  -9.14168298e-01,  -9.11819160e-01,
                         -9.38607872e-01,  -9.39583898e-01,  -9.17421818e-01,
                         -9.36770797e-01,  -9.55747843e-01,  -9.09156740e-01,
                         -9.11635518e-01,  -9.32421565e-01,  -9.28610682e-01,
                         -9.11078095e-01,  -9.04507697e-01,  -9.01258647e-01,
                         -9.52268362e-01,  -9.20647025e-01,  -8.96988034e-01,
                         -8.99888277e-01,  -9.01786208e-01,  -9.07294095e-01,
                         -9.26356256e-01,  -9.05212939e-01,  -9.19774413e-01,
                         -9.26887512e-01,  -9.53353345e-01,  -9.32806134e-01,
                         -9.22601104e-01,  -9.19843614e-01,  -9.32072043e-01,
                         -9.16288733e-01,  -1.66935809e-02,   1.66090913e-02,
                         -3.99519131e-03,   2.65137907e-02,  -1.81127321e-02,
                         -1.38487294e-03,  -9.17644240e-03,   1.41633227e-02,
                         -1.00872396e-02,   1.44449612e-02,   1.02576590e-03,
                          2.13632900e-02,  -1.96228381e-02,  -1.21573452e-02,
                         -1.52910911e-02,  -5.95936505e-03,   1.05342519e-06,
                          2.48666573e-03,  -8.25551338e-03,   1.65734831e-02,
                          1.76908970e-02,   5.05113006e-02,   1.62148345e-02,
                         -4.30252822e-03,  -1.65254828e-02,  -1.73918009e-02,
                          2.32018083e-02,  -1.35865863e-02,   2.12651212e-02,
                          1.37064410e-02,  -1.17246713e-02,  -6.87586563e-03,
                         -3.08745615e-02,  -2.63456665e-02,   7.88287818e-03,
                          1.58114415e-02,   2.76730433e-02,   1.67618245e-02,
                         -4.12296504e-02,  -2.18287092e-02,   2.72300653e-02,
                          1.27314962e-02,  -8.09379853e-03,  -1.76211707e-02,
                          7.36523746e-03,  -1.83424894e-02,  -2.26735715e-02,
                         -4.31926250e-02,  -9.51540053e-01,  -9.70477760e-01,
                         -9.77567732e-01,  -9.66162026e-01,  -9.53297019e-01,
                         -9.41018105e-01,  -9.50338125e-01,  -9.42555308e-01,
                         -9.55905974e-01,  -9.27634239e-01,  -9.61202264e-01,
                         -9.33690250e-01,  -9.16115940e-01,  -9.45317626e-01,
                         -9.30485845e-01,  -9.48369980e-01,  -9.47928011e-01,
                         -9.61503088e-01,  -9.35649753e-01,  -9.82016265e-01,
                         -9.57062542e-01,  -9.12593246e-01,  -9.50690329e-01,
                         -9.10071433e-01,  -9.36186314e-01,  -9.26117361e-01,
                         -9.49987590e-01,  -9.37652588e-01,  -9.41871047e-01,
                         -9.44101095e-01,  -9.44727898e-01,  -9.21862960e-01,
                         -9.39394951e-01,  -9.07467365e-01,  -9.12096441e-01,
                         -9.48612273e-01,  -9.46775556e-01,  -9.13253725e-01,
                         -8.92857075e-01,  -9.12587047e-01,  -9.13443327e-01,
                         -9.37751472e-01,  -9.34405446e-01,  -9.27108228e-01,
                         -9.54457939e-01,  -9.40348685e-01,  -9.17840660e-01,
                         -9.44075704e-01,  -9.27298307e-01,  -9.65939999e-01,
                         -9.25520778e-01,  -9.18206573e-01,  -9.47345436e-01,
                         -9.25836325e-01,  -9.34587121e-01,  -8.93309891e-01,
                         -9.22993600e-01,  -9.30119097e-01,  -9.18150604e-01,
                         -9.28888202e-01,  -9.15820420e-01,  -9.13558841e-01,
                         -9.26137090e-01,  -9.16777313e-01,  -9.12215948e-01,
                         -8.97224307e-01,  -9.18801069e-01,  -9.02109265e-01,
                         -9.19676840e-01,  -9.32559073e-01,  -9.38032031e-01,
                         -9.62446511e-01,  -9.30252731e-01,  -9.32301939e-01,
                         -9.48594570e-01,  -9.62920666e-01,  -9.40201938e-01,
                         -9.27480817e-01,  -9.25129771e-01,  -9.27971303e-01,
                         -9.27863300e-01,  -9.28616762e-01,  -9.44134653e-01,
                         -9.42580462e-01,  -9.34930205e-01,  -9.39711869e-01,
                         -9.20005918e-01,  -9.24365997e-01,  -9.26662505e-01,
                         -9.25704479e-01,  -9.28479373e-01,  -9.42505836e-01,
                         -9.48613644e-01,  -9.30603266e-01,  -9.09707606e-01,
                         -9.10333037e-01,  -9.39244330e-01,  -9.21438992e-01,
                         -9.15695608e-01,  -9.13439214e-01,  -8.98609340e-01,
                         -9.27585959e-01,  -9.22590435e-01,  -9.21360552e-01,
                         -9.46655035e-01,  -9.41059351e-01,  -9.36482728e-01,
                         -9.37981904e-01,  -9.40568864e-01,  -9.35890913e-01,
                         -9.34121907e-01,  -9.30711031e-01,  -9.21804309e-01,
                         -9.38708961e-01,  -9.30011868e-01,  -9.43165541e-01,
                         -9.40244079e-01,  -9.41869020e-01,  -9.55393493e-01,
                         -9.17165995e-01,  -9.34917629e-01,  -9.32910264e-01,
                         -9.35528994e-01,  -9.49570656e-01,  -9.27165449e-01,
                         -9.21602905e-01,  -9.27678704e-01,  -9.19964194e-01,
                         -9.18203533e-01,  -9.20176625e-01,  -9.27224874e-01,
                         -9.50720370e-01,  -9.46135163e-01,  -9.26648438e-01,
                         -9.27993000e-01,  -9.42408860e-01,  -9.34737444e-01,
                         -9.44107533e-01,  -9.38835502e-01,  -9.32578146e-01,
                         -9.19658482e-01,  -9.38251793e-01,  -9.29754674e-01,
                         -9.34396923e-01,  -9.32316124e-01,  -9.37163413e-01,
                         -9.32864010e-01,  -9.26912129e-01,  -9.41987216e-01,
                         -9.31091249e-01,  -9.21311736e-01,  -9.24226880e-01,
                         -9.26004767e-01,  -9.32689726e-01,  -9.41317618e-01,
                         -9.31921840e-01,  -9.32268679e-01,  -9.43484008e-01,
                         -9.31316257e-01,  -9.29538190e-01,  -9.30363536e-01,
                         -9.27504838e-01,  -9.33913112e-01,  -9.30832684e-01,
                         -9.26616371e-01,  -9.26577091e-01,  -9.37834501e-01,
                         -9.46670353e-01,  -9.32345629e-01,  -9.22652841e-01,
                         -9.43282604e-01,  -9.36897993e-01,  -9.31730092e-01,
                         -9.27147090e-01,  -9.32813346e-01,  -9.18297946e-01,
                         -9.33832049e-01,  -9.39263105e-01,  -9.29164469e-01,
                         -9.27320361e-01,  -9.26000595e-01,  -9.34491396e-01,
                         -9.24886763e-01,  -9.28762674e-01,  -9.32169557e-01,
                         -9.26321447e-01,  -9.34923887e-01,  -9.21845078e-01,
                         -9.30329263e-01,  -9.28516030e-01,  -9.24148142e-01,
                         -9.19512808e-01,  -9.26453352e-01,  -9.21586215e-01,
                         -9.29837286e-01,  -9.20455635e-01,  -9.31216359e-01,
                         -9.29037213e-01,  -9.24051821e-01,  -9.24792051e-01,
                         -9.26090300e-01,  -9.26355660e-01,  -9.24560249e-01,
                         -9.28774655e-01,  -9.25701916e-01,  -9.23053682e-01,
                         -9.23345447e-01,  -9.24177170e-01,  -9.27420616e-01,
                         -9.28138494e-01,  -9.23019350e-01,  -9.36310709e-01,
                         -9.24036384e-01,  -9.31948960e-01,  -9.39743698e-01,
                         -9.24810767e-01,  -9.25286829e-01,  -9.28411067e-01,
                         -9.25390363e-01,  -9.26385999e-01,  -9.39620912e-01,
                         -9.32034373e-01,  -9.28914249e-01,  -9.12849188e-01,
                         -9.22107577e-01,  -9.18932855e-01,  -9.27724600e-01,
                         -9.20322359e-01,  -9.33604777e-01,  -9.25631225e-01,
                         -9.25085604e-01,  -9.27202761e-01,  -9.29666519e-01,
                         -9.09206748e-01,  -9.22806978e-01,  -9.32830632e-01,
                         -9.32747245e-01,  -9.29101765e-01,  -9.18768346e-01,
                         -9.30133522e-01,  -9.27003264e-01,  -9.40278947e-01,
                         -9.27246869e-01,  -9.28571463e-01,  -9.34870958e-01,
                         -9.30045545e-01,  -9.31742311e-01,  -9.31377351e-01,
                         -9.27195430e-01,  -9.28869307e-01,  -9.23042059e-01,
                         -9.18079674e-01,  -9.15870607e-01,  -9.25289333e-01,
                         -9.23425615e-01,  -9.18225706e-01,  -9.28830564e-01,
                         -9.20751691e-01,  -9.21949923e-01,  -9.28453684e-01,
                         -9.25964773e-01,  -9.20820653e-01,  -9.26545739e-01,
                         -9.37124074e-01,  -9.29088950e-01,  -9.34121013e-01,
                         -9.32454646e-01,  -9.35929179e-01,  -9.30668235e-01,
                         -9.27731335e-01,  -9.27798510e-01,  -9.31138098e-01,
                         -9.25081789e-01,  -9.33529556e-01,  -9.30654585e-01,
                         -9.28726494e-01,  -9.22817051e-01,  -9.33941305e-01,
                         -9.28102791e-01,  -9.36305761e-01,  -9.32852626e-01,
                         -9.36078548e-01,  -9.33012843e-01,  -9.41426039e-01,
                         -9.41093147e-01,  -9.43498969e-01,  -9.49020326e-01,
                         -9.44191575e-01,  -9.37285542e-01,  -9.33567822e-01,
                         -9.47171330e-01,  -9.33336079e-01,  -9.27917898e-01,
                         -9.26151991e-01,  -9.40456092e-01,  -9.37478006e-01,
                         -9.33473349e-01,  -9.26216781e-01,  -9.31471646e-01,
                         -9.29830015e-01,  -9.43097651e-01,  -9.23418164e-01,
                         -9.33375120e-01,  -9.33799148e-01,  -9.19816136e-01,
                         -9.24764931e-01,  -9.26949859e-01,  -9.28688824e-01,
                         -9.28879738e-01,  -9.36078608e-01,  -9.31485236e-01,
                         -9.28967237e-01,  -9.32641447e-01,  -9.30729806e-01,
                         -9.36833799e-01,  -9.42822099e-01,  -9.39924300e-01,
                         -9.50965762e-01,  -9.43314135e-01,  -9.34354901e-01,
                         -9.28937376e-01,  -9.22797501e-01,  -9.42688048e-01,
                         -9.26106811e-01,  -9.27601576e-01,  -9.28180933e-01,
                         -9.30796981e-01,  -9.22541916e-01,  -9.42063451e-01,
                         -9.39238787e-01,  -9.34524655e-01,  -9.35856402e-01,
                         -9.38758016e-01,  -9.28833306e-01,  -9.32217002e-01,
                         -9.40630674e-01,  -9.30202842e-01,  -9.29168761e-01,
                         -9.20019031e-01,  -9.25367355e-01,  -9.31166470e-01,
                         -9.23679233e-01,  -9.29637253e-01,  -9.38222826e-01,
                         -9.39473569e-01,  -9.48995650e-01,  -9.50200737e-01,
                         -9.26071405e-01,  -9.19844687e-01,  -9.34875488e-01,
                         -9.38219190e-01,  -9.34895694e-01,  -9.41860616e-01,
                         -9.29754257e-01,  -9.34370518e-01,  -9.40509021e-01,
                         -9.29996073e-01,  -9.46616352e-01,  -9.39603150e-01,
                         -9.34556365e-01,  -9.32423830e-01,  -9.34188545e-01,
                         -9.41643953e-01,  -9.37489808e-01,  -9.36855316e-01,
                         -9.39556599e-01,  -9.30822253e-01,  -9.28230047e-01,
                         -9.29016471e-01,  -9.33638453e-01,  -9.23141301e-01,
                         -9.39674675e-01,  -9.36853528e-01,  -9.21817243e-01,
                         -9.35164273e-01,  -9.24866498e-01,  -9.36799943e-01,
                         -9.27355587e-01,  -9.40902770e-01,  -9.37225997e-01,
                         -9.32450771e-01,  -9.35994387e-01,  -9.39648211e-01,
                         -9.39628005e-01,  -9.35602903e-01,  -9.36232448e-01,
                         -9.30899978e-01,  -9.38518465e-01,  -9.36701596e-01,
                         -9.23227072e-01,  -9.26445782e-01,  -9.23020184e-01,
                         -9.22046661e-01,  -9.35050607e-01,  -9.39375103e-01,
                         -9.24932361e-01,  -9.24320996e-01,  -9.21421170e-01,
                         -9.37018633e-01,  -9.42099988e-01,  -9.27903175e-01,
                         -9.25897241e-01,  -9.32759881e-01,  -9.36863720e-01,
                         -9.35180247e-01,  -9.18053567e-01,  -9.34306324e-01,
                         -9.26910341e-01,  -9.26094890e-01,  -9.21593726e-01,
                         -9.31006014e-01,  -9.30373847e-01,  -9.34226394e-01,
                         -9.39856231e-01,  -9.38832939e-01,  -9.15803969e-01,
                         -9.46032047e-01,  -9.29576695e-01,  -9.34186697e-01,
                         -9.24786985e-01,  -9.23319876e-01,  -9.32027817e-01,
                         -9.39621449e-01,  -9.26711440e-01,  -9.25488412e-01,
                         -9.25569475e-01,  -9.34724271e-01,  -9.37269092e-01,
                         -2.48177480e-02,   9.54547431e-03,   1.40181370e-02,
                          1.77589394e-02,   1.42353578e-02,   2.19203229e-03,
                          7.31294695e-03,  -8.69398750e-03,  -1.22693265e-02,
                          1.44669937e-03,  -4.38880501e-03,   5.51059202e-04,
                         -6.08540187e-03,   7.23398197e-03,   1.42341305e-03,
                         -1.19216542e-03,  -1.86253898e-03,  -7.63991103e-03,
                         -3.05771921e-03,  -2.00801827e-02,   4.67037456e-03,
                         -1.49659847e-03,  -1.14574404e-02,   7.88884517e-03,
                         -7.25229224e-03,   4.99686692e-03,  -4.96086339e-03,
                         -5.38297510e-03,   4.31817025e-03,   1.15859099e-02,
                         -4.61179856e-03,   1.29623767e-02,  -1.04736527e-02,
                         -3.53927305e-03,  -4.48797271e-03,   7.60394894e-03,
                         -3.99657758e-03,  -6.24639579e-05,  -9.33978613e-03,
                         -5.48323058e-03,  -1.28370048e-02,   7.21782679e-03,
                         -6.48719352e-03,   1.34798642e-02,  -1.57342921e-03,
                         -5.27474936e-03,   5.19037852e-03,   7.95452483e-03,
                         -6.58641662e-03,  -6.06142962e-03,  -1.59734604e-03,
                          3.25685809e-03,  -1.29019087e-02,   6.84165047e-04,
                         -1.21300183e-02,  -3.04725417e-03,  -7.55409827e-04,
                          1.16309300e-02,  -1.50369378e-02,   7.86743686e-03,
                         -1.64892711e-02,  -5.04605239e-03,  -2.82776752e-03,
                         -1.31564215e-02,   2.19501927e-03,   1.36230059e-03,
                         -7.47909024e-03,  -9.29170940e-03,  -5.18755801e-03,
                          7.87490804e-04,  -3.40561289e-03,   2.26200884e-03,
                         -9.07911174e-03,   1.09111983e-03,  -6.30031456e-04,
                         -3.38225742e-04,  -1.91809461e-02,  -8.96161981e-03,
                         -2.55496707e-02,  -5.87856304e-03,  -1.98006034e-02,
                         -6.27449155e-03,   5.85305225e-03,   3.94778035e-04,
                         -2.57641473e-03,   5.34218270e-03,   5.54845296e-03,
                         -3.75718647e-03,  -1.14671299e-02,  -5.58269629e-03,
                          2.58896570e-03,   1.97378613e-05,  -4.29887587e-04,
                          1.15175555e-02,  -1.80198083e-04,   9.62164626e-03,
                          6.91656838e-04,   2.73293164e-03,  -6.25961879e-03,
                          8.05706717e-03,  -5.61728608e-03,  -7.49790622e-03,
                         -1.07698869e-02,   5.45780314e-03,  -7.79991364e-03,
                         -1.25468487e-03,  -6.38458133e-03,  -1.59059581e-03,
                         -7.37836352e-03,  -9.65073332e-03,   5.90571668e-03,
                          5.42396167e-03,   2.60306918e-03,  -6.64016185e-03,
                         -8.66195560e-03,  -6.90247864e-03,  -7.43135344e-03,
                         -1.77831342e-03,   2.89651728e-03,   7.29171210e-04,
                          3.22895619e-04,  -6.50731241e-03,  -8.80610850e-03,
                         -2.58078775e-03,   6.33461983e-04,   3.34112509e-03,
                          5.38881728e-03,  -1.78770418e-03,  -1.25709665e-03,
                         -5.07462630e-03,  -3.02272057e-03,  -1.33632537e-04,
                         -6.11889642e-03,  -7.76513014e-04,  -3.48306727e-03,
                         -1.06138624e-02,  -9.78011731e-03,  -2.51212809e-03,
                         -6.07947633e-03,   5.80715202e-03,  -1.38897579e-02,
                          8.00166558e-03,  -5.06755058e-03,  -1.70732643e-02,
                         -7.02960358e-04,  -2.53876857e-03,  -1.17673762e-02,
                         -2.74903793e-03,   7.02180667e-03,   7.06762401e-03,
                          5.19239530e-03,  -2.08431273e-03,  -8.34169332e-03,
                         -3.26159154e-03,  -3.77280777e-03,   4.39697597e-03,
                          2.28413078e-03,   4.57011908e-03,   1.99632393e-03,
                          2.77673872e-03,   2.20073690e-03,  -6.36801776e-03,
                         -5.34781022e-03,  -6.56724675e-03,  -6.82354113e-03,
                          4.83054388e-03,  -1.26702590e-02,  -4.53464221e-03,
                         -5.01335459e-03,   1.03043839e-02,   7.46213831e-03,
                         -9.04717576e-03,  -7.02861231e-03,  -5.86799433e-05,
                          1.16093699e-02,   7.75738154e-03,   1.09712854e-02,
                          1.20863700e-02,  -3.76591203e-03,  -2.99381372e-03,
                          2.08463846e-03,  -6.86443737e-03,   8.43744352e-03,
                          1.87592162e-03,   1.04305032e-03,  -1.65693392e-03,
                         -4.61722491e-03,  -4.03079297e-03,   1.22439470e-02,
                         -3.86313908e-03,   1.10773481e-02,   6.37436612e-03,
                          5.97581081e-03,   4.07094089e-03,   1.97122898e-03,
                          7.95439992e-04,  -3.52960522e-03,  -2.01810617e-03,
                         -2.90404377e-03,   4.10363171e-03,   5.35023585e-03,
                          7.80385733e-03,   5.56053268e-03,   1.01759491e-04,
                          2.44382862e-03,  -5.43303369e-03,  -6.03401940e-03,
                          4.96292859e-03,  -2.84862122e-03,  -2.75900384e-04,
                         -9.24807508e-03,  -5.59149776e-03,   9.46772867e-04,
                         -2.77625374e-03,  -1.02861428e-04,  -3.96805163e-03,
                         -6.89048227e-03,  -1.04330678e-03,  -6.77061325e-04,
                         -4.55294549e-03,  -3.55904549e-03,  -2.70685228e-03,
                          2.21578288e-03,   1.02608465e-03,  -1.08226901e-02,
                          7.38593843e-03,   1.25789642e-02,   3.35523556e-03,
                          1.36263259e-02,   1.52251758e-02,   8.54082499e-03,
                          9.57651529e-03,   5.20190364e-03,  -4.80160909e-03,
                          1.29310722e-02,   1.10227643e-02,   1.40524702e-02,
                          6.09697588e-03,  -5.58284158e-03,  -5.63896447e-03,
                         -4.55150381e-03,   5.52633777e-03,  -3.80379381e-03,
                         -3.71011510e-03,   2.06984187e-04,   4.25133295e-03,
                         -9.45560727e-03,  -3.57953878e-03,  -3.95283941e-03,
                          2.14774697e-03,   7.11249141e-03,   3.10984300e-03,
                         -5.23284124e-03,  -2.94821151e-03,   1.51186611e-03,
                         -4.37651761e-03,  -6.83731167e-03,  -8.30586255e-03,
                          4.09823988e-04,   2.50616786e-03,  -4.44957102e-03,
                         -1.77529873e-03,   2.45673303e-03,   2.75479699e-03,
                         -3.63125373e-03,  -2.00948492e-03,   1.95687590e-03,
                         -3.02791828e-03,  -1.95327215e-04,  -1.12055540e-02,
                         -9.38425865e-03,  -8.99417209e-04,  -1.55837624e-03,
                         -1.17549091e-03,  -5.38739003e-03,  -2.90665659e-03,
                         -6.42913021e-03,  -1.07344305e-02,  -1.43787696e-03,
                          3.67148477e-03,   4.08075424e-03,   3.54900351e-03,
                          2.88135349e-03,   1.62657863e-03,   1.96002936e-03,
                          8.50168243e-03,   8.66006967e-03,   1.14121158e-02,
                          8.27532075e-03,   8.06615967e-03,   1.72016025e-03,
                          4.28668503e-03,  -3.72834899e-03,  -2.22483394e-03,
                          3.87493451e-03,   8.93359352e-03,   1.63295604e-02,
                          4.99769161e-03,   5.21245878e-03,   5.56998560e-03,
                         -7.27277854e-03,   2.50548171e-03,  -5.52005228e-03,
                         -2.07240621e-04,  -1.40237226e-03,  -6.06718194e-03,
                          6.24399772e-03,  -7.72913313e-03,  -6.60993811e-03,
                         -3.34744575e-03,  -4.74324124e-03,  -2.61326390e-03,
                          1.12706795e-03,   5.54586807e-03,  -3.51557112e-03,
                         -1.35362369e-03,  -8.44982173e-03,   3.09044472e-03,
                         -1.13799726e-03,   1.79171690e-03,  -4.60407091e-03,
                         -7.70459976e-03,  -1.04031982e-02,  -8.03671218e-03,
                         -1.03269080e-02,  -9.80139431e-03,  -2.45366292e-03,
                         -9.02548432e-03,  -1.56332459e-03,  -4.47490159e-03,
                         -1.76389818e-03,  -4.71643405e-04,  -2.37133633e-03,
                         -5.75463334e-03,   3.55792278e-03,   4.53649275e-03,
                          6.01204345e-03,  -4.21441486e-03,   5.46706188e-03,
                         -2.63141468e-03,   4.81115235e-03,  -6.98318332e-03,
                          1.56641559e-04,  -9.60400142e-03,  -9.96830594e-03,
                         -8.50585406e-04,   9.78576601e-04,   2.10700976e-03,
                         -2.99282256e-03,   4.88871057e-03,   5.91385271e-03,
                         -1.73809612e-03,  -1.00842873e-02,  -2.02538329e-03,
                         -8.13622680e-03,  -4.23692493e-03,   1.04825513e-03,
                         -6.75051531e-04,  -9.13638432e-05,   9.49983671e-03,
                          9.70093068e-03,   3.73710226e-03,   4.40161256e-03,
                         -1.94257149e-03,   1.52629185e-02,  -8.42008274e-03,
                          6.97698072e-03,  -3.45230312e-03,  -4.04342019e-04,
                          4.63014329e-03,   1.19002398e-04,  -6.17498439e-03,
                         -8.94660130e-03,  -2.16153145e-04,   3.14333779e-03,
                          4.84213838e-03,   1.05678095e-02,  -5.84259443e-03,
                         -8.04276264e-04,   5.41613030e-04,  -2.75312690e-03,
                          3.16092023e-03,   7.65406294e-03,   4.28969320e-03,
                         -6.22155005e-03,   4.30926448e-03,   5.26145706e-03,
                          5.63241495e-03,  -9.30579938e-03,  -9.02809668e-03,
                          2.75630085e-03,  -6.10683067e-03,   1.11223687e-03,
                         -5.59235737e-03,   2.06524716e-03,  -5.19532710e-04,
                         -6.43060659e-04,   8.25227005e-04,  -6.51677931e-03,
                         -9.45802603e-04,   4.94001666e-03,  -3.25204828e-03,
                         -8.30512121e-03,   3.22894240e-03,  -8.81582499e-03,
                          7.92159792e-03,   5.10623632e-03,   5.53241605e-03,
                          7.12425215e-03,  -5.07141091e-03,  -7.39078270e-03,
                         -3.01820878e-03,  -1.49802538e-02,  -9.33020748e-03,
                         -2.48946552e-03,   8.09832383e-03,  -8.40579253e-03,
                          3.28264618e-03,  -1.00352271e-02,  -1.08938024e-03,
                          8.12048744e-03,   7.42665492e-03,   4.82628820e-03,
                          2.82456574e-04,  -3.69371090e-04,  -1.17805507e-03,
                         -3.63026955e-03,  -1.01275742e-03,   1.96075696e-03,
                          5.85543644e-03,  -6.28479710e-03,  -7.02888984e-03,
                         -9.71339177e-03,  -9.15611535e-03,   7.26752495e-03,
                          3.76599515e-03,  -6.37716614e-03,  -9.41164698e-03,
                         -9.21848230e-03,  -3.98374919e-04,  -1.08037489e-02,
                         -1.03606172e-02,   1.72865693e-04,  -1.00449636e-03,
                         -5.11367945e-03,  -1.92771968e-03,   1.07572041e-02,
                         -1.09237283e-02,  -1.07866302e-02,   1.05063152e-02,
                         -2.75790179e-03,  -8.25777929e-03,  -7.94476655e-04,
                          2.99695320e-03,   4.93810372e-03,  -6.30964991e-03,
                         -9.38380072e-06,  -1.40532954e-02,  -5.55351237e-03,
                         -7.23392656e-03,  -1.38118872e-02,  -1.45311207e-02,
                         -8.81091133e-03,  -4.79855982e-04,   2.30080541e-03,
                         -4.73921467e-03,  -2.52339686e-03,  -1.20147578e-02,
                         -9.37575042e-01,  -9.23857987e-01,  -9.44291830e-01,
                         -9.33007061e-01,  -9.17353690e-01,  -9.34266329e-01,
                         -9.38151658e-01,  -9.28318024e-01,  -9.28097546e-01,
                         -9.25411105e-01,  -9.29629862e-01,  -9.38768864e-01,
                          7.98744429e-03,  -2.97886482e-03,   8.58527666e-04,
                         -2.55811843e-03,  -6.69845380e-03,  -2.08449969e-03,
                         -5.57885692e-03,   2.85722176e-03,   7.56465318e-03,
                          4.89994511e-03,  -4.97882029e-05,   2.86559388e-03,
                         -1.56360529e-02,   3.32491496e-03,  -9.21702664e-03,
                         -1.78512465e-02,  -1.58378319e-03,   3.31561430e-03,
                          2.50172545e-03,   5.64749585e-03,  -1.64104241e-03,
                          4.25956631e-03,   1.26255304e-02,   8.95051053e-04,
                          1.05064400e-02,   1.20117504e-03,   6.10590912e-03,
                          8.75024218e-03,   1.00701833e-02,   1.47374608e-02,
                         -1.36555722e-02,  -2.79872213e-03,   4.00716020e-03,
                          2.71200854e-03,   1.57570234e-03,   6.78849407e-04,
                         -3.12788971e-03,  -7.41307111e-03,   9.21980664e-03,
                         -3.00774374e-03,  -1.18985698e-02,  -5.66742057e-03,
                          6.71379780e-03,   1.07274728e-03,   1.31564904e-02,
                          1.27931423e-02,   8.82967189e-03,   7.61931355e-04,
                          1.20477192e-03,   9.62463324e-04,   1.47507945e-03,
                          1.35973631e-03,   7.65721640e-03,  -5.82611375e-03,
                          7.24105071e-03,  -4.14349575e-04,   6.69026887e-03,
                          1.36245304e-04,   9.88412928e-03,   1.07922303e-02,
                          1.04034683e-02,   1.45513366e-03,   7.45786913e-03,
                         -4.93466668e-03,  -9.20547724e-01,  -9.29613292e-01,
                         -9.32460606e-01,  -9.35488582e-01,  -9.38286185e-01,
                         -9.26494896e-01,  -9.31564569e-01,  -9.29163575e-01,
                         -9.25882876e-01,  -9.26030159e-01,  -9.22753334e-01,
                         -9.25437689e-01,  -9.21533167e-01,  -9.27850783e-01,
                         -9.25942719e-01,  -9.18686688e-01,  -9.20643449e-01,
                         -9.32864785e-01,  -9.23962593e-01,  -9.31141734e-01,
                         -9.27623510e-01,  -9.17122722e-01,  -9.17969167e-01,
                         -9.25952256e-01,  -9.26395833e-01,  -9.33546007e-01,
                         -9.22140241e-01,  -9.30954456e-01,  -9.27131116e-01,
                         -9.29838300e-01,  -9.41253364e-01,  -9.36600029e-01,
                         -9.31279898e-01,  -9.35692668e-01,  -9.29517746e-01,
                         -9.41342413e-01,  -9.40468669e-01,  -9.33815897e-01,
                         -9.24974918e-01,  -9.25663531e-01,  -9.46171224e-01,
                         -9.28610027e-01,  -9.30842757e-01,  -9.31579053e-01,
                         -9.25167263e-01,  -9.34790373e-01,  -9.35520768e-01,
                         -9.30539489e-01,  -9.28485334e-01,  -9.33301449e-01,
                         -9.19572413e-01,  -9.29284334e-01,  -9.25513268e-01,
                         -9.28033173e-01,  -9.24163818e-01,  -9.38867331e-01,
                         -9.26301777e-01,  -9.35100615e-01,  -9.26939666e-01,
                         -9.30172503e-01,  -9.35509920e-01,  -9.33412910e-01,
                         -9.34757650e-01,  -9.33164537e-01,  -9.31748390e-01,
                         -9.34052289e-01,  -9.16371405e-01,  -9.17036891e-01,
                         -9.27953601e-01,  -9.28830981e-01,  -9.33919668e-01,
                         -9.31910753e-01,  -9.27068889e-01,  -9.26677048e-01,
                         -9.22656655e-01,  -9.33499515e-01,  -9.29252148e-01,
                         -9.34692800e-01,  -9.44086134e-01,  -9.42191958e-01,
                         -9.24037933e-01,  -9.30152237e-01,  -9.37974274e-01,
                         -9.35769260e-01,  -9.30244684e-01,  -9.33593690e-01,
                         -9.37618434e-01,  -9.34921980e-01,  -9.33521271e-01,
                         -9.34240937e-01,  -9.30877686e-01,  -9.39670920e-01,
                         -9.30860639e-01,  -9.37937558e-01,  -9.33379889e-01,
                         -9.36721444e-01,  -9.30583179e-01,  -9.44556296e-01,
                         -9.30446565e-01,  -9.46676314e-01,  -9.36500311e-01,
                         -9.35991704e-01,  -9.27337348e-01,  -9.40307558e-01,
                         -9.39565897e-01,  -9.33165848e-01,  -9.38345075e-01,
                         -9.28386033e-01,  -9.36361611e-01,  -9.29853439e-01,
                         -9.31121349e-01,  -9.40547943e-01,  -9.31015015e-01,
                         -9.34934735e-01,  -9.31237519e-01,  -9.32177067e-01,
                         -9.31145072e-01,  -9.22655702e-01,  -9.32179749e-01,
                         -9.34767306e-01,  -9.25471842e-01,  -9.26101804e-01,
                         -9.23227727e-01,  -9.33187902e-01,  -9.36168909e-01,
                         -9.34922516e-01,  -9.27365541e-01,  -9.35298085e-01,
                         -9.23390031e-01,  -9.31079328e-01,  -9.32466745e-01,
                         -9.30752635e-01,  -9.29854453e-01,  -9.40407634e-01,
                         -9.34368789e-01,  -9.30723667e-01,  -9.31501448e-01,
                         -9.36236203e-01,  -9.39054370e-01,  -9.40121591e-01,
                         -9.37682927e-01,  -9.37171757e-01,  -9.36974466e-01,
                         -9.35712039e-01,  -9.29679215e-01,  -9.33513403e-01,
                         -9.40161705e-01,  -9.32682395e-01,  -9.33377743e-01,
                         -9.42869008e-01,  -9.35656905e-01,  -9.44699407e-01,
                         -9.35313165e-01,  -9.37474012e-01,  -9.45798218e-01,
                         -9.31813836e-01,  -9.31404293e-01,  -9.27496850e-01,
                         -9.29458797e-01,  -9.30411220e-01,  -9.34609830e-01,
                         -9.29667771e-01,  -9.28847551e-01,  -9.34068024e-01,
                         -9.38176274e-01,  -9.26874280e-01,  -9.37334538e-01,
                         -9.35508430e-01,  -9.26968932e-01,  -9.27855849e-01,
                         -9.26723123e-01,  -9.30100083e-01,  -9.32778060e-01,
                         -9.44154322e-01,  -9.38004434e-01,  -9.37398970e-01,
                         -9.38183844e-01,  -9.44892049e-01,  -9.31807041e-01,
                         -9.31045949e-01,  -9.33580041e-01,  -9.36187983e-01,
                         -9.32695925e-01,  -9.41243410e-01,  -9.34276700e-01,
                         -9.44489181e-01,  -9.33494747e-01,  -9.44485188e-01,
                         -9.32021976e-01,  -9.36746955e-01,  -9.36479270e-01,
                         -9.30141687e-01,  -9.35712159e-01,  -9.28141594e-01,
                         -9.33722198e-01,  -9.33774710e-01,  -9.33100104e-01,
                         -9.34946895e-01,  -9.29367661e-01,  -9.29989219e-01,
                         -9.35517192e-01,  -9.34105098e-01,  -9.23704267e-01,
                         -9.33654010e-01,  -9.37662780e-01,  -9.40502465e-01,
                         -9.38489676e-01,  -9.42075312e-01,  -9.31250513e-01,
                         -9.30295885e-01,  -9.32968676e-01,  -9.29901600e-01,
                         -9.33612943e-01,  -9.34797645e-01,  -9.32989001e-01,
                         -9.31328475e-01,  -9.31118429e-01,  -9.31859493e-01,
                         -9.32912588e-01,  -9.35155153e-01,  -9.26392794e-01,
                         -9.29596722e-01,  -9.30226564e-01,  -9.31888580e-01,
                         -9.39773738e-01,  -9.18909490e-01,  -9.29328978e-01,
                         -9.34132218e-01,  -9.32310283e-01,  -9.30309057e-01,
                         -9.31475937e-01,  -9.26181853e-01,  -9.23757195e-01,
                         -9.26115870e-01,  -9.28577304e-01,  -9.26792562e-01,
                         -9.28664029e-01,  -9.20581460e-01,  -9.31741655e-01,
                         -9.35042500e-01,  -9.34696853e-01,  -9.35496569e-01,
                         -9.33596432e-01,  -9.33538020e-01,  -9.29294288e-01,
                         -9.29877877e-01,  -9.35583532e-01,  -9.29490805e-01,
                         -9.26104844e-01,  -9.37695146e-01,  -9.37683403e-01,
                         -9.34633911e-01,  -9.32646692e-01,  -9.40791011e-01,
                         -9.35965538e-01,  -9.33039248e-01,  -9.32287753e-01,
                         -9.26724851e-01,  -9.33172524e-01,  -9.33660984e-01,
                         -9.39713180e-01,  -9.32748914e-01,  -9.31238651e-01,
                         -9.32902813e-01,  -9.33345139e-01,  -9.35025215e-01,
                         -9.33784723e-01,  -9.32056189e-01,  -9.37564075e-01,
                         -9.31932032e-01,  -9.27554071e-01,  -9.36447918e-01,
                         -9.36554432e-01,  -9.35227036e-01,  -9.32467937e-01,
                         -9.39763546e-01,  -9.42605197e-01,  -9.35784876e-01,
                         -9.36588824e-01,  -9.37944531e-01,  -9.39527452e-01,
                         -9.35924172e-01,  -9.42197144e-01,  -9.36997354e-01,
                         -9.36919630e-01,  -9.33044970e-01,  -9.41543460e-01,
                         -9.44240212e-01,  -9.42231536e-01,  -9.38130260e-01,
                         -9.33219433e-01,  -9.33423102e-01,  -9.43832934e-01,
                         -9.41097260e-01,  -9.32682812e-01,  -9.38073695e-01,
                         -9.35972273e-01,  -9.33708966e-01,  -9.35608923e-01,
                         -9.36637163e-01,  -9.37197506e-01,  -9.40888226e-01,
                         -9.37156141e-01,  -9.38339293e-01,  -9.41404283e-01,
                         -9.34495628e-01,  -9.42987859e-01,  -9.30034757e-01,
                         -9.32131588e-01,  -9.31987882e-01,  -9.33822215e-01,
                         -9.39241707e-01,  -9.40706968e-01,  -9.37836528e-01,
                         -9.33967888e-01,  -9.33646023e-01,  -9.36573505e-01,
                         -9.43239152e-01,  -9.39949155e-01,  -9.32382643e-01,
                         -9.32316601e-01,  -9.39110518e-01,  -9.38372970e-01,
                         -9.35659349e-01,  -9.42954600e-01,  -9.48597014e-01,
                         -9.50013101e-01,  -9.40651178e-01,  -9.36099052e-01,
                         -9.36462522e-01,  -9.38603878e-01,  -9.28856611e-01,
                         -9.29172635e-01,  -9.31450784e-01,  -9.37421501e-01,
                         -9.22358692e-01,  -9.27363634e-01,  -9.28567708e-01,
                         -9.33971107e-01,  -9.34792221e-01,  -9.28062320e-01,
                         -9.24473405e-01,  -9.43516016e-01,  -9.48374093e-01,
                         -9.37598228e-01,  -9.42128301e-01,  -9.40632999e-01,
                         -9.30078328e-01,  -9.31910813e-01,  -9.25867558e-01,
                         -9.29078221e-01,  -9.30952311e-01,  -9.38141584e-01,
                         -9.36667323e-01,  -9.23183858e-01,  -9.33084011e-01,
                         -9.30980504e-01,  -9.26600814e-01,  -9.33708072e-01,
                         -9.37736273e-01,  -9.28438723e-01,  -9.43947971e-01,
                         -9.37236607e-01,  -9.35495377e-01,   4.29223664e-03,
                         -7.75300141e-04,   5.29207569e-03,  -5.22934133e-03,
                         -1.14915799e-02,   2.22367677e-03,  -6.21947786e-03,
                          7.99577450e-04,  -4.36574733e-03,  -6.34572934e-03,
                          3.03379522e-04,  -8.47633055e-04,  -9.72049497e-03,
                         -9.70689754e-04,  -5.80067886e-03,  -5.93117904e-03,
                         -4.62218042e-04,   5.42245107e-03,   4.67457430e-05,
                         -4.93798591e-03,   3.68991983e-03,   7.90460501e-03,
                         -2.57707317e-03,  -6.65233843e-03,  -1.19201303e-03,
                          3.51326307e-03,  -8.71529162e-04,   9.41311650e-04,
                          5.38446521e-03,   1.92222383e-03,  -1.36347185e-03,
                          1.73903874e-03,  -2.67212396e-03,   3.62649956e-03,
                          4.92207380e-03,  -1.04580176e-04,   4.05215938e-03,
                          1.09643547e-03,   6.98075071e-03,   5.27543575e-03,
                          3.09255836e-03,   3.97318741e-03,   5.70658478e-04,
                         -8.64489283e-03,   2.62855925e-03,   7.38107320e-03,
                         -6.36698504e-04,  -1.71697920e-03,  -1.30267814e-03,
                         -6.46318635e-03,  -2.16415129e-03,   3.68946930e-03,
                          8.95757927e-04,  -7.10334338e-04,  -6.21297723e-03,
                         -6.63942017e-04,  -4.98807942e-03,   1.62689737e-03,
                          1.13686756e-03,   1.00239646e-03,   5.43419784e-03,
                          5.41624101e-03,  -5.22900885e-03,   7.10513815e-03,
                         -2.65296811e-04,  -4.91016731e-03,   2.24845996e-03,
                         -4.36180411e-03,  -5.54796774e-03,  -2.82095489e-03,
                         -6.37072744e-03,  -4.09758138e-03,  -3.55891394e-03,
                         -1.86019647e-03,   2.25367164e-03,  -1.46293035e-03,
                         -1.70557851e-05,  -1.34153699e-03,  -1.77278987e-03,
                         -7.19679985e-03,   9.50847927e-04,   1.88906165e-03,
                         -1.24430307e-03,   5.31936064e-03,   3.14694853e-03,
                          1.71292480e-03,  -5.43517526e-03,   2.52598198e-03,
                          6.66601257e-03,  -1.19080709e-03,   4.76952118e-04,
                          2.81375414e-03,   5.43331786e-04,  -4.23498405e-03,
                         -2.89452146e-03,   4.33424860e-03,   2.10948405e-04,
                          1.95846995e-04,  -1.05174107e-03,   1.54977560e-03,
                         -1.14502467e-03,  -8.38729553e-03,  -6.07761182e-03,
                         -5.20176534e-03,  -5.08690020e-03,  -3.49464803e-03,
                         -3.23784794e-03,  -1.56663731e-03,  -5.06000314e-03,
                         -2.85298051e-03,  -7.92577746e-04,  -2.72837142e-03,
                         -4.34354926e-03,  -1.18408457e-03,   4.03274724e-04,
                          3.34684271e-04,  -5.31938160e-04,  -1.24774757e-03,
                          3.34270531e-03,   8.70450120e-03,   3.57036991e-03,
                          3.69445235e-03,  -3.34760523e-04,  -2.71914690e-03,
                         -5.91880828e-03,   2.76385508e-05,  -1.02804322e-02,
                          2.17392994e-03,   5.44856477e-04,   3.87154549e-04,
                          2.07275269e-03,   2.81541754e-04,   7.32380024e-04,
                          4.48725186e-03,  -1.12114241e-03,  -2.90201325e-03,
                          3.65989725e-03,   5.44432318e-03,   3.18407477e-03,
                         -1.07822916e-03,  -6.20085606e-03,  -1.94876731e-04,
                          2.54431297e-03,  -2.06467882e-03,  -3.46111855e-03,
                         -3.57336388e-03,   8.26668518e-04,   1.03476853e-03,
                         -1.90006034e-03,  -4.41489136e-03,  -9.35677206e-04,
                         -5.04651666e-03,  -6.50899671e-03,   2.34109884e-05,
                          2.06020870e-03,   1.46592432e-03,  -1.03497645e-03,
                         -2.43508257e-03,   2.85464375e-05,   3.92856915e-03,
                          2.07020226e-03,   2.70702550e-03,  -3.76252981e-04,
                          1.73335569e-03,  -3.66321695e-03,  -1.03693770e-03,
                         -4.27538180e-04,   2.05002096e-03,  -2.72907829e-03,
                         -6.35429565e-03,  -1.28095818e-03,  -1.77299092e-03,
                          1.89152895e-03,  -4.73376014e-04,  -4.11941949e-03,
                          1.89685834e-05,  -3.77183757e-03,   1.68534170e-04,
                         -4.58511664e-03,   2.94633326e-03,  -7.95398431e-04,
                          1.31537463e-03,  -3.96685954e-03,   3.23346094e-03,
                          1.26302219e-03,   2.99366802e-04,   4.67214175e-03,
                         -1.56905607e-03,   4.02745930e-03,  -2.55458383e-03,
                          2.38209241e-03,  -3.03830020e-04,   1.33356010e-03,
                         -4.83903335e-04,  -2.80030916e-04,  -1.03034684e-03,
                          7.66808307e-03,   1.97759108e-03,   3.48153571e-03,
                          7.87267648e-03,   2.21276819e-03,   1.27143576e-03,
                          3.24913068e-03,   2.56453583e-04,  -9.35614866e-04,
                          2.88994727e-03,   7.29634194e-03,   3.51514830e-03,
                          1.72615505e-03,  -2.91563163e-04,   3.63392197e-03,
                          7.16018677e-03,   4.65429574e-03,   4.10612673e-03,
                          2.68758577e-03,  -3.66044464e-04,   3.00808344e-03,
                          1.90150182e-04,   1.78340729e-03,   6.58806603e-05,
                          2.47095432e-03,   3.46684316e-03,  -2.67847208e-04,
                          2.02143984e-03,   7.27223756e-04,   2.47223652e-03,
                          4.40075994e-03,   3.64661845e-03,   4.79262741e-03,
                          5.26202517e-03,   3.21544870e-03,   2.35657464e-03,
                          3.13054421e-03,   4.15469520e-03,   1.74246926e-03,
                          1.86206773e-03,   1.80181453e-03,   1.40321092e-03,
                          2.69163307e-03,   8.04470328e-04,   5.20175137e-03,
                          1.95550383e-03,  -4.13253857e-03,   4.65911959e-04,
                          1.63061905e-03,   5.61939960e-04,   4.68268292e-04,
                         -5.92363859e-03,   3.83696286e-04,   2.45353812e-03,
                          4.80653672e-03,   4.34530957e-04,   3.59211059e-04,
                         -3.14978999e-03,   1.23293721e-03,   3.92005866e-04,
                         -1.46232056e-03,  -3.29904351e-03,   1.72757579e-03,
                          3.50600015e-03,  -9.38976125e-04,   1.54037098e-03,
                          6.35074731e-03,  -2.47291569e-03,  -3.42848332e-04,
                          9.34457465e-04,  -5.12269617e-04,   5.79494750e-04,
                         -5.95905993e-04,  -1.70889823e-03,   1.14186446e-03,
                          7.38652074e-04,   4.14773030e-03,  -5.73562284e-04,
                         -1.57527265e-03,   2.16611940e-03,  -2.47288798e-03,
                          2.42815213e-03,  -5.95081307e-04,  -1.19599805e-03,
                          9.17852158e-04,   3.58832674e-03,   4.78978595e-03,
                          4.18144651e-03,   5.32666547e-03,   1.72880245e-03,
                          1.21186173e-03,  -5.26296790e-05,  -4.83014155e-03,
                         -1.15694501e-03,  -8.12856189e-04,   6.36934128e-04,
                          4.02391097e-03,   2.60631950e-03,  -1.31441827e-03,
                         -5.51114650e-03,   1.07881136e-03,   1.76823663e-03,
                         -8.61868175e-05,  -1.12579972e-03,  -3.86919617e-03,
                          1.02750538e-03,  -1.18655874e-03,   6.74046576e-04,
                         -9.06500100e-06,   2.30094395e-03,  -3.24539514e-03,
                         -9.95043316e-04,  -8.78646737e-04,   2.99202558e-03,
                          9.04185348e-04,  -1.77351071e-03,  -2.44033569e-03,
                          3.66765936e-03,   1.28451339e-03,   3.32237827e-03,
                          4.86475928e-03,   4.20997245e-03,  -8.50959681e-04,
                          3.08831711e-03,   3.38942325e-03,   2.81330361e-03,
                          2.02495349e-03,   8.87399830e-04,   4.92903916e-03,
                         -3.51724820e-03,   9.59051494e-03,   2.48016487e-03,
                          3.14960285e-04,   2.89753615e-03,  -3.32542782e-04,
                         -3.44826956e-03,   1.04666117e-03,   1.04165042e-03,
                          9.70260080e-05,  -5.58500411e-03,  -2.37526590e-04,
                          2.50625098e-03,  -1.82160095e-03,   3.55900405e-03,
                          3.93003837e-04,  -1.71346543e-03,  -1.72140764e-03,
                         -3.58642777e-04,  -1.72225316e-03,  -1.66063476e-03,
                          1.86377950e-03,   3.30526032e-04,   2.16703420e-03,
                          1.33232644e-03,  -5.82114444e-04,  -2.01347680e-03,
                         -1.33581937e-03,   1.68986735e-03,   2.20549805e-03,
                         -1.41229667e-03,   1.91540422e-03,   3.37497331e-03,
                          1.37773459e-03,   1.77098799e-03,  -4.06681048e-03,
                         -5.68314595e-03,   1.60857337e-03,   4.93861688e-03,
                         -2.95243901e-03,  -2.14363704e-03,  -7.63920427e-04,
                         -1.22935418e-03,   5.15748688e-04,  -2.48459354e-03,
                         -4.93154768e-03,  -4.98124585e-03,   2.87721609e-03,
                         -2.54841568e-03,  -8.74862715e-04,  -6.57451013e-03,
                         -7.95398431e-04,  -2.13926402e-03,  -5.83692500e-03,
                         -2.57294951e-03,  -5.14198327e-03,  -2.42835307e-03,
                          8.15863954e-04,  -3.91969131e-03,   3.42867733e-03,
                          1.85111072e-03,  -3.02336505e-03,   5.25833154e-03,
                         -3.22811073e-03,  -3.33673134e-03,   3.88905173e-03,
                         -2.51186476e-03,  -8.69914365e-04,  -2.35776650e-03,
                          1.54590153e-03,  -4.26429295e-04,   2.81093339e-03,
                         -6.22362923e-03,  -2.92577082e-03,  -3.28801037e-03,
                         -6.23468310e-04,   4.18632571e-03,   6.42251177e-03,
                          6.78904122e-03,  -3.55926738e-03,  -6.64648949e-04,
                         -8.10471363e-03,   1.82159391e-04,  -3.12533253e-03,
                         -2.88192881e-03,   4.37672529e-03,  -4.38377348e-04,
                          4.26260196e-03,   8.32384732e-03,   8.84141214e-03,
                         -3.06999288e-03,  -1.58395653e-03,   3.27760790e-04,
                         -1.18390436e-03,   7.25213962e-04,   4.56826156e-03,
                          1.22710802e-02,   8.88588466e-03,   9.05829296e-03,
                          1.20783516e-04,  -3.41650750e-03,  -1.62912207e-03,
                         -5.48133161e-03,   8.37999745e-04,   2.83975713e-03,
                         -1.02070393e-02,   1.75691233e-03,   4.66268882e-03,
                          7.34095974e-03,  -4.81318311e-05,  -1.70903688e-03,
                          9.47233755e-03,   1.64486803e-02,   5.21008857e-04,
                          4.12774272e-03,   9.73050296e-03,   8.30494100e-04,
                          5.00473287e-03,  -1.18033518e-03,  -3.17423348e-03,
                          5.76037169e-03,  -5.81422821e-03,   4.18527238e-03,
                          1.52881804e-03,  -4.63688001e-03,  -8.55295360e-03,
                          7.31692510e-03,  -1.35896010e-02,  -1.92833785e-02,
                         -1.06363790e-02,  -7.21590733e-03,  -8.47926922e-03,
                         -1.11761419e-02,   1.06831873e-03,  -6.20414084e-03,
                          1.92895322e-03,  -1.26949523e-03,  -6.03291066e-03,
                         -4.35353629e-03,   2.03902293e-02,   1.20158466e-02,
                          6.71536382e-03,   2.71291635e-03,  -7.45140342e-03,
                         -1.28498476e-03,   1.99051425e-02,  -7.36108609e-03,
                         -1.31463312e-04,  -2.36586132e-03,  -1.36768203e-02,
                         -1.93943065e-02,  -8.95095430e-03,  -1.71635188e-02,
                         -2.40052529e-02,  -1.19764255e-02,   2.45669158e-03,
                         -1.31387003e-02,   3.85612529e-03,   1.80560071e-02,
                         -1.88883988e-03,  -6.31822972e-03,  -6.15133112e-03,
                         -7.11906841e-03,   7.37979123e-03,   7.73158669e-03,
                         -9.74202808e-03,   9.41588893e-04,   8.58537387e-03,
                          1.80489861e-03,   2.06880923e-03,   1.42722419e-02,
                         -6.86736195e-04,   5.23855211e-03,  -6.43294910e-03,
                         -3.01746023e-03,  -2.69236770e-02,  -7.17681972e-03,
                         -5.66913234e-03,  -1.58987306e-02,  -2.21640933e-02,
                         -8.62381049e-03,  -1.24703646e-02,  -2.53162961e-02,
                         -3.70978238e-03,  -2.72167791e-02,  -9.06152930e-03,
                         -1.79838184e-02,  -1.53146125e-02,  -5.33404620e-03,
                         -1.75288506e-02,  -1.04739571e-04,   8.72919429e-03,
                          8.46064743e-03,  -1.45215495e-02,   2.35405890e-03,
                          6.94919657e-03,   2.77304910e-02,  -1.90733036e-03,
                         -4.44059633e-03,   1.33957015e-02,   1.60128251e-03,
                         -4.91914246e-03,  -1.38162747e-02,  -2.43039262e-02,
                         -5.25133871e-03,  -1.69382454e-03,   1.37296095e-02,
                          2.09011976e-02,   1.82781890e-02,   1.94341913e-02,
                         -8.89619719e-03,  -2.06346594e-04,  -1.39287142e-02,
                          1.75831222e-03,   5.82194142e-03,   1.77318770e-02,
                          1.33558102e-02,   8.88478197e-03,   2.80505028e-02,
                         -7.92098790e-03,  -2.40717363e-03,  -2.14552227e-03,
                         -9.23319161e-01,  -9.40514028e-01,  -9.49759543e-01,
                         -9.25577521e-01,  -9.01015639e-01,  -9.20403302e-01,
                         -9.44380641e-01,  -9.20915067e-01,  -9.24960315e-01,
                         -9.38706100e-01,  -9.16931510e-01,  -9.21247900e-01,
                          6.53822208e-03,   6.89536100e-04,  -2.12771105e-04,
                         -6.45663030e-03,   1.67990346e-02,   3.02361175e-02,
                          2.28678379e-02,   7.56378006e-03,  -1.21932582e-03,
                         -3.94576369e-03,   1.73005890e-02,   1.27532436e-02,
                          1.71867982e-02,   7.51782442e-03,  -1.08644180e-03,
                          8.18783045e-03,   1.58685204e-02,  -4.01005708e-03,
                          2.89092660e-02,  -1.02362717e-02,   1.09330984e-02,
                          7.54864421e-03,   9.99624282e-03,   2.70521604e-02,
                          1.09547628e-02,  -2.74966843e-02,  -8.35500658e-03,
                         -1.05278066e-03,   1.44795859e-02,  -4.11290489e-03,
                          4.29478008e-03,   3.71725345e-03,  -4.40712227e-03,
                          1.05571644e-02,   3.29245976e-03,   4.52766335e-03,
                          1.41041854e-03,   8.54993181e-04,  -8.43576714e-03,
                         -2.37570256e-02,  -2.65240967e-02,  -1.29716843e-03,
                         -6.23643678e-03,   1.05578983e-02,   3.25802248e-03,
                         -6.33129326e-04,  -2.04005707e-02,  -2.19220556e-02,
                         -9.31098964e-03,  -1.49806764e-03,   2.32847650e-02,
                          1.30983032e-02,   9.02334927e-04,   1.60635151e-02,
                          1.61725786e-02,  -1.78616568e-02,  -3.35985124e-02,
                          2.41649500e-03,   8.91137403e-03,   2.46065091e-02,
                         -6.44940883e-03,  -1.12424307e-02,  -2.88183801e-02,
                         -3.89261404e-03,  -9.45782363e-01,  -9.27687287e-01,
                         -9.17486429e-01,  -9.49134588e-01,  -9.41063344e-01,
                         -9.34634984e-01,  -9.21235859e-01,  -9.20630455e-01,
                         -9.14748609e-01,  -9.32897627e-01,  -9.32360291e-01,
                         -9.32478130e-01,  -9.27137196e-01,  -9.34939265e-01,
                         -8.96846294e-01,  -9.18990433e-01,  -8.95066261e-01,
                         -9.05582786e-01,  -9.12051141e-01,  -9.10899341e-01,
                         -9.37272906e-01,  -9.33521807e-01,  -9.20381248e-01,
                         -9.24665689e-01,  -9.34052050e-01,  -9.32854593e-01,
                         -9.21712995e-01,  -8.97798479e-01,  -9.31967854e-01,
                         -9.16585863e-01,  -9.51605678e-01,  -9.19574142e-01,
                         -9.21345353e-01,  -9.36990917e-01,  -9.34084535e-01,
                         -9.13289070e-01,  -9.26010907e-01,  -9.20962751e-01,
                         -9.37727749e-01,  -9.55702960e-01,  -9.54194665e-01,
                         -9.40596521e-01,  -9.29903924e-01,  -9.24649537e-01,
                         -9.38195109e-01,  -9.47504520e-01,  -9.01671171e-01,
                         -9.27907705e-01,  -9.37463701e-01,  -9.28056955e-01,
                         -9.22714174e-01,  -9.25620794e-01,  -9.29895699e-01,
                         -9.09821510e-01,  -9.36502099e-01,  -9.31788445e-01,
                         -9.17091429e-01,  -9.22565281e-01,  -9.36626434e-01,
                         -9.54465806e-01,  -9.36168790e-01,  -9.22300100e-01,
                         -9.47367013e-01,  -9.34177041e-01,  -9.48927760e-01,
                         -9.23724294e-01,  -9.35921729e-01,  -9.18774426e-01,
                         -9.09752071e-01,  -9.31593716e-01,  -9.03879225e-01,
                         -9.08297598e-01,  -9.28864956e-01,  -9.34531212e-01,
                         -9.34240222e-01,  -9.36890304e-01,  -9.22020197e-01,
                         -9.28723872e-01,  -9.21413720e-01,  -9.33770776e-01,
                         -9.38836932e-01,  -9.31958497e-01,  -9.30346906e-01,
                         -9.28184330e-01,  -9.09359932e-01,  -9.31358397e-01,
                         -9.24581766e-01,  -9.18950915e-01,  -9.18617368e-01,
                         -9.12992656e-01,  -9.07526374e-01,  -9.11434770e-01,
                         -9.00015354e-01,  -9.31558430e-01,  -9.15288329e-01,
                         -9.02859032e-01,  -9.13981259e-01,  -9.14583862e-01,
                         -9.35460567e-01,  -9.14725482e-01,  -9.24763978e-01,
                         -9.41388011e-01,  -9.20645833e-01,  -9.25460577e-01,
                         -9.31585610e-01,  -9.27068889e-01,  -9.42657351e-01,
                         -9.28309023e-01,  -9.29784238e-01,  -9.28882837e-01,
                         -9.33626831e-01,  -9.17630017e-01,  -9.29136634e-01,
                         -9.28410649e-01,  -9.30885792e-01,  -9.24040914e-01,
                         -9.30300891e-01,  -9.30196226e-01,  -9.35959756e-01,
                         -9.24615800e-01,  -9.23252225e-01,  -9.16727602e-01,
                         -9.38790381e-01,  -9.19586003e-01,  -9.21201050e-01,
                         -9.24946725e-01,  -9.21023250e-01,  -9.03231978e-01,
                         -9.30671930e-01,  -9.19251859e-01,  -9.34426427e-01,
                         -9.35412526e-01,  -9.22982693e-01,  -9.24815357e-01,
                         -9.11380112e-01,  -9.17857051e-01,  -9.18684363e-01,
                         -9.24667239e-01,  -9.30598378e-01,  -9.40931618e-01,
                         -9.16147828e-01,  -9.19459283e-01,  -9.15071249e-01,
                         -9.22871411e-01,  -9.42347288e-01,  -9.34318960e-01,
                         -9.39874828e-01,  -9.44628358e-01,  -9.29585099e-01,
                         -9.20874238e-01,  -9.23508346e-01,  -9.28498924e-01,
                         -9.18913126e-01,  -9.42864358e-01,  -9.06067431e-01,
                         -9.31132555e-01,  -9.54736233e-01,  -9.27930176e-01,
                         -9.34252799e-01,  -9.29743588e-01,  -9.31064785e-01,
                         -9.18761492e-01,  -9.09882307e-01,  -9.12632167e-01,
                         -9.20733094e-01,  -9.08017933e-01,  -9.25810933e-01,
                         -9.22492564e-01,  -9.20354307e-01,  -9.52408254e-01,
                         -9.35997903e-01,  -9.27037120e-01,  -9.20729041e-01,
                         -9.26806331e-01,  -9.27189529e-01,  -9.27634358e-01,
                         -9.15325582e-01,  -9.40158486e-01,  -9.39523101e-01,
                         -9.42195177e-01,  -9.26002920e-01,  -9.59813535e-01,
                         -9.23898757e-01,  -9.39451039e-01,  -9.36019301e-01,
                         -9.24324274e-01,  -9.35973644e-01,  -9.40525115e-01,
                         -9.38475668e-01,  -9.33371305e-01,  -9.43583131e-01,
                         -9.30210054e-01,  -9.40834224e-01,  -9.51532602e-01,
                         -9.50595081e-01,  -9.46016431e-01,  -9.43689823e-01,
                         -9.30285931e-01,  -9.32729185e-01,  -9.18647647e-01,
                         -9.45767045e-01,  -9.37349379e-01,  -9.18327272e-01,
                         -9.22576129e-01,  -9.21512544e-01,  -9.24594820e-01,
                         -9.22264814e-01,  -9.25477803e-01,  -9.27398384e-01,
                         -9.22127247e-01,  -9.47691798e-01,  -9.30084109e-01,
                         -9.30431724e-01,  -9.19070005e-01,  -9.29529428e-01,
                         -9.22747016e-01,  -9.31714773e-01,  -9.26804960e-01,
                         -9.25508857e-01,  -9.31995869e-01,  -9.24735785e-01,
                         -9.38653529e-01,  -9.33935523e-01,  -9.32129085e-01,
                         -9.23231244e-01,  -9.45425272e-01,  -9.45932567e-01,
                         -9.38129842e-01,  -9.32690918e-01,  -9.46632504e-01,
                         -9.65300739e-01,  -9.41071987e-01,  -9.26331222e-01,
                         -9.28714693e-01,  -9.29587185e-01,  -9.25492883e-01,
                         -9.29050744e-01,  -9.42148387e-01,  -9.21258092e-01,
                         -9.35170472e-01,  -9.25640643e-01,  -9.32265878e-01,
                         -9.23234999e-01,  -9.20300007e-01,  -9.59050059e-01,
                         -9.28428650e-01,  -9.53066051e-01,  -9.14458573e-01,
                         -9.32696819e-01,  -9.33387756e-01,  -9.25579131e-01,
                         -9.27043676e-01,  -9.35329795e-01,  -9.37044322e-01,
                         -9.26389456e-01,  -9.15229738e-01,  -9.41494584e-01,
                         -9.50585306e-01,  -9.31183398e-01,  -9.26635861e-01,
                         -9.31857407e-01,  -9.23505485e-01,  -9.36238647e-01,
                         -9.30380166e-01,  -9.20794129e-01,  -9.14483070e-01,
                         -9.24395859e-01,  -9.32529509e-01,  -9.27816272e-01,
                         -9.14666295e-01,  -9.19365764e-01,  -9.11228597e-01,
                         -9.41817045e-01,  -9.34437096e-01,  -9.32898164e-01,
                         -9.45915759e-01,  -9.34884191e-01,  -9.13817286e-01,
                         -9.19803500e-01,  -9.28613007e-01,  -9.49914515e-01,
                         -9.46232677e-01,  -9.33221400e-01,  -9.38079894e-01,
                         -9.32665884e-01,  -9.29606974e-01,  -9.36799526e-01,
                         -9.22492981e-01,  -9.65793669e-01,  -9.43939388e-01,
                         -9.44729924e-01,  -9.42212462e-01,  -9.36399639e-01,
                         -9.66252923e-01,  -9.19531643e-01,  -9.42897081e-01,
                         -9.69326496e-01,  -9.68253016e-01,  -9.50440288e-01,
                         -9.59254682e-01,  -9.49368119e-01,  -9.27815020e-01,
                         -9.11358297e-01,  -9.42637682e-01,  -9.22317863e-01,
                         -9.25396800e-01,  -9.36280906e-01,  -9.30864513e-01,
                         -9.29143548e-01,  -9.04414773e-01,  -9.47293818e-01,
                         -9.33946729e-01,  -9.20904219e-01,  -9.33132589e-01,
                         -9.26976979e-01,  -9.26456153e-01,  -9.46938872e-01,
                         -9.46548581e-01,  -9.46363807e-01,  -9.48961675e-01,
                         -9.49269414e-01,  -9.31191862e-01,  -9.31526721e-01,
                         -9.23351288e-01,  -9.20701981e-01,  -9.25277770e-01,
                         -9.53213513e-01,  -9.50321615e-01,  -9.51410949e-01,
                         -9.60990369e-01,  -9.55104709e-01,  -9.38673496e-01,
                         -9.48161185e-01,  -9.41210151e-01,  -9.48248684e-01,
                         -9.47544336e-01,  -9.46021438e-01,  -9.66602147e-01,
                         -9.68029797e-01,  -9.60758746e-01,  -9.61064100e-01,
                         -9.48601425e-01,  -9.54485416e-01,  -9.40346777e-01,
                         -9.55921948e-01,  -9.59903777e-01,  -9.44180906e-01,
                         -9.41437602e-01,  -9.40433919e-01,  -9.46519196e-01,
                         -9.58904147e-01,  -9.41883683e-01,  -9.33353126e-01,
                         -9.67893541e-01,  -9.38668489e-01,  -9.65048492e-01,
                         -9.48653102e-01,  -9.14149821e-01,  -9.51227903e-01,
                         -9.42868352e-01,  -9.21004534e-01,  -9.27175820e-01,
                         -9.43715751e-01,  -9.25931633e-01,  -3.67705151e-02,
                         -1.22890510e-02,  -2.45889612e-02,  -1.15649868e-02,
                          1.30782183e-02,  -4.51124506e-03,  -2.39123572e-02,
                          5.74828498e-03,   1.15957102e-02,  -1.66885499e-02,
                          1.63401216e-02,  -7.36620044e-03,  -6.49018027e-03,
                          3.67278088e-04,  -1.15066888e-02,   1.15512507e-02,
                         -1.49871148e-02,   2.91485190e-02,  -1.58499889e-02,
                         -2.00132071e-03,   1.85422376e-02,   8.86518974e-03,
                          1.05994465e-02,   2.28521880e-03,  -2.46134191e-03,
                          1.63524784e-02,  -5.27883822e-04,   2.11217999e-03,
                         -1.54794389e-02,   1.15414513e-02,  -3.95550765e-03,
                          2.06101742e-02,  -5.34072705e-03,  -2.30571209e-03,
                         -8.30325019e-03,   1.08929779e-02,  -2.36787111e-03,
                          1.17848618e-02,   1.89758968e-02,   8.09351448e-03,
                         -1.31910462e-02,  -4.15933179e-03,  -2.62776427e-02,
                          3.18840635e-03,  -3.70190945e-03,   2.32718256e-03,
                         -4.90133825e-04,  -4.10661194e-03,   2.86807492e-03,
                         -1.59089100e-02,   1.17288502e-02,  -7.18712527e-03,
                         -2.16786247e-02,   3.23314220e-03,  -1.58952996e-02,
                          4.20467043e-03,  -3.93270655e-03,   2.30438635e-02,
                          5.93329966e-03,   6.00868883e-03,   5.85371745e-04,
                          5.09970775e-03,  -3.96997156e-03,   3.45773995e-02,
                         -7.13764178e-03,   2.48379651e-02,  -1.27465902e-02,
                          8.77791550e-03,  -1.05788151e-03,  -8.73184204e-03,
                          2.20220275e-02,  -2.54578497e-02,   9.51622799e-03,
                          2.44852068e-04,  -1.19544845e-02,   1.36040021e-02,
                          2.58173724e-03,  -1.61079522e-02,   1.23319151e-02,
                          5.97281707e-03,   2.46019345e-02,  -2.74508749e-03,
                          3.08910366e-02,   2.53854264e-02,   1.20231304e-02,
                          3.22491005e-02,   1.05065722e-02,   2.20203642e-02,
                          6.25773380e-03,   7.89368246e-03,   7.36818276e-03,
                          3.33651230e-02,   1.78025942e-02,   1.39477728e-02,
                          5.93600934e-03,   2.03975905e-02,   3.00874189e-03,
                         -9.34755523e-03,  -9.78979934e-03,  -2.41424260e-03,
                          2.83572357e-03,   1.70686357e-02,   1.14447027e-02,
                          1.54792862e-02,   2.65696645e-02,   1.08763240e-02,
                          3.92743247e-03,   9.26478487e-03,   3.47690284e-02,
                          1.43952633e-03,  -6.38555852e-04,   1.01568829e-02,
                          1.02388635e-02,   2.47966591e-03,   1.73756052e-02,
                         -3.60103021e-03,   2.47659236e-02,  -1.84169710e-02,
                          2.38709971e-02,  -1.59140527e-02,   1.54357702e-02,
                         -2.75418023e-03,   1.88297674e-03,  -1.62448559e-03,
                         -1.61318481e-02,   2.11859751e-03,  -1.51377206e-03,
                         -3.21051432e-03,  -6.17066678e-03,  -3.73189745e-04,
                         -5.92718017e-04,   8.85543879e-03,   9.13184509e-03,
                         -1.18183987e-02,  -3.08156256e-02,   5.32777421e-03,
                         -1.65664498e-02,   2.12714961e-03,  -1.76226664e-02,
                          9.56242625e-03,  -3.52641707e-03,   1.42344357e-02,
                         -4.78817103e-03,   1.27854077e-02,  -3.79312299e-02,
                          4.10773471e-04,  -2.24978775e-02,  -1.60933156e-02,
                         -9.53487772e-03,  -2.03991290e-02,   4.30304790e-03,
                         -2.16783816e-03,  -1.61881577e-02,  -1.05830012e-02,
                         -1.59693155e-02,   8.51891097e-03,  -1.05163921e-02,
                          6.88503496e-03,  -1.41891111e-02,  -2.19267001e-03,
                         -2.03980133e-02,  -3.18895373e-03,  -2.10173652e-02,
                         -1.24194671e-03,  -1.47148529e-02,  -4.50125150e-03,
                         -1.67789981e-02,  -3.59257497e-03,  -2.44013470e-04,
                          2.04137177e-03,   4.34835907e-04,   6.42692624e-03,
                          2.55661868e-02,   2.61848932e-03,   1.72799714e-02,
                         -1.52977090e-02,   1.61990598e-02,   4.77586268e-03,
                         -2.85445666e-03,  -1.20849013e-02,   3.13756452e-03,
                          1.40453326e-02,   1.39222341e-02,  -1.61268306e-03,
                         -5.18242223e-03,   1.39668174e-02,  -2.03803610e-02,
                          6.78012194e-03,  -2.95459777e-02,   1.08508691e-02,
                         -4.26696800e-03,   1.20001007e-02,   3.53602273e-03,
                          9.09415726e-03,  -6.68694917e-03,  -1.70551625e-03,
                          4.18288121e-03,   1.63980876e-04,  -1.97127182e-02,
                          8.62196647e-03,   8.34954530e-03,   2.23120246e-02,
                         -1.43328201e-04,  -3.82355927e-03,   1.21989483e-02,
                          1.27062900e-02,  -7.12508382e-03,   1.72639061e-02,
                         -1.70294642e-02,  -2.87699443e-03,  -1.67723875e-02,
                         -1.81460455e-02,   1.76933575e-02,  -1.24596711e-02,
                          4.33604373e-03,   1.13810813e-02,   8.53637606e-03,
                         -4.45764512e-03,  -2.30752993e-02,   1.20797376e-04,
                         -1.35744307e-02,  -8.34630895e-03,   1.01806689e-02,
                         -4.12747264e-03,  -4.15203394e-03,   1.21423893e-03,
                         -4.72181896e-03,   1.04258191e-02,   7.95632694e-03,
                          3.15195229e-03,   3.16586858e-03,   1.16899703e-02,
                         -3.17150913e-02,   1.66724361e-02,   3.56310676e-03,
                          1.86880119e-02,   2.41625663e-02,  -3.31832543e-02,
                          3.14153843e-02,  -3.16272900e-02,   1.16164945e-02,
                         -2.49284208e-02,  -1.08020436e-02,  -3.90619761e-03,
                         -1.51306512e-02,  -1.83794014e-02,   3.99422133e-03,
                         -5.37157478e-03,  -6.08826429e-03,   1.35109611e-02,
                         -6.34014374e-03,  -7.66695337e-03,  -1.04656407e-04,
                          8.98130238e-03,   1.05464011e-02,   6.20391220e-03,
                          1.52900582e-02,  -1.01569947e-02,   6.01214706e-05,
                          9.06694867e-03,   7.98146334e-03,   8.74371361e-03,
                          1.58107206e-02,  -3.60398949e-03,  -7.47369289e-01,
                         -7.41287291e-01,  -7.59813249e-01,  -7.40180850e-01,
                         -7.27502108e-01,  -7.59994447e-01,  -7.38251209e-01,
                         -7.66101122e-01,  -7.75443852e-01,  -7.59998083e-01,
                         -7.77853370e-01,  -7.39030898e-01,  -7.58480012e-01,
                         -7.68567026e-01,  -7.69289196e-01,  -7.31457055e-01,
                         -7.49967873e-01,  -7.41030395e-01,  -7.53348231e-01,
                         -7.29196608e-01,  -7.58278251e-01,  -7.33180165e-01,
                         -7.36294448e-01,  -7.26742864e-01,  -7.24735618e-01,
                         -7.27249563e-01,  -7.53447652e-01,  -7.40982354e-01,
                         -7.49365628e-01,  -7.65141487e-01,  -7.42314816e-01,
                         -7.51563013e-01,  -7.57930279e-01,  -7.61832595e-01,
                         -7.57479131e-01,  -7.41503775e-01,  -7.47910619e-01,
                         -7.36625850e-01,  -7.46168494e-01,  -7.45948970e-01,
                         -7.34464943e-01,  -7.40105093e-01,  -7.61311650e-01,
                         -7.29180574e-01,  -7.57224917e-01,  -7.61530101e-01,
                         -7.66149163e-01,  -7.34869182e-01,  -7.78431296e-01,
                         -7.52023935e-01,  -7.63053358e-01,  -7.57361174e-01,
                         -7.46123075e-01,  -7.57203281e-01,  -7.76950896e-01,
                         -7.66513646e-01,  -7.58804917e-01,  -7.69294441e-01,
                         -7.36021757e-01,  -7.81391740e-01,  -7.33460128e-01,
                         -7.43935347e-01,  -7.43663609e-01,  -7.19753385e-01,
                         -7.75659263e-01,  -7.34214842e-01,  -7.55347908e-01,
                         -7.69956946e-01,  -7.48957574e-01,  -7.49779999e-01,
                         -7.59129405e-01,  -7.34987497e-01,  -7.63721168e-01,
                         -7.39367902e-01,  -7.78171659e-01,  -7.74687648e-01,
                         -7.40860581e-01,  -7.57564425e-01,  -7.67287850e-01,
                         -7.53282964e-01,  -9.27450120e-01,  -9.28936183e-01,
                         -9.43021595e-01,  -9.15763736e-01,  -7.69882083e-01,
                         -7.38668025e-01,  -7.48017550e-01,  -7.67515182e-01,
                         -7.61792660e-01,  -7.58015633e-01,  -7.81893671e-01,
                         -7.54388869e-01,  -7.68938541e-01,  -7.76268482e-01,
                         -7.59489417e-01,  -7.69606948e-01,  -7.65824795e-01,
                         -7.95674741e-01,  -7.76441514e-01,  -7.63181746e-01,
                         -9.44012582e-01,  -9.07217681e-01,  -9.25696492e-01,
                         -9.43560719e-01,  -9.00391459e-01,  -9.10206556e-01,
                         -9.05197740e-01,  -9.27935123e-01,  -9.02703404e-01,
                         -9.39942181e-01,  -9.50323164e-01,  -9.08562422e-01,
                         -7.87824810e-01,  -7.45592773e-01,  -7.49571502e-01,
                         -7.32369781e-01,  -7.54172862e-01,  -7.58898973e-01,
                         -7.41877198e-01,  -7.53988206e-01,  -7.42019892e-01,
                         -7.28214502e-01,  -7.64785290e-01,  -7.43480444e-01,
                         -7.72315323e-01,  -7.22045004e-01,  -7.68013835e-01,
                         -7.73009241e-01,  -9.26031530e-01,  -9.31058705e-01,
                         -9.12026882e-01,  -9.17883873e-01,  -9.14221823e-01,
                         -9.37241256e-01,  -9.43486571e-01,  -9.24018025e-01,
                         -7.62000322e-01,  -7.69025505e-01,  -7.45090187e-01,
                         -7.55420744e-01,  -7.73430228e-01,  -7.69899428e-01,
                         -7.51387894e-01,  -7.61067212e-01,  -7.67540157e-01,
                         -7.60085881e-01,  -7.62547731e-01,  -7.73080468e-01,
                         -7.62107968e-01,  -7.70838439e-01,  -7.16444552e-01,
                         -7.42431641e-01,  -8.89566004e-01,  -8.97187829e-01,
                         -9.17070389e-01,  -9.01158810e-01,  -9.12466347e-01,
                         -9.42310929e-01,  -9.23495054e-01,  -9.65687513e-01,
                         -9.62137699e-01,  -9.43111300e-01,  -9.71317708e-01,
                         -9.34114277e-01,  -9.15602624e-01,  -9.12647665e-01,
                         -9.33417022e-01,  -9.24693704e-01,  -7.88763225e-01,
                         -7.56908357e-01,  -8.18401098e-01,  -7.62754738e-01,
                         -7.74106085e-01,  -7.69540846e-01,  -7.36564219e-01,
                         -7.62492895e-01,  -7.21385300e-01,  -7.70191193e-01,
                         -7.40871310e-01,  -7.74625480e-01,  -7.52896488e-01,
                         -7.35237598e-01,  -7.59056509e-01,  -7.36929119e-01,
                         -7.71466911e-01,  -7.40496576e-01,  -7.47622907e-01,
                         -7.42358863e-01,  -7.45724440e-01,  -7.56084919e-01,
                         -7.54390955e-01,  -7.65930891e-01,  -7.55877614e-01,
                         -7.49313354e-01,  -7.49965787e-01,  -7.22468078e-01,
                         -7.58507431e-01,  -7.59666145e-01,  -7.61475205e-01,
                         -7.49171257e-01,  -7.65212595e-01,  -7.61034727e-01,
                         -7.62576282e-01,  -7.58325279e-01,  -7.46734560e-01,
                         -7.61854112e-01,  -7.27455139e-01,  -7.51954138e-01,
                         -7.59213746e-01,  -7.19060183e-01,  -7.62136877e-01,
                         -7.44311512e-01,  -7.74347246e-01,  -7.52785802e-01,
                         -7.61599004e-01,  -7.63639152e-01,  -1.14922179e-02,
                          3.60927731e-03,   1.01546869e-02,   8.29877274e-04,
                          1.70399975e-02,  -2.18855329e-02,  -1.30195944e-02,
                         -1.08521786e-02,  -7.72145033e-01,  -7.64492512e-01,
                         -8.00638437e-01,  -7.59491086e-01,  -7.35621214e-01,
                         -7.91440189e-01,  -7.59041250e-01,  -7.82305241e-01,
                         -7.61296630e-01,  -7.53516436e-01,  -7.66057134e-01,
                         -7.32152879e-01,  -7.33253956e-01,  -7.72457659e-01,
                         -7.42496908e-01,  -7.67119527e-01,  -6.93244338e-01,
                         -7.61845231e-01,  -7.27914751e-01,  -7.78176248e-01,
                         -7.86856234e-01,  -7.53884315e-01,  -7.39914417e-01,
                         -8.03277254e-01,  -8.05903316e-01,  -7.59016871e-01,
                         -7.71275401e-01,  -7.79364049e-01,  -7.71699190e-01,
                         -7.68790066e-01,  -7.84766316e-01,  -7.33938158e-01,
                         -7.74417996e-01,  -7.32162893e-01,  -7.57665575e-01,
                         -7.45455921e-01,  -7.11952507e-01,  -7.67062187e-01,
                         -7.54470766e-01,  -7.41447270e-01,  -7.63051987e-01,
                         -7.48336375e-01,  -7.65037239e-01,  -7.74153411e-01,
                         -7.35930800e-01,  -7.51613498e-01,  -7.76263535e-01,
                         -7.61915922e-01,  -7.79260516e-01,  -7.75318325e-01,
                         -7.79368699e-01,  -7.65964568e-01,  -7.84631014e-01,
                         -7.80111313e-01,  -7.79318810e-01,  -7.68726408e-01,
                         -1.65476818e-02,   2.68398202e-03,   3.67447622e-02,
                          1.10743539e-02,  -7.49155521e-01,  -7.76149452e-01,
                         -7.81274199e-01,  -7.60265172e-01,  -7.82667339e-01,
                         -7.44732559e-01,  -7.58615851e-01,  -7.79493153e-01,
                         -7.87786365e-01,  -7.76874721e-01,  -7.57068574e-01,
                         -7.46036172e-01,  -7.58731067e-01,  -7.65196323e-01,
                         -7.65798151e-01,  -7.48909891e-01,  -7.49102235e-01,
                         -7.66766131e-01,  -7.44279563e-01,  -7.77940094e-01,
                         -7.58180797e-01,  -7.74027407e-01,  -7.54042566e-01,
                         -7.77515471e-01,  -7.31270790e-01,  -7.61716962e-01,
                         -7.63406754e-01,  -7.48485982e-01,  -7.73237944e-01,
                         -7.72003472e-01,  -7.81910300e-01,  -7.32821107e-01,
                         -7.76349306e-01,  -7.52960026e-01,  -7.30973005e-01,
                         -7.90947676e-01,  -7.92236447e-01,  -7.67804325e-01,
                         -7.70206094e-01,  -7.34212697e-01,  -1.56946492e-03,
                          1.26921246e-02,   3.64207220e-03,  -8.05762131e-03,
                         -1.86461527e-02,   2.08198396e-03,   6.39234344e-03,
                          1.45791490e-02,  -7.69416571e-01,  -7.65517116e-01,
                         -8.07701409e-01,  -7.61760354e-01,  -7.46532261e-01,
                         -7.70960689e-01,  -7.48198330e-01,  -7.78731644e-01,
                         -7.65076220e-01,  -7.81917036e-01,  -7.53224373e-01,
                         -7.54092693e-01,  -7.60958076e-01,  -7.69807458e-01,
                         -7.95197189e-01,  -7.84539580e-01,  -7.45168269e-01,
                         -7.38499999e-01,  -7.83940732e-01,  -7.64657199e-01,
                         -7.60389268e-01,  -7.64799953e-01,  -7.38204181e-01,
                         -7.82084763e-01,  -7.55518258e-01,  -7.97456086e-01,
                         -8.28060925e-01,  -7.49781489e-01,  -7.44919121e-01,
                         -7.79273868e-01,  -7.44452775e-01,  -7.38071501e-01,
                         -7.49936342e-01,  -7.32799947e-01,  -7.56384671e-01,
                         -8.23631525e-01,  -7.30203872e-04,   3.16151627e-03,
                          4.70442660e-02,   4.69596386e-02,  -7.61705697e-01,
                         -7.24565327e-01,  -7.68468261e-01,  -7.69739926e-01,
                         -7.61261046e-01,  -7.72795200e-01,  -7.66621411e-01,
                         -7.39373267e-01,  -7.57067919e-01,  -7.40674019e-01,
                         -7.38703132e-01,  -7.53702939e-01,  -7.61604607e-01,
                         -7.51356661e-01,  -7.71517038e-01,  -7.61044741e-01,
                         -7.56132245e-01,  -7.60703146e-01,  -7.58901536e-01,
                         -7.66600490e-01,  -7.67164469e-01,  -8.10788214e-01,
                         -7.50305653e-01,  -7.61940360e-01,  -7.70561218e-01,
                         -7.45515168e-01,  -7.86524832e-01,  -7.81089664e-01,
                         -7.37011850e-01,  -7.85290182e-01,  -7.68549025e-01,
                         -7.38800287e-01,  -7.16439843e-01,  -7.50409126e-01,
                         -7.77907073e-01,  -7.72575438e-01,  -7.43342757e-01,
                         -7.39198506e-01,  -7.33590126e-01,  -7.47797906e-01,
                         -7.61219501e-01,  -7.62581706e-01,  -7.70558953e-01,
                         -7.51237333e-01,  -7.53168583e-01,  -7.55728781e-01,
                         -7.59315729e-01,  -7.63301849e-01,  -7.48968780e-01,
                         -7.63437510e-01,  -7.59820402e-01,  -7.40556300e-01,
                         -9.21766400e-01,  -9.25989807e-01,  -9.08789217e-01,
                         -9.29366767e-01,  -9.07009602e-01,  -9.21024859e-01,
                         -9.19352353e-01,  -9.26555157e-01,  -9.05971825e-01,
                         -8.87214482e-01,  -9.15257215e-01,  -9.23366487e-01,
                         -7.52338946e-01,  -7.67381132e-01,  -7.43139625e-01,
                         -7.33870924e-01,  -7.16180980e-01,  -7.37348020e-01,
                         -7.29039490e-01,  -7.49219298e-01,  -7.74527848e-01,
                         -7.64705956e-01,  -7.71348834e-01,  -7.59209871e-01,
                         -7.66604602e-01,  -7.55715609e-01,  -7.51232028e-01,
                         -7.54574120e-01,  -7.68669486e-01,  -7.83632219e-01,
                         -7.36740410e-01,  -7.52974570e-01,  -7.20977664e-01,
                         -7.32360959e-01,  -7.36009657e-01,  -7.76628375e-01,
                         -9.28743064e-01,  -9.27818358e-01,  -9.48700666e-01,
                         -9.38449383e-01,  -9.43684459e-01,  -9.29491937e-01,
                         -9.31254029e-01,  -9.27071214e-01,  -9.23310459e-01,
                         -9.28992510e-01,  -9.29093063e-01,  -9.21547771e-01,
                         -7.62869179e-01,  -7.56149352e-01,  -7.46582747e-01,
                         -7.62993634e-01,  -9.41107571e-01,  -9.47805822e-01,
                         -9.33428884e-01,  -9.17046785e-01,  -9.30885017e-01,
                         -9.17738020e-01,  -9.32689071e-01,  -9.15719867e-01,
                         -9.47204351e-01,  -9.06172752e-01,  -9.24502075e-01,
                         -9.40028667e-01,  -9.18846965e-01,  -9.30825949e-01,
                         -9.30073440e-01,  -9.23033595e-01,  -9.32830513e-01,
                         -9.18008983e-01,  -9.06838238e-01,  -9.33543205e-01,
                         -9.10571337e-01,  -9.27761137e-01,  -9.17801738e-01,
                         -8.95120263e-01,  -7.26360857e-01,  -7.45422065e-01,
                         -7.51937211e-01,  -7.61382461e-01,  -7.81264722e-01,
                         -7.54164100e-01,  -7.57467031e-01,  -7.60246217e-01,
                         -7.61599362e-01,  -7.53386736e-01,  -7.71487296e-01,
                         -7.81401098e-01,  -7.75346160e-01,  -7.44037092e-01,
                         -7.37644613e-01,  -7.68812358e-01,  -7.55784035e-01,
                         -7.60198772e-01,  -7.63491988e-01,  -7.76999235e-01,
                         -9.31663454e-01,  -9.38860476e-01,  -9.52022195e-01,
                         -9.46051717e-01,  -9.43149447e-01,  -9.29085493e-01,
                         -9.48520005e-01,  -9.43796813e-01,  -9.15820599e-01,
                         -9.20263112e-01,  -9.22433138e-01,  -9.27320302e-01,
                         -9.24543142e-01,  -9.54597831e-01,  -9.28544283e-01,
                         -9.19193864e-01,  -7.43629694e-01,  -7.59142280e-01,
                         -7.50960469e-01,  -7.68394709e-01,  -7.48391151e-01,
                         -7.25582600e-01,  -7.51412153e-01,  -7.50310957e-01,
                          8.50631855e-03,   8.67201108e-03,   5.89398318e-04,
                          6.27540657e-03,   1.54589182e-02,   2.61055194e-02,
                          1.43014397e-02,   9.88730323e-03,  -3.02344118e-03,
                          2.78771645e-03,   1.69100743e-02,  -1.29574770e-02,
                         -7.50520110e-01,  -7.42985547e-01,  -7.52889276e-01,
                         -7.20554471e-01,  -1.51826572e-02,  -4.07540426e-03,
                         -1.95044037e-02,   1.43065611e-02,   1.38940960e-02,
                          1.12893777e-02,   1.07191978e-02,   6.87270565e-03,
                          1.68058217e-01,   1.83794260e-01,   1.58959702e-01,
                          1.60219014e-01,  -1.21016037e-02,  -1.57631841e-02,
                          1.04846582e-02,   1.72934644e-02,   1.75406024e-01,
                          1.46163970e-01,   1.45598859e-01,   1.62784636e-01,
                          2.73870528e-02,  -1.10588651e-02,   3.17624328e-03,
                          1.26950145e-02,   1.96557352e-03,   3.51763852e-02,
                         -5.83128398e-03,   1.62891764e-02,  -1.24148382e-02,
                         -1.23799574e-02,   1.78864668e-03,   7.91192334e-03,
                          1.44928038e-01,   1.59817204e-01,   1.62952855e-01,
                          1.65877774e-01,   1.65955082e-01,   1.56567827e-01,
                          1.79017767e-01,   1.86904401e-01,   1.80592373e-01,
                          1.77222818e-01,   1.77675903e-01,   1.74970657e-01,
                          1.71385407e-01,   1.70865372e-01,   1.59035102e-01,
                          1.90145195e-01,   1.83256820e-01,   1.66333839e-01,
                          1.68428421e-01,   1.41846806e-01,   1.62037820e-01,
                          1.59089848e-01,   1.49554223e-01,   1.65179953e-01,
                          1.62979245e-01,   1.72819167e-01,   1.78272873e-01,
                          1.74745366e-01,   1.65474936e-01,   1.51541889e-01,
                          1.65315509e-01,   1.59191594e-01,   1.65836766e-01,
                          1.45484433e-01,   1.61997557e-01,   1.67179078e-01,
                          1.77594081e-01,   1.57264620e-01,   1.62756443e-01,
                          1.63419247e-01,   1.55880317e-01,   1.66335016e-01,
                          1.49847269e-01,   1.67269468e-01,   1.68054268e-01,
                          1.70284316e-01,   1.57307163e-01,   1.56486884e-01,
                          1.51356444e-01,   1.69303343e-01,   1.50667623e-01,
                          1.57800958e-01,   1.54726028e-01,   1.46481022e-01,
                          1.72613010e-01,   1.61091506e-01,   1.38782322e-01,
                          1.42856330e-01,   1.44589230e-01,   1.33641586e-01,
                          2.05820566e-03,   1.46542955e-02,  -9.96448752e-03,
                          3.85638187e-03,  -2.60495418e-03,  -4.33665374e-03,
                         -4.76191845e-03,  -4.00959980e-03,   1.82290319e-02,
                         -1.00197298e-02,   5.38612134e-04,   4.50268574e-03,
                          1.58313178e-02,   8.46359972e-03,  -1.13372121e-03,
                          4.45958264e-02,   2.95768538e-03,   1.72332041e-02,
                         -1.06478492e-02,   1.06652509e-02,   1.65565506e-01,
                          1.59207180e-01,   1.73945889e-01,   1.64612293e-01,
                          1.71021968e-01,   1.85725853e-01,   1.80624321e-01,
                          1.80222929e-01,   1.58589840e-01,   1.55233517e-01,
                          1.80516079e-01,   1.56110272e-01,  -7.38090675e-05,
                          1.55697353e-02,  -2.36980468e-02,  -2.05780379e-03,
                          3.67492926e-03,   1.40189414e-03,   1.71549525e-02,
                         -6.36263285e-03,  -7.06930785e-03,   7.93176517e-03,
                          8.65873974e-03,  -1.83693655e-02,  -2.05606502e-02,
                         -3.91762741e-02,   1.51115786e-02,  -8.85835662e-03,
                         -9.37596988e-03,   1.14537049e-02,  -2.70913937e-03,
                         -1.50916334e-02,   8.95218737e-03,  -6.60229381e-03,
                          1.75142828e-02,   3.03381607e-02,   1.32729085e-02,
                          1.59638133e-02,   5.85489580e-03,   2.46012695e-02,
                          1.54401641e-03,   8.07994511e-03,   2.80340016e-02,
                          4.58117994e-03,  -7.22934538e-03,  -1.88015755e-02,
                         -1.39562488e-02,  -7.18012545e-03,   5.40310109e-04,
                         -6.64027268e-03,   2.07227245e-02,  -4.33426257e-03,
                          7.19936425e-03,   3.37561853e-02,   3.17391530e-02,
                          9.65350587e-03,  -4.99032496e-04,   2.18397714e-02,
                          4.75113466e-03,   1.27288420e-03,   1.71306133e-02,
                         -1.70910340e-02,   6.37045014e-04,  -1.02001084e-02,
                          6.18181797e-03,  -1.30378352e-02,   1.99124943e-02,
                          3.64717431e-02,  -7.94577133e-03,  -9.17272083e-03,
                          1.38106542e-02,  -5.03850495e-03,  -2.82209087e-02,
                         -7.34547153e-03,   5.96723799e-03,  -3.54845589e-03,
                          3.68161984e-02,   2.00719084e-03,   5.96626103e-03,
                          1.47202313e-02,   1.86344683e-02,  -5.41411340e-03,
                         -3.47326766e-03,   4.40677581e-03,   2.43689343e-02,
                          4.55992436e-03,   1.89833734e-02,   6.67028176e-03,
                         -1.03903208e-02,   2.96795624e-04,   2.67357584e-02,
                          3.48949176e-03,   1.15807196e-02,   8.28353316e-03,
                          1.78345237e-02,   4.28760704e-03,   3.91738350e-03,
                          3.83562525e-03,   3.73874465e-03,  -1.65012330e-02,
                         -1.53417524e-03,  -1.38391312e-02,   3.44858156e-04,
                         -1.14329141e-02,   1.17561771e-02,   1.42929908e-02,
                          8.30916862e-04,  -2.68246625e-02,  -1.07791461e-02,
                          1.07816411e-02,   1.46063501e-02,  -1.89574677e-02,
                         -9.08819616e-01,  -9.41002131e-01,  -9.30602074e-01,
                         -9.46137965e-01,  -9.26802933e-01,  -9.36986685e-01,
                         -9.11430895e-01,  -9.29880083e-01,  -9.18822229e-01,
                         -9.47739720e-01,  -9.26371157e-01,  -9.38876212e-01,
                         -9.49998293e-03,  -2.40902752e-02,  -8.45488068e-03,
                         -2.99799889e-02,  -4.11092956e-03,  -1.89975258e-02,
                         -8.15522950e-03,   1.28906674e-03,  -1.73975807e-02,
                          1.05949072e-02,  -2.03666314e-02,  -4.91171982e-03,
                         -9.33064163e-01,  -9.17993963e-01,  -9.51869011e-01,
                         -9.40095603e-01,  -9.40651953e-01,  -9.30700958e-01,
                         -9.33457732e-01,  -9.13454235e-01,  -9.34458911e-01,
                         -9.53856468e-01,  -9.22765315e-01,  -9.51071739e-01,
                         -9.20737088e-01,  -9.29948926e-01,  -9.32031035e-01,
                         -9.34425652e-01,  -9.29996192e-01,  -9.39476788e-01,
                         -9.28237379e-01,  -9.58538532e-01,  -9.59855199e-01,
                         -9.26908553e-01,  -9.47176635e-01,  -9.25386488e-01,
                         -9.39359307e-01,  -9.47932541e-01,  -9.33735847e-01,
                         -9.58847165e-01,  -9.51083601e-01,  -9.62424159e-01,
                         -9.63940501e-01,  -9.42601025e-01,  -9.24709737e-01,
                         -9.42945063e-01,  -9.35636640e-01,  -9.36261058e-01,
                         -9.18927073e-01,  -9.14645910e-01,  -9.17412043e-01,
                         -9.32829559e-01,  -9.40706372e-01,  -9.44755673e-01,
                         -9.42726731e-01,  -9.46916163e-01,  -9.39430058e-01,
                         -9.28825617e-01,  -8.95749569e-01,  -9.12741780e-01,
                         -9.34687674e-01,  -9.50015783e-01,  -9.68386829e-01,
                         -9.38093662e-01,  -9.33876872e-01,  -9.39743459e-01,
                         -9.28408802e-01,  -9.42252398e-01,  -9.20933783e-01,
                         -9.47617412e-01,  -9.57566321e-01,  -9.30800080e-01,
                         -9.37485814e-01,  -9.20953929e-01,  -9.16542590e-01,
                         -9.23595071e-01,  -9.55847085e-01,  -9.43402708e-01,
                         -9.45294857e-01,  -9.31139171e-01,  -9.21727955e-01,
                         -9.07069266e-01,  -8.94681811e-01,  -9.34089005e-01,
                         -9.01583314e-01,  -9.34087634e-01,  -9.14744079e-01,
                         -9.20000732e-01,  -9.14674997e-01,  -9.32738841e-01,
                         -9.28219736e-01,  -9.28153455e-01,  -9.44163084e-01,
                         -9.29449618e-01,  -9.37479913e-01,  -9.23474371e-01,
                         -9.34196413e-01,  -9.66897845e-01,  -9.36965168e-01,
                         -9.22871590e-01,  -9.16506231e-01,  -9.21324968e-01,
                         -9.12446856e-01,  -9.10557806e-01,  -9.13093805e-01,
                         -9.09388542e-01,  -9.12762642e-01,  -9.19656754e-01,
                         -9.08389270e-01,  -9.20804322e-01,  -9.04366195e-01,
                         -9.12076473e-01,  -9.58586037e-01,  -9.47524071e-01,
                         -9.49167371e-01,  -9.28414822e-01,  -9.48017061e-01,
                         -9.25312698e-01,  -9.09414589e-01,  -8.95241261e-01,
                         -9.02453721e-01,  -9.10486996e-01,  -9.12723005e-01,
                         -9.09482539e-01,  -9.03113425e-01,  -9.30383384e-01,
                         -9.19787526e-01,  -9.22148108e-01,  -9.07732129e-01,
                         -9.21705723e-01,  -9.26778674e-01,  -9.52418387e-01,
                         -9.30370629e-01,  -9.32942986e-01,  -9.56112683e-01,
                         -9.31529939e-01,  -9.39607501e-01,  -9.33729410e-01,
                         -9.48390543e-01,  -9.31404948e-01,  -9.52697337e-01,
                         -9.53449070e-01,  -9.53526914e-01,  -9.41389978e-01,
                         -9.54164505e-01,  -9.14320588e-01,  -9.27124918e-01,
                         -9.24439371e-01,  -9.45045829e-01,  -9.10438180e-01,
                         -9.46090817e-01,  -9.30921853e-01,  -9.29459691e-01,
                         -9.21218693e-01,  -9.02173340e-01,  -9.44465458e-01,
                         -9.32552516e-01,  -9.33839083e-01,  -9.28627431e-01,
                         -9.36487913e-01,  -9.24178243e-01,  -9.50008154e-01,
                         -9.47387636e-01,  -9.32473123e-01,  -9.44527328e-01,
                         -9.40037727e-01,  -9.34736013e-01,  -9.35077548e-01,
                         -9.42885339e-01,  -9.41713572e-01,  -9.40391600e-01,
                         -9.49664354e-01,  -9.57605779e-01,  -9.42421794e-01,
                         -9.61655259e-01,  -9.28147495e-01,  -9.48541880e-01,
                         -9.51413095e-01,  -9.33607101e-01,  -9.49926853e-01,
                         -9.50392663e-01,  -9.52600241e-01,  -9.27513838e-01,
                         -9.35262501e-01,  -9.28659379e-01,  -9.29793239e-01,
                         -9.36813354e-01,  -9.33072507e-01,  -9.28918779e-01,
                         -9.28552330e-01,  -9.28878248e-01,  -9.38361585e-01,
                         -9.25380528e-01,  -9.19089854e-01,  -9.54325855e-01,
                         -9.25149202e-01,  -9.41500008e-01,  -9.50981140e-01,
                         -9.34245646e-01,  -9.20328379e-01,  -9.47365284e-01,
                         -9.50340927e-01,  -9.48247135e-01,  -9.40064669e-01,
                         -9.29438174e-01,  -9.16062713e-01,  -9.44876194e-01,
                         -9.20941830e-01,  -9.46778238e-01,  -9.43198800e-01,
                         -9.34958816e-01,  -9.61255193e-01,  -9.54543650e-01,
                         -9.46642041e-01,  -9.30253863e-01,  -9.24032569e-01,
                         -9.54805672e-01,  -9.23958659e-01,  -9.52108026e-01,
                         -9.29444134e-01,  -9.45545614e-01,  -9.42688048e-01,
                         -9.35502052e-01,  -9.27309930e-01,  -9.18140054e-01,
                         -9.21765924e-01,  -9.38296020e-01,  -9.28702116e-01,
                         -9.54683006e-01,  -9.29697335e-01,  -9.35368598e-01,
                         -9.16957736e-01,  -9.24660861e-01,  -9.22602534e-01,
                         -9.31914389e-01,  -9.20252144e-01,  -9.31773126e-01,
                         -9.14926231e-01,  -9.30159569e-01,  -9.28010702e-01,
                         -9.25325096e-01,  -9.70842361e-01,  -9.46795046e-01,
                         -9.45663571e-01,  -9.51492488e-01,  -9.21799481e-01,
                         -9.45043385e-01,  -9.34445798e-01,  -9.21213567e-01,
                         -9.20694828e-01,  -9.20974672e-01,  -9.32824433e-01,
                         -9.39127564e-01,  -9.38500047e-01,  -9.34677780e-01,
                         -9.57910478e-01,  -9.46796656e-01,  -9.32591140e-01,
                         -9.29212809e-01,  -9.23779786e-01,  -9.40185010e-01,
                         -9.33446288e-01,  -9.29483891e-01,  -9.40858066e-01,
                         -9.22417920e-03,   7.15412945e-03,  -9.31518967e-04,
                          9.38742515e-03,  -6.47543930e-03,   1.44471796e-02,
                          1.87659524e-02,   6.96259318e-03,   2.96168425e-03,
                         -4.77216858e-03,   6.87467353e-03,  -2.22806353e-03,
                          3.32331401e-03,  -2.36218758e-02,   3.79708502e-03,
                         -1.44787123e-02,  -5.38577500e-04,   8.69569927e-03,
                          1.20034134e-02,  -1.19122295e-02,  -3.62733798e-03,
                         -3.39407357e-03,   2.02938411e-02,  -7.45735643e-03,
                         -7.47389253e-03,   7.34382891e-04,  -9.49430000e-03,
                         -2.71717180e-03,  -1.41952168e-02,  -6.05013967e-03,
                         -4.73028095e-03,  -2.86349319e-02,  -1.87049992e-02,
                          2.94559170e-03,  -2.34619007e-02,   1.63911711e-02,
                         -5.93525404e-03,   2.71402532e-03,  -1.08664203e-02,
                         -1.29793072e-04,   1.74799969e-03,   9.26082022e-03,
                         -3.09593286e-02,   1.00443396e-03,   7.52830319e-03,
                          2.78691947e-03,  -4.33045765e-03,   1.10988254e-02,
                         -9.20294583e-01,  -9.35193419e-01,  -9.36699390e-01,
                         -9.24145460e-01,  -9.36614215e-01,  -9.43569362e-01,
                         -9.48621511e-01,  -9.47739065e-01,  -9.55001056e-01,
                         -9.25271630e-01,  -9.40456808e-01,  -9.38715279e-01,
                         -9.34268534e-01,  -9.24084365e-01,  -9.40378249e-01,
                         -9.36180413e-01,  -9.39006150e-01,  -9.33652222e-01,
                         -9.27688539e-01,  -9.45471883e-01,  -9.42448437e-01,
                         -9.35722470e-01,  -9.47503626e-01,  -9.14774895e-01,
                         -9.21436846e-01,  -9.10841584e-01,  -9.27390575e-01,
                         -9.06321406e-01,  -9.35960114e-01,  -9.27863657e-01,
                         -9.23837006e-01,  -9.24006999e-01,  -9.16088879e-01,
                         -9.25790191e-01,  -9.50605571e-01,  -9.29222107e-01,
                         -9.36093032e-01,  -9.26107883e-01,  -9.35763717e-01,
                         -9.28607643e-01,  -9.16263819e-01,  -9.17869151e-01,
                         -9.10939813e-01,  -9.14223969e-01,  -9.21314240e-01,
                         -9.29024279e-01,  -9.15949881e-01,  -9.24570262e-01,
                         -9.17286038e-01,  -9.10199940e-01,  -9.19838190e-01,
                         -9.40874279e-01,  -9.34309423e-01,  -9.27346408e-01,
                         -9.27206457e-01,  -9.19082582e-01,  -9.31866705e-01,
                         -9.24893022e-01,  -9.34512496e-01,  -9.19257343e-01,
                         -9.43006516e-01,  -9.35329616e-01,  -9.19932783e-01,
                         -9.33975995e-01,  -9.31021392e-01,  -9.32188153e-01,
                         -9.40894365e-01,  -9.27289307e-01,  -9.07058179e-01,
                         -9.26194429e-01,  -9.50209379e-01,  -9.22638595e-01,
                         -9.36005354e-01,  -9.15706038e-01,  -9.12005782e-01,
                         -9.38419223e-01,  -9.27562416e-01,  -9.24671233e-01,
                         -9.23200369e-01,  -9.49230492e-01,  -9.25879240e-01,
                         -9.16605651e-01,  -9.37686265e-01,  -9.28778827e-01,
                         -9.33754861e-01,  -9.21164215e-01,  -9.35009658e-01,
                         -9.34361458e-01,  -9.50727582e-01,  -9.25990224e-01,
                         -9.37686265e-01,  -9.39810514e-01,  -9.15743649e-01,
                         -9.20351326e-01,  -9.27532613e-01,  -9.25175250e-01,
                         -9.20962453e-01,  -9.05645430e-01,  -9.19125736e-01,
                         -9.25737858e-01,  -9.18757915e-01,  -9.43485439e-01,
                         -9.09329116e-01,  -9.36721802e-01,  -9.27706063e-01,
                         -9.29352880e-01,  -9.35648263e-01,  -9.29281056e-01,
                         -9.30463433e-01,  -9.24278259e-01,  -9.41803634e-01,
                         -9.34654951e-01,  -9.32761252e-01,  -9.30246234e-01,
                         -9.14784670e-01,  -9.24734354e-01,  -9.20643866e-01,
                         -9.43981349e-01,  -9.23572123e-01,  -9.40962315e-01,
                         -9.31264818e-01,  -9.35435474e-01,  -9.33269203e-01,
                         -9.26975906e-01,  -9.30197537e-01,  -9.35232818e-01,
                         -9.39435959e-01,  -9.16852772e-01,  -9.49894488e-01,
                         -9.21792388e-01,  -9.43914592e-01,  -9.29252923e-01,
                         -9.34007823e-01,  -9.31652725e-01,  -9.25131500e-01,
                         -9.26960647e-01,  -9.10750389e-01,  -9.39321756e-01,
                         -9.17859674e-01,  -9.23402071e-01,  -9.29060161e-01,
                         -9.33696926e-01,  -9.33190465e-01,  -9.27202582e-01,
                         -9.25738156e-01,  -9.34823275e-01,  -9.14484084e-01,
                         -9.33387756e-01,  -9.28125918e-01,  -9.37534928e-01,
                         -9.19276714e-01,  -9.29522276e-01,  -9.30444121e-01,
                         -9.31477845e-01,  -9.26920116e-01,  -9.15199757e-01,
                         -9.22497034e-01,  -9.35678422e-01,  -9.13437128e-01,
                         -9.28504348e-01,  -9.24877703e-01,  -9.31075871e-01,
                         -9.37208474e-01,  -9.25158381e-01,  -9.34398353e-01,
                         -9.23428774e-01,  -9.13045168e-01,  -9.19340491e-01,
                         -9.21244621e-01,  -9.24353302e-01,  -9.13693666e-01,
                         -9.12233174e-01,  -8.96265388e-01,  -9.12852168e-01,
                         -9.24705267e-01,  -9.14641440e-01,  -9.23999846e-01,
                         -9.12088156e-01,  -9.19726551e-01,  -9.29766774e-01,
                         -9.14856970e-01,  -9.14477825e-01,  -9.22027588e-01,
                         -9.14640546e-01,  -9.36338902e-01,  -9.16469812e-01,
                         -9.30730999e-01,  -9.23753440e-01,  -9.31324363e-01,
                         -9.18383658e-01,  -9.25920486e-01,  -9.23272431e-01,
                         -9.26739275e-01,  -9.27240133e-01,  -9.28584337e-01,
                         -9.22230721e-01,  -9.25925374e-01,  -9.16393638e-01,
                         -9.14625943e-01,  -9.16428030e-01,  -9.27154303e-01,
                         -9.38570142e-01,  -9.20968056e-01,  -9.31914151e-01,
                         -9.34989810e-01,  -9.29468751e-01,  -9.28843200e-01,
                         -9.24535930e-01,  -9.25102830e-01,  -9.37712193e-01,
                         -9.18002129e-01,  -9.44045424e-01,  -9.27013397e-01,
                         -9.24491704e-01,  -9.41191435e-01,  -9.32428002e-01,
                         -9.37435865e-01,  -9.30547059e-01,  -9.25017953e-01,
                         -9.32287514e-01,  -9.28127050e-01,  -9.41135764e-01,
                         -9.38577831e-01,  -9.43189561e-01,  -9.10608888e-01,
                         -9.42601204e-01,  -9.25330997e-01,  -9.34554160e-01,
                         -9.31490779e-01,  -9.23070729e-01,  -9.31115091e-01,
                         -9.24232602e-01,  -9.26441431e-01,  -9.40337241e-01,
                         -9.21179533e-01,  -9.47206020e-01,  -9.29154634e-01,
                         -9.31075513e-01,  -9.36660230e-01,  -9.29464817e-01,
                         -9.28259790e-01,  -9.32069719e-01,  -9.37658787e-01,
                         -9.31550682e-01,  -9.26201165e-01,  -9.30126667e-01,
                         -9.38905895e-01,  -9.24392045e-01,  -9.37059343e-01,
                         -9.39614475e-01,  -9.27557588e-01,  -9.39435542e-01,
                         -9.20882046e-01,  -9.29307818e-01,  -9.34959233e-01,
                         -9.24599707e-01,  -9.34721708e-01,  -9.36548889e-01,
                         -9.22748446e-01,  -9.36613023e-01,  -9.29256737e-01,
                         -9.42890286e-01,  -9.35298860e-01,  -9.33632374e-01,
                         -9.27835286e-01,  -9.28157449e-01,  -9.29683566e-01,
                         -9.32864010e-01,  -9.28379714e-01,  -9.35709596e-01,
                         -9.39256430e-01,  -9.31238949e-01,  -9.34494376e-01,
                         -9.30619359e-01,  -9.19274330e-01,  -9.21915352e-01,
                         -9.23195362e-01,  -9.34601605e-01,  -9.31637645e-01,
                         -9.27132726e-01,  -9.23730075e-01,  -9.34440494e-01,
                         -9.26660478e-01,  -9.24690664e-01,  -9.32670951e-01,
                         -9.34883177e-01,  -9.22529161e-01,  -9.41659570e-01,
                         -9.36722696e-01,  -9.38596189e-01,  -9.33143139e-01,
                         -9.24933195e-01,  -9.34526205e-01,  -9.38983679e-01,
                         -9.23040748e-01,  -9.36401784e-01,  -9.41842735e-01,
                         -9.26475406e-01,  -9.31003094e-01,  -9.21976149e-01,
                         -9.37009513e-01,  -9.26326096e-01,  -9.33244944e-01,
                         -9.24864590e-01,  -9.28834140e-01,  -9.31120992e-01,
                         -9.27982152e-01,  -9.30496693e-01,  -9.34127331e-01,
                         -9.31824923e-01,  -9.26575184e-01,  -9.17711258e-01,
                         -9.31574941e-01,  -9.33007181e-01,  -9.29540038e-01,
                         -9.29953575e-01,  -9.27428961e-01,  -9.28136945e-01,
                         -9.31542814e-01,  -9.36066329e-01,  -9.25756335e-01,
                         -9.30829585e-01,  -9.23156500e-01,  -9.24866557e-01,
                         -9.28321838e-01,  -9.22409296e-01,  -9.35696304e-01,
                         -9.16988969e-01,  -9.27707732e-01,  -9.30442393e-01,
                         -9.31872249e-01,  -9.27862465e-01,  -9.26911414e-01,
                         -9.27545547e-01,  -9.25790310e-01,  -9.32130396e-01,
                         -9.19260979e-01,  -9.28062439e-01,  -9.30216253e-01,
                         -9.29294944e-01,  -9.33456481e-01,  -9.23065543e-01,
                         -9.25272465e-01,  -9.25242305e-01,  -9.30895686e-01,
                         -9.27969754e-01,  -9.31354523e-01,  -9.40073431e-01,
                         -9.17938292e-01,  -9.39959884e-01,  -9.25983250e-01,
                         -9.33256030e-01,  -9.27652836e-01,  -9.16147888e-01,
                         -9.43163335e-01,  -9.23097312e-01,  -9.37239289e-01,
                         -9.19506490e-01,  -9.30278599e-01,  -9.30985034e-01,
                         -9.38149691e-01,  -9.16177750e-01,  -9.38302577e-01,
                         -9.26586390e-01,  -9.38410282e-01,  -9.29248095e-01,
                         -9.29625988e-01,  -9.37220991e-01,  -9.29868042e-01,
                         -9.28067625e-01,  -9.31995034e-01,  -9.16459084e-01,
                         -9.42424595e-01,  -9.31373596e-01,  -9.23248827e-01,
                         -9.35174465e-01,  -9.17139053e-01,  -9.43267524e-01,
                         -9.21740532e-01,  -9.30142820e-01,  -9.29885685e-01,
                         -9.33691561e-01,  -9.27388191e-01,  -9.16380405e-01,
                         -9.23341095e-01,  -9.24907982e-01,  -9.41473067e-01,
                         -9.12504196e-01,  -9.36389029e-01,  -9.22881842e-01,
                         -9.22158539e-01,  -9.34011579e-01,  -9.35674369e-01,
                         -9.39859867e-01,  -9.34488177e-01,  -9.39386070e-01,
                         -9.35669124e-01,  -9.21814024e-01,  -9.23104048e-01,
                         -9.39321280e-01,  -9.32015181e-01,  -9.38955486e-01,
                         -9.33780372e-01,  -9.49765623e-01,  -9.22598898e-01,
                         -9.35652137e-01,  -9.27728891e-01,  -9.19933319e-01,
                         -9.32316601e-01,  -9.22857761e-01,  -9.43822622e-01,
                         -9.35654402e-01,  -9.39199448e-01,  -9.31618571e-01,
                         -9.27879989e-01,  -9.52046692e-01,  -9.37567949e-01,
                         -9.50872064e-01,  -9.30205643e-01,  -9.44788933e-01,
                         -9.37736392e-01,  -9.47507203e-01,  -9.38413680e-01,
                         -9.33972120e-01,  -9.35228109e-01,  -9.36072111e-01,
                         -9.25919652e-01,  -9.48599756e-01,   3.06687434e-03,
                         -8.56236462e-03,  -7.94485025e-03,   1.34940993e-03,
                         -3.00110457e-03,  -8.94088391e-03,  -4.29639453e-03,
                         -3.66666820e-03,   1.24311382e-02,   7.72179384e-03,
                          1.14280907e-02,   2.00452395e-02,   1.85434718e-03,
                          1.12640951e-03,  -7.72881438e-04,  -1.19682830e-02,
                          6.84460253e-03,   4.52459994e-04,   4.81866486e-03,
                          3.90474242e-03,  -2.08356138e-02,  -1.21766946e-03,
                          3.42502492e-03,  -2.75664739e-02,   7.95218907e-03,
                          5.14664734e-03,  -6.32920023e-03,  -5.87573554e-03,
                         -4.19999240e-03,  -2.00149678e-02,  -9.86866094e-03,
                         -1.91615277e-03,   4.77663893e-03,  -1.74736910e-04,
                         -6.43737055e-03,   1.09309638e-02,  -3.40491277e-03,
                          4.33128932e-03,   9.96318486e-05,  -1.02236653e-02,
                          3.18311132e-03,   1.23688055e-03,  -7.71457236e-03,
                         -1.49290869e-02,   1.10539095e-02,   9.27818101e-03,
                          1.14623820e-02,  -8.16289522e-03,   1.06119839e-02,
                         -1.58782362e-03,  -5.33032464e-03,   8.12079944e-03,
                         -1.20883519e-02,   9.54363775e-03,  -2.18437426e-03,
                         -8.04902799e-03,  -1.47123449e-02,  -7.27182196e-04,
                         -2.46703182e-03,   3.47960205e-03,  -4.45995294e-03,
                         -1.18551506e-02,   1.69618167e-02,  -5.45356143e-03,
                          1.60388630e-02,  -5.85655915e-03,   4.70799999e-03,
                         -1.11369218e-03,  -4.82285768e-03,  -6.20033592e-03,
                         -5.48439508e-04,  -1.36479549e-03,  -1.30334413e-02,
                         -3.60376760e-03,  -1.00466274e-02,  -2.17936765e-02,
                         -4.82021039e-03,  -9.86938830e-03,  -6.92726206e-03,
                          9.06666461e-03,   4.11031954e-03,  -1.99357257e-03,
                         -8.37800838e-03,  -1.69316344e-02,   6.77960226e-03,
                          7.19820708e-03,  -7.55951088e-03,   7.78767467e-03,
                          2.07890701e-02,  -1.82305626e-03,   2.12761406e-02,
                          1.28697930e-02,  -5.53717045e-03,  -1.08441117e-03,
                          4.29757312e-03,   2.36827806e-02,   1.70295332e-02,
                          1.56349577e-02,   2.27992535e-02,   2.10657325e-02,
                          1.15234256e-02,  -5.65017760e-03,   1.64712947e-02,
                          4.82623978e-03,   1.33686103e-02,   2.02707434e-03,
                          1.21167256e-02,  -7.13860523e-03,  -1.64207090e-02,
                         -4.57581598e-03,   6.87955972e-03,   4.49626148e-03,
                          4.22605779e-03,   1.14013115e-02,   2.29359921e-02,
                          1.59937385e-02,   1.42066795e-02,   1.64612103e-02,
                         -4.66639642e-04,   2.01431545e-03,   5.81844850e-03,
                          2.23473762e-03,   2.38583493e-03,  -2.12189648e-03,
                         -2.33490998e-03,  -6.66899234e-03,  -8.64120550e-04,
                          1.35175942e-03,   3.56002268e-03,   8.74696358e-04,
                          4.18191077e-03,   1.25984047e-02,   1.34762190e-02,
                          8.18111468e-03,   3.53318825e-03,   8.42769258e-03,
                          2.75967596e-03,   8.51487741e-03,   8.08078982e-03,
                          9.07046907e-03,  -9.42677632e-03,  -2.03061572e-05,
                         -9.90256388e-03,  -7.78402248e-03,  -1.48218311e-03,
                         -1.17671341e-02,  -1.23825492e-02,  -2.13601161e-02,
                         -5.78988856e-03,  -8.51406716e-03,   2.62468518e-03,
                         -4.11433214e-03,  -7.62736006e-03,  -1.76134077e-03,
                          1.36624472e-02,   1.02999136e-02,  -6.00586133e-03,
                          1.51671749e-03,  -1.47421309e-03,   1.17800105e-02,
                          4.92261432e-04,   2.37042154e-03,  -3.60466167e-03,
                         -5.75660169e-03,   8.00477713e-03,  -1.52902734e-02,
                          7.77861662e-03,  -9.27984423e-04,  -1.32922851e-03,
                         -1.12380367e-03,  -2.49701971e-03,  -1.94784557e-03,
                          1.42222794e-03,  -1.53522869e-03,  -5.53904148e-03,
                          8.94490350e-03,  -6.08435553e-03,  -1.16238473e-02,
                         -6.04368746e-03,  -9.20835696e-03,  -9.52552829e-04,
                          4.31571668e-03,  -4.35203221e-03,   5.27446531e-03,
                          2.31912942e-04,  -3.04267323e-03,  -4.09773411e-03,
                         -9.66988225e-03,  -5.39590046e-03,   3.74552957e-03,
                         -7.34938029e-03,   2.24292930e-03,  -4.76023462e-03,
                          1.70147582e-03,   1.05403718e-02,  -2.28799810e-03,
                         -4.52033756e-03,   7.71074696e-03,  -3.02908273e-04,
                          2.68601254e-03,  -2.75392388e-03,  -8.39060114e-04,
                         -9.07642953e-03,   9.44139261e-04,  -1.37357293e-02,
                          3.12052970e-03,   3.63648613e-03,  -3.77104059e-03,
                          4.76347096e-03,   4.71615698e-04,   3.69260204e-04,
                          3.75390146e-03,   1.05049852e-02,  -1.52499927e-03,
                          4.63612424e-03,   3.43214953e-03,  -6.91514043e-03,
                         -5.20189013e-03,   2.88387621e-03,  -8.48998374e-04,
                         -2.42052856e-03,  -6.55678893e-03,   3.39911901e-03,
                         -2.46580504e-03,  -2.92462017e-03,   1.06324842e-02,
                          1.13143763e-02,   1.03386473e-02,   1.19796488e-02,
                          7.01234676e-03,   5.83305117e-03,   4.35495703e-03,
                          2.33328133e-03,   3.03695560e-03,   7.70773226e-03,
                          5.96465310e-03,  -1.13153117e-04,  -2.36629113e-03,
                         -9.67697892e-03,  -1.48574328e-02,  -1.20948050e-02,
                          2.37893910e-04,  -4.01020283e-03,  -1.95650873e-03,
                          2.68228381e-04,   9.02833941e-04,  -5.29240118e-03,
                         -4.29770444e-03,  -3.87059618e-03,  -2.88747321e-03,
                         -2.61069951e-03,  -4.49604634e-03,   3.76322314e-05,
                          2.99845007e-03,  -6.52353652e-03,   9.89783090e-04,
                         -3.99103994e-03,  -5.53380873e-04,  -3.57577577e-03,
                         -5.23605011e-03,  -1.67116208e-03,  -1.94766535e-03,
                         -1.30037020e-03,   2.51124799e-03,  -5.01605729e-03,
                         -1.13890376e-02,  -1.39616746e-02,  -1.06754601e-02,
                         -8.55693128e-03,   1.86379335e-03,   5.88540360e-03,
                          2.81884801e-03,   1.88141048e-03,  -6.85496349e-03,
                         -5.20551461e-04,   3.02625494e-03,  -2.61170994e-02,
                         -7.97976553e-03,  -5.16561605e-03,   2.34360085e-03,
                         -7.39172520e-03,  -5.42110624e-03,  -7.95462169e-03,
                         -4.03127121e-03,  -3.78870615e-03,   1.03042107e-02,
                         -1.12689054e-02,  -2.25728303e-02,   2.07119267e-02,
                          1.24333974e-03,   4.96938778e-03,  -3.99932172e-03,
                          3.13635170e-03,   2.80883367e-04,   2.17394391e-03,
                          1.95890665e-03,   3.79094467e-06,  -6.29856111e-03,
                          1.60051335e-04,  -5.77020599e-03,  -4.13807621e-03,
                         -2.92386487e-03,   1.78080844e-03,  -3.29120527e-03,
                          4.46528243e-03,   3.84755246e-03,  -4.64702584e-03,
                         -1.01815350e-02,  -4.87654796e-03,   3.70005216e-03,
                         -7.35387846e-04,   3.29526654e-03,   7.02452334e-03,
                          4.98040719e-03,   6.50706282e-03,  -2.38469825e-03,
                          1.15216302e-03,   1.76395359e-03,  -1.13626393e-02,
                         -1.84870381e-02,  -4.12606541e-03,   3.14699695e-03,
                         -7.00292131e-03,  -6.30757771e-03,   5.46200958e-04,
                         -5.55742811e-03,  -5.62153431e-03,  -2.11813324e-03,
                         -6.96355663e-03,  -1.35216964e-02,  -5.59495622e-03,
                         -2.99989176e-03,   8.71778684e-05,   4.26790398e-03,
                         -2.93165469e-03,   1.44770427e-03,   2.70055258e-03,
                          7.36514712e-03,   6.03894005e-03,   1.39709553e-02,
                         -6.92661735e-04,   1.49688253e-03,   1.27150221e-02,
                          1.17839612e-02,   9.55686066e-03,   8.65506649e-04,
                          7.52774207e-03,   7.16561312e-03,   7.92188942e-03,
                         -1.19948890e-02,   2.38414109e-02,  -6.51928829e-03,
                          4.99349181e-03,   6.05751388e-03,   4.52213269e-03,
                         -3.78955156e-03,  -7.07101962e-03,  -2.53861617e-05,
                          2.30576075e-03,   1.04639772e-03,  -9.66680516e-03,
                         -3.51339485e-03,   1.24647161e-02,   5.22990292e-03,
                          2.43282318e-03,   5.96802821e-03,  -1.55166415e-02,
                         -8.67829751e-03,   7.76650198e-03,   3.68115283e-03,
                         -3.47470236e-03,   1.85081956e-03,  -1.26159447e-03,
                          1.36564039e-02,  -7.66993361e-03,  -6.37154561e-03,
                         -4.35712608e-03,  -2.15565320e-02,  -2.06591859e-02,
                         -1.27910078e-02,  -1.49180675e-02,   2.81728175e-03,
                          2.39340984e-03,   8.45705718e-03,   8.99933558e-03,
                          1.01479292e-02,   8.34533852e-03,   9.76261124e-03,
                         -8.92017595e-03,  -8.63304827e-03,   7.27473991e-03,
                         -2.95631326e-04,   7.70859839e-03,   4.79372917e-03,
                         -7.85437971e-03,  -9.72167309e-03,   6.52616331e-03,
                          1.81683898e-02,   1.17232921e-02,  -1.22732557e-02,
                         -2.21022475e-03,   7.84843345e-04,   1.36548998e-02,
                         -2.54928891e-04,   2.07265560e-03,  -5.89180738e-03,
                         -1.82081084e-03,   1.22150891e-02,   1.52551429e-02,
                          3.74358217e-03,   7.09434738e-03,   1.02783740e-02,
                          2.26545949e-02,   6.21101586e-03,   1.75827201e-02,
                          3.12974863e-02,   1.67932268e-02,   1.55750792e-02,
                         -4.35820036e-03,  -2.37716478e-03,   7.57265091e-03,
                         -1.53499993e-03,   1.50125148e-02,   7.94934109e-03,
                          9.54176579e-03,   2.36800290e-03,  -8.16799607e-03,
                         -1.33746881e-02,  -6.71890564e-03,  -1.70282926e-02,
                         -1.07468776e-02,   5.13661234e-03,   5.97793190e-03,
                         -8.40630569e-03,   1.34735992e-02,   4.85671312e-03,
                         -3.42941321e-02,  -1.52619136e-03,  -6.68015052e-03,
                          1.07287895e-03,  -8.06112832e-04,   7.74410320e-03,
                         -1.34984660e-03,  -3.11895646e-03,  -6.02155877e-03,
                          1.18847573e-02,   5.24772076e-05,   6.82950113e-03,
                         -7.30344560e-03,   1.18833715e-02,   2.12431718e-02,
                         -4.32915473e-03,  -8.98043625e-03,   7.68951885e-03,
                          2.93015083e-03,   1.71555355e-02,   2.70775538e-02,
                          3.68292145e-02,   1.08811064e-02,   2.16269512e-02,
                          9.37816687e-03,   4.04177792e-03,   1.60107110e-02,
                          5.28951129e-03,  -4.49819490e-03,  -1.57751404e-02,
                         -3.72175826e-03,   7.73372827e-03,  -9.30052817e-01,
                         -9.30522859e-01,  -9.14941370e-01,  -9.22483206e-01,
                         -9.21925187e-01,  -9.30756152e-01,  -9.31905985e-01,
                         -9.23738062e-01,  -9.14540887e-01,  -9.19290423e-01,
                         -9.16852713e-01,  -9.28977728e-01,  -7.62389461e-03,
                         -1.38269337e-02,  -7.75348686e-04,   1.57720633e-02,
                          1.66519359e-02,   1.86459590e-02,   3.57118086e-04,
                          2.10434292e-02,   1.94829330e-02,   1.44481845e-02,
                          2.64225379e-02,   5.06843068e-03,  -4.94430657e-04,
                          9.20399092e-03,  -1.80731725e-03,  -3.56093496e-02,
                          7.60911917e-03,  -5.42449532e-03,  -3.19119915e-03,
                          1.40255941e-02,   1.15880724e-02,   5.46785910e-03,
                         -2.21125111e-02,  -2.83181220e-02,  -1.00666285e-02,
                         -1.61924064e-02,   4.00797091e-03,   6.34217402e-03,
                         -5.72503358e-03,  -1.10540409e-02,   5.84103493e-03,
                         -8.64731148e-03,  -7.82785751e-03,   1.09950285e-02,
                          8.07949400e-05,  -9.66925174e-03,  -8.05939562e-05,
                         -8.49435665e-03,  -1.27391266e-02,  -2.70077232e-02,
                         -1.39586953e-02,  -1.23434197e-02,  -9.93192848e-03,
                         -6.34237519e-03,   1.41852573e-02,   7.62528786e-03,
                         -2.15929914e-02,  -1.97934583e-02,   6.95654983e-03,
                         -4.24190774e-04,   8.04396160e-03,  -6.79182063e-04,
                          1.19685736e-02,   8.65666009e-03,   1.74833108e-02,
                          3.24152107e-03,   6.72211405e-03,   8.91038310e-03,
                         -3.70267872e-03,   9.35006328e-03,  -1.60280447e-02,
                         -4.56719426e-03,  -5.62767452e-03,   7.15562655e-03,
                         -9.27599072e-01,  -9.38608825e-01,  -9.33169603e-01,
                         -9.08592224e-01,  -9.10041749e-01,  -9.26600277e-01,
                         -9.29544330e-01,  -9.25421476e-01,  -9.28719223e-01,
                         -9.28179622e-01,  -9.25250292e-01,  -9.33098674e-01,
                         -9.27404821e-01,  -9.22095895e-01,  -9.25793290e-01,
                         -9.46498454e-01,  -9.34885502e-01,  -9.31471825e-01,
                         -9.25901413e-01,  -9.13347900e-01,  -9.28846419e-01,
                         -9.19196725e-01,  -9.21974063e-01,  -9.15899694e-01,
                         -9.25251067e-01,  -9.26807344e-01,  -9.14387703e-01,
                         -9.37746704e-01,  -9.33154643e-01,  -9.36388314e-01,
                         -9.34946239e-01,  -9.31649029e-01,  -9.20919776e-01,
                         -9.25930500e-01,  -9.20218349e-01,  -9.38251793e-01,
                         -9.17712688e-01,  -9.24787998e-01,  -9.31664586e-01,
                         -9.31002438e-01,  -9.29219842e-01,  -9.24524307e-01,
                         -9.34768617e-01,  -9.33474243e-01,  -9.38554823e-01,
                         -9.31031823e-01,  -9.43110645e-01,  -9.53105509e-01,
                         -9.26491797e-01,  -9.34740543e-01,  -9.25553024e-01,
                         -9.24671173e-01,  -9.35956001e-01,  -9.32031035e-01,
                         -9.46895957e-01,  -9.37288940e-01,  -9.21985269e-01,
                         -9.27746773e-01,  -9.46886241e-01,  -9.32079196e-01,
                         -9.26935196e-01,  -9.27098930e-01,  -9.41015124e-01,
                         -9.35438573e-01,  -9.30261075e-01,  -9.40743446e-01,
                         -9.29537237e-01,  -9.38652515e-01,  -9.13379192e-01,
                         -9.28763568e-01,  -9.38706756e-01,  -9.40435946e-01,
                         -9.42819238e-01,  -9.21335459e-01,  -9.19691205e-01,
                         -9.37310576e-01,  -9.24075127e-01,  -9.40165401e-01,
                         -9.26635504e-01,  -9.25372064e-01,  -9.21842337e-01,
                         -9.21178997e-01,  -9.23747897e-01,  -9.33266521e-01,
                         -9.33421552e-01,  -9.50312853e-01,  -9.48428869e-01,
                         -9.33367789e-01,  -9.45597172e-01,  -9.40371871e-01,
                         -9.42584157e-01,  -9.49985623e-01,  -9.41533029e-01,
                         -9.39182699e-01,  -9.42845404e-01,  -9.24395621e-01,
                         -9.33813214e-01,  -9.27053928e-01,  -9.33510959e-01,
                         -9.30174708e-01,  -9.28929567e-01,  -9.31830585e-01,
                         -9.35097158e-01,  -9.25303578e-01,  -9.38489854e-01,
                         -9.30726886e-01,  -9.36438024e-01,  -9.45075214e-01,
                         -9.53004181e-01,  -9.41360950e-01,  -9.42808330e-01,
                         -9.30844784e-01,  -9.32210684e-01,  -9.40609157e-01,
                         -9.36389208e-01,  -9.36608553e-01,  -9.39455450e-01,
                         -9.35383379e-01,  -9.46021199e-01,  -9.34668481e-01,
                         -9.37640905e-01,  -9.46695805e-01,  -9.37796712e-01,
                         -9.39851224e-01,  -9.37064290e-01,  -9.34124231e-01,
                         -9.34041440e-01,  -9.29308593e-01,  -9.27462876e-01,
                         -9.41918254e-01,  -9.24169600e-01,  -9.26314652e-01,
                         -9.40009356e-01,  -9.34852123e-01,  -9.37940180e-01,
                         -9.29757416e-01,  -9.29539740e-01,  -9.38294828e-01,
                         -9.23629165e-01,  -9.27739024e-01,  -9.42845643e-01,
                         -9.42538321e-01,  -9.33159113e-01,  -9.38963473e-01,
                         -9.30200398e-01,  -9.32649016e-01,  -9.23793733e-01,
                         -9.33700800e-01,  -9.30873036e-01,  -9.23955202e-01,
                         -9.30957198e-01,  -9.24249947e-01,  -9.32514846e-01,
                         -9.27502632e-01,  -9.35336113e-01,  -9.30050910e-01,
                         -9.29888487e-01,  -9.29164290e-01,  -9.25764501e-01,
                         -9.25446332e-01,  -9.42148149e-01,  -9.42561090e-01,
                         -9.27270472e-01,  -9.32654023e-01,  -9.41657603e-01,
                         -9.31040287e-01,  -9.34473872e-01,  -9.36886787e-01,
                         -9.26939249e-01,  -9.54498947e-01,  -9.30258632e-01,
                         -9.20206964e-01,  -9.21557188e-01,  -9.24493909e-01,
                         -9.29804742e-01,  -9.24999237e-01,  -9.31273103e-01,
                         -9.28855896e-01,  -9.44858670e-01,  -9.35117781e-01,
                         -9.37737286e-01,  -9.29096699e-01,  -9.42351043e-01,
                         -9.18521702e-01,  -9.39834952e-01,  -9.15647328e-01,
                         -9.08967912e-01,  -9.29422557e-01,  -9.20112371e-01,
                         -9.13199663e-01,  -9.35903788e-01,  -9.26354170e-01,
                         -9.36670125e-01,  -9.34581101e-01,  -9.27456379e-01,
                         -9.32225347e-01,  -9.29205418e-01,  -9.26509380e-01,
                         -9.32450652e-01,  -9.31550026e-01,  -9.27413344e-01,
                         -9.31486130e-01,  -9.50742185e-01,  -9.42324340e-01,
                         -9.48999524e-01,  -9.43522334e-01,  -9.41138864e-01,
                         -9.53440547e-01,  -9.27480936e-01,  -9.46872711e-01,
                         -9.48875427e-01,  -9.56532717e-01,  -9.34602976e-01,
                         -9.52661455e-01,  -9.40304339e-01,  -9.06372547e-01,
                         -9.36697602e-01,  -9.38067079e-01,  -9.43765104e-01,
                         -9.29541051e-01,  -9.47913229e-01,  -9.29642618e-01,
                         -9.23104882e-01,  -9.56831753e-01,  -9.35101390e-01,
                         -9.44579780e-01,  -9.33053076e-01,  -9.36988592e-01,
                         -9.32390749e-01,  -9.30706382e-01,  -9.39273179e-01,
                         -9.42705452e-01,  -9.47667837e-01,  -9.37759578e-01,
                         -9.35674548e-01,  -9.45421398e-01,  -9.48350728e-01,
                         -9.37157691e-01,  -9.60126221e-01,  -9.43114281e-01,
                         -9.47918475e-01,  -9.35524762e-01,  -9.49477077e-01,
                         -9.52230334e-01,  -9.48640227e-01,  -9.45805550e-01,
                         -9.33530807e-01,  -9.51157033e-01,  -9.53224301e-01,
                         -9.32950497e-01,  -9.51846838e-01,  -9.32371378e-01,
                         -9.37080026e-01,  -9.23330545e-01,  -9.26773489e-01,
                         -9.17905331e-01,  -9.31084871e-01,  -9.42925572e-01,
                         -9.40532744e-01,  -9.25447464e-01,  -9.25300777e-01,
                         -9.37891066e-01,  -9.25240815e-01,  -9.44698453e-01,
                         -9.29877937e-01,  -9.33935404e-01,  -9.42993522e-01,
                         -9.28846955e-01,  -9.40065026e-01,  -9.30725455e-01,
                         -9.28389668e-01,  -9.40288782e-01,  -9.29190874e-01,
                         -9.33874547e-01,  -9.27944243e-01,  -9.34355259e-01,
                         -9.46837306e-01,  -9.10333991e-01,  -9.11588907e-01,
                         -9.40516889e-01,  -9.29527640e-01,  -9.37043250e-01,
                         -9.31997418e-01,  -9.30497587e-01,  -9.21928585e-01,
                         -9.29274678e-01,  -9.50365305e-01,  -9.28179026e-01,
                         -9.40302551e-01,  -9.26263273e-01,  -9.43345249e-01,
                         -9.54947054e-01,  -9.51413870e-01,  -9.42785740e-01,
                         -9.30369616e-01,  -9.45448160e-01,  -9.33425903e-01,
                         -9.33455288e-01,  -9.40621316e-01,  -9.46442902e-01,
                         -9.22314048e-01,  -9.44967091e-01,  -9.20097649e-01,
                         -9.47800577e-01,  -9.29785192e-01,  -9.59308743e-01,
                         -9.50483739e-01,  -9.42004442e-01,  -9.43857253e-01,
                         -9.44290936e-01,  -9.55195665e-01,  -9.37855363e-01,
                         -9.33809578e-01,  -9.36784446e-01,  -9.35874283e-01,
                         -9.55891132e-01,  -9.42377567e-01,  -9.49715078e-01,
                         -9.56280351e-01,  -9.32561517e-01,  -9.33608055e-01,
                         -9.30723906e-01,  -9.27782178e-01,  -9.29025412e-01,
                         -9.05507386e-01,  -9.36739504e-01,  -9.30651367e-01,
                         -9.35508013e-01,  -9.45285559e-01,  -9.38260913e-01,
                         -9.19495463e-01,  -9.36050355e-01,  -9.41819608e-01,
                         -9.20887887e-01,  -9.43699539e-01,  -9.34428334e-01,
                         -9.46137428e-01,  -9.42390740e-01,  -9.41268146e-01,
                         -9.35663342e-01,  -9.55185413e-01,  -9.26781356e-01,
                         -9.42265034e-01,  -9.45360780e-01,  -9.51474488e-01,
                         -9.14918363e-01,  -9.24412847e-01,  -9.32894170e-01,
                         -9.45263922e-01,  -9.46213007e-01,  -9.56736505e-01,
                         -9.21490490e-01,  -9.43137586e-01,  -9.30408299e-01,
                         -9.35421526e-01,  -9.35366392e-01,  -9.39914405e-01,
                         -9.50063705e-01,  -9.39595401e-01,  -9.29222226e-01,
                         -9.40031409e-01,  -9.21662927e-01,  -9.24431205e-01,
                         -9.31700408e-01,  -1.68168452e-02,  -1.85531955e-02,
                         -1.17249694e-03,  -7.74860103e-03,  -1.68469101e-02,
                          2.67632364e-04,  -1.68185364e-02,   2.23385752e-03,
                         -5.03465859e-03,  -3.61780869e-03,   2.29049288e-03,
                          1.33147817e-02,   5.96192246e-03,   1.87358609e-03,
                         -5.65234711e-03,   7.54127686e-04,   2.92477955e-04,
                          8.88217648e-04,  -1.64294895e-02,  -7.74946017e-03,
                         -8.65630712e-03,  -1.02052996e-02,  -6.90729544e-03,
                          1.74471550e-02,  -1.32603087e-02,   1.96969733e-02,
                          8.79224017e-03,   1.43794622e-02,   1.19166647e-03,
                         -3.51906405e-03,   3.67804104e-03,  -6.32157689e-03,
                         -4.94221365e-03,  -1.03470823e-02,  -3.48017737e-03,
                          2.84367288e-03,   1.48101607e-02,   3.84670007e-03,
                         -4.23572585e-03,   1.76331599e-03,  -1.21750310e-03,
                          7.65045919e-03,  -3.42358346e-03,   7.30405562e-03,
                         -1.50279418e-04,   4.31134365e-03,  -8.28227843e-04,
                          2.51999404e-03,  -9.68846260e-04,  -1.86001565e-02,
                         -6.52028597e-04,   8.89903121e-03,  -8.21611378e-03,
                          1.58125777e-02,   6.74449932e-03,   2.87903193e-03,
                         -3.76636931e-03,  -2.38579325e-03,  -3.12507595e-03,
                         -9.30459984e-03,  -5.02122054e-03,  -5.84505440e-04,
                         -1.07086152e-02,   5.41858375e-03,   1.25826092e-03,
                         -3.48295644e-03,  -8.68677348e-03,  -8.40231369e-04,
                         -7.92791881e-03,   2.81814113e-03,  -1.65114005e-03,
                         -1.00399535e-02,  -1.04040429e-02,   7.76914938e-04,
                         -3.39961797e-03,   9.82526908e-05,  -1.64972630e-03,
                          4.81090276e-03,  -2.53039668e-03,  -2.16577295e-03,
                         -6.78052369e-04,   7.34917261e-03,   3.35972640e-03,
                          6.96944713e-04,   3.18569643e-03,  -6.81846775e-03,
                          7.28880172e-04,   4.18455154e-03,   1.21531934e-02,
                          1.69452187e-02,  -8.09855293e-04,   9.29125864e-03,
                          3.18256393e-03,   1.08160293e-02,  -8.82143807e-03,
                          5.72006404e-03,  -2.11128587e-04,   1.03562027e-02,
                         -6.90235384e-03,  -3.74812842e-03,  -2.54405662e-03,
                         -3.24122305e-03,  -1.09143863e-02,  -3.16453795e-03,
                         -2.38879421e-03,   3.94962402e-03,  -6.56859810e-03,
                          8.07681866e-03,  -1.05742412e-02,  -8.05398356e-03,
                         -7.43788900e-03,   1.81580009e-03,   8.96171667e-03,
                          3.12904012e-03,  -3.86821199e-03,   7.15347100e-03,
                          9.39245056e-03,  -6.86860271e-03,   6.12331135e-03,
                         -6.58359565e-03,  -1.19585311e-02,  -5.19359426e-04,
                         -9.45824105e-03,   1.15914200e-03,   9.86310886e-04,
                          6.59431005e-03,   6.96249632e-03,  -6.49337517e-03,
                         -1.02477483e-02,  -3.92936636e-03,  -6.50282158e-03,
                         -6.18264265e-03,   2.04858072e-02,   3.27261793e-03,
                         -2.77938624e-03,  -1.45371293e-03,   7.88551848e-03,
                          7.57940812e-03,  -2.54735537e-03,   3.75693012e-03,
                         -4.37893625e-03,   9.59320366e-03,   1.82819867e-03,
                         -6.84255827e-03,   1.18201936e-03,   2.36469693e-03,
                          9.82859638e-04,   6.45539677e-03,  -4.50786296e-03,
                          1.42537095e-02,   4.72440413e-04,   1.41610429e-02,
                          3.91569229e-05,   1.13838809e-02,   4.22164332e-03,
                          1.49371680e-02,   9.32154525e-03,   8.08569696e-03,
                          1.02642423e-03,   2.16044346e-03,  -1.46585502e-04,
                          7.53911491e-03,   1.61795027e-03,   7.80068990e-03,
                          1.91331818e-03,   7.14254891e-03,  -7.48806540e-03,
                          7.87808932e-03,   1.18191885e-02,   1.94942579e-03,
                          4.22804675e-04,   7.60865491e-03,  -3.15764220e-04,
                          1.23303486e-02,   4.02321806e-03,   4.09590453e-03,
                          6.41441019e-03,  -5.61156822e-03,  -4.92273225e-03,
                          4.77307662e-03,  -1.25143519e-02,  -2.00150092e-03,
                         -1.12802088e-02,  -8.17749067e-04,  -1.13794319e-02,
                         -6.81498880e-03,   1.21123735e-02,  -2.69349036e-03,
                         -1.25495028e-02,  -6.73546921e-03,  -2.16766493e-03,
                         -9.17660911e-03,   1.29241757e-02,   1.94424868e-03,
                          8.60461267e-04,   6.59178756e-03,   1.25300009e-02,
                          1.23396078e-02,   7.04202987e-03,   3.76530224e-05,
                         -1.83917652e-03,   8.93642753e-03,  -2.01621419e-03,
                          1.33051621e-02,  -1.13533530e-02,   1.93567574e-03,
                         -4.47172060e-04,   7.45705143e-03,   1.19056590e-02,
                         -8.19523266e-05,   1.11006899e-02,  -2.75499793e-03,
                          2.51239142e-03,  -1.39941298e-03,  -3.24011431e-04,
                         -8.10229511e-04,  -1.02928374e-02,   9.16622672e-03,
                          1.38518488e-04,  -5.17210981e-04,   2.01251335e-03,
                         -8.07350595e-03,   2.70762155e-03,  -3.39503004e-03,
                          5.73883858e-03,   7.59000471e-03,   3.08916951e-03,
                          1.16623181e-03,   5.39675262e-03,   1.37696532e-03,
                          1.92598708e-03,  -2.32201256e-03,   7.67104235e-03,
                          3.07984115e-03,  -8.10682774e-03,  -2.23079417e-03,
                          3.99980694e-03,   1.35157228e-04,  -9.31463495e-04,
                         -5.33779571e-03,   5.51754329e-03,   7.31985690e-03,
                         -8.61105800e-04,   1.26018072e-03,   3.82498698e-03,
                          1.01024867e-04,   2.10899883e-03,   8.51964578e-04,
                          2.28192704e-03,   2.19396592e-04,  -5.89390704e-03,
                         -3.41180875e-03,  -3.38140479e-03,   1.50948903e-03,
                          7.40120606e-03,  -2.62559298e-03,   7.91217294e-03,
                         -4.83743241e-03,   2.56949128e-03,   4.36729984e-03,
                          4.22776968e-04,   2.45240168e-03,  -1.90870953e-04,
                          3.11829802e-03,   7.47163314e-03,   1.15332042e-03,
                          5.93399955e-03,  -8.44704919e-03,   2.99652340e-03,
                         -5.69190597e-03,   4.58472827e-03,   3.45285074e-03,
                         -1.09136931e-03,  -4.17634583e-04,  -4.32927953e-03,
                          3.86320124e-03,   4.47706413e-03,   4.03219281e-04,
                         -4.51714266e-03,  -6.48734579e-03,  -6.03808789e-03,
                         -2.55492353e-03,  -1.12592932e-02,  -6.10084971e-03,
                         -2.12476566e-03,  -3.34825669e-03,   3.70304612e-03,
                          4.23009135e-03,  -3.47005203e-03,  -9.50988661e-03,
                          3.35754338e-03,  -7.74156651e-04,   1.56673440e-03,
                          7.85009688e-05,   3.21565662e-03,   1.86906045e-03,
                         -2.19138782e-03,   1.64016231e-03,   1.13264692e-03,
                         -1.42111222e-03,   6.14293804e-03,   2.76587182e-03,
                         -2.09982297e-03,  -1.92410883e-03,   1.23733806e-03,
                          3.92497925e-04,   5.59985579e-04,  -2.90655275e-03,
                          1.64057114e-04,  -1.06609403e-03,   1.77689968e-03,
                         -2.14358170e-05,  -2.12071138e-03,   3.29989614e-03,
                          1.54972705e-03,   5.86636551e-03,  -1.34713686e-04,
                          1.35730370e-03,  -2.15715147e-03,  -8.90802708e-04,
                         -1.23012345e-03,   4.56604379e-04,   4.79077687e-03,
                          2.16518389e-03,  -1.75237283e-03,   7.55000947e-05,
                         -6.61599566e-04,   5.37156768e-04,   3.16186954e-04,
                          4.05380875e-03,   1.90297107e-03,   1.64664222e-03,
                          4.97464789e-03,   1.52584480e-03,   3.30797001e-03,
                          1.27766619e-03,  -2.57146632e-04,   3.16747627e-03,
                         -1.69416412e-03,   9.21629253e-04,   3.38848773e-03,
                          1.49681326e-03,  -6.05219137e-03,  -2.59768427e-03,
                          1.66759986e-04,  -1.86845055e-03,  -6.45358069e-03,
                          3.39246588e-03,  -3.34196375e-03,   2.05868389e-04,
                         -5.79765718e-03,   5.89622185e-03,  -1.95650174e-03,
                          8.35347455e-03,  -3.45208822e-03,  -9.24603082e-03,
                          6.75120810e-03,   1.77813321e-03,   1.04546908e-03,
                         -4.76520369e-03,  -3.27014364e-03,  -6.70333952e-03,
                         -4.64380340e-04,  -6.29391056e-03,   3.64939752e-03,
                         -7.01819593e-03,  -5.77145314e-04,   5.79869025e-04,
                         -7.32470816e-03,  -3.10117984e-03,   4.41371318e-04,
                         -7.20709155e-04,  -2.71783001e-03,   5.19017037e-03,
                          1.34588929e-03,   7.28083134e-04,  -7.90942169e-04,
                         -1.47670112e-03,  -8.24707211e-04,   7.26242410e-03,
                         -1.72079087e-03,   4.19830158e-03,  -6.11913204e-03,
                          5.59740933e-03,   1.03237748e-03,   2.11459165e-03,
                          2.71743513e-03,   1.98986483e-04,  -2.11803615e-03,
                          3.17139900e-03,   3.32291191e-03,   4.50215908e-03,
                          2.80195870e-03,   2.27404013e-03,   1.18989230e-03,
                          3.99234297e-04,   3.80067504e-03,  -2.35119648e-03,
                          8.03231914e-03,  -1.16236461e-03,  -1.64318399e-03,
                          3.64105334e-03,  -1.52478449e-03,  -2.93444074e-03,
                         -2.71225115e-03,   5.09739993e-03,  -4.16556187e-03,
                          1.90933316e-03,   3.98469856e-03,  -6.42182585e-03,
                          7.07035419e-04,  -1.95734715e-03,   3.11631593e-03,
                         -5.34359645e-03,   4.56542708e-03,  -1.48241187e-03,
                          3.54884402e-03,   1.16935046e-03,   2.80915247e-03,
                          3.93791823e-03,   3.54487984e-03,   5.45757415e-04,
                          8.77347309e-03,   1.86740409e-03,   2.92285997e-03,
                         -2.30607949e-03,  -9.20187030e-03,   6.72487961e-03,
                         -7.65215699e-03,   8.45413283e-03,  -4.66521829e-04,
                         -1.70457363e-03,   5.28427213e-03,  -9.55442153e-03,
                          2.91571463e-03,  -4.13184566e-03,   8.61743372e-03,
                          4.98548057e-03,   4.69843578e-03,  -7.03452388e-04,
                          8.90787411e-03,  -6.48408150e-03,   3.68718919e-03,
                         -4.90684761e-03,   1.16398640e-03,  -1.18578947e-03,
                         -6.34116260e-03,  -1.76108442e-03,  -2.87920516e-03,
                          6.94892649e-03,  -8.72756541e-03,   9.88308247e-03,
                         -4.98498837e-03,   5.87572856e-03,  -5.37946820e-04,
                         -3.17733153e-03,  -6.63856789e-03,  -2.56966450e-04,
                          2.00228416e-03,  -7.17371469e-03,  -3.82269989e-03,
                         -4.04552696e-03,  -7.57317105e-03,   1.90316510e-04,
                         -2.03578570e-03,   4.54920297e-03,  -2.34532650e-04,
                          9.72372480e-03,   1.55425270e-03,   1.01457322e-02,
                         -4.39389214e-06,   8.54603667e-03,  -2.09174911e-03,
                          8.99440050e-03,  -8.77504610e-03,   1.44526679e-02,
                         -2.42246213e-04,   1.78994960e-03,   7.92044774e-03,
                          3.21158860e-03,   1.50197437e-02,   2.99501955e-03,
                          2.14516185e-03,   1.63015891e-02,  -6.76777214e-04,
                          1.00218998e-02,   1.59275811e-02,  -7.67975394e-03,
                          8.80636461e-03,   9.86672752e-03,  -8.99839972e-04,
                          9.43818409e-03,   9.33370087e-03,  -8.09800532e-03,
                          1.69735085e-02,   1.08534680e-03,  -7.06827501e-04,
                          1.42786931e-03,  -9.37861018e-03,  -2.24593724e-03,
                         -3.92032182e-03,  -3.45039042e-03,   5.55985374e-03,
                         -8.00565723e-03,  -4.80721565e-03,   1.58239435e-02,
                         -4.66109486e-03,   3.04780179e-03,  -5.92648692e-04,
                         -3.78511613e-03,   5.64448815e-03,  -1.33265916e-03,
                          6.46602781e-03,  -9.96870827e-03,   3.11001623e-03,
                          1.29824958e-03,   2.03620153e-03,  -1.07354838e-02,
                          7.93520245e-04,   3.02220765e-03,   2.76764599e-03,
                         -3.52333300e-03,   1.51468134e-02,  -2.39903461e-02,
                          1.56539325e-02,  -3.12465313e-03,  -1.28345238e-02,
                          1.85885199e-03,  -1.82340282e-03,   2.66043236e-03,
                         -9.55234922e-04,   1.44293613e-03,   5.93599584e-03,
                         -7.66874850e-03,  -8.58479831e-03,  -1.00968517e-02,
                          3.62821826e-04,  -4.52943053e-03,  -2.77996832e-03,
                          6.87576877e-03,  -6.14990341e-03,  -3.14797414e-03,
                         -1.30849960e-03,  -7.69844512e-03,   6.68848748e-04,
                          3.38763534e-03,   2.29348685e-03,  -9.18612599e-01,
                         -9.42799509e-01,  -9.33330297e-01,  -9.35123324e-01,
                         -9.46354866e-01,  -9.15726960e-01,  -9.40631092e-01,
                         -9.38874841e-01,  -9.19896424e-01,  -9.36436355e-01,
                         -9.28717375e-01,  -9.27381337e-01,  -1.92633353e-03,
                         -5.87621378e-03,   7.05866283e-03,  -1.60054248e-02,
                          9.82317608e-03,  -1.11849913e-02,   1.39159206e-02,
                         -3.39244507e-05,  -2.57346244e-03,   1.06110554e-02,
                         -1.15636773e-02,  -3.88654298e-03,  -2.79716286e-03,
                          9.01898311e-04,   3.30882240e-03,  -1.17114130e-02,
                         -1.16738921e-03,  -4.65103844e-03,  -2.30309251e-03,
                         -3.99342412e-03,   3.49439867e-03,  -1.29456809e-02,
                          1.35581996e-02,  -1.22666303e-02,   7.41971744e-05,
                         -7.01152906e-03,  -6.66088378e-03,   4.42951452e-03,
                         -1.61643245e-03,  -1.04289511e-02,  -1.47293517e-02,
                          3.61756608e-03,  -3.59043363e-03,  -1.38095934e-02,
                          4.07822477e-03,  -9.70724411e-03,  -3.15293623e-03,
                         -1.49760265e-02,   6.83939783e-03,  -3.81719717e-03,
                         -1.44775966e-02,  -8.88924522e-04,   4.09970246e-03,
                         -3.24662193e-03,   1.82295230e-03,  -2.22870824e-03,
                         -7.51121296e-03,   2.14624368e-02,  -1.35624204e-02,
                          1.15554091e-02,  -3.41026997e-03,  -7.47477962e-03,
                          1.48922652e-02,   1.06276115e-02,   8.13336484e-03,
                          1.27912294e-02,  -1.79886911e-03,   2.73637590e-03,
                          2.79351743e-03,  -6.93573104e-03,   2.01839451e-02,
                          1.89150125e-03,   7.32821506e-03,  -5.32375462e-03,
                         -9.20259118e-01,  -9.32648361e-01,  -9.21086788e-01,
                         -9.34586406e-01,  -9.30176198e-01,  -9.35917199e-01,
                         -9.27391291e-01,  -9.40188110e-01,  -9.06310856e-01,
                         -9.27011192e-01,  -9.17962611e-01,  -9.38032925e-01,
                         -9.22466278e-01,  -9.27470386e-01,  -9.23951089e-01,
                         -9.15690958e-01,  -9.48893726e-01,  -9.16673064e-01,
                         -9.22410607e-01,  -9.30634975e-01,  -9.26773965e-01,
                         -9.32944000e-01,  -9.32055533e-01,  -9.37251508e-01,
                         -9.25512075e-01,  -9.47212219e-01,  -9.19912636e-01,
                         -9.52375114e-01,  -9.39653397e-01,  -9.41889644e-01,
                         -9.34699893e-01,  -9.49790776e-01,  -9.50596750e-01,
                         -9.42875326e-01,  -9.33911324e-01,  -9.24478352e-01,
                         -9.38299835e-01,  -9.64291692e-01,  -9.22254443e-01,
                         -9.40765023e-01,  -9.34049964e-01,  -9.45024848e-01,
                         -9.18925226e-01,  -9.37574387e-01,  -9.40842211e-01,
                         -9.36737418e-01,  -9.26749945e-01,  -9.42524850e-01,
                         -9.09372866e-01,  -9.31127310e-01,  -9.27822709e-01,
                         -9.55583751e-01,  -9.21748996e-01,  -9.26849425e-01,
                         -9.37714338e-01,  -9.28697348e-01,  -9.38644111e-01,
                         -9.33235705e-01,  -9.45811391e-01,  -9.33621168e-01,
                         -9.51509655e-01,  -9.24610913e-01,  -9.26347852e-01,
                         -9.36458290e-01,  -9.30356741e-01,  -9.29195046e-01,
                         -9.32659864e-01,  -9.39028800e-01,  -9.31615114e-01,
                         -9.45446789e-01,  -9.18508947e-01,  -9.45745528e-01,
                         -9.38656867e-01,  -9.42324340e-01,  -9.28702712e-01,
                         -9.29042876e-01,  -9.20341432e-01,  -9.33617711e-01,
                         -9.27155256e-01,  -9.36065555e-01,  -9.24585760e-01,
                         -9.21356976e-01,  -9.35624421e-01,  -9.31972742e-01,
                         -9.08704817e-01,  -9.32428241e-01,  -9.29252207e-01,
                         -9.43635821e-01,  -9.27505314e-01,  -9.22976196e-01,
                         -9.03089285e-01,  -9.28590178e-01,  -9.23716486e-01,
                         -9.44469750e-01,  -9.28487241e-01,  -9.29446697e-01,
                         -9.24360573e-01,  -9.37161982e-01,  -9.40306723e-01,
                         -9.35630560e-01,  -9.28253055e-01,  -9.20686364e-01,
                         -9.26206887e-01,  -9.43167210e-01,  -9.27747011e-01,
                         -9.26166236e-01,  -9.34853673e-01,  -9.43420887e-01,
                         -9.39036071e-01,  -9.35823917e-01,  -9.37802374e-01,
                         -9.48963583e-01,  -9.34565902e-01,  -9.27798569e-01,
                         -9.37420726e-01,  -9.33306575e-01,  -9.32942986e-01,
                         -9.20932055e-01,  -9.09251332e-01,  -9.24108744e-01,
                         -9.28932965e-01,  -9.35731888e-01,  -9.38206792e-01,
                         -9.19359028e-01,  -9.33985293e-01,  -9.35523331e-01,
                         -9.40644085e-01,  -9.30988133e-01,  -9.28761065e-01,
                         -9.39500153e-01,  -9.53171730e-01,  -9.42575276e-01,
                         -9.51062560e-01,  -9.41814363e-01,  -9.31781113e-01,
                         -9.40235674e-01,  -9.26944196e-01,  -9.38772500e-01,
                         -9.33892071e-01,  -9.45230246e-01,  -9.59560812e-01,
                         -9.31963742e-01,  -9.33389544e-01,  -9.47172523e-01,
                         -9.45402563e-01,  -9.39910531e-01,  -9.52891052e-01,
                         -9.56551433e-01,  -9.39181566e-01,  -9.45675135e-01,
                         -9.45123136e-01,  -9.34130907e-01,  -9.29376423e-01,
                         -9.27646160e-01,  -9.39485192e-01,  -9.48279321e-01,
                         -9.44209099e-01,  -9.38801885e-01,  -9.25904036e-01,
                         -9.20306623e-01,  -9.37799811e-01,  -9.36922014e-01,
                         -9.35411513e-01,  -9.22659755e-01,  -9.45329845e-01,
                         -9.50526953e-01,  -9.34111953e-01,  -9.35604393e-01,
                         -9.36864495e-01,  -9.39646661e-01,  -9.53494549e-01,
                         -9.52652812e-01,  -9.39884067e-01,  -9.49550927e-01,
                         -9.55221474e-01,  -9.48624492e-01,  -9.45996821e-01,
                         -9.65154052e-01,  -9.47612405e-01,  -9.46453750e-01,
                         -9.48595524e-01,  -9.55705583e-01,  -9.16922629e-01,
                         -9.53434110e-01,  -9.30528402e-01,  -9.40837920e-01,
                         -9.31533039e-01,  -9.35991168e-01,  -9.33811903e-01,
                         -9.23173726e-01,  -9.42766130e-01,  -9.13472235e-01,
                         -9.33576465e-01,  -9.32535350e-01,  -9.46720660e-01,
                         -9.40700650e-01,  -9.23539877e-01,  -9.35644865e-01,
                         -9.28443730e-01,  -9.23951030e-01,  -9.37224627e-01,
                         -9.21531856e-01,  -9.31845546e-01,  -9.39603269e-01,
                         -9.26235795e-01,  -9.22913015e-01,  -9.16427195e-01,
                         -9.28016424e-01,  -9.34881628e-01,  -9.14562166e-01,
                         -9.28683639e-01,  -9.19838130e-01,  -9.36811149e-01,
                         -9.17033672e-01,  -9.26749587e-01,  -9.21525776e-01,
                         -9.51264143e-01,  -9.48412240e-01,  -9.14057970e-01,
                         -9.31250930e-01,  -9.48819637e-01,  -9.32850599e-01,
                         -9.34096754e-01,  -9.23773825e-01,  -9.30969775e-01,
                         -9.33158994e-01,  -9.35457647e-01,  -9.35959518e-01,
                         -9.26387250e-01,  -9.26157534e-01,  -9.22351718e-01,
                         -9.21382666e-01,  -9.27642584e-01,  -9.09992933e-01,
                         -9.31592345e-01,  -9.26441669e-01,  -9.35245752e-01,
                         -9.35219824e-01,  -9.31298614e-01,  -9.32362795e-01,
                         -9.39525008e-01,  -9.33587253e-01,  -9.33491409e-01,
                         -9.30166900e-01,  -9.26733434e-01,  -9.43654418e-01,
                         -9.23934639e-01,  -9.35200274e-01,  -9.31622565e-01,
                         -9.45873618e-01,  -9.42887664e-01,  -9.23923910e-01,
                         -9.32911575e-01,  -9.43736792e-01,  -9.21770215e-01,
                         -9.38114941e-01,  -9.30362284e-01,  -9.38854218e-01,
                         -9.24055040e-01,  -9.21365499e-01,  -9.23187912e-01,
                         -9.72552419e-01,  -9.45698619e-01,  -9.42677736e-01,
                         -9.40116465e-01,  -9.27656591e-01,  -9.51745510e-01,
                         -9.50560212e-01,  -9.43678498e-01,  -9.25295472e-01,
                         -9.16846693e-01,  -9.12978768e-01,  -9.27960634e-01,
                         -9.09703672e-01,  -9.30929065e-01,  -9.23418105e-01,
                         -9.26869452e-01,  -9.23789501e-01,  -9.29047465e-01,
                         -9.39923286e-01,  -9.31260705e-01,  -9.45028543e-01,
                         -9.18135822e-01,  -9.11397874e-01,  -9.24392402e-01,
                         -9.31207597e-01,  -9.39322650e-01,  -9.68037903e-01,
                         -9.52176332e-01,  -9.52977657e-01,  -9.64028537e-01,
                         -9.60104465e-01,  -9.26765919e-01,  -9.28405046e-01,
                         -9.24540281e-01,  -9.44791019e-01,  -9.53908920e-01,
                         -9.28454936e-01,  -9.48900461e-01,  -9.35929477e-01,
                         -9.23566699e-01,  -9.27660942e-01,  -9.45192635e-01,
                         -9.45546806e-01,  -9.49779928e-01,  -9.66906071e-01,
                         -9.54499066e-01,  -9.52395320e-01,  -9.39709544e-01,
                         -9.51200843e-01,  -9.65170383e-01,  -9.68625605e-01,
                         -9.30897772e-01,  -9.44285512e-01,  -9.45497155e-01,
                         -9.40524340e-01,  -9.38340366e-01,  -9.30444896e-01,
                         -9.40571010e-01,  -9.52999175e-01,  -9.54044998e-01,
                         -9.36311066e-01,  -9.36608016e-01,  -9.29572463e-01,
                         -9.40979064e-01,  -9.21623170e-01,  -9.11767840e-01,
                         -9.23692346e-01,  -9.13118124e-01,  -9.48905468e-01,
                         -9.36310291e-01,  -9.12170589e-01,  -9.14742410e-01,
                         -9.43733513e-01,  -9.45711136e-01,  -9.27365124e-01,
                         -9.39195871e-01,  -9.37585473e-01,  -9.22071815e-01,
                         -9.05470669e-01,  -9.28924322e-01,  -9.36075449e-01,
                         -9.45211411e-01,  -9.51860845e-01,  -9.59973395e-01,
                         -9.69447732e-01,  -9.38489318e-01,  -9.36150074e-01,
                         -9.45758700e-01,  -9.44256306e-01,  -9.48259473e-01,
                         -9.52612102e-01,  -9.40487742e-01,  -9.24377263e-01,
                         -9.54139233e-01,  -9.39357460e-01,  -9.28828120e-01,
                         -9.37691569e-01,  -9.36499774e-01,  -9.35698271e-01,
                         -9.31584954e-01,  -9.69948232e-01,  -9.66994882e-01,
                         -9.17088568e-01,  -2.17250716e-02,  -8.35319795e-03,
                         -8.96672776e-04,   1.47375921e-02,  -3.30157322e-03,
                         -8.31173267e-04,  -2.06618831e-02,  -1.84059106e-02,
                         -1.80892367e-02,  -1.51212607e-02,  -2.06979960e-02,
                         -8.80110450e-03,   3.42302909e-03,  -2.25123204e-02,
                         -1.58453789e-02,  -4.29301290e-03,  -3.40447836e-02,
                         -8.93770345e-03,   4.61622025e-04,   3.07243248e-03,
                          9.27357934e-03,   4.16487595e-03,   1.08263837e-02,
                          2.04607053e-03,   1.68128742e-03,   5.56577230e-03,
                          9.85659426e-04,  -2.73480965e-03,  -1.41814733e-02,
                          9.29685868e-03,   3.90887959e-03,  -1.67674106e-02,
                          6.04604371e-03,  -6.80799596e-03,   5.32325543e-03,
                         -1.96297821e-02,   3.19652190e-03,   2.54499214e-03,
                         -3.78021644e-03,   3.93478572e-03,   1.92848202e-02,
                          1.94959212e-02,  -5.54929161e-03,   1.39924809e-02,
                          2.37302333e-02,   1.06656393e-02,   3.18584894e-03,
                          2.22831387e-02,   1.06267175e-02,   1.03546083e-02,
                          1.26813129e-02,   4.43282723e-03,   1.40228914e-02,
                          6.68874430e-03,   2.84948759e-03,  -5.16815926e-04,
                         -1.02278441e-02,  -1.09929983e-02,  -7.14004692e-03,
                          1.52374767e-02,  -4.73615807e-03,   8.86028353e-03,
                          1.20662302e-02,   1.63376965e-02,  -3.14351101e-03,
                          1.49431836e-03,   9.01281461e-03,   1.17274020e-02,
                          2.27332078e-02,   1.59058273e-02,   1.59067207e-03,
                          3.06052119e-02,   3.47899348e-02,   5.38124936e-03,
                          3.08176782e-03,  -8.02849978e-03,   7.76503980e-03,
                          9.13784653e-03,   6.85736863e-03,   7.89473578e-03,
                          5.80038782e-03,   1.84123486e-03,  -5.40365581e-04,
                          9.17042699e-03,   1.14872551e-03,   2.84766331e-02,
                          1.57160927e-02,  -2.42523427e-04,  -6.23738629e-07,
                          2.00171992e-02,   3.53964744e-03,   1.99204101e-03,
                         -7.10653141e-03,  -3.13394703e-03,  -4.53002658e-03,
                         -1.74070261e-02,  -1.28940772e-02,   4.88717202e-03,
                         -1.52327502e-02,   8.24513147e-04,  -1.12716705e-02,
                         -1.12378644e-02,   4.96364245e-03,   7.70085026e-03,
                          1.18369302e-02,   5.16767439e-04,  -3.78214312e-03,
                         -1.77542698e-02,  -8.74423329e-03,  -1.15333917e-02,
                         -2.93374760e-03,  -2.19493210e-02,  -5.62987151e-03,
                         -4.48807655e-03,  -1.26679856e-02,  -1.28862802e-02,
                          5.00172516e-03,  -1.25196809e-03,  -2.65705641e-02,
                         -8.28179345e-03,  -4.19556396e-03,   2.02243924e-02,
                         -7.25189690e-03,  -1.35158403e-02,  -1.80540178e-02,
                         -1.41412076e-02,  -1.03759402e-02,  -1.45359030e-02,
                         -2.73711747e-03,   1.51230348e-02,   5.18249162e-03,
                         -1.46376071e-02,   9.41102393e-03,   5.27355773e-03,
                         -5.06863871e-04,   5.50197763e-03,  -4.38107061e-04,
                          2.84171151e-03,   1.41225858e-02,   4.23208717e-03,
                          5.73746674e-03,   3.47688682e-02,   2.27770004e-02,
                          1.43108508e-02,  -1.02591002e-02,  -1.66696291e-02,
                         -3.13826464e-03,   8.38721916e-03,   5.89871686e-03,
                         -1.32657280e-02,   1.21130040e-04,  -7.13064242e-03,
                         -1.31661585e-02,   1.13447523e-02,  -3.93470237e-03,
                         -1.85474916e-03,   3.02860443e-03,  -1.84515249e-02,
                          1.33280810e-02,  -2.60864608e-02,  -3.51345725e-03,
                         -1.53741175e-02,   8.42749886e-03,  -2.42888671e-03,
                         -1.45625155e-02,  -1.27186263e-02,   4.14226903e-03,
                          5.63152775e-04,   3.20017636e-02,  -1.33051137e-02,
                         -1.13305449e-02,   2.52160896e-03,   3.74927884e-03,
                          9.61616449e-03,   9.01576784e-03,   1.38616273e-02,
                          2.24155858e-02,   8.52166209e-03,   9.99620836e-03,
                          6.18807599e-03,  -1.54199479e-02,  -1.71827171e-02,
                          6.36706129e-03,   6.09531254e-03,  -9.50269215e-03,
                         -3.27662379e-03,   3.72595806e-03,   7.81909749e-03,
                          1.87364145e-04,  -7.51932152e-03,   7.96144828e-03,
                          1.19349472e-02,  -1.49277626e-02,  -1.32883005e-02,
                          8.38566013e-03,  -1.03553776e-02,   2.60405671e-02,
                         -4.23392374e-03,  -1.21547803e-02,  -4.93513793e-03,
                          7.71040050e-03,  -8.29731021e-03,  -1.76158752e-02,
                         -5.44496765e-03,   1.07718622e-02,  -1.04377875e-02,
                         -4.44263360e-03,   5.98778669e-03,   5.97295584e-03,
                          8.48288648e-03,   8.47490318e-03,  -2.92905583e-03,
                         -7.95361027e-03,  -2.41768081e-02,   5.48023672e-04,
                         -1.77014042e-02,  -1.17257731e-02,   1.27962744e-03,
                          1.18800513e-02,  -3.21873389e-02,   7.25511275e-03,
                         -1.11229229e-03,  -1.90903514e-03,  -1.65646952e-02,
                         -2.11210363e-03,   8.98919627e-03,  -1.40160993e-02,
                         -2.13542804e-02,  -1.18355092e-03,   2.40284903e-03,
                          2.37674490e-02,   3.46726598e-03,   8.34294781e-03,
                         -6.94160769e-03,  -2.60686711e-03,  -1.96200446e-04,
                          6.57818327e-03,  -4.94540855e-03,   7.28079677e-03,
                          2.83978484e-03,  -1.82454493e-02,   5.37857413e-03,
                          1.57741550e-02,  -2.27041002e-02,   6.40709139e-03,
                          3.55528924e-03,   2.26092781e-03,   1.15288375e-03,
                          1.34970937e-02,  -1.09382963e-04,   9.11359023e-03,
                          1.07312845e-02,   9.77535639e-03,  -7.51164928e-03,
                          3.22872750e-03,   6.77979598e-03,  -6.57089241e-03,
                         -1.61805004e-02,  -1.09317119e-03,  -4.52025468e-03,
                         -1.72994733e-02,   1.03582192e-04,  -1.37511566e-02,
                         -3.81089598e-02,  -7.67176986e-01,  -7.89820135e-01,
                         -7.58192599e-01,  -7.51704395e-01,  -7.58103192e-01,
                         -7.71242142e-01,  -7.44432509e-01,  -7.60954499e-01,
                         -7.56795824e-01,  -7.44063973e-01,  -7.70475030e-01,
                         -7.37943232e-01,  -7.45987356e-01,  -7.72010863e-01,
                         -7.59201109e-01,  -7.76195467e-01,  -7.65960276e-01,
                         -7.49578595e-01,  -7.69826412e-01,  -7.54439235e-01,
                         -7.49162495e-01,  -7.51741886e-01,  -7.35895932e-01,
                         -7.38962531e-01,  -7.52806544e-01,  -7.59877503e-01,
                         -7.51991808e-01,  -7.36081660e-01,  -7.41853833e-01,
                         -7.57839322e-01,  -7.57797599e-01,  -7.55555272e-01,
                         -7.48791575e-01,  -7.78923392e-01,  -7.52518296e-01,
                         -7.40030468e-01,  -7.67114997e-01,  -7.56921530e-01,
                         -7.43735611e-01,  -7.53923118e-01,  -7.41998017e-01,
                         -7.57926941e-01,  -7.62634814e-01,  -7.54237115e-01,
                         -7.52163649e-01,  -7.33499229e-01,  -7.65815973e-01,
                         -7.40506828e-01,  -7.48829544e-01,  -7.47059882e-01,
                         -7.40497649e-01,  -7.34458625e-01,  -7.31677771e-01,
                         -7.37784863e-01,  -7.20738471e-01,  -7.59081364e-01,
                         -7.43925214e-01,  -7.53472686e-01,  -7.36385763e-01,
                         -7.47018695e-01,  -7.47828007e-01,  -7.41118252e-01,
                         -7.28042245e-01,  -7.65875638e-01,  -7.50960648e-01,
                         -7.59061575e-01,  -7.46922433e-01,  -7.56075740e-01,
                         -7.72541046e-01,  -7.44212508e-01,  -7.48304367e-01,
                         -7.47763991e-01,  -7.66566992e-01,  -7.53776968e-01,
                         -7.50158131e-01,  -7.71605611e-01,  -7.76568115e-01,
                         -7.58336663e-01,  -7.71855652e-01,  -7.70734429e-01,
                         -9.33364928e-01,  -9.32280660e-01,  -9.34819758e-01,
                         -9.09832299e-01,  -7.41221488e-01,  -7.49186814e-01,
                         -7.51407623e-01,  -7.56945610e-01,  -7.65009463e-01,
                         -7.55597770e-01,  -7.57770300e-01,  -7.43642390e-01,
                         -7.24454463e-01,  -7.68258870e-01,  -7.55545735e-01,
                         -7.49454618e-01,  -7.54232585e-01,  -7.29175508e-01,
                         -7.49639690e-01,  -7.55803406e-01,  -9.39742208e-01,
                         -9.43850696e-01,  -9.38966572e-01,  -9.23371077e-01,
                         -9.39961016e-01,  -9.16110516e-01,  -9.06729400e-01,
                         -9.18727577e-01,  -9.22371268e-01,  -9.07525301e-01,
                         -9.14535522e-01,  -9.44638968e-01,  -7.61852562e-01,
                         -7.72771418e-01,  -7.57370353e-01,  -7.43633807e-01,
                         -7.50872374e-01,  -7.53321946e-01,  -7.71732688e-01,
                         -7.45063484e-01,  -7.43040502e-01,  -7.59115934e-01,
                         -7.56904781e-01,  -7.42673993e-01,  -7.43299365e-01,
                         -7.53724158e-01,  -7.65032291e-01,  -7.90422738e-01,
                         -9.50344443e-01,  -9.38175082e-01,  -9.26683843e-01,
                         -9.23539519e-01,  -9.32450533e-01,  -9.40368652e-01,
                         -9.26432967e-01,  -9.34425414e-01,  -7.60933042e-01,
                         -7.47612238e-01,  -7.53158689e-01,  -7.51865089e-01,
                         -7.54146934e-01,  -7.50242352e-01,  -7.49120533e-01,
                         -7.20890641e-01,  -7.62808383e-01,  -7.56340146e-01,
                         -7.72203803e-01,  -7.79723525e-01,  -7.58544385e-01,
                         -7.66734004e-01,  -7.56242275e-01,  -7.47949660e-01,
                         -9.49200988e-01,  -9.50648844e-01,  -9.23141897e-01,
                         -9.06598926e-01,  -9.12029088e-01,  -9.09844041e-01,
                         -9.20844853e-01,  -9.36822712e-01,  -9.32642698e-01,
                         -9.11786139e-01,  -9.03409839e-01,  -9.23754036e-01,
                         -9.45923626e-01,  -9.63158667e-01,  -9.30225253e-01,
                         -9.42492664e-01,  -7.52690196e-01,  -7.68692136e-01,
                         -7.34745741e-01,  -7.60677755e-01,  -7.50193596e-01,
                         -7.58160651e-01,  -7.93053925e-01,  -8.01005006e-01,
                         -7.77021527e-01,  -7.52043366e-01,  -7.64450431e-01,
                         -7.39517570e-01,  -7.59863317e-01,  -7.68049538e-01,
                         -7.54026294e-01,  -7.74205565e-01,  -7.50736475e-01,
                         -7.35274851e-01,  -7.37310112e-01,  -7.48504460e-01,
                         -7.80633748e-01,  -7.74309754e-01,  -7.63679206e-01,
                         -7.45677769e-01,  -7.27372169e-01,  -7.58223414e-01,
                         -7.74052203e-01,  -7.73039997e-01,  -7.48933017e-01,
                         -7.52677083e-01,  -7.51543999e-01,  -7.69833148e-01,
                         -7.57920563e-01,  -7.65688121e-01,  -7.81033516e-01,
                         -7.65463591e-01,  -7.85751641e-01,  -7.65312850e-01,
                         -7.42255807e-01,  -7.41988361e-01,  -7.73800790e-01,
                         -7.70660937e-01,  -7.61283636e-01,  -7.65588999e-01,
                         -7.67873466e-01,  -7.79209256e-01,  -7.59476364e-01,
                         -7.51826942e-01,  -2.50984319e-02,   3.78230177e-02,
                         -2.76625101e-02,  -3.48083861e-02,  -1.18016265e-02,
                         -2.01043990e-02,  -2.08187383e-02,  -1.73810162e-02,
                         -7.54876852e-01,  -7.48512328e-01,  -7.72363424e-01,
                         -7.32541859e-01,  -7.48632789e-01,  -7.61581063e-01,
                         -7.67159045e-01,  -7.57936656e-01,  -7.67674088e-01,
                         -7.67514348e-01,  -7.67885804e-01,  -7.59632885e-01,
                         -7.79094458e-01,  -7.60057330e-01,  -7.88571656e-01,
                         -7.75681674e-01,  -7.96793818e-01,  -7.81189978e-01,
                         -7.80013919e-01,  -7.80808866e-01,  -7.76048183e-01,
                         -7.69881010e-01,  -7.49175549e-01,  -7.88655341e-01,
                         -7.57875323e-01,  -7.60064065e-01,  -7.52511203e-01,
                         -7.72541225e-01,  -7.79755712e-01,  -7.76386261e-01,
                         -7.45967865e-01,  -7.68732786e-01,  -7.82327771e-01,
                         -7.83305466e-01,  -7.59252131e-01,  -7.64455199e-01,
                         -7.82254517e-01,  -8.00381720e-01,  -7.82483935e-01,
                         -7.90521443e-01,  -7.80260086e-01,  -7.69112289e-01,
                         -7.48465478e-01,  -7.64428079e-01,  -7.58309007e-01,
                         -7.57220447e-01,  -7.93120325e-01,  -8.01163971e-01,
                         -7.62863457e-01,  -7.67763674e-01,  -7.69480407e-01,
                         -7.41891921e-01,  -7.64434516e-01,  -7.76547909e-01,
                         -7.84101009e-01,  -7.38903821e-01,   7.19437422e-03,
                         -2.96573155e-03,  -1.96408704e-02,  -4.06773202e-03,
                         -7.68358290e-01,  -7.90371656e-01,  -7.70711362e-01,
                         -8.03669870e-01,  -7.89188027e-01,  -7.63791561e-01,
                         -7.61834204e-01,  -8.01235735e-01,  -7.77038157e-01,
                         -7.63074994e-01,  -7.63031006e-01,  -7.52820015e-01,
                         -7.71436691e-01,  -7.82479584e-01,  -7.77952015e-01,
                         -7.42467701e-01,  -7.64744103e-01,  -7.53949344e-01,
                         -7.37720907e-01,  -7.77977884e-01,  -7.43547380e-01,
                         -7.66854405e-01,  -7.25884318e-01,  -7.71815062e-01,
                         -7.45692432e-01,  -7.89994478e-01,  -7.57562339e-01,
                         -7.69187093e-01,  -7.63975799e-01,  -7.78385878e-01,
                         -7.54679203e-01,  -7.75575995e-01,  -7.74591684e-01,
                         -7.57965147e-01,  -7.75377572e-01,  -7.67874837e-01,
                         -7.52721548e-01,  -7.70064652e-01,  -7.89036632e-01,
                         -7.67219305e-01,  -2.76073497e-02,  -9.35587101e-03,
                         -1.82415824e-03,   4.23366058e-04,  -1.09825470e-02,
                         -1.63673926e-02,   1.94602497e-02,  -1.22566512e-02,
                         -7.68094480e-01,  -7.41902590e-01,  -7.31981039e-01,
                         -7.78952718e-01,  -7.50380039e-01,  -7.61451185e-01,
                         -7.69377828e-01,  -7.28903472e-01,  -7.19597042e-01,
                         -7.50130296e-01,  -7.51867115e-01,  -7.57215798e-01,
                         -7.54969120e-01,  -7.61250019e-01,  -7.47380435e-01,
                         -7.68460631e-01,  -7.55588353e-01,  -7.66748071e-01,
                         -7.90006161e-01,  -7.47339904e-01,  -7.70367682e-01,
                         -7.58384526e-01,  -7.37149537e-01,  -7.76278615e-01,
                         -7.53044426e-01,  -7.56642938e-01,  -7.77893186e-01,
                         -7.66726077e-01,  -7.83980072e-01,  -7.74572134e-01,
                         -7.56252110e-01,  -7.43286669e-01,  -7.56564438e-01,
                         -7.31077492e-01,  -7.71697521e-01,  -7.50262678e-01,
                         -1.55162392e-02,   6.25027693e-04,  -1.39533998e-02,
                          9.09911934e-03,  -7.78507352e-01,  -7.88726687e-01,
                         -7.24222958e-01,  -7.78661907e-01,  -7.57766843e-01,
                         -7.43708968e-01,  -7.28230715e-01,  -7.33554840e-01,
                         -7.61672437e-01,  -7.41482675e-01,  -7.90538073e-01,
                         -7.39506602e-01,  -7.23093569e-01,  -7.28910387e-01,
                         -7.55593598e-01,  -7.55774975e-01,  -7.78836548e-01,
                         -8.12455356e-01,  -7.79395998e-01,  -7.93900192e-01,
                         -7.90050387e-01,  -7.41893232e-01,  -7.58873940e-01,
                         -7.58798778e-01,  -7.52744615e-01,  -7.48971343e-01,
                         -7.75798261e-01,  -7.50687003e-01,  -7.68134713e-01,
                         -7.60733128e-01,  -7.51115978e-01,  -7.40388155e-01,
                         -7.40715563e-01,  -7.52452433e-01,  -7.35720813e-01,
                         -7.71383345e-01,  -7.33509958e-01,  -7.77806044e-01,
                         -7.74263859e-01,  -7.62245715e-01,  -7.74954140e-01,
                         -7.50448287e-01,  -7.60809958e-01,  -7.47050047e-01,
                         -7.40982890e-01,  -7.71304846e-01,  -7.25181162e-01,
                         -7.63451278e-01,  -7.82556951e-01,  -7.86153495e-01,
                         -7.86970735e-01,  -7.82452762e-01,  -9.57806826e-01,
                         -9.33298945e-01,  -9.70993936e-01,  -9.76768017e-01,
                         -9.43268657e-01,  -9.44408774e-01,  -9.22561824e-01,
                         -9.78259027e-01,  -9.67567742e-01,  -9.47686374e-01,
                         -9.51594055e-01,  -9.49446619e-01,  -7.81713307e-01,
                         -7.81320095e-01,  -7.93125868e-01,  -7.48346150e-01,
                         -7.53954232e-01,  -7.73340762e-01,  -7.58507133e-01,
                         -7.36185431e-01,  -7.58549273e-01,  -7.57031918e-01,
                         -7.70244479e-01,  -7.66594768e-01,  -7.66855299e-01,
                         -7.47173011e-01,  -7.74616003e-01,  -7.75978863e-01,
                         -7.73204386e-01,  -7.51398444e-01,  -7.47110546e-01,
                         -7.62239516e-01,  -7.73851395e-01,  -7.77094841e-01,
                         -7.89064884e-01,  -7.46710956e-01,  -9.30743873e-01,
                         -9.44504619e-01,  -9.47620392e-01,  -9.22388375e-01,
                         -9.57582176e-01,  -9.47920918e-01,  -9.11958456e-01,
                         -9.08629835e-01,  -9.37177837e-01,  -9.51435566e-01,
                         -9.36625421e-01,  -9.36050117e-01,  -7.59471714e-01,
                         -7.37271130e-01,  -7.51009464e-01,  -7.67181039e-01,
                         -9.33298171e-01,  -9.35338914e-01,  -9.42553222e-01,
                         -9.31638956e-01,  -9.47872579e-01,  -9.43231821e-01,
                         -9.30099845e-01,  -9.34781134e-01,  -9.52800512e-01,
                         -9.45562243e-01,  -9.41513777e-01,  -9.17689443e-01,
                         -9.19295251e-01,  -9.00969923e-01,  -9.16220844e-01,
                         -9.43881512e-01,  -9.38690603e-01,  -9.37880099e-01,
                         -9.41538692e-01,  -9.10674095e-01,  -9.61965084e-01,
                         -9.13586676e-01,  -9.29675162e-01,  -9.34184492e-01,
                         -7.82128394e-01,  -7.58817136e-01,  -7.41695046e-01,
                         -7.47514963e-01,  -7.50773609e-01,  -7.70075202e-01,
                         -7.48701036e-01,  -7.56744027e-01,  -7.86211133e-01,
                         -7.65909553e-01,  -7.67796516e-01,  -7.57102311e-01,
                         -7.65307426e-01,  -7.75835335e-01,  -8.11954677e-01,
                         -7.57777214e-01,  -7.59059191e-01,  -7.79348493e-01,
                         -7.75760889e-01,  -7.56241739e-01,  -9.11070585e-01,
                         -9.04864669e-01,  -9.07509625e-01,  -9.09133136e-01,
                         -9.72661853e-01,  -9.31228340e-01,  -9.05344486e-01,
                         -9.48944092e-01,  -9.16663647e-01,  -9.28615451e-01,
                         -9.62525606e-01,  -9.20668364e-01,  -9.34321761e-01,
                         -9.22038019e-01,  -9.49553072e-01,  -9.47521508e-01,
                         -7.59021759e-01,  -7.62349963e-01,  -7.66144872e-01,
                         -7.40657806e-01,  -7.94601738e-01,  -7.79065967e-01,
                         -7.95385480e-01,  -7.84977376e-01,  -9.85983107e-03,
                          1.27236992e-02,  -9.86086391e-03,   1.53092621e-02,
                         -1.01696076e-02,   4.10066568e-04,  -4.42157220e-03,
                         -1.98155940e-02,  -1.46601722e-02,   1.90503639e-03,
                          2.46403087e-03,   1.74979065e-02,  -7.74258792e-01,
                         -7.55225360e-01,  -7.87130177e-01,  -7.76336372e-01,
                         -1.14900349e-02,   6.08687103e-03,  -1.98528450e-02,
                          1.46410232e-02,   1.15450202e-02,   3.08696553e-03,
                          1.52360704e-02,  -1.35565223e-02,   1.74458385e-01,
                          1.44703031e-01,   1.64955139e-01,   1.70124292e-01,
                          3.45924054e-03,   4.59754542e-02,   4.19655489e-03,
                          3.20918933e-02,   1.79176733e-01,   1.98334739e-01,
                          1.86332867e-01,   1.88427165e-01,  -9.18193161e-03,
                          1.73869077e-02,  -6.81282673e-03,   9.65741405e-04,
                          2.45195115e-03,  -2.56066676e-02,   3.22212977e-03,
                          1.51898926e-02,   2.62541212e-02,   2.70505324e-02,
                          3.91479861e-03,  -2.90351436e-02,   2.02229202e-01,
                          1.78322539e-01,   1.72424078e-01,   1.63368374e-01,
                          2.05769628e-01,   1.88386112e-01,   1.90884426e-01,
                          1.85444072e-01,   1.97330773e-01,   2.06375539e-01,
                          2.12802038e-01,   1.90217599e-01,   1.73427269e-01,
                          1.76959783e-01,   1.44422963e-01,   1.57909527e-01,
                          1.60001680e-01,   1.96164235e-01,   1.85186565e-01,
                          1.87248990e-01,   2.00315878e-01,   1.95644051e-01,
                          1.76941857e-01,   1.85125172e-01,   1.80329680e-01,
                          2.01839969e-01,   1.82127401e-01,   1.67131513e-01,
                          1.72069758e-01,   1.54408872e-01,   1.61544695e-01,
                          1.68627292e-01,   1.79463789e-01,   1.59298882e-01,
                          1.45498902e-01,   1.60777390e-01,   1.76794082e-01,
                          1.97132304e-01,   2.09602371e-01,   1.93699032e-01,
                          1.66793644e-01,   1.87575355e-01,   1.69354841e-01,
                          1.62353769e-01,   1.62459895e-01,   1.46785975e-01,
                          1.62030309e-01,   1.77424133e-01,   1.56458676e-01,
                          1.75404996e-01,   1.52541742e-01,   1.86724916e-01,
                          1.89933509e-01,   1.95843503e-01,   2.05582216e-01,
                          1.74903393e-01,   1.78065762e-01,   1.71250790e-01,
                          1.75438121e-01,   1.69811949e-01,  -2.73663439e-02,
                         -1.25450334e-02,  -7.42332125e-03,  -9.37250443e-04,
                         -4.64359531e-04,   1.40699488e-03,   3.38015729e-03,
                         -3.48510483e-04,   9.53661685e-04,   8.89396481e-03,
                         -7.28250155e-03,   9.22445673e-03,  -9.02287103e-03,
                          1.00231748e-02,   3.34489532e-03,   1.57458037e-02,
                          2.57799421e-02,   2.15531904e-02,   4.67173988e-03,
                         -8.64289608e-03,   1.53827831e-01,   1.87774360e-01,
                          1.69607699e-01,   1.74489394e-01,   1.61948547e-01,
                          1.63091391e-01,   1.75825760e-01,   1.59224585e-01,
                          1.61273167e-01,   1.65651917e-01,   1.91059470e-01,
                          1.66852772e-01,   4.21481673e-03,  -1.53846303e-02,
                         -3.15729342e-02,  -1.31706633e-02,   7.36827962e-03,
                          2.67068315e-02,   1.80887878e-02,   1.43639240e-02,
                          1.09665724e-03,  -5.81186451e-03,   1.80166140e-02,
                         -1.34163266e-02,  -2.13160384e-02,  -2.28015073e-02,
                          9.21983365e-03,   2.22552437e-02,  -1.27966912e-03,
                         -9.78702679e-03,  -1.19178500e-02,  -4.87524085e-02,
                         -2.50801351e-02,  -1.54836038e-02,  -3.00443936e-02,
                          1.55311190e-02,  -2.11259583e-03,  -9.61375248e-04,
                         -2.26175250e-03,   2.43632309e-03,   6.87529752e-03,
                          5.46482345e-03,  -5.64477220e-03,   1.57501698e-02,
                          2.24250667e-02,   2.76192296e-02,   3.53151672e-02,
                          4.87709558e-03,  -1.43712498e-02,  -5.45753958e-03,
                         -1.02722477e-02,  -2.81378739e-02,  -6.68330397e-03,
                          3.04949959e-03,   1.68593768e-02,   2.48642527e-02,
                          5.31132147e-03,  -2.24577785e-02,  -7.08009861e-03,
                         -2.16105822e-02,  -1.03232553e-02,  -2.30677263e-03,
                         -1.88724592e-03,  -1.09860469e-02,  -1.36075299e-02,
                         -1.50573831e-02,  -1.31353186e-02,  -1.39595680e-02,
                         -5.62621932e-03,   5.09374775e-03,   4.43069264e-04,
                         -2.80204881e-03,  -6.18671067e-03,  -5.01978584e-03,
                          1.94928497e-02,   5.17476443e-03,   1.31909763e-02,
                          4.97344229e-03,   1.01905102e-02,   2.77084787e-03,
                          3.66063882e-03,  -3.03590223e-02,   3.14376038e-03,
                          9.73018352e-04,  -3.73873785e-02,  -1.02082519e-02,
                         -1.02848606e-02,  -6.95375679e-03,   5.50865137e-04,
                          2.19311356e-03,  -2.81181578e-02,  -7.22251879e-03,
                         -2.09006146e-02,   1.54789747e-03,  -2.86232326e-02,
                         -3.22062522e-02,   3.93976178e-03,   1.39139937e-02,
                         -8.82680237e-04,  -9.10956413e-04,  -1.68281347e-02,
                         -1.05561940e-02,   6.82051247e-03,  -6.06679358e-03,
                         -5.46625815e-03,   3.64153157e-03,   5.35464333e-03,
                         -3.37663665e-03,  -5.09164762e-04,  -3.39709409e-02,
                         -1.50991173e-03,  -7.88184535e-03,  -9.31476295e-01,
                         -9.37765658e-01,  -9.54922080e-01,  -9.03972745e-01,
                         -9.17711139e-01,  -9.35230792e-01,  -9.63972986e-01,
                         -9.29374099e-01,  -9.34943736e-01,  -9.32639480e-01,
                         -9.33348060e-01,  -9.12496984e-01,   9.18380264e-03,
                          2.63699982e-02,   2.31270846e-02,  -3.03005276e-04,
                          4.14723111e-03,   1.75684988e-02,  -1.04503939e-03,
                          4.38608136e-03,  -2.68546920e-02,  -1.27435690e-02,
                          9.22610611e-03,  -5.00327768e-03,  -9.28776205e-01,
                         -9.30606008e-01,  -9.17438328e-01,  -9.28492010e-01,
                         -9.52136040e-01,  -9.66716886e-01,  -9.39543426e-01,
                         -9.41484392e-01,  -9.29486930e-01,  -9.39901471e-01,
                         -9.52076077e-01,  -9.67956185e-01,  -9.56904054e-01,
                         -9.59353328e-01,  -9.29480314e-01,  -9.26734626e-01,
                         -9.20908511e-01,  -9.29880381e-01,  -9.44582522e-01,
                         -9.33289528e-01,  -9.46012676e-01,  -9.16901529e-01,
                         -9.33580041e-01,  -9.44864750e-01,  -9.69333827e-01,
                         -9.51015532e-01,  -9.45656717e-01,  -9.46481287e-01,
                         -9.54313874e-01,  -9.12738502e-01,  -9.43220317e-01,
                         -9.39038634e-01,  -9.23324406e-01,  -9.35845912e-01,
                         -9.20768738e-01,  -9.26407814e-01,  -9.35795069e-01,
                         -9.37577248e-01,  -9.32466745e-01,  -9.03688014e-01,
                         -9.37107205e-01,  -9.38696802e-01,  -9.21183527e-01,
                         -9.58092332e-01,  -9.61387694e-01,  -9.66573298e-01,
                         -9.43661392e-01,  -9.62483346e-01,  -9.63852465e-01,
                         -9.52135742e-01,  -9.47410047e-01,  -9.29507077e-01,
                         -9.26660001e-01,  -9.48472023e-01,  -9.45185781e-01,
                         -9.26120579e-01,  -9.17300940e-01,  -9.31601107e-01,
                         -8.93712580e-01,  -9.47446644e-01,  -9.49751854e-01,
                         -9.54216063e-01,  -9.23263371e-01,  -9.10291016e-01,
                         -9.03538764e-01,  -9.37449634e-01,  -9.23858285e-01,
                         -9.11042213e-01,  -9.24291193e-01,  -9.25762057e-01,
                         -9.37716544e-01,  -9.36094284e-01,  -9.30271924e-01,
                         -9.09610927e-01,  -9.03782725e-01,  -9.15717304e-01,
                         -9.18624341e-01,  -9.07013655e-01,  -9.30693865e-01,
                         -9.40888882e-01,  -9.48261678e-01,  -9.21713471e-01,
                         -9.13290381e-01,  -9.22551215e-01,  -9.47046995e-01,
                         -9.24100637e-01,  -9.38416898e-01,  -9.63672817e-01,
                         -9.18334961e-01,  -9.28184330e-01,  -9.27915633e-01,
                         -9.41185296e-01,  -9.35924590e-01,  -9.52402413e-01,
                         -9.48405027e-01,  -9.18800890e-01,  -9.26986694e-01,
                         -9.37208772e-01,  -9.62271094e-01,  -9.17044640e-01,
                         -9.89091754e-01,  -9.15152669e-01,  -9.17096794e-01,
                         -9.23180163e-01,  -9.48595524e-01,  -9.40536499e-01,
                         -9.37329352e-01,  -9.28297162e-01,  -9.19708490e-01,
                         -9.37678039e-01,  -9.34050620e-01,  -9.42621171e-01,
                         -8.97678792e-01,  -9.04277861e-01,  -9.26953852e-01,
                         -9.29473758e-01,  -9.44312513e-01,  -9.20568705e-01,
                         -9.33894038e-01,  -9.37658548e-01,  -9.29973960e-01,
                         -9.31322038e-01,  -9.18724835e-01,  -9.13690269e-01,
                         -9.39549387e-01,  -9.17885900e-01,  -9.40508902e-01,
                         -9.10269260e-01,  -8.95659149e-01,  -9.13579226e-01,
                         -9.02518570e-01,  -9.27215636e-01,  -9.09672916e-01,
                         -9.25964832e-01,  -9.41672742e-01,  -9.18648720e-01,
                         -9.44294810e-01,  -9.26600039e-01,  -9.53450859e-01,
                         -9.33563828e-01,  -9.14644420e-01,  -9.07607317e-01,
                         -9.35682654e-01,  -9.27517593e-01,  -9.24049079e-01,
                         -9.18519557e-01,  -9.23432231e-01,  -9.32166994e-01,
                         -9.06225979e-01,  -9.49486971e-01,  -9.44786787e-01,
                         -9.43961024e-01,  -9.12149012e-01,  -9.15343285e-01,
                         -9.27563369e-01,  -9.35563684e-01,  -8.96789551e-01,
                         -9.30213690e-01,  -9.16068077e-01,  -9.49096978e-01,
                         -9.47903931e-01,  -9.57192361e-01,  -9.35468197e-01,
                         -9.57369804e-01,  -9.25251782e-01,  -9.48063970e-01,
                         -9.29345548e-01,  -9.52964842e-01,  -9.34182703e-01,
                         -9.43743229e-01,  -9.38892365e-01,  -9.49367762e-01,
                         -9.19094205e-01,  -9.34915006e-01,  -9.34978843e-01,
                         -9.22257006e-01,  -9.19950485e-01,  -9.47970688e-01,
                         -9.45170164e-01,  -9.09266591e-01,  -9.29058850e-01,
                         -9.46429253e-01,  -9.30609822e-01,  -9.22520757e-01,
                         -9.26116288e-01,  -9.38276649e-01,  -9.41969275e-01,
                         -9.25748229e-01,  -9.41163480e-01,  -9.44483638e-01,
                         -9.57045317e-01,  -9.54251349e-01,  -9.55704629e-01,
                         -9.34875727e-01,  -9.71699834e-01,  -9.55479622e-01,
                         -9.61056232e-01,  -9.36358154e-01,  -9.33803439e-01,
                         -9.28376496e-01,  -9.08750713e-01,  -9.40063119e-01,
                         -9.37084615e-01,  -9.31891561e-01,  -9.46286082e-01,
                         -9.55253541e-01,  -9.42733705e-01,  -9.53424573e-01,
                         -9.63646770e-01,  -9.50299978e-01,  -9.52766418e-01,
                         -9.21804726e-01,  -9.21318769e-01,  -9.30800200e-01,
                         -9.17783678e-01,  -9.09667015e-01,  -9.46839094e-01,
                         -9.32903290e-01,  -9.52213228e-01,  -9.26092863e-01,
                         -9.63462055e-01,  -9.10727382e-01,  -9.32385325e-01,
                         -9.45153594e-01,  -9.35683310e-01,  -9.18504357e-01,
                         -9.28131580e-01,  -9.30767596e-01,  -9.27763045e-01,
                         -9.31268275e-01,  -9.25222576e-01,  -9.39412653e-01,
                         -9.40977752e-01,  -9.12605464e-01,  -9.26667213e-01,
                         -9.30450678e-01,  -9.10916567e-01,  -9.37302291e-01,
                         -9.45462763e-01,  -9.41754162e-01,  -9.01318908e-01,
                         -9.46665227e-01,  -9.42424119e-01,  -9.62849617e-01,
                         -9.45118129e-01,  -9.38243568e-01,  -9.61790502e-01,
                         -9.49435651e-01,  -9.53197896e-01,  -9.22629118e-01,
                         -9.56742823e-01,  -9.51081157e-01,  -1.34433554e-02,
                         -2.38407664e-02,  -3.96789089e-02,  -2.51371302e-02,
                         -4.03997581e-03,   1.09312413e-02,   1.34161878e-02,
                          1.01246219e-02,   1.76223554e-02,  -8.13418254e-03,
                          8.78670253e-03,  -1.30190812e-02,  -1.72374882e-02,
                          1.94624462e-03,   2.95472611e-03,  -1.73724294e-02,
                          2.32115388e-02,   6.62450586e-03,   2.27406784e-03,
                         -1.13716489e-02,  -1.62834935e-02,  -1.76367145e-02,
                         -2.48577446e-02,  -3.17950472e-02,   1.68428826e-03,
                         -1.75306585e-03,  -9.39867366e-03,  -2.58741193e-02,
                         -4.43238346e-03,  -2.64336057e-02,  -1.69914018e-03,
                          1.85079817e-02,  -2.19097473e-02,  -2.59884167e-04,
                          1.68318283e-02,  -2.10273303e-02,  -3.42898369e-02,
                          8.38440564e-03,  -1.14926193e-02,   3.26222703e-02,
                          7.48155778e-03,   9.86664370e-03,   2.90329251e-02,
                         -2.24384144e-02,   7.42531009e-03,  -4.06537578e-03,
                          1.43559538e-02,  -1.50591298e-03,  -9.25018549e-01,
                         -9.35686231e-01,  -9.30963755e-01,  -9.30890322e-01,
                         -9.45553720e-01,  -9.42776620e-01,  -9.46731746e-01,
                         -9.52582717e-01,  -9.44923639e-01,  -9.56332684e-01,
                         -9.30110037e-01,  -8.96768749e-01,  -9.22985971e-01,
                         -9.17405903e-01,  -9.33660746e-01,  -9.13853049e-01,
                         -9.24090266e-01,  -9.46126640e-01,  -9.44456339e-01,
                         -9.12093818e-01,  -9.13563311e-01,  -9.34569776e-01,
                         -9.35938835e-01,  -9.47189748e-01,  -9.26749706e-01,
                         -9.20591593e-01,  -9.34978187e-01,  -9.38979745e-01,
                         -9.29533005e-01,  -9.29716349e-01,  -9.47795391e-01,
                         -9.54247892e-01,  -9.46578205e-01,  -9.35772598e-01,
                         -9.25251842e-01,  -8.99214864e-01,  -9.18892145e-01,
                         -9.32077944e-01,  -9.43827748e-01,  -9.27877247e-01,
                         -9.03363287e-01,  -9.35655296e-01,  -9.24703360e-01,
                         -9.46336687e-01,  -9.56893444e-01,  -9.54669178e-01,
                         -9.36042726e-01,  -9.39965308e-01,  -9.36733425e-01,
                         -9.30181146e-01,  -9.18347776e-01,  -9.14875805e-01,
                         -9.29653704e-01,  -9.54650164e-01,  -9.29927945e-01,
                         -9.09609199e-01,  -9.27286506e-01,  -9.10479188e-01,
                         -9.09142911e-01,  -9.30611253e-01,  -9.25638378e-01,
                         -9.36731756e-01,  -9.13687706e-01,  -9.33127284e-01,
                         -9.59917307e-01,  -9.30007637e-01,  -9.13363934e-01,
                         -9.45696175e-01,  -9.13991511e-01,  -9.39441502e-01,
                         -9.28926766e-01,  -9.28813934e-01,  -9.34644639e-01,
                         -9.44383860e-01,  -9.34706271e-01,  -9.39316750e-01,
                         -9.37085629e-01,  -9.41695154e-01,  -9.25613940e-01,
                         -8.98370504e-01,  -9.46645379e-01,  -9.38247919e-01,
                         -9.20502186e-01,  -9.53757107e-01,  -9.47168291e-01,
                         -9.20556307e-01,  -9.39681590e-01,  -9.29150820e-01,
                         -9.31889892e-01,  -9.39004600e-01,  -9.30479288e-01,
                         -9.36208248e-01,  -9.30216372e-01,  -9.42055881e-01,
                         -9.16507781e-01,  -9.16407883e-01,  -9.26396251e-01,
                         -9.21486676e-01,  -9.14027810e-01,  -9.12788689e-01,
                         -9.11467612e-01,  -9.18756127e-01,  -9.10303354e-01,
                         -9.44446504e-01,  -9.16565657e-01,  -9.30590391e-01,
                         -9.84520674e-01,  -9.30477500e-01,  -9.30802286e-01,
                         -9.21455622e-01,  -9.19101536e-01,  -9.34916675e-01,
                         -9.14320886e-01,  -9.38000202e-01,  -9.46015418e-01,
                         -9.07716453e-01,  -9.22961533e-01,  -9.19063926e-01,
                         -9.38655317e-01,  -9.44204092e-01,  -9.60377812e-01,
                         -9.66444910e-01,  -9.51203942e-01,  -9.42586482e-01,
                         -9.38276649e-01,  -9.31509197e-01,  -9.43268776e-01,
                         -9.11531448e-01,  -8.95405412e-01,  -9.25660610e-01,
                         -9.24080133e-01,  -9.29578006e-01,  -9.30484831e-01,
                         -9.39041734e-01,  -9.32571828e-01,  -9.26438808e-01,
                         -9.12736177e-01,  -9.21403110e-01,  -9.13801134e-01,
                         -8.99985850e-01,  -9.09912705e-01,  -9.14953411e-01,
                         -9.11286771e-01,  -9.34317410e-01,  -9.13625360e-01,
                         -9.34153736e-01,  -9.20704424e-01,  -9.16551948e-01,
                         -8.94599736e-01,  -9.22025144e-01,  -9.09759998e-01,
                         -9.19343472e-01,  -9.29127276e-01,  -9.02293265e-01,
                         -9.18394446e-01,  -9.23268557e-01,  -9.32441771e-01,
                         -9.32439983e-01,  -9.43346024e-01,  -9.26442266e-01,
                         -9.09295559e-01,  -9.24084425e-01,  -9.16630507e-01,
                         -9.14061785e-01,  -9.48634267e-01,  -9.24833000e-01,
                         -9.24344122e-01,  -9.20061171e-01,  -9.23308015e-01,
                         -9.31556880e-01,  -9.25918400e-01,  -9.17738855e-01,
                         -9.22278762e-01,  -9.19348419e-01,  -9.19710934e-01,
                         -9.41106379e-01,  -9.28997457e-01,  -9.26189661e-01,
                         -9.26527262e-01,  -9.29262280e-01,  -9.26278591e-01,
                         -9.25458789e-01,  -9.26426172e-01,  -9.26343560e-01,
                         -9.26662385e-01,  -9.22867715e-01,  -9.23241436e-01,
                         -9.26308930e-01,  -9.35913086e-01,  -9.18995380e-01,
                         -9.12499785e-01,  -9.10663784e-01,  -9.09563780e-01,
                         -9.28250492e-01,  -9.24685180e-01,  -9.25861299e-01,
                         -9.14826155e-01,  -9.28608358e-01,  -9.30442154e-01,
                         -9.44576323e-01,  -9.16705132e-01,  -9.10727262e-01,
                         -9.28604186e-01,  -9.28480625e-01,  -9.36717033e-01,
                         -9.46177542e-01,  -9.29734468e-01,  -9.26351905e-01,
                         -9.19586122e-01,  -9.18441594e-01,  -9.13501978e-01,
                         -9.27679121e-01,  -9.24894214e-01,  -9.35531974e-01,
                         -9.25412357e-01,  -9.13651884e-01,  -9.42535460e-01,
                         -9.32037055e-01,  -9.38588917e-01,  -9.28248882e-01,
                         -9.35775161e-01,  -9.27176178e-01,  -9.13898945e-01,
                         -9.24660206e-01,  -9.30026293e-01,  -9.44755077e-01,
                         -9.41659331e-01,  -9.42084372e-01,  -9.46031511e-01,
                         -9.45838034e-01,  -9.35624897e-01,  -9.26218271e-01,
                         -9.25486267e-01,  -9.40730810e-01,  -9.25489604e-01,
                         -9.33041990e-01,  -9.37860250e-01,  -9.47663307e-01,
                         -9.48449194e-01,  -9.30247545e-01,  -9.35051024e-01,
                         -9.44364905e-01,  -9.41173553e-01,  -9.30366158e-01,
                         -9.19916391e-01,  -9.25287008e-01,  -9.26531851e-01,
                         -9.28157210e-01,  -9.27368999e-01,  -9.31046247e-01,
                         -9.35674787e-01,  -9.24886942e-01,  -9.31516528e-01,
                         -9.32565391e-01,  -9.30793464e-01,  -9.28078830e-01,
                         -9.31175530e-01,  -9.29432034e-01,  -9.30619001e-01,
                         -9.20662820e-01,  -9.29392517e-01,  -9.22569752e-01,
                         -9.20786202e-01,  -9.24661338e-01,  -9.25584257e-01,
                         -9.28417444e-01,  -9.23820615e-01,  -9.26765263e-01,
                         -9.28173482e-01,  -9.31219101e-01,  -9.30214405e-01,
                         -9.34174180e-01,  -9.31728542e-01,  -9.34336245e-01,
                         -9.29640234e-01,  -9.30497587e-01,  -9.24022317e-01,
                         -9.29695070e-01,  -9.35202301e-01,  -9.21466649e-01,
                         -9.46960509e-01,  -9.36748624e-01,  -9.36390460e-01,
                         -9.28791344e-01,  -9.32467937e-01,  -9.35420513e-01,
                         -9.34862971e-01,  -9.29899335e-01,  -9.26293314e-01,
                         -9.26427841e-01,  -9.30322826e-01,  -9.35270071e-01,
                         -9.35373962e-01,  -9.32264149e-01,  -9.36230540e-01,
                         -9.41363633e-01,  -9.39775586e-01,  -9.34244215e-01,
                         -9.30114686e-01,  -9.24414933e-01,  -9.28694785e-01,
                         -9.33974802e-01,  -9.24786568e-01,  -9.27912474e-01,
                         -9.42162573e-01,  -9.38869238e-01,  -9.28520143e-01,
                         -9.24182296e-01,  -9.31590259e-01,  -9.37766194e-01,
                         -9.31509316e-01,  -9.26897049e-01,  -9.19828415e-01,
                         -9.23867822e-01,  -9.30883944e-01,  -9.38065171e-01,
                         -9.34591293e-01,  -9.20294046e-01,  -9.16374743e-01,
                         -9.34111595e-01,  -9.11925793e-01,  -9.22709346e-01,
                         -9.19890344e-01,  -9.22819078e-01,  -9.29420412e-01,
                         -9.37433541e-01,  -9.35770810e-01,  -9.33323979e-01,
                         -9.35928047e-01,  -9.35535610e-01,  -9.36142862e-01,
                         -9.36105609e-01,  -9.33808208e-01,  -9.31813955e-01,
                         -9.29297805e-01,  -9.26053166e-01,  -9.18559790e-01,
                         -9.27826464e-01,  -9.27536547e-01,  -9.31198418e-01,
                         -9.35301125e-01,  -9.21771407e-01,  -9.34231162e-01,
                         -9.29575205e-01,  -9.37682807e-01,  -9.20170724e-01,
                         -9.31520879e-01,  -9.27760541e-01,  -9.23859596e-01,
                         -9.22111928e-01,  -9.33351278e-01,  -9.35939252e-01,
                         -9.34246123e-01,  -9.25861537e-01,  -9.31803286e-01,
                         -9.37924147e-01,  -9.31816936e-01,  -9.22772825e-01,
                         -9.26244199e-01,  -9.35671151e-01,  -9.24221814e-01,
                         -9.20396328e-01,  -9.26222026e-01,  -9.18986082e-01,
                         -9.22259152e-01,  -9.32638586e-01,  -9.26687717e-01,
                         -9.29805517e-01,  -9.28544343e-01,  -9.20151770e-01,
                         -9.31137741e-01,  -9.37846065e-01,  -9.37643230e-01,
                         -9.26283002e-01,  -9.30436492e-01,  -9.31278765e-01,
                         -9.31012869e-01,  -9.34757650e-01,  -9.40625906e-01,
                         -9.36488390e-01,  -9.25647855e-01,  -9.18623030e-01,
                         -9.24823999e-01,  -9.18456674e-01,  -9.32068288e-01,
                         -9.32648599e-01,  -9.15005088e-01,  -9.43223417e-01,
                         -9.35480416e-01,  -9.29753482e-01,  -9.29012656e-01,
                         -9.21683967e-01,  -9.21270549e-01,  -9.24618423e-01,
                         -9.39570010e-01,  -9.41608131e-01,  -9.35409963e-01,
                         -9.28105772e-01,  -9.28623021e-01,  -9.36433792e-01,
                         -9.30043399e-01,  -9.23116803e-01,  -9.31267798e-01,
                         -9.25795197e-01,  -9.22167778e-01,  -9.34557915e-01,
                         -9.33128357e-01,  -9.28288817e-01,  -9.27232087e-01,
                         -9.27652895e-01,  -9.23820972e-01,  -9.32847500e-01,
                         -9.35908973e-01,  -9.19251442e-01,  -9.28880572e-01,
                         -9.32183087e-01,  -9.33501065e-01,  -9.33283389e-01,
                         -9.30976629e-01,  -9.29301620e-01,  -9.35212731e-01,
                         -9.43721414e-01,  -9.36811030e-01,  -9.26938474e-01,
                         -9.32185054e-01,  -9.25294399e-01,  -9.24877048e-01,
                         -9.19384062e-01,   4.15917905e-03,   1.54468173e-03,
                          1.67610832e-02,   1.05201211e-02,   2.87262117e-03,
                          6.71259873e-03,   1.50940591e-03,  -1.00509170e-02,
                         -7.56990677e-03,   1.81828125e-03,   8.57917825e-04,
                         -2.44215154e-03,  -1.16627822e-02,  -7.07567018e-03,
                         -1.61913538e-03,   2.31154752e-03,   2.91930465e-03,
                         -5.23445616e-03,  -2.48462806e-04,  -1.36358966e-03,
                         -1.10993593e-03,  -1.31027726e-02,   4.08431655e-03,
                         -2.21723830e-03,  -2.66350253e-04,  -3.57240741e-03,
                         -8.76311865e-03,  -2.86032679e-03,   6.61338260e-03,
                          4.86017112e-03,  -7.71499518e-03,  -1.48595469e-02,
                          3.44090257e-03,  -3.26814083e-03,  -4.14161757e-03,
                         -5.25974529e-03,  -2.68935313e-04,   1.49442786e-02,
                         -6.12317957e-03,   1.23144854e-02,   1.02232629e-02,
                          2.39887787e-03,   2.32053641e-03,  -2.65233056e-03,
                         -2.52817897e-03,   3.27143283e-03,  -7.53817894e-03,
                          2.40975176e-03,   3.56346718e-03,   4.57581598e-03,
                          1.48864929e-03,   5.83863677e-03,  -5.44938259e-03,
                         -5.10466285e-03,  -1.14059756e-02,   2.03098985e-03,
                          1.33651448e-02,   8.65361746e-03,   1.11074122e-02,
                          9.40105040e-03,  -2.84993788e-03,   4.91014682e-03,
                         -8.30168370e-03,   7.77668273e-03,  -9.07080155e-03,
                         -6.81884936e-04,   9.61246341e-03,  -5.07642841e-03,
                         -8.77108192e-04,  -3.33061162e-03,   1.11923658e-03,
                         -7.30966218e-04,   1.16861723e-02,  -4.17579152e-03,
                          1.28412538e-03,  -2.44646217e-03,   6.39856700e-03,
                          1.51692256e-02,  -5.31118270e-03,  -1.26397167e-03,
                          1.36002738e-04,  -1.55432196e-03,  -2.94783711e-03,
                         -1.05507812e-02,  -1.25695877e-02,   1.06450627e-02,
                         -1.96097251e-02,   5.87642146e-03,  -2.58790539e-03,
                          8.09023622e-04,  -1.06642740e-02,   1.07661448e-03,
                          4.64378251e-03,   8.10720865e-03,  -9.91474139e-04,
                          1.36229361e-03,  -2.01036502e-03,  -5.52581809e-03,
                         -3.52601521e-03,  -2.11378769e-03,  -2.07505352e-03,
                         -2.87282909e-03,   5.11742895e-04,   6.71422062e-03,
                         -2.32757069e-03,   7.24683097e-03,   3.83877149e-03,
                          2.99200474e-04,  -8.03084229e-04,   2.90010736e-04,
                          4.78614029e-03,  -6.86649606e-03,   5.64780738e-03,
                         -1.40501279e-03,   8.06277804e-03,   5.41498000e-03,
                          3.53058917e-03,   6.51967619e-03,   6.48376299e-04,
                         -8.62609711e-04,  -1.06972074e-02,  -6.56091236e-03,
                         -1.30482586e-02,   3.48054455e-03,   3.11329425e-03,
                         -4.69650235e-03,   1.68586150e-03,  -1.35108025e-03,
                         -8.48050974e-03,  -1.67112052e-03,   3.46317003e-03,
                          5.46580087e-03,   1.66342082e-03,   5.98206942e-04,
                         -4.32196120e-03,  -2.31682160e-03,   3.04295728e-03,
                         -1.55561103e-03,   1.96285686e-03,   6.97201176e-04,
                          2.03583436e-03,  -6.46247948e-03,   2.43265694e-03,
                          4.40137694e-04,   3.36860423e-03,   2.75380589e-04,
                         -4.43762314e-04,  -2.29176111e-03,   5.13482420e-03,
                          2.87577463e-03,   8.43156013e-05,  -3.48987989e-03,
                         -2.64687650e-03,  -1.66898519e-02,  -5.56177320e-03,
                          1.08664273e-03,   3.64835118e-03,   4.86183446e-03,
                          1.71715234e-04,   4.15292103e-04,  -5.43841859e-03,
                         -1.05599640e-03,  -6.96021598e-03,  -7.67468766e-04,
                         -2.44614342e-03,  -9.03014094e-04,   4.30266699e-03,
                         -2.28583580e-03,   2.75438814e-03,   3.36266495e-03,
                          4.96529182e-03,  -2.03586207e-03,  -3.38544516e-04,
                         -2.97618262e-03,  -8.03635921e-03,  -4.77636140e-03,
                         -2.92265904e-03,  -3.32966913e-03,  -1.61698693e-03,
                         -4.10074880e-03,  -8.78487306e-04,  -5.04784752e-03,
                         -1.54021860e-03,  -3.11493687e-03,  -4.95375274e-03,
                         -7.83366524e-03,  -2.04587658e-03,  -3.45131219e-03,
                         -8.66670907e-03,  -1.33076990e-02,  -1.12274196e-02,
                          6.08941447e-03,  -1.78754481e-03,  -3.31988354e-04,
                         -2.13663047e-03,  -1.86705065e-03,  -1.28977362e-03,
                         -2.44240789e-03,  -2.25364394e-03,  -2.08000885e-03,
                         -8.63625016e-03,  -4.36307956e-03,  -2.06548278e-03,
                          2.62741582e-03,   3.20556597e-03,  -1.43835507e-03,
                         -1.93286198e-03,  -1.64418889e-03,  -2.37225811e-03,
                         -7.63511518e-04,   6.75917836e-04,  -9.60120873e-04,
                         -3.78054916e-03,  -8.41622334e-03,   2.06433213e-03,
                         -1.30759866e-03,  -2.49465648e-03,  -2.11787666e-03,
                         -1.38726391e-04,   9.40445345e-04,   1.37099135e-03,
                         -1.55722583e-03,  -8.32739577e-04,   2.98104784e-03,
                          8.31443584e-04,  -3.33418790e-03,  -3.28875892e-03,
                          9.62705875e-04,   5.40434849e-04,   8.43467889e-04,
                          3.24875652e-03,   3.02285911e-03,  -2.55930354e-03,
                          6.48729736e-04,  -3.65149067e-03,  -1.44349749e-03,
                         -5.58116473e-03,  -2.12019146e-03,   9.39135498e-04,
                         -7.77732712e-05,  -1.50113092e-05,  -3.09450581e-04,
                         -5.12230769e-03,  -3.74062289e-03,   1.90929859e-03,
                          7.82523770e-03,   5.37333498e-03,   4.94581042e-03,
                         -4.17461328e-04,  -2.65664840e-03,  -1.66815425e-05,
                         -5.50989877e-04,  -4.15018341e-03,  -4.31768503e-03,
                         -1.90399680e-03,  -5.76188962e-04,  -5.99832786e-03,
                         -5.40844444e-03,   1.82577304e-03,   4.27511148e-03,
                          1.03569375e-02,   8.99896771e-03,  -9.61444573e-04,
                         -3.78409051e-03,   1.24955632e-05,  -2.97535094e-03,
                          7.41070762e-05,  -1.94314681e-03,   2.36995728e-03,
                         -7.24036479e-03,  -3.04444041e-03,  -1.09644234e-03,
                          3.30758188e-03,   3.12985806e-03,   2.08803429e-03,
                         -4.25482588e-03,  -8.28936137e-03,  -2.31772265e-03,
                         -5.24295960e-03,  -4.29092674e-03,   8.20257876e-04,
                         -3.03448131e-03,  -6.90046186e-03,  -9.87714343e-03,
                         -1.85271853e-03,   7.75154622e-04,   5.43990871e-03,
                          1.78671314e-03,  -1.61832446e-04,  -7.21336389e-03,
                          3.21456860e-03,  -3.05480137e-03,   8.07288289e-03,
                         -1.57852995e-03,   4.67456039e-03,   8.45671748e-04,
                         -4.40126611e-03,   4.38549230e-03,  -5.49176894e-03,
                          1.85977365e-03,   1.11286063e-03,   7.34744687e-03,
                          1.96042424e-03,   9.62733664e-03,   9.71847156e-04,
                          6.26816414e-03,  -1.22599289e-04,  -1.72042418e-02,
                         -2.42551859e-03,  -1.45884836e-03,   2.78978888e-03,
                          2.46127951e-03,   8.65045749e-03,  -6.67863293e-03,
                          5.98809868e-03,   2.15227250e-03,   1.44258756e-02,
                         -5.82270371e-03,  -5.22935530e-04,  -8.15386418e-03,
                         -1.27501395e-02,   1.12369284e-02,  -1.78244188e-02,
                         -9.97136231e-04,  -1.11000594e-02,  -8.17710254e-03,
                          7.65668927e-03,  -5.58673684e-03,  -5.26892813e-03,
                          1.14707332e-02,   2.96745030e-03,   1.36279399e-02,
                          1.39349448e-02,  -3.22235143e-03,   9.28358734e-03,
                          1.77009813e-02,  -3.59728769e-03,   9.17775929e-03,
                         -8.16617347e-03,  -1.28084724e-03,   1.62566453e-02,
                         -2.14519855e-02,  -1.19929691e-03,  -2.46690493e-02,
                         -4.75949282e-03,  -9.40542377e-04,   9.44230054e-03,
                          2.54746643e-03,   1.80126005e-03,   9.50657390e-03,
                          1.08289334e-03,   5.89834934e-04,  -5.51357225e-04,
                         -5.58924535e-03,  -2.17226129e-02,   1.07164457e-02,
                         -1.34886941e-04,   5.37305791e-03,   5.70003549e-03,
                          6.55071111e-04,   1.13233989e-02,   9.61618498e-03,
                          6.82281330e-03,   4.30410821e-03,   1.74004287e-02,
                         -4.44566924e-03,   1.43769113e-02,  -8.50864034e-03,
                          9.53428820e-03,  -2.05839286e-03,  -4.99268109e-03,
                          7.61363097e-03,   1.06426445e-03,  -6.34277007e-03,
                         -2.10158341e-03,   1.72686130e-02,   1.07383877e-02,
                          1.13528119e-02,  -1.14069106e-02,  -9.38533992e-03,
                          1.48159405e-03,   1.84352323e-02,  -1.82230084e-03,
                         -1.48873096e-02,  -1.97507180e-02,  -7.98995316e-04,
                         -1.42590320e-02,  -3.82628990e-03,   4.02040407e-03,
                          5.30137634e-03,   6.58763619e-03,  -8.19242559e-03,
                         -1.01146074e-02,   1.41931721e-03,  -2.08860878e-02,
                          2.99774320e-03,  -1.68662313e-02,  -1.62245508e-03,
                         -1.85480174e-02,  -1.57423653e-02,   8.10842868e-03,
                          1.69937368e-02,  -1.06939988e-03,   4.71955305e-03,
                          1.49701703e-02,   3.99275171e-03,   3.47211724e-03,
                          2.61383355e-02,   3.52948741e-03,   6.51203189e-03,
                          1.90076721e-03,   1.09703355e-02,  -2.53484808e-02,
                         -2.14679595e-02,  -2.55179014e-02,   2.27631126e-02,
                         -9.20693623e-04,   1.37203299e-02,  -4.83804243e-03,
                         -2.45680586e-02,   1.34099852e-02,  -1.39588332e-02,
                         -5.88718476e-03,   3.74581777e-02,   8.82217288e-03,
                          2.98463088e-03,   3.03832791e-03,  -1.15152337e-02,
                         -2.22803522e-02,  -3.03043053e-02,  -1.96714066e-02,
                         -2.70261080e-03,   1.22477179e-02,   8.86311755e-04,
                          1.32669481e-02,  -3.12322285e-02,  -1.31561998e-02,
                         -1.55285830e-02,   6.98813889e-03,  -1.17908632e-02,
                          2.82800314e-03,  -9.95603297e-03,  -9.52177215e-03,
                          1.47777537e-04,  -5.15050068e-03,  -1.20928437e-02,
                         -2.27143504e-02,   3.07883625e-03,   3.02231847e-03,
                          3.10830446e-03,   2.07669754e-02,   3.32582975e-03,
                          5.85898466e-04,   1.23424428e-02,   1.40893124e-02,
                         -2.38111597e-02,  -6.82016602e-03,   1.99706480e-02,
                          6.57870295e-03,   1.73725486e-02,   2.88386028e-02,
                          7.26133632e-03,  -2.99919164e-03,   5.84311376e-04,
                          1.10202208e-02,   3.08153895e-03,   8.98496155e-03,
                          1.48339318e-02,  -9.33338761e-01,  -9.46826100e-01,
                         -9.29736912e-01,  -9.26601887e-01,  -9.41970944e-01,
                         -9.60587382e-01,  -9.55419183e-01,  -9.41944301e-01,
                         -9.54697967e-01,  -9.29842114e-01,  -9.27246749e-01,
                         -9.47303057e-01,  -1.59547490e-03,  -5.07410662e-03,
                          2.09489535e-03,   1.07255597e-02,  -9.53295734e-03,
                         -2.46755849e-03,  -7.83468410e-03,   5.97992074e-03,
                         -1.13059068e-02,  -1.30992045e-03,   9.91512928e-03,
                         -3.19110905e-03,  -2.48665530e-02,  -2.55778916e-02,
                         -6.83435937e-03,   4.59868606e-04,   3.36175715e-03,
                         -3.59684676e-02,  -2.16294602e-02,  -1.99979879e-02,
                         -1.20912492e-02,  -2.65507232e-02,  -1.21260397e-02,
                         -1.83059592e-02,  -1.73812807e-02,  -3.96381039e-03,
                         -2.05896124e-02,   1.39375087e-02,  -5.54896565e-03,
                         -2.13933960e-02,  -1.14934926e-03,  -2.45052353e-02,
                         -7.93963787e-04,   1.15544803e-03,   2.78785522e-03,
                          6.08773716e-03,   3.50128743e-03,  -5.62910223e-03,
                         -5.11929300e-03,  -1.07725756e-02,  -1.98334679e-02,
                          2.28678230e-02,  -8.29198118e-03,   3.94965144e-04,
                          1.59683323e-03,  -2.19740476e-02,  -1.63805336e-02,
                          8.34039040e-03,   7.70022627e-03,   9.08146799e-03,
                          4.88674268e-03,  -2.79775192e-03,  -7.54933711e-03,
                          3.12411948e-03,   3.40780020e-02,  -4.53430257e-04,
                         -2.51251683e-02,  -3.07601551e-03,   8.99219699e-03,
                          1.08687636e-02,   3.20668868e-03,  -1.76898506e-03,
                          4.16222867e-03,  -1.22582102e-02,  -9.11532283e-01,
                         -9.51335669e-01,  -9.44053173e-01,  -9.38379288e-01,
                         -9.22586024e-01,  -9.22634423e-01,  -9.28253770e-01,
                         -9.44323063e-01,  -9.45844650e-01,  -9.32065070e-01,
                         -9.21776593e-01,  -9.46978688e-01,  -9.10002410e-01,
                         -9.49152648e-01,  -9.51894403e-01,  -9.52776968e-01,
                         -9.47517931e-01,  -9.58373427e-01,  -9.60912883e-01,
                         -9.34905350e-01,  -9.51338649e-01,  -9.32508528e-01,
                         -9.16984916e-01,  -9.35936451e-01,  -9.43795919e-01,
                         -9.35467422e-01,  -9.40605819e-01,  -9.13596213e-01,
                         -9.36187625e-01,  -9.26125228e-01,  -9.37431872e-01,
                         -9.32039678e-01,  -9.31760609e-01,  -9.63092029e-01,
                         -9.45201278e-01,  -9.57693815e-01,  -9.38182175e-01,
                         -9.15995657e-01,  -9.22056854e-01,  -9.19473886e-01,
                         -8.96482348e-01,  -9.20711517e-01,  -9.21950400e-01,
                         -9.29795444e-01,  -9.39100623e-01,  -9.20042992e-01,
                         -9.23319042e-01,  -9.54693437e-01,  -9.58746672e-01,
                         -9.34389174e-01,  -9.46053684e-01,  -9.26848173e-01,
                         -9.34807122e-01,  -9.28368092e-01,  -9.33757901e-01,
                         -9.31577981e-01,  -9.37120974e-01,  -9.74202096e-01,
                         -9.58270311e-01,  -9.54471350e-01,  -9.20019448e-01,
                         -9.35283780e-01,  -9.24114764e-01,  -9.26755905e-01,
                         -9.56150949e-01,  -9.19542432e-01,  -9.21283185e-01,
                         -9.48204994e-01,  -9.22561884e-01,  -9.17901158e-01,
                         -9.40187573e-01,  -9.43424881e-01,  -9.33798254e-01,
                         -9.26359713e-01,  -9.16686952e-01,  -9.33518946e-01,
                         -9.37471032e-01,  -9.34039295e-01,  -9.31203723e-01,
                         -9.39008355e-01,  -9.62833524e-01,  -9.82509613e-01,
                         -9.32181060e-01,  -9.17608082e-01,  -9.38646436e-01,
                         -9.34133470e-01,  -9.29535747e-01,  -9.24353540e-01,
                         -9.39190149e-01,  -9.42554116e-01,  -9.48650777e-01,
                         -9.47570980e-01,  -9.58852053e-01,  -9.43395197e-01,
                         -9.53442514e-01,  -9.21197355e-01,  -9.23511624e-01,
                         -9.41980064e-01,  -9.25902188e-01,  -9.40419197e-01,
                         -9.31834459e-01,  -9.33793247e-01,  -9.50582445e-01,
                         -9.40943360e-01,  -9.51497793e-01,  -9.51711893e-01,
                         -9.21337962e-01,  -9.46948647e-01,  -9.60888028e-01,
                         -9.38723743e-01,  -9.46623981e-01,  -9.45475757e-01,
                         -9.39244688e-01,  -9.31651473e-01,  -9.20755565e-01,
                         -9.21065986e-01,  -9.32899952e-01,  -9.49886143e-01,
                         -9.42531824e-01,  -9.20956075e-01,  -9.43362653e-01,
                         -9.24302280e-01,  -9.30549622e-01,  -9.37502325e-01,
                         -9.29252982e-01,  -9.32953835e-01,  -9.47044134e-01,
                         -9.22164083e-01,  -9.49507475e-01,  -9.57082272e-01,
                         -9.42998409e-01,  -9.27690506e-01,  -9.62970674e-01,
                         -9.49093997e-01,  -9.40790534e-01,  -9.44626927e-01,
                         -9.33842838e-01,  -9.24938798e-01,  -9.28316712e-01,
                         -9.37008321e-01,  -9.34889734e-01,  -9.30001497e-01,
                         -9.38244045e-01,  -9.52367604e-01,  -9.22134340e-01,
                         -9.23148394e-01,  -9.28070962e-01,  -9.46955502e-01,
                         -9.34892595e-01,  -9.32591140e-01,  -9.17809784e-01,
                         -9.24829245e-01,  -8.97506654e-01,  -9.05456960e-01,
                         -9.10759032e-01,  -9.15045559e-01,  -8.98557901e-01,
                         -9.19505179e-01,  -9.24329221e-01,  -9.24038827e-01,
                         -9.52234864e-01,  -9.52230334e-01,  -9.48627830e-01,
                         -9.40549493e-01,  -9.38365221e-01,  -9.44604635e-01,
                         -9.36246872e-01,  -9.44308996e-01,  -9.38090444e-01,
                         -9.65084314e-01,  -9.30564225e-01,  -9.53253210e-01,
                         -9.35034275e-01,  -9.20662344e-01,  -9.30478275e-01,
                         -9.29762423e-01,  -9.22911942e-01,  -9.36434031e-01,
                         -9.33490992e-01,  -9.29216087e-01,  -9.29652572e-01,
                         -9.42894101e-01,  -9.42680955e-01,  -9.21570182e-01,
                         -9.37023401e-01,  -9.35649514e-01,  -9.37242150e-01,
                         -9.47915256e-01,  -9.65238214e-01,  -9.48686004e-01,
                         -9.33983743e-01,  -9.51087058e-01,  -9.47220206e-01,
                         -9.29248333e-01,  -9.29689288e-01,  -9.50533867e-01,
                         -9.56414521e-01,  -9.49060917e-01,  -9.40509677e-01,
                         -9.52291191e-01,  -9.46208060e-01,  -9.49018896e-01,
                         -9.37785625e-01,  -9.31006551e-01,  -9.25299466e-01,
                         -9.42433119e-01,  -9.47515309e-01,  -9.57509160e-01,
                         -9.42884743e-01,  -9.52374816e-01,  -9.52364028e-01,
                         -9.53142345e-01,  -9.40684974e-01,  -9.48734045e-01,
                         -9.44704652e-01,  -9.40300405e-01,  -9.44329977e-01,
                         -9.37879980e-01,  -9.29034233e-01,  -9.52987015e-01,
                         -9.54474449e-01,  -9.52491581e-01,  -9.44473863e-01,
                         -9.35796678e-01,  -9.34358358e-01,  -9.30242300e-01,
                         -9.27361667e-01,  -9.30013657e-01,  -9.21960115e-01,
                         -9.30817842e-01,  -9.26911831e-01,  -9.41283882e-01,
                         -9.24398005e-01,  -9.44965541e-01,  -9.37164426e-01,
                         -9.37026262e-01,  -9.52376008e-01,  -9.23382461e-01,
                         -9.26654279e-01,  -9.35714722e-01,  -9.47809577e-01,
                         -9.24375951e-01,  -9.22877967e-01,  -9.31529522e-01,
                         -9.31713104e-01,  -9.35429037e-01,  -9.45411980e-01,
                         -9.51156497e-01,  -9.38799560e-01,  -9.24786568e-01,
                         -9.44950700e-01,  -9.53144789e-01,  -9.52697039e-01,
                         -9.48729396e-01,  -9.45061266e-01,  -9.42473948e-01,
                         -9.40665364e-01,  -9.37278748e-01,  -9.50728655e-01,
                         -9.46621776e-01,  -9.48691368e-01,  -9.39500391e-01,
                         -9.26318705e-01,  -9.13872182e-01,  -9.22963917e-01,
                         -9.26313400e-01,  -9.32462156e-01,  -9.36278224e-01,
                         -9.34391379e-01,  -9.26832020e-01,  -9.36361611e-01,
                         -9.42443669e-01,  -9.32688296e-01,  -9.12414908e-01,
                         -9.10780787e-01,  -9.21885550e-01,  -9.26246464e-01,
                         -9.35444117e-01,  -9.54636335e-01,  -9.65111256e-01,
                         -9.73803580e-01,  -9.65734243e-01,  -9.44855750e-01,
                         -9.30951476e-01,  -9.44486082e-01,  -9.51519072e-01,
                         -9.38003063e-01,  -9.31562960e-01,  -9.46462750e-01,
                         -9.45352018e-01,  -9.34083462e-01,  -9.33863997e-01,
                         -9.32757914e-01,  -9.23050106e-01,  -9.28939700e-01,
                         -9.54834819e-01,  -9.38319445e-01,  -9.45209622e-01,
                         -9.64015782e-01,  -9.23393607e-01,  -9.56234515e-01,
                         -9.45146739e-01,  -9.29535806e-01,  -9.37894285e-01,
                         -9.36380267e-01,  -9.21157897e-01,  -9.22763228e-01,
                         -9.31798041e-01,  -9.37023699e-01,  -9.42022264e-01,
                         -9.47838604e-01,  -9.44216073e-01,  -9.37847495e-01,
                         -9.31886911e-01,  -9.43740606e-01,  -9.45752084e-01,
                         -9.37573254e-01,  -9.25949991e-01,  -9.34320331e-01,
                         -9.39924181e-01,  -9.35120702e-01,  -9.36030149e-01,
                         -9.40458357e-01,  -9.39638078e-01,  -9.33849454e-01,
                         -9.22207117e-01,  -9.23953652e-01,  -9.23299193e-01,
                         -9.34952021e-01,  -9.30935144e-01,  -9.25545871e-01,
                         -9.21913922e-01,  -9.35605943e-01,  -9.36922133e-01,
                         -9.33249891e-01,  -9.31207180e-01,  -9.40207839e-01,
                         -9.30907011e-01,  -9.31738973e-01,  -9.43746269e-01,
                         -9.53205526e-01,  -9.57763016e-01,  -9.38813686e-01,
                         -9.31093276e-01,  -9.34118152e-01,  -9.23941314e-01,
                         -9.44866180e-01,  -9.45809841e-01,  -9.28501666e-01,
                         -9.14031029e-01,  -9.28540230e-01,  -9.24263239e-01,
                         -9.26276445e-01,  -9.30982172e-01,  -9.44497049e-01,
                         -9.33094203e-01,  -9.36774254e-01,  -9.43737268e-01,
                         -9.36272025e-01,  -9.48332846e-01,  -9.06606436e-01,
                         -9.25230145e-01,  -9.45807278e-01,  -9.16416526e-01,
                         -2.62033902e-02,   9.77805257e-03,   1.35573745e-03,
                         -1.55755365e-02,   1.00093549e-02,  -1.15740802e-02,
                          1.53980276e-04,   3.86840617e-03,   5.03205275e-03,
                         -4.04896447e-03,   1.93419959e-03,  -1.49902683e-02,
                         -1.79109387e-02,  -1.21960649e-02,   4.27746773e-03,
                          7.37566082e-03,  -5.21977060e-03,  -2.34638341e-02,
                         -1.36128184e-03,  -1.16083371e-02,  -1.65062724e-03,
                          1.49268480e-02,   7.48200808e-03,   8.93082819e-04,
                         -6.57599326e-03,  -7.04161404e-03,  -1.29260821e-03,
                         -1.97278825e-03,  -1.62723707e-03,   6.54094573e-03,
                          1.07205426e-03,  -9.10269562e-03,  -1.19514000e-02,
                         -4.67452593e-03,  -6.53843023e-03,  -1.12123117e-02,
                          3.10763204e-03,   1.28731329e-03,   3.74451769e-03,
                         -6.48404704e-03,  -1.19950622e-02,  -1.12556266e-02,
                         -1.32547366e-02,  -4.59407037e-03,  -6.30099373e-03,
                         -1.62878186e-02,  -7.88232312e-03,   7.02392031e-03,
                         -1.32144773e-02,  -1.63429212e-02,   1.17478808e-02,
                          1.31615913e-02,  -4.10713162e-03,   1.98362046e-03,
                          1.40533166e-03,  -1.27104064e-02,  -1.97687857e-02,
                         -3.17803840e-03,   5.52804302e-03,   3.54723609e-03,
                         -4.79010458e-04,  -9.05044004e-03,  -2.06261361e-03,
                          9.71459039e-03,   5.78261155e-04,   7.87067320e-03,
                         -7.48278399e-04,  -7.77420879e-04,  -3.42607847e-03,
                          1.23094609e-02,   5.11609809e-03,   4.64649918e-03,
                         -1.28038842e-02,   2.87753483e-03,   2.02860590e-03,
                          1.15520963e-02,   7.87894800e-03,   2.42462512e-02,
                          2.00391281e-03,   3.89668928e-03,   1.57497462e-03,
                          8.86638928e-03,   4.07166872e-03,   7.27320788e-03,
                          3.90987098e-03,   1.05791893e-02,   6.15924550e-03,
                         -2.37567490e-03,   2.62482371e-03,   1.47978528e-04,
                         -2.74649449e-03,   3.32131120e-03,   7.67780642e-04,
                         -1.41165906e-03,   3.47990007e-03,   1.22915320e-02,
                          1.33173040e-03,   8.14816076e-03,   6.92473212e-03,
                         -9.38255340e-04,   3.40724853e-03,   3.64413741e-03,
                          4.22546174e-03,  -1.51394529e-03,   4.61084209e-03,
                          1.92146143e-03,   5.06160408e-03,   6.49187854e-03,
                         -3.15084332e-03,   4.53421939e-03,  -6.31934544e-03,
                          1.32572174e-03,  -6.13067159e-03,  -4.04870836e-03,
                         -5.61262202e-03,  -9.57715965e-05,  -7.46060687e-04,
                          7.04783073e-04,  -3.84681788e-03,  -1.56108886e-02,
                         -1.16654225e-02,  -7.03956233e-03,  -8.58072378e-03,
                         -1.15565872e-02,  -5.89627016e-04,   2.83877307e-04,
                          4.38891584e-03,  -2.02527246e-03,  -5.21293026e-04,
                          8.21555965e-03,   2.78508989e-03,  -5.50817326e-03,
                         -1.74777105e-03,  -4.33413079e-03,   6.76520076e-03,
                         -2.48692906e-03,  -4.20314586e-03,  -9.32999328e-03,
                         -9.56266839e-03,   1.23057386e-03,   1.04843534e-03,
                         -6.24535605e-04,   2.65910174e-03,   1.20797376e-05,
                          3.35858995e-03,  -6.19600434e-03,   1.27937109e-03,
                         -6.73080515e-03,   3.64888483e-03,  -8.07741482e-04,
                          2.93076760e-03,  -3.00587947e-03,   1.32680289e-03,
                         -5.89421205e-03,  -4.57109604e-03,   2.39422056e-03,
                         -1.34719221e-03,  -6.72212103e-03,  -9.05328896e-04,
                         -2.38088658e-03,  -2.16586306e-03,  -3.70899937e-03,
                         -5.42470999e-03,  -4.83551994e-03,  -3.12910951e-03,
                         -1.61167129e-03,  -6.37950841e-03,  -1.73325872e-03,
                         -3.64257814e-03,  -3.42335465e-04,  -8.36121617e-04,
                         -1.57114211e-03,  -2.82703293e-03,   8.43162939e-04,
                         -6.83293864e-03,   1.09599193e-03,   8.08116421e-03,
                          4.65196744e-03,   3.61075354e-06,   1.41422544e-02,
                          9.09418520e-03,   8.16985313e-03,  -1.71248126e-03,
                         -1.55369134e-03,   5.98900672e-03,   5.57660451e-03,
                          1.82591157e-03,  -4.35874797e-03,   1.60254387e-03,
                          4.99805203e-03,   2.56804959e-03,  -2.35779444e-03,
                         -5.45280613e-03,   1.52693293e-03,   4.54542600e-03,
                          9.70502617e-04,  -1.16794358e-03,  -1.51074340e-03,
                          7.04419194e-03,   7.09710584e-04,   1.17380673e-03,
                         -8.18235520e-03,  -5.30576333e-03,   5.72287128e-04,
                         -6.92193909e-03,  -9.47821420e-03,  -2.77119433e-03,
                         -3.65427666e-04,  -2.91389204e-03,   8.63337424e-04,
                         -1.26302906e-03,  -1.13555079e-03,  -5.83812420e-04,
                          1.32994930e-04,   7.26308936e-05,   2.66929623e-03,
                         -1.40290591e-03,  -2.24033050e-04,   1.92506530e-04,
                          2.53371638e-03,  -1.27037533e-03,   2.23051012e-03,
                         -9.91037465e-04,   8.25393305e-04,   1.71521876e-03,
                         -1.93151063e-04,  -3.31513607e-03,   4.06940235e-03,
                          1.40136050e-03,   1.85886584e-03,  -2.53861625e-04,
                          6.84248167e-04,  -1.61759683e-03,   3.77244054e-04,
                          1.54606090e-03,  -5.33954881e-04,   2.04144116e-03,
                         -2.02945829e-03,   3.94299830e-04,   3.80556798e-04,
                          4.42369288e-04,  -2.53248960e-03,  -1.60550320e-04,
                          4.38125804e-03,   2.53977347e-03,   4.43285471e-03,
                         -1.53025263e-03,  -7.27556471e-05,   2.75301584e-03,
                          2.78672553e-03,   2.60977773e-03,  -2.14399755e-04,
                         -3.63831595e-03,  -1.90101669e-03,  -3.53001407e-04,
                          1.21446757e-03,   3.41589749e-03,   7.61792762e-04,
                          1.85620459e-03,  -4.54580702e-04,   1.90046220e-03,
                          3.14322673e-03,   4.33601579e-03,  -1.38598180e-03,
                          4.79460956e-04,  -2.05484452e-03,   5.89017174e-04,
                         -5.96820842e-04,   7.59893795e-04,   1.14465738e-03,
                          1.02643121e-03,   1.72519858e-03,   2.52007041e-03,
                          4.12307167e-03,   4.27304627e-03,   4.12655761e-03,
                          3.26435687e-03,   2.15008948e-03,   1.78249250e-03,
                          1.54357986e-03,   2.60783732e-03,  -8.74100369e-04,
                         -3.41857260e-04,   2.24808557e-03,   1.27672369e-03,
                          3.06133693e-03,   1.47479528e-04,   2.14909832e-03,
                          7.80657399e-04,   1.90719170e-03,  -3.94732971e-03,
                         -3.24729411e-03,  -1.19459808e-04,  -2.04765773e-03,
                         -2.66030757e-03,  -4.58571222e-03,  -2.74083926e-03,
                         -1.83137972e-03,   2.00711470e-03,  -3.21966945e-03,
                         -2.16476806e-03,  -3.76382587e-03,  -3.82462662e-04,
                          2.61402619e-03,  -1.32796029e-03,  -3.68136074e-03,
                         -2.06009089e-03,  -9.88501008e-04,  -9.97829367e-04,
                         -4.56266198e-03,  -5.20300586e-03,  -2.92067695e-03,
                          2.53684889e-03,  -8.50737910e-04,   9.37818724e-04,
                         -2.10739090e-03,  -2.97539961e-03,  -2.19387584e-03,
                         -1.55895844e-03,   7.44237972e-04,   1.03743677e-03,
                          2.41625938e-03,   4.55011753e-03,   2.77760508e-03,
                          7.17088720e-03,   4.20567533e-03,   1.84276642e-03,
                         -6.01450331e-04,   3.08629335e-03,   1.51266321e-03,
                         -5.04479802e-04,  -4.56099864e-03,   1.29302405e-03,
                         -1.29206071e-03,  -6.25686080e-04,  -3.37068341e-04,
                         -3.75722814e-03,   5.30316429e-05,   2.58637383e-03,
                          3.91600421e-03,   1.88734289e-03,   8.75659680e-05,
                         -7.34417583e-04,  -2.34034355e-03,   2.63407594e-03,
                         -7.23301142e-04,  -4.22158092e-03,  -9.03498568e-03,
                         -2.21409881e-03,  -1.93457387e-03,  -4.73547913e-03,
                         -2.71724793e-03,  -2.36231298e-03,  -4.96793259e-03,
                          4.91547631e-04,   5.82853239e-03,   2.69483496e-03,
                         -4.32907883e-03,   1.02150370e-03,   6.57579908e-03,
                          5.90020698e-03,   7.67895719e-03,  -1.48324354e-03,
                         -7.28103973e-04,  -3.62713006e-03,  -1.83097774e-03,
                         -2.76997476e-03,  -6.45376090e-03,   1.93320855e-03,
                          2.13346328e-04,  -1.07334321e-03,  -2.64063198e-03,
                          1.34141231e-03,   6.80916058e-03,   5.79796918e-03,
                          6.54863846e-03,   3.02790431e-04,  -4.41247271e-03,
                         -1.61966204e-03,   4.90113022e-03,  -4.93374467e-03,
                          6.27011852e-03,   3.24205466e-05,   6.86953124e-03,
                          1.64343347e-03,   2.55888072e-03,   9.59861651e-03,
                         -1.23554992e-03,  -3.31510836e-03,  -2.94871745e-03,
                          2.32723798e-03,   4.39132797e-03,   8.38023983e-03,
                         -1.83038868e-03,  -2.24866089e-03,  -2.41170614e-03,
                          5.42995660e-03,  -1.50458922e-03,  -6.33572880e-03,
                         -1.77582540e-03,  -3.28670046e-03,  -1.13088661e-03,
                         -5.78293717e-03,  -3.56315542e-03,   7.42500508e-03,
                          8.17444082e-03,   1.59905162e-02,   6.53650321e-04,
                         -1.88650435e-03,   2.95383204e-03,   1.37119023e-02,
                          3.64754023e-03,   3.15694907e-03,   2.93288816e-04,
                          3.52565479e-03,  -4.04258166e-03,   8.23529065e-03,
                         -2.44136155e-03,  -6.48945291e-03,  -1.37458823e-03,
                          2.62021506e-03,   4.90684062e-03,   3.39084398e-03,
                          5.99186867e-03,   2.38794857e-03,   4.82138153e-03,
                          2.50977161e-03,   4.46460303e-03,  -1.72476203e-03,
                         -8.80922005e-03,   3.27487034e-03,  -9.00063850e-03,
                          3.93226324e-03,  -1.83907256e-03,  -1.26358634e-02,
                         -7.61796907e-03,   2.00606114e-03,   1.50591295e-04,
                         -6.72467845e-03,  -6.60123350e-03,   3.00135394e-03,
                          5.95271168e-03,   6.60112966e-03,   7.97323696e-03,
                          2.78283050e-03,   8.37529171e-03,   8.28992948e-03,
                          5.27308602e-03,   1.56883430e-03,  -3.78720229e-03,
                          9.89852357e-04,  -3.96977039e-03,   1.46004045e-03,
                          1.74985025e-02,   8.82279687e-03,   5.82274562e-03,
                         -1.91362319e-03,   5.35746431e-03,   1.42390514e-03,
                          7.05449749e-03,  -1.36993104e-03,   8.61041341e-03,
                          7.27745658e-03,   3.54275899e-03,   1.07258158e-02,
                         -5.97513863e-04,  -8.90619028e-03,   8.13923404e-03,
                         -8.78813036e-04,   9.07030329e-03,  -4.44810186e-03,
                          4.23537940e-03,  -4.46057646e-03,  -6.62833173e-03,
                         -1.45568121e-02,  -9.86654684e-03,  -7.08048651e-03,
                         -5.62742539e-03,   1.09690605e-02,  -1.13320136e-02,
                         -9.36231634e-04,  -2.78603256e-04,   4.65237629e-03,
                          7.11048860e-03,   3.99959926e-03,   6.11929165e-04,
                          1.83400214e-02,   7.64216343e-03,   1.24796648e-02,
                         -9.00265481e-03,  -1.43674028e-03,   2.42260075e-03,
                          4.92691121e-04,   2.75770784e-03,  -3.10721621e-03,
                         -3.68253887e-03,   1.36239966e-02,   1.00023346e-02,
                          7.98636302e-03,   6.76326035e-03,   4.03268496e-03,
                          1.28527852e-02,   3.09607224e-03,  -1.77194434e-03,
                         -1.21780392e-02,   6.23017177e-03,  -1.06709893e-03,
                          6.40917057e-03,   1.34092709e-03,   4.78351396e-03,
                         -4.15620580e-03,   6.11736486e-03,  -3.31679243e-03,
                          1.61396526e-03,  -1.10915145e-02,   3.51924426e-03,
                          3.85753228e-03,  -9.95902610e-06,   2.40408955e-03,
                          4.94955294e-03,  -3.21716745e-03,   5.88480756e-03,
                          3.83112044e-03,   1.94958448e-02,   5.36424201e-03,
                          2.28458606e-02,   1.24416938e-02,   1.57869626e-02,
                          3.91077192e-04,  -9.71396628e-04,  -1.65855559e-03,
                          6.39221212e-03,  -6.69495389e-03,  -5.77785727e-03,
                         -1.64867286e-03,  -7.52997352e-03,   5.58431121e-03,
                         -2.25044903e-03,   2.28696526e-03,  -1.05842343e-02,
                         -2.71658966e-04,   1.15950787e-02,  -8.69529042e-03,
                          6.77728048e-03,   3.30661167e-03,  -2.41749315e-03,
                         -7.24159135e-03,  -9.23445225e-01,  -9.36709046e-01,
                         -9.44511712e-01,  -9.42284763e-01,  -9.26621199e-01,
                         -9.37066197e-01,  -9.35982823e-01,  -9.30952251e-01,
                         -9.43515718e-01,  -9.44482744e-01,  -9.44727063e-01,
                         -9.36130404e-01,  -1.07406126e-02,  -8.60530604e-03,
                         -1.11578172e-02,  -4.14391141e-03,  -1.00534887e-03,
                         -3.20101273e-03,  -1.01397512e-02,  -2.61246692e-03,
                         -5.27610118e-03,  -1.31856266e-03,  -1.21221729e-02,
                         -1.86395906e-02,  -2.78008613e-03,   1.51156820e-03,
                         -6.49190601e-03,  -4.58636368e-03,  -2.50108098e-03,
                          2.54402892e-03,   1.79640669e-02,  -8.88784602e-03,
                         -1.14957448e-02,  -8.48576985e-03,   5.28904703e-03,
                         -7.22275465e-04,   1.94627028e-02,   2.96968883e-05,
                         -1.33784997e-04,   1.04864109e-02,  -1.50119327e-03,
                         -2.12593679e-03,   2.00769678e-03,   1.15077831e-02,
                         -1.22315977e-02,   3.92428599e-03,   7.24062789e-03,
                          2.61900917e-04,  -1.14866323e-03,   1.48228575e-02,
                          3.50215379e-03,  -1.25401402e-02,  -8.40889756e-04,
                         -1.23418327e-02,   3.88962007e-03,  -1.60052013e-02,
                         -9.80892032e-03,   2.76000169e-03,   8.29015113e-03,
                         -4.60783427e-04,  -1.08210335e-03,   1.84978899e-02,
                          8.65695812e-03,   8.21620412e-03,  -8.78972467e-03,
                          3.81813967e-03,   3.97270918e-03,  -1.18563492e-02,
                          3.24820192e-03,  -1.47677669e-02,  -1.85903220e-03,
                         -5.66189736e-03,  -1.30286869e-02,  -2.47458797e-02,
                          8.96553602e-03,  -1.06973527e-02,  -9.31442320e-01,
                         -9.28608060e-01,  -9.20736194e-01,  -9.26394165e-01,
                         -9.26166236e-01,  -9.34283614e-01,  -9.48229074e-01,
                         -9.42668438e-01,  -9.48419988e-01,  -9.39623237e-01,
                         -9.42370117e-01,  -9.48326230e-01,  -9.37947989e-01,
                         -9.45840895e-01,  -9.28034902e-01,  -9.32272553e-01,
                         -9.35478210e-01,  -9.49336708e-01,  -9.26261127e-01,
                         -9.21237648e-01,  -9.24170017e-01,  -9.34788883e-01,
                         -9.30304408e-01,  -9.37750340e-01,  -9.41044033e-01,
                         -9.14351225e-01,  -9.32704806e-01,  -9.30830717e-01,
                         -9.41222429e-01,  -9.37080026e-01,  -9.20881808e-01,
                         -9.14294183e-01,  -9.42258477e-01,  -9.33682501e-01,
                         -9.29355800e-01,  -9.12503719e-01,  -9.34907019e-01,
                         -9.41659153e-01,  -9.27710950e-01,  -9.30029511e-01,
                         -9.37176645e-01,  -9.37434912e-01,  -9.46554661e-01,
                         -9.45152640e-01,  -9.43579376e-01,  -9.33954954e-01,
                         -9.21809077e-01,  -9.35905874e-01,  -9.14000154e-01,
                         -9.26604629e-01,  -9.40138519e-01,  -9.27741051e-01,
                         -9.37323332e-01,  -9.36564863e-01,  -9.43033993e-01,
                         -9.37274575e-01,  -9.47788298e-01,  -9.32481229e-01,
                         -9.25725460e-01,  -9.48199987e-01,  -9.31336462e-01,
                         -9.31783557e-01,  -9.28340256e-01,  -9.38709974e-01,
                         -9.44936395e-01,  -9.29322839e-01,  -9.32447195e-01,
                         -9.40791428e-01,  -9.27339613e-01,  -9.30056930e-01,
                         -9.44907129e-01,  -9.16614234e-01,  -9.24661338e-01,
                         -9.40889239e-01,  -9.48864341e-01,  -9.36529160e-01,
                         -9.25778270e-01,  -9.17186975e-01,  -9.18267727e-01,
                         -9.23760891e-01,  -9.28286612e-01,  -9.49231923e-01,
                         -9.35236573e-01,  -9.18256164e-01,  -9.39451933e-01,
                         -9.24720466e-01,  -9.26902473e-01,  -9.21121657e-01,
                         -9.25444722e-01,  -9.43104208e-01,  -9.31456566e-01,
                         -9.26071763e-01,  -9.23305392e-01,  -9.28758025e-01,
                         -9.19839025e-01,  -9.10211504e-01,  -9.20389950e-01,
                         -9.03007627e-01,  -9.15820241e-01,  -9.40935791e-01,
                         -9.21930552e-01,  -9.37222540e-01,  -9.35024858e-01,
                         -9.43822443e-01,  -9.33633566e-01,  -9.39599395e-01,
                         -9.32298303e-01,  -9.46588814e-01,  -9.36446130e-01,
                         -9.47196245e-01,  -9.44813967e-01,  -9.29869711e-01,
                         -9.43029702e-01,  -9.20216143e-01,  -9.15850282e-01,
                         -9.39779818e-01,  -9.46269929e-01,  -9.59809005e-01,
                         -9.59607184e-01,  -9.31407213e-01,  -9.32926655e-01,
                         -9.25285518e-01,  -9.33843851e-01,  -9.50028419e-01,
                         -9.54325378e-01,  -9.42796707e-01,  -9.26431715e-01,
                         -9.48011041e-01,  -9.43798482e-01,  -9.52800691e-01,
                         -9.47738528e-01,  -9.52739716e-01,  -9.42707896e-01,
                         -9.38303471e-01,  -9.23220694e-01,  -9.42760706e-01,
                         -9.27321136e-01,  -9.32456613e-01,  -9.30757284e-01,
                         -9.35757816e-01,  -9.27766323e-01,  -9.24215198e-01,
                         -9.24980938e-01,  -9.37185526e-01,  -9.35979366e-01,
                         -9.26253200e-01,  -9.35827911e-01,  -9.42593038e-01,
                         -9.54496264e-01,  -9.44039881e-01,  -9.23450053e-01,
                         -9.26645160e-01,  -9.40450370e-01,  -9.28684115e-01,
                         -9.33142006e-01,  -9.25981820e-01,  -9.37442541e-01,
                         -9.39281285e-01,  -9.25825238e-01,  -9.35498834e-01,
                         -9.21817899e-01,  -9.34107602e-01,  -9.23578441e-01,
                         -9.38884318e-01,  -9.33541775e-01,  -9.42246854e-01,
                         -9.29408073e-01,  -9.54078674e-01,  -9.50678468e-01,
                         -9.31733727e-01,  -9.32781219e-01,  -9.62097585e-01,
                         -9.49337065e-01,  -9.35888231e-01,  -9.40958679e-01,
                         -9.45780218e-01,  -9.46252167e-01,  -9.51436043e-01,
                         -9.47502553e-01,  -9.53902245e-01,  -9.50178146e-01,
                         -9.29638565e-01,  -9.46182549e-01,  -9.44257975e-01,
                         -9.33959246e-01,  -9.24991071e-01,  -9.38272536e-01,
                         -9.27705288e-01,  -9.25418377e-01,  -9.30987477e-01,
                         -9.41683948e-01,  -9.20338869e-01,  -9.37907040e-01,
                         -9.41749275e-01,  -9.25731122e-01,  -9.38177288e-01,
                         -9.41953182e-01,  -9.44577336e-01,  -9.36318278e-01,
                         -9.24553096e-01,  -9.41761911e-01,  -9.49707508e-01,
                         -9.37780082e-01,  -9.40594733e-01,  -9.33671474e-01,
                         -9.24690843e-01,  -9.38177824e-01,  -9.43501651e-01,
                         -9.32168961e-01,  -9.34222281e-01,  -9.42509830e-01,
                         -9.45541739e-01,  -9.44085538e-01,  -9.32156444e-01,
                         -9.31423604e-01,  -9.38797235e-01,  -9.37311828e-01,
                         -9.51657593e-01,  -9.49484289e-01,  -9.41193044e-01,
                         -9.34237480e-01,  -9.41537678e-01,  -9.24450457e-01,
                         -9.42744255e-01,  -9.47850406e-01,  -9.37315583e-01,
                         -9.34488654e-01,  -9.34994519e-01,  -9.34277833e-01,
                         -9.24250782e-01,  -9.24643219e-01,  -9.35378730e-01,
                         -9.36659455e-01,  -9.37651992e-01,  -9.34651613e-01,
                         -9.38745677e-01,  -9.27304924e-01,  -9.18391287e-01,
                         -9.32566822e-01,  -9.38735902e-01,  -9.12834764e-01,
                         -9.21450794e-01,  -9.17633235e-01,  -9.15733993e-01,
                         -9.27388966e-01,  -9.18722153e-01,  -9.33790028e-01,
                         -9.12582874e-01,  -9.17508900e-01,  -9.23247278e-01,
                         -9.37741399e-01,  -9.41910863e-01,  -9.32486594e-01,
                         -9.30811822e-01,  -9.26076829e-01,  -9.29853678e-01,
                         -9.29566145e-01,  -9.38105404e-01,  -9.38433647e-01,
                         -9.10725832e-01,  -9.21071827e-01,  -9.31347430e-01,
                         -9.41473305e-01,  -9.31484699e-01,  -9.25231695e-01,
                         -9.20472383e-01,  -9.35066879e-01,  -9.35755968e-01,
                         -9.43992317e-01,  -9.17632580e-01,  -9.34222639e-01,
                         -9.11403120e-01,  -9.34801221e-01,  -9.21442032e-01,
                         -9.30163920e-01,  -9.27656174e-01,  -9.24380660e-01,
                         -9.21606302e-01,  -9.45860624e-01,  -9.34972882e-01,
                         -9.43041086e-01,  -9.39894140e-01,  -9.40181673e-01,
                         -9.35638726e-01,  -9.52196360e-01,  -9.48042214e-01,
                         -9.47505295e-01,  -9.45810080e-01,  -9.62992549e-01,
                         -9.29357231e-01,  -9.45535421e-01,  -9.54763830e-01,
                         -9.48190928e-01,  -9.34828579e-01,  -9.36327696e-01,
                         -9.37408745e-01,  -9.24981356e-01,  -9.17086899e-01,
                         -9.34434652e-01,  -9.29785430e-01,  -9.34364319e-01,
                         -9.25732076e-01,  -9.36648607e-01,  -9.23339546e-01,
                         -9.51430023e-01,  -9.41745758e-01,  -9.43188608e-01,
                         -9.42181289e-01,  -9.52428043e-01,  -9.53090549e-01,
                         -9.35215950e-01,  -9.20682371e-01,  -9.35835361e-01,
                         -9.25215244e-01,  -9.52809811e-01,  -9.36929822e-01,
                         -9.32187855e-01,  -9.35092628e-01,  -9.37828124e-01,
                         -9.27597344e-01,  -9.32711124e-01,  -9.27392900e-01,
                         -9.28338170e-01,  -9.28033948e-01,  -9.33068037e-01,
                         -9.31974709e-01,  -9.34144855e-01,  -9.30073857e-01,
                         -9.43479657e-01,  -9.33826625e-01,  -9.56206143e-01,
                         -9.50457215e-01,  -9.38433290e-01,  -9.20355856e-01,
                         -9.48503494e-01,  -9.16203082e-01,  -9.35077012e-01,
                         -9.32687521e-01,  -9.38914120e-01,  -9.39089239e-01,
                         -9.36402977e-01,  -9.21716869e-01,  -9.31773543e-01,
                         -9.18065369e-01,  -9.26764846e-01,  -9.36036944e-01,
                         -9.53079164e-01,  -9.30136144e-01,  -9.48067963e-01,
                         -9.39692318e-01,  -9.43394184e-01,  -9.41652119e-01,
                         -9.42588031e-01,  -9.21255112e-01,  -9.49187338e-01,
                         -9.36252415e-01,  -9.33255553e-01,  -9.48157847e-01,
                         -9.24343824e-01,  -9.47483122e-01,  -9.30291474e-01,
                         -9.38538015e-01,  -9.50897455e-01,  -9.17990208e-01,
                         -1.25671830e-02,   7.82189704e-03,  -2.09351629e-03,
                          3.02292849e-03,   2.38624867e-02,  -8.78051389e-03,
                          6.03095628e-03,   6.50812313e-03,  -1.25383660e-02,
                         -5.14318235e-03,  -2.20617466e-02,   1.27804177e-02,
                          9.79134440e-03,   2.02453844e-02,  -8.77729803e-03,
                         -9.50610265e-03,  -2.22245213e-02,   1.52637567e-02,
                          1.52054233e-02,   2.55081449e-02,   6.14710338e-03,
                          1.13464986e-04,  -7.17617525e-03,   4.86715045e-03,
                         -1.05154710e-02,  -6.21653255e-03,  -4.40385798e-03,
                          7.85255060e-03,   1.51346922e-02,   7.13577075e-03,
                          7.32683577e-03,  -2.97800543e-05,  -9.51790484e-04,
                          2.72808224e-02,   3.67315509e-03,  -9.20205750e-03,
                         -1.39808170e-02,  -1.67224109e-02,  -2.87373713e-03,
                          2.74107489e-03,   1.66622072e-03,  -1.43440058e-02,
                         -1.77615602e-02,  -1.36361597e-02,   7.65418075e-03,
                         -5.49643999e-03,  -7.65847042e-03,  -3.27451690e-03,
                         -1.87079441e-02,  -3.29258456e-03,  -2.17334162e-02,
                         -9.83929634e-03,   5.83026512e-03,  -1.72395874e-02,
                         -4.21857275e-03,   9.75796115e-03,   6.49943249e-03,
                         -7.10335001e-03,   2.31953487e-02,   8.00982956e-03,
                         -1.63972080e-02,   7.71709532e-03,   2.00636405e-02,
                         -1.39849270e-02,   1.05615510e-02,  -1.84644852e-02,
                         -1.01389131e-02,  -1.50380265e-02,  -1.62227899e-02,
                         -1.04314946e-02,  -8.06342252e-03,  -4.21142764e-03,
                         -6.68146741e-03,   2.70189717e-04,  -3.51219601e-03,
                          2.01280247e-02,  -1.86122842e-02,   5.23166312e-03,
                         -1.31475087e-03,   5.16665587e-03,   1.72171816e-02,
                          1.00570992e-02,   2.56945584e-02,   1.49165150e-02,
                          1.06810667e-02,   8.03732220e-03,  -8.62722006e-03,
                         -1.28295822e-02,  -3.71659501e-03,  -3.70360748e-03,
                         -4.65261890e-03,   4.76026908e-03,   1.04995864e-02,
                         -2.00531282e-03,   1.07929856e-02,   1.20711857e-02,
                          6.58217492e-03,   2.26542689e-02,   2.91082170e-02,
                          1.40917106e-02,  -4.47043171e-03,   1.60220768e-02,
                          7.24024000e-03,  -1.79762170e-02,  -1.30238077e-02,
                          3.87416524e-03,  -6.78072497e-03,  -6.34252746e-03,
                         -6.76594209e-03,   1.07264118e-02,   2.27598064e-02,
                          2.81696301e-03,   3.09801963e-03,   1.73683614e-02,
                         -6.49126153e-03,  -6.36941753e-03,   2.34736409e-03,
                         -1.61086656e-02,  -2.14502327e-02,  -1.50992218e-02,
                          6.10328931e-03,   2.36961758e-03,  -7.65883084e-03,
                          3.53256450e-03,   2.51800641e-02,  -1.32579450e-02,
                          4.62530600e-03,   5.56657603e-03,   1.27488011e-02,
                          2.06667334e-02,   2.61520501e-02,  -4.62143170e-03,
                          1.06581338e-02,  -8.04501493e-03,  -5.74116770e-04,
                         -8.73005367e-04,   9.19500925e-03,  -4.08002688e-03,
                         -8.71376041e-03,  -1.40038263e-02,  -1.80941715e-03,
                         -7.70377461e-03,   1.29857389e-02,  -1.92225575e-02,
                          2.60993373e-02,  -2.29702629e-02,  -1.49393231e-02,
                         -8.52222368e-03,  -1.82627626e-02,   1.08904140e-02,
                         -2.20959466e-02,   1.69886998e-03,   1.25784446e-02,
                          1.02553647e-02,  -1.23308552e-02,  -8.53787293e-04,
                         -2.71178056e-02,   1.63898133e-02,  -6.23464864e-03,
                         -2.22481266e-02,   4.77747759e-03,   2.02389117e-02,
                          2.02843193e-02,  -1.41870314e-02,   1.27951866e-02,
                          7.11548515e-03,   2.03156248e-02,   9.46939166e-04,
                         -1.85703486e-02,  -3.75390844e-03,   5.94991213e-03,
                          1.95016656e-02,   8.93881172e-03,   2.36284663e-03,
                         -7.10734911e-03,  -5.38490200e-03,  -6.20617159e-03,
                         -1.67403687e-02,  -4.24147816e-03,  -1.12029416e-02,
                          1.88927241e-02,  -2.89725550e-02,   2.63458733e-02,
                         -2.24776901e-02,   8.44657794e-03,  -1.52710900e-02,
                         -3.17260064e-02,  -2.12522093e-02,  -1.03766192e-02,
                         -4.94194357e-03,  -7.91579718e-04,  -2.28412040e-02,
                         -3.90549772e-03,  -9.57993232e-03,  -3.52465687e-03,
                          9.51908249e-03,  -1.31405368e-02,  -1.47449726e-03,
                         -4.91508096e-03,  -1.58214755e-02,  -6.86149206e-03,
                         -9.89765767e-03,  -1.20447529e-02,   1.21500744e-02,
                         -7.46770343e-03,  -1.45691615e-02,   1.18516991e-02,
                         -2.13329978e-02,  -1.25259468e-02,  -2.43244059e-02,
                         -1.46053527e-02,  -2.64859796e-02,  -1.14555899e-02,
                         -1.61356330e-02,  -4.82119434e-03,  -7.67558161e-03,
                         -7.81998411e-03,  -4.17177193e-03,   5.62411267e-04,
                         -9.37860273e-03,  -1.48445636e-03,  -1.55564221e-02,
                         -2.92930938e-02,  -1.29653430e-02,  -1.07231066e-02,
                         -1.43382056e-02,  -2.22244933e-02,  -1.23425331e-02,
                          5.39909536e-03,  -2.81196963e-02,  -4.41955542e-03,
                         -1.35957832e-02,  -1.20088188e-02,  -1.16662821e-02,
                         -8.06869660e-03,  -8.02163221e-03,  -5.43884840e-03,
                         -2.62189843e-02,  -1.37044387e-02,  -5.39223431e-03,
                         -2.53752526e-02,  -2.77574845e-02,   2.18212530e-02,
                         -4.53518983e-03,  -1.02613037e-02,   2.37462763e-02,
                         -2.25262158e-02,   4.69879135e-02,  -2.83870306e-02,
                          1.06063634e-02,  -9.05284565e-03,  -1.28571037e-02,
                         -1.59311444e-02,   1.26880908e-03,  -3.11390683e-02,
                         -4.40578442e-03,  -1.76472012e-02,   1.43067138e-02,
                          3.12271272e-03,  -1.74927767e-02,  -2.70847883e-02,
                          1.83815137e-02,  -2.50715539e-02,  -1.94660705e-02,
                         -7.69495130e-01,  -7.66803861e-01,  -7.52541125e-01,
                         -7.75368512e-01,  -7.54671395e-01,  -7.84893751e-01,
                         -7.78070271e-01,  -7.72970915e-01,  -7.69337654e-01,
                         -7.71075964e-01,  -7.65562654e-01,  -7.40800500e-01,
                         -7.82303095e-01,  -7.48310685e-01,  -7.86657631e-01,
                         -7.52578855e-01,  -7.44202256e-01,  -7.94577301e-01,
                         -7.50139058e-01,  -7.73129046e-01,  -7.47866511e-01,
                         -7.81879604e-01,  -7.63326764e-01,  -7.47963488e-01,
                         -7.78847098e-01,  -7.47633278e-01,  -7.56529629e-01,
                         -7.48027682e-01,  -7.49387980e-01,  -7.70276010e-01,
                         -7.54996121e-01,  -7.63902605e-01,  -7.44511425e-01,
                         -7.58002460e-01,  -7.59081006e-01,  -7.67860770e-01,
                         -7.58746207e-01,  -7.58585036e-01,  -7.36526787e-01,
                         -7.84477532e-01,  -7.28339255e-01,  -7.81235933e-01,
                         -7.53539920e-01,  -7.53046095e-01,  -7.87017822e-01,
                         -7.75318146e-01,  -7.64912367e-01,  -7.39044726e-01,
                         -7.61041880e-01,  -7.64095485e-01,  -7.51299739e-01,
                         -7.66821444e-01,  -7.35262215e-01,  -7.64995039e-01,
                         -7.67222822e-01,  -7.47366607e-01,  -7.83238590e-01,
                         -7.27152050e-01,  -7.56410837e-01,  -7.46027112e-01,
                         -7.66261518e-01,  -7.72584677e-01,  -7.68350482e-01,
                         -7.52141654e-01,  -7.64937460e-01,  -7.71708786e-01,
                         -7.70363510e-01,  -7.77176738e-01,  -7.64946759e-01,
                         -7.66910851e-01,  -7.39683330e-01,  -7.56940901e-01,
                         -7.65021861e-01,  -7.50310004e-01,  -7.53039420e-01,
                         -7.50509143e-01,  -7.80773580e-01,  -7.62334585e-01,
                         -7.51874924e-01,  -7.75416017e-01,  -9.16886806e-01,
                         -9.34314847e-01,  -9.03815031e-01,  -9.25883293e-01,
                         -7.42810607e-01,  -7.71454096e-01,  -7.37716258e-01,
                         -7.61677861e-01,  -7.51272857e-01,  -7.55067229e-01,
                         -7.64931560e-01,  -7.33125567e-01,  -7.83072531e-01,
                         -7.38969386e-01,  -7.58229554e-01,  -7.37754166e-01,
                         -7.66389787e-01,  -7.43951380e-01,  -7.38698304e-01,
                         -7.54300237e-01,  -9.08354580e-01,  -9.51450884e-01,
                         -9.00777042e-01,  -9.24716949e-01,  -9.20198143e-01,
                         -9.43085253e-01,  -9.36778784e-01,  -9.30341125e-01,
                         -9.15227056e-01,  -9.32208359e-01,  -8.97326946e-01,
                         -9.28464711e-01,  -7.39801347e-01,  -7.49933660e-01,
                         -7.70855188e-01,  -7.68764377e-01,  -7.59057999e-01,
                         -7.29009867e-01,  -7.79298782e-01,  -7.55571067e-01,
                         -7.62847662e-01,  -7.79839516e-01,  -7.63157487e-01,
                         -7.69177556e-01,  -7.54541874e-01,  -7.46959388e-01,
                         -7.63983250e-01,  -7.42412925e-01,  -9.17313576e-01,
                         -9.34406877e-01,  -9.20667410e-01,  -9.20148909e-01,
                         -9.26224291e-01,  -9.22005296e-01,  -9.48498309e-01,
                         -9.23199534e-01,  -7.78226078e-01,  -7.79361069e-01,
                         -7.28227973e-01,  -7.72484064e-01,  -7.45610833e-01,
                         -7.61737347e-01,  -7.64750779e-01,  -7.61606693e-01,
                         -7.38866031e-01,  -7.37784624e-01,  -7.55094349e-01,
                         -7.70363390e-01,  -7.67573833e-01,  -7.60697424e-01,
                         -7.61842966e-01,  -7.64542282e-01,  -9.49729800e-01,
                         -9.27653491e-01,  -9.25482690e-01,  -9.21000004e-01,
                         -9.25748706e-01,  -9.46145952e-01,  -9.25425112e-01,
                         -9.48584676e-01,  -9.27690506e-01,  -9.08920228e-01,
                         -9.37138617e-01,  -9.31786299e-01,  -9.10739541e-01,
                         -9.41475928e-01,  -9.30111706e-01,  -9.32432473e-01,
                         -7.56358504e-01,  -7.40307331e-01,  -7.81539500e-01,
                         -7.42373228e-01,  -7.60608196e-01,  -7.77381420e-01,
                         -7.31061876e-01,  -7.67594278e-01,  -7.51524746e-01,
                         -7.23031461e-01,  -7.67646492e-01,  -7.45012879e-01,
                         -7.47348547e-01,  -7.52010286e-01,  -7.55823791e-01,
                         -7.60723174e-01,  -7.83070207e-01,  -7.41725206e-01,
                         -7.57903934e-01,  -7.33611822e-01,  -7.68517911e-01,
                         -7.53543139e-01,  -7.40398109e-01,  -7.52924383e-01,
                         -7.32073724e-01,  -7.55762339e-01,  -7.55057633e-01,
                         -7.60947585e-01,  -7.66546428e-01,  -7.41494060e-01,
                         -7.63083935e-01,  -7.47434437e-01,  -7.77522922e-01,
                         -7.53284633e-01,  -7.70717919e-01,  -7.78698981e-01,
                         -7.21107364e-01,  -8.01266670e-01,  -7.41315484e-01,
                         -7.74832487e-01,  -7.61429608e-01,  -7.43803740e-01,
                         -7.57750511e-01,  -7.64954567e-01,  -7.61565149e-01,
                         -7.70530820e-01,  -7.41904974e-01,  -7.37189829e-01,
                         -1.73201121e-03,   2.18503606e-02,  -5.62922005e-03,
                          1.41665936e-02,   2.42533963e-02,   2.13436559e-02,
                         -2.09981743e-02,   2.29753833e-02,  -7.72995710e-01,
                         -7.47371852e-01,  -7.41005599e-01,  -7.49191999e-01,
                         -7.62940943e-01,  -7.30401039e-01,  -7.57858753e-01,
                         -7.35598147e-01,  -7.64492929e-01,  -7.69245028e-01,
                         -7.63605237e-01,  -7.55276382e-01,  -7.41944909e-01,
                         -7.67143250e-01,  -7.65149534e-01,  -7.69195557e-01,
                         -7.57454216e-01,  -7.44737804e-01,  -7.53075957e-01,
                         -7.43050277e-01,  -7.42300928e-01,  -7.73101628e-01,
                         -7.59551108e-01,  -7.82289684e-01,  -7.62157619e-01,
                         -7.65480995e-01,  -7.42137671e-01,  -7.44221628e-01,
                         -7.58091450e-01,  -7.74814069e-01,  -7.29815185e-01,
                         -8.10799599e-01,  -7.49259889e-01,  -7.53441036e-01,
                         -7.47940183e-01,  -7.63248146e-01,  -7.62908697e-01,
                         -7.62753069e-01,  -7.53020704e-01,  -7.37874389e-01,
                         -7.37858474e-01,  -7.52064586e-01,  -7.66464233e-01,
                         -7.66565919e-01,  -7.80001223e-01,  -7.63622224e-01,
                         -7.64026463e-01,  -7.32328713e-01,  -7.56576180e-01,
                         -7.68317521e-01,  -7.56789625e-01,  -7.37774014e-01,
                         -7.45403230e-01,  -7.42751598e-01,  -7.56690443e-01,
                         -7.76576519e-01,  -5.96524915e-03,  -2.27763690e-03,
                         -8.10296088e-03,  -2.50826776e-03,  -7.50325739e-01,
                         -7.46570289e-01,  -7.65303910e-01,  -7.45824635e-01,
                         -7.65664518e-01,  -7.47873425e-01,  -7.68202782e-01,
                         -7.67874658e-01,  -7.55466044e-01,  -7.43835032e-01,
                         -7.78979480e-01,  -7.47674286e-01,  -7.73523748e-01,
                         -7.77988315e-01,  -7.54780710e-01,  -7.66469061e-01,
                         -7.56698072e-01,  -7.53373563e-01,  -7.46524334e-01,
                         -7.64334977e-01,  -7.47964978e-01,  -7.64729142e-01,
                         -7.51111150e-01,  -7.52493739e-01,  -7.50276387e-01,
                         -7.28965700e-01,  -7.79253423e-01,  -7.41012633e-01,
                         -7.78095901e-01,  -7.65793324e-01,  -7.65904009e-01,
                         -7.54507005e-01,  -7.37654984e-01,  -7.70999134e-01,
                         -7.50008523e-01,  -7.65199542e-01,  -7.80216694e-01,
                         -7.78984427e-01,  -7.52603114e-01,  -7.97606528e-01,
                          9.82190762e-03,   1.43325226e-02,  -8.87973700e-03,
                          2.14481596e-02,  -2.54015401e-02,   8.51749719e-05,
                          1.66411530e-02,   1.94503181e-03,  -7.43328094e-01,
                         -7.54157126e-01,  -7.49613881e-01,  -7.64100611e-01,
                         -7.34233856e-01,  -7.83097386e-01,  -7.81182408e-01,
                         -7.51055121e-01,  -7.58006692e-01,  -7.33418286e-01,
                         -7.66583323e-01,  -7.45043039e-01,  -7.74470150e-01,
                         -7.83130884e-01,  -7.37999141e-01,  -7.77109146e-01,
                         -7.53798068e-01,  -7.76561558e-01,  -7.68131077e-01,
                         -7.67758131e-01,  -7.70731628e-01,  -7.46106565e-01,
                         -7.52767801e-01,  -7.53272295e-01,  -7.39471495e-01,
                         -7.49812067e-01,  -7.50082970e-01,  -7.34880388e-01,
                         -7.80196071e-01,  -7.51436472e-01,  -7.81069875e-01,
                         -7.50702918e-01,  -7.61958241e-01,  -7.83413708e-01,
                         -7.45240331e-01,  -7.60176659e-01,   2.62153521e-02,
                          3.10046319e-02,   1.76339913e-02,  -1.30042565e-04,
                         -7.60795832e-01,  -7.83139110e-01,  -7.55059183e-01,
                         -7.83104897e-01,  -7.40380645e-01,  -7.61451185e-01,
                         -7.70444214e-01,  -7.71822810e-01,  -7.32775509e-01,
                         -7.68312216e-01,  -7.50928283e-01,  -7.43701458e-01,
                         -7.60077953e-01,  -7.64115214e-01,  -7.56440520e-01,
                         -7.71787465e-01,  -7.27588356e-01,  -7.75960028e-01,
                         -7.46051073e-01,  -7.42961466e-01,  -7.71646142e-01,
                         -7.51846790e-01,  -7.52000630e-01,  -7.73757994e-01,
                         -7.36688256e-01,  -7.59896219e-01,  -7.45720088e-01,
                         -7.14676857e-01,  -7.89889872e-01,  -7.16964304e-01,
                         -7.70838439e-01,  -7.51396954e-01,  -7.66192973e-01,
                         -7.81250596e-01,  -7.31126249e-01,  -7.79600859e-01,
                         -7.34485149e-01,  -7.68126190e-01,  -7.67692506e-01,
                         -7.46574938e-01,  -7.43238807e-01,  -7.13028073e-01,
                         -7.60133803e-01,  -7.31133223e-01,  -7.43034542e-01,
                         -7.61950672e-01,  -7.53882945e-01,  -7.55519688e-01,
                         -7.62823522e-01,  -7.47622252e-01,  -7.51392066e-01,
                         -7.60283589e-01,  -9.18012023e-01,  -9.16227579e-01,
                         -9.43719208e-01,  -9.08614099e-01,  -9.16815341e-01,
                         -9.43190157e-01,  -9.23598647e-01,  -9.14591730e-01,
                         -9.16191518e-01,  -9.27184045e-01,  -8.99436533e-01,
                         -9.49528456e-01,  -7.33218372e-01,  -7.47008145e-01,
                         -7.43698359e-01,  -7.73594022e-01,  -7.52320707e-01,
                         -7.54882514e-01,  -7.64946401e-01,  -7.42845058e-01,
                         -7.50471830e-01,  -7.49117017e-01,  -7.83575654e-01,
                         -7.59007156e-01,  -7.63094127e-01,  -7.76346564e-01,
                         -7.35289037e-01,  -7.50179887e-01,  -7.58280516e-01,
                         -7.55492151e-01,  -7.55670547e-01,  -7.30168164e-01,
                         -7.62500346e-01,  -7.29988813e-01,  -7.37593710e-01,
                         -7.41255403e-01,  -9.40069258e-01,  -9.46890533e-01,
                         -9.44308519e-01,  -9.29096341e-01,  -8.96993577e-01,
                         -9.37083244e-01,  -9.25827861e-01,  -9.47439194e-01,
                         -9.45891917e-01,  -9.42960024e-01,  -9.30414438e-01,
                         -9.19868946e-01,  -7.64204323e-01,  -7.48082459e-01,
                         -7.64206529e-01,  -7.76100278e-01,  -9.26688254e-01,
                         -9.28546607e-01,  -9.19997215e-01,  -9.33444500e-01,
                         -9.33715761e-01,  -9.27411497e-01,  -9.27959383e-01,
                         -9.35269833e-01,  -9.19092119e-01,  -9.31200862e-01,
                         -9.40674663e-01,  -9.33162749e-01,  -9.49899435e-01,
                         -9.23597157e-01,  -9.13100123e-01,  -9.52772975e-01,
                         -9.15040553e-01,  -9.47676957e-01,  -9.10120070e-01,
                         -9.36306059e-01,  -9.38094020e-01,  -9.04997587e-01,
                         -9.57073271e-01,  -9.20280278e-01,  -7.53368556e-01,
                         -7.66205430e-01,  -7.44952798e-01,  -7.55830348e-01,
                         -7.59744465e-01,  -7.32957006e-01,  -7.74047673e-01,
                         -7.58241415e-01,  -7.66867220e-01,  -7.84358323e-01,
                         -7.42377937e-01,  -7.56806552e-01,  -7.53718257e-01,
                         -7.58594275e-01,  -7.87923872e-01,  -7.46728420e-01,
                         -7.67013729e-01,  -7.65832603e-01,  -7.49746799e-01,
                         -7.71775961e-01,  -9.25716400e-01,  -9.21026170e-01,
                         -9.29250538e-01,  -9.46005642e-01,  -9.36940789e-01,
                         -9.35791552e-01,  -9.31395531e-01,  -9.40020800e-01,
                         -9.13860261e-01,  -9.53913033e-01,  -9.25877929e-01,
                         -9.38784301e-01,  -9.30959225e-01,  -9.29085314e-01,
                         -9.26553130e-01,  -9.50997591e-01,  -7.53919959e-01,
                         -7.86857426e-01,  -7.59176612e-01,  -7.54778624e-01,
                         -7.66548693e-01,  -7.90279150e-01,  -7.45856285e-01,
                         -7.79459953e-01,  -1.59717980e-03,  -2.06609955e-04,
                          2.14363653e-02,   6.24253554e-03,   4.19822522e-03,
                         -3.71960970e-03,   9.76821780e-03,  -1.66112538e-02,
                          6.84871944e-03,   7.06744380e-03,   2.43485589e-02,
                         -6.50246814e-03,  -7.40442753e-01,  -7.85396993e-01,
                         -7.57962465e-01,  -7.42767453e-01,  -8.93859752e-03,
                          1.65400226e-02,  -2.12309118e-02,   2.73703423e-04,
                         -1.60896145e-02,  -1.29879010e-03,  -7.58907618e-03,
                         -2.27259868e-03,   1.55920327e-01,   1.78611338e-01,
                          1.79192707e-01,   1.71680942e-01,  -1.54368998e-02,
                          4.79259965e-04,  -1.15694506e-02,   1.95187498e-02,
                          1.87435210e-01,   1.59845993e-01,   1.90472946e-01,
                          1.53408989e-01,   2.19190139e-02,   8.28026852e-04,
                         -1.67858116e-02,   2.60214042e-02,  -1.58658586e-02,
                         -7.64162978e-03,   7.28925876e-03,   6.63885893e-03,
                         -1.09689496e-02,   3.02745607e-02,  -1.37225129e-02,
                          6.47139922e-03,   1.83615476e-01,   1.56913415e-01,
                          1.81867898e-01,   1.86234519e-01,   1.52914941e-01,
                          2.10388198e-01,   1.81699187e-01,   1.84697047e-01,
                          1.93591639e-01,   1.44415215e-01,   1.98270202e-01,
                          1.62897602e-01,   1.64388746e-01,   1.81307286e-01,
                          1.70729324e-01,   1.72235966e-01,   1.86701968e-01,
                          1.72052160e-01,   2.01486781e-01,   1.74216539e-01,
                          1.72361538e-01,   1.77724361e-01,   1.68289065e-01,
                          1.87761322e-01,   1.60046339e-01,   1.78876743e-01,
                          1.53168470e-01,   1.57547012e-01,   1.60401627e-01,
                          1.61760911e-01,   1.51555941e-01,   1.54642701e-01,
                          1.71812996e-01,   1.54220209e-01,   1.72335714e-01,
                          1.51927069e-01,   1.65049478e-01,   1.56248331e-01,
                          1.64722711e-01,   1.89300314e-01,   1.64403811e-01,
                          1.82548642e-01,   1.80336908e-01,   1.79726481e-01,
                          1.63649902e-01,   1.69146389e-01,   1.46223068e-01,
                          1.75374985e-01,   1.63256466e-01,   1.79796875e-01,
                          1.67116344e-01,   1.49248645e-01,   1.52930081e-01,
                          1.52893901e-01,   1.64725408e-01,   1.52925909e-01,
                          1.62186041e-01,   1.91293284e-01,   1.92260638e-01,
                          1.78378880e-01,  -9.97794699e-03,  -8.42526741e-03,
                         -5.67904301e-03,  -2.90067904e-02,  -1.79122407e-02,
                          1.55110555e-02,   6.78974102e-05,   4.20688139e-03,
                         -1.71975128e-03,  -2.62310840e-02,  -1.13438722e-02,
                          1.03519124e-03,  -1.27213225e-02,   1.03182588e-02,
                          1.05622374e-02,   4.03367588e-03,  -1.26248226e-02,
                         -1.51038095e-02,  -1.93647761e-02,  -8.54385365e-03,
                         -1.56048657e-02,  -9.93567798e-03,   1.21717737e-03,
                          1.68987345e-02,  -7.65305804e-03,   2.15314576e-04,
                         -1.43844243e-02,   8.77807476e-03,  -7.25103775e-03,
                          3.01860389e-03,   1.64809339e-02,   1.40083032e-02,
                          1.06172441e-02,  -5.61228208e-03,  -9.15888045e-03,
                          8.74354690e-03,   6.42281678e-03,   1.45415785e-02,
                         -5.12824021e-03,  -5.35970274e-03,  -1.32917380e-02,
                          1.17550476e-03,  -1.67286769e-02,  -2.37512253e-02,
                          1.23040481e-02,  -3.97966010e-03,  -7.89855421e-03,
                         -1.13278627e-02,  -3.07240896e-02,  -1.28808124e-02,
                          3.05011659e-03,  -1.50201591e-02,   3.73582705e-03,
                         -5.56625053e-03,  -9.60792415e-03,   3.90516110e-02,
                         -2.06219275e-02,   2.34728642e-02,   9.11404099e-03,
                          5.21466974e-03,   1.93185229e-02,  -8.29887018e-03,
                          2.18209415e-03,   2.25907452e-02,  -1.37957814e-03,
                          1.17499810e-02,   6.32268563e-03,  -7.80116813e-03,
                          3.03088455e-03,   4.97161271e-03,  -1.36617403e-02,
                         -1.15462542e-02,  -6.81995787e-03,   1.31838936e-02,
                          6.67942967e-03,  -1.42572997e-02,   2.18706671e-02,
                         -1.64039377e-02,  -1.01170614e-02,  -1.34722823e-02,
                          2.57328921e-03,  -3.06123984e-04,   1.05219996e-02,
                         -7.96630606e-03,   1.71400458e-02,   3.81840300e-03,
                          8.78840126e-03,  -2.00147321e-03,  -4.18003974e-03,
                          1.73008870e-02,  -9.41204131e-01,  -9.00948584e-01,
                         -9.67297375e-01,  -9.12843525e-01,  -9.32089508e-01,
                         -9.06845987e-01,  -9.33495402e-01,  -9.33116853e-01,
                         -9.29579318e-01,  -9.22667623e-01,  -9.16596055e-01,
                         -9.40551937e-01,   1.91408880e-02,  -2.91559137e-02,
                          5.30622061e-03,   1.41320247e-02,  -2.50782296e-02,
                         -1.32603366e-02,  -5.30474447e-03,   1.10757267e-02,
                          1.52743189e-03,  -8.14710092e-03,  -4.53634001e-03,
                          1.15267104e-02,  -9.42925990e-01,  -8.98561418e-01,
                         -9.45953310e-01,  -8.99761438e-01,  -9.28664029e-01,
                         -9.25534010e-01,  -9.20881450e-01,  -9.09165144e-01,
                         -9.13738847e-01,  -9.00512636e-01,  -9.09904063e-01,
                         -9.01195884e-01,  -9.29826975e-01,  -9.23164725e-01,
                         -9.34933603e-01,  -9.24310505e-01,  -9.33036029e-01,
                         -9.33760107e-01,  -9.44427967e-01,  -9.21077907e-01,
                         -9.30229664e-01,  -9.51332331e-01,  -9.32142258e-01,
                         -9.40824032e-01,  -9.33915138e-01,  -9.42648232e-01,
                         -9.24011350e-01,  -9.25286651e-01,  -9.33781624e-01,
                         -9.19888914e-01,  -9.19831932e-01,  -9.18623269e-01,
                         -9.31247950e-01,  -9.15681362e-01,  -9.08390224e-01,
                         -9.13518667e-01,  -9.34420884e-01,  -9.10705984e-01,
                         -9.41141844e-01,  -9.26402390e-01,  -9.25110698e-01,
                         -9.42061961e-01,  -9.12708223e-01,  -9.27205086e-01,
                         -9.43563044e-01,  -9.17377412e-01,  -9.48531091e-01,
                         -9.16535497e-01,  -9.28914189e-01,  -9.01539028e-01,
                         -9.29373860e-01,  -9.16204631e-01,  -9.09434199e-01,
                         -9.40310836e-01,  -9.49704945e-01,  -9.36132312e-01,
                         -9.04582381e-01,  -9.34424520e-01,  -9.42868114e-01,
                         -9.39393938e-01,  -9.37979341e-01,  -9.56766486e-01,
                         -9.18375373e-01,  -9.19238806e-01,  -9.01662707e-01,
                         -9.36937690e-01,  -9.18126285e-01,  -9.24889863e-01,
                         -9.31578398e-01,  -9.24904585e-01,  -9.16536629e-01,
                         -9.35802996e-01,  -9.34386492e-01,  -9.15936768e-01,
                         -9.23676252e-01,  -9.25355971e-01,  -9.39207852e-01,
                         -9.23263490e-01,  -9.35773134e-01,  -9.12868321e-01,
                         -9.32295084e-01,  -9.24255133e-01,  -9.34191883e-01,
                         -9.16460812e-01,  -8.98523092e-01,  -9.28107560e-01,
                         -9.05248523e-01,  -9.38277662e-01,  -9.30258095e-01,
                         -9.30901527e-01,  -9.33619082e-01,  -9.22849536e-01,
                         -9.16261435e-01,  -9.07066345e-01,  -9.35340881e-01,
                         -9.40236688e-01,  -9.39867556e-01,  -9.35136199e-01,
                         -9.31693256e-01,  -9.24818933e-01,  -9.16162312e-01,
                         -9.09634411e-01,  -9.36830580e-01,  -9.31981027e-01,
                         -9.24438894e-01,  -9.32032824e-01,  -9.22484815e-01,
                         -9.29914057e-01,  -9.35603261e-01,  -9.00573790e-01,
                         -9.36162353e-01,  -9.23879504e-01,  -9.26000178e-01,
                         -9.43036318e-01,  -9.55030084e-01,  -9.12463129e-01,
                         -9.30909216e-01,  -9.26273465e-01,  -9.30816472e-01,
                         -9.40101147e-01,  -9.34444189e-01,  -9.32300925e-01,
                         -9.25397933e-01,  -9.30987477e-01,  -9.50755537e-01,
                         -9.21988606e-01,  -9.22131002e-01,  -9.46696579e-01,
                         -9.17965353e-01,  -9.46057022e-01,  -9.24837291e-01,
                         -9.41516876e-01,  -9.19659197e-01,  -9.36924279e-01,
                         -9.28437769e-01,  -9.45736349e-01,  -9.17765498e-01,
                         -9.39109862e-01,  -9.39921319e-01,  -9.29415107e-01,
                         -9.37667966e-01,  -9.31919277e-01,  -9.19999063e-01,
                         -9.32552993e-01,  -9.44447279e-01,  -9.11133528e-01,
                         -9.40628350e-01,  -9.33055758e-01,  -9.34444845e-01,
                         -9.44675148e-01,  -9.33333158e-01,  -9.40213263e-01,
                         -9.20980811e-01,  -9.36012566e-01,  -9.36829448e-01,
                         -9.13679600e-01,  -9.48581696e-01,  -9.34293687e-01,
                         -9.38049853e-01,  -9.28678393e-01,  -9.42632616e-01,
                         -9.59083915e-01,  -9.18042660e-01,  -9.38412130e-01,
                         -9.40041065e-01,  -9.32047546e-01,  -9.25518930e-01,
                         -9.36808288e-01,  -9.16776776e-01,  -9.35192347e-01,
                         -9.20168877e-01,  -9.36811030e-01,  -9.34843242e-01,
                         -9.32950318e-01,  -9.33169723e-01,  -9.40805197e-01,
                         -9.41497207e-01,  -9.25263762e-01,  -9.37138021e-01,
                         -9.46377814e-01,  -9.32146370e-01,  -9.50984359e-01,
                         -9.41491663e-01,  -9.53411222e-01,  -9.20093417e-01,
                         -9.32519495e-01,  -9.17119324e-01,  -9.36521649e-01,
                         -9.31532800e-01,  -9.45611894e-01,  -9.24006760e-01,
                         -9.33132470e-01,  -9.39863622e-01,  -9.32558179e-01,
                         -9.30383146e-01,  -9.21097755e-01,  -9.35693622e-01,
                         -9.17415619e-01,  -9.35458243e-01,  -9.29527104e-01,
                         -9.32302296e-01,  -9.30834889e-01,  -9.19008851e-01,
                         -9.33394730e-01,  -9.43614960e-01,  -9.37986970e-01,
                         -9.32404160e-01,  -9.38315749e-01,  -9.35635746e-01,
                         -9.34953272e-01,  -9.29389715e-01,  -9.46118891e-01,
                         -9.30111825e-01,  -9.43928659e-01,  -9.37711239e-01,
                         -9.47391331e-01,  -9.27545965e-01,  -9.53723729e-01,
                         -9.09720540e-01,  -9.28907633e-01,  -9.26843226e-01,
                         -9.50835347e-01,  -9.21438575e-01,  -9.32525396e-01,
                         -9.31912482e-01,  -9.40414727e-01,  -9.51112032e-01,
                         -9.29189086e-01,  -9.29319024e-01,  -9.26183760e-01,
                         -9.15034056e-01,  -9.45925474e-01,  -9.27605629e-01,
                         -9.44960237e-01,  -9.26082551e-01,  -9.22253072e-01,
                         -9.38755691e-01,  -9.34520900e-01,  -9.42161798e-01,
                         -9.45986688e-01,  -9.25836265e-01,  -9.16390538e-01,
                         -9.42472279e-01,  -9.18138027e-01,  -9.43479121e-01,
                         -9.24997091e-01,  -9.27254796e-01,  -9.38378334e-01,
                         -9.31491673e-01,  -9.23316121e-01,  -9.47315335e-01,
                         -9.21581686e-01,  -2.29294561e-02,  -1.07260309e-02,
                         -1.62751488e-02,  -7.98201095e-03,   5.42278343e-04,
                         -9.63236112e-03,   8.01858306e-03,   7.41555880e-07,
                         -5.32961078e-03,  -1.24057801e-02,  -1.43586984e-02,
                          1.60489678e-02,  -7.30587123e-03,   1.29826344e-03,
                         -1.39679816e-02,  -4.63255541e-03,  -1.98628171e-03,
                          4.39041294e-03,  -2.72753276e-03,   2.85359728e-03,
                         -1.28061371e-02,  -4.11713915e-03,  -1.75821446e-02,
                          1.14698605e-05,  -2.58077886e-02,   1.13784131e-02,
                         -1.64025519e-02,  -2.35595088e-03,  -4.87579918e-03,
                         -2.55269669e-02,   4.00899677e-03,  -1.46295885e-02,
                         -7.49256322e-03,  -2.23987512e-02,  -1.64959189e-02,
                         -5.78744197e-03,  -2.09294036e-02,  -1.74930263e-02,
                         -1.64605733e-02,  -2.40149628e-02,   1.21150687e-02,
                         -1.45849977e-02,  -2.82661011e-03,  -1.19042043e-02,
                         -2.96662636e-02,  -2.46540718e-02,  -1.58705860e-02,
                         -2.62848437e-02,  -9.04357195e-01,  -9.36276793e-01,
                         -9.38549399e-01,  -9.39630449e-01,  -9.31333482e-01,
                         -9.43890393e-01,  -9.49663043e-01,  -9.26663101e-01,
                         -9.46097732e-01,  -9.22674119e-01,  -9.39510167e-01,
                         -9.19413507e-01,  -9.19391870e-01,  -9.37757909e-01,
                         -9.31078613e-01,  -9.28772092e-01,  -9.12846863e-01,
                         -9.32845056e-01,  -9.28205371e-01,  -9.37526941e-01,
                         -9.15672064e-01,  -9.36679184e-01,  -9.31963861e-01,
                         -9.27166760e-01,  -9.42392230e-01,  -9.41907644e-01,
                         -9.31954622e-01,  -9.51624990e-01,  -9.18451071e-01,
                         -9.32629585e-01,  -9.42497075e-01,  -9.27228212e-01,
                         -9.49397802e-01,  -9.22121286e-01,  -9.24712181e-01,
                         -9.24087226e-01,  -9.38594222e-01,  -9.44815516e-01,
                         -9.40647960e-01,  -8.99335384e-01,  -9.31870699e-01,
                         -9.62707460e-01,  -9.41079736e-01,  -9.42647159e-01,
                         -9.24311757e-01,  -9.54808772e-01,  -9.26908076e-01,
                         -9.37957704e-01,  -9.36803818e-01,  -9.39897239e-01,
                         -9.07153547e-01,  -9.35107708e-01,  -9.47952390e-01,
                         -9.27325308e-01,  -9.30275500e-01,  -9.24542308e-01,
                         -9.21998084e-01,  -9.27105367e-01,  -9.32288826e-01,
                         -9.47827458e-01,  -9.25301015e-01,  -9.37905490e-01,
                         -9.19631183e-01,  -9.37199712e-01,  -9.39284682e-01,
                         -9.03261185e-01,  -9.39317226e-01,  -9.37132180e-01,
                         -9.54455137e-01,  -9.60438907e-01,  -9.55719233e-01,
                         -9.37007964e-01,  -9.34025347e-01,  -9.27394092e-01,
                         -9.23742056e-01,  -9.32617962e-01,  -9.45220470e-01,
                         -9.32933211e-01,  -9.61170554e-01,  -9.42708015e-01,
                         -9.33864117e-01,  -9.51144159e-01,  -9.27388787e-01,
                         -9.37018931e-01,  -9.22053039e-01,  -9.18824077e-01,
                         -9.28041399e-01,  -9.23506081e-01,  -9.20079350e-01,
                         -9.18968856e-01,  -9.01470423e-01,  -9.13797617e-01,
                         -9.16721165e-01,  -9.31508780e-01,  -9.22744691e-01,
                         -9.12869513e-01,  -9.36616242e-01,  -9.28878069e-01,
                         -9.31479514e-01,  -9.49062467e-01,  -9.36686397e-01,
                         -9.40670788e-01,  -9.31459308e-01,  -9.23137724e-01,
                         -9.22609031e-01,  -9.29753900e-01,  -9.38863754e-01,
                         -9.18040097e-01,  -9.34960544e-01,  -9.18188751e-01,
                         -9.14779246e-01,  -9.42881644e-01,  -9.12692785e-01,
                         -9.27841425e-01,  -9.21320200e-01,  -9.29981291e-01,
                         -9.19496357e-01,  -9.16860223e-01,  -9.12428200e-01,
                         -9.22691464e-01,  -9.20307279e-01,  -9.05423999e-01,
                         -9.19593215e-01,  -9.08938408e-01,  -9.34975207e-01,
                         -9.22729492e-01,  -9.15892780e-01,  -9.06582594e-01,
                         -9.27317441e-01,  -9.21794355e-01,  -9.31658924e-01,
                         -9.40109134e-01,  -9.20184433e-01,  -9.32338119e-01,
                         -9.42012310e-01,  -9.41619754e-01,  -9.56049025e-01,
                         -9.28532481e-01,  -9.37468827e-01,  -9.55699503e-01,
                         -9.35267031e-01,  -9.41037357e-01,  -9.32417691e-01,
                         -9.50028896e-01,  -9.32950735e-01,  -9.43378448e-01,
                         -9.35929954e-01,  -9.50948656e-01,  -9.42003191e-01,
                         -9.28094804e-01,  -9.43305492e-01,  -9.34662044e-01,
                         -9.29741979e-01,  -9.30418611e-01,  -9.26368356e-01,
                         -9.24381614e-01,  -9.36314702e-01,  -9.37165201e-01,
                         -9.42271233e-01,  -9.33621705e-01,  -9.39797699e-01,
                         -9.32157099e-01,  -9.34397817e-01,  -9.32669103e-01,
                         -9.37011957e-01,  -9.34260070e-01,  -9.33168054e-01,
                         -9.44199741e-01,  -9.27891850e-01,  -9.43650782e-01,
                         -9.36044574e-01,  -9.22116756e-01,  -9.34473872e-01,
                         -9.13931727e-01,  -9.24760818e-01,  -9.13117349e-01,
                         -9.18307483e-01,  -9.27876770e-01,  -9.20277119e-01,
                         -9.21211243e-01,  -9.28580105e-01,  -9.39052761e-01,
                         -9.30311501e-01,  -9.42826331e-01,  -9.40602064e-01,
                         -9.27197814e-01,  -9.24243152e-01,  -9.30593193e-01,
                         -9.24278080e-01,  -9.27986860e-01,  -9.17054772e-01,
                         -9.34845924e-01,  -9.30888593e-01,  -9.37639594e-01,
                         -9.32818651e-01,  -9.21243608e-01,  -9.30343330e-01,
                         -9.36894417e-01,  -9.39477623e-01,  -9.37650025e-01,
                         -9.35413659e-01,  -9.26476717e-01,  -9.35665667e-01,
                         -9.40611124e-01,  -9.35093760e-01,  -9.25617456e-01,
                         -9.39871848e-01,  -9.20290709e-01,  -9.33558702e-01,
                         -9.25269067e-01,  -9.28986132e-01,  -9.22259688e-01,
                         -9.26858306e-01,  -9.36927259e-01,  -9.29482162e-01,
                         -9.28896368e-01,  -9.25248921e-01,  -9.31335807e-01,
                         -9.09113288e-01,  -9.20285225e-01,  -9.25742090e-01,
                         -9.24729943e-01,  -9.36168015e-01,  -9.29110765e-01,
                         -9.20252621e-01,  -9.27980483e-01,  -9.17635918e-01,
                         -9.24542546e-01,  -9.28226948e-01,  -9.29509282e-01,
                         -9.25991476e-01,  -9.33637023e-01,  -9.25987184e-01,
                         -9.28591430e-01,  -9.24879193e-01,  -9.36642408e-01,
                         -9.28063512e-01,  -9.16251719e-01,  -9.39760327e-01,
                         -9.22269702e-01,  -9.29886043e-01,  -9.32439446e-01,
                         -9.42920923e-01,  -9.24547255e-01,  -9.33866858e-01,
                         -9.31386113e-01,  -9.35938835e-01,  -9.40512240e-01,
                         -9.43623722e-01,  -9.38958168e-01,  -9.23071206e-01,
                         -9.44413900e-01,  -9.36780572e-01,  -9.34955478e-01,
                         -9.24822032e-01,  -9.31525528e-01,  -9.22322035e-01,
                         -9.37638819e-01,  -9.29352164e-01,  -9.24738169e-01,
                         -9.28625226e-01,  -9.18067157e-01,  -9.25640225e-01,
                         -9.21490490e-01,  -9.18177307e-01,  -9.37436342e-01,
                         -9.31271791e-01,  -9.26788986e-01,  -9.34772193e-01,
                         -9.42224443e-01,  -9.43047881e-01,  -9.35034394e-01,
                         -9.45106387e-01,  -9.39237893e-01,  -9.37182426e-01,
                         -9.30034459e-01,  -9.29302990e-01,  -9.26391423e-01,
                         -9.36126292e-01,  -9.25851822e-01,  -9.22646403e-01,
                         -9.33824062e-01,  -9.32366669e-01,  -9.37650681e-01,
                         -9.41433787e-01,  -9.40327823e-01,  -9.37953949e-01,
                         -9.32420015e-01,  -9.36987102e-01,  -9.22248721e-01,
                         -9.28320706e-01,  -9.31094468e-01,  -9.25142050e-01,
                         -9.32386518e-01,  -9.20657754e-01,  -9.22644556e-01,
                         -9.24369693e-01,  -9.30006802e-01,  -9.28046107e-01,
                         -9.37071860e-01,  -9.02816772e-01,  -9.38136816e-01,
                         -9.31778669e-01,  -9.23407376e-01,  -9.30947781e-01,
                         -9.23440695e-01,  -9.19446051e-01,  -9.54628706e-01,
                         -9.28270400e-01,  -9.36467767e-01,  -9.41466868e-01,
                         -9.06133533e-01,  -9.49948132e-01,  -9.17219937e-01,
                         -9.43913102e-01,  -9.22909021e-01,  -9.33251917e-01,
                         -9.19391930e-01,  -9.15814281e-01,  -9.17316198e-01,
                         -9.22020912e-01,  -9.32519734e-01,  -9.30885553e-01,
                         -9.17911351e-01,  -9.29079890e-01,  -9.22159791e-01,
                         -9.35775578e-01,  -9.25114095e-01,  -9.25726116e-01,
                         -9.36426699e-01,  -9.35088992e-01,  -9.30745006e-01,
                         -9.32777286e-01,  -9.25567448e-01,  -9.35580313e-01,
                         -9.16061223e-01,  -9.44592774e-01,  -9.25707459e-01,
                         -9.39691424e-01,  -9.24230814e-01,  -9.44110632e-01,
                         -9.29176509e-01,  -9.30959761e-01,  -9.11533117e-01,
                         -9.35375631e-01,  -9.19888854e-01,  -9.20592487e-01,
                         -9.33975339e-01,  -9.31982696e-01,  -9.27798927e-01,
                         -9.36798394e-01,  -9.22456086e-01,  -9.39436078e-01,
                         -9.18603718e-01,  -9.27797139e-01,  -9.30245221e-01,
                         -9.25840139e-01,  -9.14108515e-01,  -9.24262822e-01,
                         -9.26686049e-01,  -9.26102161e-01,  -9.28729594e-01,
                         -9.32408392e-01,  -9.27820683e-01,  -9.15174842e-01,
                         -9.19423103e-01,  -9.27900195e-01,  -9.27073479e-01,
                         -9.39814091e-01,  -9.29683924e-01,  -9.45196986e-01,
                         -9.17214870e-01,  -9.39241707e-01,  -9.17809486e-01,
                         -9.41247404e-01,  -9.33150232e-01,  -9.46260810e-01,
                         -9.40477610e-01,  -9.14068460e-01,  -9.37989771e-01,
                         -9.34478998e-01,  -9.29005325e-01,  -9.30647731e-01,
                         -9.33723867e-01,  -9.33681607e-01,  -9.32146490e-01,
                         -9.22455370e-01,  -9.33152914e-01,  -9.36542392e-01,
                         -9.26798642e-01,  -9.36099589e-01,  -9.17320669e-01,
                         -9.31841195e-01,  -9.22695339e-01,  -9.20662820e-01,
                         -9.26385581e-01,  -9.45001900e-01,  -9.34965909e-01,
                         -9.42837954e-01,  -9.37898397e-01,  -9.55043495e-01,
                         -9.26620126e-01,  -9.38913226e-01,  -9.28373098e-01,
                         -9.40116346e-01,  -9.32973683e-01,  -9.26131487e-01,
                         -9.39432740e-01,  -9.39783692e-01,  -9.37141716e-01,
                         -9.39191461e-01,  -9.38266754e-01,  -9.38880086e-01,
                         -9.24120903e-01,  -9.34850037e-01,  -9.19460952e-01,
                         -9.23845291e-01,  -9.25110579e-01,  -9.42104578e-01,
                         -9.20996785e-01,  -9.33858454e-01,  -9.17034566e-01,
                         -9.24946368e-01,  -9.35188234e-01,  -9.19980466e-01,
                         -9.05450046e-01,  -9.42217231e-01,  -8.89031172e-01,
                         -1.53033296e-02,   1.25061320e-02,   1.03444206e-02,
                          2.83985422e-03,   3.98503849e-03,  -2.32135411e-03,
                          7.36087793e-04,   1.28504848e-02,   9.91589855e-03,
                          9.16502811e-03,   7.63668120e-03,  -1.24666495e-02,
                          2.62503861e-04,   3.16866150e-04,   1.97651051e-02,
                         -6.12841919e-03,  -2.38038762e-03,   5.15647465e-03,
                         -3.71871586e-03,  -7.23356614e-03,  -4.36050817e-03,
                          1.80225805e-04,   6.64584478e-03,   7.04179425e-03,
                          1.76488224e-03,   4.73346934e-03,   6.26538531e-04,
                          1.77597790e-03,   1.65171605e-02,  -2.46657431e-03,
                          1.15661928e-03,   8.02551955e-03,   9.50738415e-03,
                          7.25018512e-03,  -8.08358309e-04,   7.51088001e-03,
                          1.26978627e-03,   1.61414538e-02,   1.03177940e-02,
                          5.69961267e-03,  -2.90493784e-03,  -6.47177338e-04,
                         -9.74321272e-03,  -3.46152065e-03,   2.26708202e-04,
                         -4.73712152e-03,   1.94971683e-03,   1.53852059e-02,
                         -5.20405918e-03,   6.90820999e-03,  -1.77997258e-02,
                          7.52249546e-03,  -4.58325911e-03,   1.83430442e-03,
                          2.56439741e-03,  -8.51728953e-03,  -1.60439163e-02,
                         -1.23101054e-03,  -7.30673736e-03,  -1.27982982e-02,
                         -3.33022373e-03,  -1.00740719e-04,  -3.10658570e-03,
                         -2.80751684e-03,  -9.18746181e-03,  -6.74662692e-03,
                         -1.80518683e-02,  -7.10994797e-03,  -6.48548873e-03,
                         -8.25698208e-03,   1.47955655e-03,   2.05368716e-02,
                          3.15940240e-03,  -1.42797679e-02,  -4.29555634e-03,
                         -1.46343559e-02,   4.66001360e-03,  -1.79226585e-02,
                         -1.52053749e-02,   7.75357010e-03,  -7.57109188e-03,
                         -1.28485514e-02,   2.63319584e-03,  -3.92075162e-04,
                          9.13533848e-03,  -1.74481999e-02,   7.69290095e-03,
                         -1.87631100e-02,  -3.82064166e-03,   9.99408029e-03,
                         -1.13494089e-03,  -1.70276072e-02,   2.38587637e-03,
                         -2.40949951e-02,   2.94527295e-03,  -3.32539319e-03,
                          4.22591902e-03,   1.41233823e-03,  -1.29378848e-02,
                         -1.20236771e-02,  -4.74881986e-03,  -1.20678870e-02,
                         -7.12359417e-03,  -9.32635460e-03,  -1.83429606e-02,
                         -1.19201858e-02,  -2.56523732e-02,  -1.57392193e-02,
                         -1.91110261e-02,  -9.83592868e-03,  -1.33978017e-02,
                         -1.79691128e-02,  -9.50740557e-03,  -1.54985115e-02,
                          6.44231914e-04,  -1.32807605e-02,   1.82757492e-03,
                         -2.68924213e-03,  -5.39975381e-03,   4.99382475e-03,
                         -1.49741210e-02,  -4.03692620e-03,  -8.83086398e-03,
                         -7.17148324e-03,  -1.11816237e-02,  -5.43677621e-03,
                         -1.08299116e-02,  -6.93837833e-03,  -1.00721521e-02,
                         -1.48452073e-02,  -8.52609146e-03,  -1.88925155e-02,
                         -5.63328154e-03,   3.35046742e-03,  -1.98149905e-02,
                          5.41931833e-04,  -7.30647426e-03,  -3.06864153e-03,
                         -5.05458377e-03,  -3.80339869e-03,  -4.00745135e-04,
                         -4.65983339e-03,  -2.58358778e-03,  -1.97208812e-03,
                         -5.44391433e-03,  -5.96052920e-03,  -2.16626492e-03,
                          1.35718597e-04,  -1.74095575e-02,   5.51939374e-05,
                         -1.71771795e-02,  -5.11700613e-03,  -7.10700965e-03,
                         -7.74801197e-03,  -7.00341351e-03,  -3.00910906e-03,
                          2.19490845e-03,  -3.16443387e-03,   4.49728686e-03,
                          1.91442017e-03,   1.01193069e-02,   8.78819264e-03,
                          7.74713838e-03,   1.60909239e-02,   7.53941992e-03,
                          1.28172394e-02,   8.49118270e-03,   7.51040177e-03,
                          1.13816634e-02,   1.39284786e-02,   1.11804449e-03,
                          8.99097696e-03,  -6.10869518e-03,   5.69635537e-03,
                          2.45757867e-03,   7.88322417e-04,   6.88009337e-03,
                         -3.16353282e-04,  -7.41241965e-03,   6.50326535e-03,
                          1.02638965e-03,   1.11351209e-03,   3.80134722e-03,
                         -7.03416392e-03,  -4.68680682e-03,  -6.65741181e-03,
                         -3.90706398e-03,  -8.63599405e-03,  -1.39390891e-02,
                         -3.26576363e-03,  -7.51573127e-03,   1.06645646e-02,
                          1.36935711e-02,  -4.19470435e-03,   4.79456782e-03,
                         -5.86010050e-03,  -2.72385264e-03,  -2.51977239e-03,
                          5.92173962e-03,   3.40805226e-03,   1.06380705e-03,
                          4.31081001e-03,  -9.12890676e-03,  -9.40851495e-03,
                          1.45573664e-04,  -4.55332641e-03,  -2.22638645e-03,
                         -5.99135598e-03,  -4.82975366e-03,  -8.65435228e-03,
                         -7.12391967e-03,  -8.56808946e-03,  -9.15689860e-03,
                         -6.05238508e-03,  -2.99054943e-03,  -4.35935752e-03,
                          8.21415219e-04,   9.75859875e-04,  -2.11679563e-03,
                          2.93788500e-03,  -2.34397501e-03,  -3.19853163e-04,
                          5.84935129e-04,   1.57615973e-03,   4.96889604e-03,
                         -2.24605505e-03,  -1.53405053e-04,  -1.92128820e-03,
                          2.18157424e-03,  -2.73518381e-03,   5.32367849e-04,
                         -2.89411261e-03,  -9.67557193e-04,  -9.14691889e-04,
                          3.58816725e-03,   1.48211385e-03,  -5.82249602e-03,
                         -3.20530962e-03,  -5.55651309e-03,  -3.28891142e-03,
                         -5.98541647e-03,  -3.99968913e-03,  -5.40790381e-03,
                         -1.90270774e-03,  -2.35307473e-03,  -1.49537867e-04,
                         -9.91507340e-03,  -8.00833292e-03,  -1.69620174e-03,
                         -1.38099887e-03,  -1.26399938e-03,   2.63134541e-04,
                         -5.79516217e-03,  -4.07391414e-03,  -2.35698349e-03,
                          1.59392934e-04,  -2.20035575e-03,  -6.31022500e-04,
                          2.89357197e-03,  -6.57566066e-04,   7.04676332e-03,
                          1.32886122e-03,   8.67792312e-03,   2.16126814e-03,
                          3.23949731e-03,   3.60905565e-03,  -7.74731860e-04,
                          3.35743953e-03,   5.11550903e-03,  -3.11767426e-03,
                         -2.02002609e-03,   5.32684568e-03,   3.65801901e-03,
                          2.08246917e-03,  -2.37519664e-04,  -2.14103120e-03,
                          1.59763719e-03,   9.27047431e-03,   7.44476402e-03,
                          2.28803954e-03,  -4.44921758e-03,  -3.14895832e-03,
                         -6.95828930e-04,   1.58491288e-03,   5.70194097e-04,
                         -4.42268094e-03,   1.32041995e-03,  -5.21929935e-03,
                          1.01819988e-02,  -3.78699438e-03,  -8.25587369e-04,
                          8.68182443e-03,   7.15904310e-03,   5.88623527e-03,
                          8.90717469e-03,   3.18297977e-03,  -2.60868284e-04,
                          1.16552494e-03,   7.70241627e-03,   2.09118775e-03,
                          1.26730523e-03,  -4.94340551e-04,   8.03111994e-04,
                         -9.18841828e-03,  -5.15364017e-03,  -7.37317931e-03,
                          5.50440326e-03,   1.34801557e-02,   1.36492716e-03,
                          7.85911363e-03,   1.17449288e-03,  -1.26519902e-02,
                         -9.67835076e-03,  -9.52820294e-03,  -3.99119966e-03,
                          4.35463106e-03,  -5.13006281e-03,  -5.36630722e-03,
                         -6.00390695e-03,   3.48684448e-03,  -6.81334641e-03,
                         -5.91024896e-03,   6.96016068e-04,   2.56258855e-03,
                         -9.51277651e-03,   3.69447313e-04,  -6.43990701e-03,
                         -9.86177195e-03,   7.59471091e-04,  -4.36718203e-03,
                         -1.46607822e-02,  -6.22738572e-03,  -5.31247165e-03,
                         -1.08178314e-02,  -8.42489954e-03,  -2.27084523e-03,
                          7.67353736e-03,  -6.53654523e-03,  -5.05776471e-03,
                         -1.80821475e-02,  -2.10308451e-02,  -9.32521839e-03,
                         -1.41642932e-02,  -1.44695789e-02,   1.04261441e-02,
                         -2.91625527e-03,  -3.71315051e-03,  -1.32688815e-02,
                         -1.29726054e-02,  -3.73921590e-03,  -2.29730550e-03,
                         -1.31975464e-03,   2.72639608e-03,   5.73743880e-03,
                          1.30939367e-03,  -5.94041729e-03,  -3.19322990e-03,
                         -3.89543478e-03,  -5.72318304e-03,  -4.36824933e-03,
                          7.17887096e-03,  -2.15893891e-02,  -1.30818778e-04,
                         -1.46912690e-02,  -1.49297453e-02,  -4.46761772e-03,
                         -1.20157283e-02,   6.84687588e-03,   6.66434225e-03,
                          1.52918389e-02,  -4.13176930e-03,  -1.54296095e-02,
                         -1.54337194e-02,  -6.34051766e-03,  -9.06080846e-03,
                          2.09021606e-02,   2.36748299e-03,  -1.19915826e-03,
                          7.71349820e-04,   4.48559551e-03,   1.34302012e-03,
                         -2.11022217e-02,  -1.78821292e-02,   6.41445862e-04,
                         -6.74385484e-03,  -3.18322913e-03,   4.63497406e-03,
                         -1.27294445e-02,  -6.84591942e-03,  -3.98900919e-03,
                         -7.09017552e-03,   1.05323186e-02,  -5.27739711e-03,
                          1.84596963e-02,  -4.54051234e-03,   1.17395371e-02,
                         -6.24521752e-04,   1.03430068e-02,  -3.81023204e-03,
                          4.56680631e-04,   7.63185089e-03,  -1.02512408e-02,
                         -1.56630129e-02,  -1.63175561e-03,   4.48766770e-03,
                         -1.17236590e-02,  -5.76729514e-03,  -8.67913570e-03,
                         -2.37433314e-02,  -5.46609191e-03,  -1.55798402e-02,
                         -2.59082997e-03,   6.17865752e-03,   7.43708480e-03,
                          1.50189605e-02,  -1.25076780e-02,  -1.81125998e-02,
                         -1.37163727e-02,  -2.52457522e-03,  -1.85290780e-02,
                         -1.97384856e-03,  -2.10462511e-02,  -9.16107744e-03,
                          3.98591161e-03,  -2.23569814e-02,   5.22880768e-03,
                         -1.43115092e-02,   8.49715620e-03,   3.86988930e-03,
                          1.08581390e-02,   1.20242042e-02,   1.79867297e-02,
                          5.24768606e-03,   2.66024517e-03,  -5.98242972e-03,
                          6.13123970e-03,   7.12659489e-03,  -6.95499731e-03,
                          6.52015442e-03,  -2.49410886e-03,  -5.87936025e-04,
                         -8.74140579e-03,   2.02000793e-02,  -4.92070848e-03,
                          4.34245449e-03,   1.42569316e-03,   1.04862032e-02,
                         -4.97609656e-03,  -6.70193974e-03,  -1.46378698e-02,
                         -6.32873597e-03,  -3.76367336e-03,  -5.71054872e-03,
                         -3.55950147e-02,  -3.11339684e-02,  -1.70538668e-02,
                         -3.51303461e-05,  -2.17812303e-02,  -2.08258498e-02,
                         -1.41188083e-02,   8.18566827e-04,  -1.88443288e-02,
                         -1.12551628e-02,  -4.02233796e-03,  -1.35071082e-02,
                          9.79588367e-04,  -3.97438603e-03,  -1.73259266e-02,
                         -9.21242774e-01,  -9.31551993e-01,  -9.35336232e-01,
                         -9.30635512e-01,  -9.39905226e-01,  -9.42782283e-01,
                         -9.32045698e-01,  -9.20200706e-01,  -8.97390664e-01,
                         -9.30022657e-01,  -9.36291635e-01,  -9.28651094e-01,
                         -1.38549600e-02,  -2.43817065e-02,   4.30029677e-03,
                          6.93986844e-03,   3.48768989e-03,  -1.23993005e-03,
                          1.41230226e-02,  -1.14815449e-02,   3.69253248e-04,
                          5.13341743e-03,   3.47788329e-03,   1.66251988e-03,
                          9.65981185e-03,   5.39924065e-03,  -1.37154087e-02,
                         -2.53567006e-02,   3.04744137e-03,  -5.10610454e-03,
                         -8.46291985e-03,  -4.08120500e-03,  -1.32454634e-02,
                         -6.35203626e-03,   1.39325880e-03,  -1.97950657e-02,
                          4.64241020e-03,  -1.98779954e-03,   1.74217056e-02,
                         -1.37317441e-02,  -1.13712540e-02,   4.66183620e-03,
                          2.21552793e-02,   1.01871975e-02,   1.73542593e-02,
                         -1.58443465e-04,   1.12089571e-02,   1.76846460e-02,
                          1.55432895e-02,   2.09335685e-02,   4.53356989e-02,
                          2.78278142e-02,   3.89928813e-03,  -1.18599804e-02,
                          9.20719933e-03,  -2.44863983e-02,   1.79732647e-02,
                          2.29937974e-02,   1.02064358e-02,  -3.65669536e-03,
                          1.46795148e-02,   1.61362570e-02,   1.83902960e-02,
                          1.18823247e-02,   2.87814755e-02,   2.62852455e-03,
                         -1.19609013e-02,  -1.04030520e-02,   5.64239500e-03,
                         -6.60918280e-03,  -2.39857985e-03,  -6.24519680e-03,
                          7.98655674e-03,  -5.66512672e-03,   9.24140122e-03,
                         -1.03486488e-02,  -9.25410032e-01,  -9.40490186e-01,
                         -9.38649416e-01,  -9.34695542e-01,  -9.43273067e-01,
                         -9.38429415e-01,  -9.34177577e-01,  -9.24756169e-01,
                         -9.23387527e-01,  -9.29901958e-01,  -9.33968127e-01,
                         -9.15968120e-01,  -9.36064780e-01,  -9.34375107e-01,
                         -9.40603912e-01,  -9.37421143e-01,  -9.23688829e-01,
                         -9.38348353e-01,  -9.34881389e-01,  -9.20114636e-01,
                         -9.40568566e-01,  -9.53234911e-01,  -9.25654411e-01,
                         -9.38819289e-01,  -9.43258584e-01,  -9.52959716e-01,
                         -9.52202141e-01,  -9.43473101e-01,  -9.22500074e-01,
                         -9.46177423e-01,  -9.59653080e-01,  -9.47856367e-01,
                         -9.26323593e-01,  -9.27339375e-01,  -9.25734162e-01,
                         -9.48233068e-01,  -9.63547945e-01,  -9.39581335e-01,
                         -9.20738876e-01,  -9.47083175e-01,  -9.26901877e-01,
                         -9.41626847e-01,  -9.38513815e-01,  -9.40451324e-01,
                         -9.37259912e-01,  -9.32909727e-01,  -9.31951344e-01,
                         -9.34431612e-01,  -9.34443831e-01,  -9.40255761e-01,
                         -9.35149968e-01,  -9.38392520e-01,  -9.38568830e-01,
                         -9.49490964e-01,  -9.06039000e-01,  -9.31396306e-01,
                         -9.18513715e-01,  -9.10865426e-01,  -9.35582399e-01,
                         -9.49016452e-01,  -9.41630960e-01,  -9.45799947e-01,
                         -9.33478653e-01,  -9.45064664e-01,  -9.49904144e-01,
                         -9.33320343e-01,  -9.20277953e-01,  -9.29172516e-01,
                         -9.41712677e-01,  -9.27217603e-01,  -9.09895718e-01,
                         -9.23033893e-01,  -9.15980399e-01,  -9.33372200e-01,
                         -9.06114578e-01,  -9.36428845e-01,  -9.38125193e-01,
                         -9.28277791e-01,  -9.36844647e-01,  -9.31635618e-01,
                         -9.29358423e-01,  -9.40174580e-01,  -9.19056594e-01,
                         -9.25280750e-01,  -9.30675328e-01,  -9.17643964e-01,
                         -9.14970160e-01,  -9.37985122e-01,  -9.42529678e-01,
                         -9.35563684e-01,  -9.34044540e-01,  -9.39976633e-01,
                         -9.22185004e-01,  -9.24211085e-01,  -9.25792098e-01,
                         -9.33710337e-01,  -9.46209729e-01,  -9.28569257e-01,
                         -9.40476418e-01,  -9.24506903e-01,  -9.45832908e-01,
                         -9.19050932e-01,  -9.24945354e-01,  -9.36244428e-01,
                         -9.23301399e-01,  -9.35628414e-01,  -9.35240209e-01,
                         -9.41287637e-01,  -9.21002448e-01,  -9.47374821e-01,
                         -9.32105243e-01,  -9.26382303e-01,  -9.30845976e-01,
                         -9.39445853e-01,  -9.60932493e-01,  -9.41041827e-01,
                         -9.39130485e-01,  -9.42017078e-01,  -9.51446474e-01,
                         -9.41930234e-01,  -9.37923253e-01,  -9.23516929e-01,
                         -9.20617044e-01,  -9.19655025e-01,  -9.41762388e-01,
                         -9.29212987e-01,  -9.30621803e-01,  -9.31819797e-01,
                         -9.39601183e-01,  -9.29618955e-01,  -9.23177183e-01,
                         -9.49495256e-01,  -9.43600655e-01,  -9.52377319e-01,
                         -9.27315414e-01,  -9.44910526e-01,  -9.54628706e-01,
                         -9.46432710e-01,  -9.41923261e-01,  -9.38035905e-01,
                         -9.32374895e-01,  -9.23669934e-01,  -9.23568785e-01,
                         -9.22115028e-01,  -9.22915637e-01,  -9.30525184e-01,
                         -9.41891313e-01,  -9.27760363e-01,  -9.27730799e-01,
                         -9.33744490e-01,  -9.47347283e-01,  -9.27300930e-01,
                         -9.35978711e-01,  -9.38418686e-01,  -9.23642278e-01,
                         -9.19126034e-01,  -9.17740822e-01,  -9.28416312e-01,
                         -9.39576328e-01,  -9.43451822e-01,  -9.36502337e-01,
                         -9.45656061e-01,  -9.52487230e-01,  -9.41459298e-01,
                         -9.43849802e-01,  -9.37436998e-01,  -9.39640522e-01,
                         -9.32745814e-01,  -9.39101517e-01,  -9.33863997e-01,
                         -9.28715885e-01,  -9.28992033e-01,  -9.22887325e-01,
                         -9.27355349e-01,  -9.32027817e-01,  -9.40919161e-01,
                         -9.37219679e-01,  -9.40326512e-01,  -9.32734370e-01,
                         -9.36744273e-01,  -9.35163260e-01,  -9.31291640e-01,
                         -9.31002915e-01,  -9.39362764e-01,  -9.33489621e-01,
                         -9.27920163e-01,  -9.30979848e-01,  -9.34301138e-01,
                         -9.28692341e-01,  -9.29149985e-01,  -9.42272305e-01,
                         -9.35547590e-01,  -9.32265580e-01,  -9.36588824e-01,
                         -9.35669482e-01,  -9.29762363e-01,  -9.41115797e-01,
                         -9.34634864e-01,  -9.31160033e-01,  -9.26162958e-01,
                         -9.17616665e-01,  -9.33657110e-01,  -9.25385952e-01,
                         -9.22683597e-01,  -9.15459812e-01,  -9.31755602e-01,
                         -9.31701362e-01,  -9.31653023e-01,  -9.47453439e-01,
                         -9.43183959e-01,  -9.37053084e-01,  -9.32089925e-01,
                         -9.33631003e-01,  -9.38379884e-01,  -9.32222903e-01,
                         -9.36388314e-01,  -9.32831287e-01,  -9.34632540e-01,
                         -9.33090568e-01,  -9.29252863e-01,  -9.46141183e-01,
                         -9.34383094e-01,  -9.32437658e-01,  -9.33982670e-01,
                         -9.38366234e-01,  -9.38334644e-01,  -9.34917867e-01,
                         -9.37804282e-01,  -9.31384265e-01,  -9.39647079e-01,
                         -9.27271903e-01,  -9.25150514e-01,  -9.39917862e-01,
                         -9.26859319e-01,  -9.29979205e-01,  -9.25195396e-01,
                         -9.31570292e-01,  -9.25723910e-01,  -9.30207729e-01,
                         -9.24980938e-01,  -9.27113056e-01,  -9.34908092e-01,
                         -9.31275249e-01,  -9.30737019e-01,  -9.36621010e-01,
                         -9.37010109e-01,  -9.32737291e-01,  -9.24980938e-01,
                         -9.39332068e-01,  -9.35853422e-01,  -9.36588705e-01,
                         -9.32223856e-01,  -9.34013724e-01,  -9.29074347e-01,
                         -9.41132665e-01,  -9.33186233e-01,  -9.34389949e-01,
                         -9.21456695e-01,  -9.27435040e-01,  -9.25612152e-01,
                         -9.33338165e-01,  -9.30568993e-01,  -9.34809983e-01,
                         -9.24295187e-01,  -9.24466312e-01,  -9.33141232e-01,
                         -9.32231307e-01,  -9.31562781e-01,  -9.30499673e-01,
                         -9.26777244e-01,  -9.42742467e-01,  -9.33159649e-01,
                         -9.34117138e-01,  -9.31412518e-01,  -9.32581127e-01,
                         -9.40246880e-01,  -9.34507251e-01,  -9.38474774e-01,
                         -9.35721040e-01,  -9.41267490e-01,  -9.43191350e-01,
                         -9.36820567e-01,  -9.33534980e-01,  -9.41352725e-01,
                         -9.24458802e-01,  -9.45461750e-01,  -9.40764844e-01,
                         -9.42418933e-01,  -9.30263758e-01,  -9.28693652e-01,
                         -9.29393351e-01,  -9.30291772e-01,  -9.35079992e-01,
                         -9.27561462e-01,  -9.36360300e-01,  -9.39128697e-01,
                         -9.33186948e-01,  -9.31831896e-01,  -9.31888878e-01,
                         -9.36160803e-01,  -9.39641118e-01,  -9.28854346e-01,
                         -9.36291754e-01,  -9.38644350e-01,  -9.33255792e-01,
                         -9.36390340e-01,  -9.31428790e-01,  -9.31104124e-01,
                         -9.25934374e-01,  -9.28349733e-01,  -9.30084527e-01,
                         -9.25304055e-01,  -9.28436220e-01,  -9.30579305e-01,
                         -9.23527479e-01,  -9.25724328e-01,  -9.26917911e-01,
                         -9.31535244e-01,  -9.31109548e-01,  -9.27414417e-01,
                         -9.27556813e-01,  -9.24418390e-01,  -9.26303566e-01,
                         -9.32158470e-01,  -9.28681433e-01,  -9.31609571e-01,
                         -9.33048844e-01,  -9.22742665e-01,  -9.19924438e-01,
                         -9.31952298e-01,  -9.26132798e-01,  -9.29692209e-01,
                         -9.36310828e-01,  -9.32291090e-01,  -9.32473063e-01,
                         -9.36611235e-01,  -9.36072230e-01,  -9.23804045e-01,
                         -9.38058853e-01,  -9.29816067e-01,  -9.37476933e-01,
                         -9.28582072e-01,  -9.32727993e-01,  -9.39139247e-01,
                         -9.35244441e-01,  -9.30993378e-01,  -9.34515119e-01,
                         -9.39768970e-01,  -9.29270029e-01,  -9.26669955e-01,
                         -9.31669533e-01,  -9.35050607e-01,  -9.23746943e-01,
                         -9.25733984e-01,  -9.27642286e-01,  -9.30487394e-01,
                         -9.41813350e-01,  -9.29365456e-01,  -9.25920904e-01,
                         -9.29567039e-01,  -9.32682753e-01,  -9.36503530e-01,
                         -9.32158470e-01,  -9.32906032e-01,  -2.66652415e-03,
                         -6.58062240e-03,  -3.04261083e-03,   1.48407510e-03,
                         -9.13165137e-03,  -1.38257481e-02,  -1.22173829e-02,
                         -8.01603962e-03,  -7.29027065e-03,   5.52263716e-03,
                         -5.67732425e-03,  -4.67318823e-05,  -2.16429681e-03,
                         -3.77460266e-03,   4.57325164e-04,  -1.72229484e-03,
                          5.07114036e-03,  -2.69274897e-04,  -1.37582114e-02,
                         -2.17566267e-03,  -3.63626448e-03,  -9.51687247e-03,
                         -1.13334348e-02,  -5.12551656e-03,  -1.11508109e-02,
                         -2.01618648e-03,  -3.93948471e-03,   2.72203004e-03,
                         -4.38952586e-03,  -4.89805313e-03,   1.24080600e-02,
                         -1.69345038e-03,  -7.77781243e-03,  -5.34822606e-03,
                         -4.39612381e-03,  -8.79287813e-03,  -8.57437495e-03,
                         -8.77747871e-03,  -3.64712439e-03,  -2.48906366e-03,
                         -6.01970125e-04,  -7.80721148e-03,   1.25171861e-03,
                         -5.97262289e-03,  -4.00537206e-03,   4.52419091e-03,
                          1.01440139e-02,   2.24366412e-03,   1.52814575e-03,
                         -2.17083911e-03,  -5.39226178e-03,  -1.59511447e-03,
                         -4.81609371e-04,   4.25407058e-03,   4.59100027e-03,
                         -5.74163860e-03,  -5.01110218e-03,   1.17515132e-03,
                         -3.75395012e-03,  -7.72920251e-03,   3.24766152e-03,
                          7.01170228e-03,   7.13619345e-04,   7.02186208e-03,
                         -1.02979247e-04,   3.36762704e-03,  -4.68413858e-03,
                          4.52505052e-03,  -8.62588931e-04,  -2.58112745e-03,
                         -3.37174372e-03,  -4.05014958e-03,   8.31415877e-04,
                         -1.30926201e-03,   1.09013566e-03,   6.70668017e-03,
                         -9.72924847e-03,   3.87270306e-03,  -2.94640253e-04,
                         -6.20674668e-03,  -3.02268588e-03,  -3.54982121e-03,
                          6.57417020e-03,   5.92951570e-03,   1.89529220e-03,
                          1.87336424e-04,   3.97105981e-03,  -2.92069768e-03,
                         -2.84990342e-03,   4.35007084e-03,   3.77449882e-03,
                          8.45814496e-03,   8.21730588e-03,  -3.52245988e-03,
                          2.72422680e-03,   5.29845152e-03,   4.80714673e-03,
                          4.43077553e-03,   4.16197209e-03,   4.93962178e-03,
                          1.36842020e-03,   4.51342808e-03,   2.63041654e-03,
                          3.08742980e-03,  -8.73475242e-03,  -7.12115457e-03,
                         -5.25896903e-03,  -6.39007753e-03,   1.74700178e-03,
                          5.04508195e-03,  -1.76555454e-03,  -1.35073368e-03,
                          3.58264381e-03,   1.03896146e-03,   7.15706078e-03,
                         -6.60374248e-03,  -6.51495007e-04,   3.13765462e-03,
                          5.53366356e-03,   1.56025437e-03,  -1.94785942e-03,
                          1.85790937e-04,   6.74899714e-03,  -3.26300529e-03,
                          5.72748668e-03,   1.11298531e-03,   4.73908987e-03,
                         -8.84800963e-03,  -1.22973532e-03,   5.84685651e-04,
                         -7.46702449e-03,   5.39824972e-03,   3.79089615e-03,
                          4.29776701e-04,  -7.67628197e-04,   1.48092175e-03,
                          5.80197480e-03,   4.48861718e-03,   3.99024319e-03,
                         -6.61740918e-03,   6.45340770e-04,  -9.36914980e-03,
                         -7.18060369e-03,  -3.73758050e-03,  -2.33442499e-03,
                         -3.62764299e-03,  -1.01154875e-02,  -9.43410862e-03,
                         -7.35302595e-03,   1.32704549e-03,  -1.32162590e-03,
                         -5.92343090e-03,   4.48475685e-03,   1.18462520e-03,
                          2.64345272e-03,   3.02143837e-03,   2.61884276e-03,
                          1.97530398e-03,   2.93295062e-03,   4.34535835e-03,
                          1.62993290e-03,  -1.92811468e-03,  -6.20929012e-03,
                          3.60756560e-04,   3.23240762e-03,   3.37760686e-03,
                          2.64320336e-03,   2.83387327e-03,  -3.82573548e-04,
                          7.71577843e-03,   1.00507298e-02,  -4.53298562e-04,
                         -3.00793792e-03,  -2.15123291e-03,  -6.57191791e-04,
                         -1.50400016e-03,   1.27984234e-03,   1.78367761e-03,
                         -1.51587883e-03,   2.70972843e-03,  -5.28766774e-03,
                         -5.20177884e-03,  -1.63255958e-03,   3.79644753e-03,
                         -3.37399612e-03,  -3.16074700e-03,   3.96866864e-03,
                         -1.23245898e-03,  -4.05983161e-03,  -1.00429542e-03,
                          4.72563086e-03,   2.43575475e-03,  -8.64279922e-04,
                          1.31505588e-03,  -2.47681746e-03,   1.52266375e-03,
                         -7.43323180e-04,   9.00623098e-04,   2.44551268e-03,
                          8.54133815e-03,   2.85798428e-03,  -4.93778521e-03,
                         -2.61353399e-03,  -1.10686570e-03,  -2.28697923e-03,
                         -2.05336139e-03,  -2.71294406e-03,  -4.04049549e-03,
                         -6.74781215e-04,   3.33144329e-03,   1.77956780e-03,
                          1.89364969e-03,  -8.57280218e-04,   1.92425447e-03,
                         -1.21711497e-03,   9.32426832e-04,  -1.01780286e-03,
                          4.85476543e-04,  -3.62198078e-03,  -1.85718865e-03,
                          2.89601827e-04,  -3.44353612e-03,  -2.73435237e-03,
                         -7.71280495e-04,   7.63109536e-04,   1.88498665e-03,
                         -5.44946583e-04,   1.01071293e-03,  -7.01248529e-04,
                          4.70316224e-03,   1.60878827e-03,   2.04851013e-03,
                          3.57733504e-03,   2.51305662e-03,  -5.33684622e-04,
                         -1.38026429e-03,   1.62188674e-03,   2.30381312e-03,
                          1.28952414e-03,  -4.13885224e-04,  -1.40072976e-03,
                          2.32543610e-03,  -5.80231473e-03,  -1.03545457e-03,
                          1.72874704e-03,   1.41358573e-03,  -1.42080724e-04,
                         -6.67192435e-05,   1.05354306e-03,   3.53285548e-04,
                          4.62100230e-04,   5.96973288e-04,   8.89305724e-04,
                         -2.45059957e-04,  -9.70100693e-04,   4.48913686e-03,
                          6.75186655e-03,  -7.37466966e-04,   1.88291445e-03,
                          7.99792295e-04,   1.22037227e-03,   4.41745535e-04,
                          1.09215942e-03,   1.09768298e-03,   1.78647751e-03,
                          3.79648904e-04,   2.85872584e-03,  -4.64602112e-04,
                          1.43913133e-03,   1.31492421e-03,   5.25513664e-04,
                         -1.19752961e-03,  -8.76740844e-04,  -1.20992819e-03,
                          3.08327872e-04,   1.39305787e-03,  -2.51255784e-04,
                          2.19454104e-03,   2.45307386e-03,   3.40010319e-03,
                          2.37929937e-03,   2.53121438e-03,   2.48069852e-03,
                          4.02804138e-03,   2.97155324e-03,   3.39385192e-03,
                          2.20438233e-03,   1.67943013e-03,   9.93490918e-04,
                         -1.74421573e-03,  -8.29690194e-04,  -2.17377068e-03,
                          9.58984252e-04,   4.79634211e-04,  -1.14563457e-03,
                         -4.50638682e-03,   2.18952354e-03,  -5.69549564e-04,
                          6.62050035e-04,   1.64831942e-03,   3.62026901e-03,
                          3.88309872e-03,   2.85601593e-03,   3.37326853e-03,
                         -4.91388200e-04,   1.53037734e-04,  -2.68759276e-03,
                          1.17172764e-04,  -6.00410800e-04,  -3.52746365e-03,
                         -1.20325421e-03,  -4.02939320e-03,  -2.06544111e-03,
                          4.81817289e-04,   1.76992069e-03,  -3.82838980e-03,
                         -3.35471565e-03,  -4.14199848e-03,  -2.63314717e-03,
                          1.82120583e-03,   1.14359013e-04,  -3.30893323e-04,
                          1.60594669e-03,   5.97562362e-03,   3.29388049e-03,
                          4.43211338e-03,   9.53800278e-04,   2.97020166e-03,
                         -3.56989168e-03,  -3.20386811e-04,   7.99056329e-03,
                          3.52402613e-03,   2.03103153e-03,   6.67316467e-03,
                          2.75657116e-03,   1.96755584e-03,  -1.82022864e-03,
                         -7.88787473e-03,  -2.89006508e-03,  -4.17357369e-04,
                          2.66195019e-03,   7.12285936e-03,   1.78384397e-03,
                         -2.02242401e-03,   4.34656395e-03,   2.18680687e-03,
                          1.74939272e-03,   3.60307470e-03,   3.88396485e-03,
                         -2.01904186e-04,  -5.15130488e-03,  -7.23633799e-04,
                         -1.37747340e-02,  -1.33968173e-02,  -9.72830597e-03,
                         -4.90950886e-03,  -1.62063923e-03,   1.25165209e-02,
                          5.64746791e-03,   4.50477190e-03,  -4.13492275e-03,
                          8.02628882e-03,  -6.42159674e-03,   1.71779003e-03,
                          3.04182083e-03,  -1.35281906e-02,  -5.71653666e-03,
                          2.24290858e-03,   7.63539225e-04,  -7.95862754e-04,
                         -5.63524989e-03,  -6.29485305e-03,  -3.82286613e-03,
                          3.44865769e-03,  -1.22358110e-02,   2.87028565e-03,
                          2.08930252e-03,  -8.93756468e-03,  -1.09371040e-02,
                          5.44479443e-03,  -6.29356410e-03,  -5.87804336e-03,
                          5.31156408e-03,  -3.16114188e-03,  -5.27925417e-03,
                         -5.48702152e-03,  -1.36051254e-04,   2.87501910e-03,
                          6.80074701e-03,  -1.09751103e-02,  -1.48579320e-02,
                          4.76865517e-03,  -1.44989286e-02,   2.03284738e-03,
                         -3.18835070e-03,  -1.11827599e-02,  -2.89515895e-03,
                          7.66954524e-03,   1.53035587e-02,   4.29252069e-03,
                          7.34022527e-04,  -5.62809035e-03,  -1.62237398e-02,
                         -1.78472344e-02,  -9.47907381e-03,  -2.04605609e-02,
                         -7.42077781e-03,  -6.29532430e-03,   2.41707731e-03,
                         -6.66628266e-03,   5.88646391e-03,  -2.58658174e-03,
                         -1.17561212e-02,  -7.53659895e-03,   3.81360715e-03,
                          3.79343954e-04,   1.66427330e-04,  -9.50963702e-03,
                         -1.86975636e-02,  -4.66505904e-03,  -4.93976707e-03,
                         -1.03663281e-03,  -3.18622310e-03,  -8.67887959e-03,
                          9.48446523e-03,   1.81354769e-02,  -8.50481447e-03,
                         -1.53075857e-03,  -6.28411816e-03,  -1.03052501e-02,
                          6.32930454e-03,   5.33751864e-03,   1.88981500e-02,
                          5.66477329e-03,   1.09528359e-02,   9.00991820e-03,
                          2.01299582e-02,   8.52865516e-04,   5.21197356e-03,
                         -6.61341054e-03,  -5.60893503e-04,   4.21007629e-03,
                          4.80585732e-03,  -1.27024157e-02,  -4.15286561e-03,
                         -7.40460877e-04,  -7.39259878e-03,  -1.01460097e-03,
                         -1.79915328e-03,  -3.29385279e-03,   5.57720754e-03,
                         -5.40944235e-03,  -3.20881628e-03,  -1.38702560e-02,
                          1.56774353e-02,   1.08507993e-02,   1.86234494e-04,
                         -1.38982828e-03,   5.00368653e-03,   7.70109255e-05,
                          2.71812128e-03,   1.27705419e-02,   1.25006232e-02,
                          1.54167814e-02,   2.92136986e-03,   1.13759870e-02,
                          4.90388134e-03,   1.49081359e-02,  -1.86151117e-02,
                         -2.54332880e-03,   1.53726619e-03,   1.03756078e-02,
                          1.77055337e-02,   2.08399463e-02,   1.22831808e-02,
                         -6.09739160e-04,   2.50065401e-02,   7.13621406e-03,
                         -1.34887425e-02,  -2.07976624e-03,   1.54511491e-02,
                          4.99600777e-04,  -1.33316510e-03,   2.11675130e-02,
                          6.08986523e-03,  -9.93930269e-03,   9.19318665e-03,
                          2.99878279e-03,  -1.91131122e-02,  -6.31175656e-03,
                         -5.32139151e-04,  -5.40245650e-03,  -4.92582330e-03,
                          1.06908660e-02,   2.31965608e-03,   2.45994190e-03,
                          7.29510840e-03,   4.41385852e-03,   7.13790534e-03,
                          3.62316589e-03,   4.41913260e-03,   1.08924648e-02,
                         -2.96912063e-03,   1.35014462e-03,  -1.34282466e-02,
                         -2.37263590e-02,   8.15734360e-03,   4.71143750e-03,
                          5.44316601e-03,  -2.85201008e-03,  -2.06765607e-02,
                         -1.65384784e-02,   8.91343225e-03,  -1.68044195e-02,
                         -2.68726703e-03,   1.01372497e-02,  -1.33631490e-02,
                         -1.15924040e-02,  -1.09884171e-02,   1.90198002e-03,
                          2.87170638e-03,   1.64760202e-02,   1.12380302e-02,
                          7.18753412e-03,  -8.77766579e-04,  -1.60683040e-02,
                          5.63510414e-03,   1.16625605e-02,   1.48118027e-02,
                          3.14662280e-03,  -6.08554063e-03,   3.20776296e-03,
                          1.04055610e-02,   7.11893663e-05,   1.03504853e-02,
                          6.59998623e-04,   4.07512672e-03,  -9.29255504e-03,
                          6.06113859e-03,   2.90848836e-02,  -1.11646578e-02,
                         -3.07832332e-03,   4.70228214e-03,   2.83105951e-03,
                          1.47121362e-02,   2.16751322e-02,  -1.51316216e-03,
                         -9.09273624e-01,  -9.33769941e-01,  -9.29533422e-01,
                         -9.48815227e-01,  -9.35034215e-01,  -9.34008062e-01,
                         -9.24512148e-01,  -9.34077680e-01,  -9.49760079e-01,
                         -9.33653772e-01,  -9.30817068e-01,  -9.18220937e-01,
                          5.94189344e-03,   6.61338959e-03,  -4.61982377e-03,
                         -1.90315675e-02,   6.47192588e-03,  -6.47482276e-03,
                          1.02067962e-02,  -1.38706295e-03,   2.97499052e-03,
                          2.31235698e-02,   7.65611418e-03,   1.70935430e-02,
                          3.93600529e-03,   6.32298365e-03,   1.00817364e-02,
                          3.91628128e-03,   1.85324103e-02,   6.87574781e-03,
                          5.60230948e-03,   1.27817213e-03,   8.71020462e-03,
                         -2.29519862e-03,   5.11148246e-03,   2.52741519e-02,
                          7.87336938e-03,   7.92549271e-03,  -6.11908385e-04,
                         -5.65646356e-03,   5.96036296e-03,   4.66050551e-04,
                          1.26383025e-02,   1.01337431e-03,   4.79901722e-03,
                         -8.14297702e-03,  -5.02490730e-04,  -1.64214373e-02,
                          1.29000237e-03,  -1.55222556e-02,   2.04531522e-03,
                         -1.30313553e-03,  -1.82659701e-02,  -8.54349323e-03,
                          7.83354044e-03,   2.68710754e-03,  -1.05934311e-02,
                          1.53862108e-02,  -1.68978758e-02,   1.70080010e-02,
                          1.47789186e-02,   3.85069894e-03,   1.52305467e-02,
                         -4.10212111e-03,   1.68144610e-02,   8.43695924e-03,
                          1.49016418e-02,  -1.99118163e-03,   4.90840711e-03,
                          1.37045495e-02,   1.62999742e-02,   9.42732394e-03,
                          8.72843154e-03,   5.16502000e-03,  -7.65928160e-03,
                         -2.70168427e-02,  -9.37378109e-01,  -9.17141795e-01,
                         -9.29835677e-01,  -9.40293908e-01,  -9.37022388e-01,
                         -9.40627992e-01,  -9.21473444e-01,  -9.41235662e-01,
                         -9.25979197e-01,  -9.23253596e-01,  -9.29059625e-01,
                         -9.29774404e-01,  -9.15192842e-01,  -9.30637419e-01,
                         -9.35115159e-01,  -9.40656960e-01,  -9.35506880e-01,
                         -9.48175967e-01,  -9.53441322e-01,  -9.38132584e-01,
                         -9.39796984e-01,  -9.21653748e-01,  -9.27149236e-01,
                         -9.44392264e-01,  -9.28135276e-01,  -9.38859880e-01,
                         -9.29844379e-01,  -9.32276011e-01,  -9.22318578e-01,
                         -9.29367721e-01,  -9.33257997e-01,  -9.47319210e-01,
                         -9.31182086e-01,  -9.21532512e-01,  -9.37109530e-01,
                         -9.36975241e-01,  -9.28774357e-01,  -9.36360419e-01,
                         -9.33060408e-01,  -9.40990031e-01,  -9.31508780e-01,
                         -9.47289824e-01,  -9.20088708e-01,  -9.10079956e-01,
                         -9.19388533e-01,  -9.37439322e-01,  -9.36558545e-01,
                         -9.25638437e-01,  -9.45860505e-01,  -9.32280779e-01,
                         -9.31124985e-01,  -9.36265230e-01,  -9.38300252e-01,
                         -9.24871087e-01,  -9.32933450e-01,  -9.29916918e-01,
                         -9.35724914e-01,  -9.29066062e-01,  -9.39337134e-01,
                         -9.37521279e-01,  -9.28141534e-01,  -9.41073000e-01,
                         -9.33989525e-01,  -9.22804892e-01,  -9.37698007e-01,
                         -9.25800800e-01,  -9.39158380e-01,  -9.12622869e-01,
                         -9.43369567e-01,  -9.45984721e-01,  -9.33383405e-01,
                         -9.55366194e-01,  -9.36707020e-01,  -9.26242530e-01,
                         -9.44128156e-01,  -9.47571754e-01,  -9.13383245e-01,
                         -9.19900835e-01,  -9.12205756e-01,  -9.08574700e-01,
                         -9.22000527e-01,  -9.24408674e-01,  -9.19519782e-01,
                         -9.26948667e-01,  -9.31247413e-01,  -9.36502993e-01,
                         -9.42545116e-01,  -9.52791631e-01,  -9.44699764e-01,
                         -9.42026079e-01,  -9.29438770e-01,  -9.29396510e-01,
                         -9.36061203e-01,  -9.29684103e-01,  -9.23179448e-01,
                         -9.29300070e-01,  -9.19018328e-01,  -9.24088478e-01,
                         -9.36710477e-01,  -9.25122917e-01,  -9.23519075e-01,
                         -9.29042220e-01,  -9.35055912e-01,  -9.16461766e-01,
                         -9.13651049e-01,  -9.50896680e-01,  -9.31694150e-01,
                         -9.34256196e-01,  -9.31713223e-01,  -9.31623757e-01,
                         -9.21040595e-01,  -9.35143054e-01,  -9.10134017e-01,
                         -9.32328463e-01,  -9.46195304e-01,  -9.30624545e-01,
                         -9.30434823e-01,  -9.17199969e-01,  -9.24906850e-01,
                         -9.35165942e-01,  -9.33373213e-01,  -9.14631426e-01,
                         -9.31725979e-01,  -9.27725911e-01,  -9.31143820e-01,
                         -9.27650452e-01,  -9.26725626e-01,  -9.26755011e-01,
                         -9.36420262e-01,  -9.39084888e-01,  -9.29984093e-01,
                         -9.23614025e-01,  -9.21411633e-01,  -9.22308803e-01,
                         -9.26295221e-01,  -9.27020729e-01,  -9.19898212e-01,
                         -9.13666427e-01,  -9.11267400e-01,  -9.27924156e-01,
                         -9.28583562e-01,  -9.23369348e-01,  -9.23529565e-01,
                         -9.29480255e-01,  -9.30576563e-01,  -9.37070310e-01,
                         -9.41645503e-01,  -9.43726718e-01,  -9.34026659e-01,
                         -9.28073108e-01,  -9.32833552e-01,  -9.25206482e-01,
                         -9.21535552e-01,  -9.29279864e-01,  -9.09608960e-01,
                         -9.16934133e-01,  -9.18724179e-01,  -9.23940897e-01,
                         -9.28051353e-01,  -9.18075800e-01,  -9.35993373e-01,
                         -9.11477804e-01,  -9.24825788e-01,  -9.41579819e-01,
                         -9.23644543e-01,  -9.28362966e-01,  -9.07790184e-01,
                         -9.22408640e-01,  -9.11648214e-01,  -9.31123555e-01,
                         -9.15997088e-01,  -9.26001728e-01,  -9.11133230e-01,
                         -9.30304766e-01,  -9.42507982e-01,  -9.27789211e-01,
                         -9.02383029e-01,  -9.26331818e-01,  -9.11853731e-01,
                         -9.37789083e-01,  -9.27066684e-01,  -9.26139057e-01,
                         -9.26770866e-01,  -9.30104733e-01,  -9.32309687e-01,
                         -9.31411386e-01,  -9.28335667e-01,  -9.22312200e-01,
                         -9.30840015e-01,  -9.26792622e-01,  -9.21432674e-01,
                         -9.28698719e-01,  -9.25884187e-01,  -9.18512404e-01,
                         -9.19985235e-01,  -9.24164832e-01,  -9.22736645e-01,
                         -9.15306151e-01,  -9.37454641e-01,  -9.35735524e-01,
                         -9.41569209e-01,  -9.39095855e-01,  -9.32549119e-01,
                         -9.27851856e-01,  -9.24773693e-01,  -9.29653168e-01,
                         -9.16162610e-01,  -9.28146005e-01,  -9.30250764e-01,
                         -9.32336450e-01,  -9.22091007e-01,  -9.27268028e-01,
                         -9.09886122e-01,  -9.17272568e-01,  -9.35524881e-01,
                         -9.25662577e-01,  -9.29722130e-01,  -9.28104997e-01,
                         -9.39062178e-01,  -9.31412935e-01,  -9.38119829e-01,
                         -9.27243948e-01,  -9.35831368e-01,  -9.40208614e-01,
                         -9.42143261e-01,  -9.40621793e-01,  -9.27116156e-01,
                         -9.33064520e-01,  -9.27772820e-01,  -9.44097877e-01,
                         -9.33040142e-01,  -9.40858185e-01,  -9.43769515e-01,
                         -9.24287260e-01,  -9.18858767e-01,  -9.29186106e-01,
                         -9.31886137e-01,  -9.26822603e-01,  -9.45692062e-01,
                         -9.24555659e-01,  -9.33805764e-01,  -9.41348195e-01,
                         -9.15397346e-01,  -9.24101532e-01,  -9.23703909e-01,
                         -9.15317714e-01,  -9.24248457e-01,  -9.28676248e-01,
                         -9.25330818e-01,  -9.25330460e-01,  -9.33678925e-01,
                         -9.30082440e-01,  -9.23695624e-01,  -9.34087753e-01,
                         -9.27654445e-01,  -9.34853673e-01,  -9.40397322e-01,
                         -9.33698475e-01,  -9.25654948e-01,  -9.28163826e-01,
                         -9.40107942e-01,  -9.36140060e-01,  -9.43131268e-01,
                         -9.29925144e-01,  -9.22625303e-01,  -9.22882140e-01,
                         -9.26991463e-01,  -9.31554258e-01,  -9.35446560e-01,
                         -9.28661108e-01,  -9.30743098e-01,  -9.27361727e-01,
                         -9.32498336e-01,  -9.28974688e-01,  -9.18573499e-01,
                         -9.30815816e-01,  -9.27367270e-01,  -9.33424652e-01,
                         -9.30577517e-01,  -9.26681459e-01,  -9.26898062e-01,
                         -9.36563551e-01,  -9.37401831e-01,  -9.30295527e-01,
                         -9.36207354e-01,  -9.22347248e-01,  -9.21746314e-01,
                         -9.21019256e-01,  -9.21223283e-01,  -9.07321036e-01,
                         -9.37064111e-01,  -9.29469526e-01,  -8.96801531e-01,
                         -9.12908375e-01,  -9.20407653e-01,  -9.43768620e-01,
                         -9.29027379e-01,  -9.22169209e-01,  -9.43139911e-01,
                         -9.21880126e-01,  -9.17704821e-01,  -9.13395643e-01,
                         -9.19440329e-01,  -9.22038257e-01,  -9.18674469e-01,
                         -9.35684562e-01,  -9.05448139e-01,  -9.28316414e-01,
                         -9.44147527e-01,  -9.21713948e-01,  -9.39092994e-01,
                         -9.18209374e-01,  -9.36630726e-01,  -9.27531898e-01,
                         -9.26566362e-01,  -9.34924722e-01,  -9.25407469e-01,
                         -9.24682677e-01,  -9.28236067e-01,  -9.17613506e-01,
                         -9.22071755e-01,  -9.34927881e-01,  -9.22236800e-01,
                         -9.38053966e-01,  -9.20859993e-01,  -9.20020580e-01,
                         -9.42616761e-01,  -9.24734473e-01,  -9.25624311e-01,
                         -9.21349108e-01,  -9.29014266e-01,  -9.31541920e-01,
                         -9.41288412e-01,  -9.24817324e-01,  -9.34216976e-01,
                         -9.34408784e-01,  -9.23171759e-01,  -9.30255949e-01,
                         -9.31375682e-01,  -9.37054753e-01,  -9.31259930e-01,
                         -9.32563543e-01,  -9.40329909e-01,  -9.26394284e-01,
                         -9.35132086e-01,  -9.28855896e-01,  -9.26133215e-01,
                         -9.04949248e-01,  -9.21497583e-01,  -9.20602202e-01,
                         -9.31035280e-01,  -9.40326154e-01,  -9.30093884e-01,
                         -9.20182288e-01,  -9.24585342e-01,  -9.39085126e-01,
                         -9.38860476e-01,  -9.39753413e-01,  -9.26241577e-01,
                         -9.11002696e-01,  -9.22814608e-01,  -9.44082677e-01,
                         -9.16843057e-01,  -9.25496936e-01,  -1.20270663e-04,
                         -1.07205287e-02,   1.80380214e-02,   2.64877523e-03,
                         -2.34991089e-02,  -1.28891012e-02,  -1.13775465e-03,
                          1.11077446e-03,  -6.00868188e-05,  -5.58943953e-03,
                         -2.35235039e-02,   2.13499484e-03,   5.14584353e-05,
                         -1.08153159e-02,   1.25186769e-02,  -1.38630690e-02,
                          8.09080433e-03,  -1.19299709e-03,   7.97820557e-03,
                          6.89026015e-03,   8.71772412e-03,   7.38748396e-03,
                          5.56309009e-03,  -6.84677856e-03,  -4.19055345e-03,
                         -1.17334863e-02,   4.61566560e-05,   2.27404628e-02,
                          1.33453244e-02,   1.99367641e-03,   9.62389167e-03,
                         -1.42833991e-02,  -1.11474702e-02,  -1.37365814e-02,
                          1.06673306e-02,   8.42968188e-03,   1.50349559e-02,
                         -4.98311035e-03,   1.00443745e-02,   2.98937131e-03,
                          6.30786177e-03,   1.70924887e-02,  -4.92772926e-03,
                          5.18899923e-03,   2.02204287e-03,  -1.19722327e-02,
                         -3.87383276e-04,  -4.49808408e-03,   2.93390709e-03,
                         -9.40520223e-03,   8.75808671e-03,  -1.51891373e-02,
                          1.20283067e-02,  -4.87484317e-03,   1.35306297e-02,
                         -4.22837958e-03,  -2.90553388e-03,  -8.34770873e-03,
                         -1.51326612e-03,  -2.19673803e-03,   2.11495906e-03,
                         -1.13101695e-02,  -8.29123240e-03,  -3.96680413e-03,
                         -4.60289977e-03,  -7.60473218e-03,  -9.12739616e-03,
                          2.07342021e-02,  -7.91561697e-03,   1.31194890e-02,
                         -2.22775177e-03,   1.52470274e-02,  -8.16183444e-03,
                          1.19892191e-02,  -1.58237703e-02,  -3.43556609e-03,
                          1.76288630e-03,  -8.60972051e-03,   2.03616708e-03,
                         -1.75658520e-02,  -8.18614662e-03,  -1.50819993e-04,
                         -5.94083336e-04,   9.51159804e-04,  -1.81561708e-02,
                         -9.56210680e-03,  -1.39021007e-02,   1.45054574e-03,
                         -9.79408273e-04,  -6.28040312e-03,  -7.35443272e-03,
                         -1.85176414e-02,  -3.78127676e-03,  -8.03769659e-03,
                         -1.03891362e-02,  -1.63870268e-02,  -9.23812331e-04,
                         -1.00172348e-02,   9.81271826e-03,  -1.08593376e-02,
                         -7.35528534e-03,  -7.22759217e-03,  -3.42356274e-03,
                         -1.67502929e-03,  -7.64888572e-03,  -8.82399548e-03,
                          3.31675773e-03,   1.16574047e-02,   3.03880591e-03,
                         -1.11195270e-03,  -8.03241599e-03,  -2.10182723e-02,
                          4.27448074e-04,  -1.00172563e-02,  -4.66316706e-03,
                         -1.12663619e-02,  -1.09794280e-02,  -9.94876958e-03,
                         -3.95605527e-03,   6.82282727e-03,  -1.21753011e-02,
                         -2.23580492e-03,   6.72923867e-04,  -6.19093142e-03,
                          8.30619503e-03,  -3.56580969e-03,  -1.55618768e-02,
                          7.10417470e-03,  -5.59334131e-03,   1.41253229e-02,
                         -1.46798342e-02,  -2.81882728e-03,   1.44778257e-02,
                         -1.52516775e-02,   1.34657752e-02,   2.02247668e-02,
                         -6.00706739e-03,   1.24660674e-02,  -6.87391125e-03,
                         -1.28955883e-03,  -1.07417349e-02,  -2.59860940e-02,
                          5.91650714e-05,  -3.09334160e-03,   5.12123341e-03,
                         -5.86286595e-04,   1.28635904e-02,  -1.37590570e-02,
                          6.71379082e-03,  -4.83658724e-03,   3.20647378e-03,
                         -4.15231800e-03,  -4.63380245e-03,   2.68342043e-03,
                          1.00686103e-02,  -1.13452096e-02,   1.92680694e-02,
                          4.40506404e-03,   2.71223043e-03,  -2.35480047e-03,
                          6.94037415e-03,   3.45814554e-03,   1.02574788e-02,
                         -6.14357600e-03,   2.11857678e-03,  -1.17349625e-02,
                          1.80506483e-02,  -3.93046811e-03,   9.41956881e-03,
                          7.88132567e-03,   2.33158353e-03,   7.16991676e-03,
                          6.96307165e-04,   1.08920699e-02,  -7.68162496e-03,
                          1.79304481e-02,   1.99377500e-02,  -7.00506987e-03,
                          6.01415010e-03,  -5.94105478e-03,   3.45992669e-03,
                         -3.05359554e-03,   1.23083657e-02,   1.22840395e-02,
                          2.00672657e-03,  -3.06729018e-03,   2.19041063e-03,
                          7.19950302e-03,   6.27276581e-03,   7.07268296e-03,
                          7.61550199e-03,   1.00465994e-02,   9.06964473e-04,
                          1.67948212e-02,   4.88020713e-03,   2.52813729e-03,
                         -1.15687577e-02,  -1.54476496e-03,   9.10242525e-05,
                          1.20468391e-02,  -1.66945718e-02,  -1.56281865e-03,
                         -2.30722371e-02,  -6.87195687e-03,   1.30952671e-02,
                         -1.32765677e-02,   2.33694067e-04,  -1.42726637e-02,
                          5.59734041e-03,  -2.43308451e-02,  -1.72151858e-03,
                          3.94405844e-03,  -1.11099211e-02,  -1.24644525e-02,
                          1.12210575e-04,  -1.24499956e-02,   1.47312926e-02,
                         -5.50269149e-03,  -3.78550426e-03,  -2.23612785e-02,
                         -9.86894500e-03,   1.49794156e-02,  -1.74872745e-02,
                         -2.13089213e-03,  -1.52195618e-02,  -7.25010224e-03,
                          1.89358729e-03,  -3.86506552e-03,  -1.05987331e-02,
                         -8.20716657e-03,  -2.60068499e-03,  -2.36236840e-03,
                         -1.00945374e-02,   2.99533149e-05,  -7.57573498e-03,
                         -4.93508938e-04,   1.80735532e-02,  -6.93709590e-03,
                         -7.75709050e-03,   1.39538646e-02,   5.93391666e-03,
                         -2.53075710e-03,  -1.02301938e-02,  -3.06604267e-03,
                          7.94340856e-03,  -2.53184307e-02,   7.14437151e-03,
                          3.76264774e-03,  -6.44398900e-03,  -9.79685428e-05,
                          2.40998194e-02,   8.79857503e-03,  -1.24107143e-02,
                          5.21653390e-04,  -6.33234670e-03,   2.24203821e-02,
                         -1.35508319e-02,  -1.15866167e-02,  -1.04336219e-03,
                         -1.57470014e-02,  -1.00859990e-02,   1.72518194e-02,
                         -5.54527203e-03,   1.36514409e-02,  -7.74383724e-01,
                         -7.58610547e-01,  -7.59174228e-01,  -7.70289004e-01,
                         -7.45783746e-01,  -7.66958117e-01,  -7.33610392e-01,
                         -7.51626551e-01,  -7.52362967e-01,  -7.47076750e-01,
                         -7.50961006e-01,  -7.44427681e-01,  -7.47867167e-01,
                         -7.62351036e-01,  -7.69598365e-01,  -7.65023470e-01,
                         -7.48560965e-01,  -7.52417207e-01,  -7.66260564e-01,
                         -7.63999164e-01,  -7.66377807e-01,  -7.70308554e-01,
                         -7.68759251e-01,  -7.84942389e-01,  -7.86768138e-01,
                         -7.61844814e-01,  -7.64473200e-01,  -7.72331655e-01,
                         -7.60004938e-01,  -7.76283920e-01,  -7.65653670e-01,
                         -7.76602149e-01,  -7.76443124e-01,  -7.82942295e-01,
                         -7.57816911e-01,  -7.67848313e-01,  -7.67231345e-01,
                         -7.80716538e-01,  -7.57495046e-01,  -7.63122380e-01,
                         -7.66329408e-01,  -7.95300245e-01,  -7.68488944e-01,
                         -7.83794761e-01,  -7.65562296e-01,  -7.62489617e-01,
                         -7.70928741e-01,  -7.64200628e-01,  -7.64512122e-01,
                         -7.72993386e-01,  -7.65247166e-01,  -7.87745893e-01,
                         -7.68696785e-01,  -7.73927748e-01,  -7.73185551e-01,
                         -7.58344054e-01,  -7.76897609e-01,  -7.69181371e-01,
                         -7.68784940e-01,  -7.81460464e-01,  -7.78532326e-01,
                         -7.58509457e-01,  -7.69919038e-01,  -7.71392703e-01,
                         -7.77638078e-01,  -7.85498083e-01,  -7.69144773e-01,
                         -7.80341268e-01,  -7.76296139e-01,  -7.67314553e-01,
                         -7.84328461e-01,  -7.78899193e-01,  -7.76562631e-01,
                         -7.82658637e-01,  -7.76474178e-01,  -7.78298378e-01,
                         -7.69344389e-01,  -7.81949759e-01,  -7.64618874e-01,
                         -7.86998510e-01,  -9.38315868e-01,  -9.50284243e-01,
                         -9.30919290e-01,  -9.44245458e-01,  -7.59026825e-01,
                         -7.56992400e-01,  -7.61966944e-01,  -7.77850628e-01,
                         -7.68216193e-01,  -7.66170204e-01,  -7.75781512e-01,
                         -7.60706663e-01,  -7.80363321e-01,  -7.61009574e-01,
                         -7.81935275e-01,  -7.91671455e-01,  -7.57674575e-01,
                         -7.74410844e-01,  -7.72626102e-01,  -7.36623526e-01,
                         -9.34487939e-01,  -9.19014871e-01,  -9.41726685e-01,
                         -9.41140711e-01,  -9.35706258e-01,  -9.32022631e-01,
                         -9.20012653e-01,  -9.28671539e-01,  -9.29420292e-01,
                         -9.13390458e-01,  -9.25412774e-01,  -9.40612555e-01,
                         -7.58931100e-01,  -7.49378324e-01,  -7.49739707e-01,
                         -7.56581664e-01,  -7.61910677e-01,  -7.62565970e-01,
                         -7.58861780e-01,  -7.44933426e-01,  -7.73783624e-01,
                         -7.65152216e-01,  -7.68201768e-01,  -7.67346978e-01,
                         -7.52745390e-01,  -7.65739501e-01,  -7.48186767e-01,
                         -7.64413536e-01,  -9.06931162e-01,  -9.34840143e-01,
                         -9.17789280e-01,  -9.32465136e-01,  -9.30584073e-01,
                         -9.28894460e-01,  -9.17178988e-01,  -9.35495496e-01,
                         -7.60258973e-01,  -7.58395076e-01,  -7.70175695e-01,
                         -7.62407184e-01,  -7.59904802e-01,  -7.37169683e-01,
                         -7.65837312e-01,  -7.58616090e-01,  -7.56470203e-01,
                         -7.61552572e-01,  -7.61205852e-01,  -7.50972807e-01,
                         -7.64970720e-01,  -7.69571900e-01,  -7.72101521e-01,
                         -7.83369780e-01,  -9.09379721e-01,  -9.42321479e-01,
                         -9.23634827e-01,  -9.43936944e-01,  -9.35703754e-01,
                         -9.48347390e-01,  -9.21404183e-01,  -9.14935708e-01,
                         -9.38931406e-01,  -9.11705434e-01,  -9.35661376e-01,
                         -9.26766157e-01,  -9.36444104e-01,  -9.24163222e-01,
                         -9.21858370e-01,  -9.29194689e-01,  -7.56885350e-01,
                         -7.78038323e-01,  -7.48331308e-01,  -7.68319368e-01,
                         -7.62046576e-01,  -7.55189776e-01,  -7.73932517e-01,
                         -7.50843465e-01,  -7.59244025e-01,  -7.40990281e-01,
                         -7.66997397e-01,  -7.36439705e-01,  -7.54429698e-01,
                         -7.43237376e-01,  -7.60260940e-01,  -7.53043830e-01,
                         -7.54572392e-01,  -7.60878980e-01,  -7.63032079e-01,
                         -7.75456905e-01,  -7.66383171e-01,  -7.61130989e-01,
                         -7.73721039e-01,  -7.60304689e-01,  -7.70274341e-01,
                         -7.56382227e-01,  -7.49617398e-01,  -7.50126660e-01,
                         -7.34711826e-01,  -7.58589864e-01,  -7.42011487e-01,
                         -7.59046912e-01,  -7.52042592e-01,  -7.52708197e-01,
                         -7.64707208e-01,  -7.54576445e-01,  -7.75400579e-01,
                         -7.58318007e-01,  -7.47926414e-01,  -7.72058904e-01,
                         -7.52775490e-01,  -7.50632524e-01,  -7.69548416e-01,
                         -7.37115860e-01,  -7.61846483e-01,  -7.59663522e-01,
                         -7.61834502e-01,  -7.52363563e-01,   1.03170043e-02,
                          1.98062714e-02,  -4.68399987e-04,   1.99667737e-03,
                         -4.46696626e-03,  -6.75227540e-03,  -1.11118406e-02,
                          5.25520556e-03,  -7.77376115e-01,  -7.68959403e-01,
                         -7.88868010e-01,  -7.56299317e-01,  -7.68678010e-01,
                         -7.51886666e-01,  -7.48740315e-01,  -7.56142259e-01,
                         -7.32841372e-01,  -7.69790471e-01,  -7.43404627e-01,
                         -7.68562198e-01,  -7.63082385e-01,  -7.61436880e-01,
                         -7.42969513e-01,  -7.61726141e-01,  -7.38150835e-01,
                         -7.50267804e-01,  -7.54563332e-01,  -7.51419425e-01,
                         -7.59690762e-01,  -7.37170696e-01,  -7.74795175e-01,
                         -7.70049751e-01,  -7.55393803e-01,  -7.67031550e-01,
                         -7.71467328e-01,  -7.79518247e-01,  -7.64646649e-01,
                         -7.71369576e-01,  -7.56043911e-01,  -7.39075541e-01,
                         -7.68382490e-01,  -7.62085140e-01,  -7.64368653e-01,
                         -7.60322511e-01,  -7.33936965e-01,  -7.72168815e-01,
                         -7.28628814e-01,  -7.80668616e-01,  -7.52305329e-01,
                         -7.75218725e-01,  -7.53320754e-01,  -7.71903276e-01,
                         -7.76269913e-01,  -7.50857592e-01,  -7.80571699e-01,
                         -7.51952171e-01,  -7.67955601e-01,  -7.62884915e-01,
                         -7.58413315e-01,  -7.70128548e-01,  -7.70464122e-01,
                         -7.80087650e-01,  -7.59243369e-01,  -7.56365836e-01,
                          1.71479397e-02,  -8.67370924e-04,  -1.36529589e-02,
                          1.68234780e-02,  -7.73783386e-01,  -7.34322071e-01,
                         -7.67814040e-01,  -7.49072313e-01,  -7.64982820e-01,
                         -7.71474600e-01,  -7.70643532e-01,  -7.61101782e-01,
                         -7.72426784e-01,  -7.53274620e-01,  -7.52867043e-01,
                         -7.59737670e-01,  -7.53674150e-01,  -7.53474653e-01,
                         -7.68917561e-01,  -7.69267976e-01,  -7.66760290e-01,
                         -7.66832888e-01,  -7.48020530e-01,  -7.43655801e-01,
                         -7.52011836e-01,  -7.52113640e-01,  -7.67679393e-01,
                         -7.82744050e-01,  -7.79723346e-01,  -7.61760056e-01,
                         -7.88257003e-01,  -7.42405713e-01,  -7.66860187e-01,
                         -7.45931089e-01,  -7.45340228e-01,  -7.86057889e-01,
                         -7.24398911e-01,  -7.76542723e-01,  -7.47539461e-01,
                         -7.53500879e-01,  -7.85939872e-01,  -7.73951709e-01,
                         -7.90788114e-01,  -7.64577568e-01,  -9.49321128e-03,
                          1.90498363e-02,   1.80675033e-02,   1.73273347e-02,
                          9.07380320e-03,   1.28461113e-02,   5.38246939e-03,
                         -9.46895499e-03,  -7.78449833e-01,  -7.61818886e-01,
                         -7.63706028e-01,  -7.54497945e-01,  -7.38903522e-01,
                         -7.82681167e-01,  -7.52126336e-01,  -7.73775637e-01,
                         -7.59409606e-01,  -7.42452145e-01,  -7.59672523e-01,
                         -7.76159823e-01,  -7.59591520e-01,  -7.67898500e-01,
                         -7.39613712e-01,  -7.50872195e-01,  -7.50128090e-01,
                         -7.57911921e-01,  -7.70340443e-01,  -7.42401958e-01,
                         -7.72556007e-01,  -7.64117718e-01,  -7.42656231e-01,
                         -7.71292508e-01,  -7.74534583e-01,  -7.65350878e-01,
                         -7.74783492e-01,  -7.66319752e-01,  -7.46498466e-01,
                         -7.67040551e-01,  -7.76393056e-01,  -7.62195289e-01,
                         -7.46199846e-01,  -7.41697609e-01,  -7.44693935e-01,
                         -7.57987559e-01,  -7.48674851e-03,  -5.47459535e-03,
                          2.85058259e-03,   2.17769537e-02,  -7.74733543e-01,
                         -7.43937075e-01,  -7.52671063e-01,  -7.67690182e-01,
                         -7.54210234e-01,  -7.75502503e-01,  -7.44129121e-01,
                         -7.67740369e-01,  -7.75269508e-01,  -7.53881454e-01,
                         -7.82296598e-01,  -7.47947574e-01,  -7.53780484e-01,
                         -7.93506622e-01,  -7.29164898e-01,  -8.03876162e-01,
                         -7.45943308e-01,  -7.49385238e-01,  -7.89320350e-01,
                         -7.54784286e-01,  -7.78175175e-01,  -7.53810406e-01,
                         -7.66059399e-01,  -7.57578373e-01,  -7.59412706e-01,
                         -7.48881400e-01,  -7.64919460e-01,  -7.62878537e-01,
                         -7.61414886e-01,  -7.73432255e-01,  -7.55528212e-01,
                         -7.70330310e-01,  -7.62789309e-01,  -7.74998128e-01,
                         -7.74736166e-01,  -7.59151816e-01,  -7.69377053e-01,
                         -7.61703432e-01,  -7.69193828e-01,  -7.56401300e-01,
                         -7.60101736e-01,  -7.54251540e-01,  -7.63721883e-01,
                         -7.38790929e-01,  -7.79652596e-01,  -7.62552977e-01,
                         -7.72645116e-01,  -7.63190210e-01,  -7.55590618e-01,
                         -7.71973789e-01,  -7.52733707e-01,  -7.64948666e-01,
                         -9.49687362e-01,  -9.37310040e-01,  -9.26949084e-01,
                         -9.20318604e-01,  -9.08753514e-01,  -9.39372778e-01,
                         -9.29211855e-01,  -9.24567342e-01,  -9.32068884e-01,
                         -9.50184762e-01,  -9.48511064e-01,  -9.42243636e-01,
                         -7.69752204e-01,  -7.70344496e-01,  -7.60861993e-01,
                         -7.61188030e-01,  -7.78098702e-01,  -7.38938451e-01,
                         -7.59354293e-01,  -7.59557486e-01,  -7.70389736e-01,
                         -7.57737100e-01,  -7.75140762e-01,  -7.38690317e-01,
                         -7.71391511e-01,  -7.68712401e-01,  -7.45085895e-01,
                         -7.87748814e-01,  -7.53457069e-01,  -7.74983525e-01,
                         -7.43986428e-01,  -7.80724943e-01,  -7.44115591e-01,
                         -7.53968716e-01,  -7.98161745e-01,  -7.53872097e-01,
                         -9.58605945e-01,  -9.20789659e-01,  -9.40696180e-01,
                         -9.16795552e-01,  -9.42173541e-01,  -9.27034557e-01,
                         -9.64597940e-01,  -9.01862025e-01,  -9.63420689e-01,
                         -9.31798637e-01,  -9.34494257e-01,  -8.98118138e-01,
                         -7.64728367e-01,  -7.46932268e-01,  -7.81470716e-01,
                         -7.83711195e-01,  -9.19588864e-01,  -9.29869056e-01,
                         -9.28588688e-01,  -9.43897724e-01,  -9.31820452e-01,
                         -9.35228825e-01,  -9.52903032e-01,  -9.39558268e-01,
                         -9.29313123e-01,  -9.41041589e-01,  -9.27887201e-01,
                         -9.36568618e-01,  -9.58991766e-01,  -9.49228406e-01,
                         -9.41899419e-01,  -9.53780711e-01,  -9.21343505e-01,
                         -9.43842590e-01,  -9.16631997e-01,  -9.22194362e-01,
                         -9.25313175e-01,  -9.33108866e-01,  -9.29223776e-01,
                         -9.46171582e-01,  -7.62519062e-01,  -7.67042756e-01,
                         -7.58245170e-01,  -7.43048847e-01,  -7.67065227e-01,
                         -7.46250212e-01,  -7.70293772e-01,  -7.52231717e-01,
                         -7.48081326e-01,  -7.67200708e-01,  -7.57086933e-01,
                         -7.66776741e-01,  -7.67163992e-01,  -7.78002501e-01,
                         -7.66530693e-01,  -7.64243782e-01,  -7.63729095e-01,
                         -7.37276554e-01,  -7.59902477e-01,  -7.65993357e-01,
                         -9.33775723e-01,  -9.35765266e-01,  -9.30020273e-01,
                         -9.28857803e-01,  -9.28500235e-01,  -9.44421113e-01,
                         -9.19814110e-01,  -9.28672314e-01,  -9.52790618e-01,
                         -9.18085217e-01,  -9.54236031e-01,  -8.94157648e-01,
                         -9.52889502e-01,  -9.19787288e-01,  -9.22371328e-01,
                         -9.40665901e-01,  -7.75330842e-01,  -7.46280015e-01,
                         -7.65989542e-01,  -7.42794156e-01,  -7.95286000e-01,
                         -7.43007004e-01,  -7.62885571e-01,  -7.48380899e-01,
                          2.05093576e-03,   9.80047882e-03,  -1.27767306e-03,
                          1.53195541e-02,   5.25716692e-03,  -1.52115226e-02,
                          6.07034191e-03,   3.58252600e-03,  -1.39498999e-02,
                          1.11676035e-02,  -8.25878466e-04,  -4.30308282e-03,
                         -7.28348970e-01,  -7.57343411e-01,  -7.54832923e-01,
                         -7.53847301e-01,  -4.77442797e-03,   1.96269471e-02,
                          4.30279830e-03,   4.28665057e-03,   1.69240516e-02,
                         -2.64516938e-02,   3.05710584e-02,   6.05744449e-03,
                          1.55688092e-01,   1.73893690e-01,   1.66328490e-01,
                          1.70608342e-01,   2.22250819e-02,   1.07636489e-03,
                          1.89733668e-03,   1.16878292e-02,   1.39306337e-01,
                          1.89636022e-01,   1.68362319e-01,   1.79135144e-01,
                          8.67645349e-03,  -4.86310991e-03,   1.51426755e-02,
                          2.67531741e-02,  -6.08876999e-03,  -1.06634283e-02,
                          2.17572227e-02,  -1.51650468e-02,   3.35026234e-02,
                         -1.27396323e-02,   1.44286333e-02,   1.32730883e-03,
                          1.75424218e-01,   1.83777645e-01,   1.57064617e-01,
                          1.77525699e-01,   1.76564068e-01,   1.70093074e-01,
                          1.92364499e-01,   1.78574562e-01,   1.81017950e-01,
                          1.51268870e-01,   1.81627005e-01,   1.42415628e-01,
                          1.73322707e-01,   1.69197559e-01,   1.62398055e-01,
                          1.68863177e-01,   1.71590373e-01,   1.68070421e-01,
                          1.82926267e-01,   1.58467606e-01,   1.94164261e-01,
                          1.79060087e-01,   1.80492297e-01,   1.80925116e-01,
                          1.71228662e-01,   1.93750620e-01,   1.66970938e-01,
                          1.89080879e-01,   1.52363285e-01,   1.95461199e-01,
                          1.44872621e-01,   1.74495250e-01,   1.79889038e-01,
                          1.72969043e-01,   2.04382405e-01,   1.79760143e-01,
                          1.81119472e-01,   1.53727412e-01,   1.85178265e-01,
                          1.78706318e-01,   1.95091993e-01,   1.74536735e-01,
                          1.85698465e-01,   2.01267362e-01,   1.52671963e-01,
                          1.94908977e-01,   1.56862110e-01,   1.92320570e-01,
                          1.77619129e-01,   1.81431979e-01,   1.95622250e-01,
                          1.98865175e-01,   1.86887100e-01,   2.04515859e-01,
                          1.87196568e-01,   1.66722178e-01,   1.95139766e-01,
                          1.57206535e-01,   1.78678125e-01,   1.62247539e-01,
                          5.65478671e-03,   2.32441048e-03,   1.84192639e-02,
                          1.63194556e-02,   3.59123060e-03,   8.66899674e-04,
                         -1.08074285e-02,   1.63630897e-03,  -6.99993409e-03,
                          9.99304838e-03,   7.13824481e-03,   1.99485533e-02,
                         -6.31360710e-03,   3.78976017e-02,  -2.71485001e-02,
                          2.52860524e-02,   3.28186862e-02,  -6.03014557e-03,
                          3.79407518e-02,   3.21040191e-02,   1.66572526e-01,
                          1.93967015e-01,   1.54642880e-01,   1.82307705e-01,
                          1.68417573e-01,   2.02320546e-01,   1.84832603e-01,
                          1.80395022e-01,   1.76715165e-01,   1.92057207e-01,
                          1.59735620e-01,   1.72881052e-01,   1.45484949e-03,
                          2.63004582e-02,   8.67056940e-03,   2.99904123e-02,
                          1.08643416e-02,  -1.39068002e-02,   1.44217582e-02,
                         -3.16023752e-02,   3.07788942e-02,   9.22882929e-03,
                          1.61186252e-02,  -4.81808279e-03,   2.07478814e-02,
                         -1.60517674e-02,  -3.45617719e-03,  -1.60426535e-02,
                         -6.09899219e-03,   2.17682496e-02,  -2.22282968e-02,
                          4.24800627e-03,   8.44022259e-03,  -2.62534842e-02,
                          1.06961951e-02,  -7.44154118e-03,   1.36577967e-03,
                          1.51237904e-03,  -8.38676840e-03,   2.39602267e-03,
                         -4.46395157e-03,  -2.15276387e-02,   8.23626062e-04,
                         -2.62092613e-02,  -1.53873824e-02,   1.91052526e-03,
                          8.20846297e-03,  -5.07786311e-03,   1.58514157e-02,
                         -4.55756113e-03,   1.66993886e-02,   3.05128773e-03,
                         -1.37597434e-02,   3.16843614e-02,  -1.03557315e-02,
                         -1.86841115e-02,   1.16969496e-02,  -5.98920044e-03,
                          1.70160327e-02,  -2.23930404e-02,  -1.59863029e-02,
                         -4.38568648e-03,  -1.38562424e-02,   8.81138910e-03,
                          9.15849954e-03,  -3.03557981e-02,   2.14685425e-02,
                         -6.19802158e-04,   1.16253998e-02,  -1.92194097e-02,
                         -1.32928817e-02,  -5.17698890e-03,  -2.36256933e-03,
                         -2.21838173e-03,  -1.07059879e-02,  -1.57353729e-02,
                         -2.79945675e-02,   1.40374457e-03,  -1.97567549e-02,
                         -1.46519598e-02,   1.47921136e-02,  -2.99907178e-02,
                         -4.34427027e-04,  -2.27631181e-02,  -7.59500172e-03,
                         -6.78391289e-03,  -8.22234433e-03,   1.25121966e-04,
                         -1.60892829e-02,  -6.92693610e-03,   1.17087038e-02,
                          2.51719425e-03,   7.11821578e-03,  -4.31475323e-03,
                          1.00320801e-02,  -1.09296544e-02,   5.71120018e-03,
                         -6.74443040e-03,   1.47381122e-03,  -3.00687887e-02,
                         -2.11105309e-02,  -1.42498072e-02,  -1.52902314e-02,
                          2.03966675e-03,  -2.72174235e-02,   7.27890478e-03,
                         -2.50151902e-02,  -2.13832352e-02,   9.24075674e-03,
                         -1.02303252e-02,  -1.03311904e-03,  -4.99381777e-03,
                         -9.13037896e-01,  -9.28503633e-01,  -9.34269071e-01,
                         -9.39707279e-01,  -9.25472617e-01,  -9.40995157e-01,
                         -9.24019635e-01,  -9.28569138e-01,  -9.43373799e-01,
                         -9.38705862e-01,  -9.37184930e-01,  -9.33132231e-01,
                         -1.47301275e-02,  -2.88787298e-02,   1.01733848e-03,
                         -3.81619926e-03,   3.83373327e-03,  -6.10089116e-03,
                         -8.19661841e-03,   1.49476603e-02,  -1.07495040e-02,
                          1.45539008e-02,   2.10257433e-03,  -2.41858531e-02,
                         -9.22750771e-01,  -9.17960942e-01,  -9.32175636e-01,
                         -9.27020848e-01,  -9.63520348e-01,  -9.27876532e-01,
                         -9.46938336e-01,  -9.36932921e-01,  -9.42276418e-01,
                         -9.53066528e-01,  -9.40079093e-01,  -9.28046644e-01,
                         -9.48157787e-01,  -9.30568099e-01,  -9.42952096e-01,
                         -9.51948881e-01,  -9.16923821e-01,  -9.49907362e-01,
                         -9.09399033e-01,  -9.49203670e-01,  -9.28723097e-01,
                         -9.41879809e-01,  -9.24585521e-01,  -9.38009262e-01,
                         -9.43975091e-01,  -9.29308891e-01,  -9.56305385e-01,
                         -9.39882159e-01,  -9.52073932e-01,  -9.43252265e-01,
                         -9.31540728e-01,  -9.49160278e-01,  -9.27768350e-01,
                         -9.23745334e-01,  -9.52302575e-01,  -9.23477292e-01,
                         -9.35592055e-01,  -9.21446979e-01,  -9.26153839e-01,
                         -9.21875834e-01,  -9.11764920e-01,  -9.28233385e-01,
                         -9.17966306e-01,  -9.13353443e-01,  -9.16402936e-01,
                         -9.19357300e-01,  -9.23580050e-01,  -9.35282350e-01,
                         -9.37240958e-01,  -9.33804810e-01,  -9.58352566e-01,
                         -9.32662666e-01,  -9.34075117e-01,  -9.33313787e-01,
                         -9.17647660e-01,  -9.55530167e-01,  -9.19617951e-01,
                         -9.42825556e-01,  -9.46033955e-01,  -9.30268049e-01,
                         -9.38483119e-01,  -9.27219450e-01,  -9.34097290e-01,
                         -9.38979745e-01,  -9.40722048e-01,  -9.41106439e-01,
                         -9.35312212e-01,  -9.24173176e-01,  -9.29116189e-01,
                         -9.25797403e-01,  -9.29305375e-01,  -9.22252178e-01,
                         -9.40021992e-01,  -9.26125467e-01,  -9.25367415e-01,
                         -9.22710299e-01,  -9.23783004e-01,  -9.24970388e-01,
                         -9.27364528e-01,  -9.28171039e-01,  -9.42346156e-01,
                         -9.46303844e-01,  -9.44888711e-01,  -9.54888940e-01,
                         -9.20836926e-01,  -9.32150245e-01,  -9.05920923e-01,
                         -9.34683323e-01,  -9.37006414e-01,  -9.27617967e-01,
                         -9.39687133e-01,  -9.29972649e-01,  -9.42041218e-01,
                         -9.37629163e-01,  -9.32030380e-01,  -9.25498426e-01,
                         -9.38409269e-01,  -9.49093878e-01,  -9.49231505e-01,
                         -9.24284697e-01,  -9.28333163e-01,  -9.31453526e-01,
                         -9.32898283e-01,  -9.44667041e-01,  -9.46187496e-01,
                         -9.23335373e-01,  -9.39891279e-01,  -9.40194547e-01,
                         -9.30532157e-01,  -9.25268590e-01,  -9.24206972e-01,
                         -9.28813279e-01,  -9.29177701e-01,  -9.19679701e-01,
                         -9.16297734e-01,  -9.30058062e-01,  -9.22380269e-01,
                         -9.18457687e-01,  -9.14901435e-01,  -9.28946733e-01,
                         -9.15321469e-01,  -9.30602372e-01,  -9.19516683e-01,
                         -9.37264681e-01,  -9.25559461e-01,  -9.33634460e-01,
                         -9.34350789e-01,  -9.38722491e-01,  -9.22645569e-01,
                         -9.21359122e-01,  -9.23653722e-01,  -9.08139944e-01,
                         -9.15016770e-01,  -9.22224164e-01,  -9.37683940e-01,
                         -9.15608943e-01,  -9.26097691e-01,  -9.18782055e-01,
                         -9.20569360e-01,  -9.18444216e-01,  -9.35073435e-01,
                         -9.18927550e-01,  -9.31702793e-01,  -9.18344259e-01,
                         -9.32734370e-01,  -9.24740076e-01,  -9.30152297e-01,
                         -9.22762752e-01,  -9.26818967e-01,  -9.36370492e-01,
                         -9.33397412e-01,  -9.38442647e-01,  -9.32989001e-01,
                         -9.33667302e-01,  -9.24374282e-01,  -9.31535959e-01,
                         -9.32478487e-01,  -9.37075973e-01,  -9.18027282e-01,
                         -9.40591633e-01,  -9.47490692e-01,  -9.26216960e-01,
                         -9.41124678e-01,  -9.30560708e-01,  -9.35809612e-01,
                         -9.22252119e-01,  -9.36396778e-01,  -9.11705196e-01,
                         -9.30231988e-01,  -9.18168187e-01,  -9.46212590e-01,
                         -9.25686955e-01,  -9.40662801e-01,  -9.37166750e-01,
                         -9.29882288e-01,  -9.39010143e-01,  -9.39934254e-01,
                         -9.43835080e-01,  -9.35972512e-01,  -9.46068227e-01,
                         -9.26578999e-01,  -9.37450886e-01,  -9.40762162e-01,
                         -9.49404359e-01,  -9.37555075e-01,  -9.39618170e-01,
                         -9.06910419e-01,  -9.40512657e-01,  -9.27869678e-01,
                         -9.31336462e-01,  -9.28220689e-01,  -9.35242414e-01,
                         -9.15678799e-01,  -9.36515749e-01,  -9.08369660e-01,
                         -9.23982859e-01,  -9.13829327e-01,  -9.37518835e-01,
                         -9.34893489e-01,  -9.24911082e-01,  -9.26923871e-01,
                         -9.29779053e-01,  -9.19506669e-01,  -9.18875873e-01,
                         -8.99226665e-01,  -9.14272428e-01,  -9.16577935e-01,
                         -9.22114372e-01,  -9.09273744e-01,  -9.15954232e-01,
                         -9.31850851e-01,  -9.27253067e-01,  -9.21208382e-01,
                         -9.27301645e-01,  -9.41908598e-01,  -9.33069587e-01,
                         -9.22135472e-01,  -9.29979086e-01,  -9.16100085e-01,
                         -9.12330925e-01,  -9.27610338e-01,  -9.27570403e-01,
                         -9.38565612e-01,  -9.30107296e-01,  -9.15003598e-01,
                         -9.24916327e-01,  -9.22688603e-01,  -9.34348226e-01,
                         -9.20986414e-01,  -9.22452450e-01,  -9.09635961e-01,
                         -9.13651884e-01,  -9.18956757e-01,  -9.08141911e-01,
                         -9.23084974e-01,  -9.25985813e-01,  -9.23491418e-01,
                         -9.25399005e-01,  -9.25100625e-01,  -9.25782025e-01,
                         -9.26546037e-01,  -9.44032311e-01,  -9.21093881e-01,
                         -9.16655004e-01,  -9.20586050e-01,  -9.14763808e-01,
                         -9.21968222e-01,  -9.40019250e-01,  -9.35428202e-01,
                         -9.35227931e-01,  -9.29123998e-01,  -9.16670084e-01,
                         -7.67096598e-03,   4.02912265e-03,   3.36891622e-03,
                         -4.47540777e-03,  -1.13705331e-02,   1.13860294e-02,
                          3.10074328e-03,   3.35211679e-03,   7.55740423e-03,
                          1.43515673e-02,   4.73874994e-03,  -1.08612992e-03,
                          1.26095000e-03,   1.60912927e-02,  -4.02761885e-04,
                          6.05951669e-03,  -7.19621079e-04,   9.92193446e-03,
                          3.19242594e-03,   1.39638307e-02,   5.30606834e-03,
                          1.76336654e-02,   1.83710642e-02,   1.61423422e-02,
                          1.24115739e-02,   2.46665403e-02,   7.75205204e-03,
                          3.03930156e-02,   1.03999544e-02,  -1.86990597e-03,
                          1.25014130e-02,   1.73368840e-03,   3.61045543e-03,
                          6.83117146e-03,  -4.68576001e-03,   7.10438297e-04,
                          1.20736109e-02,   4.97008115e-03,   3.12404335e-03,
                          8.23909510e-03,  -1.52246282e-03,   1.23759862e-02,
                          1.22472672e-02,   2.08000885e-03,  -1.79879628e-02,
                          1.30789736e-02,  -6.31449418e-03,  -2.03884207e-03,
                         -9.30388808e-01,  -9.24843788e-01,  -9.22894955e-01,
                         -9.22289193e-01,  -9.32888508e-01,  -9.39487636e-01,
                         -9.43844616e-01,  -9.11073327e-01,  -9.29515898e-01,
                         -9.25079942e-01,  -9.11915839e-01,  -9.41708028e-01,
                         -9.20385361e-01,  -9.28871095e-01,  -9.55037415e-01,
                         -9.38382626e-01,  -9.27976191e-01,  -9.28421736e-01,
                         -9.30744529e-01,  -9.40297306e-01,  -9.19566333e-01,
                         -9.24848914e-01,  -9.44292009e-01,  -9.33299243e-01,
                         -9.42210257e-01,  -9.32292163e-01,  -9.30465102e-01,
                         -9.29092288e-01,  -9.28973377e-01,  -9.47951615e-01,
                         -9.43108737e-01,  -9.30394769e-01,  -9.19860959e-01,
                         -9.29296374e-01,  -9.28758383e-01,  -9.22585249e-01,
                         -9.15470064e-01,  -9.22759175e-01,  -9.26831663e-01,
                         -8.99324298e-01,  -9.22559202e-01,  -9.35007572e-01,
                         -9.44509387e-01,  -9.15280223e-01,  -9.18826282e-01,
                         -9.45615351e-01,  -9.23367321e-01,  -9.23183262e-01,
                         -9.28955615e-01,  -9.16825056e-01,  -9.48380649e-01,
                         -9.25275266e-01,  -9.30719674e-01,  -9.13888335e-01,
                         -9.24170911e-01,  -9.19015586e-01,  -9.21236217e-01,
                         -9.16205406e-01,  -9.33672845e-01,  -9.29825664e-01,
                         -9.23635542e-01,  -9.36975837e-01,  -9.26974297e-01,
                         -9.27438200e-01,  -9.33939278e-01,  -9.22905028e-01,
                         -9.26806033e-01,  -9.42819655e-01,  -9.24772859e-01,
                         -9.46967185e-01,  -9.18216288e-01,  -9.07549977e-01,
                         -9.23101068e-01,  -9.32478249e-01,  -9.27590251e-01,
                         -9.30229247e-01,  -9.31071758e-01,  -9.23936009e-01,
                         -9.36131835e-01,  -9.32995677e-01,  -9.42831755e-01,
                         -9.28078294e-01,  -9.25873995e-01,  -9.48452592e-01,
                         -9.41582084e-01,  -9.38040555e-01,  -9.32163000e-01,
                         -9.25640702e-01,  -9.35082972e-01,  -9.27295923e-01,
                         -9.27643657e-01,  -9.29760754e-01,  -9.33916867e-01,
                         -9.16315973e-01,  -9.30163145e-01,  -9.40464973e-01,
                         -9.26194370e-01,  -9.35996711e-01,  -9.39418852e-01,
                         -9.46723878e-01,  -9.43889737e-01,  -9.42752898e-01,
                         -9.36319470e-01,  -9.43222106e-01,  -9.31953073e-01,
                         -9.37318325e-01,  -9.31415260e-01,  -9.22886193e-01,
                         -9.28569019e-01,  -9.28524911e-01,  -9.30368960e-01,
                         -9.47361708e-01,  -9.35246766e-01,  -9.31236863e-01,
                         -9.37162876e-01,  -9.35222924e-01,  -9.40520227e-01,
                         -9.33558404e-01,  -9.43236470e-01,  -9.29842174e-01,
                         -9.37861919e-01,  -9.27716076e-01,  -9.46810126e-01,
                         -9.47832227e-01,  -9.46573973e-01,  -9.41197276e-01,
                         -9.19153512e-01,  -9.31934357e-01,  -9.22836602e-01,
                         -9.37730849e-01,  -9.44020569e-01,  -9.30761516e-01,
                         -9.34208512e-01,  -9.37661767e-01,  -9.37016606e-01,
                         -9.45989013e-01,  -9.32942212e-01,  -9.42760229e-01,
                         -9.20643270e-01,  -9.30059612e-01,  -9.21704054e-01,
                         -9.33723152e-01,  -9.35472548e-01,  -9.35652077e-01,
                         -9.33700085e-01,  -9.29561734e-01,  -9.40203309e-01,
                         -9.40580547e-01,  -9.46267605e-01,  -9.32305038e-01,
                         -9.22752678e-01,  -9.29498971e-01,  -9.28533614e-01,
                         -9.29833055e-01,  -9.32764769e-01,  -9.26486015e-01,
                         -9.34086680e-01,  -9.28061903e-01,  -9.25358891e-01,
                         -9.23927069e-01,  -9.24869061e-01,  -9.26321924e-01,
                         -9.23013449e-01,  -9.23262596e-01,  -9.30592597e-01,
                         -9.38419580e-01,  -9.23776388e-01,  -9.30992603e-01,
                         -9.27890182e-01,  -9.27070200e-01,  -9.31724429e-01,
                         -9.41882014e-01,  -9.38789845e-01,  -9.31589484e-01,
                         -9.32963908e-01,  -9.38815296e-01,  -9.34881032e-01,
                         -9.35212970e-01,  -9.32820439e-01,  -9.39770818e-01,
                         -9.29788053e-01,  -9.28755403e-01,  -9.23665941e-01,
                         -9.30034220e-01,  -9.37681258e-01,  -9.35756981e-01,
                         -9.34832931e-01,  -9.31513429e-01,  -9.27217901e-01,
                         -9.30310726e-01,  -9.34031129e-01,  -9.41468418e-01,
                         -9.33561087e-01,  -9.24508452e-01,  -9.32455182e-01,
                         -9.36393678e-01,  -9.31100488e-01,  -9.31678772e-01,
                         -9.39399481e-01,  -9.30736542e-01,  -9.33445752e-01,
                         -9.33007717e-01,  -9.30132329e-01,  -9.32330012e-01,
                         -9.28088784e-01,  -9.30876493e-01,  -9.34538841e-01,
                         -9.34194446e-01,  -9.32078421e-01,  -9.36437488e-01,
                         -9.35051382e-01,  -9.33547437e-01,  -9.38243687e-01,
                         -9.38722491e-01,  -9.32849944e-01,  -9.40977931e-01,
                         -9.31197524e-01,  -9.27769601e-01,  -9.36155677e-01,
                         -9.28022027e-01,  -9.37150896e-01,  -9.31346893e-01,
                         -9.39719617e-01,  -9.29547071e-01,  -9.34306979e-01,
                         -9.33285952e-01,  -9.36604559e-01,  -9.30468619e-01,
                         -9.35763478e-01,  -9.36120987e-01,  -9.39076662e-01,
                         -9.28718090e-01,  -9.31900203e-01,  -9.22118187e-01,
                         -9.39842224e-01,  -9.30429697e-01,  -9.31431055e-01,
                         -9.45217252e-01,  -9.33498502e-01,  -9.40141201e-01,
                         -9.32488799e-01,  -9.33016300e-01,  -9.32072759e-01,
                         -9.32718754e-01,  -9.31598127e-01,  -9.33101654e-01,
                         -9.28517461e-01,  -9.31613564e-01,  -9.38810647e-01,
                         -9.43101406e-01,  -9.35774684e-01,  -9.34149444e-01,
                         -9.30425942e-01,  -9.34087217e-01,  -9.41335917e-01,
                         -9.37438667e-01,  -9.30738866e-01,  -9.34226394e-01,
                         -9.40222263e-01,  -9.32927668e-01,  -9.35690224e-01,
                         -9.38808918e-01,  -9.37483668e-01,  -9.33264315e-01,
                         -9.35435355e-01,  -9.35111284e-01,  -9.29125190e-01,
                         -9.33816433e-01,  -9.34363008e-01,  -9.38294291e-01,
                         -9.31435108e-01,  -9.31723535e-01,  -9.34958994e-01,
                         -9.34633434e-01,  -9.27225113e-01,  -9.29423511e-01,
                         -9.43469107e-01,  -9.41484928e-01,  -9.30010974e-01,
                         -9.34827030e-01,  -9.37241197e-01,  -9.31501567e-01,
                         -9.25491691e-01,  -9.37897205e-01,  -9.39811647e-01,
                         -9.35043156e-01,  -9.39742804e-01,  -9.38229382e-01,
                         -9.38527584e-01,  -9.30627346e-01,  -9.21075344e-01,
                         -9.21367526e-01,  -9.32755709e-01,  -9.26973522e-01,
                         -9.31142747e-01,  -9.26440537e-01,  -9.32569742e-01,
                         -9.24248338e-01,  -9.30046022e-01,  -9.27932918e-01,
                         -9.28098679e-01,  -9.33033466e-01,  -9.39236581e-01,
                         -9.40156281e-01,  -9.27700460e-01,  -9.29643810e-01,
                         -9.32095230e-01,  -9.34169948e-01,  -9.36385214e-01,
                         -9.35959220e-01,  -9.30637419e-01,  -9.34494495e-01,
                         -9.25420582e-01,  -9.33692813e-01,  -9.32531118e-01,
                         -9.31239426e-01,  -9.24745321e-01,  -9.32273448e-01,
                         -9.45011556e-01,  -9.30628777e-01,  -9.38152552e-01,
                         -9.37113345e-01,  -9.39393580e-01,  -9.32162225e-01,
                         -9.42497432e-01,  -9.35955346e-01,  -9.28945243e-01,
                         -9.38296139e-01,  -9.36480165e-01,  -9.39061940e-01,
                         -9.30083394e-01,  -9.38869536e-01,  -9.30351973e-01,
                         -9.33516145e-01,  -9.44555938e-01,  -9.39963639e-01,
                         -9.42948103e-01,  -9.44813073e-01,  -9.43401039e-01,
                         -9.38391626e-01,  -9.35827255e-01,  -9.32457387e-01,
                         -9.42539334e-01,  -9.39859748e-01,  -9.31924284e-01,
                         -9.43879426e-01,  -9.31915820e-01,  -9.36143398e-01,
                         -9.47648883e-01,  -9.41210926e-01,  -9.37935114e-01,
                         -9.33162630e-01,  -9.35287237e-01,  -9.46079433e-01,
                         -9.19943571e-01,  -9.20882761e-01,  -9.24482644e-01,
                         -9.35400784e-01,  -9.30295467e-01,  -9.33713436e-01,
                         -9.26111698e-01,  -9.37580049e-01,  -9.42022622e-01,
                         -9.32163894e-01,  -9.35071886e-01,  -9.30785894e-01,
                         -9.36899543e-01,  -9.33906794e-01,  -9.47150707e-01,
                         -9.57423568e-01,  -9.41392004e-01,  -9.28910851e-01,
                         -9.36439931e-01,  -9.39798474e-01,  -9.18570578e-01,
                         -9.22076762e-01,  -9.38178480e-01,  -9.29710805e-01,
                         -9.24874067e-01,  -9.26664531e-01,  -9.27619338e-01,
                         -9.19887722e-01,  -9.29655015e-01,  -9.28022683e-01,
                         -9.46181417e-01,  -9.35479522e-01,  -9.31186438e-01,
                         -9.31840420e-01,  -9.42799926e-01,  -9.38026905e-01,
                         -9.35188532e-01,  -9.27188516e-01,  -9.34453130e-01,
                         -9.54560041e-01,  -9.36639369e-01,  -9.32449102e-01,
                         -9.44356799e-01,  -9.33012962e-01,  -9.40687895e-01,
                         -9.40901458e-01,  -9.30937052e-01,  -9.30140555e-01,
                         -9.41063583e-01,  -9.38599765e-01,  -9.35629427e-01,
                         -9.41874802e-01,  -9.33189452e-01,  -9.19825494e-01,
                         -9.28199232e-01,  -9.38522696e-01,  -9.39175487e-01,
                         -9.14463639e-01,  -9.33118522e-01,  -9.28247154e-01,
                         -9.19043005e-01,  -9.22976673e-01,  -9.24816549e-01,
                         -9.46764350e-01,  -9.21536148e-01,  -9.27415669e-01,
                         -9.13072824e-01,  -9.14467454e-01,  -9.38769102e-01,
                         -9.42038476e-01,  -9.26543415e-01,  -9.35891926e-01,
                         -9.28128600e-01,  -9.23159957e-01,  -1.25409644e-02,
                         -7.28620263e-03,  -1.60768628e-02,  -4.89929365e-03,
                          1.46898758e-02,   1.10617271e-02,   1.07902968e-02,
                         -5.97457029e-03,   4.10212809e-03,   8.18343647e-03,
                          7.81849434e-04,   8.41630623e-03,  -1.82468491e-03,
                         -1.24508003e-02,  -9.06296354e-03,  -1.07801231e-02,
                         -2.90416856e-03,   3.95125244e-03,  -7.94518273e-04,
                          4.54701995e-03,   3.28804031e-02,   3.01142465e-02,
                          1.19680054e-02,   1.50538553e-02,   1.41840028e-02,
                          1.67008094e-03,   1.73771642e-02,   1.12759117e-02,
                          9.26702342e-04,   3.82399582e-03,   1.01621989e-02,
                          4.96349018e-03,   9.75313690e-03,   3.24963662e-03,
                          6.39379909e-03,   6.77652517e-03,  -4.69353609e-03,
                          1.46747055e-02,  -3.37550021e-03,   4.99334652e-03,
                         -1.92997896e-03,  -9.25636385e-03,  -4.82802792e-03,
                         -3.10964184e-03,  -4.99778893e-03,  -1.15024196e-02,
                         -6.10626955e-03,   9.15508252e-03,   4.52812063e-03,
                         -7.44840223e-03,  -6.02169754e-03,  -7.36539671e-03,
                          5.74800791e-03,   9.01780499e-04,   5.95060503e-03,
                         -1.62616279e-03,   7.08438177e-03,   1.27053065e-02,
                          9.48727876e-03,   7.88429193e-03,   1.06707402e-02,
                          2.46297121e-02,   1.53423066e-03,   3.00526270e-03,
                          9.63537581e-03,   3.88179580e-03,   6.11880654e-03,
                          1.22369267e-02,   1.33977113e-02,   2.49461494e-02,
                         -2.41416646e-03,   7.14423251e-04,   8.85653368e-04,
                         -2.83159316e-03,   9.51640774e-03,   1.32302446e-02,
                          1.10122021e-02,   2.91157723e-03,   1.50503553e-02,
                          1.27558913e-02,   3.75402626e-03,   1.27161597e-03,
                          1.05303712e-02,   1.15184216e-02,   3.15842521e-03,
                          5.56845404e-03,   2.79680244e-03,  -3.56990565e-03,
                         -8.17809347e-03,  -8.67606548e-04,  -3.65194795e-03,
                         -7.22227618e-03,   2.04049167e-03,  -1.70796260e-03,
                         -1.74754374e-02,  -1.32387970e-02,   7.97522627e-03,
                         -4.04613698e-03,  -1.07154832e-03,  -1.36507694e-02,
                         -6.17750734e-03,  -9.93287843e-03,  -1.55992177e-03,
                         -1.34814521e-02,  -1.12609491e-02,  -6.83444971e-03,
                         -1.93855877e-03,  -2.31115874e-02,  -1.30140979e-03,
                         -4.47205361e-03,   1.11922547e-02,   1.18348859e-02,
                         -1.00210328e-02,   3.44910123e-03,   1.71618216e-04,
                          6.41496433e-03,  -1.68645056e-03,  -2.88428506e-03,
                         -9.65087861e-03,  -1.36182448e-02,  -1.77068997e-03,
                         -8.81474349e-04,   4.23927413e-04,   4.92783310e-03,
                          9.17229149e-03,   2.80211098e-03,  -1.22733042e-03,
                          4.05963743e-04,   1.07869841e-02,  -2.33371113e-03,
                          4.41741385e-03,   7.16024917e-03,   7.24019855e-03,
                          5.77886915e-03,  -4.12399322e-03,   9.43501666e-03,
                          2.82656867e-03,   3.91021743e-03,   7.43299583e-03,
                          7.42607238e-03,   3.97917524e-04,   1.09260983e-03,
                         -2.78303842e-03,  -2.72985431e-03,   4.03696811e-03,
                         -1.97123573e-03,   1.65151432e-03,   8.05448927e-03,
                          5.47767244e-03,   1.01985214e-02,  -7.26315891e-04,
                         -7.10392557e-03,  -1.22831808e-02,  -1.59237697e-03,
                         -8.47390480e-03,  -4.94989241e-03,  -1.11107463e-02,
                         -1.87683641e-03,  -2.35520932e-03,  -1.18900521e-03,
                          7.09017564e-04,  -4.09482326e-03,  -1.03094289e-03,
                          4.15798044e-03,   4.43086587e-03,   4.57827607e-03,
                          4.43500327e-03,  -3.31316795e-03,  -6.17077108e-03,
                         -4.73216642e-03,  -3.77395819e-03,   4.42981953e-03,
                         -1.90317899e-03,  -8.89060367e-03,   1.66249555e-02,
                         -4.16845921e-03,  -7.08601018e-03,  -7.29485881e-03,
                         -3.00171436e-03,  -1.76134775e-03,  -1.79137033e-03,
                          1.17633643e-03,  -8.36676045e-04,  -6.24141283e-03,
                          6.19208906e-03,  -5.42708032e-04,   4.03395342e-03,
                          2.18945416e-03,   1.08277351e-02,   1.06094684e-02,
                          9.99832898e-03,  -4.20076167e-03,   1.16525181e-02,
                          2.72296555e-03,  -2.03796895e-03,   1.18535291e-03,
                          7.30695948e-03,   7.25568086e-03,  -2.10675341e-03,
                          1.46093444e-04,  -3.75395687e-03,   1.08253298e-04,
                          1.70377665e-04,   5.99870225e-04,   3.92258819e-03,
                          9.33768600e-03,   6.76096603e-03,  -3.81222810e-03,
                         -2.89576198e-03,   1.67355302e-03,   7.89819378e-03,
                         -5.31210448e-04,  -4.06770455e-03,  -5.79799013e-03,
                         -1.13444682e-02,  -5.48020191e-03,  -2.31892150e-03,
                         -6.56892406e-03,  -1.44634936e-02,  -4.12321696e-03,
                         -1.00834277e-02,  -7.21530430e-03,   2.33326748e-04,
                         -4.31869691e-03,  -4.51286649e-03,  -1.82142074e-03,
                         -4.36404953e-03,   1.62914291e-03,  -6.33100932e-03,
                         -2.90197844e-04,   1.24123571e-02,  -1.51271163e-03,
                          2.46740598e-03,  -6.44953363e-03,  -4.18322766e-03,
                         -1.32960770e-02,   6.56602019e-03,  -1.43281771e-02,
                         -1.57149490e-02,   1.57726172e-03,   5.11631323e-03,
                          3.24405078e-03,  -9.06139729e-04,  -4.73638019e-03,
                         -2.15385249e-03,   1.07447989e-03,  -9.16646270e-04,
                          7.55813206e-03,  -4.17294999e-04,   1.02939049e-03,
                         -1.04651069e-02,   4.87324223e-03,   7.89891463e-03,
                          4.48745268e-04,   5.53685823e-04,  -1.17253438e-02,
                         -8.03741254e-03,  -3.78477667e-03,  -3.87445628e-03,
                          5.83001552e-03,   1.26573886e-03,  -2.40267580e-03,
                         -8.59728083e-03,  -5.95305813e-03,   1.86414679e-03,
                          8.89633503e-03,  -5.11535676e-03,   4.20044316e-03,
                          4.20668023e-03,   7.92618655e-03,  -3.92329507e-03,
                         -6.41470822e-03,  -5.15323831e-03,  -2.43846443e-03,
                         -4.77521820e-03,  -5.68766438e-04,  -4.60903347e-03,
                         -5.61611494e-03,  -8.96963850e-03,  -3.38174449e-03,
                         -4.02046647e-03,  -7.64815835e-03,   5.59673738e-03,
                         -2.64229544e-04,  -5.48739592e-03,   5.45646530e-04,
                         -5.04032103e-03,  -5.55177964e-03,  -6.30924106e-03,
                         -1.77380862e-03,  -7.63025694e-03,   2.91193766e-03,
                          4.29204246e-03,   4.57511563e-03,  -3.64975794e-03,
                         -4.64033801e-04,   6.02838537e-03,   5.54356026e-03,
                          5.76922158e-03,   7.15807267e-03,   4.42877971e-03,
                         -7.27040833e-03,   7.65412534e-03,   2.26941053e-03,
                         -1.20789474e-02,   8.42988305e-03,   4.57113096e-03,
                          5.13329927e-04,   9.14133992e-03,   3.08713201e-03,
                          1.47454580e-02,   2.92629050e-03,   4.18552151e-03,
                          3.01518710e-03,   9.70261451e-03,   1.21611357e-02,
                         -6.12289528e-04,  -1.92464946e-03,  -1.80577184e-03,
                         -4.31392854e-03,   4.13261478e-05,  -6.97081257e-03,
                          4.82496471e-05,   5.91807347e-03,  -5.78178652e-03,
                         -1.41367586e-02,  -8.37464724e-03,   7.26443436e-03,
                         -2.18131091e-03,  -6.88536046e-03,  -8.96198023e-03,
                          1.98161753e-04,   8.96785781e-03,  -3.29024880e-03,
                          9.48068127e-03,   1.22277159e-02,  -1.15594706e-02,
                          1.18692536e-02,  -5.78706060e-03,  -3.00301029e-03,
                          5.36650827e-04,  -4.51962370e-03,   1.40592624e-02,
                          2.90199253e-03,   2.04827450e-03,   3.51913320e-03,
                         -1.55456451e-04,   5.25142159e-03,   1.51093611e-02,
                         -8.00413266e-03,  -1.28658637e-02,  -1.13453483e-02,
                         -3.40431696e-03,  -5.65447472e-03,  -2.27421336e-03,
                          5.90028986e-03,   1.87236071e-02,   6.29858172e-04,
                          2.26667314e-03,   7.21689826e-03,   7.02304021e-03,
                          1.54773807e-02,   1.47502469e-02,  -1.48937001e-03,
                         -8.11949652e-03,  -2.61332607e-04,   9.78207868e-03,
                          2.85530905e-03,  -7.77215045e-03,  -7.07913516e-03,
                          1.02323554e-02,   9.34929401e-03,   5.54003241e-03,
                          1.34671470e-02,  -6.63798582e-03,   8.22122151e-04,
                         -4.70039714e-03,  -3.48976208e-03,   8.81770253e-03,
                         -1.17960060e-03,   2.86770752e-03,   4.22307756e-03,
                          2.27013836e-03,  -5.11958404e-03,  -3.84900789e-03,
                          1.53389107e-03,   1.28551833e-02,   1.09166035e-03,
                          6.97854720e-03,   6.17543515e-03,   9.60130524e-03,
                          6.41212985e-03,  -2.53716088e-03,   5.86265756e-04,
                         -1.21094901e-02,  -1.19144404e-02,   1.91002693e-02,
                          1.70108695e-02,   3.34988534e-03,   1.60945207e-02,
                          1.18512204e-02,   1.87088810e-02,   1.04110292e-03,
                          5.73664857e-03,   8.62753205e-03,   1.55747531e-03,
                          4.91239224e-03,   8.44591949e-03,  -2.89786188e-03,
                         -7.53946835e-03,   8.92368960e-04,   1.76771823e-02,
                          1.24390945e-02,   5.11146849e-04,   9.50750895e-03,
                         -9.08191130e-03,   1.30149990e-03,   1.14235643e-03,
                          4.46318230e-03,  -2.27259868e-03,  -5.26382728e-03,
                         -3.30499676e-03,  -1.70672906e-03,  -1.15475431e-02,
                         -1.18630305e-02,  -6.75527612e-03,  -4.05165367e-03,
                          1.47617860e-02,  -4.86875093e-03,   1.23135012e-03,
                          1.70069467e-02,   1.40004512e-02,   1.41365640e-02,
                          7.53840804e-03,  -3.69939371e-04,  -1.43124377e-02,
                         -1.06067304e-02,   3.75350658e-03,  -8.39613844e-03,
                         -5.22953551e-03,  -9.06737149e-03,  -7.09589291e-03,
                         -3.49795376e-03,  -7.56938010e-03,  -3.94429406e-03,
                         -3.72516806e-03,   3.54420068e-03,   4.17655380e-03,
                          2.10473663e-03,  -6.83635520e-03,  -3.01231095e-03,
                          1.45142656e-02,  -1.84574239e-02,   7.75819935e-04,
                          2.51396466e-03,  -1.18014114e-02,  -3.80314910e-03,
                         -1.58675644e-03,   2.82355375e-03,  -3.33556696e-03,
                          2.07942678e-03,  -1.04045905e-02,  -1.66810360e-02,
                         -3.31964088e-03,  -1.09467926e-02,  -4.14578244e-03,
                         -7.00190943e-03,  -4.04612301e-03,  -9.24869120e-01,
                         -9.39428091e-01,  -9.10328865e-01,  -9.42493320e-01,
                         -9.41299438e-01,  -9.39651191e-01,  -9.32875752e-01,
                         -9.30249512e-01,  -9.35550928e-01,  -9.23706114e-01,
                         -9.35912848e-01,  -9.19732332e-01,  -1.69750117e-02,
                         -1.31445499e-02,  -1.65454985e-03,   8.63001961e-03,
                          1.68039335e-03,   1.58255938e-02,   2.86086719e-03,
                          6.73427712e-03,   1.34480679e-02,  -1.71742607e-02,
                          2.92025059e-02,   2.71543907e-03,  -1.77592936e-03,
                          4.41016443e-03,  -7.64696626e-04,   7.78361317e-03,
                          1.51704531e-02,   5.97400218e-03,  -3.86849628e-04,
                          1.66753605e-02,   1.64271817e-02,   1.37688778e-02,
                         -6.60823367e-04,  -1.39735676e-02,  -8.11491534e-03,
                         -1.57551114e-02,   1.25680352e-02,   1.76133390e-03,
                         -1.10379215e-02,  -1.08222878e-02,   1.47972424e-02,
                         -1.33216018e-02,  -2.23360658e-02,   3.72420473e-04,
                          7.88433291e-03,  -2.14837748e-03,   1.10913198e-02,
                         -1.42563777e-02,  -1.37936054e-02,   1.66482143e-02,
                          2.06578411e-02,   2.59283222e-02,  -4.34734719e-03,
                          2.25859918e-02,  -3.33284333e-05,  -1.20718926e-02,
                         -1.48956059e-02,  -2.04821005e-02,  -1.42468829e-02,
                          2.37862580e-02,   1.24765048e-02,   9.52469651e-04,
                         -5.71806123e-03,  -1.67239495e-02,   5.33345714e-03,
                          1.94970369e-02,   1.90187606e-03,   8.20483081e-03,
                          1.52505683e-02,   1.44560570e-02,   4.39553671e-02,
                          5.34995878e-03,  -3.77285614e-04,   8.53332598e-03,
                         -9.08682168e-01,  -9.25074577e-01,  -9.24665928e-01,
                         -9.34529960e-01,  -9.47710097e-01,  -9.47825789e-01,
                         -9.44797873e-01,  -9.50984597e-01,  -9.38837588e-01,
                         -9.42552328e-01,  -9.33318675e-01,  -9.24458146e-01,
                         -9.02816474e-01,  -9.31797743e-01,  -9.27714646e-01,
                         -9.07576084e-01,  -9.14367974e-01,  -9.13622916e-01,
                         -9.15556252e-01,  -9.21382129e-01,  -9.09432769e-01,
                         -9.21418548e-01,  -9.16690171e-01,  -9.43539560e-01,
                         -9.30907547e-01,  -9.27524149e-01,  -9.37751114e-01,
                         -9.25782025e-01,  -9.27934468e-01,  -9.26718593e-01,
                         -9.45979714e-01,  -9.40368652e-01,  -9.26909983e-01,
                         -9.26234782e-01,  -9.26614881e-01,  -9.36499119e-01,
                         -9.24923837e-01,  -9.48597312e-01,  -9.13522005e-01,
                         -9.47738588e-01,  -9.39218163e-01,  -9.41065192e-01,
                         -9.28095758e-01,  -9.34148848e-01,  -9.27015424e-01,
                         -9.57526803e-01,  -9.52748597e-01,  -9.17675912e-01,
                         -9.44047987e-01,  -9.12580490e-01,  -9.17149007e-01,
                         -9.11731064e-01,  -9.23371077e-01,  -9.13366377e-01,
                         -9.17568684e-01,  -9.32106316e-01,  -9.41659689e-01,
                         -9.31058586e-01,  -9.20365036e-01,  -9.33490336e-01,
                         -9.09416199e-01,  -9.15810227e-01,  -9.21744347e-01,
                         -9.30500925e-01,  -9.36034739e-01,  -9.22858000e-01,
                         -9.34755623e-01,  -9.24127162e-01,  -9.10920978e-01,
                         -9.15334761e-01,  -9.28133667e-01,  -8.96128535e-01,
                         -9.29049432e-01,  -9.29749429e-01,  -9.44688439e-01,
                         -9.30810750e-01,  -9.27508533e-01,  -9.02137101e-01,
                         -9.25026417e-01,  -9.16255593e-01,  -9.22183275e-01,
                         -9.25153375e-01,  -9.34432387e-01,  -9.30989146e-01,
                         -9.51696813e-01,  -9.23937738e-01,  -9.34820175e-01,
                         -9.18313682e-01,  -9.11043704e-01,  -9.39546704e-01,
                         -9.06727374e-01,  -9.22989368e-01,  -9.24542606e-01,
                         -9.18211520e-01,  -9.16789174e-01,  -9.42073166e-01,
                         -9.35512245e-01,  -9.47893620e-01,  -9.23270583e-01,
                         -9.37428117e-01,  -9.27072942e-01,  -9.28998411e-01,
                         -9.19952452e-01,  -9.16386425e-01,  -9.29980457e-01,
                         -9.16399300e-01,  -9.00350332e-01,  -9.18294132e-01,
                         -8.98804486e-01,  -9.26001191e-01,  -9.47619975e-01,
                         -9.40412104e-01,  -9.30375278e-01,  -9.24553752e-01,
                         -9.21607852e-01,  -9.28638995e-01,  -9.27331746e-01,
                         -9.10377324e-01,  -9.14219737e-01,  -9.35930610e-01,
                         -9.30431485e-01,  -9.26130950e-01,  -9.08377945e-01,
                         -9.11844492e-01,  -9.14924085e-01,  -9.16664064e-01,
                         -9.09820914e-01,  -9.31714356e-01,  -9.24879670e-01,
                         -9.37110424e-01,  -9.37504530e-01,  -9.46544468e-01,
                         -9.44025099e-01,  -9.34030771e-01,  -9.43790913e-01,
                         -9.31295395e-01,  -9.38057661e-01,  -9.31795299e-01,
                         -9.34387803e-01,  -9.26731944e-01,  -9.24872696e-01,
                         -9.17052090e-01,  -9.25268710e-01,  -9.47855175e-01,
                         -9.34053838e-01,  -9.28467214e-01,  -9.38443542e-01,
                         -9.44942057e-01,  -9.29349899e-01,  -9.12474453e-01,
                         -9.43646550e-01,  -9.29969311e-01,  -9.32897627e-01,
                         -9.27958190e-01,  -9.31859374e-01,  -9.32745814e-01,
                         -9.31024432e-01,  -9.33349073e-01,  -9.20737565e-01,
                         -9.28212404e-01,  -9.29467201e-01,  -9.24636662e-01,
                         -9.28540409e-01,  -9.33399618e-01,  -9.31986809e-01,
                         -9.36278880e-01,  -9.38126802e-01,  -9.20464635e-01,
                         -9.18361962e-01,  -9.32372332e-01,  -9.34954703e-01,
                         -9.35557485e-01,  -9.11916316e-01,  -9.35460746e-01,
                         -9.12819445e-01,  -9.38076615e-01,  -9.50783134e-01,
                         -9.30127501e-01,  -9.32094693e-01,  -9.35334504e-01,
                         -9.19297218e-01,  -9.18808997e-01,  -9.24478590e-01,
                         -9.39409792e-01,  -9.41310167e-01,  -9.35055017e-01,
                         -9.39010024e-01,  -9.38053191e-01,  -9.22607839e-01,
                         -9.24600005e-01,  -9.41636860e-01,  -9.43907142e-01,
                         -9.32525396e-01,  -9.13843274e-01,  -9.64596987e-01,
                         -9.51869011e-01,  -9.29595411e-01,  -9.42945182e-01,
                         -9.45667684e-01,  -9.48805213e-01,  -9.52257574e-01,
                         -9.42789972e-01,  -9.43865657e-01,  -9.47708666e-01,
                         -9.36328590e-01,  -9.48043466e-01,  -9.49847102e-01,
                         -9.44201767e-01,  -9.40198302e-01,  -9.38309669e-01,
                         -9.34509933e-01,  -9.37522173e-01,  -9.39059734e-01,
                         -9.41567183e-01,  -9.07364726e-01,  -9.37591374e-01,
                         -9.46259499e-01,  -9.29857492e-01,  -9.25720632e-01,
                         -9.38800335e-01,  -9.34781909e-01,  -9.45825040e-01,
                         -9.39282715e-01,  -9.25461531e-01,  -9.25784290e-01,
                         -9.30875242e-01,  -9.30004656e-01,  -9.34813440e-01,
                         -9.25634921e-01,  -9.31727409e-01,  -9.22924757e-01,
                         -9.21020031e-01,  -9.26434159e-01,  -9.41897988e-01,
                         -9.23979521e-01,  -9.39828932e-01,  -9.47819114e-01,
                         -9.16649401e-01,  -9.47322428e-01,  -9.28935409e-01,
                         -9.32929993e-01,  -9.26498055e-01,  -9.36630189e-01,
                         -9.27848220e-01,  -9.35094655e-01,  -9.27917659e-01,
                         -9.39511359e-01,  -9.37307179e-01,  -9.46943581e-01,
                         -9.27326858e-01,  -9.25855756e-01,  -9.22603726e-01,
                         -9.31876600e-01,  -9.35387671e-01,  -9.27964628e-01,
                         -9.18374121e-01,  -9.44219410e-01,  -9.18167651e-01,
                         -9.33898270e-01,  -9.28129792e-01,  -9.43144560e-01,
                         -9.26610172e-01,  -9.32463050e-01,  -9.21026826e-01,
                         -9.15730536e-01,  -9.17909265e-01,  -9.19009805e-01,
                         -9.22388196e-01,  -9.36163604e-01,  -9.45726037e-01,
                         -9.44897354e-01,  -9.49955583e-01,  -9.39590216e-01,
                         -9.28704202e-01,  -9.33828294e-01,  -9.53651965e-01,
                         -9.17852402e-01,  -9.48653340e-01,  -9.40418303e-01,
                         -9.32152152e-01,  -9.36298847e-01,  -9.34879959e-01,
                         -9.27352548e-01,  -9.21606541e-01,  -9.60084200e-01,
                         -9.56149161e-01,  -9.48704422e-01,  -9.31471825e-01,
                         -9.29295480e-01,  -9.21642959e-01,  -9.37803566e-01,
                         -9.26511228e-01,  -9.38738704e-01,  -9.28497374e-01,
                         -9.37990010e-01,  -9.23369348e-01,  -9.63626266e-01,
                         -9.34483171e-01,  -9.38867986e-01,  -9.34445798e-01,
                         -9.20815945e-01,  -9.25547242e-01,  -9.17776883e-01,
                         -9.26389754e-01,  -9.22959566e-01,  -9.06876564e-01,
                         -9.22703862e-01,  -9.18753982e-01,  -9.21776295e-01,
                         -8.98378551e-01,  -9.17612791e-01,  -9.15740490e-01,
                         -9.21251893e-01,  -9.21574831e-01,  -9.34627771e-01,
                         -9.25553441e-01,  -9.33703542e-01,  -9.31010664e-01,
                         -9.46776986e-01,  -9.52147603e-01,  -9.35302198e-01,
                         -8.96155179e-01,  -9.49613512e-01,  -9.19138134e-01,
                         -9.37054753e-01,  -9.26943421e-01,  -9.17265058e-01,
                         -9.23284411e-01,  -9.29684520e-01,  -9.24109757e-01,
                         -9.27208126e-01,  -9.20782745e-01,  -9.11397457e-01,
                         -9.09743309e-01,  -9.17701483e-01,  -9.22956645e-01,
                         -9.21428561e-01,  -9.28157687e-01,  -9.23468530e-01,
                         -9.05706823e-01,  -9.25548434e-01,  -8.84911776e-01,
                         -9.36659217e-01,  -9.30581987e-01,  -9.20937657e-01,
                         -9.27622139e-01,  -9.35548484e-01,  -9.43543315e-01,
                         -9.28417921e-01,  -9.33696032e-01,  -9.37741935e-01,
                         -9.25301313e-01,  -9.25500154e-01,  -9.29936528e-01,
                         -9.35518861e-01,  -9.26736832e-01,  -9.47413027e-01,
                         -9.27076340e-01,  -9.34318841e-01,  -9.41631854e-01,
                         -9.28284049e-01,  -9.07390952e-01,  -9.22360122e-01,
                         -9.04047549e-01,   6.13828088e-05,   2.39363648e-02,
                         -1.09232366e-02,   1.48020592e-02,   1.02093881e-02,
                          1.53098516e-02,   1.66778490e-02,   4.00289856e-02,
                          2.51744930e-02,   2.10690107e-02,   1.38379252e-02,
                          1.56454574e-02,   2.47137016e-03,   1.07701086e-02,
                         -1.87207526e-03,  -2.80912477e-03,   1.24859996e-02,
                          8.81043263e-03,   1.87270381e-02,   7.78183225e-04,
                         -1.41115105e-02,   1.40852099e-02,  -1.19265821e-02,
                          2.15949528e-02,   9.80946817e-04,  -7.07756216e-03,
                         -1.54656684e-03,   1.44263115e-02,   1.47897853e-02,
                          6.20518066e-03,  -1.91206380e-03,   2.28392286e-03,
                          1.19316280e-02,  -2.28121993e-03,   2.53804098e-03,
                          1.37945684e-02,   1.09326129e-03,   3.72039992e-03,
                          6.74516475e-03,   7.97221088e-04,  -1.16014061e-02,
                          3.25578381e-03,   5.84736234e-03,  -7.83537701e-03,
                          2.68068444e-02,  -8.71795975e-03,   7.35559687e-03,
                          4.55151079e-03,   5.10469778e-03,   3.01416148e-03,
                         -1.74951758e-02,  -1.75986253e-02,   9.84393992e-03,
                          3.28938477e-02,   2.99967621e-02,   1.23276254e-02,
                         -1.22682871e-02,  -1.07669970e-02,  -6.03769254e-03,
                          1.41764078e-02,  -1.13910611e-03,  -1.80313624e-02,
                          3.38631980e-02,   7.50953564e-04,   9.75287426e-03,
                          2.79831327e-03,   1.84358638e-02,   2.79130172e-02,
                         -1.80447865e-02,   3.56307207e-03,   1.98785290e-02,
                          2.58120857e-02,   9.40990821e-03,   1.04974099e-02,
                         -7.73961889e-03,  -4.05781483e-03,  -8.57911538e-03,
                         -7.25257630e-03,   9.16125067e-03,   1.95707344e-02,
                          3.94955464e-03,   8.86644423e-03,   2.11997656e-03,
                         -3.37213883e-03,  -2.59281341e-02,  -8.00194277e-04,
                          3.36479250e-04,  -3.76928714e-03,   8.11523478e-03,
                         -7.81073235e-03,   4.22782497e-03,  -4.13098605e-03,
                          1.05407387e-02,  -5.89938229e-03,  -5.43650589e-04,
                          7.54030654e-04,  -1.24079629e-03,  -1.13433106e-02,
                          1.05625903e-02,  -3.06896726e-03,   1.84070040e-02,
                          1.56827439e-02,  -1.45495972e-02,  -2.25171018e-02,
                          2.83641182e-02,  -1.89440791e-02,  -1.75911619e-03,
                          1.95324160e-02,   5.36772143e-03,   1.12111261e-02,
                         -2.24976288e-03,   1.51876537e-02,   1.31416181e-02,
                          1.47602679e-02,   8.65034014e-03,   7.55247660e-03,
                         -8.77429731e-03,  -1.33043446e-03,  -7.91917276e-03,
                         -1.48648070e-02,  -1.95113197e-02,  -2.04403303e-03,
                         -4.01926087e-03,  -1.12187080e-02,  -7.30151869e-03,
                          4.60730074e-03,   1.95187912e-03,  -5.26027195e-03,
                          1.41639467e-02,   7.63033284e-04,  -5.86759252e-03,
                          1.99229736e-03,  -7.70340767e-03,   1.01176638e-03,
                         -2.68757879e-03,  -8.37688614e-03,  -4.83030127e-03,
                         -9.83842276e-03,  -1.00226197e-02,  -4.44538513e-04,
                         -4.14362038e-03,  -8.53246718e-04,   3.39274993e-03,
                         -4.21936298e-03,   1.21242309e-03,  -1.04011188e-03,
                         -6.47872454e-03,   5.95172774e-03,  -1.52968150e-02,
                         -7.87197612e-03,  -2.95826048e-03,  -8.11138097e-03,
                         -1.04093309e-02,  -1.67006708e-03,   2.13436433e-03,
                         -6.23348448e-03,  -1.21075287e-03,   7.16755353e-03,
                          8.54471978e-03,   3.86607065e-03,   6.28331397e-03,
                          1.12381969e-02,   4.05568723e-03,   1.81099738e-03,
                         -2.55779969e-03,  -9.50425863e-03,  -8.07038043e-03,
                          8.10608640e-03,  -1.42795942e-03,   4.62051714e-04,
                         -1.11301653e-02,   1.77118350e-02,  -3.78601020e-03,
                         -9.77728330e-03,   1.50531624e-02,   8.40540417e-03,
                         -8.77298787e-03,  -6.59563392e-03,  -8.48579034e-03,
                         -5.65697672e-03,   4.24127001e-03,   3.69322574e-04,
                         -3.63961188e-03,  -1.55906935e-04,  -1.04726409e-03,
                         -1.05621130e-03,  -3.66563560e-03,  -3.82394041e-03,
                         -4.97092633e-03,  -5.46583533e-03,  -2.76680756e-03,
                          1.79419795e-03,   1.50176026e-02,  -3.54539952e-04,
                          6.13105949e-03,  -5.57388086e-03,   3.75261938e-04,
                          2.17889226e-03,  -2.62009026e-03,  -4.47464548e-03,
                         -8.33446451e-04,  -3.26170935e-03,   4.18979093e-04,
                          1.00763584e-03,  -9.06534784e-04,   8.39441316e-04,
                         -3.42053408e-03,  -4.62075276e-03,   2.43097264e-03,
                          7.46889552e-03,  -4.36039036e-03,   5.60269749e-04,
                         -1.05566448e-02,  -3.33269779e-03,  -1.46922318e-03,
                         -2.51555862e-03,   2.61975755e-03,  -1.28473516e-03,
                         -2.28440110e-03,  -2.37941719e-03,  -9.39793885e-04,
                         -6.93472568e-04,  -2.59684562e-03,  -4.98066377e-03,
                         -7.12345541e-03,  -4.47778497e-03,  -5.85357891e-04,
                         -7.14437163e-04,  -2.61824665e-04,  -1.56240282e-03,
                         -2.85256468e-03,   1.46158587e-03,  -1.23245898e-03,
                         -3.31496983e-03,   5.76334496e-05,   1.69310388e-05,
                         -9.23091546e-04,  -6.04991801e-04,   3.91710643e-03,
                          3.96780932e-04,   1.58044277e-03,  -1.77772436e-03,
                          3.27296439e-04,   2.64973869e-03,   4.93404968e-03,
                          1.38310576e-03,  -8.00152658e-04,  -8.67377850e-04,
                         -2.17601613e-04,  -2.10352388e-04,  -2.32919236e-03,
                         -3.62405990e-04,  -2.49578618e-03,  -2.83496134e-04,
                         -1.81033893e-03,   5.64448768e-04,   2.45150062e-03,
                         -7.55936548e-04,   3.39147489e-04,  -1.28594809e-03,
                          8.49947828e-05,   1.85279478e-03,   4.23090905e-03,
                         -6.02219603e-04,  -6.12317293e-04,  -1.39050744e-03,
                         -1.76517339e-03,  -3.51144059e-04,  -1.30179105e-03,
                         -1.06181798e-03,  -1.31086295e-03,  -2.25521694e-03,
                         -1.80180068e-03,  -1.13968132e-03,  -1.98320462e-03,
                         -4.69744482e-05,  -2.55944906e-03,   3.54898255e-03,
                         -1.62709143e-03,   3.52618145e-03,   3.06123984e-03,
                         -7.16474664e-04,  -5.80218295e-03,  -2.25344277e-03,
                         -2.38227262e-03,  -3.12382169e-03,  -3.94557649e-03,
                          3.97170428e-03,   2.63381936e-03,   9.10963339e-04,
                          2.76946882e-03,  -3.70642124e-03,  -2.82386574e-03,
                         -6.46760128e-03,  -1.32093977e-04,  -7.24389218e-04,
                         -1.48199603e-03,  -2.92757270e-03,  -3.70904780e-03,
                         -7.55354413e-04,  -2.08244147e-03,   1.53941463e-03,
                          5.00266091e-04,   5.29339956e-03,   4.32320870e-03,
                          3.41588375e-03,   2.36515445e-03,  -1.60460229e-04,
                          5.32886246e-03,   4.80649527e-03,   5.18354529e-04,
                          3.25848674e-03,   7.34590809e-04,   5.20076742e-03,
                          4.03757114e-03,   2.13246536e-03,   9.38971993e-03,
                         -1.33518176e-03,  -4.12117952e-04,  -5.40391216e-03,
                         -3.73921590e-03,  -6.79932628e-03,   2.12796056e-03,
                          2.05885712e-03,  -1.44228467e-03,  -1.00263907e-02,
                         -9.85439774e-03,  -1.92649988e-03,  -4.90188552e-03,
                          8.35197791e-03,  -4.18084348e-03,   4.59217140e-03,
                          5.58498316e-03,   5.65647730e-04,   5.23492042e-03,
                         -1.03321327e-02,  -4.48491611e-03,  -1.51013350e-03,
                          1.05340304e-02,   3.58928996e-03,   4.00807522e-03,
                         -2.42517889e-03,  -1.32029527e-03,  -5.16531803e-03,
                         -2.54885922e-03,   3.90937878e-03,  -3.84878600e-03,
                          7.22118840e-03,  -1.87256723e-03,   1.97711284e-03,
                          7.57218659e-05,   6.58737263e-05,   3.97083769e-03,
                          4.02095867e-03,  -4.17533377e-03,   2.98009138e-03,
                          4.43692988e-04,   9.94154811e-03,   9.45015997e-03,
                          6.02365192e-03,   6.57111406e-03,   1.72207993e-03,
                          4.24570544e-03,  -1.74152676e-03,   3.17087234e-03,
                          2.58748257e-03,   1.05681838e-02,   4.46526846e-03,
                         -3.81487538e-03,  -3.99281411e-03,  -8.94113351e-03,
                          4.61748149e-03,  -5.16904658e-03,   1.23996809e-02,
                          8.72839056e-03,   1.25148299e-03,  -4.16484149e-03,
                          6.53399481e-03,  -6.18521404e-03,  -9.15899128e-03,
                         -5.97014884e-03,   1.18690599e-02,   6.06952421e-03,
                          1.02105737e-02,   1.93803757e-02,   6.00957591e-03,
                          1.81613620e-02,   3.77489370e-03,   4.29832144e-04,
                         -5.39873494e-03,  -1.16987724e-03,  -9.45984852e-03,
                          1.77646999e-03,   2.45109177e-03,   4.46970388e-03,
                          4.45084646e-03,   2.16896785e-03,  -9.46179591e-03,
                         -2.87788827e-03,   4.00824845e-03,   6.44974131e-03,
                          9.48593486e-03,   8.54938384e-03,  -6.19365484e-04,
                          2.57356628e-03,   3.43270390e-03,  -2.53868551e-04,
                          2.06004921e-03,  -3.54986964e-03,  -1.03166504e-02,
                         -1.18289259e-03,  -2.68690661e-03,  -6.87488867e-03,
                         -1.76354474e-03,   2.80359411e-03,  -1.08827213e-02,
                         -1.29435053e-02,  -4.80174785e-04,  -5.04139485e-03,
                         -1.62521331e-03,  -6.80597220e-03,  -7.30898976e-03,
                         -6.96606515e-03,   8.76142085e-03,  -1.78616564e-03,
                          4.67690313e-03,  -8.69574782e-04,  -9.76178679e-04,
                          8.81672557e-03,  -2.78031477e-03,   6.61717355e-03,
                         -1.12051107e-02,  -1.08735659e-03,   3.20532330e-04,
                          6.45184843e-03,   6.93157967e-03,  -8.78882362e-04,
                         -8.19072768e-04,  -8.80386308e-03,  -7.17713824e-03,
                         -1.70514341e-02,  -2.19145720e-03,  -3.76436650e-03,
                         -1.06978519e-02,   3.56085435e-03,  -2.96817790e-03,
                          2.06437381e-03,   8.76411702e-03,  -2.22269259e-03,
                          1.56410225e-02,  -3.52656259e-03,   6.98141614e-03,
                          1.22795487e-02,  -7.43763242e-03,  -6.12056674e-03,
                          3.33843613e-03,  -5.00813592e-03,   6.38648728e-03,
                         -3.11958021e-03,   4.38021822e-03,  -1.14006246e-03,
                         -1.21046454e-02,  -1.71866326e-03,   1.40683551e-03,
                         -1.01913000e-02,   7.94096850e-03,   1.05922599e-03,
                         -8.89511593e-03,   3.07600159e-04,   1.24857221e-02,
                          1.38020876e-03,  -2.33077258e-03,  -2.51374277e-03,
                          4.59286472e-04,   9.26326029e-03,   9.67555773e-03,
                          3.48179904e-03,   5.77460695e-03,   5.19378157e-03,
                          1.79554522e-02,   1.50064714e-02,   6.91118324e-03,
                          9.37670376e-03,  -2.21387018e-03,  -8.86517577e-03,
                          2.04779627e-03,   1.97434053e-03,   2.14426573e-02,
                          2.14119069e-03,  -5.47407568e-03,  -5.28808357e-03,
                          9.74407233e-03,  -9.65990964e-03,   6.34824531e-03,
                         -6.10306067e-03,   3.98124754e-03,   6.99313544e-03,
                          1.03961979e-03,   7.85060972e-03,   1.84101034e-02,
                          1.67601537e-02,  -1.92250100e-05,  -9.68941860e-03,
                          7.72966677e-03,   6.00325549e-03,   8.26345570e-03,
                         -3.39089264e-03,  -1.55105358e-02,  -3.61518905e-04,
                          3.21621122e-03,   9.39412694e-03,   2.70986697e-03,
                         -3.08713876e-03,   5.91545366e-03,   2.02084724e-02,
                          5.40014170e-03,  -1.69360079e-02,  -1.06931878e-02,
                         -9.33820568e-03,  -1.74928680e-02,  -3.28986766e-03,
                          8.89466517e-03,  -1.55100785e-02,  -1.02143018e-02,
                         -4.75399010e-03,   1.43743679e-02,  -4.28828597e-03,
                          9.51615814e-03,   6.29999582e-03,   6.26906520e-03,
                          1.46376137e-02,   4.01287759e-03,   9.31580644e-03,
                          1.38584599e-02,   1.45948874e-02,   1.23936858e-03,
                         -5.64172957e-03,  -1.51159866e-02,   1.89069033e-04,
                         -3.81735666e-03,  -2.30809283e-02,   9.61490255e-03,
                          7.14478723e-04,  -1.75095908e-03,  -6.87769521e-03,
                         -9.41196643e-03,   5.29482681e-03,  -9.25349593e-01,
                         -9.33043659e-01,  -9.21724379e-01,  -9.35689449e-01,
                         -9.38284278e-01,  -9.21031058e-01,  -9.31965411e-01,
                         -9.45130110e-01,  -9.44987178e-01,  -9.30626094e-01,
                         -9.31702375e-01,  -9.14671600e-01,   1.45960310e-02,
                         -2.08588596e-03,   3.31593305e-03,   6.75745960e-03,
                         -3.01680202e-03,   2.10995530e-03,   1.67157445e-02,
                          9.48170014e-03,   9.81411152e-03,  -3.20290471e-03,
                          3.78546282e-03,  -4.94970568e-03,   1.10027287e-02,
                          3.22544249e-03,   1.87887391e-03,   1.18213370e-02,
                          1.33133056e-02,  -4.60049510e-03,   5.55785780e-04,
                         -6.69180742e-03,   3.89035465e-03,  -4.96014953e-03,
                         -4.30288166e-03,  -1.85043011e-02,   7.17625138e-04,
                         -1.48223583e-02,  -1.44628007e-02,  -3.71696316e-02,
                         -3.72822993e-02,  -1.29360892e-02,  -1.71322841e-02,
                         -1.37143144e-02,  -2.48823198e-03,  -1.03975497e-02,
                         -1.37519115e-03,  -8.77112988e-03,  -1.53866608e-03,
                         -2.15553679e-03,   2.88761174e-03,  -1.11671593e-02,
                         -1.37516689e-02,  -7.86310527e-03,  -2.01855544e-02,
                         -1.56440157e-02,  -4.06053150e-03,   1.23618962e-02,
                          4.13286453e-03,   1.79511975e-04,   2.06974484e-02,
                         -1.25237983e-02,   3.56379990e-03,   1.16012814e-02,
                         -1.78371230e-03,   3.33725801e-03,   7.52968248e-03,
                         -1.16249146e-02,   1.55373977e-03,  -9.22855907e-05,
                          6.87838858e-03,   2.05519442e-02,   1.50695254e-04,
                         -2.32594903e-03,   9.38451476e-03,   5.93291875e-03,
                         -9.17007208e-01,  -9.32062864e-01,  -9.14886355e-01,
                         -9.41947520e-01,  -9.25862193e-01,  -9.29877818e-01,
                         -9.26926672e-01,  -9.27458704e-01,  -9.24894214e-01,
                         -9.30503666e-01,  -9.26876366e-01,  -9.25199211e-01,
                         -9.12007749e-01,  -9.31046486e-01,  -9.39611852e-01,
                         -9.44297373e-01,  -9.41177189e-01,  -9.38307881e-01,
                         -9.27567124e-01,  -9.42242265e-01,  -9.36628401e-01,
                         -9.25856292e-01,  -9.20982122e-01,  -9.36771333e-01,
                         -9.37714219e-01,  -9.31292176e-01,  -9.16405559e-01,
                         -9.34254408e-01,  -9.26690578e-01,  -9.37272251e-01,
                         -9.30258632e-01,  -9.35002804e-01,  -9.32969272e-01,
                         -9.29406404e-01,  -9.33777153e-01,  -9.31753159e-01,
                         -9.33570623e-01,  -9.34057713e-01,  -9.37575042e-01,
                         -9.39140439e-01,  -9.23640192e-01,  -9.26048100e-01,
                         -9.45914626e-01,  -9.47353959e-01,  -9.42724407e-01,
                         -9.40734565e-01,  -9.45102274e-01,  -9.34433758e-01,
                         -9.33450520e-01,  -9.28328753e-01,  -9.46182430e-01,
                         -9.50265825e-01,  -9.40882146e-01,  -9.38040555e-01,
                         -9.37639832e-01,  -9.31182206e-01,  -9.37343419e-01,
                         -9.30026650e-01,  -9.29026306e-01,  -9.46591020e-01,
                         -9.24218535e-01,  -9.32552516e-01,  -9.31478262e-01,
                         -9.40260172e-01,  -9.25377727e-01,  -9.21673834e-01,
                         -9.43728805e-01,  -9.33314025e-01,  -9.48274553e-01,
                         -9.40580726e-01,  -9.37646806e-01,  -9.34599757e-01,
                         -9.43405390e-01,  -9.31647718e-01,  -9.39286172e-01,
                         -9.30695772e-01,  -9.36945438e-01,  -9.39430535e-01,
                         -9.34773386e-01,  -9.31830645e-01,  -9.33290839e-01,
                         -9.31088865e-01,  -9.46262836e-01,  -9.41639841e-01,
                         -9.29133356e-01,  -9.30878580e-01,  -9.34077263e-01,
                         -9.24398959e-01,  -9.25178707e-01,  -9.32475567e-01,
                         -9.36658561e-01,  -9.33499753e-01,  -9.27069664e-01,
                         -9.27260160e-01,  -9.36673224e-01,  -9.43854809e-01,
                         -9.46250200e-01,  -9.35755193e-01,  -9.44993258e-01,
                         -9.45345223e-01,  -9.33725178e-01,  -9.30800974e-01,
                         -9.39159393e-01,  -9.38770831e-01,  -9.43847895e-01,
                         -9.45174992e-01,  -9.35507774e-01,  -9.42010880e-01,
                         -9.34568226e-01,  -9.43200469e-01,  -9.37272310e-01,
                         -9.35629904e-01,  -9.46089387e-01,  -9.42746818e-01,
                         -9.35860217e-01,  -9.38939393e-01,  -9.33771193e-01,
                         -9.27885234e-01,  -9.42633510e-01,  -9.36267018e-01,
                         -9.35430408e-01,  -9.30120111e-01,  -9.46449339e-01,
                         -9.34331179e-01,  -9.27810013e-01,  -9.33536768e-01,
                         -9.32071507e-01,  -9.33106542e-01,  -9.31335032e-01,
                         -9.35507894e-01,  -9.27920163e-01,  -9.35252726e-01,
                         -9.30056632e-01,  -9.29004014e-01,  -9.31808054e-01,
                         -9.36715543e-01,  -9.31875110e-01,  -9.28541541e-01,
                         -9.36866462e-01,  -9.31812286e-01,  -9.31725204e-01,
                         -9.23248231e-01,  -9.38270450e-01,  -9.29158509e-01,
                         -9.35902417e-01,  -9.34085548e-01,  -9.35378730e-01,
                         -9.37218547e-01,  -9.40013885e-01,  -9.35384154e-01,
                         -9.38061833e-01,  -9.34977174e-01,  -9.36617076e-01,
                         -9.37794507e-01,  -9.42074537e-01,  -9.34854686e-01,
                         -9.35817301e-01,  -9.37925041e-01,  -9.35567796e-01,
                         -9.35620129e-01,  -9.30398703e-01,  -9.38635468e-01,
                         -9.40848529e-01,  -9.38530147e-01,  -9.37576413e-01,
                         -9.30237889e-01,  -9.41446364e-01,  -9.31025863e-01,
                         -9.32883680e-01,  -9.27536488e-01,  -9.30776119e-01,
                         -9.30786788e-01,  -9.33880091e-01,  -9.28462803e-01,
                         -9.27633166e-01,  -9.33223844e-01,  -9.42218542e-01,
                         -9.36682940e-01,  -9.37841415e-01,  -9.33125138e-01,
                         -9.39463794e-01,  -9.41597700e-01,  -9.35937226e-01,
                         -9.37805057e-01,  -9.34465349e-01,  -9.36521649e-01,
                         -9.34229612e-01,  -9.28383291e-01,  -9.38951075e-01,
                         -9.33018684e-01,  -9.31882799e-01,  -9.34951484e-01,
                         -9.37030256e-01,  -9.28001583e-01,  -9.28443611e-01,
                         -9.34344590e-01,  -9.35290813e-01,  -9.36198056e-01,
                         -9.33862865e-01,  -9.33794022e-01,  -9.31840897e-01,
                         -9.33227539e-01,  -9.35425282e-01,  -9.32714343e-01,
                         -9.30622578e-01,  -9.37544465e-01,  -9.37504888e-01,
                         -9.34199452e-01,  -9.36133742e-01,  -9.37906504e-01,
                         -9.38511372e-01,  -9.39572334e-01,  -9.32863474e-01,
                         -9.27284002e-01,  -9.33836818e-01,  -9.36173558e-01,
                         -9.38336074e-01,  -9.31571186e-01,  -9.33786273e-01,
                         -9.31871593e-01,  -9.30971086e-01,  -9.33811903e-01,
                         -9.29777861e-01,  -9.32983577e-01,  -9.31834996e-01,
                         -9.33894694e-01,  -9.44321275e-01,  -9.36059475e-01,
                         -9.34934974e-01,  -9.41784203e-01,  -9.41745520e-01,
                         -9.30476964e-01,  -9.36927497e-01,  -9.33346689e-01,
                         -9.31287229e-01,  -9.36917484e-01,  -9.25454617e-01,
                         -9.34847116e-01,  -9.33832526e-01,  -9.37065184e-01,
                         -9.36428845e-01,  -9.37389433e-01,  -9.33101237e-01,
                         -9.33515847e-01,  -9.28315341e-01,  -9.29703832e-01,
                         -9.31035638e-01,  -9.31135952e-01,  -9.30408895e-01,
                         -9.30917382e-01,  -9.33905244e-01,  -9.26694930e-01,
                         -9.30938721e-01,  -9.27580059e-01,  -9.30534720e-01,
                         -9.30766165e-01,  -9.24968004e-01,  -9.32437658e-01,
                         -9.39549267e-01,  -9.30223942e-01,  -9.37124193e-01,
                         -9.34544504e-01,  -9.34878707e-01,  -9.34823513e-01,
                         -9.27757978e-01,  -9.38270211e-01,  -9.33674276e-01,
                         -9.32700813e-01,  -9.33637559e-01,  -9.33904588e-01,
                         -9.37401295e-01,  -9.36503470e-01,  -9.45083737e-01,
                         -9.38206971e-01,  -9.30312634e-01,  -9.36066568e-01,
                         -9.31635261e-01,  -9.30719018e-01,  -9.32667732e-01,
                         -9.37779844e-01,  -9.38839614e-01,  -9.26597059e-01,
                         -9.32519734e-01,  -9.35366869e-01,  -9.32481825e-01,
                         -9.23978746e-01,  -9.28925753e-01,  -9.39647615e-01,
                         -9.38547313e-01,  -9.38089013e-01,  -9.41453636e-01,
                         -9.42628384e-01,  -9.40058470e-01,  -9.29999053e-01,
                         -9.37714100e-01,  -9.36918497e-01,  -9.36491251e-01,
                         -9.33577120e-01,  -9.37222421e-01,  -9.40027416e-01,
                         -9.30958331e-01,  -9.27931488e-01,  -9.42054689e-01,
                         -9.41995919e-01,  -9.40939784e-01,  -9.32517290e-01,
                         -9.42200840e-01,  -9.34161723e-01,  -9.41910505e-01,
                         -9.39523697e-01,  -9.35208201e-01,  -9.42707539e-01,
                         -9.25349295e-01,  -9.36958313e-01,  -9.35757756e-01,
                         -9.36071217e-01,  -9.35237467e-01,  -9.39619243e-01,
                         -9.38972771e-01,  -9.33471799e-01,  -9.30898011e-01,
                         -9.31552887e-01,  -9.23326194e-01,  -9.28100467e-01,
                         -9.27347958e-01,  -9.20221746e-01,  -9.29658949e-01,
                         -9.34771955e-01,  -9.31054354e-01,  -9.37998295e-01,
                         -9.31454122e-01,  -9.23587143e-01,  -9.26802695e-01,
                         -9.25908506e-01,  -9.34900105e-01,  -9.34037447e-01,
                         -9.27894413e-01,  -9.32305038e-01,  -9.37189281e-01,
                         -9.31431711e-01,  -9.37015414e-01,  -9.37251508e-01,
                         -9.33515072e-01,  -9.34066832e-01,  -9.40069318e-01,
                         -9.34014678e-01,  -9.35182214e-01,  -9.31059778e-01,
                         -9.20431018e-01,  -9.21313941e-01,  -9.30829167e-01,
                         -9.29287851e-01,  -9.26731825e-01,  -9.24145520e-01,
                         -9.26467776e-01,  -9.29289579e-01,  -9.40443575e-01,
                         -9.37359035e-01,  -9.47666883e-01,  -9.40386713e-01,
                         -9.31565523e-01,  -9.25085485e-01,  -9.38156188e-01,
                         -9.28803921e-01,  -3.75634804e-03,   5.19116875e-03,
                         -7.38517614e-03,  -2.24337982e-05,   3.88776272e-04,
                          4.39032307e-03,  -3.25071765e-03,  -2.98431201e-04,
                         -5.41475788e-03,   1.30187417e-03,  -2.43241433e-03,
                         -7.80660845e-03,  -4.47492953e-03,   7.51320180e-03,
                         -4.11113033e-05,  -7.02969357e-03,  -4.13260795e-03,
                         -2.27276492e-03,  -6.41598308e-04,   3.79871367e-03,
                         -6.15435943e-04,  -1.11525157e-03,  -1.04223536e-02,
                          3.31260636e-03,  -6.25422038e-03,   7.16828159e-04,
                          1.29929604e-02,  -1.00921253e-02,  -7.15357484e-03,
                         -1.02185644e-02,  -7.09538721e-03,  -1.50627329e-03,
                         -7.85862154e-04,   3.81249841e-03,  -2.18618312e-03,
                         -1.41021963e-02,  -2.02460703e-03,  -1.04897032e-02,
                         -9.21802502e-03,  -6.32923516e-03,  -1.33502306e-02,
                         -9.42469016e-03,  -7.32608722e-04,   2.35701120e-03,
                         -3.58138932e-03,   4.52342862e-03,  -1.03981802e-02,
                         -3.70659446e-03,   3.83002544e-03,  -3.78011237e-03,
                          3.53178126e-03,   4.50342754e-03,   8.08561407e-03,
                          2.71383813e-03,   2.04523894e-04,  -1.19889146e-02,
                         -5.37892105e-03,   4.91013285e-03,   7.47959595e-04,
                          1.13395683e-03,  -4.39890288e-03,  -9.87073290e-04,
                         -6.61302218e-03,  -2.70997803e-03,  -7.70536205e-03,
                         -2.51055486e-03,  -5.68940397e-03,  -1.81950792e-03,
                          6.49047177e-03,  -5.14151203e-03,  -5.50723774e-03,
                         -6.42142352e-03,  -2.42917775e-03,  -7.00728735e-03,
                          2.98736151e-04,   1.25716592e-03,  -3.57223419e-03,
                         -1.30714476e-02,  -2.37424718e-03,  -2.71825981e-03,
                         -1.55165372e-02,  -1.56535804e-02,  -1.95608102e-02,
                         -5.43333869e-03,   3.80875601e-04,  -2.43706466e-03,
                          1.08093210e-03,  -1.12612750e-02,  -3.24847922e-03,
                         -4.55431081e-03,   1.90648483e-03,  -1.20776589e-03,
                         -3.70979635e-03,  -7.62857264e-03,  -7.31070852e-03,
                         -3.41523229e-03,  -6.82279933e-04,   4.49583866e-03,
                         -4.41394188e-03,  -1.43324048e-03,  -2.09149253e-03,
                         -7.03890389e-03,   3.05303419e-03,  -7.47137656e-03,
                          1.25711050e-03,   3.33369570e-03,   7.04263279e-04,
                          1.00934142e-02,   5.56105236e-03,   6.41655177e-03,
                         -7.05448401e-05,   9.52712260e-03,  -4.40906966e-03,
                         -1.00090923e-02,  -1.23142703e-02,  -1.25853820e-02,
                         -9.24290530e-03,  -3.45576834e-03,  -3.38132167e-03,
                         -4.38216561e-03,  -6.42184634e-03,  -4.56704199e-03,
                          3.04986699e-03,   4.31373483e-03,  -3.05425399e-03,
                          2.13481463e-03,  -2.08289898e-03,  -8.51345714e-03,
                          1.65674684e-03,  -3.12423726e-05,   4.16419702e-03,
                          7.79837510e-03,   1.16704265e-03,   1.28929538e-03,
                         -7.69353879e-04,   4.98622889e-03,  -3.83989420e-03,
                          6.04610657e-04,   1.38584326e-03,   1.52081338e-04,
                         -2.52191373e-03,   6.37788000e-03,   3.19706928e-03,
                          4.81422944e-03,  -3.81651800e-03,  -4.39646328e-03,
                          2.05435231e-03,   6.69690128e-03,  -4.36755654e-05,
                          4.01921896e-03,  -9.24007036e-03,  -3.27706733e-03,
                          1.46793423e-03,  -7.39899522e-04,  -5.43287443e-03,
                          4.72739106e-03,   3.99200339e-03,  -2.83108721e-03,
                          1.08100830e-04,  -6.82783779e-03,  -6.37462270e-03,
                         -2.30719522e-03,  -1.98703026e-03,   4.75135678e-03,
                         -8.04366358e-03,  -8.94259568e-03,   6.31278905e-04,
                          2.19388283e-03,   3.31407576e-03,   3.04268696e-03,
                          1.19674645e-04,  -4.46522003e-03,   3.33909458e-03,
                          7.00777955e-03,   5.77462045e-03,   4.57000826e-03,
                          4.93162428e-04,  -1.06560893e-03,  -1.13681215e-03,
                          2.49534263e-03,  -2.10143765e-03,  -3.53946723e-03,
                         -7.15194643e-03,  -2.72898120e-03,  -5.96414693e-03,
                          2.64781201e-03,   6.82848925e-03,   4.53433720e-03,
                          2.07444374e-03,  -7.05566199e-04,   3.19709699e-03,
                          2.51210737e-03,  -4.40850155e-03,   2.23219418e-03,
                         -2.26340187e-03,   5.73188066e-04,  -6.78793935e-04,
                          1.64471555e-03,   4.96703153e-03,  -3.09858797e-03,
                          8.02541617e-03,  -5.64151490e-03,  -5.03459619e-03,
                          7.24544469e-03,   1.15696581e-04,  -6.26589777e-03,
                         -8.00395268e-04,   1.67829345e-03,  -1.59758166e-03,
                          6.33718446e-05,  -1.69514131e-03,  -2.32109777e-03,
                         -4.32882924e-03,   1.61266921e-03,   6.26785913e-03,
                          3.90876176e-06,  -1.49511534e-03,   8.71584634e-04,
                         -2.36740685e-03,  -5.71909407e-03,  -6.53548446e-03,
                         -1.85860251e-03,  -9.54316650e-03,   2.59657530e-03,
                         -1.23832626e-02,  -4.55723517e-03,   2.74149072e-03,
                         -1.25995202e-05,  -4.58849827e-03,  -3.76257836e-03,
                         -4.00339020e-03,  -3.90801346e-03,  -4.73805703e-03,
                          3.76521889e-03,   2.18630093e-03,  -3.71161196e-03,
                          1.72516401e-03,  -2.01320648e-03,   2.24936777e-03,
                          5.21777431e-03,   3.26234009e-03,  -1.05920592e-02,
                          3.34926834e-03,  -1.08003458e-02,   3.56344646e-03,
                          4.87209172e-06,  -2.47866102e-03,  -3.09907296e-03,
                          4.39666415e-04,  -8.09828937e-03,  -8.96653347e-03,
                         -9.44189914e-03,  -5.09317918e-03,  -1.04864603e-02,
                         -1.31479595e-02,  -1.14920307e-02,  -1.76906958e-02,
                          2.89002364e-03,  -5.99520933e-03,   3.39757348e-03,
                         -4.52376809e-03,  -7.56387017e-04,   1.23993065e-02,
                         -1.72847733e-02,  -7.51622498e-01,  -7.61650503e-01,
                         -7.62677193e-01,  -7.66704500e-01,  -7.71215320e-01,
                         -7.68875301e-01,  -7.67921031e-01,  -7.74994850e-01,
                         -7.64002919e-01,  -7.64927804e-01,  -7.75287211e-01,
                         -7.58969843e-01,  -7.68429399e-01,  -7.54688978e-01,
                         -7.61027873e-01,  -7.65617192e-01,  -7.47523963e-01,
                         -7.62032330e-01,  -7.64035821e-01,  -7.67800748e-01,
                         -7.70864487e-01,  -7.58352399e-01,  -7.61088073e-01,
                         -7.62025595e-01,  -7.60914564e-01,  -7.73855388e-01,
                         -7.43856013e-01,  -7.65101492e-01,  -7.64006078e-01,
                         -7.64648676e-01,  -7.55739748e-01,  -7.53705800e-01,
                         -7.64250040e-01,  -7.55519807e-01,  -7.57507563e-01,
                         -7.71556735e-01,  -7.45689034e-01,  -7.65531242e-01,
                         -7.51379430e-01,  -7.58668125e-01,  -7.47656882e-01,
                         -7.57690489e-01,  -7.56420314e-01,  -7.50157535e-01,
                         -7.71523595e-01,  -7.61411667e-01,  -7.65569270e-01,
                         -7.51347244e-01,  -7.53051639e-01,  -7.63805270e-01,
                         -7.48905897e-01,  -7.58335710e-01,  -7.41279781e-01,
                         -7.48611391e-01,  -7.62471080e-01,  -7.49118090e-01,
                         -7.54898548e-01,  -7.58965433e-01,  -7.67827034e-01,
                         -7.61187136e-01,  -7.73666620e-01,  -7.68419385e-01,
                         -7.59505033e-01,  -7.53778934e-01,  -7.71148264e-01,
                         -7.36273468e-01,  -7.59712636e-01,  -7.58092046e-01,
                         -7.42811263e-01,  -7.69038856e-01,  -7.54174948e-01,
                         -7.70385385e-01,  -7.57378459e-01,  -7.67376959e-01,
                         -7.49465346e-01,  -7.64813185e-01,  -7.65301704e-01,
                         -7.71232069e-01,  -7.60410666e-01,  -7.75017560e-01,
                         -9.49635446e-01,  -9.10187006e-01,  -9.53917444e-01,
                         -9.19168174e-01,  -7.62197077e-01,  -7.58162916e-01,
                         -7.49294996e-01,  -7.56033361e-01,  -7.45091617e-01,
                         -7.58231342e-01,  -7.52444088e-01,  -7.62234092e-01,
                         -7.45372951e-01,  -7.66000986e-01,  -7.53290474e-01,
                         -7.66443789e-01,  -7.57153451e-01,  -7.62960553e-01,
                         -7.57894993e-01,  -7.62335002e-01,  -9.39779401e-01,
                         -9.16467130e-01,  -9.43875074e-01,  -9.12414908e-01,
                         -9.46290970e-01,  -9.14496541e-01,  -9.32188272e-01,
                         -9.14825618e-01,  -9.27657247e-01,  -9.21351731e-01,
                         -9.16648686e-01,  -9.18878138e-01,  -7.47225583e-01,
                         -7.61237383e-01,  -7.55217075e-01,  -7.56009102e-01,
                         -7.54439831e-01,  -7.44313180e-01,  -7.47564197e-01,
                         -7.68746436e-01,  -7.45997012e-01,  -7.65503049e-01,
                         -7.36998200e-01,  -7.66935050e-01,  -7.46950805e-01,
                         -7.78799117e-01,  -7.56743133e-01,  -7.67175198e-01,
                         -9.30838346e-01,  -9.26263690e-01,  -9.13458586e-01,
                         -9.20893788e-01,  -9.23048854e-01,  -9.20319974e-01,
                         -9.21011984e-01,  -9.10413146e-01,  -7.47212052e-01,
                         -7.49760389e-01,  -7.42572725e-01,  -7.50120044e-01,
                         -7.51289606e-01,  -7.51001477e-01,  -7.54554808e-01,
                         -7.53199339e-01,  -7.59361923e-01,  -7.53721416e-01,
                         -7.62401283e-01,  -7.49917746e-01,  -7.76320517e-01,
                         -7.52039790e-01,  -7.66358316e-01,  -7.53585219e-01,
                         -9.14191365e-01,  -9.32704210e-01,  -9.13212538e-01,
                         -9.33743000e-01,  -9.26711977e-01,  -9.21797633e-01,
                         -9.28431094e-01,  -9.28590000e-01,  -9.28758979e-01,
                         -9.32505846e-01,  -9.25581753e-01,  -9.24172521e-01,
                         -9.36228454e-01,  -9.26221550e-01,  -9.45435405e-01,
                         -9.27200019e-01,  -7.62825847e-01,  -7.71238863e-01,
                         -7.51586735e-01,  -7.59243965e-01,  -7.58980811e-01,
                         -7.71379769e-01,  -7.71127880e-01,  -7.65048981e-01,
                         -7.77203918e-01,  -7.65459955e-01,  -7.64242113e-01,
                         -7.66328037e-01,  -7.64225721e-01,  -7.42870212e-01,
                         -7.45857060e-01,  -7.67449439e-01,  -7.63823330e-01,
                         -7.42698610e-01,  -7.47778416e-01,  -7.68982887e-01,
                         -7.62716651e-01,  -7.81030953e-01,  -7.75774121e-01,
                         -7.55207837e-01,  -7.57043004e-01,  -7.49879181e-01,
                         -7.48183072e-01,  -7.68415928e-01,  -7.50140011e-01,
                         -7.62518346e-01,  -7.74651468e-01,  -7.50248194e-01,
                         -7.75041163e-01,  -7.48560548e-01,  -7.66955495e-01,
                         -7.63823390e-01,  -7.52970874e-01,  -7.70545959e-01,
                         -7.75821745e-01,  -7.47581363e-01,  -7.87364960e-01,
                         -7.45300114e-01,  -7.67706037e-01,  -7.63177991e-01,
                         -7.56638765e-01,  -7.56839991e-01,  -7.54143715e-01,
                         -7.52321362e-01,   5.50875533e-03,  -1.07778497e-02,
                          2.39938870e-02,  -9.59675200e-03,   1.00321360e-02,
                          6.30761217e-03,  -2.86439061e-02,   1.15220668e-02,
                         -7.53767908e-01,  -7.57698238e-01,  -7.49799371e-01,
                         -7.57552087e-01,  -7.61481941e-01,  -7.59335935e-01,
                         -7.53639758e-01,  -7.48374879e-01,  -7.57151961e-01,
                         -7.69245565e-01,  -7.37224102e-01,  -7.69593418e-01,
                         -7.54553318e-01,  -7.31778443e-01,  -7.52137125e-01,
                         -7.59662509e-01,  -7.44354963e-01,  -7.77856290e-01,
                         -7.58840442e-01,  -7.49304354e-01,  -7.60267615e-01,
                         -7.37848222e-01,  -7.59710312e-01,  -7.39860535e-01,
                         -7.48816848e-01,  -7.47276187e-01,  -7.66927481e-01,
                         -7.65069783e-01,  -7.42607057e-01,  -7.75493920e-01,
                         -7.35999167e-01,  -7.80359864e-01,  -7.65973926e-01,
                         -7.45640397e-01,  -7.70594895e-01,  -7.38653183e-01,
                         -7.59304702e-01,  -7.58182883e-01,  -7.49399960e-01,
                         -7.64711857e-01,  -7.45964646e-01,  -7.66332150e-01,
                         -7.52452672e-01,  -7.58768857e-01,  -7.59533882e-01,
                         -7.51416624e-01,  -7.55057931e-01,  -7.55932510e-01,
                         -7.71899164e-01,  -7.48593271e-01,  -7.57621169e-01,
                         -7.41712570e-01,  -7.39169657e-01,  -7.75597334e-01,
                         -7.59142339e-01,  -7.68098593e-01,  -1.13934381e-02,
                          1.07219070e-02,  -1.21092265e-02,   2.06134245e-02,
                         -7.65090585e-01,  -7.45101690e-01,  -7.62928426e-01,
                         -7.36065745e-01,  -7.69672513e-01,  -7.49592185e-01,
                         -7.53797174e-01,  -7.70732641e-01,  -7.31081426e-01,
                         -7.79513359e-01,  -7.44757056e-01,  -7.67647922e-01,
                         -7.56948054e-01,  -7.28384614e-01,  -7.71471262e-01,
                         -7.40526915e-01,  -7.72825241e-01,  -7.60340989e-01,
                         -7.60874629e-01,  -7.64582634e-01,  -7.48120368e-01,
                         -7.50970066e-01,  -7.73842156e-01,  -7.51765490e-01,
                         -7.58090138e-01,  -7.58582175e-01,  -7.48791993e-01,
                         -7.56663620e-01,  -7.54266202e-01,  -7.65204310e-01,
                         -7.33777881e-01,  -7.47820497e-01,  -7.41966426e-01,
                         -7.49741077e-01,  -7.65379846e-01,  -7.52247036e-01,
                         -7.83826768e-01,  -7.67788887e-01,  -7.53851235e-01,
                         -7.72903323e-01,   1.55617238e-03,  -1.05945123e-02,
                         -1.83072835e-02,   1.26928519e-02,   4.71986458e-03,
                          1.28527023e-02,   2.11275369e-02,  -7.80051667e-03,
                         -7.45980144e-01,  -7.71781087e-01,  -7.49510586e-01,
                         -7.51506805e-01,  -7.56236136e-01,  -7.48843253e-01,
                         -7.55740404e-01,  -7.62606561e-01,  -7.41255820e-01,
                         -7.62178361e-01,  -7.56530941e-01,  -7.79043853e-01,
                         -7.60821223e-01,  -7.58787155e-01,  -7.73256004e-01,
                         -7.39333868e-01,  -7.59675741e-01,  -7.35570431e-01,
                         -7.62614131e-01,  -7.39249706e-01,  -7.61477470e-01,
                         -7.76478708e-01,  -7.52789438e-01,  -7.74506271e-01,
                         -7.60034442e-01,  -7.35637188e-01,  -7.59634554e-01,
                         -7.54834414e-01,  -7.63772488e-01,  -7.54100323e-01,
                         -7.60386646e-01,  -7.57138550e-01,  -7.56832540e-01,
                         -7.59851217e-01,  -7.49582231e-01,  -7.63097286e-01,
                          1.74920564e-03,   8.46607378e-04,  -1.04742972e-02,
                          1.03778597e-02,  -7.85901308e-01,  -7.63931274e-01,
                         -7.53808796e-01,  -7.77093947e-01,  -7.53201365e-01,
                         -7.81809032e-01,  -7.50172675e-01,  -7.71559536e-01,
                         -7.54961848e-01,  -7.57536411e-01,  -7.47227907e-01,
                         -7.60463357e-01,  -7.48056412e-01,  -7.71919429e-01,
                         -7.61973977e-01,  -7.68631279e-01,  -7.55655169e-01,
                         -7.69118786e-01,  -7.69369006e-01,  -7.62960076e-01,
                         -7.63662338e-01,  -7.66986907e-01,  -7.73116112e-01,
                         -7.61542022e-01,  -7.82695532e-01,  -7.45251119e-01,
                         -7.70056248e-01,  -7.56679356e-01,  -7.35432863e-01,
                         -7.69045949e-01,  -7.63672829e-01,  -7.54695177e-01,
                         -7.64473259e-01,  -7.62750208e-01,  -7.50105441e-01,
                         -7.57144392e-01,  -7.63397753e-01,  -7.60942340e-01,
                         -7.63567865e-01,  -7.63921678e-01,  -7.53226399e-01,
                         -7.72121549e-01,  -7.69670904e-01,  -7.57249057e-01,
                         -7.61855483e-01,  -7.44924426e-01,  -7.52257586e-01,
                         -7.57886171e-01,  -7.77393401e-01,  -7.57928252e-01,
                         -7.41431653e-01,  -7.44432986e-01,  -9.27998781e-01,
                         -9.01013076e-01,  -9.34029996e-01,  -9.32416618e-01,
                         -9.33467388e-01,  -9.31700706e-01,  -9.26677942e-01,
                         -9.30216610e-01,  -9.24041569e-01,  -9.06253040e-01,
                         -9.14447486e-01,  -9.08548951e-01,  -7.62488306e-01,
                         -7.60618031e-01,  -7.54877388e-01,  -7.72716939e-01,
                         -7.41622746e-01,  -7.54768610e-01,  -7.65046179e-01,
                         -7.66441345e-01,  -7.61245251e-01,  -7.61755347e-01,
                         -7.38331079e-01,  -7.48675108e-01,  -7.62030602e-01,
                         -7.51535475e-01,  -7.43265331e-01,  -7.50803113e-01,
                         -7.56351292e-01,  -7.65089512e-01,  -7.62159050e-01,
                         -7.52661228e-01,  -7.37817585e-01,  -7.67429590e-01,
                         -7.51212597e-01,  -7.60807931e-01,  -9.19015408e-01,
                         -9.21055317e-01,  -9.19949055e-01,  -9.23343658e-01,
                         -9.19357896e-01,  -9.10364330e-01,  -9.17474866e-01,
                         -9.24256742e-01,  -9.30593371e-01,  -9.24065769e-01,
                         -9.25855756e-01,  -9.46299613e-01,  -7.42292285e-01,
                         -7.61145651e-01,  -7.44542122e-01,  -7.59498596e-01,
                         -9.15329337e-01,  -9.23038363e-01,  -9.65857208e-01,
                         -9.31110024e-01,  -9.20842648e-01,  -9.22601044e-01,
                         -9.11056995e-01,  -9.48145151e-01,  -9.41216886e-01,
                         -9.35111284e-01,  -9.47171092e-01,  -9.36277926e-01,
                         -9.70466435e-01,  -9.43353236e-01,  -9.09356475e-01,
                         -9.43904459e-01,  -9.07208741e-01,  -9.27534521e-01,
                         -9.55136001e-01,  -9.22988594e-01,  -9.39764082e-01,
                         -9.30335045e-01,  -9.19484317e-01,  -9.31860805e-01,
                         -7.71374941e-01,  -7.63310850e-01,  -7.61393309e-01,
                         -7.73627281e-01,  -7.92954922e-01,  -7.59176254e-01,
                         -7.58253872e-01,  -7.29448378e-01,  -7.63050556e-01,
                         -7.48690724e-01,  -7.68006086e-01,  -7.42551029e-01,
                         -7.52723038e-01,  -7.75027275e-01,  -7.53034055e-01,
                         -7.58857667e-01,  -7.61677980e-01,  -7.63589323e-01,
                         -7.50282228e-01,  -7.42789328e-01,  -9.39849257e-01,
                         -9.33743119e-01,  -9.18397367e-01,  -9.41005647e-01,
                         -9.31001782e-01,  -9.36109900e-01,  -9.16696012e-01,
                         -9.45950568e-01,  -9.36002016e-01,  -9.18893278e-01,
                         -9.40885246e-01,  -9.18016136e-01,  -9.53966677e-01,
                         -9.23713386e-01,  -9.45105135e-01,  -9.18445945e-01,
                         -7.53520846e-01,  -7.35458076e-01,  -7.48069346e-01,
                         -7.58432090e-01,  -7.63839841e-01,  -7.60379493e-01,
                         -7.74816513e-01,  -7.35721529e-01,  -4.45857719e-02,
                          8.25549942e-03,   1.43247808e-03,  -1.03802579e-02,
                         -1.12203304e-02,  -4.66361679e-02,  -1.50281154e-02,
                         -1.00437095e-02,   1.43708684e-03,   1.03444206e-02,
                         -1.35163395e-02,   4.52938210e-03,  -7.45511055e-01,
                         -7.56098866e-01,  -7.59630620e-01,  -7.56826818e-01,
                         -9.41920839e-03,   9.33074858e-03,   2.46702619e-02,
                          4.58025141e-03,   1.61741804e-02,  -6.28670305e-03,
                          1.57060160e-03,  -6.86612865e-03,   1.53268442e-01,
                          1.75730571e-01,   1.79872960e-01,   1.55062363e-01,
                          9.10740811e-03,   1.05319237e-02,  -4.64085070e-03,
                          7.36387214e-03,   1.73962027e-01,   1.64927050e-01,
                          1.91808552e-01,   1.97037712e-01,   1.75115652e-02,
                          1.33804407e-03,  -9.55067202e-03,  -1.68533195e-02,
                          4.36828425e-03,   9.98029578e-03,   2.62757577e-02,
                          1.61763001e-02,   1.24677448e-02,   2.90770382e-02,
                          1.16027165e-02,  -9.44427587e-03,   1.49298623e-01,
                          1.63481861e-01,   1.76233515e-01,   1.70922354e-01,
                          1.62364602e-01,   1.73555672e-01,   1.68888301e-01,
                          1.82916343e-01,   1.55919746e-01,   1.78354114e-01,
                          1.72009826e-01,   1.84759200e-01,   1.65141389e-01,
                          1.58107743e-01,   1.65588498e-01,   1.68090254e-01,
                          1.48311466e-01,   1.37545913e-01,   1.88284874e-01,
                          1.54902741e-01,   1.90540299e-01,   1.56491160e-01,
                          1.71373039e-01,   1.81519613e-01,   1.78817302e-01,
                          1.72959968e-01,   1.51669323e-01,   1.41249046e-01,
                          2.05204993e-01,   1.71805561e-01,   1.47440195e-01,
                          1.59388274e-01,   1.81482866e-01,   1.89966381e-01,
                          1.82119057e-01,   1.50254861e-01,   1.84205905e-01,
                          1.64198831e-01,   1.71517044e-01,   1.55537367e-01,
                          1.73087507e-01,   1.71096489e-01,   1.84448689e-01,
                          1.89313203e-01,   1.71148613e-01,   1.59480423e-01,
                          1.51324987e-01,   1.91903085e-01,   1.65403664e-01,
                          1.82261229e-01,   2.07107008e-01,   1.75454214e-01,
                          1.69798389e-01,   1.95059076e-01,   1.79647535e-01,
                          1.98741883e-01,   1.76859200e-01,   1.77365229e-01,
                          1.64196789e-01,   1.61319673e-01,   2.70032324e-02,
                          1.32820215e-02,   2.31640935e-02,  -2.70927455e-02,
                         -2.62829592e-03,  -1.91186275e-02,  -1.05881016e-03,
                         -7.87426345e-03,  -1.82276387e-02,   5.10944473e-03,
                          1.40158571e-02,  -1.86095189e-03,  -2.66793109e-02,
                          1.31131066e-02,   7.56714819e-03,   3.61401075e-03,
                          2.74672862e-02,   6.18836051e-03,   1.31178470e-02,
                         -4.25080629e-03,   1.87917873e-01,   1.36670768e-01,
                          1.44357875e-01,   1.74357936e-01,   1.83825284e-01,
                          1.63840801e-01,   2.01345116e-01,   1.71227202e-01,
                          1.88629180e-01,   1.57848343e-01,   1.81584299e-01,
                          1.46372169e-01,   3.21233016e-03,   2.55261082e-02,
                          1.33255171e-02,  -2.89127114e-03,  -8.61765631e-03,
                         -4.80630808e-03,  -7.75636313e-03,   2.19508167e-02,
                          1.19048136e-03,   6.38334779e-03,   6.29879674e-03,
                         -1.28506506e-02,   1.16071384e-02,  -8.63898732e-03,
                          6.53091073e-03,   1.33499056e-02,  -1.65155586e-02,
                         -3.46264616e-02,  -1.02976337e-02,  -8.54993181e-04,
                          2.13740394e-02,   8.44547618e-03,   1.20270663e-04,
                          1.48383258e-02,  -1.93581376e-02,  -1.59259874e-03,
                          1.31135434e-02,  -1.33116702e-02,   3.83503735e-02,
                          4.67042290e-02,   2.60309689e-02,   3.50502916e-02,
                          2.60436032e-02,   1.84504371e-02,   1.94202755e-02,
                          2.21855156e-02,   1.51657397e-02,  -9.15041193e-03,
                         -6.93482999e-03,   4.18308377e-02,   1.94378030e-02,
                         -3.47313471e-02,   1.69925727e-02,   1.45759676e-02,
                          1.98709611e-02,   1.02291536e-02,   1.90755837e-02,
                          6.86232373e-03,  -6.37193350e-03,  -1.10497857e-02,
                         -1.23765264e-02,  -1.05263442e-02,   1.96681619e-02,
                         -2.73907818e-02,  -1.04424928e-03,   1.12235667e-02,
                         -7.93265924e-03,   3.03293727e-02,  -1.14067513e-02,
                          2.40360457e-03,   1.05547523e-02,  -1.87815111e-02,
                          4.19685990e-03,  -1.25885354e-02,   1.18185924e-02,
                          2.02271231e-02,   2.41237842e-02,   4.51728143e-02,
                         -2.01193132e-02,  -1.06678912e-02,   1.69320647e-02,
                          2.05106940e-02,  -1.02027766e-02,  -9.33651440e-03,
                         -3.04004941e-02,   2.63931248e-02,  -2.07002703e-02,
                         -1.59735302e-03,   1.56070422e-02,  -2.69989762e-02,
                          7.74907926e-03,  -1.66988410e-02,  -1.14840399e-02,
                          3.73183712e-02,   3.25875506e-02,   3.94937024e-02,
                          4.85057943e-02,  -1.60288420e-02,   4.28770185e-02,
                          7.93022662e-03,   6.70631276e-03,   7.12538185e-03,
                          1.38215413e-02,  -9.28619318e-03,   2.59210318e-02,
                          2.02339701e-02,   1.37030110e-02,  -5.41331666e-03,
                          6.53506210e-03,  -7.64649501e-03,  -9.22995389e-01,
                         -9.38040912e-01,  -9.25518751e-01,  -9.36908484e-01,
                         -9.60528851e-01,  -9.35081124e-01,  -9.56316710e-01,
                         -9.28095758e-01,  -9.40409005e-01,  -9.43098664e-01,
                         -9.21811223e-01,  -8.93317759e-01,  -1.01107061e-02,
                          2.13900339e-02,   2.54862085e-02,   7.42668938e-03,
                          3.28357494e-03,   6.01270178e-04,   4.61227521e-02,
                          2.42559202e-02,   3.25417519e-02,   3.40729696e-03,
                         -2.19504144e-02,  -1.55056221e-02,  -9.28713500e-01,
                         -9.09153283e-01,  -9.30183649e-01,  -9.38799918e-01,
                         -9.55914438e-01,  -9.38316226e-01,  -9.26160753e-01,
                         -9.42966402e-01,  -9.31988895e-01,  -9.46807146e-01,
                         -9.18719769e-01,  -9.48627949e-01,  -9.59875643e-01,
                         -9.55247343e-01,  -9.43562925e-01,  -9.40297306e-01,
                         -9.28866804e-01,  -9.69421625e-01,  -9.33301687e-01,
                         -9.43239272e-01,  -9.28186655e-01,  -9.43817198e-01,
                         -9.57280755e-01,  -9.29564774e-01,  -9.42596018e-01,
                         -9.20260549e-01,  -9.09921169e-01,  -9.43921208e-01,
                         -9.39735770e-01,  -9.22066391e-01,  -9.54753339e-01,
                         -9.17402387e-01,  -9.31855500e-01,  -9.50409532e-01,
                         -9.49241817e-01,  -9.36786294e-01,  -9.38074470e-01,
                         -9.44715500e-01,  -9.57067430e-01,  -9.40896332e-01,
                         -9.38856363e-01,  -9.75189447e-01,  -9.39908564e-01,
                         -9.48342621e-01,  -9.51021552e-01,  -9.42474902e-01,
                         -9.40353632e-01,  -9.00206923e-01,  -9.17844892e-01,
                         -9.26465034e-01,  -9.47323322e-01,  -9.10470426e-01,
                         -9.20262992e-01,  -9.08488333e-01,  -9.25502658e-01,
                         -9.53288853e-01,  -9.20632303e-01,  -9.17233884e-01,
                         -9.24162865e-01,  -9.32762802e-01,  -9.50504124e-01,
                         -9.32776332e-01,  -9.07987952e-01,  -9.24566388e-01,
                         -9.37694371e-01,  -9.16937172e-01,  -9.27258313e-01,
                         -9.28051114e-01,  -9.60978270e-01,  -9.65695500e-01,
                         -9.51903522e-01,  -9.50930178e-01,  -9.49910343e-01,
                         -9.67631817e-01,  -9.37339544e-01,  -9.10369635e-01,
                         -9.63845134e-01,  -9.55074787e-01,  -9.45247293e-01,
                         -9.49449182e-01,  -9.50085104e-01,  -9.32162762e-01,
                         -9.44295585e-01,  -9.45043743e-01,  -9.66880023e-01,
                         -9.44285393e-01,  -9.26002920e-01,  -9.30116832e-01,
                         -9.55629110e-01,  -9.25530493e-01,  -9.58907902e-01,
                         -9.12496448e-01,  -9.48999166e-01,  -9.34929967e-01,
                         -9.54227030e-01,  -9.07074690e-01,  -8.98390055e-01,
                         -9.23204720e-01,  -9.21004951e-01,  -9.29890633e-01,
                         -9.62502956e-01,  -9.46719468e-01,  -9.38905835e-01,
                         -9.49815094e-01,  -9.54198658e-01,  -9.61500764e-01,
                         -9.56552029e-01,  -9.44187582e-01,  -9.50255215e-01,
                         -9.44901705e-01,  -9.57719564e-01,  -9.21887159e-01,
                         -9.24473226e-01,  -9.43045318e-01,  -9.53549087e-01,
                         -9.43251789e-01,  -9.23838079e-01,  -9.28404033e-01,
                         -9.26969051e-01,  -9.32512641e-01,  -9.49549615e-01,
                         -9.37888741e-01,  -9.42411602e-01,  -9.28758442e-01,
                         -9.33480322e-01,  -9.72342968e-01,  -9.49384391e-01,
                         -8.98621380e-01,  -9.48039353e-01,  -9.30397213e-01,
                         -9.43886638e-01,  -9.40936029e-01,  -9.16090608e-01,
                         -9.20829892e-01,  -9.21421468e-01,  -9.25858736e-01,
                         -9.14203405e-01,  -9.35757756e-01,  -9.18561280e-01,
                         -9.37596798e-01,  -9.24459696e-01,  -9.12690699e-01,
                         -9.37539577e-01,  -9.50888574e-01,  -9.48149920e-01,
                         -9.47647154e-01,  -9.14274216e-01,  -9.32214975e-01,
                         -9.33789372e-01,  -9.34654295e-01,  -9.57496226e-01,
                         -9.38436210e-01,  -9.43754554e-01,  -9.54797208e-01,
                         -9.35896337e-01,  -9.43583429e-01,  -9.17648256e-01,
                         -9.58521605e-01,  -9.48179603e-01,  -9.18909967e-01,
                         -9.22226965e-01,  -9.03311074e-01,  -8.85559142e-01,
                         -8.70377421e-01,  -9.27917659e-01,  -9.15514052e-01,
                         -9.09296811e-01,  -9.22342598e-01,  -9.50157821e-01,
                         -9.26832497e-01,  -9.29837525e-01,  -9.33632672e-01,
                         -9.18686390e-01,  -9.41168904e-01,  -9.16953027e-01,
                         -9.43293512e-01,  -9.30261970e-01,  -9.20135617e-01,
                         -9.37489569e-01,  -9.17511165e-01,  -9.25305724e-01,
                         -9.57448781e-01,  -9.29910421e-01,  -8.95565450e-01,
                         -9.19845819e-01,  -9.29746926e-01,  -9.46542561e-01,
                         -9.04044390e-01,  -9.13446069e-01,  -9.24814641e-01,
                         -9.35394049e-01,  -9.38311100e-01,  -9.45886374e-01,
                         -9.31591690e-01,  -9.27044868e-01,  -9.18230593e-01,
                         -9.27965820e-01,  -9.34840918e-01,  -9.56210613e-01,
                         -9.55864310e-01,  -9.54018891e-01,  -9.44032669e-01,
                         -9.76286352e-01,  -9.39478636e-01,  -9.84887362e-01,
                         -9.65727687e-01,  -9.46322918e-01,  -9.62160528e-01,
                         -9.65582550e-01,  -9.19928908e-01,  -9.23632562e-01,
                         -9.25264359e-01,  -9.06567872e-01,  -9.43064749e-01,
                         -9.54448402e-01,  -9.51469481e-01,  -9.37105358e-01,
                         -9.40664887e-01,  -9.23812330e-01,  -9.29515481e-01,
                         -9.11960125e-01,  -9.30736125e-01,  -9.45629239e-01,
                         -9.43841934e-01,  -9.32005882e-01,  -9.12731409e-01,
                         -9.39895689e-01,  -9.46001768e-01,  -9.21032727e-01,
                         -9.50543940e-01,  -9.46959615e-01,  -9.36560452e-01,
                         -9.38452184e-01,  -9.22589660e-01,  -9.75223601e-01,
                         -9.31124985e-01,  -9.38396037e-01,  -8.89540851e-01,
                         -9.00072217e-01,  -9.15584564e-01,  -9.45182562e-01,
                         -9.21460450e-01,  -9.17912841e-01,  -9.32443321e-01,
                         -9.34493423e-01,  -9.57134962e-01,  -9.21552122e-01,
                         -9.22469079e-01,  -9.31324780e-01,  -9.35976267e-01,
                         -9.12959635e-01,  -9.09871578e-01,   8.94122350e-04,
                          2.02872846e-02,   7.80955423e-04,   5.51947616e-02,
                          3.11816838e-02,   4.93911840e-02,   1.03636738e-02,
                          3.52995321e-02,  -8.66414513e-03,  -5.88914612e-03,
                         -1.89935472e-02,   1.02118412e-02,   5.02502546e-03,
                         -1.49952788e-02,  -1.20825581e-02,  -5.73938619e-03,
                         -1.01069426e-02,  -1.63281113e-02,   3.56030010e-04,
                          1.40752923e-02,  -3.95937711e-02,   2.62757507e-03,
                         -6.66511152e-03,  -3.35214883e-02,   1.42915081e-02,
                          4.92041744e-03,  -5.71114477e-03,  -6.96673756e-03,
                          1.26236314e-02,  -2.08265632e-02,   1.56082893e-02,
                         -8.28539021e-03,  -2.44194437e-02,  -4.34324667e-02,
                          6.89439103e-03,   7.94365769e-04,   9.23182350e-03,
                         -3.50556336e-03,  -1.06127735e-03,   1.39292199e-02,
                          3.23350960e-03,   1.94743332e-02,   2.98432596e-02,
                         -1.52993659e-02,   1.63028371e-02,   1.16847660e-02,
                          1.99325513e-02,  -2.31193565e-03,  -8.97958457e-01,
                         -9.34853196e-01,  -9.68487322e-01,  -9.53975916e-01,
                         -9.38120067e-01,  -9.45345879e-01,  -9.57204819e-01,
                         -9.67434227e-01,  -9.35694277e-01,  -9.38779950e-01,
                         -9.36038494e-01,  -9.40828562e-01,  -9.41466391e-01,
                         -9.45767283e-01,  -9.18401003e-01,  -9.30747509e-01,
                         -9.36369181e-01,  -9.36330676e-01,  -9.14723277e-01,
                         -9.39115942e-01,  -9.22280848e-01,  -9.44879591e-01,
                         -9.33500290e-01,  -9.26127255e-01,  -9.27768111e-01,
                         -9.39667463e-01,  -9.29621875e-01,  -9.27940011e-01,
                         -9.56012666e-01,  -8.97688448e-01,  -9.29826140e-01,
                         -9.18772697e-01,  -9.16791558e-01,  -9.52270329e-01,
                         -9.18496788e-01,  -9.32984233e-01,  -9.53103423e-01,
                         -9.55488384e-01,  -9.57785487e-01,  -9.41055894e-01,
                         -9.50857520e-01,  -9.46037710e-01,  -9.25463378e-01,
                         -9.33899939e-01,  -9.44760621e-01,  -9.21939909e-01,
                         -9.48143661e-01,  -9.52826321e-01,  -9.10307586e-01,
                         -9.36900616e-01,  -9.02907789e-01,  -9.24514294e-01,
                         -9.24487889e-01,  -9.26403403e-01,  -9.34886396e-01,
                         -9.31925356e-01,  -9.40524995e-01,  -9.27053094e-01,
                         -9.36905861e-01,  -9.24778163e-01,  -9.29636300e-01,
                         -9.39014375e-01,  -9.22917247e-01,  -9.46489453e-01,
                         -9.28576171e-01,  -9.19219077e-01,  -9.26995099e-01,
                         -9.30474281e-01,  -9.52681303e-01,  -9.19185042e-01,
                         -9.42995429e-01,  -9.15733218e-01,  -9.29101586e-01,
                         -9.52829182e-01,  -9.28726673e-01,  -9.02718127e-01,
                         -9.06190872e-01,  -9.36387539e-01,  -9.42529798e-01,
                         -9.25164044e-01,  -9.51928675e-01,  -9.25927818e-01,
                         -9.28685188e-01,  -9.40034330e-01,  -9.31889117e-01,
                         -9.53268409e-01,  -9.26525235e-01,  -9.09580886e-01,
                         -9.24807489e-01,  -9.22428370e-01,  -9.15570557e-01,
                         -9.40478265e-01,  -9.51016843e-01,  -9.35166121e-01,
                         -9.21040356e-01,  -9.42709863e-01,  -9.37091947e-01,
                         -9.41280365e-01,  -9.37653422e-01,  -9.22434688e-01,
                         -9.41722691e-01,  -9.23063815e-01,  -9.43999529e-01,
                         -9.21482444e-01,  -9.23206568e-01,  -9.21079993e-01,
                         -9.21777427e-01,  -9.33449388e-01,  -9.27982867e-01,
                         -9.22185063e-01,  -9.23973203e-01,  -9.16605592e-01,
                         -9.25472796e-01,  -9.12826300e-01,  -9.33661759e-01,
                         -9.23264444e-01,  -9.42459941e-01,  -9.36633170e-01,
                         -9.42880630e-01,  -9.46905196e-01,  -9.28874671e-01,
                         -9.36288536e-01,  -9.30768132e-01,  -9.27693844e-01,
                         -9.44371641e-01,  -9.32337105e-01,  -9.25984919e-01,
                         -9.21345234e-01,  -9.23988342e-01,  -9.26628113e-01,
                         -9.18857872e-01,  -9.16556239e-01,  -9.18580770e-01,
                         -9.21310663e-01,  -9.20162499e-01,  -9.27898824e-01,
                         -9.24389064e-01,  -9.37020183e-01,  -9.30622339e-01,
                         -9.26312923e-01,  -9.26106691e-01,  -9.25762415e-01,
                         -9.21298444e-01,  -9.39812422e-01,  -9.46025848e-01,
                         -9.25291896e-01,  -9.26034451e-01,  -9.27219808e-01,
                         -9.34144318e-01,  -9.38917458e-01,  -9.23142493e-01,
                         -9.29780960e-01,  -9.42136705e-01,  -9.35544133e-01,
                         -9.24750447e-01,  -9.28681672e-01,  -9.33154464e-01,
                         -9.26757216e-01,  -9.26602364e-01,  -9.21673357e-01,
                         -9.21025097e-01,  -9.25558925e-01,  -9.26391780e-01,
                         -9.30369496e-01,  -9.21979606e-01,  -9.28936541e-01,
                         -9.35825825e-01,  -9.18926775e-01,  -9.38355565e-01,
                         -9.23991621e-01,  -9.31611896e-01,  -9.30147946e-01,
                         -9.30249870e-01,  -9.26491320e-01,  -9.27615464e-01,
                         -9.27104115e-01,  -9.25850570e-01,  -9.29986596e-01,
                         -9.30808723e-01,  -9.29996490e-01,  -9.25702929e-01,
                         -9.37178314e-01,  -9.29986417e-01,  -9.30665374e-01,
                         -9.36252952e-01,  -9.40835357e-01,  -9.33815002e-01,
                         -9.27599847e-01,  -9.28376794e-01,  -9.29697454e-01,
                         -9.35499609e-01,  -9.18415308e-01,  -9.31599259e-01,
                         -9.23641205e-01,  -9.26185429e-01,  -9.23210382e-01,
                         -9.24132347e-01,  -9.30755317e-01,  -9.30632412e-01,
                         -9.27161872e-01,  -9.36497569e-01,  -9.25194860e-01,
                         -9.27525580e-01,  -9.24668550e-01,  -9.25718665e-01,
                         -9.21195924e-01,  -9.20842409e-01,  -9.29861188e-01,
                         -9.21237767e-01,  -9.25874233e-01,  -9.19279158e-01,
                         -9.13668096e-01,  -9.26002204e-01,  -9.28496718e-01,
                         -9.20598269e-01,  -9.25993145e-01,  -9.24198866e-01,
                         -9.31383491e-01,  -9.27465916e-01,  -9.21987355e-01,
                         -9.22420382e-01,  -9.13957000e-01,  -9.23289895e-01,
                         -9.28381443e-01,  -9.31073010e-01,  -9.23297465e-01,
                         -9.29480076e-01,  -9.27011907e-01,  -9.33772385e-01,
                         -9.22958016e-01,  -9.34827626e-01,  -9.21094060e-01,
                         -9.30921495e-01,  -9.28143680e-01,  -9.28190887e-01,
                         -9.34490860e-01,  -9.32056308e-01,  -9.35525537e-01,
                         -9.29997385e-01,  -9.35262501e-01,  -9.31534052e-01,
                         -9.24886942e-01,  -9.23701942e-01,  -9.18444037e-01,
                         -9.18669403e-01,  -9.12507772e-01,  -9.21987593e-01,
                         -9.35483158e-01,  -9.28011000e-01,  -9.35608566e-01,
                         -9.31141853e-01,  -9.23781276e-01,  -9.26525176e-01,
                         -9.35707033e-01,  -9.34049308e-01,  -9.35550928e-01,
                         -9.26741362e-01,  -9.21236455e-01,  -9.28433120e-01,
                         -9.34563339e-01,  -9.29459453e-01,  -9.25801516e-01,
                         -9.28792238e-01,  -9.24686134e-01,  -9.22291279e-01,
                         -9.22387540e-01,  -9.34004188e-01,  -9.40659940e-01,
                         -9.26216960e-01,  -9.30580735e-01,  -9.19252634e-01,
                         -9.36751366e-01,  -9.28306103e-01,  -9.38076258e-01,
                         -9.32824194e-01,  -9.33611870e-01,  -9.32767093e-01,
                         -9.43736374e-01,  -9.25661385e-01,  -9.39096868e-01,
                         -9.33569372e-01,  -9.25850749e-01,  -9.35510874e-01,
                         -9.31036055e-01,  -9.51963603e-01,  -9.31567192e-01,
                         -9.39099431e-01,  -9.27486539e-01,  -9.29207444e-01,
                         -9.30277824e-01,  -9.24267888e-01,  -9.26004410e-01,
                         -9.35558140e-01,  -9.27749276e-01,  -9.31785405e-01,
                         -9.40243542e-01,  -9.33903396e-01,  -9.38166976e-01,
                         -9.50021684e-01,  -9.36852157e-01,  -9.31754172e-01,
                         -9.32200015e-01,  -9.32722628e-01,  -9.43378329e-01,
                         -9.50057805e-01,  -9.37194049e-01,  -9.38195467e-01,
                         -9.34495747e-01,  -9.23617184e-01,  -9.32504416e-01,
                         -9.38026011e-01,  -9.36307371e-01,  -9.43536222e-01,
                         -9.43603754e-01,  -9.40260291e-01,  -9.49288905e-01,
                         -9.54044640e-01,  -9.43878889e-01,  -9.36372817e-01,
                         -9.45175886e-01,  -9.46579397e-01,  -9.38041568e-01,
                         -9.50966418e-01,  -9.28651989e-01,  -9.41048801e-01,
                         -9.39063251e-01,  -9.35837328e-01,  -9.31321919e-01,
                         -9.39443946e-01,  -9.38755333e-01,  -9.33681369e-01,
                         -9.27338302e-01,  -9.28755522e-01,  -9.37701106e-01,
                         -9.36566412e-01,  -9.35987949e-01,  -9.36862946e-01,
                         -9.24266815e-01,  -9.31906879e-01,  -9.39266503e-01,
                         -9.36940253e-01,  -9.33436632e-01,  -9.28446710e-01,
                         -9.37406063e-01,  -9.31719780e-01,  -9.28600669e-01,
                         -9.18125212e-01,  -9.16867495e-01,  -9.38659966e-01,
                         -9.34307337e-01,  -9.34528887e-01,  -9.37976599e-01,
                         -9.24925327e-01,  -9.36886311e-01,  -9.44150984e-01,
                         -9.32230294e-01,  -9.37837839e-01,  -9.39116359e-01,
                         -9.32580352e-01,  -9.42162454e-01,  -9.40488935e-01,
                         -9.35462415e-01,  -9.30075526e-01,  -9.54748333e-01,
                         -9.39955711e-01,  -9.36412871e-01,  -9.36104894e-01,
                         -9.16087270e-01,  -9.30554688e-01,  -9.24198389e-01,
                         -9.20388103e-01,  -9.25196230e-01,  -9.40308988e-01,
                         -9.35767055e-01,  -9.40119028e-01,  -9.41684604e-01,
                         -9.42840099e-01,  -9.44651186e-01,  -9.44728494e-01,
                         -9.34583962e-01,  -9.37277853e-01,  -9.38295484e-01,
                         -9.39468682e-01,  -9.40922737e-01,  -9.48679626e-01,
                         -9.53769982e-01,  -9.29770648e-01,  -9.24021244e-01,
                         -9.37325418e-01,  -9.25940335e-01,  -9.15094733e-01,
                         -9.35384154e-01,  -9.35128212e-01,  -9.32709694e-01,
                         -9.42534924e-01,  -9.31257725e-01,  -9.40071344e-01,
                         -9.29726005e-01,  -9.41960990e-01,  -9.31712449e-01,
                         -9.37518418e-01,  -9.33587551e-01,  -9.37868655e-01,
                         -9.36865389e-01,  -9.34485734e-01,  -9.48977113e-01,
                         -9.42166746e-01,  -9.32141244e-01,  -9.45761859e-01,
                         -9.46112871e-01,  -9.34795558e-01,  -9.30924475e-01,
                         -9.53432977e-01,  -9.37827766e-01,  -9.34241712e-01,
                         -9.33372915e-01,  -9.28453445e-01,  -9.21108902e-01,
                         -9.31984663e-01,  -9.36233997e-01,  -9.43343818e-01,
                         -9.28109705e-01,  -9.40807402e-01,  -9.35107172e-01,
                         -9.35310423e-01,  -9.39021111e-01,  -9.37107563e-01,
                         -9.31320250e-01,  -5.53574972e-03,   1.44777838e-02,
                          8.17076769e-04,   4.37784102e-03,   1.44138858e-02,
                          1.32475153e-03,   4.88733873e-04,   5.66493254e-04,
                         -1.09885838e-02,  -1.73357539e-02,  -1.83849111e-02,
                         -1.81789312e-03,  -2.95059546e-03,   4.64026874e-04,
                         -1.51023613e-02,   5.25776995e-03,  -6.35438552e-03,
                          4.55745030e-05,   8.31880199e-04,  -3.47561715e-03,
                         -4.26886696e-03,  -3.37428733e-04,  -5.78478072e-03,
                         -1.45819690e-03,  -9.82584432e-03,  -1.58755342e-04,
                         -3.71392001e-03,  -3.43574630e-03,  -4.41915356e-03,
                          1.18899823e-03,  -1.22341479e-03,  -2.24117609e-03,
                         -9.43935569e-03,   1.50312409e-02,   8.13809130e-03,
                          1.23428795e-02,   4.23470017e-04,   5.94454072e-03,
                         -2.49022781e-03,  -7.28722150e-03,  -2.42053419e-02,
                         -5.24386065e-03,  -1.04791555e-03,   1.21241761e-02,
                         -1.37993856e-03,   6.01649936e-03,  -1.22110697e-03,
                          9.90652852e-03,  -4.23840806e-03,   4.04893002e-03,
                         -8.33309907e-03,   1.10362507e-02,  -6.68100966e-03,
                         -2.52304343e-03,  -6.62607932e-03,  -4.12005698e-03,
                         -1.01939198e-02,  -1.66115453e-04,  -5.87836932e-03,
                          4.51871613e-03,  -7.52630737e-03,   4.02443763e-03,
                          2.83421273e-03,  -1.33952722e-02,   2.52683437e-03,
                          2.70522363e-03,  -9.62863211e-03,   5.01935650e-03,
                          5.53290127e-03,   6.28548348e-03,   4.31252876e-03,
                          2.42619626e-02,   1.37803261e-03,   1.15474397e-02,
                          5.05843014e-03,   1.38752386e-02,   1.10025201e-02,
                          1.90908853e-02,   2.76711234e-03,   8.90686922e-03,
                          2.30784044e-02,   7.16495467e-03,   1.51924009e-03,
                          5.72637795e-03,  -7.28678470e-03,  -1.87034952e-03,
                         -8.63540452e-03,   4.68493532e-03,   2.08081282e-03,
                          1.19832037e-02,   7.43449293e-03,   2.61241826e-03,
                         -1.19618792e-02,  -5.35675744e-03,   2.17733975e-03,
                          6.63217111e-03,  -1.59915071e-02,  -4.21706215e-03,
                         -5.80231473e-03,   8.41116346e-03,   2.81225028e-03,
                          1.23361633e-06,   3.49001167e-03,   7.02265231e-03,
                         -2.92167487e-03,   2.74085999e-03,   9.91597492e-03,
                          1.42463984e-03,  -1.27987284e-02,  -4.15757811e-03,
                          5.29499352e-03,  -1.73957238e-03,   3.64548876e-03,
                         -4.65447607e-04,  -1.85625311e-02,  -6.09484781e-03,
                         -1.22616757e-02,  -1.07695125e-02,  -8.55085999e-03,
                         -6.44518808e-03,  -2.58064223e-03,   3.11231706e-04,
                         -3.17554339e-03,  -6.03403337e-03,  -6.01653429e-03,
                         -1.53905218e-02,  -1.48317416e-03,  -5.25481068e-03,
                         -8.09536490e-04,  -1.14175696e-02,  -9.16691963e-03,
                         -1.16840107e-04,  -1.19070457e-02,  -3.92393966e-04,
                         -4.55033965e-03,   6.35595899e-03,   5.80643117e-03,
                         -6.35471148e-03,  -5.73766045e-03,   6.15858007e-03,
                         -2.03810050e-04,  -5.00160037e-03,  -5.10507869e-03,
                         -1.04393053e-03,  -6.13241084e-03,   2.80565955e-03,
                         -1.18877375e-02,   7.06498325e-03,   5.65391313e-03,
                         -6.89485529e-03,  -1.09612774e-02,  -4.37996862e-03,
                         -1.86147168e-03,   6.77670538e-03,  -1.85625302e-03,
                          1.88473015e-04,   4.78945998e-03,  -5.18491026e-03,
                          8.07954930e-03,  -4.92323795e-03,  -6.94137905e-03,
                          6.77877758e-03,  -7.64381979e-03,  -8.50306824e-03,
                         -5.75190934e-04,  -6.96754130e-03,  -1.70620643e-02,
                         -3.32238525e-03,  -3.70161841e-03,  -1.01661077e-02,
                         -1.27262287e-02,  -1.38115825e-03,  -6.22045528e-03,
                         -1.02945082e-02,  -5.21726161e-03,  -5.43178618e-03,
                          6.22256892e-03,  -2.51922477e-03,  -1.21566793e-02,
                         -9.91384685e-03,  -1.49920431e-03,  -4.06962400e-03,
                          2.05711764e-03,   1.76829897e-04,  -1.03512884e-03,
                         -1.09035743e-03,   1.90435024e-03,   1.33485608e-02,
                          1.15183657e-02,  -1.07093286e-02,   7.30913552e-03,
                         -3.10836663e-03,   4.67404770e-03,  -3.52142029e-04,
                         -5.28936600e-03,   2.69058649e-03,   4.22043027e-03,
                          2.42565011e-06,  -1.00362664e-02,  -1.15828949e-03,
                         -1.68077461e-03,   4.87902207e-06,  -7.10433442e-03,
                         -3.61861964e-03,   1.35954923e-03,   2.77463184e-03,
                         -1.48990366e-04,   7.14369211e-03,   2.99423654e-03,
                         -2.01672711e-03,   3.14570777e-03,  -2.61734589e-04,
                         -4.90408950e-03,   6.39858772e-04,   4.91533778e-04,
                          6.76988577e-03,  -9.41331033e-03,  -8.08070041e-03,
                          5.86922094e-03,   1.21441910e-04,  -7.99043104e-03,
                         -2.24579871e-03,  -1.14514946e-03,  -3.55303683e-03,
                         -1.63766043e-03,   2.84507964e-03,   8.05676216e-04,
                         -3.66867124e-03,  -6.69014407e-03,  -6.75855408e-05,
                          9.86373285e-04,   1.82915502e-03,  -1.63436844e-03,
                         -2.21461858e-04,   2.89219967e-03,   1.15731929e-03,
                          3.61962453e-03,  -2.09174206e-04,   3.12354423e-05,
                          3.62946557e-05,  -7.89301004e-03,  -5.76018449e-03,
                         -4.82376572e-03,   5.26028592e-03,  -3.93832009e-03,
                         -3.36086308e-03,  -6.72029855e-04,   2.46023294e-04,
                         -1.63691188e-03,  -6.16048602e-03,  -3.69268516e-03,
                         -4.99678403e-03,  -5.22974320e-03,  -8.98130238e-03,
                         -3.50229233e-03,  -2.56782793e-03,  -8.33384134e-03,
                         -2.12909025e-03,  -1.86296168e-03,   4.87997849e-03,
                         -3.13081429e-03,  -9.16487537e-03,  -4.62748902e-03,
                         -4.44257818e-03,  -1.34212605e-03,  -1.28747206e-02,
                         -7.47301208e-04,   1.49390940e-03,  -1.34278033e-02,
                          2.00373260e-03,  -7.28060957e-03,   3.10670352e-04,
                         -4.85148747e-03,  -3.31583596e-03,  -3.82604031e-03,
                         -1.16383107e-02,   2.86312657e-03,   1.45012292e-03,
                          6.04685489e-03,  -7.64689699e-04,   6.07268466e-03,
                         -8.00540764e-03,  -2.55561643e-03,  -8.91544949e-03,
                         -1.10556008e-02,  -4.07097582e-03,  -8.72254744e-03,
                         -4.71105613e-03,   1.12933628e-02,   7.65258679e-03,
                          1.60819909e-03,   4.12086770e-03,   7.12489709e-04,
                         -1.28633610e-03,   5.54557703e-03,   1.46082358e-03,
                         -2.75749294e-03,  -1.68241712e-03,  -1.23198074e-03,
                         -9.62269958e-03,  -6.40173443e-03,   3.73640214e-04,
                         -2.09332909e-03,  -3.11034196e-03,   1.09598495e-03,
                         -5.98375313e-03,   2.87097879e-03,  -8.56233703e-04,
                          4.74133529e-03,   5.71381999e-03,   6.25670794e-03,
                          5.79298614e-03,   4.07925050e-04,   5.70205878e-03,
                          3.21156076e-05,   2.88949674e-03,   3.49132135e-03,
                          1.21542402e-02,   8.96609016e-03,   1.34761361e-02,
                         -1.14518404e-03,   8.15099571e-03,   3.48782842e-03,
                         -1.81960489e-03,  -6.45475229e-03,  -7.60683883e-03,
                          6.07242109e-03,   6.22845301e-03,   6.14865590e-03,
                         -7.18234992e-03,   2.89660064e-03,  -3.15791229e-03,
                         -8.14872910e-04,   3.13367671e-03,  -5.71955834e-03,
                         -2.59423978e-03,  -5.60498447e-04,  -1.56044844e-03,
                         -1.15218386e-03,  -1.23359554e-03,  -4.72468138e-03,
                         -9.79435910e-03,   1.80468371e-04,  -1.08032918e-03,
                          6.63571246e-03,   4.22354229e-03,   5.65570826e-03,
                          1.59069290e-03,   6.84199668e-03,  -1.64465315e-03,
                          8.80053639e-03,   1.12204552e-02,  -2.72435165e-04,
                          3.04533448e-03,   1.82712451e-03,   7.41370860e-03,
                          9.56467167e-03,  -5.28535293e-03,   5.87601960e-03,
                          7.53406947e-03,   6.74668280e-03,   9.46957152e-03,
                          5.18707279e-03,  -1.39624933e-02,  -7.58877117e-03,
                         -4.02602484e-04,  -4.21534339e-03,  -7.63285579e-03,
                         -4.68136603e-03,   1.38436712e-03,  -3.04122479e-03,
                          7.95980566e-04,   7.29124108e-03,  -4.03676694e-03,
                         -3.42870504e-03,  -6.17029960e-04,  -1.94506650e-03,
                         -2.71422626e-03,  -8.82186834e-03,   4.19318676e-03,
                         -2.83593847e-03,   2.91754422e-03,   5.97624760e-03,
                         -6.73838006e-03,  -8.99465010e-03,   4.89649363e-03,
                         -2.46114773e-03,  -1.04810961e-03,  -1.23893889e-03,
                         -1.39003620e-04,   2.88638519e-04,   8.67828354e-03,
                         -1.00080874e-02,  -8.96782987e-03,   1.37932934e-02,
                          1.73377851e-03,   1.39977131e-02,  -5.55002596e-04,
                         -8.23390437e-04,   7.72645790e-03,  -3.80360661e-03,
                          1.69056724e-03,  -3.47357965e-03,   3.70615791e-03,
                         -2.31758389e-03,   9.29675472e-04,  -9.76566807e-04,
                          5.30878501e-03,  -9.48549807e-03,  -6.49613375e-03,
                          8.99320177e-04,   2.10472965e-03,  -6.23984635e-03,
                          2.27898848e-03,   3.28112836e-03,   6.44746842e-03,
                          3.73605581e-04,  -1.87166629e-03,  -8.49900022e-03,
                         -3.09815817e-03,   8.21825489e-03,   4.38643480e-03,
                          5.49522042e-03,  -1.98316295e-03,  -1.22958981e-03,
                         -5.36378473e-03,  -6.24381052e-03,   4.13733441e-03,
                         -4.54405369e-03,  -1.42645352e-02,  -5.19209029e-03,
                         -8.83652549e-03,  -5.34861395e-03,   6.98869303e-03,
                         -7.37014413e-03,  -1.56238896e-03,   3.67752137e-03,
                          1.01579782e-02,   4.71263612e-03,   1.36090058e-03,
                          4.94431378e-03,   9.24743805e-03,   1.98371755e-03,
                          7.62767158e-03,   4.99159982e-03,  -5.85314259e-03,
                          8.09290446e-03,   9.80122760e-03,   6.04178151e-03,
                          7.18246773e-03,   1.55221508e-03,   9.92375077e-04,
                          1.23610580e-02,   3.77585716e-03,  -7.31306477e-03,
                         -1.59026049e-02,  -4.54710983e-03,  -2.26494041e-03,
                         -5.26144286e-04,   5.15099289e-03,   6.22558361e-03,
                          3.99627956e-03,   5.64587396e-03,   2.26320093e-03,
                          8.27812683e-03,  -2.98882369e-03,   7.32264295e-03,
                          4.87026200e-03,  -9.25141692e-01,  -9.31799412e-01,
                         -9.18042302e-01,  -9.34790671e-01,  -9.23569679e-01,
                         -9.41651046e-01,  -9.36608791e-01,  -9.26227510e-01,
                         -9.32121217e-01,  -9.25739408e-01,  -9.36569095e-01,
                         -9.32643473e-01,  -7.34673988e-04,  -2.07643979e-03,
                          2.90287950e-04,  -3.28448974e-03,   4.31906432e-03,
                          1.10766618e-02,   9.52695590e-03,   3.18449759e-03,
                          2.74838647e-03,  -1.40827009e-03,  -1.12540331e-02,
                          2.62990384e-03,  -1.62574009e-03,   8.08550976e-03,
                         -6.73623150e-03,   5.31451637e-03,   1.56128011e-03,
                          3.42063792e-03,   2.51383288e-03,   9.88758076e-03,
                          7.38568185e-03,   3.43022961e-03,   1.01140188e-02,
                          8.89612734e-03,   5.40313590e-03,   3.77673726e-03,
                          1.47811426e-02,  -4.47578868e-03,   3.05659650e-03,
                          2.22348259e-03,  -9.97413509e-03,  -1.90587493e-03,
                         -3.51585518e-03,   1.69728976e-03,   5.65330358e-03,
                         -3.18344403e-03,  -8.56386207e-04,  -2.47163349e-03,
                          1.55477246e-04,   4.24030004e-03,   8.69839545e-03,
                         -1.27958588e-03,  -1.05630066e-02,   2.70009506e-04,
                          2.53445096e-03,  -4.09200264e-04,   3.33690457e-03,
                          1.10580539e-03,   9.75107867e-03,   7.89102074e-03,
                          1.03755174e-02,   7.35071115e-03,   9.02431959e-04,
                          6.94144145e-03,   1.13089979e-02,   8.21803347e-04,
                          8.68447870e-03,  -6.28136657e-03,   1.46158587e-03,
                         -7.64396507e-03,  -9.78449732e-03,  -1.07332936e-03,
                          8.45095143e-03,  -9.76674911e-03,  -9.37981009e-01,
                         -9.38742340e-01,  -9.29352939e-01,  -9.37596440e-01,
                         -9.38797712e-01,  -9.27934945e-01,  -9.38318551e-01,
                         -9.39822853e-01,  -9.35301661e-01,  -9.32952940e-01,
                         -9.33467150e-01,  -9.45489049e-01,  -9.32078719e-01,
                         -9.23005760e-01,  -9.24457669e-01,  -9.36661780e-01,
                         -9.25940096e-01,  -9.47311461e-01,  -9.24139857e-01,
                         -9.17349219e-01,  -9.24181998e-01,  -9.25012529e-01,
                         -9.21659887e-01,  -9.33115602e-01,  -9.33084011e-01,
                         -9.34348702e-01,  -9.34023142e-01,  -9.28664744e-01,
                         -9.33397174e-01,  -9.30488944e-01,  -9.43010151e-01,
                         -9.39756632e-01,  -9.34058607e-01,  -9.37075973e-01,
                         -9.24401641e-01,  -9.25379515e-01,  -9.27555025e-01,
                         -9.21728075e-01,  -9.20293927e-01,  -9.30862844e-01,
                         -9.32705343e-01,  -9.42132711e-01,  -9.27309692e-01,
                         -9.30963397e-01,  -9.38280761e-01,  -9.38532233e-01,
                         -9.29950833e-01,  -9.42971945e-01,  -9.31657910e-01,
                         -9.39356208e-01,  -9.36959088e-01,  -9.34706748e-01,
                         -9.39273298e-01,  -9.37878430e-01,  -9.35132980e-01,
                         -9.35075104e-01,  -9.31140065e-01,  -9.35160398e-01,
                         -9.42471266e-01,  -9.37735498e-01,  -9.33654428e-01,
                         -9.33941483e-01,  -9.33522940e-01,  -9.36426163e-01,
                         -9.26852465e-01,  -9.31824148e-01,  -9.36854064e-01,
                         -9.30144429e-01,  -9.32252705e-01,  -9.33353364e-01,
                         -9.28090513e-01,  -9.25720274e-01,  -9.22815502e-01,
                         -9.28552568e-01,  -9.28324997e-01,  -9.34953272e-01,
                         -9.29857790e-01,  -9.27972078e-01,  -9.34743464e-01,
                         -9.30253744e-01,  -9.31087375e-01,  -9.32175279e-01,
                         -9.28641140e-01,  -9.35504556e-01,  -9.25047457e-01,
                         -9.35437620e-01,  -9.32335556e-01,  -9.40970838e-01,
                         -9.35478866e-01,  -9.40643609e-01,  -9.37700808e-01,
                         -9.38284636e-01,  -9.30090308e-01,  -9.30509031e-01,
                         -9.26264763e-01,  -9.36373353e-01,  -9.37749684e-01,
                         -9.39074695e-01,  -9.20270741e-01,  -9.30433691e-01,
                         -9.38677073e-01,  -9.36768234e-01,  -9.22236621e-01,
                         -9.33256030e-01,  -9.31405187e-01,  -9.33117628e-01,
                         -9.32071745e-01,  -9.30829048e-01,  -9.34318066e-01,
                         -9.36022878e-01,  -9.29509223e-01,  -9.40917075e-01,
                         -9.33582366e-01,  -9.33759987e-01,  -9.29597855e-01,
                         -9.31132078e-01,  -9.36933339e-01,  -9.39016044e-01,
                         -9.42224205e-01,  -9.33453739e-01,  -9.35343802e-01,
                         -9.29964781e-01,  -9.39786673e-01,  -9.38714504e-01,
                         -9.30906534e-01,  -9.32654679e-01,  -9.27286923e-01,
                         -9.35861647e-01,  -9.27861929e-01,  -9.32266891e-01,
                         -9.25392628e-01,  -9.24382925e-01,  -9.21287000e-01,
                         -9.34586644e-01,  -9.32496786e-01,  -9.36032712e-01,
                         -9.28610325e-01,  -9.31650698e-01,  -9.31196392e-01,
                         -9.27801192e-01,  -9.25734282e-01,  -9.26922500e-01,
                         -9.24708188e-01,  -9.27022874e-01,  -9.32572067e-01,
                         -9.36245859e-01,  -9.28510785e-01,  -9.32213664e-01,
                         -9.29685116e-01,  -9.30335462e-01,  -9.25064445e-01,
                         -9.33962464e-01,  -9.31044400e-01,  -9.33531582e-01,
                         -9.32680726e-01,  -9.27491248e-01,  -9.26089227e-01,
                         -9.35761392e-01,  -9.32121754e-01,  -9.34112489e-01,
                         -9.34517682e-01,  -9.31165934e-01,  -9.31756020e-01,
                         -9.34825182e-01,  -9.34555411e-01,  -9.37497675e-01,
                         -9.38591778e-01,  -9.32749152e-01,  -9.36150253e-01,
                         -9.37462628e-01,  -9.32269096e-01,  -9.33832169e-01,
                         -9.25328910e-01,  -9.37676609e-01,  -9.25216615e-01,
                         -9.35199976e-01,  -9.24216986e-01,  -9.30559158e-01,
                         -9.34565365e-01,  -9.36490119e-01,  -9.29587781e-01,
                         -9.34808552e-01,  -9.33823645e-01,  -9.35039818e-01,
                         -9.25560296e-01,  -9.32902932e-01,  -9.31888223e-01,
                         -9.28560257e-01,  -9.32282090e-01,  -9.37697351e-01,
                         -9.35254872e-01,  -9.31902170e-01,  -9.35973823e-01,
                         -9.28580761e-01,  -9.34801877e-01,  -9.30771947e-01,
                         -9.29259062e-01,  -9.29633141e-01,  -9.36020315e-01,
                         -9.32378769e-01,  -9.36150610e-01,  -9.38555062e-01,
                         -9.28953826e-01,  -9.26295638e-01,  -9.27594483e-01,
                         -9.35067654e-01,  -9.33650672e-01,  -9.30674314e-01,
                         -9.34787929e-01,  -9.31797743e-01,  -9.26068842e-01,
                         -9.23194826e-01,  -9.29672778e-01,  -9.35048163e-01,
                         -9.33378100e-01,  -9.29957330e-01,  -9.35677886e-01,
                         -9.31826353e-01,  -9.41063106e-01,  -9.33431983e-01,
                         -9.40882564e-01,  -9.32857454e-01,  -9.33943510e-01,
                         -9.35772359e-01,  -9.38442528e-01,  -9.36985791e-01,
                         -9.42906737e-01,  -9.35715497e-01,  -9.46368694e-01,
                         -9.35977638e-01,  -9.35051918e-01,  -9.32334304e-01,
                         -9.38053846e-01,  -9.39425409e-01,  -9.30723488e-01,
                         -9.35325146e-01,  -9.34914231e-01,  -9.41173196e-01,
                         -9.43602979e-01,  -9.34062183e-01,  -9.38232481e-01,
                         -9.31499481e-01,  -9.35636401e-01,  -9.35829163e-01,
                         -9.28312480e-01,  -9.33411717e-01,  -9.43469346e-01,
                         -9.44420755e-01,  -9.45195198e-01,  -9.37681377e-01,
                         -9.34161484e-01,  -9.37239528e-01,  -9.35926616e-01,
                         -9.38563943e-01,  -9.38360572e-01,  -9.31771100e-01,
                         -9.42115307e-01,  -9.25591528e-01,  -9.31920946e-01,
                         -9.38693345e-01,  -9.32827115e-01,  -9.31776762e-01,
                         -9.35239673e-01,  -9.36113656e-01,  -9.28145707e-01,
                         -9.37234104e-01,  -9.29761767e-01,  -9.34264839e-01,
                         -9.34022009e-01,  -9.31898415e-01,  -9.26968575e-01,
                         -9.34218645e-01,  -9.38212097e-01,  -9.39317644e-01,
                         -9.33671296e-01,  -9.36394870e-01,  -9.30502117e-01,
                         -9.29493964e-01,  -9.37388539e-01,  -9.40201402e-01,
                         -9.40378487e-01,  -9.39831138e-01,  -9.33573723e-01,
                         -9.34370339e-01,  -9.35426950e-01,  -9.36864853e-01,
                         -9.32884872e-01,  -9.44725573e-01,  -9.39016700e-01,
                         -9.35803294e-01,  -9.35651600e-01,  -9.31562006e-01,
                         -9.33965027e-01,  -9.37426686e-01,  -9.33494210e-01,
                         -9.34383929e-01,  -9.39161181e-01,  -9.33805883e-01,
                         -9.27410007e-01,  -9.24118936e-01,  -9.35944140e-01,
                         -9.33434188e-01,  -9.25961673e-01,  -9.29757237e-01,
                         -9.27334785e-01,  -9.21857119e-01,  -9.34983492e-01,
                         -9.33073163e-01,  -9.39579666e-01,  -9.30221379e-01,
                         -9.38884079e-01,  -9.37077940e-01,  -9.31099236e-01,
                         -9.31496680e-01,  -9.32149589e-01,  -9.38301563e-01,
                         -9.39506054e-01,  -9.43005085e-01,  -9.34606254e-01,
                         -9.32365119e-01,  -9.36661899e-01,  -9.29248035e-01,
                         -9.34712410e-01,  -9.32915688e-01,  -9.35465515e-01,
                         -9.36981499e-01,  -9.38127935e-01,  -9.37187850e-01,
                         -9.36669886e-01,  -9.37636614e-01,  -9.37392533e-01,
                         -9.38005209e-01,  -9.37611878e-01,  -9.37589824e-01,
                         -9.30258870e-01,  -9.31232750e-01,  -9.33826387e-01,
                         -9.39477742e-01,  -9.39631879e-01,  -9.36272919e-01,
                         -9.29476738e-01,  -9.34174716e-01,  -9.38887715e-01,
                         -9.33319747e-01,  -9.29521441e-01,  -9.29153204e-01,
                         -9.27448869e-01,  -9.32257235e-01,  -9.27940488e-01,
                         -9.37582493e-01,  -9.38168049e-01,  -9.28671420e-01,
                         -9.44571912e-01,  -9.32951212e-01,  -9.29481685e-01,
                         -9.25745606e-01,  -9.32733834e-01,  -9.27266598e-01,
                         -9.29410756e-01,  -9.30106342e-01,  -9.26320374e-01,
                         -9.29568827e-01,  -9.30480182e-01,  -9.19378102e-01,
                          3.85345030e-03,   2.68638670e-03,   1.28538662e-03,
                          4.41281212e-04,   6.05185144e-03,  -1.17041776e-03,
                          1.55963073e-03,   5.28447283e-03,   5.35363844e-03,
                         -2.74263415e-03,   4.12134593e-03,   1.31889600e-02,
                          1.65822299e-03,  -6.16260688e-04,   8.28906335e-03,
                          1.25061674e-03,   5.20913210e-03,   3.31354211e-03,
                         -3.01214471e-03,   6.76340569e-05,   1.34161394e-02,
                          7.12091895e-03,  -1.12120484e-04,   4.79919743e-03,
                          1.25287601e-03,   1.12761268e-02,   7.88361952e-03,
                         -5.26178977e-04,   5.06193005e-03,   4.39209025e-03,
                          1.41182682e-02,   6.62783254e-03,   3.51920258e-03,
                          1.27747832e-02,   4.25350945e-03,   1.99781405e-03,
                          2.74652903e-05,   6.27605105e-03,   2.92153633e-03,
                         -3.47718340e-03,  -8.36168043e-03,  -3.12449387e-03,
                         -5.55619411e-03,   4.96649789e-03,   1.26675772e-03,
                          9.35412478e-03,   4.55606403e-03,   2.04845471e-03,
                          4.31543263e-03,   6.84631430e-03,   8.69235198e-04,
                          1.64990639e-03,  -3.78467957e-03,  -3.10928165e-03,
                         -1.56232656e-03,  -5.98806376e-03,  -2.61090742e-03,
                          2.87126284e-03,  -1.68742088e-04,  -8.48048180e-03,
                         -3.27292294e-03,  -1.28382037e-03,   5.18770365e-04,
                          4.20279941e-03,   1.35401182e-03,   3.19620990e-03,
                          2.89684301e-03,  -3.03322007e-03,   1.26013916e-03,
                         -3.14339320e-03,  -1.78747543e-03,   1.50237151e-03,
                         -1.94662588e-03,   4.74366406e-03,   3.54390265e-03,
                          2.99897674e-03,   8.87413695e-03,   4.07692185e-03,
                         -3.60333803e-03,   3.40604247e-03,   5.26366093e-05,
                          1.67348376e-03,   4.46330011e-03,   4.24358482e-03,
                          2.38243886e-03,  -3.06315254e-03,  -3.22359893e-03,
                         -2.88154068e-03,  -5.80724888e-03,   7.85439392e-04,
                          6.17193524e-03,   1.85181061e-03,   5.69196127e-05,
                         -4.76209866e-03,  -1.65737746e-03,  -1.00227866e-04,
                          3.13450140e-03,   5.64421061e-04,  -6.86507497e-04,
                          1.62606582e-03,  -1.23595889e-03,  -4.08389373e-03,
                         -4.44558589e-03,  -4.75386530e-03,  -8.55062448e-04,
                          1.41356501e-03,  -8.90005686e-05,  -1.03810208e-03,
                         -3.89521290e-03,  -1.38165036e-04,  -4.56343824e-03,
                         -5.72897680e-03,  -7.67676020e-03,   7.46906211e-04,
                          2.89738365e-03,  -1.87292078e-03,  -7.30578788e-03,
                         -1.44441926e-03,  -8.89685471e-03,   4.03795904e-03,
                          6.30669035e-07,   6.93555747e-04,   7.43593439e-04,
                          3.85477382e-04,   3.25450185e-03,   8.34407005e-03,
                          5.76618651e-04,   1.46812131e-03,   2.67908908e-03,
                          1.22737896e-03,   4.49197134e-03,   1.33902824e-03,
                          3.18835070e-03,   7.62394303e-03,   7.77524838e-04,
                          4.56791511e-03,   1.79559796e-03,  -2.51094298e-03,
                          3.76352784e-03,  -4.63379594e-03,  -2.31147138e-03,
                          1.16895550e-04,   2.20321794e-03,   3.52918240e-03,
                          5.30640781e-03,   4.14253213e-03,   3.51185631e-03,
                          7.43621169e-03,  -5.96585218e-04,   4.07911197e-04,
                         -1.45843253e-03,   8.02051625e-04,  -3.91215086e-03,
                          2.58080871e-03,  -1.49131741e-03,  -3.48509103e-03,
                          3.91801400e-03,   3.79628123e-04,   7.76519941e-04,
                         -3.20830353e-04,   2.73164245e-03,   8.63964576e-03,
                          3.16062919e-03,  -3.31815076e-03,   3.54916975e-03,
                          1.67337293e-03,   1.20595703e-03,   9.95521434e-04,
                         -4.78298729e-03,  -1.95165037e-03,   4.12232988e-03,
                          8.98934901e-03,  -1.02521142e-03,   4.61145211e-03,
                         -2.26125354e-03,   2.23841774e-03,  -2.96686823e-03,
                          2.81798188e-04,   5.58521179e-03,   2.57477909e-03,
                         -5.12599479e-03,   5.57601510e-04,   2.44554039e-03,
                          4.63858480e-03,   3.04979761e-03,  -1.18205394e-03,
                          1.69976393e-03,  -3.32965545e-04,   1.12391461e-03,
                         -6.07341237e-04,   2.82875868e-03,  -1.67149468e-03,
                          3.11023789e-03,  -2.70342873e-03,   3.19388811e-04,
                         -4.18418413e-03,  -3.95401055e-03,  -6.71089394e-03,
                          1.76711392e-03,  -4.36580973e-03,  -5.62462537e-03,
                          2.91541661e-03,  -4.02947608e-03,  -4.95033630e-04,
                          3.97313852e-03,   3.60685866e-03,   4.57578804e-03,
                          1.73761800e-03,   5.77493943e-03,   5.58064505e-03,
                          4.40511946e-03,   1.17893529e-03,   1.11628418e-04,
                         -8.54930782e-04,   7.46039907e-04,  -3.38599959e-04,
                         -4.92643984e-03,  -1.29057060e-03,  -2.07205978e-03,
                          1.47805258e-03,   4.34498396e-03,   5.43097546e-03,
                          3.42070032e-03,  -8.46378622e-04,  -3.05548747e-04,
                          2.57617212e-03,  -4.38176387e-04,  -3.33267706e-03,
                         -8.59969237e-04,  -2.83426815e-03,  -2.68724607e-03,
                          8.51867546e-04,   3.98544734e-03,  -1.35108712e-03,
                         -2.13644336e-04,  -3.42450524e-03,   5.07723249e-04,
                          3.93703114e-03,  -5.24355564e-03,   1.44940219e-03,
                          2.33145873e-03,  -1.24887028e-03,   4.85982484e-04,
                         -1.30897097e-03,   3.16900807e-03,  -2.64786743e-03,
                          1.84952354e-04,  -3.09529598e-03,   6.28146343e-04,
                         -3.63909901e-04,   1.43182662e-03,   1.73427747e-03,
                          3.32693849e-03,  -2.39085243e-03,  -8.07381119e-04,
                         -1.81175966e-03,  -1.43856998e-03,  -1.04670273e-03,
                         -3.84559808e-03,  -6.63278811e-03,  -5.12625836e-03,
                          1.69289589e-04,  -2.81635998e-03,  -7.27701990e-04,
                          1.40877604e-03,  -2.78091081e-03,  -7.85911363e-03,
                         -6.28483901e-03,  -2.42463150e-03,  -3.66273173e-03,
                         -3.14703165e-03,  -2.11704499e-03,  -4.89350641e-04,
                          6.68398279e-04,   4.39400272e-03,  -2.34249886e-03,
                         -7.38104573e-04,   1.76167348e-03,   1.10575685e-03,
                         -2.98833172e-03,  -1.89130020e-03,   3.53556522e-03,
                          4.73151496e-03,  -5.49929537e-05,  -6.38444966e-04,
                          6.63131184e-04,   5.34467748e-04,   1.71354855e-03,
                          2.72805244e-03,   3.37401009e-03,   1.37447042e-03,
                         -2.57825828e-04,   6.84137281e-04,   3.49812722e-03,
                          7.36649148e-04,   2.22637272e-03,   2.88878987e-03,
                          7.35428696e-03,   2.29289779e-03,   5.26829017e-03,
                         -4.73534735e-03,   2.08292669e-03,  -1.26691011e-03,
                         -4.24571946e-04,  -1.54259568e-03,  -2.49468419e-03,
                         -2.43240735e-03,  -1.42539525e-03,   4.31284076e-03,
                         -2.41749315e-03,   1.18991314e-03,  -2.06136610e-03,
                         -5.35045052e-03,  -3.71160521e-03,  -2.45662918e-03,
                          3.14191013e-04,  -1.03843468e-03,  -3.51316622e-03,
                         -5.04733436e-03,  -2.76872725e-03,  -4.21317434e-03,
                          3.33353644e-04,   2.34368397e-03,  -4.35527554e-03,
                         -6.68308232e-04,  -1.59001374e-03,   3.25572840e-03,
                         -1.45419803e-03,  -2.86140083e-03,   2.80489703e-03,
                         -3.60659542e-05,   4.43623692e-04,   1.02386693e-03,
                         -2.32259466e-04,  -3.13134119e-03,  -5.74532569e-05,
                          4.73892363e-03,   5.54219470e-04,  -2.19777063e-03,
                         -4.74008778e-03,  -1.85763219e-03,  -3.42709718e-05,
                         -9.01551801e-04,  -2.56470218e-03,  -4.11314704e-03,
                         -2.80484860e-03,   1.99227664e-03,   2.92256195e-03,
                          1.30210980e-03,  -4.60468093e-03,   9.46682761e-04,
                         -1.42121618e-03,   1.54389860e-03,  -2.45621341e-04,
                          1.88084916e-04,  -3.13161151e-03,  -5.56570990e-03,
                          3.01137543e-03,  -4.57685528e-04,  -1.37179531e-03,
                          5.91713120e-04,   1.39975257e-03,  -5.89721277e-03,
                          2.57936714e-04,   4.13978100e-03,   3.27491877e-03,
                         -1.81297248e-03,   1.99346861e-04,   1.05799932e-03,
                         -2.02383078e-03,   4.04203427e-04,  -4.56846971e-03,
                         -1.04777690e-03,  -6.58462849e-03,  -6.84134522e-03,
                         -1.29998219e-03,  -7.82972143e-04,   1.71141396e-03,
                         -1.57166889e-03,  -2.25093402e-03,   4.71125729e-03,
                         -4.26774425e-03,   2.90341326e-03,   5.80201682e-04,
                          3.38211859e-04,   1.54771039e-03,  -7.12018402e-04,
                         -6.11656113e-03,  -1.95690361e-03,  -1.24609114e-05,
                         -3.50798923e-03,  -8.36233236e-03,  -5.62209589e-03,
                          2.76704994e-03,   3.03362217e-03,   5.16393874e-03,
                          5.80758182e-03,  -7.06944661e-03,   9.06398240e-03,
                          2.11830647e-03,  -7.22264359e-03,   1.09223081e-02,
                         -2.05961964e-03,  -4.68631461e-03,  -4.29880660e-04,
                          2.97077000e-03,   6.56422507e-03,   2.34491751e-03,
                          1.86958723e-03,  -5.70413098e-03,  -5.28331567e-03,
                          1.11048827e-02,  -3.03861895e-03,  -6.72544073e-03,
                         -7.87617639e-03,   2.89752916e-03,   6.67401031e-03,
                         -8.03853571e-03,  -2.88543571e-03,  -3.06598027e-03,
                         -4.99092788e-03,  -3.58058535e-03,  -8.57404957e-04,
                         -2.77369632e-03,   1.72436005e-03,  -9.70763247e-03,
                         -2.19036895e-03,  -9.86844534e-04,   2.49151699e-03,
                         -1.45010906e-03,  -9.30496771e-03,   2.40998738e-03,
                          1.88579748e-03,   1.25676543e-02,  -1.44894479e-03,
                         -4.17630421e-03,   7.61986827e-04,   7.11231818e-03,
                          1.33063539e-03,  -2.87023722e-04,   9.47043125e-04,
                          4.23086062e-03,   2.51934951e-04,  -1.23444805e-03,
                         -9.21848975e-03,   6.29113149e-03,  -9.36859567e-03,
                          1.52261528e-05,  -2.65742443e-03,   5.28445198e-05,
                          9.23924614e-03,  -5.96587965e-03,   1.30140292e-03,
                          7.28450483e-03,   5.93404146e-03,   1.86280918e-03,
                         -1.46658963e-03,  -6.62907306e-03,  -2.86593335e-03,
                          5.65076713e-03,  -1.11091109e-02,   6.80219522e-03,
                          1.54183544e-02,   4.25668340e-03,   1.38222417e-02,
                         -1.50763374e-02,  -1.23351449e-02,  -1.38104809e-02,
                         -2.17521214e-03,   3.68569233e-03,   5.79561293e-03,
                         -1.62958298e-02,   4.68420750e-03,  -8.02924857e-04,
                          8.12299643e-03,  -1.60488021e-02,  -1.62756555e-02,
                         -8.67392402e-03,   7.00520165e-03,   6.63746614e-03,
                         -1.02952560e-02,   1.13063855e-02,   1.49371121e-02,
                         -1.43814029e-03,   3.71667813e-03,  -1.85090695e-02,
                         -1.43329380e-02,   4.65448992e-03,   4.00717399e-04,
                          2.27118470e-02,  -1.06240287e-02,  -6.45493902e-03,
                          5.72815211e-03,  -7.43775722e-03,  -1.73633303e-02,
                         -1.94724271e-04,  -2.83528003e-03,   8.01441725e-03,
                         -2.07857438e-03,  -1.50614162e-03,  -9.44430381e-03,
                          3.16627044e-03,  -7.30023661e-04,   6.21833419e-03,
                         -1.40086422e-02,  -4.13952442e-03,   5.00046415e-03,
                         -2.06778497e-02,  -4.62848693e-03,  -9.75122489e-03,
                          1.51595508e-03,  -6.54965034e-03,   8.40508554e-04,
                          2.50541954e-04,   5.99038554e-04,   5.23642404e-04,
                         -1.70370322e-02,   9.77432355e-03,   1.80202108e-02,
                          2.23630462e-02,   4.72320523e-03,  -6.51492225e-03,
                          4.49825730e-03,   3.22492956e-03,   1.02770431e-02,
                          6.84259972e-03,   3.00949020e-03,   5.89884864e-03,
                          4.72764065e-03,   3.23805586e-03,  -6.53974013e-03,
                          7.06289010e-03,   2.45233513e-02,  -5.08344872e-03,
                         -1.01012876e-02,   2.60715596e-02,   6.86199125e-03,
                         -2.05011442e-02,  -3.25925127e-02,   4.70057037e-03,
                          4.94264346e-03,  -2.00880915e-02,  -1.47044435e-02,
                         -1.31708095e-02,  -1.27670355e-02,   1.33996662e-02,
                          7.94132240e-03,  -9.30126786e-01,  -9.48894143e-01,
                         -9.13541794e-01,  -8.86685491e-01,  -9.25090969e-01,
                         -8.96647513e-01,  -9.28505540e-01,  -9.35510337e-01,
                         -9.14780259e-01,  -9.24729109e-01,  -9.07733262e-01,
                         -9.20878887e-01,   1.51330493e-02,   8.82121641e-03,
                         -4.42196033e-04,   3.53624439e-03,  -1.04566314e-03,
                         -3.74600701e-02,  -2.34449767e-02,  -3.58913764e-02,
                         -3.94192431e-03,  -1.26472432e-02,   4.70301695e-03,
                         -1.91720556e-02,   1.80982817e-02,   8.37627612e-03,
                          6.99763326e-03,   5.61364743e-07,   1.23398367e-03,
                          8.46652407e-03,  -1.99851599e-02,  -1.13568529e-02,
                         -2.97593325e-03,  -7.88100623e-03,   4.83412668e-03,
                          3.66819301e-03,  -1.37939034e-02,  -2.81703025e-02,
                          4.76107327e-03,  -3.34090255e-02,  -2.71915309e-02,
                          7.69264437e-03,  -1.18079884e-02,   1.26961581e-02,
                          1.55012282e-02,  -2.75531411e-02,  -1.21534150e-02,
                         -1.29061220e-02,  -6.89114025e-03,   2.17071432e-03,
                         -2.49379016e-02,  -1.66526642e-02,   7.00926967e-03,
                          2.93676945e-04,  -2.12816503e-02,   9.50339250e-03,
                         -4.14610840e-03,  -4.16718377e-03,  -2.15880517e-02,
                          4.56187874e-03,  -7.33874226e-03,  -1.17969625e-02,
                         -6.89813343e-04,  -1.40330242e-02,  -3.49738565e-03,
                          7.99258647e-04,   2.69191718e-04,  -9.11403354e-03,
                         -2.94410791e-02,   1.22998208e-02,   6.00826635e-04,
                         -4.42170398e-03,  -6.00990187e-03,   7.56486133e-03,
                          9.03021079e-03,   1.27921309e-02,  -9.25158083e-01,
                         -9.38341856e-01,  -9.38863337e-01,  -9.40201163e-01,
                         -9.31782782e-01,  -9.38992083e-01,  -9.15567219e-01,
                         -9.26884174e-01,  -9.41181779e-01,  -9.40374255e-01,
                         -9.61942017e-01,  -9.63345826e-01,  -9.58042085e-01,
                         -9.52457726e-01,  -9.29718018e-01,  -9.42867815e-01,
                         -9.42390203e-01,  -9.46774781e-01,  -9.31508183e-01,
                         -9.52506304e-01,  -9.45384026e-01,  -9.65267837e-01,
                         -9.35225666e-01,  -9.40271914e-01,  -9.57791626e-01,
                         -9.33291256e-01,  -9.49050426e-01,  -9.22854781e-01,
                         -9.25439298e-01,  -9.37744617e-01,  -9.39558506e-01,
                         -9.34094429e-01,  -9.35344458e-01,  -9.15088117e-01,
                         -9.42008853e-01,  -9.35470641e-01,  -9.35858071e-01,
                         -9.43741500e-01,  -9.34822619e-01,  -9.26750541e-01,
                         -9.59428430e-01,  -9.28048909e-01,  -9.06564832e-01,
                         -9.23307478e-01,  -9.26865578e-01,  -9.03080821e-01,
                         -9.31708932e-01,  -9.39850688e-01,  -9.24903929e-01,
                         -9.14357364e-01,  -9.29743528e-01,  -9.23347712e-01,
                         -8.98988485e-01,  -9.37352717e-01,  -9.30820465e-01,
                         -9.20474827e-01,  -9.42452431e-01,  -9.31124866e-01,
                         -9.26167488e-01,  -9.26476359e-01,  -9.19124663e-01,
                         -9.23731983e-01,  -9.34544384e-01,  -9.25872505e-01,
                         -9.27532494e-01,  -9.38792586e-01,  -9.45051134e-01,
                         -9.43673491e-01,  -9.51895118e-01,  -9.47628379e-01,
                         -9.40699399e-01,  -9.48627234e-01,  -9.29673493e-01,
                         -9.29221034e-01,  -9.35933292e-01,  -9.34717834e-01,
                         -9.60516214e-01,  -9.52453315e-01,  -9.43360925e-01,
                         -9.34553623e-01,  -9.05935705e-01,  -9.10726368e-01,
                         -9.33658957e-01,  -9.45520759e-01,  -9.41827357e-01,
                         -9.53727067e-01,  -9.33397174e-01,  -9.28857386e-01,
                         -9.32333767e-01,  -9.52241600e-01,  -9.27783132e-01,
                         -9.40907657e-01,  -9.32634473e-01,  -9.23518121e-01,
                         -9.14533496e-01,  -9.28990126e-01,  -9.32110786e-01,
                         -9.24945354e-01,  -9.43625152e-01,  -9.52564299e-01,
                         -9.34543610e-01,  -9.34582114e-01,  -9.31443691e-01,
                         -9.10431087e-01,  -9.11755264e-01,  -9.22594368e-01,
                         -9.46229339e-01,  -9.35964525e-01,  -9.39515471e-01,
                         -9.41041350e-01,  -9.51502860e-01,  -9.22617316e-01,
                         -9.49253798e-01,  -9.17384505e-01,  -9.43724513e-01,
                         -9.18284178e-01,  -9.33836937e-01,  -9.34312761e-01,
                         -9.40547585e-01,  -9.44134474e-01,  -9.21858132e-01,
                         -9.39122677e-01,  -9.36247170e-01,  -9.36851203e-01,
                         -9.42081392e-01,  -9.30659473e-01,  -9.35402453e-01,
                         -9.21867013e-01,  -9.40488696e-01,  -9.34564352e-01,
                         -9.25749600e-01,  -9.34029996e-01,  -9.30166721e-01,
                         -9.38322902e-01,  -9.36846852e-01,  -9.44257677e-01,
                         -9.27277029e-01,  -9.28307891e-01,  -9.19565797e-01,
                         -9.16855037e-01,  -9.20044303e-01,  -9.13998008e-01,
                         -9.30400252e-01,  -9.30346787e-01,  -9.17858362e-01,
                         -9.41100240e-01,  -9.52235878e-01,  -9.43512738e-01,
                         -9.36301649e-01,  -9.21640098e-01,  -9.32199061e-01,
                         -9.47569847e-01,  -9.25653636e-01,  -9.51399088e-01,
                         -9.41153049e-01,  -9.31914151e-01,  -9.29815948e-01,
                         -9.41636622e-01,  -9.45833266e-01,  -9.35253739e-01,
                         -9.24767137e-01,  -9.22985375e-01,  -9.29989934e-01,
                         -9.25600827e-01,  -9.22874451e-01,  -9.27905142e-01,
                         -9.34792221e-01,  -9.15157735e-01,  -9.31949317e-01,
                         -9.27115381e-01,  -9.23819661e-01,  -9.23984528e-01,
                         -9.19163704e-01,  -9.22503173e-01,  -9.21682417e-01,
                         -9.30695415e-01,  -9.04579222e-01,  -9.32978451e-01,
                         -9.04626846e-01,  -9.40097928e-01,  -9.33861434e-01,
                         -9.22454774e-01,  -9.21428859e-01,  -9.20915544e-01,
                         -9.25787032e-01,  -9.31822121e-01,  -9.38412249e-01,
                         -9.27252948e-01,  -9.16962862e-01,  -9.23545659e-01,
                         -9.25251663e-01,  -9.21056330e-01,  -9.32051003e-01,
                         -9.18058813e-01,  -9.31886196e-01,  -9.32176769e-01,
                         -9.25977528e-01,  -9.21103537e-01,  -9.16005492e-01,
                         -9.15445864e-01,  -9.22944605e-01,  -9.20387089e-01,
                         -9.20493364e-01,  -9.10491586e-01,  -9.32639360e-01,
                         -9.47245836e-01,  -9.08751845e-01,  -9.12327170e-01,
                         -9.20249760e-01,  -9.10411596e-01,  -9.20728505e-01,
                         -9.18579221e-01,  -9.08679187e-01,  -9.18048143e-01,
                         -9.24562395e-01,  -9.22225058e-01,  -9.11645353e-01,
                         -9.24723268e-01,  -9.21652257e-01,  -9.20071602e-01,
                         -9.13483620e-01,  -9.20600772e-01,  -9.34869945e-01,
                         -9.32366788e-01,  -9.42478895e-01,  -9.26683187e-01,
                         -9.10101533e-01,  -9.20984507e-01,  -9.48094249e-01,
                         -9.14119661e-01,  -9.17481840e-01,  -9.04727221e-01,
                         -9.34241354e-01,  -9.28579509e-01,  -9.26758051e-01,
                         -9.40430820e-01,  -9.41289902e-01,  -9.37918246e-01,
                         -9.11364317e-01,  -9.22244191e-01,  -9.50868964e-01,
                         -9.15117979e-01,  -9.21093881e-01,  -9.08555329e-01,
                         -9.22428131e-01,  -9.32597756e-01,  -9.20944214e-01,
                         -9.13484514e-01,  -9.24019873e-01,  -9.27779496e-01,
                         -9.32795405e-01,  -9.35358763e-01,  -9.21220899e-01,
                         -9.25941467e-01,  -9.19400334e-01,  -9.08733249e-01,
                         -9.25280392e-01,  -9.32121217e-01,  -9.23639536e-01,
                         -9.24105465e-01,  -9.30527091e-01,  -9.25463796e-01,
                         -9.21815574e-01,  -9.20882106e-01,  -9.31492329e-01,
                         -9.09557879e-01,  -9.23107445e-01,  -9.25239086e-01,
                         -9.21720922e-01,  -9.23750579e-01,  -9.23970580e-01,
                         -9.15702462e-01,  -9.17403460e-01,  -9.16511178e-01,
                         -9.07341540e-01,  -9.13316131e-01,  -9.07114208e-01,
                         -9.04589415e-01,  -9.10134375e-01,  -9.12347376e-01,
                         -9.01210010e-01,  -9.10280108e-01,  -9.18275833e-01,
                         -9.19280708e-01,  -9.25126731e-01,  -9.07833993e-01,
                         -9.12839890e-01,  -9.24672782e-01,  -9.38362777e-01,
                         -9.22464430e-01,  -9.24175918e-01,  -9.11908865e-01,
                         -9.32131946e-01,  -9.08191562e-01,  -9.40271497e-01,
                         -9.38932776e-01,  -9.10536230e-01,  -9.17928517e-01,
                         -9.30528522e-01,  -9.37291741e-01,  -9.14853156e-01,
                         -9.46731448e-01,  -9.25571024e-01,  -8.92466724e-01,
                         -9.68794703e-01,  -9.34203565e-01,  -8.99081111e-01,
                         -9.42199230e-01,  -9.59253311e-01,  -9.47039664e-01,
                         -9.37358141e-01,  -9.32742953e-01,  -9.24697757e-01,
                         -9.38520789e-01,  -9.25404906e-01,  -9.36046064e-01,
                         -9.39605474e-01,  -9.49212730e-01,  -9.49581087e-01,
                         -9.40286338e-01,  -9.21861887e-01,  -9.11897063e-01,
                         -9.12688196e-01,  -9.28168952e-01,  -9.38774943e-01,
                         -9.29519892e-01,  -9.37200367e-01,  -9.39320743e-01,
                         -9.45146382e-01,  -9.39320385e-01,  -9.23573554e-01,
                         -9.12267923e-01,  -9.22377169e-01,  -9.13592398e-01,
                         -9.29305196e-01,  -9.39347148e-01,  -9.25563574e-01,
                         -9.18564737e-01,  -9.22250628e-01,  -9.19216931e-01,
                         -9.24943328e-01,  -9.38958049e-01,  -9.50031400e-01,
                         -9.53503728e-01,  -9.44296777e-01,  -9.38419819e-01,
                         -9.43721175e-01,  -9.25054431e-01,  -9.21677232e-01,
                         -9.23025727e-01,  -9.29484963e-01,  -9.49767172e-01,
                         -9.45824265e-01,  -9.43246722e-01,  -9.42306161e-01,
                         -9.32464361e-01,  -9.46581304e-01,  -9.58197653e-01,
                         -9.22419071e-01,  -9.58215117e-01,  -9.45776045e-01,
                         -9.40324366e-01,  -9.54090118e-01,  -9.00988698e-01,
                         -2.87415776e-02,   2.62073278e-02,  -4.50285897e-03,
                          8.83243699e-03,   3.28932726e-03,  -8.01391806e-03,
                         -5.59538603e-03,  -1.20982490e-02,   8.78709106e-05,
                          1.53202680e-03,  -4.52746218e-03,  -1.27156880e-02,
                          1.01635158e-02,   6.91818306e-03,   1.21151311e-02,
                          2.90669827e-03,  -1.27136707e-02,  -3.63589707e-03,
                         -2.24595666e-02,   4.93043195e-03,   9.67167038e-03,
                          1.26898233e-02,   2.83184950e-03,   9.98471770e-03,
                         -1.72130447e-02,   4.04099468e-04,  -1.72420964e-02,
                         -1.32026756e-03,  -2.14058291e-02,  -5.76382969e-04,
                         -1.33139575e-02,   1.76838215e-03,  -5.92832360e-03,
                         -2.13769078e-03,  -6.34424621e-03,   8.71165283e-03,
                          6.71074819e-03,   6.92907767e-03,  -9.84218623e-03,
                          1.10482820e-03,  -9.14247613e-03,   4.02325951e-03,
                         -2.36960384e-03,   3.54836578e-03,   2.05958206e-02,
                          1.55459438e-02,   2.34407838e-02,   2.90624145e-02,
                          1.21185137e-02,   1.72215141e-02,  -5.10384515e-03,
                          2.90167015e-02,   6.89913798e-03,   1.43413860e-02,
                         -2.06595403e-03,  -9.56901629e-03,  -2.18361188e-02,
                         -6.04021549e-03,  -6.52003661e-03,  -7.14483578e-03,
                         -2.55181715e-02,  -8.99514277e-03,  -3.53015326e-02,
                          4.72920015e-03,  -3.35741602e-02,  -1.77980342e-04,
                          1.11195957e-03,  -2.11164281e-02,   1.67636964e-02,
                         -2.16930192e-02,  -1.34193618e-02,   8.11599009e-03,
                          1.12935295e-02,   1.07840244e-02,   7.12967897e-03,
                         -6.32774504e-03,   8.24950449e-03,   1.65201407e-02,
                         -6.00741385e-03,   1.62004319e-03,   3.75258066e-02,
                         -7.26638874e-03,   1.28161237e-02,  -9.89989657e-03,
                         -1.49911279e-02,  -1.34545274e-03,  -1.91806275e-02,
                          4.01726458e-03,  -9.02195647e-03,  -1.43362507e-02,
                         -7.34136906e-03,   7.35921494e-04,  -4.48845793e-03,
                          1.08446730e-02,  -1.24350609e-03,   1.90227106e-03,
                         -7.77962152e-03,   6.34293677e-03,  -4.78331978e-03,
                          1.79533605e-02,  -7.63524696e-03,   1.09030409e-02,
                          4.14892193e-03,  -4.59427852e-03,   1.03318002e-02,
                         -1.47103900e-02,   7.80313648e-03,   6.96206652e-03,
                         -1.74702257e-02,  -2.05077212e-02,   3.13008670e-03,
                         -1.73186157e-02,   2.14046985e-02,  -1.85431037e-02,
                          2.20988728e-02,  -9.07656830e-03,   5.44663798e-03,
                         -1.72997378e-02,   2.18482260e-02,  -2.37486120e-02,
                         -8.75139236e-03,   1.27834259e-02,   1.53137534e-03,
                          2.37228582e-03,   7.38071278e-03,   1.84355993e-02,
                         -4.02522786e-03,   2.88741086e-02,   5.30801574e-03,
                          1.01133119e-02,   2.71720290e-02,   1.67189464e-02,
                          3.39754149e-02,   2.32950505e-02,   1.60770013e-03,
                          3.95852886e-02,   3.04751768e-04,   3.14744050e-03,
                          8.31304956e-03,   2.39749458e-02,   2.16863174e-02,
                          1.91403683e-02,  -6.21982431e-03,   2.86688432e-02,
                         -2.62134820e-02,   1.92213021e-02,  -1.89734697e-02,
                          8.72690044e-03,   1.27196657e-02,   1.14472322e-02,
                          1.10310595e-02,   2.16769963e-03,   5.07576298e-03,
                          1.11026997e-02,   8.49697646e-03,   1.18173864e-02,
                         -1.40656177e-02,   1.73046850e-02,  -1.70515645e-02,
                          7.01623457e-03,   7.87686929e-03,   2.80913152e-03,
                         -3.00787564e-04,   2.68713513e-04,  -7.67989969e-03,
                         -1.39190042e-02,  -1.75122246e-02,  -2.22204663e-02,
                         -2.06380971e-02,  -2.37820437e-03,  -5.63281728e-03,
                         -1.99380890e-02,  -1.45900920e-02,  -2.33868025e-02,
                         -1.01105049e-02,   5.64819574e-03,  -9.58660617e-03,
                         -1.26743959e-02,   7.89285754e-04,  -3.00138649e-02,
                         -3.10759735e-03,  -1.77288484e-02,  -7.70737184e-03,
                         -8.75792746e-03,  -2.44338866e-02,   1.26537159e-02,
                         -2.48202514e-02,   5.55251399e-03,  -1.09070819e-02,
                          1.40764154e-02,  -6.41924050e-03,   1.34316292e-02,
                         -6.04481017e-03,  -1.79007370e-02,  -1.25445547e-02,
                         -1.75533909e-02,  -1.40385823e-02,   2.17384682e-03,
                         -5.29604964e-02,   6.45852927e-03,  -2.11872850e-02,
                         -1.60537148e-03,   8.22094455e-03,  -3.73058079e-04,
                          8.91167950e-03,  -1.42618390e-02,  -5.18346205e-03,
                         -9.80087370e-03,  -1.57429967e-02,  -1.63998753e-02,
                          9.68936365e-04,   7.82848056e-03,  -3.24961590e-03,
                         -9.86191723e-03,   1.96525478e-03,  -7.33100111e-03,
                         -1.09528497e-04,  -5.11873886e-03,  -9.85651184e-03,
                         -8.87096301e-03,  -7.93898012e-03,   1.62140783e-02,
                         -1.37758907e-03,   1.16427743e-03,   3.43082566e-03,
                         -1.85537292e-03,  -1.93049181e-02,   2.76458077e-02,
                         -5.19342721e-02,   7.05559971e-03,  -1.83095969e-02,
                         -2.70884074e-02,   2.08205413e-02,  -2.31688600e-02,
                          2.30269395e-02,  -2.24396829e-02,   1.52554195e-02,
                         -7.33780675e-03,  -1.19835222e-02,   3.29507253e-04,
                         -1.89282149e-02,  -5.98178478e-03,   1.31821269e-02,
                         -1.11571802e-02,   1.54255135e-02,   4.99935495e-03,
                          1.85862817e-02,  -1.18100261e-02,  -5.83811011e-03,
                         -9.37791017e-04,   6.37120567e-03,   1.78320073e-02,
                          1.30432686e-02,  -1.41778486e-02,  -3.31221148e-03,
                         -1.53705827e-03,   2.05234960e-02,   1.15758469e-02,
                         -1.07720699e-02,  -4.37514530e-03,   1.04336292e-02,
                         -9.34610609e-03,   7.94394873e-03,   4.32804599e-03,
                         -7.53264010e-01,  -7.72679269e-01,  -7.65136063e-01,
                         -7.54713356e-01,  -7.67734051e-01,  -7.57611871e-01,
                         -7.56556749e-01,  -7.56509364e-01,  -7.96933532e-01,
                         -7.57496953e-01,  -7.62539983e-01,  -7.39919126e-01,
                         -7.66548693e-01,  -7.35840201e-01,  -7.56794214e-01,
                         -7.77351737e-01,  -7.59243906e-01,  -7.61366427e-01,
                         -7.80909181e-01,  -7.23932683e-01,  -7.69145489e-01,
                         -7.71199405e-01,  -7.72327840e-01,  -7.74919987e-01,
                         -7.52075732e-01,  -7.57805943e-01,  -7.51958489e-01,
                         -7.57889748e-01,  -7.46102154e-01,  -7.46031582e-01,
                         -7.76482344e-01,  -7.58272409e-01,  -7.70405769e-01,
                         -7.52680600e-01,  -7.43023872e-01,  -7.88996577e-01,
                         -7.49536097e-01,  -7.63204515e-01,  -7.58642912e-01,
                         -7.44562984e-01,  -7.68735468e-01,  -7.74269938e-01,
                         -7.70919323e-01,  -7.42586076e-01,  -7.60102928e-01,
                         -7.50977039e-01,  -7.45054007e-01,  -7.39818215e-01,
                         -7.78322458e-01,  -7.70299673e-01,  -7.65020132e-01,
                         -7.60878921e-01,  -7.82534420e-01,  -7.60481834e-01,
                         -7.71997988e-01,  -7.41030395e-01,  -7.94431806e-01,
                         -7.44273841e-01,  -7.61910260e-01,  -7.59888172e-01,
                         -7.55804598e-01,  -7.71047831e-01,  -7.52934277e-01,
                         -7.79419124e-01,  -7.77972817e-01,  -7.38550901e-01,
                         -7.45728791e-01,  -7.63590872e-01,  -7.68394530e-01,
                         -7.51185060e-01,  -7.63261199e-01,  -7.46570647e-01,
                         -7.64900982e-01,  -7.67144382e-01,  -7.60215819e-01,
                         -7.73925602e-01,  -7.26899981e-01,  -7.55379260e-01,
                         -7.49435544e-01,  -7.47694016e-01,  -9.27000344e-01,
                         -9.23288405e-01,  -9.23486650e-01,  -9.08702314e-01,
                         -7.96151638e-01,  -7.68375695e-01,  -7.48381257e-01,
                         -7.49941230e-01,  -7.92852879e-01,  -7.64287829e-01,
                         -7.66546547e-01,  -7.59801984e-01,  -7.47052193e-01,
                         -7.65977859e-01,  -7.45972157e-01,  -7.71119237e-01,
                         -7.43990302e-01,  -7.45408177e-01,  -7.54919767e-01,
                         -7.36766934e-01,  -9.10421431e-01,  -9.33269441e-01,
                         -9.42346513e-01,  -9.05755281e-01,  -9.38113272e-01,
                         -9.61869836e-01,  -9.39101100e-01,  -9.20750678e-01,
                         -9.19568300e-01,  -8.94910574e-01,  -9.08549011e-01,
                         -8.97344530e-01,  -7.42014110e-01,  -7.50471234e-01,
                         -7.53089845e-01,  -7.54128695e-01,  -7.77339518e-01,
                         -7.19001114e-01,  -7.56626189e-01,  -7.40004241e-01,
                         -7.40518272e-01,  -7.44677246e-01,  -7.48736560e-01,
                         -7.43467331e-01,  -7.50641227e-01,  -7.43390977e-01,
                         -7.17850626e-01,  -7.55017102e-01,  -9.20619428e-01,
                         -9.19117808e-01,  -9.37575579e-01,  -9.23125625e-01,
                         -9.50289130e-01,  -9.41377282e-01,  -9.32043433e-01,
                         -9.30084229e-01,  -7.63554633e-01,  -7.43110418e-01,
                         -7.45468438e-01,  -7.59294450e-01,  -7.54378438e-01,
                         -7.51330674e-01,  -7.59501398e-01,  -7.62066185e-01,
                         -7.56650627e-01,  -7.82606304e-01,  -7.29214966e-01,
                         -7.85512626e-01,  -7.67073274e-01,  -7.54567921e-01,
                         -7.37636507e-01,  -7.14671969e-01,  -8.89016867e-01,
                         -9.37671542e-01,  -9.26741004e-01,  -9.46029603e-01,
                         -9.10383821e-01,  -9.03754532e-01,  -9.36035514e-01,
                         -9.17256176e-01,  -9.25418317e-01,  -9.35976982e-01,
                         -9.03766930e-01,  -9.08670485e-01,  -9.62764680e-01,
                         -9.29644465e-01,  -9.44577098e-01,  -9.22649205e-01,
                         -7.61569202e-01,  -7.58937895e-01,  -7.73435473e-01,
                         -7.69542694e-01,  -7.61683881e-01,  -7.75330484e-01,
                         -7.42597520e-01,  -7.52391398e-01,  -7.50009358e-01,
                         -7.64126241e-01,  -7.41480649e-01,  -7.55176365e-01,
                         -7.70756602e-01,  -7.72418499e-01,  -7.94336259e-01,
                         -7.71693230e-01,  -7.52907813e-01,  -7.36425698e-01,
                         -7.74933636e-01,  -7.38697529e-01,  -8.09004545e-01,
                         -7.56228089e-01,  -7.98466742e-01,  -7.58642435e-01,
                         -7.72322059e-01,  -7.57447362e-01,  -7.45074213e-01,
                         -7.55731106e-01,  -7.53217101e-01,  -7.52736449e-01,
                         -7.60775983e-01,  -7.66832530e-01,  -7.50247717e-01,
                         -7.61465013e-01,  -7.50088871e-01,  -7.55961061e-01,
                         -7.80308127e-01,  -7.31739402e-01,  -7.23187029e-01,
                         -7.61257172e-01,  -7.57981837e-01,  -7.91988850e-01,
                         -7.36921072e-01,  -7.39410579e-01,  -7.22945571e-01,
                         -7.73600042e-01,  -7.99512684e-01,  -7.49284446e-01,
                         -2.10578665e-02,  -1.53139336e-02,   1.06298849e-02,
                         -2.46056709e-02,   1.78609565e-02,  -6.06971141e-03,
                          1.57741979e-02,  -1.14335101e-02,  -7.43548274e-01,
                         -7.42273033e-01,  -7.56321073e-01,  -7.71884143e-01,
                         -7.61476815e-01,  -7.38627732e-01,  -7.61542439e-01,
                         -7.62425244e-01,  -7.62842536e-01,  -7.66366601e-01,
                         -7.67766535e-01,  -7.48177052e-01,  -7.89499223e-01,
                         -7.80776739e-01,  -7.69582868e-01,  -7.54607558e-01,
                         -7.69765973e-01,  -7.62679517e-01,  -7.48063982e-01,
                         -8.04044664e-01,  -7.84041822e-01,  -7.87397385e-01,
                         -7.59850383e-01,  -7.39798486e-01,  -7.51887619e-01,
                         -7.63419032e-01,  -7.56691813e-01,  -7.39859581e-01,
                         -7.90085852e-01,  -7.95581460e-01,  -7.59767890e-01,
                         -7.69395590e-01,  -7.42101490e-01,  -7.56482840e-01,
                         -7.73727596e-01,  -7.80316293e-01,  -7.54114807e-01,
                         -7.23668396e-01,  -7.59018362e-01,  -7.64598727e-01,
                         -7.53254831e-01,  -7.26399362e-01,  -7.40766108e-01,
                         -7.60892630e-01,  -7.44114459e-01,  -7.62433171e-01,
                         -7.51379013e-01,  -7.26456940e-01,  -7.20998347e-01,
                         -7.29846239e-01,  -7.49961495e-01,  -7.70639896e-01,
                         -7.55073249e-01,  -7.90406346e-01,  -7.71612167e-01,
                         -7.59664595e-01,  -2.02538259e-02,   1.24450412e-03,
                         -1.78819485e-02,  -2.10795309e-02,  -7.61230648e-01,
                         -7.70412445e-01,  -8.05384576e-01,  -7.72437811e-01,
                         -7.80203938e-01,  -7.50047326e-01,  -7.64503837e-01,
                         -7.30836391e-01,  -7.56110013e-01,  -7.50717521e-01,
                         -7.51562774e-01,  -7.79715598e-01,  -7.37121820e-01,
                         -7.60839701e-01,  -7.28595316e-01,  -7.93401420e-01,
                         -7.54058242e-01,  -7.59561598e-01,  -7.65266538e-01,
                         -7.35421121e-01,  -7.82926023e-01,  -7.42181718e-01,
                         -7.71850467e-01,  -7.55638897e-01,  -7.89674997e-01,
                         -7.84571052e-01,  -7.96279252e-01,  -7.95211077e-01,
                         -7.71521151e-01,  -7.78197050e-01,  -7.44688809e-01,
                         -7.60534048e-01,  -7.65559912e-01,  -7.53362656e-01,
                         -7.71471322e-01,  -7.72997499e-01,  -7.80176640e-01,
                         -7.85514712e-01,  -7.83103585e-01,  -7.69132435e-01,
                         -4.66665365e-02,  -1.27677768e-02,  -5.61790261e-03,
                         -6.28187926e-03,   2.96039023e-02,  -8.18248745e-03,
                         -4.78410302e-03,  -2.32124329e-03,  -7.68037021e-01,
                         -7.83853650e-01,  -7.27434516e-01,  -7.68622458e-01,
                         -7.51987457e-01,  -7.81058788e-01,  -7.85358369e-01,
                         -7.66144931e-01,  -7.71033168e-01,  -7.27798164e-01,
                         -7.58323371e-01,  -7.22555220e-01,  -7.36719549e-01,
                         -7.43350267e-01,  -7.46554255e-01,  -7.11991906e-01,
                         -7.75939703e-01,  -7.63468027e-01,  -7.38432646e-01,
                         -7.44879663e-01,  -7.45850742e-01,  -7.57418215e-01,
                         -7.73472130e-01,  -7.61319280e-01,  -7.68416405e-01,
                         -7.62312829e-01,  -7.36956835e-01,  -7.80638516e-01,
                         -7.28329897e-01,  -7.61989653e-01,  -7.67739773e-01,
                         -7.76160598e-01,  -7.43683636e-01,  -7.72772670e-01,
                         -7.53908157e-01,  -7.36364961e-01,  -4.17218134e-02,
                         -5.73872775e-03,   1.96769983e-02,  -2.02652197e-02,
                         -7.39667475e-01,  -7.49971330e-01,  -7.60001361e-01,
                         -7.36721516e-01,  -7.43385315e-01,  -7.64173448e-01,
                         -7.22527027e-01,  -7.50656545e-01,  -7.56831110e-01,
                         -7.45463490e-01,  -7.82149374e-01,  -8.02235126e-01,
                         -7.68955767e-01,  -7.43218124e-01,  -7.88954079e-01,
                         -7.68296897e-01,  -7.68386841e-01,  -7.55342603e-01,
                         -7.53238678e-01,  -7.51616001e-01,  -7.54579127e-01,
                         -7.41386056e-01,  -7.58134484e-01,  -7.72729456e-01,
                         -7.73979127e-01,  -7.65539944e-01,  -7.45782316e-01,
                         -7.45150983e-01,  -7.51572967e-01,  -7.87028074e-01,
                         -7.68895984e-01,  -7.54105270e-01,  -7.50493228e-01,
                         -7.47760952e-01,  -7.40461588e-01,  -7.83168852e-01,
                         -7.37673223e-01,  -7.33832002e-01,  -7.68858731e-01,
                         -7.53787756e-01,  -7.64157295e-01,  -7.60114968e-01,
                         -7.47662604e-01,  -7.57967114e-01,  -7.39333689e-01,
                         -7.81802058e-01,  -7.35552013e-01,  -7.68641829e-01,
                         -7.62540042e-01,  -7.49520361e-01,  -7.76759267e-01,
                         -7.55603850e-01,  -9.47393537e-01,  -9.40708280e-01,
                         -9.60017562e-01,  -9.38482463e-01,  -9.48045850e-01,
                         -9.35244322e-01,  -9.05884683e-01,  -9.46554244e-01,
                         -8.91734362e-01,  -9.45913196e-01,  -9.40461218e-01,
                         -9.51302528e-01,  -7.81195104e-01,  -7.68924952e-01,
                         -7.67469764e-01,  -7.68965781e-01,  -7.63552785e-01,
                         -7.53472447e-01,  -7.60499239e-01,  -7.62165844e-01,
                         -7.94646263e-01,  -7.58076191e-01,  -8.01201999e-01,
                         -7.61887074e-01,  -7.90853143e-01,  -7.76909530e-01,
                         -7.42505431e-01,  -7.49945879e-01,  -7.52877593e-01,
                         -7.51106381e-01,  -7.31933296e-01,  -7.42043376e-01,
                         -7.53355682e-01,  -7.55117476e-01,  -7.85733879e-01,
                         -7.63107240e-01,  -9.46362257e-01,  -9.52050686e-01,
                         -9.55830455e-01,  -9.61862028e-01,  -9.11796212e-01,
                         -9.14015174e-01,  -9.28739905e-01,  -9.48364794e-01,
                         -9.23529148e-01,  -9.66070116e-01,  -9.25286353e-01,
                         -9.52503741e-01,  -7.91508138e-01,  -7.69446731e-01,
                         -7.76474833e-01,  -7.90304542e-01,  -9.42057669e-01,
                         -9.36929584e-01,  -9.22965825e-01,  -9.39520895e-01,
                         -9.34802651e-01,  -9.18730915e-01,  -9.16921318e-01,
                         -9.28004563e-01,  -9.31107163e-01,  -9.39964652e-01,
                         -9.38899696e-01,  -9.55592394e-01,  -9.41910148e-01,
                         -9.50905681e-01,  -9.21675324e-01,  -9.47018623e-01,
                         -9.35623527e-01,  -9.48102772e-01,  -9.20307994e-01,
                         -9.35834825e-01,  -9.19184804e-01,  -9.36016738e-01,
                         -9.42491531e-01,  -9.17626917e-01,  -7.75601625e-01,
                         -7.70690739e-01,  -7.81802058e-01,  -7.63734162e-01,
                         -7.73553431e-01,  -7.60764360e-01,  -7.82450080e-01,
                         -7.53122211e-01,  -7.74913609e-01,  -7.61171937e-01,
                         -7.41767704e-01,  -7.67540514e-01,  -7.39207506e-01,
                         -7.64094770e-01,  -7.55579948e-01,  -7.56804228e-01,
                         -7.78637230e-01,  -7.60062218e-01,  -7.64214396e-01,
                         -7.82062531e-01,  -9.22746599e-01,  -9.29268956e-01,
                         -9.46615994e-01,  -9.30376053e-01,  -9.35079217e-01,
                         -9.39457715e-01,  -9.36292291e-01,  -9.42537367e-01,
                         -9.32257891e-01,  -9.32506979e-01,  -9.45783436e-01,
                         -9.12372708e-01,  -9.69295263e-01,  -9.45774257e-01,
                         -9.20226514e-01,  -9.52757359e-01,  -7.91311860e-01,
                         -7.59706736e-01,  -7.70521045e-01,  -7.58358061e-01,
                         -7.83456028e-01,  -7.68035650e-01,  -7.65038371e-01,
                         -7.78514028e-01,  -1.05502550e-02,  -7.91711453e-03,
                          3.28557770e-04,   8.48000345e-04,  -6.69007469e-03,
                         -2.74070948e-02,  -2.06608493e-02,  -3.11656552e-03,
                         -3.80200222e-02,   1.06911985e-02,   2.64375075e-03,
                         -2.23132651e-02,  -7.61764586e-01,  -7.73723125e-01,
                         -7.73531497e-01,  -7.65812516e-01,   5.57866972e-03,
                         -1.20195197e-02,  -1.95377674e-02,  -5.86903363e-04,
                          7.76843587e-03,  -2.19046678e-02,  -2.19487660e-02,
                         -9.14183911e-03,   1.74708962e-01,   1.63472861e-01,
                          1.61416754e-01,   1.45629391e-01,  -3.07248030e-02,
                         -1.29599785e-02,  -1.09528089e-02,  -1.72002651e-02,
                          1.62065372e-01,   1.46675602e-01,   1.68592766e-01,
                          1.80732831e-01,  -8.26676842e-03,   6.28946116e-03,
                         -2.82098185e-02,  -3.08295153e-02,   7.26391422e-03,
                         -1.09115867e-02,  -9.47315525e-03,  -2.14862768e-02,
                         -1.85560789e-02,   1.75818743e-03,  -3.72418612e-02,
                         -2.72704139e-02,   1.46147996e-01,   1.37567490e-01,
                          1.44128338e-01,   1.52836248e-01,   1.40648767e-01,
                          1.62281036e-01,   1.58400014e-01,   1.78991005e-01,
                          1.90206498e-01,   1.56192034e-01,   1.66204557e-01,
                          1.61397070e-01,   1.58922330e-01,   1.92040697e-01,
                          1.45851851e-01,   1.73535421e-01,   1.91886768e-01,
                          1.48901284e-01,   1.81970745e-01,   1.47756636e-01,
                          1.65729985e-01,   1.38294473e-01,   1.94048181e-01,
                          1.48902044e-01,   1.83748156e-01,   1.64681509e-01,
                          1.47927791e-01,   1.43808931e-01,   1.42434195e-01,
                          1.73302114e-01,   1.50248677e-01,   1.78774327e-01,
                          1.55863374e-01,   1.71196595e-01,   1.38649970e-01,
                          1.73585013e-01,   1.79256946e-01,   1.57233581e-01,
                          1.76816821e-01,   1.64288595e-01,   1.48475051e-01,
                          1.72931641e-01,   1.56780168e-01,   1.40584871e-01,
                          1.52545735e-01,   1.45058632e-01,   1.90112591e-01,
                          1.54143527e-01,   1.66305766e-01,   1.54348403e-01,
                          1.51582852e-01,   1.80419698e-01,   1.57690018e-01,
                          1.79521948e-01,   1.70293644e-01,   1.87438041e-01,
                          1.55539349e-01,   1.40430003e-01,   1.71545133e-01,
                          1.60326675e-01,  -7.29772775e-03,   4.92978049e-03,
                          1.97254564e-03,   3.74849583e-03,   3.52495685e-02,
                          1.42018907e-02,   1.84750203e-02,   5.67815593e-03,
                          3.61767411e-02,   6.65570004e-03,   2.02026367e-02,
                          9.78073478e-03,  -2.19516479e-03,   9.35851224e-03,
                          1.36025753e-02,   2.80021899e-03,  -2.50218972e-03,
                         -9.21388716e-03,  -2.90962285e-03,  -2.45917551e-02,
                          1.76831067e-01,   1.72159925e-01,   1.56838194e-01,
                          1.66638672e-01,   1.62623331e-01,   1.76530153e-01,
                          1.84436455e-01,   1.76061869e-01,   1.95609614e-01,
                          1.95589200e-01,   1.72112584e-01,   1.70967445e-01,
                          1.37632918e-02,  -1.18834404e-02,  -2.70669977e-03,
                          2.48675514e-02,   1.24690617e-02,   5.37239946e-03,
                          6.06477680e-03,  -3.38615626e-02,   3.13762692e-03,
                         -2.50394121e-02,   3.83377895e-02,  -1.11857681e-02,
                          5.07570757e-03,   4.15599113e-03,   1.81029327e-02,
                         -4.49493062e-03,   3.82802859e-02,  -9.96980350e-03,
                          1.32550485e-02,  -1.02801831e-03,   1.91790964e-02,
                         -5.75279677e-03,   1.56094264e-02,  -1.63097810e-02,
                         -5.48871979e-03,  -1.10311983e-02,   1.08197855e-04,
                          9.28104389e-03,  -2.42585465e-02,   1.98567249e-02,
                          2.04976108e-02,   1.27953812e-02,   3.86090740e-03,
                         -1.77649071e-03,  -7.41999457e-03,  -1.51283918e-02,
                         -1.27616301e-02,   2.55724508e-03,   4.04062727e-03,
                         -4.03984403e-03,   1.03026787e-02,  -9.28084273e-03,
                          2.24755127e-02,  -1.88140292e-02,   1.19417394e-02,
                          6.75124954e-03,   4.61556856e-03,   9.19897296e-03,
                         -1.04605127e-02,   1.21647744e-02,   2.14236751e-02,
                         -9.98261757e-03,  -5.76639408e-03,   2.07664771e-03,
                          7.30491476e-03,   1.25588803e-02,   1.80459637e-02,
                         -1.46905761e-02,  -1.32606067e-02,  -1.84037685e-02,
                         -2.81392061e-03,   1.69288274e-02,  -2.11932529e-02,
                          1.56884752e-02,  -7.25372648e-03,   2.42434591e-02,
                         -1.00895893e-02,   9.84818116e-03,   2.51951581e-03,
                         -2.65731364e-02,  -1.83223709e-02,   1.73695269e-03,
                         -3.40191205e-03,   1.48357479e-02,   2.69783591e-03,
                          1.07094529e-03,  -2.28511635e-02,  -2.08015926e-02,
                          1.25334803e-02,  -2.25354824e-02,  -1.60469990e-02,
                         -9.74088442e-03,   2.35974938e-02,  -1.78151522e-02,
                          2.18229927e-02,  -2.34887078e-02,  -1.71656888e-02,
                         -3.20440382e-02,  -1.55672682e-02,   3.79673857e-03,
                         -1.25157107e-02,  -1.12853723e-03,   3.78800626e-03,
                         -1.25757139e-02,  -8.17132276e-03,  -1.29671516e-02,
                         -1.14816213e-02,   1.79755930e-02,   1.47057464e-03,
                         -8.53108801e-03,  -9.28818464e-01,  -9.26485896e-01,
                         -9.26569104e-01,  -9.30721462e-01,  -9.16137636e-01,
                         -9.20762181e-01,  -8.85387063e-01,  -9.06675696e-01,
                         -9.34728801e-01,  -9.22479391e-01,  -9.15085673e-01,
                         -9.25132155e-01,  -1.05271209e-02,  -3.37114707e-02,
                          6.92010950e-03,  -2.59141494e-02,  -1.01189669e-02,
                         -3.41507085e-02,  -2.08046902e-02,   4.73613758e-03,
                         -2.17550397e-02,  -8.81393254e-03,   1.38967158e-02,
                         -1.73785221e-02,  -9.26331580e-01,  -9.33797121e-01,
                         -9.40066457e-01,  -9.21739161e-01,  -9.18165326e-01,
                         -9.28404987e-01,  -8.92986476e-01,  -9.61418152e-01,
                         -9.21945035e-01,  -9.42097902e-01,  -9.19276297e-01,
                         -9.61328804e-01,  -9.19056773e-01,  -9.17541027e-01,
                         -9.08147931e-01,  -9.32900071e-01,  -9.67409194e-01,
                         -9.80654597e-01,  -9.59604740e-01,  -9.09851253e-01,
                         -9.48076487e-01,  -9.44126666e-01,  -9.19896364e-01,
                         -9.26443994e-01,  -9.24444914e-01,  -9.43834305e-01,
                         -9.41800416e-01,  -9.24720824e-01,  -9.02718246e-01,
                         -9.05695498e-01,  -9.33293045e-01,  -9.51504230e-01,
                         -9.24144268e-01,  -9.34866846e-01,  -9.27855134e-01,
                         -9.34004068e-01,  -9.47950840e-01,  -9.41567540e-01,
                         -9.19655979e-01,  -9.25935209e-01,  -9.35501337e-01,
                         -9.56471860e-01,  -9.43985283e-01,  -9.55382586e-01,
                         -9.47989106e-01,  -9.52184975e-01,  -9.58464682e-01,
                         -9.35093939e-01,  -9.59135652e-01,  -9.23409581e-01,
                         -9.45580184e-01,  -9.43775833e-01,  -9.36631083e-01,
                         -9.37839210e-01,  -9.36384380e-01,  -9.35630977e-01,
                         -9.38661277e-01,  -9.16045010e-01,  -9.28956568e-01,
                         -9.43075478e-01,  -9.57824111e-01,  -9.44269717e-01,
                         -9.48137701e-01,  -9.44369674e-01,  -9.49366987e-01,
                         -9.37930763e-01,  -9.65342581e-01,  -9.54735935e-01,
                         -9.56725538e-01,  -9.54573452e-01,  -9.68381524e-01,
                         -9.47853267e-01,  -9.52236712e-01,  -9.50493157e-01,
                         -9.40305769e-01,  -9.49494302e-01,  -9.18311536e-01,
                         -9.44975436e-01,  -9.27157938e-01,  -9.46885347e-01,
                         -9.13563728e-01,  -9.12042320e-01,  -9.09497738e-01,
                         -9.39260066e-01,  -9.43351388e-01,  -9.28529799e-01,
                         -9.24461246e-01,  -9.16092277e-01,  -9.42918003e-01,
                         -9.37561333e-01,  -9.56143260e-01,  -9.17818725e-01,
                         -9.55050051e-01,  -9.30141747e-01,  -9.55577850e-01,
                         -9.40263867e-01,  -9.43115950e-01,  -9.83484089e-01,
                         -9.44413543e-01,  -9.38993871e-01,  -9.48249578e-01,
                         -9.46250260e-01,  -9.35741186e-01,  -9.24194992e-01,
                         -9.20527756e-01,  -9.16554213e-01,  -9.51008558e-01,
                         -9.06186223e-01,  -9.62049901e-01,  -9.04614031e-01,
                         -9.33491766e-01,  -9.35726106e-01,  -8.98974597e-01,
                         -9.57822084e-01,  -9.37255561e-01,  -9.31858718e-01,
                         -9.18636143e-01,  -9.15932238e-01,  -8.85185540e-01,
                         -9.27189410e-01,  -9.11830902e-01,  -9.10274684e-01,
                         -9.11392808e-01,  -9.17720735e-01,  -9.20164049e-01,
                         -9.05776560e-01,  -9.16313589e-01,  -9.51391339e-01,
                         -9.51261699e-01,  -9.20817196e-01,  -9.60438371e-01,
                         -9.39839244e-01,  -9.27536309e-01,  -9.82027173e-01,
                         -9.26524937e-01,  -9.25292432e-01,  -9.44987059e-01,
                         -9.21320617e-01,  -9.32567716e-01,  -9.18554962e-01,
                         -9.22766864e-01,  -9.33355451e-01,  -9.21099246e-01,
                         -9.31653380e-01,  -9.05648291e-01,  -9.23549652e-01,
                         -9.57422912e-01,  -9.42220092e-01,  -9.33465779e-01,
                         -9.19796824e-01,  -9.34760392e-01,  -9.45389390e-01,
                         -9.32449520e-01,  -9.45556045e-01,  -9.37062442e-01,
                         -9.42925990e-01,  -9.42253947e-01,  -9.30448472e-01,
                         -9.48576152e-01,  -9.36407089e-01,  -9.26111102e-01,
                         -9.28951979e-01,  -9.36013877e-01,  -9.26504076e-01,
                         -9.46328878e-01,  -9.00530279e-01,  -9.26774561e-01,
                         -9.26278889e-01,  -9.33676362e-01,  -9.43686008e-01,
                         -9.11887646e-01,  -9.45244312e-01,  -9.25622821e-01,
                         -9.27223206e-01,  -9.47721541e-01,  -9.21124578e-01,
                         -9.26752448e-01,  -9.47318375e-01,  -9.63393867e-01,
                         -9.25014973e-01,  -9.37078297e-01,  -8.97395670e-01,
                         -9.50413644e-01,  -9.28069711e-01,  -9.42248702e-01,
                         -9.33763564e-01,  -9.41346645e-01,  -9.47506428e-01,
                         -9.33165312e-01,  -9.18437243e-01,  -9.61744964e-01,
                         -9.03458416e-01,  -9.48426902e-01,  -9.72054899e-01,
                         -9.54490483e-01,  -9.52660978e-01,  -9.43962276e-01,
                         -9.15801406e-01,  -9.09306705e-01,  -9.18670535e-01,
                         -9.38076615e-01,  -9.20447111e-01,  -9.31044281e-01,
                         -9.18404162e-01,  -9.35700297e-01,  -9.39747572e-01,
                         -9.31399643e-01,  -9.30078685e-01,  -9.30025876e-01,
                         -9.18030441e-01,  -9.04261053e-01,  -9.32295978e-01,
                         -9.21612561e-01,  -9.28454816e-01,  -9.62828219e-01,
                         -9.41502452e-01,  -9.46089268e-01,  -9.45507884e-01,
                         -9.47679758e-01,  -9.64271069e-01,  -9.41247821e-01,
                         -9.40711379e-01,  -9.26255345e-01,  -9.14954484e-01,
                         -9.52854276e-01,  -9.32612896e-01,  -9.14522827e-01,
                         -9.37000990e-01,  -9.00728524e-01,  -9.61752057e-01,
                         -9.13392663e-01,  -9.24894392e-01,  -9.35687184e-01,
                         -9.64292586e-01,  -9.23161626e-01,  -9.26032782e-01,
                         -9.40099299e-01,  -9.27662492e-01,  -9.40972388e-01,
                         -9.38990831e-01,  -9.45221364e-01,  -9.29235756e-01,
                         -9.32225227e-01,  -9.43013072e-01,  -9.12857115e-01,
                         -9.45132971e-01,  -9.45508122e-01,  -9.53774512e-01,
                         -9.26510692e-01,  -9.19758737e-01,  -9.58037555e-01,
                         -9.33359683e-01,  -1.26490099e-02,  -1.21395132e-02,
                         -3.06669679e-02,   4.49244282e-04,   9.34214913e-04,
                         -2.78232340e-02,  -1.32318800e-02,  -3.98493707e-02,
                         -3.43466513e-02,  -1.52674858e-02,   4.66029771e-04,
                         -1.75497383e-02,  -7.60314520e-03,  -2.62011178e-02,
                         -3.67339770e-03,  -9.70507506e-03,  -6.75328029e-03,
                         -1.13306697e-02,  -1.68967042e-02,  -9.54214763e-03,
                         -1.90573484e-02,  -2.28883382e-02,  -9.96045396e-03,
                         -1.39202932e-02,  -2.72027794e-02,   1.96564849e-02,
                         -3.47526371e-03,   6.77065505e-03,  -3.16595862e-04,
                         -6.10640086e-03,  -2.56298911e-02,  -1.91033594e-02,
                         -2.95016589e-03,  -1.67249553e-02,   1.16351503e-03,
                          8.81818775e-03,  -5.31315804e-03,  -1.10723441e-02,
                         -7.00256787e-03,   1.67878829e-02,  -2.29745246e-02,
                         -1.47779202e-02,  -8.06568842e-03,   2.40358431e-02,
                         -1.09036649e-02,  -7.17478199e-03,  -6.90144580e-03,
                         -6.33679610e-03,  -9.13706839e-01,  -9.10249174e-01,
                         -9.48207796e-01,  -9.33948278e-01,  -9.47825193e-01,
                         -9.37217891e-01,  -9.21879232e-01,  -9.33443606e-01,
                         -9.30841684e-01,  -9.41091955e-01,  -9.21853542e-01,
                         -9.41877127e-01,  -9.21556354e-01,  -9.60553348e-01,
                         -9.20766294e-01,  -9.23983991e-01,  -9.35847104e-01,
                         -9.23325837e-01,  -9.15026009e-01,  -9.33519006e-01,
                         -9.17533934e-01,  -9.36871052e-01,  -9.36783671e-01,
                         -9.20246243e-01,  -9.37593997e-01,  -9.22064900e-01,
                         -9.37971056e-01,  -9.47749615e-01,  -9.29616570e-01,
                         -9.35692966e-01,  -9.32777107e-01,  -9.34536755e-01,
                         -9.42764342e-01,  -9.27139997e-01,  -9.44098532e-01,
                         -9.32434320e-01,  -9.30845082e-01,  -9.50128675e-01,
                         -9.43231702e-01,  -9.40126002e-01,  -9.47734058e-01,
                         -9.28284407e-01,  -9.34879839e-01,  -9.41091299e-01,
                         -9.42393780e-01,  -9.26198423e-01,  -9.44567919e-01,
                         -9.32228625e-01,  -9.29354429e-01,  -9.39181268e-01,
                         -9.19464231e-01,  -9.31661248e-01,  -9.33806360e-01,
                         -9.24901009e-01,  -9.41003025e-01,  -9.35411870e-01,
                         -9.36884701e-01,  -9.37767804e-01,  -9.40321147e-01,
                         -9.27734852e-01,  -9.45118010e-01,  -9.37914491e-01,
                         -9.24686015e-01,  -9.30954456e-01,  -9.29558396e-01,
                         -9.47544754e-01,  -9.28276718e-01,  -9.43021595e-01,
                         -9.28644776e-01,  -9.43131924e-01,  -9.26365137e-01,
                         -9.31800723e-01,  -9.35670137e-01,  -9.29198921e-01,
                         -9.45482492e-01,  -9.48367536e-01,  -9.24048305e-01,
                         -9.49795365e-01,  -9.35011566e-01,  -9.28118050e-01,
                         -9.31685865e-01,  -9.28624690e-01,  -9.41672742e-01,
                         -9.41701949e-01,  -9.39885914e-01,  -9.40033197e-01,
                         -9.27345991e-01,  -9.44257438e-01,  -9.32462931e-01,
                         -9.40783799e-01,  -9.27712440e-01,  -9.34472978e-01,
                         -9.20084238e-01,  -9.43203986e-01,  -9.31450129e-01,
                         -9.49170947e-01,  -9.20448542e-01,  -9.38977122e-01,
                         -9.23904657e-01,  -9.43588912e-01,  -9.20462847e-01,
                         -9.38901901e-01,  -9.35167909e-01,  -9.25705075e-01,
                         -9.28869843e-01,  -9.40991461e-01,  -9.19658482e-01,
                         -9.47725058e-01,  -9.36354637e-01,  -9.27955925e-01,
                         -9.48370218e-01,  -9.33989644e-01,  -9.33890522e-01,
                         -9.37522471e-01,  -9.29736257e-01,  -9.47473466e-01,
                         -9.20459330e-01,  -9.43582654e-01,  -9.13453043e-01,
                         -9.40439045e-01,  -9.23277974e-01,  -9.41661000e-01,
                         -9.24166441e-01,  -9.14846957e-01,  -9.53953683e-01,
                         -9.02681112e-01,  -9.38618720e-01,  -9.23679709e-01,
                         -9.23390925e-01,  -9.46078718e-01,  -9.17807043e-01,
                         -9.59138215e-01,  -9.41948771e-01,  -9.33341384e-01,
                         -9.50825274e-01,  -9.22411442e-01,  -9.38862443e-01,
                         -9.42861915e-01,  -9.29021418e-01,  -9.34435844e-01,
                         -9.31266725e-01,  -9.45228934e-01,  -9.22212899e-01,
                         -9.35193956e-01,  -9.17123795e-01,  -9.56318259e-01,
                         -9.18156087e-01,  -9.42225516e-01,  -9.39047277e-01,
                         -9.42515850e-01,  -9.43444729e-01,  -9.35767829e-01,
                         -9.37814891e-01,  -9.45140779e-01,  -9.30505455e-01,
                         -9.56045926e-01,  -9.43977356e-01,  -9.39580977e-01,
                         -9.30138588e-01,  -9.42193151e-01,  -9.40430641e-01,
                         -9.32425261e-01,  -9.38380957e-01,  -9.29183602e-01,
                         -9.41880882e-01,  -9.35595810e-01,  -9.29463804e-01,
                         -9.43842053e-01,  -9.24638987e-01,  -9.36691403e-01,
                         -9.28180635e-01,  -9.28719461e-01,  -9.32944775e-01,
                         -9.34344053e-01,  -9.47882295e-01,  -9.21481133e-01,
                         -9.39228237e-01,  -9.24403369e-01,  -9.28728521e-01,
                         -9.31161582e-01,  -9.42325771e-01,  -9.36409056e-01,
                         -9.36737299e-01,  -9.23424721e-01,  -9.37757492e-01,
                         -9.37055528e-01,  -9.36604559e-01,  -9.25707996e-01,
                         -9.38874662e-01,  -9.28821266e-01,  -9.33294475e-01,
                         -9.21998084e-01,  -9.51067984e-01,  -9.13151979e-01,
                         -9.33661759e-01,  -9.01614845e-01,  -9.32731986e-01,
                         -9.26534355e-01,  -9.21416581e-01,  -9.40989733e-01,
                         -9.14653182e-01,  -9.32345629e-01,  -9.39422786e-01,
                         -9.21634555e-01,  -9.36165154e-01,  -9.30033267e-01,
                         -9.18872833e-01,  -9.30231333e-01,  -9.19990361e-01,
                         -9.35007334e-01,  -9.29134429e-01,  -9.16307449e-01,
                         -9.32971835e-01,  -9.23671067e-01,  -9.30392027e-01,
                         -9.22327340e-01,  -9.28741097e-01,  -9.21873629e-01,
                         -9.23987567e-01,  -9.29207504e-01,  -9.14697289e-01,
                         -9.31612790e-01,  -9.22328651e-01,  -9.31059539e-01,
                         -9.31896865e-01,  -9.28988338e-01,  -9.26297188e-01,
                         -9.36461866e-01,  -9.32615757e-01,  -9.21109796e-01,
                         -9.30826902e-01,  -9.29192960e-01,  -9.28891540e-01,
                         -9.24372315e-01,  -9.32792723e-01,  -9.33675051e-01,
                         -9.34569359e-01,  -9.33879614e-01,  -9.31991458e-01,
                         -9.41098273e-01,  -9.38020468e-01,  -9.37205255e-01,
                         -9.35941041e-01,  -9.34503138e-01,  -9.33501959e-01,
                         -9.36320603e-01,  -9.40678358e-01,  -9.30318952e-01,
                         -9.41894889e-01,  -9.33087468e-01,  -9.46472287e-01,
                         -9.23655510e-01,  -9.41219330e-01,  -9.39262390e-01,
                         -9.32965934e-01,  -9.41084385e-01,  -9.34061706e-01,
                         -9.35537398e-01,  -9.25959647e-01,  -9.43565845e-01,
                         -9.33325291e-01,  -9.35256183e-01,  -9.40987825e-01,
                         -9.45049584e-01,  -9.37606633e-01,  -9.31077957e-01,
                         -9.42600429e-01,  -9.35129583e-01,  -9.34636652e-01,
                         -9.41420615e-01,  -9.37672853e-01,  -9.41540599e-01,
                         -9.34162617e-01,  -9.37078714e-01,  -9.27941620e-01,
                         -9.37300384e-01,  -9.22708154e-01,  -9.40283775e-01,
                         -9.30017591e-01,  -9.27997351e-01,  -9.51336443e-01,
                         -9.32738841e-01,  -9.35686409e-01,  -9.45375264e-01,
                         -9.11146641e-01,  -9.47326422e-01,  -9.36815679e-01,
                         -9.36499655e-01,  -9.30020690e-01,  -9.28614080e-01,
                         -9.43726420e-01,  -9.37499344e-01,  -9.30461228e-01,
                         -9.36501563e-01,  -9.31843758e-01,  -9.38662291e-01,
                         -9.27194297e-01,  -9.40400243e-01,  -9.34736907e-01,
                         -9.35839534e-01,  -9.42257941e-01,  -9.33892965e-01,
                         -9.31075513e-01,  -9.37916696e-01,  -9.24486816e-01,
                         -9.37525690e-01,  -9.30550456e-01,  -9.32966053e-01,
                         -9.38862324e-01,  -9.28301156e-01,  -9.38376904e-01,
                         -9.33261752e-01,  -9.38264430e-01,  -9.32716548e-01,
                         -9.19515193e-01,  -9.51792538e-01,  -9.21089590e-01,
                         -9.38150108e-01,  -9.30084825e-01,  -9.34335291e-01,
                         -9.42031503e-01,  -9.29350674e-01,  -9.33969140e-01,
                         -9.47559416e-01,  -9.19469655e-01,  -9.40833032e-01,
                         -9.29730415e-01,  -9.33005393e-01,  -9.36722875e-01,
                         -9.42993104e-01,  -9.28947151e-01,  -9.43798244e-01,
                         -9.24470246e-01,  -9.48890388e-01,  -9.36797082e-01,
                         -9.39801872e-01,  -9.36588287e-01,  -9.29540634e-01,
                         -9.37230408e-01,  -9.32726622e-01,  -9.41142380e-01,
                         -9.34038997e-01,  -9.30287480e-01,  -9.42991018e-01,
                         -9.30153072e-01,  -9.53356445e-01,  -9.26939368e-01,
                         -9.48142469e-01,  -9.29647148e-01,  -9.36505556e-01,
                         -9.36476827e-01,  -9.21862245e-01,  -9.41186070e-01,
                         -9.40440238e-01,  -9.26240146e-01,  -9.38117743e-01,
                         -9.42048907e-01,  -9.38404500e-01,  -9.30222273e-01,
                         -9.32959378e-01,  -9.31791663e-01,  -9.31764603e-01,
                         -9.26762462e-01,  -9.19931591e-01,  -9.41447139e-01,
                         -9.33122039e-01,  -9.35035169e-01,  -9.34671938e-01,
                         -9.37862456e-01,  -9.31572735e-01,  -9.23998237e-01,
                         -9.23688471e-01,  -9.38849807e-01,  -9.31462646e-01,
                         -9.41993892e-01,  -9.27444458e-01,  -9.35180128e-01,
                         -9.40140426e-01,  -9.33218777e-01,  -9.32806909e-01,
                         -9.44980085e-01,  -9.21435893e-01,  -9.32055891e-01,
                         -9.39289391e-01,  -9.21919465e-01,  -9.38212752e-01,
                         -9.20325220e-01,  -9.38178301e-01,  -9.25666511e-01,
                         -9.47291851e-01,  -9.25733805e-01,  -9.39495265e-01,
                         -9.29686546e-01,  -9.31517959e-01,  -9.29186702e-01,
                         -9.30309296e-01,  -9.55624580e-01,  -9.13520217e-01,
                         -9.46915030e-01,  -9.21106696e-01,  -9.37301159e-01,
                         -9.34532642e-01,  -9.41690147e-01,  -9.24976289e-01,
                         -9.33804333e-01,  -9.35160697e-01,  -9.27897394e-01,
                         -9.38472927e-01,  -9.26952004e-01,  -9.20117259e-01,
                         -9.18796301e-01,  -9.30984378e-01,  -9.28510368e-01,
                         -9.33493316e-01,  -9.23509836e-01,  -9.36556756e-01,
                         -9.07106459e-01,  -9.35058832e-01,  -9.20332789e-01,
                         -9.38520908e-01,  -9.38546956e-01,  -9.41638589e-01,
                         -9.36733425e-01,  -9.27686870e-01,  -9.33623850e-01,
                         -9.18770730e-01,  -9.24915552e-01,  -9.39305425e-01,
                          2.11078562e-02,  -9.99151636e-03,  -1.08265085e-03,
                          1.44961011e-02,   4.37450083e-03,   7.45433476e-03,
                          1.39484098e-02,  -1.34301670e-02,   1.29502621e-02,
                         -5.75997680e-03,   1.44635979e-02,  -1.20689264e-02,
                         -6.46965951e-03,   1.03684692e-02,  -2.49453849e-04,
                         -6.97208103e-04,   9.15693305e-03,  -1.66164665e-03,
                         -1.79401711e-02,   1.04630627e-02,  -1.25673143e-02,
                          1.72603037e-02,  -8.36545043e-03,  -3.74074769e-03,
                         -1.00956671e-02,  -3.98185011e-03,  -2.34113354e-03,
                          2.65174848e-03,   9.12883040e-03,  -1.03025055e-02,
                         -6.74978737e-03,   1.48607111e-02,   5.31969359e-03,
                         -1.15830335e-03,  -3.91401537e-03,  -2.55286507e-03,
                         -8.85154400e-03,  -1.29414191e-02,  -5.12062386e-03,
                         -1.48453396e-02,  -2.53435262e-02,  -2.15004850e-02,
                         -2.58590933e-03,  -1.42682772e-02,   1.23697065e-03,
                         -2.88856756e-02,  -3.69455619e-03,  -1.24150179e-02,
                         -2.98583321e-02,  -1.32823959e-02,  -2.22454853e-02,
                          2.38806638e-03,   1.08112616e-03,  -2.24478683e-03,
                         -2.89548468e-03,   7.22980965e-03,  -4.53738635e-03,
                         -2.89800041e-03,  -7.77072972e-03,   4.26985137e-03,
                         -1.24934772e-02,  -2.60722190e-02,   2.76027201e-03,
                         -1.13866394e-02,   1.98666286e-03,   6.63892133e-03,
                          1.01609239e-02,  -9.86586791e-03,  -2.07914114e-02,
                         -1.33985709e-02,  -1.18080582e-02,  -6.25051931e-03,
                         -1.74161550e-02,  -6.12530718e-03,  -9.00206622e-03,
                         -9.98259056e-04,   9.17141140e-03,  -1.16876215e-02,
                         -2.14379653e-03,  -7.33621279e-03,   7.29220454e-03,
                          4.34388220e-03,   1.14768529e-02,  -1.05140149e-03,
                          7.23992800e-03,   3.06255642e-05,   6.16544858e-04,
                         -1.12653431e-02,  -4.68861545e-03,  -4.61145910e-03,
                         -2.48980448e-02,  -5.06781368e-03,   8.61075986e-03,
                         -2.16896795e-02,  -1.71034667e-03,  -2.38790712e-03,
                          1.86941389e-03,  -1.05869994e-02,  -7.07026431e-03,
                         -1.38855446e-02,  -8.89319554e-03,  -1.97100709e-03,
                         -5.16684260e-04,  -1.33783408e-02,  -2.25348100e-02,
                         -1.10861915e-03,  -1.14815794e-02,  -1.30384939e-03,
                          4.37065447e-03,  -8.55346583e-03,   5.23835793e-03,
                          1.22094890e-02,   7.55429221e-03,  -6.27665408e-03,
                          1.04246615e-02,   7.27128144e-03,  -3.06575163e-03,
                          2.65521370e-03,   1.59706883e-02,   1.07146790e-02,
                          1.97952450e-03,  -6.29199808e-03,   2.93478020e-03,
                         -4.15679533e-03,   1.82110188e-03,   2.88965623e-03,
                          3.04426037e-04,   6.64944854e-03,   5.15045924e-03,
                          3.55126965e-03,   9.36566386e-03,   1.46464985e-02,
                          7.97976553e-03,   5.25481068e-03,   1.74501271e-03,
                          1.15142148e-02,   5.04234433e-03,  -1.14383956e-03,
                          1.45051386e-02,   1.26271797e-02,   3.01302481e-03,
                          1.27775837e-02,  -5.06424485e-03,  -9.21130273e-03,
                         -8.43093637e-03,  -6.29560163e-05,  -5.74375922e-03,
                         -3.91368940e-03,  -2.76691141e-03,   6.88933162e-03,
                          7.11353088e-04,  -5.32042095e-03,   2.33478541e-03,
                          7.48325558e-03,   3.82032269e-03,   5.55877248e-03,
                          1.37098581e-02,   6.37855905e-04,   6.68202853e-03,
                          5.89474570e-04,   9.58935078e-03,  -2.43554683e-03,
                          1.00216912e-02,  -3.10663413e-03,  -4.20423411e-03,
                          2.83830869e-03,  -4.72924858e-03,   2.28051306e-03,
                         -5.13374992e-03,  -2.47284630e-03,   1.37089500e-02,
                          1.16067706e-02,   7.85598811e-03,   5.68224490e-03,
                         -6.95884402e-04,  -2.48120446e-03,   3.65196192e-03,
                         -1.01225227e-02,   3.99019453e-04,  -9.56307724e-03,
                         -1.29605606e-02,  -2.77039735e-03,  -1.07975462e-02,
                          7.08955852e-03,   4.84959548e-03,  -9.04246327e-03,
                          3.88166402e-04,   4.45280736e-03,  -5.71739627e-04,
                          1.83448941e-02,  -6.86687708e-04,   6.00383757e-03,
                          8.92050192e-03,   1.62363388e-02,   9.49896406e-03,
                          8.68722331e-04,   6.02957699e-03,   1.08501967e-02,
                          4.09299368e-03,   1.22121084e-04,   1.61693839e-03,
                         -1.31094607e-03,  -3.94163979e-03,  -2.35634594e-04,
                         -1.19008077e-02,   3.74828093e-03,   2.74776272e-03,
                          1.35278720e-02,  -6.64174184e-03,  -2.37232749e-03,
                          3.15071171e-04,   7.68743979e-04,  -8.43557937e-04,
                         -1.03173163e-02,   1.08127866e-03,  -9.32419905e-04,
                          7.36898684e-04,  -7.41813704e-03,  -6.04089443e-03,
                         -1.19170116e-03,   1.19562447e-02,   3.77843529e-03,
                         -4.48786857e-04,   1.33314426e-03,   1.64084835e-04,
                          1.04897451e-02,   1.37179252e-02,   6.88126450e-03,
                          3.48038529e-03,   8.09047930e-03,   4.92157508e-03,
                          9.96965077e-03,   1.23451732e-03,  -3.91897745e-03,
                         -7.06063118e-03,  -8.72019120e-03,  -3.07871844e-03,
                          1.62875478e-03,  -4.99112858e-03,   7.76970410e-05,
                          1.98113243e-03,   9.10710357e-03,   6.00436423e-03,
                         -3.83085012e-03,  -6.66520151e-04,   1.85123540e-03,
                          7.25997088e-04,   4.05062776e-04,   3.50816245e-03,
                         -4.80639108e-04,   1.88330945e-03,  -2.54812464e-03,
                          1.07928959e-03,   1.50876830e-03,   1.42576941e-03,
                         -1.87903340e-03,  -4.39972058e-03,  -3.89059051e-03,
                         -6.61180262e-03,  -1.12539083e-02,  -1.21338023e-02,
                         -1.32595329e-02,  -1.61840068e-03,  -1.64152477e-02,
                         -2.01016050e-02,  -9.32345726e-03,  -7.46770343e-03,
                          6.68730936e-04,   1.13198161e-03,  -3.35238012e-03,
                          7.78605987e-04,  -7.18401338e-04,  -9.35181044e-03,
                         -6.45904196e-03,  -1.65632684e-02,   6.04402740e-04,
                         -4.24352242e-03,   2.60178000e-03,  -1.27137816e-02,
                         -1.32948498e-03,  -5.42111322e-03,   1.51325227e-03,
                         -9.98876523e-03,   1.17927901e-02,  -5.25865704e-03,
                         -1.28790103e-02,   1.10022845e-02,   1.56075344e-03,
                          9.44645202e-04,  -5.16558159e-03,  -2.90466752e-03,
                         -6.55926298e-03,   9.38263629e-03,   5.57935564e-03,
                          8.06666631e-03,   8.08344409e-03,  -4.76987474e-03,
                         -2.44821562e-03,   1.20446004e-03,   1.68480119e-03,
                          1.20074051e-02,   8.29920918e-03,   5.50283003e-04,
                         -4.30747634e-03,  -1.47968121e-02,  -6.71973033e-03,
                          3.30227311e-03,  -8.52205046e-03,  -5.63066872e-03,
                          1.14892653e-04,   1.48145540e-03,  -5.45152416e-03,
                          3.81914456e-03,   3.69287212e-03,   9.64950677e-03,
                          1.09927694e-03,   8.02037772e-04,  -1.08049829e-02,
                          4.45273123e-04,  -3.83557659e-03,  -2.74782511e-03,
                          2.38221022e-03,   3.71358730e-03,   5.78457955e-03,
                          1.53509004e-03,  -1.17663303e-02,   1.17604183e-02,
                          2.61547451e-04,   2.02659611e-03,   9.03645437e-03,
                          1.63661111e-02,   1.33316293e-02,   1.09258145e-02,
                         -3.47949128e-04,   8.93774442e-03,   1.17904618e-02,
                         -4.53968067e-03,   5.78123238e-03,   4.80663357e-03,
                         -5.22403978e-03,  -1.29876236e-04,   1.17503274e-02,
                         -7.65909441e-03,  -1.07114634e-03,   1.19448574e-02,
                         -3.78901116e-03,  -6.98965648e-03,  -1.42528014e-02,
                          9.30654723e-03,   4.31221677e-03,   9.95814614e-03,
                          2.84262630e-03,  -4.06983914e-03,  -4.01078491e-03,
                         -5.79661108e-04,  -8.99616815e-03,  -3.11963563e-03,
                         -2.25732382e-03,  -1.37597295e-02,   1.32034859e-02,
                         -5.50557440e-03,   7.14200130e-03,  -1.24099031e-02,
                         -8.75913352e-03,  -5.62210276e-04,  -6.39388198e-03,
                         -6.66258205e-03,  -1.35734882e-02,  -2.42776461e-02,
                         -5.30229788e-03,  -1.08026331e-02,  -4.34506033e-03,
                          3.06637515e-03,  -4.31818422e-03,   2.68500764e-03,
                         -8.92663561e-03,   4.76680463e-03,   1.06795144e-03,
                          5.68057457e-03,  -2.62909988e-03,  -4.51816851e-03,
                          3.23720346e-03,  -1.14657152e-02,  -6.71805302e-03,
                          3.23775777e-04,  -8.51350557e-03,  -1.22292619e-02,
                         -2.12895847e-03,  -1.85130686e-02,  -1.70746297e-02,
                         -2.27546021e-02,  -1.37566179e-02,  -5.46909962e-03,
                          6.29951060e-03,   1.02759963e-02,  -1.14265168e-02,
                          3.00119468e-03,  -1.99732408e-02,  -2.94730358e-04,
                         -1.11248428e-02,  -5.11184987e-03,  -9.94485337e-03,
                         -7.57053727e-03,  -2.33385665e-03,   5.41808456e-03,
                         -8.46771616e-03,  -1.40378680e-02,  -2.82764696e-02,
                         -1.29115488e-02,   2.07097153e-03,  -4.31836443e-03,
                         -9.52547230e-03,   1.57207774e-03,  -8.01863149e-03,
                         -2.22492404e-03,   1.20826829e-02,  -7.49799656e-03,
                         -7.58777326e-03,   1.09207416e-02,  -2.80059339e-03,
                          5.59216319e-03,  -2.34797387e-03,   8.58202670e-03,
                          1.39362961e-02,   4.41766344e-04,  -1.13250141e-03,
                          1.32350402e-03,   2.83281290e-04,   5.22951456e-03,
                          2.70530954e-02,   2.33931770e-03,   1.68464389e-02,
                          4.84097400e-04,  -5.22889802e-03,  -7.09243491e-03,
                         -2.69618630e-03,  -1.80794317e-02,  -6.31705159e-03,
                         -6.16002874e-03,   2.67558219e-03,  -4.65741474e-03,
                         -9.44527425e-03,  -2.47143954e-03,   5.84794441e-03,
                          4.90812992e-04,  -1.58105195e-02,  -9.67628602e-03,
                         -5.27139520e-03,  -2.23811697e-02,   1.82044841e-02,
                         -1.25469873e-02,  -9.12980083e-03,  -1.20279538e-02,
                         -6.57125283e-03,  -1.58656165e-02,   1.54891622e-03,
                          1.47579052e-02,  -1.01001991e-03,   3.76081816e-03,
                          7.69702438e-03,   1.67570151e-02,   2.13693883e-02,
                          9.89020057e-03,  -1.91294390e-03,  -2.97167781e-03,
                          1.43528497e-03,  -1.04587793e-03,  -1.05184019e-02,
                         -9.38721597e-01,  -9.30190861e-01,  -9.23060417e-01,
                         -9.27613795e-01,  -9.26186025e-01,  -9.59320962e-01,
                         -9.41287637e-01,  -9.38588142e-01,  -9.30123806e-01,
                         -9.36483920e-01,  -9.42497313e-01,  -9.38079238e-01,
                         -7.26652006e-03,  -2.68511847e-03,   5.01517020e-03,
                         -1.53518291e-02,   2.34190281e-03,   1.32583054e-02,
                          1.69073360e-03,  -1.60956441e-03,   2.90947035e-03,
                         -5.12195425e-03,  -5.83035499e-03,   2.19499860e-02,
                          6.38282811e-03,   9.34625231e-03,   4.34478279e-03,
                         -1.93923172e-02,  -1.61610674e-02,  -2.04348974e-02,
                          4.30735853e-03,  -1.96121298e-02,  -1.03918593e-02,
                         -3.26889637e-03,   1.57162722e-03,  -6.19972637e-03,
                         -7.36042066e-03,   3.72945098e-03,  -2.57397513e-03,
                         -4.65758797e-03,  -1.96975954e-02,  -1.11772018e-02,
                         -1.60104409e-02,  -6.53994782e-03,  -4.76008188e-03,
                         -2.66726986e-02,   6.01146091e-03,   4.90049273e-03,
                          1.16245197e-02,  -2.18003581e-04,  -7.70393410e-04,
                         -9.18289460e-03,  -8.73532798e-03,  -2.63890978e-02,
                         -6.15959894e-03,   2.71929242e-03,   1.90547574e-02,
                          4.47751442e-03,  -6.14290358e-03,   2.36885529e-02,
                         -6.48081070e-03,   5.20731672e-04,  -8.88397859e-04,
                          4.55146236e-03,   2.49041226e-02,   9.17227753e-03,
                          8.58348235e-03,  -9.93522070e-03,  -1.69667155e-02,
                         -2.97013926e-03,   6.05027843e-03,  -7.73295900e-03,
                         -1.19880270e-02,   9.85788368e-03,   6.12733071e-04,
                         -2.06629280e-02,  -9.49191570e-01,  -9.21464324e-01,
                         -9.30961072e-01,  -9.29392338e-01,  -9.41845536e-01,
                         -9.29139853e-01,  -9.32639718e-01,  -9.44291711e-01,
                         -9.25645649e-01,  -9.37158883e-01,  -9.36811626e-01,
                         -9.31614876e-01,  -9.37091053e-01,  -9.37910914e-01,
                         -9.28450406e-01,  -9.30928051e-01,  -9.22866821e-01,
                         -9.22908664e-01,  -9.11895394e-01,  -9.14880872e-01,
                         -9.19539273e-01,  -9.13645804e-01,  -9.10095751e-01,
                         -9.24471557e-01,  -9.28762913e-01,  -9.26163614e-01,
                         -9.27748621e-01,  -9.31169450e-01,  -9.40142870e-01,
                         -9.43534911e-01,  -9.29869235e-01,  -9.40058947e-01,
                         -9.20277476e-01,  -9.31809068e-01,  -9.23547387e-01,
                         -9.21990514e-01,  -9.30671334e-01,  -9.36492264e-01,
                         -9.27870870e-01,  -9.28372324e-01,  -9.40144658e-01,
                         -9.40340340e-01,  -9.20916080e-01,  -9.37421679e-01,
                         -9.28352833e-01,  -9.21842992e-01,  -9.28968370e-01,
                         -9.45530534e-01,  -9.42391515e-01,  -9.35080230e-01,
                         -9.50948536e-01,  -9.46108580e-01,  -9.41902399e-01,
                         -9.21940029e-01,  -9.43920135e-01,  -9.23779070e-01,
                         -9.29556072e-01,  -9.30112064e-01,  -9.24794376e-01,
                         -9.15961087e-01,  -9.15613472e-01,  -9.32578504e-01,
                         -9.27872956e-01,  -9.21481848e-01,  -9.16037977e-01,
                         -9.23554182e-01,  -9.27340388e-01,  -9.55219567e-01,
                         -9.41150486e-01,  -9.36604440e-01,  -9.19459343e-01,
                         -9.22773898e-01,  -9.35264945e-01,  -9.28509414e-01,
                         -9.11298215e-01,  -9.38371778e-01,  -9.44535673e-01,
                         -9.48374331e-01,  -9.26911831e-01,  -9.36348319e-01,
                         -9.39959586e-01,  -9.44676697e-01,  -9.50090170e-01,
                         -9.52220678e-01,  -9.40827727e-01,  -9.35038269e-01,
                         -9.36047912e-01,  -9.23254192e-01,  -9.31861281e-01,
                         -9.26618576e-01,  -9.27735567e-01,  -9.39290464e-01,
                         -9.54575002e-01,  -9.40836549e-01,  -9.39534307e-01,
                         -9.49659407e-01,  -9.62404072e-01,  -9.32501853e-01,
                         -9.26127255e-01,  -9.19772923e-01,  -9.26140249e-01,
                         -9.36850190e-01,  -9.35605943e-01,  -9.24229503e-01,
                         -9.45758522e-01,  -9.36266720e-01,  -9.33183074e-01,
                         -9.47618067e-01,  -9.38556075e-01,  -9.44900334e-01,
                         -9.42833662e-01,  -9.32328463e-01,  -9.57657337e-01,
                         -9.47288990e-01,  -9.50245738e-01,  -9.45471764e-01,
                         -9.51465845e-01,  -9.38274860e-01,  -9.40562129e-01,
                         -9.42008436e-01,  -9.39291239e-01,  -9.28179681e-01,
                         -9.31427062e-01,  -9.55171883e-01,  -9.28311169e-01,
                         -9.32336450e-01,  -9.43911672e-01,  -9.43645418e-01,
                         -9.25766408e-01,  -9.42086041e-01,  -9.22750711e-01,
                         -9.13443208e-01,  -9.44075048e-01,  -9.47204709e-01,
                         -9.36203480e-01,  -9.32559729e-01,  -9.32873011e-01,
                         -9.34853792e-01,  -9.53867435e-01,  -9.48932767e-01,
                         -9.53356385e-01,  -9.49216068e-01,  -9.35999334e-01,
                         -9.51589286e-01,  -9.46555436e-01,  -9.44397032e-01,
                         -9.44638312e-01,  -9.37322140e-01,  -9.36978400e-01,
                         -9.53732371e-01,  -9.42180395e-01,  -9.39228058e-01,
                         -9.45676088e-01,  -9.48369443e-01,  -9.62414801e-01,
                         -9.44989622e-01,  -9.48163331e-01,  -9.50119257e-01,
                         -9.36118126e-01,  -9.43471789e-01,  -9.54936504e-01,
                         -9.49578643e-01,  -9.33952272e-01,  -9.40753639e-01,
                         -9.30590868e-01,  -9.33843613e-01,  -9.45751071e-01,
                         -9.46520388e-01,  -9.58869219e-01,  -9.43183482e-01,
                         -9.48907495e-01,  -9.41365361e-01,  -9.44898903e-01,
                         -9.43442762e-01,  -9.35546398e-01,  -9.38318968e-01,
                         -9.44843590e-01,  -9.31320608e-01,  -9.12589014e-01,
                         -9.40363526e-01,  -9.49393809e-01,  -9.48394477e-01,
                         -9.38342631e-01,  -9.32012975e-01,  -9.61381555e-01,
                         -9.20605123e-01,  -9.44258511e-01,  -9.28468943e-01,
                         -9.37531233e-01,  -9.46590483e-01,  -9.44144666e-01,
                         -9.30456460e-01,  -9.47549105e-01,  -9.58399713e-01,
                         -9.38031018e-01,  -9.23751295e-01,  -9.22136724e-01,
                         -9.25861478e-01,  -9.25289989e-01,  -9.30728316e-01,
                         -9.40479636e-01,  -9.26745832e-01,  -9.27049696e-01,
                         -9.16300893e-01,  -9.21812356e-01,  -9.34932709e-01,
                         -9.32561398e-01,  -9.25423265e-01,  -9.11463320e-01,
                         -9.24086928e-01,  -9.18242157e-01,  -9.46929276e-01,
                         -9.28986251e-01,  -9.31815505e-01,  -9.39099610e-01,
                         -9.26454663e-01,  -9.24512327e-01,  -9.08639669e-01,
                         -9.10340965e-01,  -9.38663423e-01,  -9.16769922e-01,
                         -9.05842185e-01,  -9.28235233e-01,  -9.21475828e-01,
                         -9.40963507e-01,  -9.26358521e-01,  -9.30065989e-01,
                         -9.29563880e-01,  -9.25603330e-01,  -9.51057255e-01,
                         -9.37883735e-01,  -9.31871831e-01,  -9.40186858e-01,
                         -9.50516641e-01,  -9.45198417e-01,  -9.48294580e-01,
                         -9.43373978e-01,  -9.36796725e-01,  -9.27817822e-01,
                         -9.19058025e-01,  -9.40544188e-01,  -9.29317474e-01,
                         -9.40069795e-01,  -9.23770666e-01,  -9.53730047e-01,
                         -9.19167638e-01,  -9.36217785e-01,  -9.27796185e-01,
                         -9.16711748e-01,  -9.41351175e-01,  -9.29778874e-01,
                         -9.26165819e-01,  -9.18509960e-01,  -9.40032423e-01,
                         -9.39299881e-01,  -9.33283508e-01,  -9.44753885e-01,
                         -9.29523170e-01,  -9.49703217e-01,  -9.62794363e-01,
                         -9.46469188e-01,  -9.34047639e-01,  -9.25818503e-01,
                         -9.27729070e-01,  -9.50286150e-01,  -9.31746185e-01,
                         -9.29959118e-01,  -9.33591783e-01,  -9.28815722e-01,
                         -9.22697544e-01,  -9.24833894e-01,  -9.16665614e-01,
                         -9.08968508e-01,  -9.26055253e-01,  -9.04165924e-01,
                         -9.21985030e-01,  -9.41749513e-01,  -9.18226540e-01,
                         -9.15515006e-01,  -9.45565999e-01,  -9.27119136e-01,
                         -9.21447873e-01,  -9.24263775e-01,  -9.44560349e-01,
                         -9.51414824e-01,  -9.30066586e-01,  -9.30636764e-01,
                         -9.25812721e-01,  -9.29592371e-01,  -9.18817461e-01,
                         -9.35709298e-01,  -9.25878584e-01,  -9.25423324e-01,
                         -9.38251257e-01,  -9.24989879e-01,  -9.35488522e-01,
                         -9.29066241e-01,  -9.42498624e-01,  -9.39174950e-01,
                         -9.39162314e-01,  -9.46488380e-01,  -9.48457956e-01,
                         -9.38411057e-01,  -9.54967082e-01,  -9.52491581e-01,
                         -9.52244699e-01,  -9.44733679e-01,  -9.58949387e-01,
                         -9.21261847e-01,  -9.61416960e-01,  -9.33550417e-01,
                         -9.41524625e-01,  -9.36958551e-01,  -9.32491243e-01,
                         -9.38395858e-01,  -9.30641532e-01,  -9.37242866e-01,
                         -9.51910853e-01,  -9.43779409e-01,  -9.49008584e-01,
                         -9.41027045e-01,  -9.16509092e-01,  -9.35036182e-01,
                         -9.29939508e-01,  -9.53189373e-01,  -9.58988547e-01,
                         -9.50158298e-01,  -9.33624625e-01,  -9.27878082e-01,
                         -9.27909672e-01,  -9.30044532e-01,  -9.64693010e-01,
                         -9.40446794e-01,  -9.30720270e-01,  -9.41369176e-01,
                         -9.30385172e-01,  -9.38380897e-01,  -9.28671837e-01,
                         -9.68201995e-01,  -9.50603247e-01,  -9.40312088e-01,
                         -9.26714003e-01,  -9.36612129e-01,  -9.40038204e-01,
                         -9.37130094e-01,  -9.25621331e-01,  -9.22100425e-01,
                         -9.29625750e-01,  -9.49854016e-01,  -9.18395460e-01,
                         -9.50970411e-01,  -9.40659165e-01,  -9.48298454e-01,
                         -9.54433501e-01,  -9.65861619e-01,  -9.41885233e-01,
                         -9.46736395e-01,  -9.46858048e-01,  -9.36417162e-01,
                         -9.47733760e-01,  -9.44437265e-01,  -9.46036041e-01,
                         -9.45130885e-01,  -9.19549167e-01,   7.84158614e-03,
                         -1.32205142e-02,  -2.09065340e-02,  -8.43972433e-03,
                         -2.38898192e-02,  -9.97378840e-04,  -4.78693051e-03,
                          4.76970151e-03,  -7.76797812e-03,  -2.43215100e-03,
                          6.50582230e-03,   5.07674040e-03,  -1.04152011e-02,
                         -3.07939760e-03,  -2.17610616e-02,  -1.26268053e-02,
                         -9.16541647e-03,   9.10359714e-03,   6.99869357e-04,
                         -4.99528693e-03,   1.98999653e-03,   5.96254598e-03,
                         -1.02874730e-02,   9.47410427e-03,  -2.43554339e-02,
                         -3.90593428e-03,  -8.61540344e-03,   3.18898144e-03,
                         -2.17622402e-03,  -9.73578356e-03,  -5.90883521e-03,
                          8.69571324e-03,   9.73028783e-03,  -1.00267371e-02,
                         -7.69215962e-03,  -1.61712766e-02,   3.49654001e-04,
                         -3.80680151e-03,  -5.55595150e-03,   1.01320795e-03,
                         -1.52798500e-02,  -4.49737720e-03,  -1.64091289e-02,
                         -7.13945786e-03,  -9.98355355e-03,  -1.20543037e-03,
                         -3.64948763e-03,   3.73681803e-04,  -6.58466993e-03,
                          7.22861756e-03,  -1.64845176e-02,  -3.91957350e-03,
                         -3.23577574e-03,  -7.66085461e-03,  -7.29375659e-03,
                         -1.88617862e-03,  -8.55785981e-03,  -1.64478701e-02,
                         -1.85758099e-02,   5.89979114e-03,   5.41438395e-03,
                         -3.05230785e-02,   1.49910722e-03,   8.72583315e-03,
                          6.20947732e-03,   1.75460577e-02,   1.22961057e-02,
                          6.25582121e-04,  -1.29434082e-03,   9.21982713e-03,
                          6.73463056e-03,   2.33019725e-03,  -7.98046496e-03,
                          6.83957804e-03,   2.79422430e-03,   1.06843170e-02,
                         -6.81733852e-03,   4.63518873e-03,  -3.30689573e-03,
                         -6.92654820e-03,  -6.53202645e-03,  -1.11750811e-02,
                         -2.87461653e-02,  -2.25713123e-02,  -1.30086783e-02,
                         -7.52916979e-03,  -2.96567613e-03,   5.26591344e-03,
                         -1.84162986e-03,   2.95430329e-03,   4.48943488e-03,
                          1.88892037e-02,  -1.24118300e-02,  -2.19698064e-03,
                         -7.41859479e-03,   4.04393999e-03,  -2.59350520e-04,
                          1.68985352e-02,   7.27442792e-03,   3.17209214e-03,
                         -7.08947564e-03,  -2.58026808e-03,  -3.27078835e-03,
                         -1.20085068e-02,  -9.01029259e-03,   2.08810368e-03,
                          8.44826922e-03,   1.11525916e-02,  -1.01261679e-02,
                         -8.01694673e-03,  -9.15021729e-03,  -8.71148019e-04,
                          2.87761120e-03,  -5.20921545e-03,   1.30015677e-02,
                          2.86499783e-03,   7.54946191e-03,   5.26932999e-03,
                          9.76811443e-03,   1.33807594e-02,   2.11504218e-03,
                          9.10620298e-03,   7.35651189e-03,   8.69083405e-03,
                          6.77144481e-03,  -6.74921228e-03,  -6.70642359e-03,
                         -7.31278094e-04,  -4.57691774e-03,  -2.63356310e-06,
                         -7.47588137e-03,  -3.94524354e-03,  -1.17969140e-02,
                          2.10801344e-02,   1.85033027e-02,   1.65662896e-02,
                         -1.83638348e-03,  -5.17591462e-03,   7.05468468e-03,
                         -1.85524812e-03,  -4.66354098e-03,  -1.34818256e-02,
                         -8.92506167e-03,  -6.26928685e-03,  -5.57901617e-03,
                         -8.31166326e-05,   2.57055857e-03,   1.43163810e-02,
                          2.71223043e-03,   7.37370644e-03,  -1.27888797e-02,
                          1.48421098e-02,   3.45069519e-03,   1.28137390e-03,
                          9.02239978e-03,  -1.54500059e-03,  -1.16056269e-02,
                         -1.64374535e-03,   5.69998659e-03,  -4.39341366e-03,
                         -8.62117624e-04,   8.67772906e-04,   5.59808174e-03,
                         -1.35227921e-03,  -1.86399296e-02,   7.75648095e-03,
                         -9.42105893e-03,   7.29326485e-03,  -1.11772222e-02,
                         -4.34530992e-03,   9.66566149e-04,   3.06986831e-03,
                         -7.84293097e-03,  -1.19934129e-02,  -8.74920934e-03,
                          3.27368523e-03,  -1.29982904e-02,   1.29218539e-02,
                         -1.00307288e-02,   5.27927512e-03,  -1.93095620e-04,
                         -1.73187740e-02,  -1.84872877e-02,  -6.18954562e-03,
                          3.97991668e-03,  -1.75547076e-03,  -1.16853963e-03,
                         -2.69789831e-03,  -2.81463447e-03,  -3.98541242e-03,
                         -2.15387344e-03,  -1.04792658e-02,   4.64468356e-03,
                          6.54255366e-03,   5.48814423e-03,  -4.61207563e-03,
                          1.85971824e-03,  -2.76223337e-03,   1.98227586e-03,
                         -2.26017227e-03,  -8.09404161e-03,   4.35874099e-03,
                         -1.73494278e-03,  -1.04899602e-02,   1.14317080e-02,
                          7.50126084e-03,  -1.69675481e-02,   2.55285809e-03,
                         -4.55172546e-03,  -8.24031513e-03,  -3.23636481e-03,
                         -5.66337351e-03,  -3.71885439e-03,  -6.87712710e-03,
                         -5.71686914e-03,   5.43080224e-03,  -1.25748133e-02,
                         -9.97115509e-04,   1.19692599e-02,   4.32593236e-03,
                         -8.24922055e-04,  -8.73809960e-03,  -8.16055946e-03,
                         -4.54914058e-03,  -5.97724551e-03,  -7.74234254e-03,
                         -7.12559698e-03,   4.44392965e-04,   2.01631826e-03,
                          2.17268942e-03,  -4.45461646e-03,  -6.44875038e-03,
                          3.37678212e-04,  -3.07350681e-04,   9.54160001e-03,
                          9.96627565e-03,   9.33116395e-03,  -3.22563644e-03,
                         -6.23353990e-03,  -1.03780469e-02,  -1.35649985e-03,
                         -3.95618007e-03,   6.72678510e-03,  -2.51423498e-03,
                         -3.30495532e-03,  -8.87424778e-03,  -3.68840201e-03,
                         -5.13267587e-05,   1.42741890e-03,  -2.39453249e-04,
                          7.99556670e-04,   3.43024358e-03,   5.13714598e-03,
                          1.48511468e-03,  -4.83549898e-03,  -1.36557454e-02,
                          5.54529252e-03,  -5.45043615e-04,  -5.36622433e-03,
                         -2.21084151e-03,  -1.98271265e-03,  -1.23454502e-03,
                          5.66486327e-04,  -2.85898219e-03,   4.37720353e-03,
                         -5.04728593e-03,   2.00595031e-03,   1.06356163e-02,
                         -5.21936826e-03,  -6.91568805e-03,   3.71559709e-03,
                         -1.58191891e-03,  -2.28496944e-03,   1.59106019e-03,
                         -2.35744775e-03,   2.97994586e-04,   7.90817372e-04,
                          4.49098734e-04,   3.70247080e-03,  -1.14365935e-03,
                         -7.04442058e-03,   2.90911703e-04,   2.47727497e-03,
                         -3.35473660e-03,  -6.42104249e-04,  -2.65031378e-03,
                         -1.43093267e-03,  -3.09877493e-03,  -1.07817375e-03,
                         -4.17920807e-03,   3.04769073e-03,   1.49772118e-03,
                          7.36462045e-03,  -6.37440756e-03,   1.72788068e-03,
                         -9.44312545e-04,  -7.21339835e-04,   4.12980793e-03,
                          2.77785468e-04,  -5.67110081e-04,   6.94789400e-04,
                          8.27943732e-04,   2.18499103e-03,  -1.27501879e-03,
                          4.57480410e-03,   2.43788934e-03,   2.44782050e-03,
                          1.31462619e-03,   6.13807293e-04,   1.74005749e-03,
                         -1.29842979e-03,   6.23860583e-03,   8.77246785e-04,
                          2.41591991e-03,  -1.48430385e-03,  -1.46098994e-03,
                          8.06965283e-04,   3.25184735e-03,  -1.03315373e-03,
                         -2.50157295e-03,   1.47556455e-03,  -9.50092508e-04,
                         -1.25424820e-03,   1.55202101e-03,   3.96531424e-04,
                          4.97008790e-04,  -2.58230558e-03,   3.68899811e-04,
                         -4.62952652e-04,   7.05164217e-04,  -4.17548651e-03,
                          3.56833916e-04,   2.91426620e-03,  -6.75716801e-05,
                          1.22502958e-03,   3.02631059e-04,   1.23550836e-03,
                          2.53348076e-03,   2.03816991e-04,   3.78678633e-05,
                         -1.55510509e-03,  -9.52642935e-04,  -1.22044852e-03,
                         -1.89437042e-03,  -5.55749005e-03,   3.36785591e-03,
                          2.97638355e-03,   3.27663758e-04,  -3.50700505e-03,
                          2.11007311e-03,   2.71277782e-03,   2.67182593e-03,
                         -3.25915217e-03,   7.29217660e-03,  -4.94218618e-03,
                         -5.89662371e-03,   9.39295627e-03,  -8.97788536e-03,
                          1.36250153e-03,   1.10165402e-03,   7.34911021e-03,
                         -4.07585467e-04,   3.02629662e-03,  -1.53267127e-03,
                          4.94128512e-03,  -2.19106907e-03,   4.44637612e-03,
                          1.35543942e-03,   2.12337263e-03,   3.40573769e-03,
                          2.92306789e-03,  -6.79490436e-03,   5.53547917e-03,
                          1.06802757e-03,  -2.26570270e-03,   4.05659480e-03,
                         -5.49675897e-03,   7.72889750e-03,  -3.10549070e-03,
                          1.58990966e-04,  -3.05331149e-03,   3.78716760e-03,
                         -1.78981107e-03,   4.39787004e-03,  -7.82975648e-03,
                          5.34096966e-03,   3.67162353e-03,  -1.20298384e-04,
                          1.04864324e-04,   1.13198161e-03,   7.21707183e-04,
                          4.47689788e-03,   1.02920341e-03,  -1.26637646e-03,
                          6.50915597e-03,  -2.83785816e-03,   5.96229639e-03,
                          1.35819078e-03,  -3.60769033e-03,   8.48206878e-03,
                          2.39016628e-03,   5.39624691e-03,   1.60122709e-03,
                         -1.16844266e-03,   2.11556884e-03,   4.33036080e-03,
                         -2.22059945e-03,   7.19350809e-03,  -6.74505392e-03,
                          5.66213951e-03,   2.11045422e-04,   6.30024530e-04,
                         -4.23317542e-04,  -2.71244510e-03,   1.27187232e-03,
                          1.01191821e-02,  -1.10153975e-02,   7.27911294e-03,
                         -5.25857415e-03,   2.06249562e-04,   6.28929527e-04,
                         -8.61623511e-03,   4.84149391e-03,  -9.73853469e-03,
                         -3.49986658e-05,  -2.93707429e-03,  -4.44267550e-03,
                          3.28096212e-03,  -5.45618124e-03,  -4.25301725e-03,
                         -5.53297752e-04,  -9.16627515e-03,   1.99998310e-03,
                         -9.02298931e-03,  -7.02566700e-03,   5.31598576e-04,
                         -9.45737399e-03,  -6.60546124e-04,  -7.39472639e-03,
                          1.28878257e-03,  -7.65386876e-03,  -6.11783611e-03,
                          4.04816074e-03,  -6.76030759e-03,  -5.11547457e-03,
                          1.80881424e-03,  -6.98791677e-03,   2.70990864e-03,
                         -6.09796681e-03,   2.24411441e-03,   1.11977709e-03,
                         -7.66574079e-03,   4.49912343e-03,  -6.18359912e-03,
                         -4.17419756e-03,   1.85133249e-03,  -4.24267678e-03,
                          2.33523571e-03,   1.58728310e-03,  -1.29339267e-02,
                          9.52676218e-03,  -1.16658807e-02,  -3.24866641e-03,
                          1.09763509e-02,  -5.75193018e-03,   4.36464557e-03,
                         -1.50978006e-03,   1.36489258e-03,   3.42145585e-03,
                         -7.35983835e-04,  -8.40663165e-03,   1.79027952e-02,
                         -9.06491838e-03,  -1.65723881e-03,   1.17591361e-03,
                         -1.15758958e-04,  -1.38982825e-04,  -3.22436821e-03,
                         -5.86480647e-03,  -3.57928243e-03,   8.12875573e-03,
                         -1.13962032e-02,   1.08072348e-02,  -1.38000092e-02,
                          1.10024717e-02,  -7.75858061e-03,  -2.63134541e-04,
                         -7.82854296e-03,   5.71111031e-03,   9.61486134e-04,
                         -2.61409557e-03,  -1.56941649e-03,   6.09561056e-03,
                         -1.02794133e-02,   3.82308802e-03,  -1.70895644e-02,
                          1.04948869e-02,  -2.02552183e-03,   7.66602461e-04,
                         -2.63429759e-03,   2.94889766e-03,  -5.42073231e-03,
                          1.03219245e-02,  -5.82153257e-03,  -3.74494051e-03,
                          7.84381106e-03,  -1.99215882e-03,   1.28068505e-02,
                         -4.89523925e-04,  -3.45090311e-03,  -8.82414822e-03,
                          2.87637068e-03,  -9.10067931e-03,   2.62501789e-03,
                         -7.92692788e-03,  -6.70359586e-04,   4.87384479e-03,
                         -3.03478632e-03,   1.01186894e-02,  -3.07783810e-03,
                         -7.68003799e-03,   4.55350662e-03,  -1.13133434e-02,
                          1.37785105e-02,  -1.49531560e-02,   1.71162393e-02,
                         -1.40335783e-02,   3.76767921e-03,  -9.73448064e-03,
                         -4.45009070e-03,   5.36413118e-03,  -1.53124984e-02,
                          8.19259230e-03,  -1.37362489e-02,   8.92912317e-03,
                         -1.33095356e-02,  -2.48073321e-03,  -5.14153996e-03,
                         -4.15509008e-03,  -1.96605874e-03,  -1.18482197e-02,
                          1.03360415e-02,  -1.26752974e-02,   9.06367786e-03,
                         -1.65819936e-02,   8.17275699e-03,  -6.39239233e-03,
                         -9.13974404e-01,  -9.40521181e-01,  -9.24592257e-01,
                         -9.38716054e-01,  -9.38083112e-01,  -9.34599102e-01,
                         -9.34259117e-01,  -9.45905447e-01,  -9.26284552e-01,
                         -9.37475562e-01,  -9.37833071e-01,  -9.28977489e-01,
                         -1.73217542e-02,   1.88494995e-02,  -1.41058415e-02,
                          1.05359294e-02,  -8.75817053e-03,   9.58944764e-03,
                         -5.01383282e-03,  -3.35034961e-03,   7.69346952e-05,
                         -1.43863652e-02,   1.43384058e-02,  -5.44179371e-03,
                         -4.89252247e-03,  -4.27140342e-03,  -1.11396462e-02,
                         -5.35206543e-03,  -5.29552018e-03,  -2.20581004e-03,
                         -1.12648997e-02,   1.93679158e-03,  -1.50541253e-02,
                          6.64680125e-03,   6.11561874e-04,  -1.35513935e-02,
                          3.23247002e-03,  -2.27542617e-03,  -2.05554720e-02,
                         -5.37271798e-03,   3.60788428e-03,  -7.04122568e-03,
                          3.06484377e-04,  -3.97056062e-03,   1.37426937e-03,
                          5.01099136e-03,  -2.64724367e-03,   4.63236123e-03,
                         -1.30549874e-02,   6.79583987e-04,   9.93989874e-04,
                         -1.29500469e-02,  -3.48279020e-03,  -4.14367579e-03,
                          3.94108566e-03,  -6.19032828e-04,   2.51508737e-03,
                         -9.73247085e-03,   1.42254476e-02,   9.67539847e-03,
                          8.63914751e-03,   3.49601335e-03,  -1.17704049e-02,
                         -1.00004841e-02,  -1.17430580e-03,   1.29472474e-02,
                          3.69391855e-05,   7.08187278e-03,   4.62814746e-03,
                         -4.34011192e-04,   7.40937702e-03,   1.21813174e-02,
                          1.45593900e-02,   6.53572055e-03,   2.03196029e-03,
                         -1.50316150e-03,  -9.03823316e-01,  -9.20996785e-01,
                         -9.24205482e-01,  -9.13614929e-01,  -9.26053107e-01,
                         -9.11662698e-01,  -8.98021817e-01,  -9.29726481e-01,
                         -9.21431363e-01,  -9.40629005e-01,  -9.25724447e-01,
                         -9.15794909e-01,  -9.12688076e-01,  -9.20077801e-01,
                         -9.25446153e-01,  -9.23556983e-01,  -9.03768063e-01,
                         -9.25404072e-01,  -9.06379700e-01,  -9.28500772e-01,
                         -9.23361599e-01,  -9.37329412e-01,  -9.24807787e-01,
                         -9.39162076e-01,  -9.28585887e-01,  -9.09426987e-01,
                         -9.24096525e-01,  -9.27325368e-01,  -9.09610271e-01,
                         -9.49647844e-01,  -9.04524028e-01,  -9.22098815e-01,
                         -9.25714016e-01,  -9.38727915e-01,  -9.25965071e-01,
                         -9.45890546e-01,  -9.22541261e-01,  -9.28758442e-01,
                         -9.20796275e-01,  -9.31927919e-01,  -9.16673005e-01,
                         -9.36866701e-01,  -9.07242954e-01,  -9.18755770e-01,
                         -9.16541457e-01,  -9.41142380e-01,  -9.38119411e-01,
                         -9.33034003e-01,  -9.35079217e-01,  -9.17125046e-01,
                         -9.30190086e-01,  -9.31254029e-01,  -8.98647249e-01,
                         -9.35283005e-01,  -9.17737961e-01,  -9.42642391e-01,
                         -9.30706739e-01,  -9.39388394e-01,  -9.30833042e-01,
                         -9.38657880e-01,  -9.31053221e-01,  -9.44799542e-01,
                         -9.16400313e-01,  -9.18578029e-01,  -9.35411215e-01,
                         -9.48100984e-01,  -9.29821968e-01,  -9.47510839e-01,
                         -9.39611495e-01,  -9.26745832e-01,  -9.43314254e-01,
                         -9.22272027e-01,  -9.29078460e-01,  -9.27190483e-01,
                         -9.36004877e-01,  -9.35798526e-01,  -9.12324429e-01,
                         -9.38913882e-01,  -9.23281848e-01,  -9.51581478e-01,
                         -9.31404114e-01,  -9.14526582e-01,  -9.33710396e-01,
                         -9.50955570e-01,  -9.22806144e-01,  -9.52716768e-01,
                         -9.25139964e-01,  -9.25502002e-01,  -9.31348741e-01,
                         -9.29436386e-01,  -9.25452292e-01,  -9.47189629e-01,
                         -9.28747416e-01,  -9.27633822e-01,  -9.45011377e-01,
                         -9.29869771e-01,  -9.31627512e-01,  -9.33583140e-01,
                         -9.26411629e-01,  -9.35807288e-01,  -9.26714242e-01,
                         -9.41427946e-01,  -9.25508320e-01,  -9.33996618e-01,
                         -9.22219634e-01,  -9.33521032e-01,  -9.40382183e-01,
                         -9.38684940e-01,  -9.46764886e-01,  -9.29986179e-01,
                         -9.42786396e-01,  -9.23009515e-01,  -9.54940140e-01,
                         -9.39800978e-01,  -9.52110350e-01,  -9.29314256e-01,
                         -9.33615148e-01,  -9.22550559e-01,  -9.25954580e-01,
                         -9.36818242e-01,  -9.24937665e-01,  -9.46231186e-01,
                         -9.46443141e-01,  -9.58992422e-01,  -9.41375792e-01,
                         -9.21873212e-01,  -9.32885885e-01,  -9.49752629e-01,
                         -9.06276643e-01,  -9.44342136e-01,  -9.27961469e-01,
                         -9.34649110e-01,  -9.23420548e-01,  -9.27216232e-01,
                         -9.30225492e-01,  -9.28771257e-01,  -9.44742978e-01,
                         -9.36581075e-01,  -9.18003738e-01,  -9.47741628e-01,
                         -9.33232963e-01,  -9.38502729e-01,  -9.32573617e-01,
                         -9.27878559e-01,  -9.28008199e-01,  -9.17225957e-01,
                         -9.27519023e-01,  -9.32710111e-01,  -9.33365464e-01,
                         -9.26721871e-01,  -9.36226130e-01,  -9.19343054e-01,
                         -9.28588867e-01,  -9.27209496e-01,  -9.34918642e-01,
                         -9.30152714e-01,  -9.37733173e-01,  -9.41895843e-01,
                         -9.41018641e-01,  -9.40123320e-01,  -9.21944022e-01,
                         -9.27132130e-01,  -9.36289072e-01,  -9.24103081e-01,
                         -9.23182726e-01,  -9.24556255e-01,  -9.22777653e-01,
                         -9.28266644e-01,  -9.33399260e-01,  -9.07703340e-01,
                         -9.30745304e-01,  -9.06419992e-01,  -9.15673435e-01,
                         -9.36202824e-01,  -9.43516791e-01,  -9.48831499e-01,
                         -9.53042090e-01,  -9.50580060e-01,  -9.32633579e-01,
                         -9.52983916e-01,  -9.24913764e-01,  -9.20354903e-01,
                         -9.49299872e-01,  -9.40814614e-01,  -9.47462618e-01,
                         -9.40857410e-01,  -9.36053932e-01,  -9.47379112e-01,
                         -9.41846848e-01,  -9.39287603e-01,  -9.41897750e-01,
                         -9.57431436e-01,  -9.42131817e-01,  -9.45362091e-01,
                         -9.22531962e-01,  -9.43781197e-01,  -9.34485734e-01,
                         -9.28179264e-01,  -9.36834216e-01,  -9.41556215e-01,
                         -9.45617676e-01,  -9.41867352e-01,  -9.34636235e-01,
                         -9.18075144e-01,  -9.31855083e-01,  -9.37671065e-01,
                         -9.49338615e-01,  -9.56028163e-01,  -9.40342903e-01,
                         -9.43771660e-01,  -9.28946018e-01,  -9.20689821e-01,
                         -9.19867039e-01,  -9.28527176e-01,  -9.31034505e-01,
                         -9.12721694e-01,  -9.28391457e-01,  -9.20823514e-01,
                         -9.27892029e-01,  -9.22365010e-01,  -9.35951114e-01,
                         -9.40074444e-01,  -9.48541105e-01,  -9.16218281e-01,
                         -9.32410300e-01,  -9.28057313e-01,  -9.27987158e-01,
                         -9.32348192e-01,  -9.51315165e-01,  -9.53159750e-01,
                         -9.39349592e-01,  -9.28303838e-01,  -9.48126912e-01,
                         -9.29309070e-01,  -9.20410097e-01,  -9.35382485e-01,
                         -9.40117002e-01,  -9.38790619e-01,  -9.29824948e-01,
                         -9.28854883e-01,  -9.32474911e-01,  -9.33334172e-01,
                         -9.26883876e-01,  -9.33551550e-01,  -9.29269314e-01,
                         -9.31965411e-01,  -9.44571435e-01,  -9.20521736e-01,
                         -9.46010888e-01,  -9.45332468e-01,  -9.34109867e-01,
                         -9.42580402e-01,  -9.39702511e-01,  -9.39548373e-01,
                         -9.27050889e-01,  -9.27325428e-01,  -9.34892595e-01,
                         -9.36373234e-01,  -9.28092301e-01,  -9.39435065e-01,
                         -9.30335701e-01,  -9.61580276e-01,  -9.15514469e-01,
                         -9.38689232e-01,  -9.43268418e-01,  -9.57766354e-01,
                         -9.58113849e-01,  -9.30003464e-01,  -9.46569324e-01,
                         -9.31945205e-01,  -9.36445773e-01,  -9.38623488e-01,
                         -9.40872729e-01,  -9.40358877e-01,  -9.37177956e-01,
                         -9.47521150e-01,  -9.18493629e-01,  -9.29423034e-01,
                         -9.41039801e-01,  -9.32102025e-01,  -9.53476012e-01,
                         -9.38394189e-01,  -9.23758090e-01,  -9.41008210e-01,
                         -9.37417030e-01,  -9.38559949e-01,  -9.40761030e-01,
                         -9.36211705e-01,  -9.43590105e-01,  -9.33773756e-01,
                         -9.34554517e-01,  -9.35184360e-01,  -9.33030665e-01,
                         -9.25129294e-01,  -9.43373978e-01,  -9.40132022e-01,
                         -9.31600690e-01,  -9.51453567e-01,  -9.52379346e-01,
                         -9.46583807e-01,  -9.17197883e-01,  -9.51131999e-01,
                         -9.28711832e-01,  -9.22603369e-01,  -9.36953843e-01,
                         -9.39519763e-01,  -9.33179498e-01,  -9.24195766e-01,
                         -9.60879505e-01,  -9.64894712e-01,  -9.53024566e-01,
                         -9.60450709e-01,  -9.50025439e-01,  -9.32484984e-01,
                         -9.41825926e-01,  -9.36654806e-01,  -9.14551795e-01,
                         -9.44263279e-01,  -9.37094152e-01,  -9.40352023e-01,
                         -9.20777977e-01,  -9.19969618e-01,  -9.38194811e-01,
                         -9.48204219e-01,  -9.51198637e-01,  -9.33759868e-01,
                         -9.46329474e-01,  -9.44739997e-01,  -9.36550677e-01,
                         -9.35301781e-01,  -9.37108099e-01,  -9.33871329e-01,
                         -9.28447366e-01,  -9.24205542e-01,  -9.49299335e-01,
                         -9.28866684e-01,  -9.29420948e-01,  -9.62990344e-01,
                         -9.24249053e-01,  -9.42153573e-01,  -9.40896451e-01,
                         -9.43758965e-01,  -9.49923217e-01,  -9.46782112e-01,
                         -9.41364706e-01,  -9.32784081e-01,  -9.43607628e-01,
                         -9.59153771e-01,  -9.51593161e-01,  -9.55907404e-01,
                         -9.60365415e-01,  -9.38948393e-01,  -9.32658315e-01,
                         -9.25938368e-01,  -9.39681470e-01,  -9.20342982e-01,
                         -9.37180758e-01,  -9.01150823e-01,  -9.43848729e-01,
                         -9.38124835e-01,  -9.26678956e-01,  -9.38091815e-01,
                         -9.58863676e-01,  -9.26106453e-01,  -3.53609473e-02,
                          8.07315297e-03,  -6.26560673e-03,  -2.62941513e-02,
                         -1.30656678e-02,  -1.31639345e-02,  -3.54608297e-02,
                         -5.34945959e-03,  -2.54083537e-02,  -1.38613228e-02,
                          2.17348170e-02,   4.95163212e-03,  -3.28968070e-03,
                         -9.70717520e-03,  -6.72779046e-03,  -9.94795840e-03,
                         -2.22628936e-03,   1.95486617e-04,  -2.45694094e-03,
                         -9.80884419e-04,   1.75343044e-02,   8.11734796e-03,
                          1.95777826e-02,   1.91228632e-02,  -6.68604812e-03,
                          3.84104485e-03,   6.29081996e-03,  -2.36006058e-03,
                          5.69939753e-03,  -5.22221671e-04,   2.25211214e-03,
                          2.29167100e-03,  -6.68850169e-03,   1.00909332e-02,
                          3.17896018e-03,   7.31742417e-04,  -1.74083021e-02,
                         -4.26056422e-03,  -6.20777253e-03,   7.40397163e-03,
                          1.19833080e-02,  -4.37323237e-03,  -8.89956485e-03,
                         -4.63924324e-03,  -6.30989904e-03,  -5.54468296e-03,
                          1.89164188e-02,   7.60887656e-03,  -2.88188038e-03,
                          3.41711740e-04,   3.41772730e-03,   2.22228579e-02,
                          1.76244210e-02,   2.88140904e-02,   2.47586537e-02,
                          2.33979877e-02,   4.26682970e-03,   1.13586267e-03,
                          5.46802534e-03,   7.60642998e-03,  -7.32229650e-03,
                         -3.35252582e-04,  -4.61761327e-03,  -4.35232325e-03,
                         -2.50389479e-04,   1.28412601e-02,   1.44530982e-02,
                          2.41287462e-02,   1.66872330e-02,  -3.85615998e-03,
                         -2.55071674e-03,  -1.11695647e-03,   7.67913694e-03,
                         -5.96181164e-03,  -7.91274826e-04,  -1.95688847e-02,
                         -4.06642910e-03,   1.54536089e-03,  -1.15451240e-03,
                         -2.39788685e-02,  -1.76369362e-02,   1.78909302e-02,
                         -1.52387107e-02,  -1.52518302e-02,  -2.13129399e-03,
                         -3.09007033e-03,  -3.40975728e-03,  -2.47000484e-04,
                          5.28972642e-03,  -2.41601821e-02,  -1.45707624e-02,
                         -6.93195360e-03,  -1.37210507e-02,  -6.55750278e-04,
                         -6.51302328e-03,   8.10305029e-03,  -7.28387386e-03,
                          1.22654042e-03,  -1.67931635e-02,  -7.60473218e-03,
                         -3.64209991e-03,  -3.47306672e-03,  -4.14839527e-03,
                         -1.03987558e-02,  -1.47086093e-02,  -8.14373954e-04,
                         -1.36231445e-03,  -5.48120704e-04,   4.31378325e-03,
                          1.60317738e-02,   9.75950621e-03,   1.48397535e-02,
                          6.56042015e-03,  -4.41288139e-04,   2.34671257e-04,
                          1.70767568e-02,   1.72706842e-02,   1.69998091e-02,
                          1.19475052e-02,   1.48658883e-02,   6.49623759e-03,
                          7.50911981e-03,   2.99309287e-03,  -1.72795206e-02,
                         -5.18077286e-04,   8.05549417e-03,   4.35278751e-03,
                          1.02924984e-02,   1.25745423e-02,   9.44206491e-03,
                          3.95037234e-03,   4.16886806e-03,   6.60636928e-03,
                         -5.17334370e-03,   3.93397501e-03,  -1.22994324e-03,
                          1.87074244e-02,   3.11702979e-03,   1.77966489e-04,
                          6.40127016e-03,   1.36006139e-02,   1.34061808e-02,
                          1.63404625e-02,   4.14093120e-05,  -5.46284160e-03,
                          7.65472138e-03,   1.02035664e-02,  -5.71616925e-03,
                         -5.43063553e-03,   1.14242509e-02,   4.31329804e-03,
                         -1.70494299e-02,  -1.89062802e-03,  -1.00339027e-02,
                         -1.30741438e-02,   9.97549295e-03,   4.73764143e-04,
                         -1.17969560e-02,  -1.22196078e-02,  -2.94543221e-04,
                          8.96120444e-03,  -4.83669108e-03,   8.73622135e-04,
                         -1.23074721e-03,   1.34500293e-02,  -6.49409601e-03,
                          2.22149696e-02,   1.96405314e-02,   6.89116120e-03,
                         -6.13453146e-03,   1.98649727e-02,   1.19974110e-02,
                         -5.19469613e-03,   1.19930934e-02,   7.84200244e-03,
                          3.52614676e-03,  -1.14199268e-02,  -4.82917856e-03,
                          1.43637443e-02,   1.09659135e-02,   9.14549083e-03,
                         -1.85358282e-02,   9.32753272e-03,  -4.21866309e-03,
                          1.73227731e-02,   7.64711155e-03,   1.42117459e-02,
                          1.46884415e-02,   1.10257580e-03,  -1.27297845e-02,
                          2.27242522e-03,   1.00409305e-02,  -1.07339108e-02,
                          8.11285060e-03,  -1.33459270e-03,   1.90295716e-04,
                          1.87383275e-02,   4.93139541e-03,  -1.09789090e-03,
                         -1.88881910e-04,  -1.20604569e-02,   4.32674307e-03,
                          6.59179455e-03,  -9.74422507e-03,   1.41762970e-02,
                          5.17198537e-03,  -1.30034948e-03,   1.65596362e-02,
                          2.77054366e-02,  -1.51001578e-02,   5.26564289e-03,
                         -3.82783543e-03,   5.26692532e-03,   1.68506452e-03,
                          1.43075725e-02,  -1.02764545e-02,   2.09840704e-02,
                         -2.17852485e-03,   1.37514959e-03,   7.41515728e-03,
                          2.06598453e-02,   8.61689355e-03,   2.50044409e-02,
                          6.18528994e-03,  -1.45027749e-02,  -5.99821680e-04,
                          4.19290973e-06,   1.19148074e-02,   1.08847860e-02,
                         -5.13883680e-03,  -1.08129112e-02,  -1.97339524e-02,
                         -1.58114750e-02,  -1.14394212e-02,  -5.03382692e-03,
                          1.61883037e-03,   1.50364321e-02,   2.93466938e-03,
                          1.29768681e-02,   1.23450207e-02,   3.91919650e-02,
                          1.71308294e-02,  -9.09625727e-04,  -1.80276402e-03,
                          1.12951370e-02,  -2.61641014e-03,   1.53215847e-03,
                         -1.03111062e-02,   2.13355338e-03,   1.65956952e-02,
                          2.00775713e-02,   1.17188497e-02,   1.40735321e-02,
                         -3.84638808e-03,  -5.29589411e-03,   1.33971777e-02,
                          2.03845948e-02,  -3.62649257e-03,  -3.40281287e-03,
                         -1.22145209e-02,  -7.84801133e-03,  -9.22242552e-03,
                          6.25740131e-03,  -4.61910339e-03,  -7.48645544e-01,
                         -7.66588092e-01,  -7.48269081e-01,  -7.72379875e-01,
                         -7.80697107e-01,  -7.66573668e-01,  -7.65833557e-01,
                         -7.70635307e-01,  -7.51178443e-01,  -7.43009508e-01,
                         -7.40784883e-01,  -7.82484472e-01,  -7.32571065e-01,
                         -7.57727325e-01,  -7.54152715e-01,  -7.60879338e-01,
                         -7.71042824e-01,  -7.46367753e-01,  -7.50888824e-01,
                         -7.47356534e-01,  -7.60762095e-01,  -7.71681726e-01,
                         -7.66621232e-01,  -7.51981020e-01,  -7.35015094e-01,
                         -7.34250188e-01,  -7.64492333e-01,  -7.56638467e-01,
                         -7.57082164e-01,  -7.64601886e-01,  -7.57665336e-01,
                         -7.46930540e-01,  -7.37428188e-01,  -7.47070670e-01,
                         -7.43427217e-01,  -7.52689838e-01,  -7.69339681e-01,
                         -7.45864451e-01,  -7.46742010e-01,  -7.50620067e-01,
                         -7.69755721e-01,  -7.69416332e-01,  -7.58682907e-01,
                         -7.57085502e-01,  -7.34759450e-01,  -7.67442167e-01,
                         -7.44929314e-01,  -7.65389860e-01,  -7.54202306e-01,
                         -7.60500073e-01,  -7.68544137e-01,  -7.42451429e-01,
                         -7.57260025e-01,  -7.64148891e-01,  -7.56469548e-01,
                         -7.71248639e-01,  -7.59122431e-01,  -7.44717121e-01,
                         -7.54586458e-01,  -7.62278378e-01,  -7.48673975e-01,
                         -7.52896726e-01,  -7.51167834e-01,  -7.44963586e-01,
                         -7.65054405e-01,  -7.57731438e-01,  -7.52645016e-01,
                         -7.59955764e-01,  -7.54899025e-01,  -7.50062823e-01,
                         -7.41888702e-01,  -7.59413719e-01,  -7.62555182e-01,
                         -7.26785243e-01,  -7.44253993e-01,  -7.63709247e-01,
                         -7.78288007e-01,  -7.45106637e-01,  -7.51047432e-01,
                         -7.55688906e-01,  -9.34301674e-01,  -9.45440590e-01,
                         -9.16973531e-01,  -9.21473563e-01,  -7.49516964e-01,
                         -7.55102694e-01,  -7.61449873e-01,  -7.55373776e-01,
                         -7.62089670e-01,  -7.46547937e-01,  -7.51732409e-01,
                         -7.56402552e-01,  -7.48939335e-01,  -7.62325585e-01,
                         -7.52532780e-01,  -7.34579861e-01,  -7.58553207e-01,
                         -7.47311354e-01,  -7.65299141e-01,  -7.63637185e-01,
                         -9.19535875e-01,  -9.29928780e-01,  -9.26064968e-01,
                         -9.33550656e-01,  -9.25308645e-01,  -9.22827005e-01,
                         -9.33039784e-01,  -9.33229923e-01,  -9.23301637e-01,
                         -9.39072132e-01,  -9.24777985e-01,  -9.16843235e-01,
                         -7.58545101e-01,  -7.46436477e-01,  -7.40659833e-01,
                         -7.45064020e-01,  -7.56207347e-01,  -7.87667215e-01,
                         -7.60266840e-01,  -7.58001924e-01,  -7.62051404e-01,
                         -7.56179035e-01,  -7.51800418e-01,  -7.55638659e-01,
                         -7.58941174e-01,  -7.38943875e-01,  -7.53217399e-01,
                         -7.51976430e-01,  -9.17122364e-01,  -9.18574095e-01,
                         -9.36513424e-01,  -9.33953404e-01,  -9.27105129e-01,
                         -9.42832410e-01,  -9.32128489e-01,  -9.52981770e-01,
                         -7.52831101e-01,  -7.59487331e-01,  -7.47979105e-01,
                         -7.65889049e-01,  -7.59217143e-01,  -7.52935350e-01,
                         -7.57770896e-01,  -7.71775186e-01,  -7.70865321e-01,
                         -7.54078031e-01,  -7.84582675e-01,  -7.66657948e-01,
                         -7.46089041e-01,  -7.31918752e-01,  -7.83342361e-01,
                         -7.76900053e-01,  -9.51764345e-01,  -9.36135292e-01,
                         -9.14628208e-01,  -9.32201266e-01,  -9.32249963e-01,
                         -9.32270348e-01,  -9.46735620e-01,  -9.20470238e-01,
                         -9.26231742e-01,  -9.27615047e-01,  -9.32246387e-01,
                         -9.23790991e-01,  -9.03235495e-01,  -9.20599222e-01,
                         -9.18250024e-01,  -9.50280905e-01,  -7.75770247e-01,
                         -7.91170657e-01,  -7.74019599e-01,  -7.71114409e-01,
                         -7.62691140e-01,  -7.84890234e-01,  -7.50682235e-01,
                         -7.72950053e-01,  -7.66784906e-01,  -7.73934782e-01,
                         -7.86130846e-01,  -7.48513818e-01,  -7.61056364e-01,
                         -7.73344517e-01,  -7.77592659e-01,  -7.75247455e-01,
                         -7.96897590e-01,  -7.71882117e-01,  -7.75118172e-01,
                         -7.68325627e-01,  -7.68765628e-01,  -7.72781491e-01,
                         -7.73624182e-01,  -7.23541558e-01,  -7.11423218e-01,
                         -7.10846484e-01,  -7.50035465e-01,  -7.67885029e-01,
                         -7.73973584e-01,  -7.45649397e-01,  -7.57798374e-01,
                         -7.66792238e-01,  -7.81425118e-01,  -7.70622909e-01,
                         -7.65099525e-01,  -7.44725704e-01,  -7.63721526e-01,
                         -7.45632231e-01,  -7.51397669e-01,  -7.62135684e-01,
                         -7.47995973e-01,  -7.23527551e-01,  -7.80428052e-01,
                         -7.65237153e-01,  -7.45480418e-01,  -7.69942641e-01,
                         -7.63826668e-01,  -7.52304554e-01,  -3.11210919e-02,
                         -4.30157445e-02,   1.33659765e-02,   2.00908016e-02,
                         -1.50595447e-02,   2.33139433e-02,   3.45409252e-02,
                          8.42686091e-03,  -7.65211761e-01,  -7.52484560e-01,
                         -7.57756174e-01,  -7.69084513e-01,  -7.73675084e-01,
                         -7.87521362e-01,  -7.61699080e-01,  -7.71613538e-01,
                         -7.61411428e-01,  -7.89521873e-01,  -7.95561433e-01,
                         -7.75160789e-01,  -7.40015328e-01,  -7.69643307e-01,
                         -7.66969085e-01,  -7.82217145e-01,  -7.65705884e-01,
                         -7.69413531e-01,  -7.64929831e-01,  -7.78354466e-01,
                         -7.81801581e-01,  -7.83074319e-01,  -7.25145042e-01,
                         -7.75487185e-01,  -7.29338109e-01,  -7.48416424e-01,
                         -7.54815996e-01,  -7.47040689e-01,  -7.92763889e-01,
                         -7.70816147e-01,  -7.84391284e-01,  -7.66325235e-01,
                         -7.92646170e-01,  -7.92511523e-01,  -7.89646804e-01,
                         -7.67011046e-01,  -7.70017028e-01,  -7.76562035e-01,
                         -7.86622226e-01,  -7.87208736e-01,  -7.78853953e-01,
                         -7.85601676e-01,  -7.68587828e-01,  -7.64266908e-01,
                         -7.93651819e-01,  -7.83850372e-01,  -7.46293187e-01,
                         -7.60058641e-01,  -7.60008454e-01,  -7.65292108e-01,
                         -7.80749023e-01,  -7.79622674e-01,  -7.83256769e-01,
                         -7.78406918e-01,  -7.50894904e-01,  -8.01195860e-01,
                         -3.54140215e-02,  -1.35321198e-02,  -2.31712591e-02,
                         -9.17231198e-03,  -7.54529417e-01,  -7.66688883e-01,
                         -8.07089508e-01,  -7.48318851e-01,  -8.01303089e-01,
                         -7.92541146e-01,  -7.70482063e-01,  -7.94080257e-01,
                         -7.44700909e-01,  -7.86041498e-01,  -7.41588533e-01,
                         -8.00573766e-01,  -7.76818097e-01,  -7.82475412e-01,
                         -8.09453785e-01,  -7.56972492e-01,  -7.56873310e-01,
                         -7.66410887e-01,  -7.64434218e-01,  -7.97383010e-01,
                         -7.78107762e-01,  -7.54888475e-01,  -7.35341549e-01,
                         -7.44329810e-01,  -7.66731799e-01,  -7.44999290e-01,
                         -7.53249526e-01,  -7.73014426e-01,  -7.54937649e-01,
                         -7.50486255e-01,  -7.68947482e-01,  -7.76213109e-01,
                         -7.83049703e-01,  -7.84067631e-01,  -7.78990626e-01,
                         -7.83699632e-01,  -7.75302529e-01,  -7.66836405e-01,
                         -7.57760346e-01,  -7.43637502e-01,   1.59937609e-02,
                         -4.15635156e-03,  -2.18241643e-02,   4.64208471e-03,
                         -1.54526876e-02,  -1.64397545e-02,   2.16684099e-02,
                         -5.72578190e-03,  -7.62543559e-01,  -7.65286446e-01,
                         -7.87597954e-01,  -8.00637007e-01,  -7.35349298e-01,
                         -7.44064093e-01,  -7.69417048e-01,  -7.94803917e-01,
                         -7.53988326e-01,  -7.39529133e-01,  -7.61417270e-01,
                         -7.73270607e-01,  -7.52970815e-01,  -7.86114335e-01,
                         -7.70083666e-01,  -7.91844010e-01,  -7.62878120e-01,
                         -7.70005405e-01,  -7.37829328e-01,  -7.61633277e-01,
                         -7.76962638e-01,  -7.59207964e-01,  -7.55632997e-01,
                         -7.52521574e-01,  -7.26999879e-01,  -7.64590681e-01,
                         -7.82650828e-01,  -7.76511192e-01,  -7.74625003e-01,
                         -7.63060629e-01,  -7.65402019e-01,  -7.60092795e-01,
                         -7.54609942e-01,  -7.46096730e-01,  -7.74873435e-01,
                         -7.82353044e-01,  -5.12460023e-02,  -4.44814265e-02,
                         -1.84116196e-02,  -1.33549373e-04,  -7.97689855e-01,
                         -7.65790701e-01,  -7.47176111e-01,  -7.54291117e-01,
                         -7.47639477e-01,  -7.58333981e-01,  -7.86953866e-01,
                         -7.63774812e-01,  -7.56980598e-01,  -7.67765641e-01,
                         -7.28517592e-01,  -7.53873765e-01,  -7.47610867e-01,
                         -7.29206800e-01,  -7.48238981e-01,  -7.35387444e-01,
                         -7.40520477e-01,  -7.72881567e-01,  -7.41625845e-01,
                         -7.67878592e-01,  -7.79228270e-01,  -7.73378193e-01,
                         -7.41302848e-01,  -7.23593116e-01,  -7.66569316e-01,
                         -7.47559488e-01,  -7.45309293e-01,  -7.75154710e-01,
                         -7.60393620e-01,  -7.62716353e-01,  -7.65809417e-01,
                         -7.45986640e-01,  -7.57966936e-01,  -7.14047074e-01,
                         -7.38420725e-01,  -7.34843493e-01,  -7.32499778e-01,
                         -7.44163454e-01,  -7.75127888e-01,  -7.40472019e-01,
                         -7.53719449e-01,  -7.74652243e-01,  -7.73865819e-01,
                         -7.51355350e-01,  -7.41425276e-01,  -7.42554605e-01,
                         -7.74154127e-01,  -7.78419197e-01,  -7.78006732e-01,
                         -7.68079519e-01,  -7.28188217e-01,  -7.94118583e-01,
                         -9.35808063e-01,  -9.17315722e-01,  -9.51046944e-01,
                         -9.07797933e-01,  -9.20245111e-01,  -9.44143236e-01,
                         -9.40476298e-01,  -9.39200103e-01,  -9.64034438e-01,
                         -9.62935984e-01,  -9.43095446e-01,  -9.30065334e-01,
                         -7.90838242e-01,  -7.34573722e-01,  -7.71884918e-01,
                         -7.74256647e-01,  -8.01239431e-01,  -7.91285038e-01,
                         -7.65676379e-01,  -7.59721160e-01,  -7.59640515e-01,
                         -7.70153880e-01,  -8.04631174e-01,  -7.40932465e-01,
                         -7.72193372e-01,  -7.55225599e-01,  -7.83951402e-01,
                         -7.81017363e-01,  -7.61622131e-01,  -7.53916204e-01,
                         -7.63749838e-01,  -7.64526844e-01,  -7.41417825e-01,
                         -7.53368258e-01,  -7.42274761e-01,  -7.50748634e-01,
                         -9.06111062e-01,  -9.04508352e-01,  -9.14373100e-01,
                         -9.46730316e-01,  -9.53543425e-01,  -9.24731135e-01,
                         -9.48878407e-01,  -9.52241957e-01,  -9.16179299e-01,
                         -9.54321206e-01,  -9.40921605e-01,  -9.31982338e-01,
                         -7.64772177e-01,  -7.44219124e-01,  -7.54309893e-01,
                         -7.20353067e-01,  -9.34680700e-01,  -9.48827326e-01,
                         -9.68561292e-01,  -9.68695998e-01,  -9.46740746e-01,
                         -9.52928364e-01,  -9.64951038e-01,  -9.38278973e-01,
                         -9.14983153e-01,  -9.70315814e-01,  -9.41223681e-01,
                         -9.45901453e-01,  -9.38773274e-01,  -9.34854865e-01,
                         -8.95418763e-01,  -9.26735878e-01,  -9.32976484e-01,
                         -9.46214795e-01,  -9.30345654e-01,  -9.56328332e-01,
                         -9.34045434e-01,  -8.84829044e-01,  -9.39121068e-01,
                         -9.07207787e-01,  -7.75708020e-01,  -7.52083540e-01,
                         -7.34175980e-01,  -7.30174363e-01,  -7.45655477e-01,
                         -7.42139578e-01,  -7.67033517e-01,  -7.31073022e-01,
                         -7.56132245e-01,  -7.46326149e-01,  -7.41691589e-01,
                         -7.50378370e-01,  -7.63977647e-01,  -7.76571572e-01,
                         -7.71760523e-01,  -7.42653847e-01,  -7.63923645e-01,
                         -7.49347508e-01,  -7.61310220e-01,  -7.38461673e-01,
                         -9.22521949e-01,  -9.08602059e-01,  -9.26494062e-01,
                         -8.95566881e-01,  -9.38164651e-01,  -9.14985597e-01,
                         -9.28173304e-01,  -9.34669375e-01,  -9.30240333e-01,
                         -9.35913086e-01,  -9.43985641e-01,  -9.24816847e-01,
                         -9.29778039e-01,  -9.16729629e-01,  -9.36537385e-01,
                         -9.24397945e-01,  -7.32729495e-01,  -7.35413134e-01,
                         -7.56761074e-01,  -7.38082051e-01,  -7.66519666e-01,
                         -7.73469508e-01,  -7.57444978e-01,  -7.77776420e-01,
                         -9.81979421e-04,  -1.41152395e-02,   2.34716991e-03,
                         -4.35133930e-04,  -2.09560450e-02,   5.39122242e-03,
                         -4.66782637e-02,   1.25214206e-02,  -9.07181390e-03,
                          3.72344221e-04,  -3.27611864e-02,  -3.22244153e-03,
                         -7.57847130e-01,  -7.66300738e-01,  -7.47459948e-01,
                         -7.38571346e-01,  -1.19518433e-02,   4.43550944e-03,
                          2.88575646e-02,  -8.61777365e-03,  -3.30733918e-02,
                          9.07012960e-04,  -2.84245033e-02,  -2.91818250e-02,
                          1.55823633e-01,   1.45971894e-01,   1.62638962e-01,
                          1.83334097e-01,  -1.07917450e-02,   2.42623240e-02,
                          1.19794197e-02,  -2.61551961e-02,   1.66594043e-01,
                          1.66016221e-01,   1.62850633e-01,   1.40819311e-01,
                         -3.85557790e-03,   2.22006869e-02,  -5.06592868e-03,
                          1.34177608e-02,  -7.08047301e-04,  -5.54377493e-03,
                         -8.91632307e-03,   1.99213112e-03,  -1.13433171e-02,
                         -1.08821597e-03,  -1.16501898e-02,   6.20231666e-02,
                          2.02687696e-01,   2.00764582e-01,   1.91812217e-01,
                          1.99314609e-01,   2.07412377e-01,   2.09388077e-01,
                          1.77527472e-01,   1.89141721e-01,   1.84175536e-01,
                          2.04962313e-01,   1.98323935e-01,   1.77116990e-01,
                          1.88787431e-01,   1.68420121e-01,   1.75765589e-01,
                          1.95375443e-01,   1.85265288e-01,   1.47429153e-01,
                          1.45463198e-01,   1.79517910e-01,   1.64129481e-01,
                          1.94540009e-01,   1.69205964e-01,   1.77565306e-01,
                          1.53669491e-01,   1.84016719e-01,   1.80600464e-01,
                          1.69359714e-01,   1.70819864e-01,   1.76866889e-01,
                          1.53591007e-01,   1.49472862e-01,   1.83544546e-01,
                          1.72058746e-01,   1.55206531e-01,   1.71621740e-01,
                          1.60965458e-01,   1.46402285e-01,   1.34910047e-01,
                          1.79027155e-01,   1.75025061e-01,   1.76224798e-01,
                          1.74771026e-01,   1.63312003e-01,   1.37183428e-01,
                          2.09376514e-01,   2.07687348e-01,   2.10981533e-01,
                          2.11533204e-01,   1.94688767e-01,   1.66018143e-01,
                          1.66298583e-01,   1.47109255e-01,   1.70963958e-01,
                          1.75749913e-01,   1.23847321e-01,   1.51698381e-01,
                          1.32138163e-01,   1.61230221e-01,   1.38481513e-01,
                         -2.75830235e-02,   2.69555580e-03,  -8.59326776e-03,
                          9.87816881e-03,   2.21120045e-02,  -3.24425511e-02,
                         -3.16557884e-02,   2.89783417e-03,  -2.03523487e-02,
                          1.32876420e-02,  -2.90605705e-02,  -1.41775096e-02,
                          2.84759197e-02,   1.89854391e-02,   8.25698208e-03,
                          1.55364554e-02,   1.08956536e-02,   2.43359730e-02,
                         -5.88156423e-03,   8.64584930e-03,   1.31587228e-02,
                          1.52578251e-03,   1.91436186e-02,  -1.63176956e-04,
                         -1.55206062e-02,  -1.10103032e-02,   8.25081428e-04,
                         -2.92981192e-02,   8.28643702e-03,  -6.48076879e-03,
                          2.18838826e-02,   1.08178733e-02,   1.46541633e-02,
                          3.87921068e-03,   5.10603515e-03,   1.35482615e-02,
                         -7.36472430e-03,  -1.62884835e-02,   3.19498591e-02,
                         -1.84330705e-03,  -2.99659278e-03,   1.13979634e-02,
                          1.54967792e-02,  -4.03949060e-03,   1.48643497e-02,
                          3.16475262e-03,   2.90606674e-02,   1.15646543e-02,
                          8.47328827e-03,  -3.18162818e-03,   1.15954122e-02,
                          2.23197788e-02,   2.63746697e-02,   1.63061004e-02,
                          1.76464934e-02,   3.62453833e-02,   2.30393093e-03,
                          5.88721922e-03,   2.63678916e-02,   4.92329383e-03,
                          4.58257971e-03,  -2.61419173e-02,   8.12976714e-03,
                         -7.70601328e-04,  -2.79711420e-03,  -1.51786790e-03,
                         -2.10172191e-04,  -1.89132728e-02,  -2.93771941e-02,
                          7.39155198e-03,  -1.30138900e-02,   3.71514373e-02,
                         -5.69456024e-03,   9.97605454e-03,   1.47896046e-02,
                          2.76062619e-02,   3.33019160e-02,   2.21531093e-02,
                          6.12992980e-03,   1.27828503e-02,   3.28544620e-03,
                          4.52612480e-03,   1.59119815e-02,  -2.73274295e-02,
                         -2.69610528e-02,   5.23883617e-03,   1.71436574e-02,
                          2.73911352e-03,  -3.52908671e-02,   2.31795330e-02,
                         -9.00499165e-01,  -9.19117391e-01,  -9.51356530e-01,
                         -9.27964091e-01,  -9.57272112e-01,  -9.15046453e-01,
                         -9.18282986e-01,  -9.23295796e-01,  -9.23418522e-01,
                         -9.36253965e-01,  -9.05659437e-01,  -9.25787628e-01,
                          8.61437060e-03,   4.49821586e-03,   1.44372480e-02,
                          3.64091480e-03,  -1.97648145e-02,  -2.51680333e-02,
                         -2.46814750e-02,   8.51739291e-03,   1.64933261e-02,
                          2.64400374e-02,   4.49042581e-02,  -2.06097102e-04,
                         -9.08534229e-01,  -9.16176856e-01,  -9.39458251e-01,
                         -9.35309410e-01,  -9.35712814e-01,  -9.06168938e-01,
                         -9.25819099e-01,  -9.19068813e-01,  -9.46299613e-01,
                         -9.31118011e-01,  -9.40919161e-01,  -9.36033189e-01,
                         -8.95538092e-01,  -9.17650044e-01,  -9.07035470e-01,
                         -8.91995728e-01,  -9.08918977e-01,  -9.47835207e-01,
                         -9.24774349e-01,  -8.99718285e-01,  -9.24155295e-01,
                         -9.15547788e-01,  -9.35423315e-01,  -9.42217529e-01,
                         -9.50129986e-01,  -9.21854794e-01,  -9.24154401e-01,
                         -9.33913469e-01,  -9.22479153e-01,  -9.14603353e-01,
                         -9.38148916e-01,  -9.43962157e-01,  -9.15492356e-01,
                         -9.34364200e-01,  -9.25190449e-01,  -9.02463377e-01,
                         -9.24465060e-01,  -8.96619260e-01,  -9.26921725e-01,
                         -9.17978942e-01,  -9.50274825e-01,  -9.37934339e-01,
                         -9.09234941e-01,  -9.30939376e-01,  -9.34246004e-01,
                         -9.17930305e-01,  -9.29588020e-01,  -9.41283762e-01,
                         -9.28346455e-01,  -9.45767045e-01,  -9.11764383e-01,
                         -9.40702856e-01,  -9.16707397e-01,  -9.57753778e-01,
                         -9.19493496e-01,  -9.36946571e-01,  -9.54033315e-01,
                         -9.33532238e-01,  -9.37743068e-01,  -9.11576629e-01,
                         -9.46762562e-01,  -9.10907984e-01,  -9.00199652e-01,
                         -9.12757158e-01,  -9.15347695e-01,  -9.27566767e-01,
                         -9.22498763e-01,  -9.47562993e-01,  -9.06676590e-01,
                         -9.15967584e-01,  -9.21573102e-01,  -8.97746384e-01,
                         -9.27825034e-01,  -9.48240459e-01,  -9.36374009e-01,
                         -9.22593713e-01,  -9.31393027e-01,  -9.46200192e-01,
                         -9.17258561e-01,  -9.13745642e-01,  -9.37962949e-01,
                         -9.20688391e-01,  -9.04884040e-01,  -9.47439134e-01,
                         -9.27772939e-01,  -9.41984594e-01,  -9.36501563e-01,
                         -9.36465979e-01,  -9.47350979e-01,  -9.58191931e-01,
                         -9.15647089e-01,  -9.41846609e-01,  -9.37802017e-01,
                         -9.25014317e-01,  -9.28402364e-01,  -9.08418655e-01,
                         -9.20485198e-01,  -9.03745592e-01,  -9.33853924e-01,
                         -9.33310449e-01,  -9.18892980e-01,  -9.33042765e-01,
                         -9.28466797e-01,  -9.20658231e-01,  -9.37025845e-01,
                         -9.22239959e-01,  -9.21460211e-01,  -9.29793060e-01,
                         -9.21296179e-01,  -9.17844057e-01,  -9.16056097e-01,
                         -9.10397947e-01,  -9.37078416e-01,  -9.25101757e-01,
                         -9.53856468e-01,  -9.54043210e-01,  -9.55733120e-01,
                         -9.20135975e-01,  -9.46109235e-01,  -9.10716832e-01,
                         -9.28042352e-01,  -8.98753345e-01,  -9.45946991e-01,
                         -9.16560590e-01,  -9.33932006e-01,  -9.41921711e-01,
                         -9.39495146e-01,  -9.35102582e-01,  -9.25247192e-01,
                         -9.25807714e-01,  -9.35593605e-01,  -9.48936105e-01,
                         -9.32116747e-01,  -9.44377959e-01,  -9.37143385e-01,
                         -9.40914631e-01,  -9.47644353e-01,  -9.23340499e-01,
                         -9.61759031e-01,  -9.48346615e-01,  -9.63573456e-01,
                         -9.40198720e-01,  -9.59052384e-01,  -9.47125435e-01,
                         -9.53156650e-01,  -9.33792174e-01,  -9.49718595e-01,
                         -9.27992404e-01,  -9.41705167e-01,  -9.67343211e-01,
                         -9.42254841e-01,  -9.40341890e-01,  -9.41940248e-01,
                         -9.44465339e-01,  -9.49894786e-01,  -9.56590056e-01,
                         -9.25819218e-01,  -9.54484403e-01,  -9.49844241e-01,
                         -9.41867828e-01,  -9.22919631e-01,  -9.34326172e-01,
                         -9.46268022e-01,  -9.35819507e-01,  -9.24102247e-01,
                         -9.41909850e-01,  -9.39537644e-01,  -9.39874947e-01,
                         -9.38371122e-01,  -9.31560755e-01,  -9.20056641e-01,
                         -9.13391292e-01,  -9.30406868e-01,  -9.27139163e-01,
                         -9.16998982e-01,  -9.35951233e-01,  -9.41916823e-01,
                         -9.31977928e-01,  -9.24668908e-01,  -9.31357086e-01,
                         -9.10888255e-01,  -9.23858166e-01,  -9.17329550e-01,
                         -9.46120560e-01,  -9.18001473e-01,  -9.16738987e-01,
                         -9.51550007e-01,  -9.30116475e-01,  -9.21532571e-01,
                         -9.27225769e-01,  -9.15668845e-01,  -9.12309587e-01,
                         -9.15333211e-01,  -9.27411735e-01,  -9.34069574e-01,
                         -9.33251381e-01,  -9.21296418e-01,  -9.24557269e-01,
                         -9.18150008e-01,  -9.58457351e-01,  -9.22437370e-01,
                         -9.29340065e-01,  -9.45150077e-01,  -9.23881054e-01,
                         -9.45822477e-01,  -9.22746658e-01,  -9.59836483e-01,
                         -9.30969298e-01,  -9.57196832e-01,  -9.47526157e-01,
                         -9.51256812e-01,  -9.41896319e-01,  -9.41437900e-01,
                         -9.23562407e-01,  -9.32645440e-01,  -9.28831756e-01,
                         -9.34670568e-01,  -9.31601882e-01,  -9.22774792e-01,
                         -9.26642954e-01,  -9.19164777e-01,  -9.27584589e-01,
                         -9.34281945e-01,  -9.24662292e-01,  -9.25083041e-01,
                         -9.09233212e-01,  -9.30651963e-01,  -9.31069016e-01,
                         -9.31654155e-01,  -9.37938213e-01,  -9.30108070e-01,
                         -9.36043799e-01,  -9.51136410e-01,  -9.23003197e-01,
                         -9.54831839e-01,  -9.39009905e-01,  -9.31826770e-01,
                         -9.54083204e-01,  -9.51997876e-01,  -9.58731472e-01,
                         -9.51626956e-01,  -9.38750446e-01,  -9.31446791e-01,
                         -9.13737476e-01,  -9.44135785e-01,  -9.43867326e-01,
                         -9.51757252e-01,  -9.28277194e-01,  -9.56022978e-01,
                         -9.06667590e-01,  -8.99830401e-01,  -9.26360130e-01,
                          2.80631776e-03,  -1.89971868e-02,   3.57312560e-02,
                          2.26432569e-02,   2.32995413e-02,   7.39142718e-03,
                          2.38315072e-02,   1.18165894e-03,   1.44884987e-02,
                          1.37831960e-02,  -1.46988861e-03,   6.15523988e-03,
                         -6.45301957e-03,   2.73020100e-03,   4.08558501e-03,
                         -4.52029258e-02,   4.59666271e-03,   7.41803320e-03,
                          1.34029230e-02,   4.69898339e-03,  -4.13705735e-03,
                         -9.91061702e-03,   2.98532378e-03,   2.85457931e-02,
                         -3.24582495e-03,  -6.35384489e-03,  -5.18974103e-03,
                         -1.33705791e-02,   6.78043393e-03,   1.10143228e-02,
                          1.26597460e-03,   2.11037938e-02,   2.22474746e-02,
                          1.68383997e-02,  -3.45032802e-03,   3.25583667e-02,
                          6.93087280e-03,   2.16948073e-02,  -6.75538741e-03,
                         -1.52047165e-02,   1.61493551e-02,  -1.54569363e-02,
                         -1.56172644e-02,   5.60610043e-03,   1.09101310e-02,
                          2.59342194e-02,  -7.01433560e-03,   2.18616016e-02,
                         -9.36003327e-01,  -9.03635621e-01,  -9.07934308e-01,
                         -9.57707345e-01,  -9.29785073e-01,  -9.22564983e-01,
                         -9.34775412e-01,  -9.30031836e-01,  -9.22633111e-01,
                         -9.47335958e-01,  -9.22692895e-01,  -9.46714342e-01,
                         -9.45199072e-01,  -9.30497587e-01,  -9.37249184e-01,
                         -9.21224535e-01,  -9.19325948e-01,  -9.14026141e-01,
                         -8.97100747e-01,  -9.18479621e-01,  -9.16346848e-01,
                         -9.32085693e-01,  -9.25557256e-01,  -9.42232072e-01,
                         -9.32524502e-01,  -9.55785334e-01,  -9.49671566e-01,
                         -9.43019927e-01,  -9.28064346e-01,  -9.50801730e-01,
                         -9.19173241e-01,  -9.29919302e-01,  -9.40197408e-01,
                         -9.02920425e-01,  -9.42048907e-01,  -9.13862228e-01,
                         -9.27542388e-01,  -9.20607150e-01,  -9.11151826e-01,
                         -9.25645053e-01,  -9.33080792e-01,  -9.18099642e-01,
                         -9.24487889e-01,  -9.00207102e-01,  -9.17429984e-01,
                         -9.41574097e-01,  -9.21780229e-01,  -9.32614505e-01,
                         -9.18258369e-01,  -9.47218001e-01,  -9.08853769e-01,
                         -9.19817030e-01,  -9.26862240e-01,  -9.35655594e-01,
                         -9.27657962e-01,  -9.28102911e-01,  -9.29289222e-01,
                         -9.32129383e-01,  -9.25843656e-01,  -9.13219392e-01,
                         -9.20816422e-01,  -9.16604698e-01,  -9.16505575e-01,
                         -9.13286448e-01,  -9.49062705e-01,  -9.37759459e-01,
                         -9.45524514e-01,  -9.26460624e-01,  -9.20270026e-01,
                         -9.15445983e-01,  -9.24784243e-01,  -9.23596442e-01,
                         -9.18671608e-01,  -9.14186656e-01,  -9.39558506e-01,
                         -9.38359559e-01,  -9.35947895e-01,  -9.38236594e-01,
                         -9.25631702e-01,  -9.41473365e-01,  -9.23955560e-01,
                         -9.43788946e-01,  -9.41123903e-01,  -9.63332534e-01,
                         -9.51589823e-01,  -9.60478067e-01,  -9.31985795e-01,
                         -9.33493316e-01,  -9.23332989e-01,  -9.37533796e-01,
                         -9.43371236e-01,  -9.57614422e-01,  -9.43479121e-01,
                         -9.65881348e-01,  -9.26117897e-01,  -9.43213105e-01,
                         -9.20743406e-01,  -9.27455783e-01,  -9.46282566e-01,
                         -9.39332306e-01,  -9.34474528e-01,  -9.39214945e-01,
                         -9.33089256e-01,  -9.22582746e-01,  -9.39613461e-01,
                         -9.27693486e-01,  -9.37388539e-01,  -9.47925687e-01,
                         -9.22797024e-01,  -9.45172906e-01,  -9.23599541e-01,
                         -9.43547845e-01,  -9.10033643e-01,  -9.22151268e-01,
                         -9.40519333e-01,  -9.23042715e-01,  -9.32248831e-01,
                         -9.32325363e-01,  -9.25929785e-01,  -9.46849167e-01,
                         -9.52752709e-01,  -9.57706451e-01,  -9.45328057e-01,
                         -9.61492658e-01,  -9.35169697e-01,  -9.61895406e-01,
                         -9.08204913e-01,  -9.46135640e-01,  -9.42221642e-01,
                         -9.38332200e-01,  -9.25741076e-01,  -9.51991022e-01,
                         -9.37261224e-01,  -9.42843378e-01,  -9.37533379e-01,
                         -9.42507386e-01,  -9.35596585e-01,  -9.33629274e-01,
                         -9.20848846e-01,  -9.39460576e-01,  -9.33268309e-01,
                         -9.32454944e-01,  -9.33585882e-01,  -9.37432647e-01,
                         -9.31936562e-01,  -9.32212591e-01,  -9.41321909e-01,
                         -9.49629366e-01,  -9.30385590e-01,  -9.19948936e-01,
                         -9.45689201e-01,  -9.41957772e-01,  -9.60758924e-01,
                         -9.54256773e-01,  -9.37419236e-01,  -9.44658637e-01,
                         -9.46936905e-01,  -9.56787288e-01,  -9.52601314e-01,
                         -9.34819758e-01,  -9.27511215e-01,  -9.29820061e-01,
                         -9.35099304e-01,  -9.40540075e-01,  -9.41851854e-01,
                         -9.24927056e-01,  -9.44130003e-01,  -9.38170433e-01,
                         -9.33821619e-01,  -9.37466383e-01,  -9.22129929e-01,
                         -9.17707801e-01,  -9.59513605e-01,  -9.26626265e-01,
                         -9.42540109e-01,  -9.44910109e-01,  -9.36356068e-01,
                         -9.50922370e-01,  -9.28421915e-01,  -9.52259779e-01,
                         -9.38266456e-01,  -9.28507209e-01,  -9.33529139e-01,
                         -9.27218914e-01,  -9.37558413e-01,  -9.36470091e-01,
                         -9.24761951e-01,  -9.33087885e-01,  -9.26734030e-01,
                         -9.39772367e-01,  -9.22959030e-01,  -9.47453618e-01,
                         -9.56420064e-01,  -9.34074342e-01,  -9.40035939e-01,
                         -9.35384154e-01,  -9.56420302e-01,  -9.35500264e-01,
                         -9.45529401e-01,  -9.35739756e-01,  -9.35511351e-01,
                         -9.50195849e-01,  -9.48637784e-01,  -9.50077236e-01,
                         -9.39168811e-01,  -9.19385910e-01,  -9.50097501e-01,
                         -9.34311867e-01,  -9.46605682e-01,  -9.34855998e-01,
                         -9.41514969e-01,  -9.33517814e-01,  -9.22048032e-01,
                         -9.38886166e-01,  -9.33892250e-01,  -9.44929540e-01,
                         -9.27055299e-01,  -9.27411139e-01,  -9.27773178e-01,
                         -9.41453755e-01,  -9.38246012e-01,  -9.44543719e-01,
                         -9.38297689e-01,  -9.31182623e-01,  -9.38491762e-01,
                         -9.36922491e-01,  -9.33131695e-01,  -9.33909118e-01,
                         -9.32150364e-01,  -9.39018011e-01,  -9.45039868e-01,
                         -9.44043398e-01,  -9.44132030e-01,  -9.44182277e-01,
                         -9.37099814e-01,  -9.54708278e-01,  -9.47532594e-01,
                         -9.41431284e-01,  -9.33219314e-01,  -9.39871967e-01,
                         -9.33449388e-01,  -9.29318428e-01,  -9.44445372e-01,
                         -9.30125535e-01,  -9.32098031e-01,  -9.35269356e-01,
                         -9.27990735e-01,  -9.42789495e-01,  -9.32550669e-01,
                         -9.42863584e-01,  -9.32742596e-01,  -9.32742357e-01,
                         -9.43575025e-01,  -9.34170187e-01,  -9.39784706e-01,
                         -9.28711116e-01,  -9.33766067e-01,  -9.40202296e-01,
                         -9.25636411e-01,  -9.35038865e-01,  -9.36251521e-01,
                         -9.36856091e-01,  -9.31324601e-01,  -9.36364710e-01,
                         -9.40076411e-01,  -9.34206307e-01,  -9.50251281e-01,
                         -9.28596079e-01,  -9.30023909e-01,  -9.40750062e-01,
                         -9.29980397e-01,  -9.37099218e-01,  -9.26250219e-01,
                         -9.41019535e-01,  -9.30997908e-01,  -9.28635478e-01,
                         -9.35268521e-01,  -9.23852682e-01,  -9.33502853e-01,
                         -9.24882591e-01,  -9.32143509e-01,  -9.27223861e-01,
                         -9.33526933e-01,  -9.25789654e-01,  -9.29277062e-01,
                         -9.24603522e-01,  -9.28435504e-01,  -9.30844426e-01,
                         -9.31053817e-01,  -9.23876107e-01,  -9.31645155e-01,
                         -9.24924314e-01,  -9.31538701e-01,  -9.29095387e-01,
                         -9.29887712e-01,  -9.25910294e-01,  -9.31103826e-01,
                         -9.32230175e-01,  -9.35140312e-01,  -9.37942863e-01,
                         -9.38315868e-01,  -9.24438715e-01,  -9.25036192e-01,
                         -9.28907156e-01,  -9.31595564e-01,  -9.27955329e-01,
                         -9.28406000e-01,  -9.29428160e-01,  -9.27381098e-01,
                         -9.24124956e-01,  -9.32042241e-01,  -9.29419518e-01,
                         -9.33889866e-01,  -9.28310871e-01,  -9.33559954e-01,
                         -9.34281826e-01,  -9.38022912e-01,  -9.29661691e-01,
                         -9.29838061e-01,  -9.33384001e-01,  -9.21018958e-01,
                         -9.31859732e-01,  -9.28124964e-01,  -9.32560205e-01,
                         -9.22700286e-01,  -9.22877908e-01,  -9.27433252e-01,
                         -9.32070494e-01,  -9.31439102e-01,  -9.33899403e-01,
                         -9.24045444e-01,  -9.29597616e-01,  -9.22133505e-01,
                         -9.27650630e-01,  -9.29100096e-01,  -9.28081214e-01,
                         -9.27091599e-01,  -9.31526721e-01,  -9.28215086e-01,
                         -9.24946785e-01,  -9.31631863e-01,  -9.27631259e-01,
                         -9.31010127e-01,  -9.26856816e-01,  -9.20752048e-01,
                         -9.23095226e-01,  -9.34736133e-01,  -9.30991590e-01,
                         -9.23996091e-01,  -9.29420948e-01,  -9.30044949e-01,
                         -9.32419598e-01,  -9.29568350e-01,  -9.30384696e-01,
                         -9.26734030e-01,  -9.34055746e-01,  -9.35484827e-01,
                         -9.23911333e-01,  -9.29113388e-01,  -9.28456604e-01,
                         -9.29442704e-01,  -9.35729027e-01,  -9.32226777e-01,
                         -9.37733531e-01,  -9.26375329e-01,  -9.34976280e-01,
                         -9.35158074e-01,  -9.35593605e-01,  -9.36047673e-01,
                         -9.36539590e-01,  -9.31169212e-01,  -9.32373703e-01,
                         -9.34750080e-01,  -9.35402691e-01,  -9.33170319e-01,
                         -9.30967510e-01,  -9.37357366e-01,  -9.39419985e-01,
                         -9.38703239e-01,  -9.34243560e-01,  -9.31722581e-01,
                         -9.30945337e-01,  -9.32262003e-01,  -9.33658957e-01,
                         -9.29657817e-01,  -9.30012643e-01,  -9.36117887e-01,
                         -9.36227202e-01,  -9.29336786e-01,  -9.38829720e-01,
                         -9.36214387e-01,  -9.39204454e-01,  -9.36178207e-01,
                         -9.33279634e-01,  -9.27881539e-01,  -9.31185663e-01,
                         -9.32157338e-01,  -9.28874195e-01,  -9.31969583e-01,
                         -9.28848624e-01,  -9.38556612e-01,  -9.23659325e-01,
                         -9.34249997e-01,  -9.30086315e-01,  -9.36844289e-01,
                         -9.26467121e-01,  -9.31216002e-01,  -9.23279583e-01,
                         -9.23520565e-01,  -9.25215244e-01,  -9.20098424e-01,
                         -9.18926656e-01,  -9.28582072e-01,  -9.36726093e-01,
                         -9.31230783e-01,  -9.36035275e-01,  -9.32052314e-01,
                         -9.25541759e-01,  -9.28150475e-01,  -9.31496263e-01,
                         -9.33183730e-01,  -9.28052962e-01,  -9.37258780e-01,
                         -9.34047878e-01,  -9.32560503e-01,  -9.22770977e-01,
                         -9.34972525e-01,  -9.37818348e-01,   2.27012439e-03,
                         -1.66376727e-03,   8.71653901e-04,  -1.85735495e-04,
                          2.37914012e-03,  -7.05374917e-03,  -6.13055378e-03,
                          2.42717491e-04,   4.05109208e-03,   4.09430359e-03,
                         -7.83928554e-04,  -3.77043057e-03,   3.08916933e-04,
                          4.64258343e-03,  -1.03209680e-02,   4.75030299e-03,
                          3.47402995e-03,   2.45634513e-03,   2.59952084e-03,
                         -8.70489632e-04,  -5.89892454e-03,  -6.40254514e-03,
                         -4.34670271e-03,  -2.72490608e-04,   7.36818276e-03,
                         -2.89675989e-03,  -5.24280732e-03,   7.35678885e-04,
                         -9.45400621e-04,  -3.97927221e-03,  -4.82852710e-03,
                         -1.39513416e-02,   2.19936483e-03,  -4.96100215e-03,
                         -2.83681857e-03,   8.66511546e-05,  -3.49279772e-03,
                         -4.26240778e-03,  -5.61796501e-03,   1.70517666e-03,
                         -8.84322726e-05,  -3.26477969e-03,  -4.65209922e-03,
                          6.64066756e-04,   7.32421584e-04,  -1.14905124e-03,
                         -1.14573154e-03,   3.37186153e-04,  -1.04374960e-02,
                         -4.92196996e-03,   4.70255269e-03,   1.45219523e-03,
                          1.55665062e-03,  -3.46638565e-03,   4.49506938e-03,
                         -4.74401721e-04,   1.80978456e-03,  -4.75701876e-03,
                         -3.86343012e-03,  -5.69470599e-03,  -7.02151563e-03,
                         -5.50617743e-03,   2.91712163e-03,  -2.42700148e-03,
                         -4.90368763e-03,   2.84707570e-03,   5.32619422e-03,
                         -3.89831094e-03,   2.04492011e-03,  -2.57360097e-03,
                         -3.21824173e-03,  -3.64833721e-03,  -7.16644479e-03,
                         -7.14492565e-03,  -1.93151063e-04,   6.54073083e-04,
                          3.42872576e-03,  -4.39396128e-03,  -3.52779636e-04,
                          6.36568898e-03,   1.11468052e-02,   1.80308276e-03,
                          1.51603133e-03,  -3.15833517e-04,   6.50254427e-04,
                          1.24199525e-03,  -4.04353114e-03,   7.41086714e-03,
                          2.83440691e-03,   3.65612004e-03,  -2.40790122e-03,
                          2.78195040e-03,   5.92626538e-03,   1.33822428e-03,
                         -1.33473135e-03,  -1.81259133e-03,  -3.00554000e-03,
                         -7.23787677e-03,  -9.35668219e-03,  -6.86455518e-03,
                         -7.03603495e-03,   2.47261766e-03,  -5.58585674e-03,
                          2.93576438e-03,  -1.21879915e-03,   1.29842281e-03,
                         -3.16882087e-03,  -2.95043620e-03,   6.68827968e-04,
                         -4.31500981e-03,   6.55522943e-03,   1.21716352e-03,
                          1.64718973e-03,   5.70816454e-03,   3.86108062e-04,
                          4.50338563e-03,  -2.12911796e-03,   5.10798255e-03,
                          4.85177850e-03,   3.79656535e-03,   9.92808212e-03,
                          3.18848947e-03,   9.23189241e-03,   3.97952879e-03,
                         -2.80696922e-03,   2.92389956e-03,  -3.17391474e-03,
                          1.23886410e-02,   5.67830168e-03,   1.09326337e-02,
                          4.34215646e-03,   3.54193442e-04,   2.34039896e-03,
                          1.04910275e-02,   4.22176113e-03,   1.40593457e-03,
                          7.19689019e-03,   6.52547693e-03,   6.39826898e-03,
                         -2.71866884e-04,   5.78789227e-03,   3.92942177e-03,
                         -5.09900786e-03,  -5.51213045e-03,  -6.61478285e-03,
                          3.33859562e-03,   3.35152075e-03,   4.57692455e-04,
                          8.77073500e-03,   6.80429535e-03,   2.02877913e-03,
                          1.58789990e-04,   3.44664790e-03,  -1.32521580e-03,
                          4.76035941e-03,   5.51452860e-03,   2.17178161e-03,
                         -5.90555719e-04,   2.58959644e-03,   2.06556590e-03,
                         -8.96651996e-04,   3.76956421e-03,   1.30904024e-03,
                          6.15959894e-03,   2.60602846e-03,   5.90139208e-03,
                          1.56388595e-03,   4.87610418e-03,   1.73323101e-03,
                          3.71694844e-03,   2.77282298e-03,  -1.16596150e-03,
                         -2.24964507e-03,  -5.81255089e-03,  -7.00196484e-03,
                         -4.83056437e-03,  -1.70166977e-03,  -5.90159278e-03,
                         -1.67920138e-03,   1.66245748e-03,   1.62637769e-03,
                          3.14251287e-03,   3.69095244e-03,   3.23380751e-04,
                          7.02410052e-03,   7.56196445e-03,   4.00131103e-03,
                          4.68919054e-03,   1.40800541e-02,   1.21540320e-03,
                         -5.81144181e-04,   1.00849522e-03,  -1.35047722e-03,
                         -1.29623967e-03,  -1.67832815e-03,  -1.98696787e-03,
                         -1.36102538e-03,  -2.29243352e-03,   3.23061249e-03,
                          4.29726811e-03,  -5.13008377e-03,   2.73259194e-03,
                          1.58140610e-03,  -1.36742217e-03,  -4.99209901e-03,
                         -1.99750904e-03,   1.51095132e-03,  -4.51280409e-03,
                         -2.09840224e-03,   1.24573079e-03,   4.14721714e-03,
                          6.88177766e-04,  -2.01953389e-03,  -2.66993395e-03,
                          1.91968726e-03,   4.28025378e-03,  -6.58543257e-04,
                         -1.32924935e-03,   3.28457286e-03,   3.73737246e-04,
                          1.66436331e-03,  -2.11344124e-03,  -5.78690844e-04,
                         -4.66063712e-03,  -1.67703908e-03],
                         dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri11",
    rate = 41000,
    data = numpy.array([ -3.25490325e-03,  -2.78991717e-03,  -2.49930075e-03,
                         -2.15056119e-03,  -1.56932836e-03,  -1.16246543e-03,
                         -6.97479292e-04,  -2.32493097e-04,   5.81232744e-05,
                          6.39356032e-04,   1.10434217e-03,   1.56932836e-03,
                          2.32493086e-03,   2.90616369e-03,   3.25490325e-03,
                          3.60364304e-03,   4.12675226e-03,   4.64986172e-03,
                          5.11484826e-03,   5.57983434e-03,   5.98669704e-03,
                          6.39356021e-03,   6.91666966e-03,   7.32353237e-03,
                          7.90476520e-03,   8.25350452e-03,   8.60224478e-03,
                          9.18347761e-03,   9.64846369e-03,   1.01134498e-02,
                          1.05203129e-02,   1.08690523e-02,   1.15665318e-02,
                          1.20896408e-02,   1.24383802e-02,   1.28452433e-02,
                          1.32521065e-02,   1.37170926e-02,   1.40077090e-02,
                          1.43564483e-02,   1.48214344e-02,   1.51120508e-02,
                          1.55189140e-02,   1.60420239e-02,   1.62745174e-02,
                          1.66813787e-02,   1.70882419e-02,   1.74951050e-02,
                          1.78438444e-02,   1.81344617e-02,   1.84832010e-02,
                          1.87738165e-02,   1.92969274e-02,   1.98781602e-02,
                          2.01106519e-02,   2.05175150e-02,   2.08081324e-02,
                          2.10406259e-02,   2.15056110e-02,   2.16799807e-02,
                          2.19124742e-02,   2.23774593e-02,   2.27262005e-02,
                          2.31330637e-02,   2.34818030e-02,   2.39467882e-02,
                          2.42955275e-02,   2.44117752e-02,   2.47023907e-02,
                          2.48767603e-02,   2.50511300e-02,   2.54579931e-02,
                          2.56323628e-02,   2.59229802e-02,   2.63298433e-02,
                          2.65042130e-02,   2.66785827e-02,   2.68529523e-02,
                          2.72016916e-02,   2.75504310e-02,   2.77248006e-02,
                          2.78991722e-02,   2.80735418e-02,   2.83641573e-02,
                          2.85385270e-02,   2.84804031e-02,   2.86547747e-02,
                          2.89453901e-02,   2.91778836e-02,   2.94103771e-02,
                          2.93522533e-02,   2.94103771e-02,   2.95266230e-02,
                          2.97009926e-02,   2.98172385e-02,   2.99916100e-02,
                          3.01659796e-02,   3.00497320e-02,   3.00497320e-02,
                          3.02822255e-02,   3.01078558e-02,   3.00497320e-02,
                          3.02241016e-02,   3.02241016e-02,   3.03403493e-02,
                          3.03984713e-02,   3.02241016e-02,   3.01659796e-02,
                          3.00497320e-02,   3.01078558e-02,   3.02822255e-02,
                          3.02241016e-02,   2.99916100e-02,   2.98753623e-02,
                          2.99916100e-02,   2.98172385e-02,   2.98172385e-02,
                          2.97591165e-02,   2.95266230e-02,   2.95847468e-02,
                          2.95266230e-02,   2.92941295e-02,   2.94103771e-02,
                          2.91778836e-02,   2.89453901e-02,   2.89453901e-02,
                          2.88291443e-02,   2.87128966e-02,   2.86547747e-02,
                          2.84804031e-02,   2.83060335e-02,   2.80154180e-02,
                          2.78991722e-02,   2.76666787e-02,   2.74923090e-02,
                          2.75504310e-02,   2.72598155e-02,   2.70854458e-02,
                          2.69691981e-02,   2.65623368e-02,   2.63879653e-02,
                          2.61554737e-02,   2.58067325e-02,   2.56323628e-02,
                          2.53417473e-02,   2.50511300e-02,   2.48186383e-02,
                          2.44117752e-02,   2.41211578e-02,   2.38886662e-02,
                          2.37142947e-02,   2.33655553e-02,   2.30168160e-02,
                          2.27843225e-02,   2.24937070e-02,   2.22612135e-02,
                          2.19124742e-02,   2.15637349e-02,   2.14474872e-02,
                          2.10406259e-02,   2.05756389e-02,   2.02850215e-02,
                          1.99362822e-02,   1.95875429e-02,   1.90063100e-02,
                          1.86575707e-02,   1.85994469e-02,   1.81925837e-02,
                          1.77275985e-02,   1.74369812e-02,   1.71463657e-02,
                          1.67976264e-02,   1.64488871e-02,   1.62745174e-02,
                          1.59839001e-02,   1.54607911e-02,   1.52282976e-02,
                          1.48795582e-02,   1.45308180e-02,   1.42983254e-02,
                          1.41239557e-02,   1.38914622e-02,   1.35427229e-02,
                          1.33683532e-02,   1.30196130e-02,   1.25546269e-02,
                          1.25546269e-02,   1.20896408e-02,   1.16246548e-02,
                          1.16246548e-02,   1.11596687e-02,   1.08690523e-02,
                          1.07528055e-02,   1.02878194e-02,   9.99720301e-03,
                          9.88095626e-03,   9.53221694e-03,   9.06723086e-03,
                          8.60224478e-03,   8.42787419e-03,   8.07913486e-03,
                          7.73039553e-03,   7.43977912e-03,   7.14916270e-03,
                          6.97479304e-03,   6.74229953e-03,   6.39356021e-03,
                          6.10294379e-03,   5.69608063e-03,   5.46358759e-03,
                          5.23109455e-03,   4.88235475e-03,   4.53361543e-03,
                          4.18487564e-03,   4.06862935e-03,   3.83613608e-03,
                          3.54551966e-03,   3.31302662e-03,   2.90616369e-03,
                          2.67367065e-03,   2.55742413e-03,   2.15056119e-03,
                          1.91806804e-03,   1.68557488e-03,   1.51120510e-03,
                          1.33683532e-03,   9.88095650e-04,   6.97479292e-04,
                          5.81232714e-04,   4.64986195e-04,   2.32493097e-04,
                          5.81232744e-05,   5.81232744e-05,  -2.32493097e-04,
                         -4.64986195e-04,  -4.64986195e-04,  -6.39356032e-04,
                         -8.13725812e-04,  -9.29972390e-04,  -1.10434217e-03,
                         -1.22058869e-03,  -1.39495858e-03,  -1.62745162e-03,
                         -1.74369826e-03,  -1.97619130e-03,  -2.26680771e-03,
                         -2.38305423e-03,  -2.49930075e-03,  -2.78991717e-03,
                         -2.96428683e-03,  -2.96428683e-03,  -3.42927314e-03,
                         -3.77801270e-03,  -3.83613608e-03,  -4.12675226e-03,
                         -4.30112239e-03,  -4.30112239e-03,  -4.64986172e-03,
                         -4.99860151e-03,  -5.28921792e-03,  -5.57983434e-03,
                         -5.81232738e-03,  -6.04482042e-03,  -6.33543683e-03,
                         -6.56792987e-03,  -6.62605325e-03,  -6.68417662e-03,
                         -7.03291595e-03,  -7.32353237e-03,  -7.55602540e-03,
                         -7.84664229e-03,  -8.19538161e-03,  -8.42787419e-03,
                         -8.54412094e-03,  -8.71849060e-03,  -9.00910702e-03,
                         -9.18347761e-03,  -9.41597018e-03,  -9.64846369e-03,
                         -9.82283335e-03,  -9.93908010e-03,  -1.01134498e-02,
                         -1.02878194e-02,  -1.03459423e-02,  -1.05784358e-02,
                         -1.08109284e-02,  -1.08690523e-02,  -1.12759154e-02,
                         -1.15084080e-02,  -1.15084080e-02,  -1.16827777e-02,
                         -1.17990244e-02,  -1.19152712e-02,  -1.22058876e-02,
                         -1.23802572e-02,  -1.24383802e-02,  -1.24965040e-02,
                         -1.27289966e-02,  -1.29614901e-02,  -1.30777368e-02,
                         -1.31939827e-02,  -1.33683532e-02,  -1.34845991e-02,
                         -1.39495861e-02,  -1.42402016e-02,  -1.44145722e-02,
                         -1.45889418e-02,  -1.47051886e-02,  -1.49376811e-02,
                         -1.51701747e-02,  -1.53445443e-02,  -1.56351607e-02,
                         -1.57514066e-02,  -1.59257762e-02,  -1.61582697e-02,
                         -1.63326394e-02,  -1.65070090e-02,  -1.65651329e-02,
                         -1.67395025e-02,  -1.69719961e-02,  -1.70882419e-02,
                         -1.73207354e-02,  -1.76694747e-02,  -1.77275985e-02,
                         -1.77857224e-02,  -1.81925837e-02,  -1.83669552e-02,
                         -1.83669552e-02,  -1.86575707e-02,  -1.88319404e-02,
                         -1.88900642e-02,  -1.91225577e-02,  -1.92388035e-02,
                         -1.94131732e-02,  -1.97037905e-02,  -1.96456667e-02,
                         -1.97037905e-02,  -1.98781602e-02,  -2.00525299e-02,
                         -2.02268995e-02,  -2.02268995e-02,  -2.02268995e-02,
                         -2.04012692e-02,  -2.05175150e-02,  -2.04593930e-02,
                         -2.05175150e-02,  -2.07500085e-02,  -2.07500085e-02,
                         -2.07500085e-02,  -2.08662543e-02,  -2.09243782e-02,
                         -2.10987478e-02,  -2.12149955e-02,  -2.11568717e-02,
                         -2.13312414e-02,  -2.14474872e-02,  -2.13312414e-02,
                         -2.13893652e-02,  -2.15056110e-02,  -2.17381045e-02,
                         -2.19124742e-02,  -2.17962284e-02,  -2.17962284e-02,
                         -2.19705980e-02,  -2.19705980e-02,  -2.21449677e-02,
                         -2.23193374e-02,  -2.23193374e-02,  -2.24355832e-02,
                         -2.25518309e-02,  -2.27262005e-02,  -2.29005702e-02,
                         -2.29586922e-02,  -2.31911857e-02,  -2.33655553e-02,
                         -2.35399250e-02,  -2.37142947e-02,  -2.40049120e-02,
                         -2.41792817e-02,  -2.44117752e-02,  -2.46442687e-02,
                         -2.47023907e-02,  -2.50511300e-02,  -2.54579931e-02,
                         -2.55161170e-02,  -2.56904867e-02,  -2.60392260e-02,
                         -2.62717195e-02,  -2.63879653e-02,  -2.65623368e-02,
                         -2.68529523e-02,  -2.69691981e-02,  -2.72016916e-02,
                         -2.74341851e-02,  -2.75504310e-02,  -2.78410483e-02,
                         -2.81316638e-02,  -2.83060335e-02,  -2.87128966e-02,
                         -2.89453901e-02,  -2.91778836e-02,  -2.95266230e-02,
                         -2.98753623e-02,  -3.02822255e-02,  -3.05728409e-02,
                         -3.07472125e-02,  -3.12121976e-02,  -3.16771828e-02,
                         -3.22002918e-02,  -3.26652788e-02,  -3.31302658e-02,
                         -3.35371271e-02,  -3.39439921e-02,  -3.45252231e-02,
                         -3.49320881e-02,  -3.54551971e-02,  -3.61526757e-02,
                         -3.67339104e-02,  -3.73732634e-02,  -3.79544981e-02,
                         -3.84776071e-02,  -3.91169637e-02,  -3.96400727e-02,
                         -4.03375514e-02,  -4.10350300e-02,  -4.17325087e-02,
                         -4.26624827e-02,  -4.34180871e-02,  -4.42318097e-02,
                         -4.51036617e-02,  -4.58011404e-02,  -4.66148667e-02,
                         -4.73704673e-02,  -4.82423156e-02,  -4.91722897e-02,
                         -4.97535206e-02,  -5.05672470e-02,  -5.16134650e-02,
                         -5.24853170e-02,  -5.35315350e-02,  -5.42290136e-02,
                         -5.51008619e-02,  -5.61470836e-02,  -5.70770539e-02,
                         -5.80651499e-02,  -5.88788763e-02,  -5.98669723e-02,
                         -6.09131902e-02,  -6.17269166e-02,  -6.27731383e-02,
                         -6.38193563e-02,  -6.47493303e-02,  -6.57955483e-02,
                         -6.67836443e-02,  -6.80042282e-02,  -6.89923242e-02,
                         -6.98641762e-02,  -7.12010115e-02,  -7.21891075e-02,
                         -7.31772035e-02,  -7.45140389e-02,  -7.54440054e-02,
                         -7.67227188e-02,  -7.79433101e-02,  -7.88732842e-02,
                         -8.02101195e-02,  -8.13144594e-02,  -8.24769214e-02,
                         -8.38137567e-02,  -8.48018527e-02,  -8.59062001e-02,
                         -8.71267840e-02,  -8.84636194e-02,  -8.96842107e-02,
                         -9.07304287e-02,  -9.20091420e-02,  -9.32297334e-02,
                         -9.45084393e-02,  -9.56709087e-02,  -9.68333706e-02,
                         -9.82864574e-02,  -9.95070413e-02,  -1.00785755e-01,
                         -1.02296963e-01,  -1.03575677e-01,  -1.04970634e-01,
                         -1.06307469e-01,  -1.07644305e-01,  -1.09097384e-01,
                         -1.10434219e-01,  -1.11887299e-01,  -1.13398507e-01,
                         -1.14793465e-01,  -1.16188422e-01,  -1.17525257e-01,
                         -1.19036466e-01,  -1.20198928e-01,  -1.21477641e-01,
                         -1.23163216e-01,  -1.24383807e-01,  -1.25662521e-01,
                         -1.27289966e-01,  -1.28568679e-01,  -1.29963636e-01,
                         -1.31416723e-01,  -1.32753551e-01,  -1.34090394e-01,
                         -1.35369107e-01,  -1.36822179e-01,  -1.38217151e-01,
                         -1.39437735e-01,  -1.40890822e-01,  -1.42111406e-01,
                         -1.43215746e-01,  -1.44552574e-01,  -1.45773172e-01,
                         -1.46993756e-01,  -1.48330599e-01,  -1.49493054e-01,
                         -1.50597408e-01,  -1.51992366e-01,  -1.53212950e-01,
                         -1.54433534e-01,  -1.55886620e-01,  -1.57049090e-01,
                         -1.58153430e-01,  -1.59548387e-01,  -1.60652727e-01,
                         -1.61640823e-01,  -1.62687048e-01,  -1.63791388e-01,
                         -1.64953843e-01,  -1.66058198e-01,  -1.67046294e-01,
                         -1.67976260e-01,  -1.69080600e-01,  -1.70243070e-01,
                         -1.71114922e-01,  -1.71928644e-01,  -1.72858611e-01,
                         -1.73846707e-01,  -1.74951047e-01,  -1.75706655e-01,
                         -1.76462263e-01,  -1.77392229e-01,  -1.78089708e-01,
                         -1.78903431e-01,  -1.79659039e-01,  -1.80356517e-01,
                         -1.81170240e-01,  -1.81809604e-01,  -1.82448953e-01,
                         -1.83204561e-01,  -1.83669537e-01,  -1.84250772e-01,
                         -1.84773892e-01,  -1.85180753e-01,  -1.85703859e-01,
                         -1.86226964e-01,  -1.86750084e-01,  -1.87040687e-01,
                         -1.87447563e-01,  -1.88086912e-01,  -1.88319400e-01,
                         -1.88435659e-01,  -1.88842520e-01,  -1.89133137e-01,
                         -1.89423755e-01,  -1.89656243e-01,  -1.89772487e-01,
                         -1.89830616e-01,  -1.89946860e-01,  -1.90179348e-01,
                         -1.90121233e-01,  -1.90179348e-01,  -1.90411851e-01,
                         -1.90295592e-01,  -1.90179348e-01,  -1.90179348e-01,
                         -1.90237477e-01,  -1.90121233e-01,  -1.89946860e-01,
                         -1.89888731e-01,  -1.89772487e-01,  -1.89423755e-01,
                         -1.89191252e-01,  -1.88842520e-01,  -1.88493773e-01,
                         -1.88203156e-01,  -1.87738180e-01,  -1.87273189e-01,
                         -1.86633825e-01,  -1.86052606e-01,  -1.85820103e-01,
                         -1.85180753e-01,  -1.84599519e-01,  -1.84134528e-01,
                         -1.83378935e-01,  -1.82681441e-01,  -1.82042092e-01,
                         -1.81344613e-01,  -1.80589005e-01,  -1.79659039e-01,
                         -1.78729072e-01,  -1.77799091e-01,  -1.77101612e-01,
                         -1.76229760e-01,  -1.75009176e-01,  -1.74137324e-01,
                         -1.73032984e-01,  -1.71812400e-01,  -1.70940548e-01,
                         -1.69778079e-01,  -1.68557495e-01,  -1.67278782e-01,
                         -1.66000068e-01,  -1.64895728e-01,  -1.63500771e-01,
                         -1.61989570e-01,  -1.60594597e-01,  -1.59141526e-01,
                         -1.57572195e-01,  -1.55944750e-01,  -1.54491663e-01,
                         -1.52922332e-01,  -1.51236758e-01,  -1.49609312e-01,
                         -1.47749364e-01,  -1.45947546e-01,  -1.44203842e-01,
                         -1.42285779e-01,  -1.40425831e-01,  -1.38333395e-01,
                         -1.36415318e-01,  -1.34497255e-01,  -1.32346690e-01,
                         -1.30370498e-01,  -1.28161818e-01,  -1.25953138e-01,
                         -1.23802572e-01,  -1.21419519e-01,  -1.19094588e-01,
                         -1.16827779e-01,  -1.14444725e-01,  -1.12003550e-01,
                         -1.09446123e-01,  -1.06830575e-01,  -1.04215026e-01,
                         -1.01541355e-01,  -9.88676846e-02,  -9.62521434e-02,
                         -9.36947167e-02,  -9.07885507e-02,  -8.80567580e-02,
                         -8.54993388e-02,  -8.24769214e-02,  -7.95707628e-02,
                         -7.67808408e-02,  -7.37003088e-02,  -7.07360208e-02,
                         -6.78879842e-02,  -6.47493303e-02,  -6.17269166e-02,
                         -5.87045066e-02,  -5.53333573e-02,  -5.22528216e-02,
                         -4.89979200e-02,  -4.56848927e-02,  -4.24881130e-02,
                         -3.91750857e-02,  -3.58620584e-02,  -3.24909091e-02,
                         -2.89453901e-02,  -2.54579931e-02,  -2.20868438e-02,
                         -1.83669552e-02,  -1.47051886e-02,  -1.12177916e-02,
                         -7.67227216e-03,  -4.18487564e-03,  -5.81232714e-04,
                          3.19678010e-03,   6.91666966e-03,   1.06946826e-02,
                          1.44726951e-02,   1.80763379e-02,   2.18543503e-02,
                          2.58067325e-02,   2.97009926e-02,   3.35371271e-02,
                          3.71988937e-02,   4.12675254e-02,   4.53361534e-02,
                          4.91141677e-02,   5.31246737e-02,   5.71351759e-02,
                          6.10875599e-02,   6.50399402e-02,   6.91085756e-02,
                          7.32934475e-02,   7.74783269e-02,   8.14307034e-02,
                          8.55574608e-02,   8.96842107e-02,   9.38690901e-02,
                          9.82864574e-02,   1.02529451e-01,   1.06772453e-01,
                          1.11073576e-01,   1.15258448e-01,   1.19617693e-01,
                          1.23918816e-01,   1.28336191e-01,   1.32811680e-01,
                          1.36996552e-01,   1.41297683e-01,   1.45831287e-01,
                          1.50190532e-01,   1.54666036e-01,   1.59025282e-01,
                          1.63384527e-01,   1.68092504e-01,   1.72684252e-01,
                          1.77101612e-01,   1.81518987e-01,   1.86110720e-01,
                          1.90760583e-01,   1.95468575e-01,   2.00234681e-01,
                          2.05000788e-01,   2.09650651e-01,   2.14358628e-01,
                          2.19182864e-01,   2.23832726e-01,   2.28308216e-01,
                          2.33016208e-01,   2.37724185e-01,   2.42432177e-01,
                          2.47314528e-01,   2.52080649e-01,   2.56788611e-01,
                          2.61554718e-01,   2.66378969e-01,   2.71203190e-01,
                          2.75794923e-01,   2.80561030e-01,   2.85385281e-01,
                          2.90093243e-01,   2.94975609e-01,   2.99683601e-01,
                          3.04391593e-01,   3.09215814e-01,   3.13981920e-01,
                          3.18748027e-01,   3.23514134e-01,   3.28338385e-01,
                          3.33046347e-01,   3.37638110e-01,   3.42346072e-01,
                          3.47054064e-01,   3.51703942e-01,   3.56528163e-01,
                          3.61178011e-01,   3.65944117e-01,   3.70710224e-01,
                          3.75418216e-01,   3.79951835e-01,   3.84427339e-01,
                          3.89193445e-01,   3.93785179e-01,   3.98493171e-01,
                          4.03317392e-01,   4.07676637e-01,   4.12093997e-01,
                          4.16743875e-01,   4.21393722e-01,   4.26043600e-01,
                          4.30344731e-01,   4.34878320e-01,   4.39528197e-01,
                          4.43771183e-01,   4.48188573e-01,   4.52605933e-01,
                          4.57081407e-01,   4.61789399e-01,   4.65799928e-01,
                          4.69984800e-01,   4.74518418e-01,   4.78819519e-01,
                          4.83120650e-01,   4.87189263e-01,   4.91083533e-01,
                          4.95094031e-01,   4.99104559e-01,   5.03173172e-01,
                          5.07125556e-01,   5.11019826e-01,   5.14972210e-01,
                          5.18692076e-01,   5.22412002e-01,   5.26131868e-01,
                          5.29851735e-01,   5.33629775e-01,   5.37000895e-01,
                          5.40488303e-01,   5.43859482e-01,   5.47172487e-01,
                          5.50718009e-01,   5.54147303e-01,   5.57344079e-01,
                          5.60482740e-01,   5.63679516e-01,   5.66643775e-01,
                          5.69666207e-01,   5.72862983e-01,   5.75711012e-01,
                          5.78442812e-01,   5.81290841e-01,   5.83906412e-01,
                          5.86696327e-01,   5.89428127e-01,   5.91811180e-01,
                          5.94310462e-01,   5.96519172e-01,   5.98669708e-01,
                          6.01052761e-01,   6.03087068e-01,   6.05353892e-01,
                          6.07388198e-01,   6.09190047e-01,   6.11166239e-01,
                          6.12968028e-01,   6.14653587e-01,   6.16397321e-01,
                          6.17966652e-01,   6.19419754e-01,   6.20756567e-01,
                          6.22035265e-01,   6.23255849e-01,   6.24476433e-01,
                          6.25871420e-01,   6.26801372e-01,   6.27498865e-01,
                          6.28428817e-01,   6.29300654e-01,   6.29940033e-01,
                          6.30463123e-01,   6.31160617e-01,   6.31741881e-01,
                          6.32032454e-01,   6.32323086e-01,   6.32555604e-01,
                          6.32788062e-01,   6.32788062e-01,   6.32613719e-01,
                          6.32323086e-01,   6.32090569e-01,   6.31858110e-01,
                          6.31509364e-01,   6.30928159e-01,   6.30463123e-01,
                          6.29881918e-01,   6.28951967e-01,   6.28254473e-01,
                          6.27382636e-01,   6.26220167e-01,   6.25173926e-01,
                          6.24069571e-01,   6.22732759e-01,   6.21512175e-01,
                          6.20465934e-01,   6.18896604e-01,   6.17152929e-01,
                          6.15525484e-01,   6.13781750e-01,   6.11979961e-01,
                          6.10236228e-01,   6.08318150e-01,   6.06051385e-01,
                          6.03958905e-01,   6.01634026e-01,   5.99425316e-01,
                          5.96984148e-01,   5.94368577e-01,   5.91927409e-01,
                          5.89195609e-01,   5.86231351e-01,   5.83441436e-01,
                          5.80651522e-01,   5.77687204e-01,   5.74606657e-01,
                          5.71642399e-01,   5.68387508e-01,   5.64783871e-01,
                          5.61645210e-01,   5.58274031e-01,   5.54554164e-01,
                          5.51124871e-01,   5.47230601e-01,   5.43452621e-01,
                          5.39790869e-01,   5.35838485e-01,   5.31886101e-01,
                          5.27643085e-01,   5.23516297e-01,   5.19622087e-01,
                          5.15088439e-01,   5.10671079e-01,   5.06486177e-01,
                          5.01778245e-01,   4.97302741e-01,   4.92769122e-01,
                          4.87944871e-01,   4.83062536e-01,   4.78354543e-01,
                          4.73530322e-01,   4.68241096e-01,   4.63126242e-01,
                          4.58069503e-01,   4.52780306e-01,   4.47374821e-01,
                          4.42027479e-01,   4.36622024e-01,   4.30984080e-01,
                          4.25404251e-01,   4.19766277e-01,   4.13953960e-01,
                          4.08025384e-01,   4.02213067e-01,   3.96342605e-01,
                          3.90181541e-01,   3.84020478e-01,   3.78150016e-01,
                          3.71988952e-01,   3.65537256e-01,   3.59376192e-01,
                          3.53040755e-01,   3.46589088e-01,   3.40137392e-01,
                          3.33453208e-01,   3.26769054e-01,   3.20084870e-01,
                          3.13284457e-01,   3.06367785e-01,   2.99683601e-01,
                          2.92825043e-01,   2.85908371e-01,   2.79107958e-01,
                          2.72191286e-01,   2.65042126e-01,   2.58009225e-01,
                          2.50976294e-01,   2.43827134e-01,   2.36561716e-01,
                          2.29296312e-01,   2.21972778e-01,   2.14649245e-01,
                          2.07325712e-01,   1.99944064e-01,   1.92562401e-01,
                          1.85296997e-01,   1.77682847e-01,   1.69952452e-01,
                          1.62512675e-01,   1.55131012e-01,   1.47458747e-01,
                          1.39844596e-01,   1.32172316e-01,   1.24383807e-01,
                          1.16769657e-01,   1.08923018e-01,   1.01192616e-01,
                          9.34040993e-02,   8.53830874e-02,   7.75364488e-02,
                          6.96898028e-02,   6.17850386e-02,   5.38221523e-02,
                          4.58592623e-02,   3.79544981e-02,   2.98172385e-02,
                          2.17962284e-02,   1.38333393e-02,   5.52171096e-03,
                         -2.44117738e-03,  -1.04621891e-02,  -1.85994469e-02,
                         -2.66204588e-02,  -3.48158404e-02,  -4.28949744e-02,
                         -5.10322340e-02,  -5.91113679e-02,  -6.73067495e-02,
                         -7.56183788e-02,  -8.36975127e-02,  -9.18347687e-02,
                         -1.00088276e-01,  -1.08283661e-01,  -1.16653413e-01,
                         -1.24848790e-01,  -1.32986054e-01,  -1.41297683e-01,
                         -1.49376810e-01,  -1.57630324e-01,  -1.66058198e-01,
                         -1.74486071e-01,  -1.82739571e-01,  -1.90934956e-01,
                         -1.99246585e-01,  -2.07383841e-01,  -2.15753585e-01,
                         -2.24181458e-01,  -2.32144356e-01,  -2.40339741e-01,
                         -2.48709485e-01,  -2.57021129e-01,  -2.65332729e-01,
                         -2.73586243e-01,  -2.81723499e-01,  -2.90035129e-01,
                         -2.98172385e-01,  -3.06425899e-01,  -3.14621270e-01,
                         -3.22700411e-01,  -3.31012040e-01,  -3.39091182e-01,
                         -3.47170323e-01,  -3.55423808e-01,  -3.63619208e-01,
                         -3.71698320e-01,  -3.79951835e-01,  -3.88089091e-01,
                         -3.95993859e-01,  -4.04073000e-01,  -4.12210256e-01,
                         -4.20405626e-01,  -4.28368539e-01,  -4.36273277e-01,
                         -4.44061816e-01,  -4.52024698e-01,  -4.59929466e-01,
                         -4.67776090e-01,  -4.75797117e-01,  -4.83759999e-01,
                         -4.91548508e-01,  -4.99162674e-01,  -5.06893039e-01,
                         -5.14855981e-01,  -5.22644460e-01,  -5.30200481e-01,
                         -5.37872791e-01,  -5.45545042e-01,  -5.53217292e-01,
                         -5.60773313e-01,  -5.68213105e-01,  -5.75885415e-01,
                         -5.83441436e-01,  -5.90881169e-01,  -5.98204732e-01,
                         -6.05470121e-01,  -6.12851799e-01,  -6.19884729e-01,
                         -6.27092004e-01,  -6.34357393e-01,  -6.41332209e-01,
                         -6.48539484e-01,  -6.55572414e-01,  -6.62314713e-01,
                         -6.69347644e-01,  -6.76264286e-01,  -6.82890356e-01,
                         -6.89574540e-01,  -6.96200550e-01,  -7.02884734e-01,
                         -7.09568918e-01,  -7.15904355e-01,  -7.22123563e-01,
                         -7.28575230e-01,  -7.34968781e-01,  -7.41013587e-01,
                         -7.47465312e-01,  -7.53684461e-01,  -7.59496808e-01,
                         -7.65716016e-01,  -7.71818936e-01,  -7.77573168e-01,
                         -7.83385456e-01,  -7.89314032e-01,  -7.94835746e-01,
                         -8.00357461e-01,  -8.06053579e-01,  -8.11459005e-01,
                         -8.16980720e-01,  -8.22328091e-01,  -8.27384770e-01,
                         -8.32848370e-01,  -8.38195741e-01,  -8.42903733e-01,
                         -8.48076701e-01,  -8.53191555e-01,  -8.58190119e-01,
                         -8.63188744e-01,  -8.67954850e-01,  -8.72953415e-01,
                         -8.77603292e-01,  -8.82253170e-01,  -8.86844933e-01,
                         -8.91436636e-01,  -8.96144629e-01,  -9.00329530e-01,
                         -9.04572487e-01,  -9.09048021e-01,  -9.13000405e-01,
                         -9.17127132e-01,  -9.21253860e-01,  -9.24857497e-01,
                         -9.28635538e-01,  -9.32297289e-01,  -9.35900927e-01,
                         -9.39272106e-01,  -9.42468882e-01,  -9.45956290e-01,
                         -9.48920548e-01,  -9.52001095e-01,  -9.55255985e-01,
                         -9.58104014e-01,  -9.60893929e-01,  -9.63451385e-01,
                         -9.66183186e-01,  -9.68856871e-01,  -9.71239924e-01,
                         -9.73681092e-01,  -9.75889742e-01,  -9.77924049e-01,
                         -9.80307102e-01,  -9.82108951e-01,  -9.83736396e-01,
                         -9.85712588e-01,  -9.87398148e-01,  -9.89025593e-01,
                         -9.90246236e-01,  -9.91699278e-01,  -9.92861748e-01,
                         -9.93907988e-01,  -9.95128572e-01,  -9.95884180e-01,
                         -9.96697903e-01,  -9.97453511e-01,  -9.98092830e-01,
                         -9.98674095e-01,  -9.99197185e-01,  -9.99487817e-01,
                         -9.99720275e-01,  -9.99487817e-01,  -9.99662161e-01,
                         -9.99952793e-01,  -9.99429703e-01,  -9.99255300e-01,
                         -9.98906553e-01,  -9.98209119e-01,  -9.97744083e-01,
                         -9.97337222e-01,  -9.96465385e-01,  -9.95651662e-01,
                         -9.94954169e-01,  -9.93733585e-01,  -9.92454886e-01,
                         -9.91234303e-01,  -9.89897490e-01,  -9.88618731e-01,
                         -9.87107575e-01,  -9.85363841e-01,  -9.83736396e-01,
                         -9.81760204e-01,  -9.79725897e-01,  -9.78098452e-01,
                         -9.75831628e-01,  -9.73564804e-01,  -9.71181750e-01,
                         -9.68624353e-01,  -9.66125071e-01,  -9.63625729e-01,
                         -9.61126447e-01,  -9.58278418e-01,  -9.55197871e-01,
                         -9.52233613e-01,  -9.49036837e-01,  -9.45723772e-01,
                         -9.42526996e-01,  -9.39097703e-01,  -9.35726583e-01,
                         -9.32006717e-01,  -9.27821815e-01,  -9.24101949e-01,
                         -9.20265794e-01,  -9.16139007e-01,  -9.12012279e-01,
                         -9.07653034e-01,  -9.03351903e-01,  -8.98876429e-01,
                         -8.94342780e-01,  -8.89809191e-01,  -8.85043085e-01,
                         -8.80160749e-01,  -8.75278354e-01,  -8.70047271e-01,
                         -8.64990532e-01,  -8.59817564e-01,  -8.54237735e-01,
                         -8.48774135e-01,  -8.43310595e-01,  -8.37730765e-01,
                         -8.32150877e-01,  -8.26571047e-01,  -8.20700645e-01,
                         -8.14655781e-01,  -8.08610976e-01,  -8.02449942e-01,
                         -7.96114504e-01,  -7.89895296e-01,  -7.83617973e-01,
                         -7.76991904e-01,  -7.70365894e-01,  -7.63681710e-01,
                         -7.56765008e-01,  -7.49964595e-01,  -7.43047953e-01,
                         -7.35898793e-01,  -7.28691459e-01,  -7.21542299e-01,
                         -7.14218795e-01,  -7.06837118e-01,  -6.99222982e-01,
                         -6.91550732e-01,  -6.83936536e-01,  -6.76031768e-01,
                         -6.68127000e-01,  -6.60222292e-01,  -6.52201235e-01,
                         -6.44005895e-01,  -6.35694265e-01,  -6.27324462e-01,
                         -6.19187236e-01,  -6.10759377e-01,  -6.02273345e-01,
                         -5.93845487e-01,  -5.85301340e-01,  -5.76931596e-01,
                         -5.68503737e-01,  -5.60133994e-01,  -5.51589847e-01,
                         -5.42871356e-01,  -5.34327269e-01,  -5.25666893e-01,
                         -5.17064631e-01,  -5.08288026e-01,  -4.99453276e-01,
                         -4.90676671e-01,  -4.81783807e-01,  -4.72890943e-01,
                         -4.64114338e-01,  -4.55163360e-01,  -4.46270496e-01,
                         -4.37377632e-01,  -4.28426653e-01,  -4.19475675e-01,
                         -4.10175949e-01,  -4.01166826e-01,  -3.92215848e-01,
                         -3.82858008e-01,  -3.73907030e-01,  -3.64897907e-01,
                         -3.55656296e-01,  -3.46472830e-01,  -3.37231219e-01,
                         -3.28047752e-01,  -3.18806142e-01,  -3.09622675e-01,
                         -3.00206721e-01,  -2.90616363e-01,  -2.81491011e-01,
                         -2.72191286e-01,  -2.62659073e-01,  -2.53533721e-01,
                         -2.44059622e-01,  -2.34585539e-01,  -2.25169554e-01,
                         -2.15521097e-01,  -2.06163257e-01,  -1.96805403e-01,
                         -1.87331304e-01,  -1.77799091e-01,  -1.68383121e-01,
                         -1.58792779e-01,  -1.49202436e-01,  -1.39786467e-01,
                         -1.30196139e-01,  -1.20547667e-01,  -1.11131698e-01,
                         -1.01657607e-01,  -9.20672640e-02,  -8.25931728e-02,
                         -7.30028301e-02,  -6.35868609e-02,  -5.41708916e-02,
                         -4.46386747e-02,  -3.52808274e-02,  -2.57486105e-02,
                         -1.64488871e-02,  -7.20728608e-03,   2.32493086e-03,
                          1.16827777e-02,   2.08662543e-02,   2.99916100e-02,
                          3.90588380e-02,   4.81260717e-02,   5.72514236e-02,
                          6.62024096e-02,   7.51533955e-02,   8.41043741e-02,
                          9.30553600e-02,   1.01831973e-01,   1.10666715e-01,
                          1.19385205e-01,   1.27987444e-01,   1.36764064e-01,
                          1.45191938e-01,   1.53677940e-01,   1.62280172e-01,
                          1.70708060e-01,   1.79135934e-01,   1.87563807e-01,
                          1.95875436e-01,   2.04128936e-01,   2.12208077e-01,
                          2.20345333e-01,   2.28482589e-01,   2.36503601e-01,
                          2.44524613e-01,   2.52487510e-01,   2.60508507e-01,
                          2.68471390e-01,   2.76376158e-01,   2.84106553e-01,
                          2.91662574e-01,   2.99509227e-01,   3.07123363e-01,
                          3.14621270e-01,   3.22409809e-01,   3.29849571e-01,
                          3.37231219e-01,   3.44787270e-01,   3.51878285e-01,
                          3.59201819e-01,   3.66583496e-01,   3.73442024e-01,
                          3.80707443e-01,   3.87914717e-01,   3.94715160e-01,
                          4.01631832e-01,   4.08548474e-01,   4.15407032e-01,
                          4.21974957e-01,   4.28484768e-01,   4.35168952e-01,
                          4.41446275e-01,   4.47839826e-01,   4.54117149e-01,
                          4.60045695e-01,   4.66264904e-01,   4.72309709e-01,
                          4.78180170e-01,   4.84225005e-01,   4.90037322e-01,
                          4.95617151e-01,   5.01196980e-01,   5.06834924e-01,
                          5.12298524e-01,   5.17704010e-01,   5.22876978e-01,
                          5.27933717e-01,   5.33164799e-01,   5.38221538e-01,
                          5.42929471e-01,   5.47753751e-01,   5.52519858e-01,
                          5.57053447e-01,   5.61528921e-01,   5.65830052e-01,
                          5.70421815e-01,   5.74781060e-01,   5.78907788e-01,
                          5.83208919e-01,   5.87219417e-01,   5.91113687e-01,
                          5.94949841e-01,   5.98553479e-01,   6.02215230e-01,
                          6.05935097e-01,   6.09538794e-01,   6.12909913e-01,
                          6.16222918e-01,   6.19768441e-01,   6.22848988e-01,
                          6.25987649e-01,   6.29242539e-01,   6.31974339e-01,
                          6.34822369e-01,   6.37786686e-01,   6.40518486e-01,
                          6.43133998e-01,   6.45517051e-01,   6.47958279e-01,
                          6.50108814e-01,   6.52201235e-01,   6.54816806e-01,
                          6.56909227e-01,   6.58827305e-01,   6.61036015e-01,
                          6.62837803e-01,   6.64523363e-01,   6.66208982e-01,
                          6.67836428e-01,   6.69405758e-01,   6.70800686e-01,
                          6.72137558e-01,   6.73241854e-01,   6.74229980e-01,
                          6.75566792e-01,   6.76613033e-01,   6.77426755e-01,
                          6.78124249e-01,   6.78937972e-01,   6.79519176e-01,
                          6.79984152e-01,   6.80565417e-01,   6.80797875e-01,
                          6.80914164e-01,   6.81204736e-01,   6.81204736e-01,
                          6.81204736e-01,   6.81262910e-01,   6.81146622e-01,
                          6.80914164e-01,   6.80507302e-01,   6.80100441e-01,
                          6.79693580e-01,   6.79054201e-01,   6.78589225e-01,
                          6.77891731e-01,   6.76729262e-01,   6.75973654e-01,
                          6.75159931e-01,   6.73997462e-01,   6.72834992e-01,
                          6.71730697e-01,   6.70393825e-01,   6.69173241e-01,
                          6.67778313e-01,   6.66325212e-01,   6.64813995e-01,
                          6.63244665e-01,   6.61675334e-01,   6.59989774e-01,
                          6.58304214e-01,   6.56676769e-01,   6.54816806e-01,
                          6.52608097e-01,   6.50631905e-01,   6.48597598e-01,
                          6.46214545e-01,   6.44005895e-01,   6.41797185e-01,
                          6.39530361e-01,   6.36972964e-01,   6.34473681e-01,
                          6.31974339e-01,   6.29300654e-01,   6.26627028e-01,
                          6.23895228e-01,   6.20872796e-01,   6.18140996e-01,
                          6.15292966e-01,   6.12096190e-01,   6.09306276e-01,
                          6.06225729e-01,   6.02854609e-01,   5.99774063e-01,
                          5.96461058e-01,   5.92973650e-01,   5.89428127e-01,
                          5.85940719e-01,   5.82569540e-01,   5.79024076e-01,
                          5.75362265e-01,   5.71642399e-01,   5.67748129e-01,
                          5.63911974e-01,   5.60250223e-01,   5.56355953e-01,
                          5.52345455e-01,   5.48276842e-01,   5.44266343e-01,
                          5.40197730e-01,   5.36187172e-01,   5.31827927e-01,
                          5.27468681e-01,   5.23632586e-01,   5.19389570e-01,
                          5.15088439e-01,   5.10729194e-01,   5.06195605e-01,
                          5.01952589e-01,   4.97593343e-01,   4.93175983e-01,
                          4.88642365e-01,   4.83934373e-01,   4.79633242e-01,
                          4.75332141e-01,   4.70682263e-01,   4.66148645e-01,
                          4.61615026e-01,   4.57139552e-01,   4.52664047e-01,
                          4.48014200e-01,   4.43422467e-01,   4.38714474e-01,
                          4.34238970e-01,   4.29589123e-01,   4.24764872e-01,
                          4.20173138e-01,   4.15465146e-01,   4.10757184e-01,
                          4.06223565e-01,   4.01457459e-01,   3.96691352e-01,
                          3.92041475e-01,   3.87333483e-01,   3.82567376e-01,
                          3.77626896e-01,   3.72918934e-01,   3.68269056e-01,
                          3.63444835e-01,   3.58620584e-01,   3.53796363e-01,
                          3.49088371e-01,   3.44438523e-01,   3.39498043e-01,
                          3.34848166e-01,   3.30140203e-01,   3.25199723e-01,
                          3.20317358e-01,   3.15551251e-01,   3.10901403e-01,
                          3.06193411e-01,   3.01311046e-01,   2.96486825e-01,
                          2.91836947e-01,   2.87361473e-01,   2.82711595e-01,
                          2.77771115e-01,   2.73063153e-01,   2.68471390e-01,
                          2.63879657e-01,   2.59287924e-01,   2.54696190e-01,
                          2.50162572e-01,   2.45687082e-01,   2.41095334e-01,
                          2.36677974e-01,   2.32376844e-01,   2.27959484e-01,
                          2.23483980e-01,   2.19124734e-01,   2.14823619e-01,
                          2.10464373e-01,   2.06337616e-01,   2.02094615e-01,
                          1.97793499e-01,   1.93783000e-01,   1.89598113e-01,
                          1.85471371e-01,   1.81460857e-01,   1.77508473e-01,
                          1.73672348e-01,   1.69719964e-01,   1.65593207e-01,
                          1.61757067e-01,   1.57920927e-01,   1.54026672e-01,
                          1.50132418e-01,   1.46528766e-01,   1.42925128e-01,
                          1.39030874e-01,   1.35369107e-01,   1.31881714e-01,
                          1.28219947e-01,   1.24732547e-01,   1.21187024e-01,
                          1.17757753e-01,   1.14212230e-01,   1.10550463e-01,
                          1.07237436e-01,   1.03924416e-01,   1.00495137e-01,
                          9.72402394e-02,   9.38690901e-02,   9.05560628e-02,
                          8.73011574e-02,   8.40462521e-02,   8.10819641e-02,
                          7.79433101e-02,   7.47465268e-02,   7.17241168e-02,
                          6.87598288e-02,   6.58536702e-02,   6.30056262e-02,
                          6.02157116e-02,   5.73095493e-02,   5.44033833e-02,
                          5.18459603e-02,   4.91722897e-02,   4.64986190e-02,
                          4.40574400e-02,   4.15000170e-02,   3.90588380e-02,
                          3.66757847e-02,   3.44089791e-02,   3.23165394e-02,
                          2.98172385e-02,   2.75504310e-02,   2.55161170e-02,
                          2.34236792e-02,   2.15056110e-02,   1.94131732e-02,
                          1.74951050e-02,   1.57514066e-02,   1.38333393e-02,
                          1.20896408e-02,   1.03459423e-02,   8.60224478e-03,
                          7.03291595e-03,   5.52171096e-03,   3.89425922e-03,
                          2.26680771e-03,   9.29972390e-04,  -4.06862906e-04,
                         -2.03431468e-03,  -3.25490325e-03,  -4.35924530e-03,
                         -5.63795771e-03,  -6.74229953e-03,  -8.07913486e-03,
                         -9.29972343e-03,  -1.02878194e-02,  -1.13921613e-02,
                         -1.23802572e-02,  -1.32521065e-02,  -1.42402016e-02,
                         -1.51701747e-02,  -1.59839001e-02,  -1.66813787e-02,
                         -1.73788592e-02,  -1.81344617e-02,  -1.87156945e-02,
                         -1.92969274e-02,  -1.99362822e-02,  -2.04593930e-02,
                         -2.09243782e-02,  -2.16218568e-02,  -2.20868438e-02,
                         -2.22612135e-02,  -2.24937070e-02,  -2.27843225e-02,
                         -2.31330637e-02,  -2.33074334e-02,  -2.33074334e-02,
                         -2.33655553e-02,  -2.33655553e-02,  -2.33655553e-02,
                         -2.34818030e-02,  -2.33655553e-02,  -2.30168160e-02,
                         -2.27262005e-02,  -2.23193374e-02,  -2.18543503e-02,
                         -2.15637349e-02,  -2.10987478e-02,  -2.05756389e-02,
                         -1.99362822e-02,  -1.92969274e-02,  -1.85994469e-02,
                         -1.77857224e-02,  -1.69719961e-02,  -1.61001459e-02,
                         -1.51701747e-02,  -1.42402016e-02,  -1.31358597e-02,
                         -1.20896408e-02,  -1.09852990e-02,  -9.76470951e-03,
                         -8.54412094e-03,  -7.09103933e-03,  -5.75420400e-03,
                         -4.41736868e-03,  -2.90616369e-03,  -1.45308184e-03,
                         -5.81232744e-05,   1.45308184e-03,   3.13865673e-03,
                          4.82423184e-03,   6.50980650e-03,   8.31162836e-03,
                          1.00553259e-02,   1.19152712e-02,   1.37752155e-02,
                          1.55189140e-02,   1.76694747e-02,   1.97619125e-02,
                          2.15637349e-02,   2.37724185e-02,   2.59811040e-02,
                          2.80735418e-02,   3.02822255e-02,   3.25490348e-02,
                          3.48739624e-02,   3.72570194e-02,   3.96981947e-02,
                          4.21393737e-02,   4.45805490e-02,   4.70798500e-02,
                          4.96372767e-02,   5.21365777e-02,   5.48683703e-02,
                          5.76001629e-02,   6.02157116e-02,   6.30637482e-02,
                          6.59699142e-02,   6.89342022e-02,   7.17822462e-02,
                          7.45721608e-02,   7.75945708e-02,   8.07332247e-02,
                          8.38718861e-02,   8.68361741e-02,   8.99748281e-02,
                          9.31134820e-02,   9.63683873e-02,   9.97395366e-02,
                          1.02936320e-01,   1.06191218e-01,   1.09736741e-01,
                          1.12991646e-01,   1.16362795e-01,   1.19908310e-01,
                          1.23279460e-01,   1.26766860e-01,   1.30370498e-01,
                          1.34032264e-01,   1.37519658e-01,   1.41007066e-01,
                          1.44610703e-01,   1.47981852e-01,   1.51759863e-01,
                          1.55479759e-01,   1.58850908e-01,   1.62687048e-01,
                          1.66290686e-01,   1.69719964e-01,   1.73556089e-01,
                          1.77043498e-01,   1.80589005e-01,   1.84483275e-01,
                          1.87970668e-01,   1.91632435e-01,   1.95294201e-01,
                          1.98781595e-01,   2.02385232e-01,   2.05988884e-01,
                          2.09592521e-01,   2.13138044e-01,   2.16683567e-01,
                          2.20112830e-01,   2.23600239e-01,   2.27378249e-01,
                          2.30749398e-01,   2.34236792e-01,   2.37956688e-01,
                          2.41444081e-01,   2.44989604e-01,   2.48418868e-01,
                          2.51790017e-01,   2.55393654e-01,   2.58822948e-01,
                          2.62252212e-01,   2.65913963e-01,   2.69226998e-01,
                          2.72540033e-01,   2.75911182e-01,   2.79282331e-01,
                          2.82653481e-01,   2.85908371e-01,   2.89279521e-01,
                          2.92592555e-01,   2.95905590e-01,   2.99102366e-01,
                          3.02241027e-01,   3.05554062e-01,   3.08750838e-01,
                          3.11889499e-01,   3.15144390e-01,   3.18166792e-01,
                          3.21247339e-01,   3.24269742e-01,   3.27175915e-01,
                          3.30314577e-01,   3.33278835e-01,   3.36126894e-01,
                          3.39033067e-01,   3.41881096e-01,   3.44729125e-01,
                          3.47402811e-01,   3.50018352e-01,   3.52750152e-01,
                          3.55365694e-01,   3.57981235e-01,   3.60654920e-01,
                          3.63212347e-01,   3.65595400e-01,   3.67978454e-01,
                          3.70652109e-01,   3.72918934e-01,   3.74953240e-01,
                          3.77510667e-01,   3.79719347e-01,   3.81695539e-01,
                          3.83846104e-01,   3.85880411e-01,   3.87856603e-01,
                          3.89774680e-01,   3.91692728e-01,   3.93552691e-01,
                          3.95296395e-01,   3.97156328e-01,   3.98783773e-01,
                          4.00353104e-01,   4.02213067e-01,   4.03782368e-01,
                          4.05177325e-01,   4.06746656e-01,   4.08199757e-01,
                          4.09536570e-01,   4.11047786e-01,   4.12384629e-01,
                          4.13430840e-01,   4.14593309e-01,   4.15755779e-01,
                          4.16860104e-01,   4.18022573e-01,   4.19010669e-01,
                          4.20056909e-01,   4.21103120e-01,   4.21916842e-01,
                          4.22846824e-01,   4.23718661e-01,   4.24416155e-01,
                          4.25171733e-01,   4.25636739e-01,   4.26043600e-01,
                          4.26799208e-01,   4.27322298e-01,   4.27729160e-01,
                          4.28136021e-01,   4.28368539e-01,   4.28601027e-01,
                          4.28891629e-01,   4.29240376e-01,   4.29414749e-01,
                          4.29472864e-01,   4.29414749e-01,   4.29066002e-01,
                          4.29007888e-01,   4.29124117e-01,   4.28775400e-01,
                          4.28484768e-01,   4.28077906e-01,   4.27380443e-01,
                          4.27031696e-01,   4.26624835e-01,   4.25985485e-01,
                          4.25346106e-01,   4.24590498e-01,   4.23834920e-01,
                          4.23253685e-01,   4.22381818e-01,   4.21335608e-01,
                          4.20463771e-01,   4.19533789e-01,   4.18371320e-01,
                          4.17266965e-01,   4.16104525e-01,   4.14825797e-01,
                          4.13547099e-01,   4.12210256e-01,   4.10989672e-01,
                          4.09594715e-01,   4.07967269e-01,   4.06514168e-01,
                          4.04886723e-01,   4.03143018e-01,   4.01399314e-01,
                          3.99539381e-01,   3.97795677e-01,   3.95877630e-01,
                          3.93959552e-01,   3.92273962e-01,   3.90239656e-01,
                          3.88205349e-01,   3.86345387e-01,   3.84252965e-01,
                          3.81986141e-01,   3.79777461e-01,   3.77568781e-01,
                          3.75243843e-01,   3.72802675e-01,   3.70419621e-01,
                          3.67862195e-01,   3.65362883e-01,   3.62921715e-01,
                          3.60364288e-01,   3.57806861e-01,   3.55016947e-01,
                          3.52110803e-01,   3.49379003e-01,   3.46472830e-01,
                          3.43566656e-01,   3.40718627e-01,   3.37579966e-01,
                          3.34499449e-01,   3.31477016e-01,   3.28222126e-01,
                          3.25083464e-01,   3.21828574e-01,   3.18457425e-01,
                          3.15086275e-01,   3.11715126e-01,   3.08227718e-01,
                          3.04798454e-01,   3.01311046e-01,   2.97591150e-01,
                          2.94045627e-01,   2.90441990e-01,   2.86722094e-01,
                          2.83060342e-01,   2.79166073e-01,   2.75329947e-01,
                          2.71493822e-01,   2.67599553e-01,   2.63763428e-01,
                          2.59752899e-01,   2.55684286e-01,   2.51848131e-01,
                          2.47605145e-01,   2.43420273e-01,   2.39409760e-01,
                          2.35050514e-01,   2.30981886e-01,   2.26797014e-01,
                          2.22437769e-01,   2.18252897e-01,   2.13951766e-01,
                          2.09476277e-01,   2.05175161e-01,   2.00757787e-01,
                          1.96282297e-01,   1.91923052e-01,   1.87505677e-01,
                          1.82913944e-01,   1.78322196e-01,   1.74021080e-01,
                          1.69487461e-01,   1.64779484e-01,   1.60187736e-01,
                          1.55596003e-01,   1.50946140e-01,   1.46180034e-01,
                          1.41413927e-01,   1.36705935e-01,   1.31881714e-01,
                          1.27173722e-01,   1.22291364e-01,   1.17409013e-01,
                          1.12701029e-01,   1.07586183e-01,   1.02587581e-01,
                          9.77052227e-02,   9.27647427e-02,   8.79986361e-02,
                          8.28837901e-02,   7.76526928e-02,   7.25959688e-02,
                          6.74229935e-02,   6.23662733e-02,   5.73095493e-02,
                          5.19622080e-02,   4.67892364e-02,   4.17325087e-02,
                          3.66176628e-02,   3.13284434e-02,   2.59811040e-02,
                          2.07500085e-02,   1.53445443e-02,   1.01134498e-02,
                          4.76610847e-03,  -7.55602552e-04,  -6.04482042e-03,
                         -1.13921613e-02,  -1.68557484e-02,  -2.23193374e-02,
                         -2.76666787e-02,  -3.28977741e-02,  -3.84776071e-02,
                         -4.39411961e-02,  -4.93466593e-02,  -5.51008619e-02,
                         -6.04482032e-02,  -6.59117922e-02,  -7.15497509e-02,
                         -7.69552141e-02,  -8.24769214e-02,  -8.79986361e-02,
                         -9.35203433e-02,  -9.91001800e-02,  -1.04447521e-01,
                         -1.09969236e-01,  -1.15665317e-01,  -1.21303275e-01,
                         -1.26883104e-01,  -1.32462934e-01,  -1.38217151e-01,
                         -1.43913224e-01,  -1.49318695e-01,  -1.55014768e-01,
                         -1.60827100e-01,  -1.66348815e-01,  -1.71928644e-01,
                         -1.77799091e-01,  -1.83495179e-01,  -1.89133137e-01,
                         -1.94829211e-01,  -2.00525299e-01,  -2.06395745e-01,
                         -2.12266192e-01,  -2.17904150e-01,  -2.23774597e-01,
                         -2.29470685e-01,  -2.35050514e-01,  -2.40804717e-01,
                         -2.46675178e-01,  -2.52313137e-01,  -2.58067340e-01,
                         -2.63879657e-01,  -2.69575745e-01,  -2.75213689e-01,
                         -2.80967891e-01,  -2.86838353e-01,  -2.92534441e-01,
                         -2.98056155e-01,  -3.03635985e-01,  -3.09390187e-01,
                         -3.15202504e-01,  -3.20956707e-01,  -3.26710910e-01,
                         -3.32290769e-01,  -3.37928712e-01,  -3.43741030e-01,
                         -3.49379003e-01,  -3.55016947e-01,  -3.60654920e-01,
                         -3.66234750e-01,  -3.71988952e-01,  -3.77685040e-01,
                         -3.83264869e-01,  -3.88844699e-01,  -3.94192040e-01,
                         -3.99829984e-01,  -4.05351698e-01,  -4.10582811e-01,
                         -4.16162640e-01,  -4.21684355e-01,  -4.26915437e-01,
                         -4.32320893e-01,  -4.37726378e-01,  -4.43131834e-01,
                         -4.48304802e-01,  -4.53594029e-01,  -4.58999485e-01,
                         -4.63998079e-01,  -4.69229192e-01,  -4.74518418e-01,
                         -4.79517013e-01,  -4.84806210e-01,  -4.89921063e-01,
                         -4.94919688e-01,  -5.00092626e-01,  -5.05091250e-01,
                         -5.10031700e-01,  -5.14972210e-01,  -5.19738317e-01,
                         -5.24736941e-01,  -5.29677391e-01,  -5.34559727e-01,
                         -5.39383948e-01,  -5.44208229e-01,  -5.49090564e-01,
                         -5.53740442e-01,  -5.58448434e-01,  -5.63214540e-01,
                         -5.67748129e-01,  -5.72339892e-01,  -5.77047884e-01,
                         -5.81639588e-01,  -5.86115062e-01,  -5.90590596e-01,
                         -5.95240414e-01,  -5.99657834e-01,  -6.03842676e-01,
                         -6.08143806e-01,  -6.12328708e-01,  -6.16629779e-01,
                         -6.20814681e-01,  -6.24883294e-01,  -6.29068196e-01,
                         -6.33253038e-01,  -6.37321711e-01,  -6.41215980e-01,
                         -6.45110190e-01,  -6.49178863e-01,  -6.52956843e-01,
                         -6.56792998e-01,  -6.60629153e-01,  -6.64000273e-01,
                         -6.67720139e-01,  -6.71265662e-01,  -6.74753070e-01,
                         -6.78240478e-01,  -6.81495368e-01,  -6.84982777e-01,
                         -6.88237667e-01,  -6.91143870e-01,  -6.94514990e-01,
                         -6.97653651e-01,  -7.00617909e-01,  -7.03640342e-01,
                         -7.06372142e-01,  -7.09278286e-01,  -7.11951971e-01,
                         -7.14800000e-01,  -7.17706203e-01,  -7.20089257e-01,
                         -7.22588539e-01,  -7.25029707e-01,  -7.27354646e-01,
                         -7.29912043e-01,  -7.32236981e-01,  -7.34329462e-01,
                         -7.36596227e-01,  -7.38688707e-01,  -7.40606725e-01,
                         -7.42641091e-01,  -7.44617283e-01,  -7.46244729e-01,
                         -7.48162746e-01,  -7.49964595e-01,  -7.51475811e-01,
                         -7.53219485e-01,  -7.54788816e-01,  -7.56183803e-01,
                         -7.57520616e-01,  -7.58741200e-01,  -7.60078073e-01,
                         -7.61356771e-01,  -7.62519240e-01,  -7.63856053e-01,
                         -7.64786005e-01,  -7.65541613e-01,  -7.66471624e-01,
                         -7.67285347e-01,  -7.68099070e-01,  -7.68796563e-01,
                         -7.69377768e-01,  -7.69726515e-01,  -7.70191491e-01,
                         -7.70714581e-01,  -7.70830870e-01,  -7.71121442e-01,
                         -7.71295846e-01,  -7.71295846e-01,  -7.71528304e-01,
                         -7.71353960e-01,  -7.71063328e-01,  -7.71063328e-01,
                         -7.70656466e-01,  -7.70075262e-01,  -7.69552112e-01,
                         -7.69087136e-01,  -7.68505931e-01,  -7.67517805e-01,
                         -7.66762197e-01,  -7.65948474e-01,  -7.64786005e-01,
                         -7.63856053e-01,  -7.62693584e-01,  -7.61182368e-01,
                         -7.59845555e-01,  -7.58450568e-01,  -7.56881237e-01,
                         -7.55137563e-01,  -7.53452003e-01,  -7.51824558e-01,
                         -7.49790251e-01,  -7.47697771e-01,  -7.45721579e-01,
                         -7.43629158e-01,  -7.41362333e-01,  -7.39037395e-01,
                         -7.36712515e-01,  -7.34155059e-01,  -7.31481373e-01,
                         -7.28982091e-01,  -7.26250291e-01,  -7.23344147e-01,
                         -7.20554233e-01,  -7.17589915e-01,  -7.14625657e-01,
                         -7.11545110e-01,  -7.08232105e-01,  -7.04919040e-01,
                         -7.01664150e-01,  -6.98351145e-01,  -6.94689393e-01,
                         -6.91143870e-01,  -6.87656462e-01,  -6.83820307e-01,
                         -6.80158556e-01,  -6.76264286e-01,  -6.72137558e-01,
                         -6.68359518e-01,  -6.64290905e-01,  -6.60047889e-01,
                         -6.55804873e-01,  -6.51271284e-01,  -6.47028267e-01,
                         -6.42610908e-01,  -6.37961030e-01,  -6.33543670e-01,
                         -6.28777564e-01,  -6.23953342e-01,  -6.19245350e-01,
                         -6.14304900e-01,  -6.09480619e-01,  -6.04423940e-01,
                         -5.99425316e-01,  -5.94368577e-01,  -5.89021266e-01,
                         -5.83906412e-01,  -5.78675330e-01,  -5.73269844e-01,
                         -5.68038762e-01,  -5.62400818e-01,  -5.57111561e-01,
                         -5.51822364e-01,  -5.46184421e-01,  -5.40604591e-01,
                         -5.34850359e-01,  -5.29038012e-01,  -5.23283839e-01,
                         -5.17587721e-01,  -5.11833549e-01,  -5.05614340e-01,
                         -4.99569535e-01,  -4.93815333e-01,  -4.87770498e-01,
                         -4.81783807e-01,  -4.75680858e-01,  -4.69345421e-01,
                         -4.63184357e-01,  -4.56848919e-01,  -4.50571626e-01,
                         -4.44294304e-01,  -4.38016981e-01,  -4.31623429e-01,
                         -4.25113618e-01,  -4.18778181e-01,  -4.12210256e-01,
                         -4.05526072e-01,  -3.99016261e-01,  -3.92448336e-01,
                         -3.85822296e-01,  -3.79021853e-01,  -3.72221440e-01,
                         -3.65653515e-01,  -3.58853102e-01,  -3.51994544e-01,
                         -3.45310360e-01,  -3.38393688e-01,  -3.31477016e-01,
                         -3.24676603e-01,  -3.17585558e-01,  -3.10552657e-01,
                         -3.03810358e-01,  -2.96777427e-01,  -2.89744526e-01,
                         -2.82885969e-01,  -2.75911182e-01,  -2.68878251e-01,
                         -2.61903465e-01,  -2.54696190e-01,  -2.47663274e-01,
                         -2.40688473e-01,  -2.33423069e-01,  -2.26390153e-01,
                         -2.19299108e-01,  -2.12149948e-01,  -2.05233276e-01,
                         -1.97909743e-01,  -1.90760583e-01,  -1.83902040e-01,
                         -1.76636621e-01,  -1.69371217e-01,  -1.62338302e-01,
                         -1.55189142e-01,  -1.48039982e-01,  -1.41007066e-01,
                         -1.34032264e-01,  -1.26883104e-01,  -1.19733945e-01,
                         -1.12701029e-01,  -1.05609991e-01,  -9.85770747e-02,
                         -9.15441588e-02,  -8.44531134e-02,  -7.74201974e-02,
                         -7.03291595e-02,  -6.33543655e-02,  -5.63214533e-02,
                         -4.94629070e-02,  -4.25462350e-02,  -3.55714448e-02,
                         -2.86547747e-02,  -2.17381045e-02,  -1.47633115e-02,
                         -7.90476520e-03,  -1.04621891e-03,   5.69608063e-03,
                          1.24965040e-02,   1.92969274e-02,   2.59811040e-02,
                          3.27815264e-02,   3.94075811e-02,   4.62080017e-02,
                          5.30084260e-02,   5.93438633e-02,   6.59117922e-02,
                          7.25959688e-02,   7.91057721e-02,   8.56737047e-02,
                          9.19510201e-02,   9.85189453e-02,   1.05086878e-01,
                          1.11247942e-01,   1.17641509e-01,   1.23976946e-01,
                          1.30196139e-01,   1.36589691e-01,   1.42692640e-01,
                          1.48795575e-01,   1.55072898e-01,   1.61059588e-01,
                          1.67278782e-01,   1.73381731e-01,   1.79194048e-01,
                          1.85238868e-01,   1.91225573e-01,   1.96921647e-01,
                          2.02850223e-01,   2.08604425e-01,   2.14242384e-01,
                          2.19938472e-01,   2.25634545e-01,   2.31214374e-01,
                          2.36794218e-01,   2.42315933e-01,   2.47721389e-01,
                          2.53243089e-01,   2.58822948e-01,   2.63995916e-01,
                          2.69168884e-01,   2.74458110e-01,   2.79631078e-01,
                          2.84687787e-01,   2.89744526e-01,   2.94626862e-01,
                          2.99625486e-01,   3.04624081e-01,   3.09448302e-01,
                          3.14272553e-01,   3.19038659e-01,   3.23514134e-01,
                          3.28280240e-01,   3.32871974e-01,   3.37173104e-01,
                          3.41474235e-01,   3.45659107e-01,   3.49960238e-01,
                          3.54377598e-01,   3.58388096e-01,   3.62456739e-01,
                          3.66583496e-01,   3.70419621e-01,   3.74255747e-01,
                          3.78033757e-01,   3.81869912e-01,   3.85589808e-01,
                          3.89251560e-01,   3.92971456e-01,   3.96575093e-01,
                          4.00062501e-01,   4.03375506e-01,   4.06630427e-01,
                          4.10059690e-01,   4.13314611e-01,   4.16162640e-01,
                          4.19417530e-01,   4.22498077e-01,   4.25404251e-01,
                          4.28484768e-01,   4.31390941e-01,   4.34297085e-01,
                          4.37087029e-01,   4.39818799e-01,   4.42492485e-01,
                          4.44991767e-01,   4.47549194e-01,   4.50048506e-01,
                          4.52373445e-01,   4.54814613e-01,   4.57197666e-01,
                          4.59406346e-01,   4.61615026e-01,   4.63649362e-01,
                          4.65683669e-01,   4.67659861e-01,   4.69577938e-01,
                          4.71321613e-01,   4.72832829e-01,   4.74750906e-01,
                          4.76494581e-01,   4.77831423e-01,   4.79284525e-01,
                          4.80563223e-01,   4.81900066e-01,   4.83178765e-01,
                          4.84108746e-01,   4.85271215e-01,   4.86491799e-01,
                          4.87421781e-01,   4.88293618e-01,   4.88991112e-01,
                          4.89746690e-01,   4.90386069e-01,   4.91025418e-01,
                          4.91722882e-01,   4.92071629e-01,   4.92478490e-01,
                          4.92827237e-01,   4.92943496e-01,   4.93292212e-01,
                          4.93582845e-01,   4.93524700e-01,   4.93582845e-01,
                          4.93757218e-01,   4.93582845e-01,   4.93292212e-01,
                          4.93175983e-01,   4.92885351e-01,   4.92710978e-01,
                          4.92594749e-01,   4.92071629e-01,   4.91490394e-01,
                          4.91025418e-01,   4.90502298e-01,   4.90037322e-01,
                          4.89397973e-01,   4.88642365e-01,   4.88061130e-01,
                          4.87305522e-01,   4.86375540e-01,   4.85503703e-01,
                          4.84631866e-01,   4.83701885e-01,   4.82713789e-01,
                          4.81783807e-01,   4.80679482e-01,   4.79691386e-01,
                          4.78587031e-01,   4.77133960e-01,   4.75971490e-01,
                          4.74750906e-01,   4.73239690e-01,   4.72077221e-01,
                          4.70624149e-01,   4.68938559e-01,   4.67543602e-01,
                          4.66090530e-01,   4.64404941e-01,   4.62603122e-01,
                          4.60975677e-01,   4.59464490e-01,   4.57662642e-01,
                          4.55860823e-01,   4.54175264e-01,   4.52257186e-01,
                          4.50455368e-01,   4.48537290e-01,   4.46561098e-01,
                          4.44643050e-01,   4.42724973e-01,   4.40748781e-01,
                          4.38423842e-01,   4.36273277e-01,   4.34238970e-01,
                          4.32146549e-01,   4.30112213e-01,   4.28019792e-01,
                          4.25869226e-01,   4.23834920e-01,   4.21626240e-01,
                          4.19359416e-01,   4.17150736e-01,   4.14883912e-01,
                          4.12675232e-01,   4.10524666e-01,   4.08432245e-01,
                          4.06107306e-01,   4.03782368e-01,   4.01573688e-01,
                          3.99074405e-01,   3.96807581e-01,   3.94773275e-01,
                          3.92332107e-01,   3.89949054e-01,   3.87624115e-01,
                          3.85299176e-01,   3.83206755e-01,   3.80823702e-01,
                          3.78614992e-01,   3.76348197e-01,   3.73732656e-01,
                          3.71291459e-01,   3.69082779e-01,   3.66874099e-01,
                          3.64549160e-01,   3.62049878e-01,   3.59783053e-01,
                          3.57458144e-01,   3.55191320e-01,   3.52866381e-01,
                          3.50308955e-01,   3.47984046e-01,   3.45717221e-01,
                          3.43334168e-01,   3.41067374e-01,   3.38742435e-01,
                          3.36417496e-01,   3.33918214e-01,   3.31418902e-01,
                          3.29152107e-01,   3.26943427e-01,   3.24560344e-01,
                          3.22293550e-01,   3.20084870e-01,   3.17701817e-01,
                          3.15318763e-01,   3.13168198e-01,   3.11017632e-01,
                          3.08634579e-01,   3.06309640e-01,   3.04042846e-01,
                          3.01717907e-01,   2.99392968e-01,   2.97358662e-01,
                          2.95266241e-01,   2.92941302e-01,   2.90906996e-01,
                          2.88756430e-01,   2.86373377e-01,   2.84164697e-01,
                          2.82072246e-01,   2.79921681e-01,   2.77945489e-01,
                          2.75911182e-01,   2.73876876e-01,   2.71784425e-01,
                          2.69808233e-01,   2.67948300e-01,   2.65797734e-01,
                          2.63763428e-01,   2.61903465e-01,   2.60043532e-01,
                          2.58299828e-01,   2.56498009e-01,   2.54696190e-01,
                          2.52894372e-01,   2.51092553e-01,   2.49290720e-01,
                          2.47547016e-01,   2.45861441e-01,   2.44117752e-01,
                          2.42432177e-01,   2.40804717e-01,   2.39002898e-01,
                          2.37433568e-01,   2.35980496e-01,   2.34411165e-01,
                          2.32899964e-01,   2.31156260e-01,   2.29645059e-01,
                          2.28308216e-01,   2.26680771e-01,   2.25053310e-01,
                          2.23542109e-01,   2.22205281e-01,   2.20810309e-01,
                          2.19240993e-01,   2.18020394e-01,   2.16683567e-01,
                          2.15230480e-01,   2.14184269e-01,   2.12731183e-01,
                          2.11452469e-01,   2.10290000e-01,   2.08953172e-01,
                          2.07848832e-01,   2.06453860e-01,   2.05175161e-01,
                          2.04303309e-01,   2.03198969e-01,   2.02152744e-01,
                          2.01164648e-01,   2.00002179e-01,   1.99130341e-01,
                          1.98142245e-01,   1.97096020e-01,   1.96166053e-01,
                          1.95177957e-01,   1.94364220e-01,   1.93492383e-01,
                          1.92446157e-01,   1.91632435e-01,   1.90876827e-01,
                          1.90179348e-01,   1.89249381e-01,   1.88493773e-01,
                          1.88086912e-01,   1.87273189e-01,   1.86575711e-01,
                          1.85994476e-01,   1.85413241e-01,   1.84832007e-01,
                          1.84134528e-01,   1.83611423e-01,   1.83146432e-01,
                          1.82390839e-01,   1.82042092e-01,   1.81577101e-01,
                          1.81053996e-01,   1.80763379e-01,   1.80124030e-01,
                          1.79775283e-01,   1.79426551e-01,   1.78787187e-01,
                          1.78438455e-01,   1.78089708e-01,   1.77624717e-01,
                          1.77334100e-01,   1.76985368e-01,   1.76636621e-01,
                          1.76346019e-01,   1.76113516e-01,   1.75997272e-01,
                          1.75764784e-01,   1.75532281e-01,   1.75416037e-01,
                          1.75241664e-01,   1.75183550e-01,   1.74951047e-01,
                          1.74776688e-01,   1.74776688e-01,   1.74776688e-01,
                          1.74718559e-01,   1.74718559e-01,   1.74776688e-01,
                          1.74776688e-01,   1.74892932e-01,   1.74892932e-01,
                          1.75009176e-01,   1.75299793e-01,   1.75474167e-01,
                          1.75706655e-01,   1.76055402e-01,   1.76346019e-01,
                          1.76694751e-01,   1.76985368e-01,   1.77275985e-01,
                          1.77857220e-01,   1.78205952e-01,   1.78729072e-01,
                          1.79252177e-01,   1.79600909e-01,   1.80298388e-01,
                          1.80879623e-01,   1.81402743e-01,   1.82158336e-01,
                          1.82681441e-01,   1.83378935e-01,   1.84192657e-01,
                          1.84832007e-01,   1.85529485e-01,   1.86343208e-01,
                          1.87040687e-01,   1.87970668e-01,   1.88900635e-01,
                          1.89772487e-01,   1.90644339e-01,   1.91632435e-01,
                          1.92504287e-01,   1.93492383e-01,   1.94538593e-01,
                          1.95410445e-01,   1.96456671e-01,   1.97619125e-01,
                          1.98549107e-01,   1.99479073e-01,   2.00350925e-01,
                          2.01629639e-01,   2.03024596e-01,   2.04070807e-01,
                          2.05233276e-01,   2.06337616e-01,   2.07441956e-01,
                          2.08836928e-01,   2.10057512e-01,   2.11278096e-01,
                          2.12556809e-01,   2.13661149e-01,   2.14997992e-01,
                          2.16334820e-01,   2.17787907e-01,   2.19240993e-01,
                          2.20403448e-01,   2.21798405e-01,   2.23193377e-01,
                          2.24472076e-01,   2.25983292e-01,   2.27436364e-01,
                          2.29063824e-01,   2.30749398e-01,   2.32028112e-01,
                          2.33597443e-01,   2.35224888e-01,   2.36561716e-01,
                          2.38072932e-01,   2.39816621e-01,   2.41269708e-01,
                          2.42664665e-01,   2.44350240e-01,   2.46035814e-01,
                          2.47488901e-01,   2.49116346e-01,   2.50743806e-01,
                          2.52254993e-01,   2.53882468e-01,   2.55393654e-01,
                          2.56846756e-01,   2.58474201e-01,   2.60101646e-01,
                          2.61670977e-01,   2.63240308e-01,   2.64984012e-01,
                          2.66553342e-01,   2.68122673e-01,   2.69633859e-01,
                          2.71145076e-01,   2.72830635e-01,   2.74341851e-01,
                          2.75736809e-01,   2.77480513e-01,   2.78875470e-01,
                          2.80154169e-01,   2.81607270e-01,   2.83002228e-01,
                          2.84455299e-01,   2.85850257e-01,   2.87070841e-01,
                          2.88582057e-01,   2.90035129e-01,   2.91430086e-01,
                          2.92883188e-01,   2.94103771e-01,   2.95324355e-01,
                          2.96661198e-01,   2.97823668e-01,   2.98927993e-01,
                          3.00090462e-01,   3.01369160e-01,   3.02415401e-01,
                          3.03577870e-01,   3.04682195e-01,   3.05612177e-01,
                          3.06658387e-01,   3.07878971e-01,   3.08867067e-01,
                          3.09913307e-01,   3.10959518e-01,   3.11947614e-01,
                          3.12877595e-01,   3.13807547e-01,   3.14853758e-01,
                          3.15783739e-01,   3.16539347e-01,   3.17353070e-01,
                          3.18224937e-01,   3.19096774e-01,   3.20026755e-01,
                          3.20666105e-01,   3.21305454e-01,   3.22119176e-01,
                          3.22700411e-01,   3.23223531e-01,   3.23862880e-01,
                          3.24444115e-01,   3.25025350e-01,   3.25548440e-01,
                          3.25955331e-01,   3.26536536e-01,   3.27001542e-01,
                          3.27408403e-01,   3.27757150e-01,   3.27873379e-01,
                          3.28280240e-01,   3.28745246e-01,   3.28861475e-01,
                          3.28977734e-01,   3.29035848e-01,   3.29210222e-01,
                          3.29384595e-01,   3.29210222e-01,   3.29152107e-01,
                          3.29326481e-01,   3.29035848e-01,   3.28745246e-01,
                          3.28687102e-01,   3.28222126e-01,   3.27815264e-01,
                          3.27582777e-01,   3.27408403e-01,   3.27001542e-01,
                          3.26420307e-01,   3.25955331e-01,   3.25374097e-01,
                          3.24850976e-01,   3.24269742e-01,   3.23339760e-01,
                          3.22642297e-01,   3.22061062e-01,   3.21131080e-01,
                          3.20433617e-01,   3.19561750e-01,   3.18806142e-01,
                          3.17934304e-01,   3.16771835e-01,   3.15899998e-01,
                          3.14853758e-01,   3.13749433e-01,   3.12645078e-01,
                          3.11424494e-01,   3.10436398e-01,   3.09332073e-01,
                          3.07937115e-01,   3.06832761e-01,   3.05670291e-01,
                          3.04217219e-01,   3.02647889e-01,   3.01194817e-01,
                          2.99857974e-01,   2.98404872e-01,   2.97009915e-01,
                          2.95440584e-01,   2.93871284e-01,   2.92243809e-01,
                          2.90558249e-01,   2.89105147e-01,   2.87361473e-01,
                          2.85501510e-01,   2.83874065e-01,   2.81897873e-01,
                          2.79921681e-01,   2.78119862e-01,   2.76143670e-01,
                          2.74109364e-01,   2.71958798e-01,   2.69691974e-01,
                          2.67715812e-01,   2.65448987e-01,   2.63007820e-01,
                          2.60624766e-01,   2.58416086e-01,   2.56207377e-01,
                          2.53766209e-01,   2.51208782e-01,   2.48825729e-01,
                          2.46500805e-01,   2.43943378e-01,   2.41269708e-01,
                          2.38770410e-01,   2.35922366e-01,   2.33248696e-01,
                          2.30865642e-01,   2.28017598e-01,   2.25285813e-01,
                          2.22554013e-01,   2.19531611e-01,   2.16683567e-01,
                          2.13777393e-01,   2.10754991e-01,   2.07906947e-01,
                          2.04942659e-01,   2.01920256e-01,   1.98839724e-01,
                          1.95817307e-01,   1.92736775e-01,   1.89656243e-01,
                          1.86633825e-01,   1.83437049e-01,   1.80182144e-01,
                          1.77101612e-01,   1.73788592e-01,   1.70533687e-01,
                          1.67453155e-01,   1.64140120e-01,   1.60827100e-01,
                          1.57455951e-01,   1.54259175e-01,   1.50946140e-01,
                          1.47400618e-01,   1.44203842e-01,   1.40948936e-01,
                          1.37287170e-01,   1.33683532e-01,   1.30312383e-01,
                          1.26883104e-01,   1.23221338e-01,   1.19559571e-01,
                          1.16014056e-01,   1.12236038e-01,   1.08516149e-01,
                          1.04970634e-01,   1.01250745e-01,   9.74146053e-02,
                          9.36365947e-02,   8.99167061e-02,   8.62549394e-02,
                          8.23025554e-02,   7.85245448e-02,   7.48627782e-02,
                          7.09685162e-02,   6.69580102e-02,   6.30637482e-02,
                          5.91113679e-02,   5.52752316e-02,   5.13228513e-02,
                          4.72542197e-02,   4.33018394e-02,   3.92913334e-02,
                          3.51064578e-02,   3.10959518e-02,   2.70854458e-02,
                          2.30168160e-02,   1.88319404e-02,   1.48214344e-02,
                          1.08109284e-02,   6.62605325e-03,   2.55742413e-03,
                         -1.45308184e-03,  -5.63795771e-03,  -9.76470951e-03,
                         -1.39495861e-02,  -1.81925837e-02,  -2.23193374e-02,
                         -2.65042130e-02,  -3.06890886e-02,  -3.48158404e-02,
                         -3.91169637e-02,  -4.34762090e-02,  -4.77192067e-02,
                         -5.18459603e-02,  -5.59727140e-02,  -6.03900813e-02,
                         -6.47493303e-02,  -6.88179582e-02,  -7.31190816e-02,
                         -7.74201974e-02,  -8.16631988e-02,  -8.59062001e-02,
                         -8.99748281e-02,  -9.42759514e-02,  -9.88095626e-02,
                         -1.03110686e-01,  -1.07353687e-01,  -1.11538559e-01,
                         -1.15897804e-01,  -1.20140806e-01,  -1.24325685e-01,
                         -1.28917426e-01,  -1.33276671e-01,  -1.37461543e-01,
                         -1.41878918e-01,  -1.46354407e-01,  -1.50713652e-01,
                         -1.55014768e-01,  -1.59432143e-01,  -1.63965762e-01,
                         -1.68325007e-01,  -1.72916740e-01,  -1.77334100e-01,
                         -1.81693345e-01,  -1.86343208e-01,  -1.90702453e-01,
                         -1.95236072e-01,  -1.99944064e-01,  -2.04303309e-01,
                         -2.08836928e-01,  -2.13312417e-01,  -2.17729777e-01,
                         -2.22379640e-01,  -2.26913258e-01,  -2.31504992e-01,
                         -2.36038610e-01,  -2.40397856e-01,  -2.44989604e-01,
                         -2.49406964e-01,  -2.53940582e-01,  -2.58474201e-01,
                         -2.62891561e-01,  -2.67483294e-01,  -2.71900684e-01,
                         -2.76376158e-01,  -2.81084150e-01,  -2.85443395e-01,
                         -2.90035129e-01,  -2.94568747e-01,  -2.98811734e-01,
                         -3.03345352e-01,  -3.07762742e-01,  -3.12238216e-01,
                         -3.16771835e-01,  -3.21189195e-01,  -3.25780958e-01,
                         -3.30140203e-01,  -3.34325075e-01,  -3.38858694e-01,
                         -3.43276054e-01,  -3.47519040e-01,  -3.51994544e-01,
                         -3.56528163e-01,  -3.60771149e-01,  -3.65188539e-01,
                         -3.69664013e-01,  -3.73848885e-01,  -3.78208131e-01,
                         -3.82683635e-01,  -3.86926621e-01,  -3.91169637e-01,
                         -3.95412624e-01,  -3.99713755e-01,  -4.04073000e-01,
                         -4.08199757e-01,  -4.12559003e-01,  -4.16976362e-01,
                         -4.21219349e-01,  -4.25404251e-01,  -4.29647237e-01,
                         -4.33948368e-01,  -4.38075125e-01,  -4.42318112e-01,
                         -4.46561098e-01,  -4.50629741e-01,  -4.54814613e-01,
                         -4.58999485e-01,  -4.63126242e-01,  -4.67427373e-01,
                         -4.71321613e-01,  -4.75273997e-01,  -4.79458869e-01,
                         -4.83527511e-01,  -4.87712383e-01,  -4.91664767e-01,
                         -4.95384663e-01,  -4.99337047e-01,  -5.03405690e-01,
                         -5.07241786e-01,  -5.11019826e-01,  -5.14855981e-01,
                         -5.18633962e-01,  -5.22353888e-01,  -5.26131868e-01,
                         -5.29851735e-01,  -5.33339143e-01,  -5.37000895e-01,
                         -5.40662706e-01,  -5.44208229e-01,  -5.47928095e-01,
                         -5.51531732e-01,  -5.54902911e-01,  -5.58564663e-01,
                         -5.62052071e-01,  -5.65481305e-01,  -5.68852484e-01,
                         -5.72165489e-01,  -5.75536668e-01,  -5.78907788e-01,
                         -5.82220852e-01,  -5.85533857e-01,  -5.88672519e-01,
                         -5.91753066e-01,  -5.94775438e-01,  -5.97972214e-01,
                         -6.01168990e-01,  -6.04191422e-01,  -6.07213855e-01,
                         -6.10119998e-01,  -6.13084316e-01,  -6.16164804e-01,
                         -6.19129121e-01,  -6.22093379e-01,  -6.24767065e-01,
                         -6.27440751e-01,  -6.30288780e-01,  -6.33020580e-01,
                         -6.35694265e-01,  -6.38251662e-01,  -6.40983462e-01,
                         -6.43773377e-01,  -6.46214545e-01,  -6.48713827e-01,
                         -6.51213169e-01,  -6.53538108e-01,  -6.56037390e-01,
                         -6.58420444e-01,  -6.60570979e-01,  -6.62721574e-01,
                         -6.65046513e-01,  -6.67138934e-01,  -6.69057012e-01,
                         -6.71207547e-01,  -6.73125625e-01,  -6.74985588e-01,
                         -6.77078009e-01,  -6.78705454e-01,  -6.80507302e-01,
                         -6.82367206e-01,  -6.83820307e-01,  -6.85505867e-01,
                         -6.87133312e-01,  -6.88586414e-01,  -6.90039515e-01,
                         -6.91143870e-01,  -6.92538798e-01,  -6.94050014e-01,
                         -6.95270598e-01,  -6.96491182e-01,  -6.97653651e-01,
                         -6.98874235e-01,  -6.99920475e-01,  -7.00676084e-01,
                         -7.01780379e-01,  -7.02768505e-01,  -7.03465998e-01,
                         -7.04337835e-01,  -7.05035329e-01,  -7.05500305e-01,
                         -7.06197798e-01,  -7.06895232e-01,  -7.07418382e-01,
                         -7.07941473e-01,  -7.08464563e-01,  -7.08871424e-01,
                         -7.09336400e-01,  -7.09685147e-01,  -7.09801435e-01,
                         -7.09917665e-01,  -7.10150182e-01,  -7.10208297e-01,
                         -7.10150182e-01,  -7.10033894e-01,  -7.09917665e-01,
                         -7.09743321e-01,  -7.09510803e-01,  -7.09220171e-01,
                         -7.08697081e-01,  -7.08173990e-01,  -7.07941473e-01,
                         -7.07302094e-01,  -7.06546485e-01,  -7.06023395e-01,
                         -7.05093443e-01,  -7.04047203e-01,  -7.03465998e-01,
                         -7.02710390e-01,  -7.01489806e-01,  -7.00443566e-01,
                         -6.99513614e-01,  -6.98176742e-01,  -6.96665525e-01,
                         -6.95212483e-01,  -6.93817496e-01,  -6.92596912e-01,
                         -6.91085696e-01,  -6.89225793e-01,  -6.87423944e-01,
                         -6.85680270e-01,  -6.83878422e-01,  -6.81960344e-01,
                         -6.79984152e-01,  -6.77717388e-01,  -6.75276220e-01,
                         -6.73125625e-01,  -6.71033204e-01,  -6.68766379e-01,
                         -6.66325212e-01,  -6.63825929e-01,  -6.61442876e-01,
                         -6.58711076e-01,  -6.55979276e-01,  -6.53247476e-01,
                         -6.50399446e-01,  -6.47551417e-01,  -6.44528985e-01,
                         -6.41506553e-01,  -6.38426006e-01,  -6.35171115e-01,
                         -6.32264972e-01,  -6.29010081e-01,  -6.25464559e-01,
                         -6.22093379e-01,  -6.18547857e-01,  -6.15002334e-01,
                         -6.11514986e-01,  -6.07969463e-01,  -6.04249537e-01,
                         -6.00297153e-01,  -5.96519172e-01,  -5.92683017e-01,
                         -5.88788748e-01,  -5.84952652e-01,  -5.80883980e-01,
                         -5.76815367e-01,  -5.72688639e-01,  -5.68619967e-01,
                         -5.64725697e-01,  -5.60424626e-01,  -5.56065381e-01,
                         -5.51938593e-01,  -5.47463119e-01,  -5.43220103e-01,
                         -5.38744628e-01,  -5.34036636e-01,  -5.29619277e-01,
                         -5.24911284e-01,  -5.20319521e-01,  -5.15785933e-01,
                         -5.10903597e-01,  -5.06253719e-01,  -5.01545727e-01,
                         -4.96663362e-01,  -4.91897255e-01,  -4.86840546e-01,
                         -4.81900066e-01,  -4.77017701e-01,  -4.71728474e-01,
                         -4.66671765e-01,  -4.61615026e-01,  -4.56383944e-01,
                         -4.51152861e-01,  -4.45747375e-01,  -4.40458179e-01,
                         -4.35227066e-01,  -4.29821610e-01,  -4.24474269e-01,
                         -4.19068813e-01,  -4.13605213e-01,  -4.07967269e-01,
                         -4.02271181e-01,  -3.96749467e-01,  -3.90995264e-01,
                         -3.85415435e-01,  -3.79951835e-01,  -3.74139518e-01,
                         -3.68443429e-01,  -3.62631112e-01,  -3.56876910e-01,
                         -3.51355195e-01,  -3.45600992e-01,  -3.39846790e-01,
                         -3.34092587e-01,  -3.28222126e-01,  -3.22409809e-01,
                         -3.16539347e-01,  -3.10727030e-01,  -3.04856569e-01,
                         -2.99044251e-01,  -2.93173790e-01,  -2.87245214e-01,
                         -2.81374753e-01,  -2.75562435e-01,  -2.69575745e-01,
                         -2.63705283e-01,  -2.57892966e-01,  -2.52080649e-01,
                         -2.46268302e-01,  -2.40339741e-01,  -2.34411165e-01,
                         -2.28482589e-01,  -2.22670257e-01,  -2.16799811e-01,
                         -2.10754991e-01,  -2.04884544e-01,  -1.98897839e-01,
                         -1.93085521e-01,  -1.87273189e-01,  -1.81112126e-01,
                         -1.75416037e-01,  -1.69719964e-01,  -1.63675144e-01,
                         -1.57862812e-01,  -1.51817992e-01,  -1.45773172e-01,
                         -1.40018970e-01,  -1.33974150e-01,  -1.28161818e-01,
                         -1.22291364e-01,  -1.16362795e-01,  -1.10434219e-01,
                         -1.04389399e-01,  -9.87514406e-02,  -9.29391161e-02,
                         -8.68361741e-02,  -8.10238421e-02,  -7.50952661e-02,
                         -6.93410635e-02,  -6.35868609e-02,  -5.76001629e-02,
                         -5.20784520e-02,  -4.63823713e-02,  -4.06281687e-02,
                         -3.49902101e-02,  -2.90616360e-02,  -2.34818030e-02,
                         -1.79019682e-02,  -1.21477637e-02,  -6.74229953e-03,
                         -1.22058869e-03,   4.30112239e-03,   9.76470951e-03,
                          1.54026672e-02,   2.07500085e-02,   2.61554737e-02,
                          3.15609388e-02,   3.69664021e-02,   4.24881130e-02,
                          4.76610847e-02,   5.28921783e-02,   5.82395196e-02,
                          6.35287389e-02,   6.87017068e-02,   7.37584308e-02,
                          7.88151622e-02,   8.38137567e-02,   8.89286101e-02,
                          9.40434560e-02,   9.89839360e-02,   1.04040660e-01,
                          1.08981140e-01,   1.13689125e-01,   1.18629605e-01,
                          1.23395711e-01,   1.27987444e-01,   1.32695436e-01,
                          1.37345299e-01,   1.41878918e-01,   1.46354407e-01,
                          1.51120514e-01,   1.55770376e-01,   1.60187736e-01,
                          1.64837599e-01,   1.69196844e-01,   1.73323601e-01,
                          1.77682847e-01,   1.81983963e-01,   1.86285093e-01,
                          1.90644339e-01,   1.94945455e-01,   1.99072212e-01,
                          2.03082711e-01,   2.07151353e-01,   2.11219981e-01,
                          2.15288609e-01,   2.19299108e-01,   2.23135248e-01,
                          2.27029502e-01,   2.30749398e-01,   2.34353036e-01,
                          2.38131046e-01,   2.41676569e-01,   2.45396465e-01,
                          2.48941973e-01,   2.52313137e-01,   2.55916774e-01,
                          2.59229809e-01,   2.62484699e-01,   2.65913963e-01,
                          2.68994510e-01,   2.72365659e-01,   2.75736809e-01,
                          2.78642982e-01,   2.81607270e-01,   2.84629673e-01,
                          2.87652075e-01,   2.90441990e-01,   2.93057531e-01,
                          2.96021819e-01,   2.98637390e-01,   3.01194817e-01,
                          3.03926587e-01,   3.06600273e-01,   3.09215814e-01,
                          3.11715126e-01,   3.14214408e-01,   3.16481233e-01,
                          3.18631798e-01,   3.21131080e-01,   3.23339760e-01,
                          3.25432211e-01,   3.27699006e-01,   3.29675198e-01,
                          3.31709534e-01,   3.33685726e-01,   3.35603774e-01,
                          3.37696224e-01,   3.39498043e-01,   3.41241747e-01,
                          3.42985451e-01,   3.44554752e-01,   3.46240342e-01,
                          3.47751558e-01,   3.49262744e-01,   3.50832075e-01,
                          3.52168918e-01,   3.53680104e-01,   3.54958832e-01,
                          3.56063187e-01,   3.57458144e-01,   3.58678728e-01,
                          3.59724939e-01,   3.60771149e-01,   3.61701131e-01,
                          3.62805486e-01,   3.63735437e-01,   3.64549160e-01,
                          3.65537256e-01,   3.66409123e-01,   3.67106587e-01,
                          3.67745966e-01,   3.68443429e-01,   3.68966550e-01,
                          3.69489640e-01,   3.70070875e-01,   3.70361507e-01,
                          3.70652109e-01,   3.71233344e-01,   3.71465832e-01,
                          3.71523976e-01,   3.71756464e-01,   3.72047067e-01,
                          3.72279555e-01,   3.72163326e-01,   3.72105211e-01,
                          3.72047067e-01,   3.71872693e-01,   3.71930838e-01,
                          3.71698320e-01,   3.71349603e-01,   3.71175230e-01,
                          3.70884597e-01,   3.70652109e-01,   3.70303363e-01,
                          3.69780272e-01,   3.69199038e-01,   3.68792176e-01,
                          3.68385315e-01,   3.67687821e-01,   3.67048472e-01,
                          3.66583496e-01,   3.65827888e-01,   3.65304768e-01,
                          3.64665419e-01,   3.63619208e-01,   3.62921715e-01,
                          3.62166107e-01,   3.61294270e-01,   3.60538661e-01,
                          3.59608680e-01,   3.58678728e-01,   3.57806861e-01,
                          3.56935024e-01,   3.56063187e-01,   3.55075091e-01,
                          3.54145110e-01,   3.53157014e-01,   3.52168918e-01,
                          3.51122707e-01,   3.49960238e-01,   3.48855883e-01,
                          3.47867787e-01,   3.46763462e-01,   3.45717221e-01,
                          3.44612896e-01,   3.43450427e-01,   3.42287958e-01,
                          3.41067374e-01,   3.39904904e-01,   3.38626176e-01,
                          3.37579966e-01,   3.36417496e-01,   3.34964424e-01,
                          3.33743840e-01,   3.32639486e-01,   3.31302673e-01,
                          3.30023944e-01,   3.28745246e-01,   3.27524632e-01,
                          3.26129675e-01,   3.24560344e-01,   3.23165387e-01,
                          3.21886688e-01,   3.20607990e-01,   3.19038659e-01,
                          3.17643702e-01,   3.16423088e-01,   3.14795643e-01,
                          3.13342571e-01,   3.12121987e-01,   3.10552657e-01,
                          3.09041440e-01,   3.07588369e-01,   3.06077152e-01,
                          3.04624081e-01,   3.02996635e-01,   3.01659793e-01,
                          3.00322950e-01,   2.98695505e-01,   2.97242433e-01,
                          2.95789331e-01,   2.94103771e-01,   2.92592555e-01,
                          2.91255713e-01,   2.90035129e-01,   2.88465798e-01,
                          2.86954612e-01,   2.85617769e-01,   2.84164697e-01,
                          2.82885969e-01,   2.81491011e-01,   2.79921681e-01,
                          2.78759211e-01,   2.77422398e-01,   2.76143670e-01,
                          2.74806827e-01,   2.73411870e-01,   2.72133172e-01,
                          2.70738214e-01,   2.69517630e-01,   2.68413275e-01,
                          2.67134577e-01,   2.66030222e-01,   2.64635265e-01,
                          2.63182193e-01,   2.61903465e-01,   2.60682881e-01,
                          2.59636670e-01,   2.58532315e-01,   2.57253617e-01,
                          2.56149262e-01,   2.54986793e-01,   2.53882468e-01,
                          2.52661884e-01,   2.51441270e-01,   2.50278801e-01,
                          2.49116346e-01,   2.47953892e-01,   2.46733293e-01,
                          2.45454580e-01,   2.44350240e-01,   2.43245900e-01,
                          2.42199674e-01,   2.41095334e-01,   2.39874750e-01,
                          2.38828525e-01,   2.37724185e-01,   2.36619845e-01,
                          2.35399261e-01,   2.34294921e-01,   2.33423069e-01,
                          2.32260600e-01,   2.31156260e-01,   2.30284408e-01,
                          2.29238197e-01,   2.28133842e-01,   2.27203876e-01,
                          2.26273909e-01,   2.25343928e-01,   2.24297717e-01,
                          2.23425865e-01,   2.22554013e-01,   2.21682161e-01,
                          2.20926568e-01,   2.20054716e-01,   2.19299108e-01,
                          2.18543515e-01,   2.17729777e-01,   2.17090428e-01,
                          2.16451064e-01,   2.15695471e-01,   2.15114236e-01,
                          2.14533001e-01,   2.13835523e-01,   2.13370532e-01,
                          2.12847427e-01,   2.12149948e-01,   2.11568713e-01,
                          2.11161852e-01,   2.10638747e-01,   2.10057512e-01,
                          2.09592521e-01,   2.09185660e-01,   2.08836928e-01,
                          2.08430052e-01,   2.07965076e-01,   2.07616329e-01,
                          2.07151353e-01,   2.06802607e-01,   2.06511989e-01,
                          2.05988884e-01,   2.05582023e-01,   2.05291405e-01,
                          2.04942659e-01,   2.04535797e-01,   2.04187065e-01,
                          2.03780189e-01,   2.03373328e-01,   2.03024596e-01,
                          2.02792108e-01,   2.02385232e-01,   2.02036500e-01,
                          2.01920256e-01,   2.01513395e-01,   2.01222777e-01,
                          2.00932160e-01,   2.00525299e-01,   2.00350925e-01,
                          2.00176552e-01,   1.99885935e-01,   1.99537203e-01,
                          1.99246585e-01,   1.99130341e-01,   1.98839724e-01,
                          1.98607221e-01,   1.98374733e-01,   1.98025987e-01,
                          1.97851628e-01,   1.97793499e-01,   1.97619125e-01,
                          1.97502881e-01,   1.97502881e-01,   1.97444767e-01,
                          1.97328508e-01,   1.97270393e-01,   1.97270393e-01,
                          1.97212264e-01,   1.97212264e-01,   1.97212264e-01,
                          1.97212264e-01,   1.97328508e-01,   1.97444767e-01,
                          1.97619125e-01,   1.97735369e-01,   1.97909743e-01,
                          1.98258489e-01,   1.98316604e-01,   1.98490977e-01,
                          1.98781595e-01,   1.98955968e-01,   1.99304700e-01,
                          1.99595317e-01,   1.99885935e-01,   2.00234681e-01,
                          2.00583413e-01,   2.01048404e-01,   2.01455265e-01,
                          2.01745883e-01,   2.02210873e-01,   2.02617735e-01,
                          2.02908352e-01,   2.03315213e-01,   2.03722075e-01,
                          2.04187065e-01,   2.04768285e-01,   2.05175161e-01,
                          2.05582023e-01,   2.06046999e-01,   2.06570119e-01,
                          2.07035094e-01,   2.07674459e-01,   2.08081320e-01,
                          2.08662555e-01,   2.09301904e-01,   2.09534407e-01,
                          2.10173756e-01,   2.10987478e-01,   2.11510599e-01,
                          2.12324321e-01,   2.13021800e-01,   2.13428661e-01,
                          2.14126140e-01,   2.14823619e-01,   2.15462968e-01,
                          2.16276705e-01,   2.17032298e-01,   2.17787907e-01,
                          2.18601629e-01,   2.19473481e-01,   2.20403448e-01,
                          2.21449673e-01,   2.22321525e-01,   2.23135248e-01,
                          2.24065214e-01,   2.24995196e-01,   2.25867033e-01,
                          2.27029502e-01,   2.28075728e-01,   2.29121938e-01,
                          2.30168164e-01,   2.31156260e-01,   2.32318729e-01,
                          2.33423069e-01,   2.34585539e-01,   2.35922366e-01,
                          2.37026706e-01,   2.38189176e-01,   2.39526004e-01,
                          2.40630358e-01,   2.41734698e-01,   2.42897153e-01,
                          2.44117752e-01,   2.45512709e-01,   2.46791422e-01,
                          2.47895762e-01,   2.49058232e-01,   2.50511318e-01,
                          2.51557529e-01,   2.52603740e-01,   2.53998697e-01,
                          2.55219281e-01,   2.56323636e-01,   2.57602334e-01,
                          2.58764803e-01,   2.60043532e-01,   2.61147857e-01,
                          2.62135953e-01,   2.63356566e-01,   2.64577150e-01,
                          2.65739620e-01,   2.66669571e-01,   2.67657667e-01,
                          2.68878251e-01,   2.69982606e-01,   2.71028817e-01,
                          2.71784425e-01,   2.72830635e-01,   2.74109364e-01,
                          2.74864972e-01,   2.75678694e-01,   2.76841164e-01,
                          2.77887374e-01,   2.78701097e-01,   2.79631078e-01,
                          2.80735403e-01,   2.81723499e-01,   2.82595366e-01,
                          2.83641577e-01,   2.84339041e-01,   2.85210907e-01,
                          2.86431491e-01,   2.87303329e-01,   2.88233310e-01,
                          2.89221406e-01,   2.89918900e-01,   2.90790737e-01,
                          2.91662574e-01,   2.92534441e-01,   2.93580651e-01,
                          2.94161886e-01,   2.94743121e-01,   2.95789331e-01,
                          2.96486825e-01,   2.97184289e-01,   2.97939897e-01,
                          2.98753619e-01,   2.99392968e-01,   2.99974203e-01,
                          3.00671697e-01,   3.01311046e-01,   3.01950395e-01,
                          3.02706003e-01,   3.03171009e-01,   3.03577870e-01,
                          3.04100960e-01,   3.04391593e-01,   3.04740310e-01,
                          3.05205315e-01,   3.05670291e-01,   3.05960923e-01,
                          3.06135267e-01,   3.06367785e-01,   3.06658387e-01,
                          3.06716502e-01,   3.06832761e-01,   3.07007134e-01,
                          3.06949019e-01,   3.06890875e-01,   3.06949019e-01,
                          3.06832761e-01,   3.06716502e-01,   3.06600273e-01,
                          3.06658387e-01,   3.06658387e-01,   3.06135267e-01,
                          3.05844665e-01,   3.05728406e-01,   3.05205315e-01,
                          3.04972827e-01,   3.04682195e-01,   3.03984731e-01,
                          3.03694099e-01,   3.03229123e-01,   3.02880377e-01,
                          3.02589774e-01,   3.01834166e-01,   3.01252931e-01,
                          3.00671697e-01,   3.00032347e-01,   2.99567342e-01,
                          2.98986107e-01,   2.98288643e-01,   2.97649294e-01,
                          2.96719313e-01,   2.96021819e-01,   2.95208097e-01,
                          2.94336259e-01,   2.93638766e-01,   2.92650670e-01,
                          2.91662574e-01,   2.90848851e-01,   2.89860755e-01,
                          2.88872659e-01,   2.88117081e-01,   2.87070841e-01,
                          2.85908371e-01,   2.84862161e-01,   2.83583462e-01,
                          2.82362849e-01,   2.81258523e-01,   2.79979795e-01,
                          2.78584838e-01,   2.77248025e-01,   2.75969297e-01,
                          2.74574339e-01,   2.73179382e-01,   2.71551937e-01,
                          2.69866347e-01,   2.68471390e-01,   2.67018318e-01,
                          2.65332729e-01,   2.63589054e-01,   2.61903465e-01,
                          2.60159761e-01,   2.58241713e-01,   2.56323636e-01,
                          2.54405558e-01,   2.52545625e-01,   2.50743806e-01,
                          2.48593241e-01,   2.46384561e-01,   2.44408369e-01,
                          2.42315933e-01,   2.40339741e-01,   2.38363549e-01,
                          2.36096740e-01,   2.33771801e-01,   2.31504992e-01,
                          2.29412556e-01,   2.27087632e-01,   2.24704579e-01,
                          2.22554013e-01,   2.20287204e-01,   2.17846036e-01,
                          2.15462968e-01,   2.13138044e-01,   2.10754991e-01,
                          2.08313808e-01,   2.05872640e-01,   2.03315213e-01,
                          2.00874031e-01,   1.98490977e-01,   1.95933551e-01,
                          1.93434253e-01,   1.90993071e-01,   1.88319400e-01,
                          1.85645729e-01,   1.83146432e-01,   1.80530891e-01,
                          1.77799091e-01,   1.75125420e-01,   1.72393635e-01,
                          1.69603705e-01,   1.66813791e-01,   1.64023876e-01,
                          1.61292091e-01,   1.58444047e-01,   1.55421630e-01,
                          1.52573586e-01,   1.49667427e-01,   1.46703139e-01,
                          1.43738851e-01,   1.40600204e-01,   1.37577787e-01,
                          1.34497255e-01,   1.31474838e-01,   1.28278062e-01,
                          1.24848790e-01,   1.21710137e-01,   1.18745849e-01,
                          1.15258448e-01,   1.12003550e-01,   1.08748645e-01,
                          1.05261251e-01,   1.01890095e-01,   9.84027013e-02,
                          9.49734300e-02,   9.17185247e-02,   8.81730095e-02,
                          8.44531134e-02,   8.09657201e-02,   7.77689368e-02,
                          7.41071701e-02,   7.02129155e-02,   6.68998882e-02,
                          6.32381216e-02,   5.94601072e-02,   5.61470836e-02,
                          5.24853170e-02,   4.87654246e-02,   4.53361534e-02,
                          4.17325087e-02,   3.81288677e-02,   3.42927314e-02,
                          3.06309648e-02,   2.70273220e-02,   2.33074334e-02,
                          1.98200364e-02,   1.61582697e-02,   1.23802572e-02,
                          8.83473735e-03,   5.11484826e-03,   1.16246543e-03,
                         -2.38305423e-03,  -5.92857366e-03,  -9.70658660e-03,
                         -1.34264762e-02,  -1.70301199e-02,  -2.08662543e-02,
                         -2.47023907e-02,  -2.85385270e-02,  -3.23746651e-02,
                         -3.58620584e-02,  -3.97563204e-02,  -4.36505787e-02,
                         -4.73704673e-02,  -5.13809733e-02,  -5.52171096e-02,
                         -5.91113679e-02,  -6.32381216e-02,  -6.70161322e-02,
                         -7.10266382e-02,  -7.49790221e-02,  -7.88732842e-02,
                         -8.30000341e-02,  -8.69524181e-02,  -9.08466727e-02,
                         -9.50896740e-02,  -9.91583019e-02,  -1.03285059e-01,
                         -1.07411809e-01,  -1.11596689e-01,  -1.15781561e-01,
                         -1.19850188e-01,  -1.23976946e-01,  -1.28161818e-01,
                         -1.32521063e-01,  -1.36705935e-01,  -1.40716448e-01,
                         -1.45075694e-01,  -1.49376810e-01,  -1.53561682e-01,
                         -1.57746568e-01,  -1.62105814e-01,  -1.66290686e-01,
                         -1.70359313e-01,  -1.74544185e-01,  -1.78961560e-01,
                         -1.83204561e-01,  -1.87447563e-01,  -1.91632435e-01,
                         -1.95875436e-01,  -2.00118437e-01,  -2.04187065e-01,
                         -2.08546311e-01,  -2.12847427e-01,  -2.16799811e-01,
                         -2.21159056e-01,  -2.25402057e-01,  -2.29470685e-01,
                         -2.33713686e-01,  -2.38014802e-01,  -2.42199674e-01,
                         -2.46384561e-01,  -2.50511318e-01,  -2.54812419e-01,
                         -2.58997321e-01,  -2.63124049e-01,  -2.67483294e-01,
                         -2.71784425e-01,  -2.76027411e-01,  -2.80444801e-01,
                         -2.84745902e-01,  -2.89047033e-01,  -2.93406278e-01,
                         -2.97707409e-01,  -3.01950395e-01,  -3.06309640e-01,
                         -3.10610771e-01,  -3.14911902e-01,  -3.19387376e-01,
                         -3.23746622e-01,  -3.28105867e-01,  -3.32639486e-01,
                         -3.36940616e-01,  -3.41241747e-01,  -3.45775366e-01,
                         -3.50250840e-01,  -3.54726344e-01,  -3.59143704e-01,
                         -3.63561064e-01,  -3.68036568e-01,  -3.72337699e-01,
                         -3.76755059e-01,  -3.81346792e-01,  -3.85880411e-01,
                         -3.90181541e-01,  -3.94424528e-01,  -3.98783773e-01,
                         -4.03201133e-01,  -4.07560378e-01,  -4.12035882e-01,
                         -4.16511387e-01,  -4.20812488e-01,  -4.24939245e-01,
                         -4.29414749e-01,  -4.33715880e-01,  -4.37610120e-01,
                         -4.42027479e-01,  -4.46328610e-01,  -4.50339109e-01,
                         -4.54640239e-01,  -4.58592623e-01,  -4.62661266e-01,
                         -4.66962367e-01,  -4.71147269e-01,  -4.75273997e-01,
                         -4.79284525e-01,  -4.83178765e-01,  -4.87131149e-01,
                         -4.91141647e-01,  -4.95035917e-01,  -4.98872042e-01,
                         -5.02882540e-01,  -5.06893039e-01,  -5.10612965e-01,
                         -5.14449120e-01,  -5.18227100e-01,  -5.22179484e-01,
                         -5.26248097e-01,  -5.29968023e-01,  -5.33687890e-01,
                         -5.37465930e-01,  -5.41127682e-01,  -5.44847548e-01,
                         -5.48509359e-01,  -5.52287340e-01,  -5.56181610e-01,
                         -5.59901476e-01,  -5.63505113e-01,  -5.67166924e-01,
                         -5.71061134e-01,  -5.74839175e-01,  -5.78442812e-01,
                         -5.82104564e-01,  -5.85533857e-01,  -5.89021266e-01,
                         -5.93031764e-01,  -5.96577287e-01,  -5.99948406e-01,
                         -6.03784561e-01,  -6.07330084e-01,  -6.10701263e-01,
                         -6.14130497e-01,  -6.17327273e-01,  -6.20582163e-01,
                         -6.24011457e-01,  -6.27150118e-01,  -6.30405009e-01,
                         -6.33659899e-01,  -6.36682332e-01,  -6.39762878e-01,
                         -6.42727137e-01,  -6.45633340e-01,  -6.48655713e-01,
                         -6.51445627e-01,  -6.54235542e-01,  -6.57083631e-01,
                         -6.59582913e-01,  -6.62372828e-01,  -6.65104628e-01,
                         -6.67545795e-01,  -6.70277596e-01,  -6.72660649e-01,
                         -6.74985588e-01,  -6.77426755e-01,  -6.79635465e-01,
                         -6.82018518e-01,  -6.84343398e-01,  -6.86377764e-01,
                         -6.88644528e-01,  -6.90678835e-01,  -6.92596912e-01,
                         -6.94747508e-01,  -6.96781814e-01,  -6.98699892e-01,
                         -7.00617909e-01,  -7.02419758e-01,  -7.04221606e-01,
                         -7.06081510e-01,  -7.07941473e-01,  -7.09568918e-01,
                         -7.10963905e-01,  -7.12649465e-01,  -7.14335024e-01,
                         -7.15788126e-01,  -7.17415571e-01,  -7.18868673e-01,
                         -7.20205486e-01,  -7.21484184e-01,  -7.22762883e-01,
                         -7.24215984e-01,  -7.25436568e-01,  -7.26482809e-01,
                         -7.27703393e-01,  -7.28749573e-01,  -7.29737699e-01,
                         -7.30725765e-01,  -7.31772006e-01,  -7.32876360e-01,
                         -7.33573854e-01,  -7.34271288e-01,  -7.35085011e-01,
                         -7.35317528e-01,  -7.35724390e-01,  -7.36421883e-01,
                         -7.36770630e-01,  -7.37177491e-01,  -7.37584352e-01,
                         -7.37526238e-01,  -7.37584352e-01,  -7.37642467e-01,
                         -7.37642467e-01,  -7.37700582e-01,  -7.37468064e-01,
                         -7.37061203e-01,  -7.36654341e-01,  -7.36073136e-01,
                         -7.35724390e-01,  -7.35375643e-01,  -7.34387577e-01,
                         -7.33748198e-01,  -7.33283222e-01,  -7.32236981e-01,
                         -7.31365144e-01,  -7.30377078e-01,  -7.29330838e-01,
                         -7.28284597e-01,  -7.26773381e-01,  -7.25610971e-01,
                         -7.24390328e-01,  -7.22704768e-01,  -7.21309841e-01,
                         -7.19798625e-01,  -7.18054891e-01,  -7.16485620e-01,
                         -7.14625657e-01,  -7.12881923e-01,  -7.11196363e-01,
                         -7.09220171e-01,  -7.07185864e-01,  -7.05151558e-01,
                         -7.03059137e-01,  -7.00850427e-01,  -6.98525488e-01,
                         -6.96258664e-01,  -6.93875611e-01,  -6.91550732e-01,
                         -6.89167678e-01,  -6.86552107e-01,  -6.83994710e-01,
                         -6.81321025e-01,  -6.78589225e-01,  -6.75683081e-01,
                         -6.72834992e-01,  -6.70045078e-01,  -6.67022705e-01,
                         -6.63942158e-01,  -6.60687268e-01,  -6.57374203e-01,
                         -6.54293716e-01,  -6.50806308e-01,  -6.47318900e-01,
                         -6.43831491e-01,  -6.40053511e-01,  -6.36507988e-01,
                         -6.32904351e-01,  -6.29068196e-01,  -6.25115812e-01,
                         -6.21163428e-01,  -6.17269158e-01,  -6.13142431e-01,
                         -6.08957529e-01,  -6.05063260e-01,  -6.00762129e-01,
                         -5.96286654e-01,  -5.91869295e-01,  -5.87568164e-01,
                         -5.83325148e-01,  -5.78617215e-01,  -5.73967338e-01,
                         -5.69549978e-01,  -5.64841986e-01,  -5.60250223e-01,
                         -5.55600345e-01,  -5.50543666e-01,  -5.45719385e-01,
                         -5.41127682e-01,  -5.36187172e-01,  -5.31130493e-01,
                         -5.26189983e-01,  -5.21249533e-01,  -5.16134679e-01,
                         -5.11136055e-01,  -5.06021202e-01,  -5.00790119e-01,
                         -4.95733410e-01,  -4.90502298e-01,  -4.85213101e-01,
                         -4.79981989e-01,  -4.74634647e-01,  -4.69229192e-01,
                         -4.63823736e-01,  -4.58476394e-01,  -4.53129053e-01,
                         -4.47549194e-01,  -4.42201853e-01,  -4.36738282e-01,
                         -4.31158453e-01,  -4.25578594e-01,  -4.19766277e-01,
                         -4.14244562e-01,  -4.08606619e-01,  -4.02910531e-01,
                         -3.97388816e-01,  -3.91692728e-01,  -3.85938525e-01,
                         -3.80126208e-01,  -3.74255747e-01,  -3.68501544e-01,
                         -3.62456739e-01,  -3.56470048e-01,  -3.50657701e-01,
                         -3.44671011e-01,  -3.38742435e-01,  -3.32755744e-01,
                         -3.26885283e-01,  -3.21131080e-01,  -3.14853758e-01,
                         -3.08750838e-01,  -3.02938491e-01,  -2.96835572e-01,
                         -2.90906996e-01,  -2.84687787e-01,  -2.78468609e-01,
                         -2.72423774e-01,  -2.66146481e-01,  -2.60217905e-01,
                         -2.54114956e-01,  -2.47779518e-01,  -2.41734698e-01,
                         -2.35573635e-01,  -2.29528800e-01,  -2.23600239e-01,
                         -2.17497289e-01,  -2.11394340e-01,  -2.05233276e-01,
                         -1.99304700e-01,  -1.93201765e-01,  -1.86982572e-01,
                         -1.80995867e-01,  -1.74776688e-01,  -1.68615609e-01,
                         -1.62861407e-01,  -1.56758472e-01,  -1.50771767e-01,
                         -1.45017564e-01,  -1.38856500e-01,  -1.32695436e-01,
                         -1.26824990e-01,  -1.21070780e-01,  -1.15084082e-01,
                         -1.09213628e-01,  -1.03401303e-01,  -9.74727273e-02,
                         -9.17185247e-02,  -8.59062001e-02,  -8.00938681e-02,
                         -7.43977875e-02,  -6.86435848e-02,  -6.29475042e-02,
                         -5.72514236e-02,  -5.16134650e-02,  -4.60336320e-02,
                         -4.02794294e-02,  -3.46995927e-02,  -2.92360056e-02,
                         -2.35980488e-02,  -1.80182140e-02,  -1.23802572e-02,
                         -6.97479304e-03,  -1.45308184e-03,   4.24299901e-03,
                          9.64846369e-03,   1.52282976e-02,   2.06918847e-02,
                          2.60392260e-02,   3.15609388e-02,   3.69082801e-02,
                          4.22556214e-02,   4.76029627e-02,   5.27759306e-02,
                          5.80651499e-02,   6.34706169e-02,   6.88179582e-02,
                          7.39328042e-02,   7.89895281e-02,   8.43368694e-02,
                          8.94517154e-02,   9.44503173e-02,   9.95070413e-02,
                          1.04331277e-01,   1.09155506e-01,   1.14095986e-01,
                          1.18920214e-01,   1.23744451e-01,   1.28336191e-01,
                          1.33044168e-01,   1.37635916e-01,   1.42169520e-01,
                          1.46877512e-01,   1.51236758e-01,   1.55479759e-01,
                          1.59955248e-01,   1.64256364e-01,   1.68673739e-01,
                          1.72858611e-01,   1.76927239e-01,   1.81170240e-01,
                          1.85064510e-01,   1.89016879e-01,   1.93143636e-01,
                          1.96921647e-01,   2.00815916e-01,   2.04768285e-01,
                          2.08488181e-01,   2.12266192e-01,   2.15869844e-01,
                          2.19589725e-01,   2.23251492e-01,   2.26738885e-01,
                          2.30342537e-01,   2.33713686e-01,   2.37259209e-01,
                          2.40920961e-01,   2.44233996e-01,   2.47488901e-01,
                          2.50860035e-01,   2.54173070e-01,   2.57427990e-01,
                          2.60566622e-01,   2.63821542e-01,   2.66727716e-01,
                          2.69866347e-01,   2.73237497e-01,   2.76259929e-01,
                          2.79282331e-01,   2.82246619e-01,   2.85094649e-01,
                          2.88000822e-01,   2.90732622e-01,   2.93522537e-01,
                          2.96254337e-01,   2.98869878e-01,   3.01485419e-01,
                          3.04042846e-01,   3.06600273e-01,   3.08925211e-01,
                          3.11308265e-01,   3.13691318e-01,   3.15958112e-01,
                          3.18166792e-01,   3.20259243e-01,   3.22351664e-01,
                          3.24676603e-01,   3.26594681e-01,   3.28396499e-01,
                          3.30256432e-01,   3.32000136e-01,   3.33860070e-01,
                          3.35371286e-01,   3.36940616e-01,   3.38800550e-01,
                          3.40137392e-01,   3.41590464e-01,   3.43159795e-01,
                          3.44322264e-01,   3.45659107e-01,   3.46995950e-01,
                          3.48274648e-01,   3.49437118e-01,   3.50425214e-01,
                          3.51529568e-01,   3.52633893e-01,   3.53331387e-01,
                          3.54203224e-01,   3.55249435e-01,   3.56063187e-01,
                          3.56935024e-01,   3.57690632e-01,   3.58388096e-01,
                          3.59259963e-01,   3.60189915e-01,   3.60771149e-01,
                          3.61468643e-01,   3.62049878e-01,   3.62514853e-01,
                          3.63096088e-01,   3.63386691e-01,   3.63677323e-01,
                          3.64316672e-01,   3.64781678e-01,   3.65246654e-01,
                          3.65711629e-01,   3.65886003e-01,   3.66176635e-01,
                          3.66292864e-01,   3.66467237e-01,   3.66757870e-01,
                          3.66815984e-01,   3.66990358e-01,   3.67106587e-01,
                          3.66990358e-01,   3.66990358e-01,   3.66932213e-01,
                          3.66757870e-01,   3.66583496e-01,   3.66467237e-01,
                          3.66234750e-01,   3.65944117e-01,   3.65653515e-01,
                          3.65130395e-01,   3.64839792e-01,   3.64607304e-01,
                          3.64026070e-01,   3.63502949e-01,   3.63096088e-01,
                          3.62514853e-01,   3.61991733e-01,   3.61468643e-01,
                          3.60713035e-01,   3.59783053e-01,   3.59143704e-01,
                          3.58504355e-01,   3.57690632e-01,   3.56993139e-01,
                          3.56179416e-01,   3.55249435e-01,   3.54551971e-01,
                          3.53680104e-01,   3.52866381e-01,   3.52227032e-01,
                          3.51297051e-01,   3.50367099e-01,   3.49495232e-01,
                          3.48449022e-01,   3.47577184e-01,   3.46647203e-01,
                          3.45717221e-01,   3.44961613e-01,   3.44089776e-01,
                          3.43276054e-01,   3.42229843e-01,   3.41241747e-01,
                          3.40544254e-01,   3.39439929e-01,   3.38393688e-01,
                          3.37521851e-01,   3.36591870e-01,   3.35720032e-01,
                          3.34615678e-01,   3.33743840e-01,   3.32871974e-01,
                          3.31767648e-01,   3.30895782e-01,   3.29965830e-01,
                          3.28861475e-01,   3.27873379e-01,   3.26827168e-01,
                          3.25897187e-01,   3.24792862e-01,   3.23688507e-01,
                          3.22816670e-01,   3.21770430e-01,   3.20666105e-01,
                          3.19561750e-01,   3.18515539e-01,   3.17527443e-01,
                          3.16248745e-01,   3.15202504e-01,   3.14098179e-01,
                          3.12819451e-01,   3.11831355e-01,   3.10727030e-01,
                          3.09622675e-01,   3.08576465e-01,   3.07239622e-01,
                          3.06077152e-01,   3.04914683e-01,   3.03694099e-01,
                          3.02764118e-01,   3.01427305e-01,   3.00206721e-01,
                          2.99160480e-01,   2.97881782e-01,   2.96777427e-01,
                          2.95673102e-01,   2.94510633e-01,   2.93406278e-01,
                          2.92185694e-01,   2.91081339e-01,   2.90035129e-01,
                          2.88930804e-01,   2.87768334e-01,   2.86663979e-01,
                          2.85675883e-01,   2.84571558e-01,   2.83467203e-01,
                          2.82537222e-01,   2.81491011e-01,   2.80502915e-01,
                          2.79631078e-01,   2.78584838e-01,   2.77654886e-01,
                          2.76724905e-01,   2.75678694e-01,   2.74806827e-01,
                          2.73876876e-01,   2.72830635e-01,   2.72133172e-01,
                          2.71319449e-01,   2.70273209e-01,   2.69459486e-01,
                          2.68645763e-01,   2.67657667e-01,   2.66843945e-01,
                          2.65855849e-01,   2.64867753e-01,   2.64054030e-01,
                          2.63124049e-01,   2.62310326e-01,   2.61380374e-01,
                          2.60276020e-01,   2.59520411e-01,   2.58648574e-01,
                          2.57776707e-01,   2.56904870e-01,   2.55974889e-01,
                          2.55335540e-01,   2.54463702e-01,   2.53417462e-01,
                          2.52603740e-01,   2.51615644e-01,   2.50685692e-01,
                          2.49930069e-01,   2.49000102e-01,   2.48244494e-01,
                          2.47372657e-01,   2.46442676e-01,   2.45861441e-01,
                          2.45047718e-01,   2.44001508e-01,   2.43071526e-01,
                          2.42374048e-01,   2.41676569e-01,   2.40804717e-01,
                          2.40165368e-01,   2.39584133e-01,   2.38770410e-01,
                          2.38072932e-01,   2.37491697e-01,   2.36677974e-01,
                          2.35864237e-01,   2.35399261e-01,   2.34759897e-01,
                          2.33946174e-01,   2.33481184e-01,   2.33016208e-01,
                          2.32493088e-01,   2.31969982e-01,   2.31214374e-01,
                          2.30749398e-01,   2.30400652e-01,   2.29586929e-01,
                          2.29005694e-01,   2.28482589e-01,   2.27901354e-01,
                          2.27494493e-01,   2.26913258e-01,   2.26448268e-01,
                          2.25925162e-01,   2.25518301e-01,   2.25169554e-01,
                          2.24472076e-01,   2.23832726e-01,   2.23542109e-01,
                          2.23019004e-01,   2.22612143e-01,   2.22089022e-01,
                          2.21565917e-01,   2.21217185e-01,   2.20577821e-01,
                          2.20054716e-01,   2.19705969e-01,   2.19124734e-01,
                          2.18717873e-01,   2.18194768e-01,   2.17613533e-01,
                          2.17148542e-01,   2.16567323e-01,   2.15927958e-01,
                          2.15579227e-01,   2.15056106e-01,   2.14300513e-01,
                          2.13893652e-01,   2.13486791e-01,   2.12847427e-01,
                          2.12498695e-01,   2.12208077e-01,   2.11626843e-01,
                          2.11336225e-01,   2.10987478e-01,   2.10464373e-01,
                          2.10115626e-01,   2.09941268e-01,   2.09708765e-01,
                          2.09185660e-01,   2.08836928e-01,   2.08778799e-01,
                          2.08488181e-01,   2.08313808e-01,   2.08023190e-01,
                          2.07732573e-01,   2.07790703e-01,   2.07732573e-01,
                          2.07732573e-01,   2.07790703e-01,   2.07732573e-01,
                          2.07848832e-01,   2.07848832e-01,   2.07558215e-01,
                          2.07732573e-01,   2.07906947e-01,   2.07848832e-01,
                          2.07848832e-01,   2.07906947e-01,   2.07965076e-01,
                          2.08197564e-01,   2.08488181e-01,   2.08546311e-01,
                          2.08720669e-01,   2.08953172e-01,   2.09127530e-01,
                          2.09360033e-01,   2.09650651e-01,   2.09883139e-01,
                          2.10290000e-01,   2.10464373e-01,   2.10813120e-01,
                          2.11278096e-01,   2.11568713e-01,   2.11917460e-01,
                          2.12266192e-01,   2.12498695e-01,   2.12789297e-01,
                          2.13254288e-01,   2.13719279e-01,   2.14068010e-01,
                          2.14533001e-01,   2.14939862e-01,   2.15288609e-01,
                          2.15811715e-01,   2.16276705e-01,   2.16683567e-01,
                          2.17322916e-01,   2.17729777e-01,   2.18136638e-01,
                          2.18834117e-01,   2.19357237e-01,   2.19822213e-01,
                          2.20577821e-01,   2.21275300e-01,   2.21740291e-01,
                          2.22437769e-01,   2.23251492e-01,   2.23890856e-01,
                          2.24472076e-01,   2.25285813e-01,   2.26099536e-01,
                          2.26971388e-01,   2.27726981e-01,   2.28424460e-01,
                          2.29238197e-01,   2.30110034e-01,   2.30923772e-01,
                          2.31737494e-01,   2.32667461e-01,   2.33539313e-01,
                          2.34353036e-01,   2.35283017e-01,   2.36154854e-01,
                          2.36852333e-01,   2.37724185e-01,   2.38712281e-01,
                          2.39700377e-01,   2.40630358e-01,   2.41444081e-01,
                          2.42432177e-01,   2.43129656e-01,   2.43885249e-01,
                          2.45047718e-01,   2.45745197e-01,   2.46326432e-01,
                          2.47372657e-01,   2.48012006e-01,   2.48651370e-01,
                          2.49406964e-01,   2.50162572e-01,   2.51034409e-01,
                          2.51557529e-01,   2.52138764e-01,   2.52894372e-01,
                          2.53475606e-01,   2.54231185e-01,   2.54870564e-01,
                          2.55451798e-01,   2.56033033e-01,   2.56439894e-01,
                          2.57137358e-01,   2.57660478e-01,   2.58241713e-01,
                          2.58997321e-01,   2.59287924e-01,   2.59694785e-01,
                          2.60334134e-01,   2.60857254e-01,   2.61380374e-01,
                          2.61845350e-01,   2.62194097e-01,   2.62659073e-01,
                          2.63124049e-01,   2.63589054e-01,   2.63937771e-01,
                          2.64402777e-01,   2.64867753e-01,   2.65390873e-01,
                          2.65855849e-01,   2.66030222e-01,   2.66495198e-01,
                          2.66902059e-01,   2.67134577e-01,   2.67657667e-01,
                          2.68064529e-01,   2.68413275e-01,   2.68762022e-01,
                          2.68936396e-01,   2.69168884e-01,   2.69459486e-01,
                          2.69691974e-01,   2.69866347e-01,   2.70098865e-01,
                          2.70273209e-01,   2.70331353e-01,   2.70447582e-01,
                          2.70563841e-01,   2.70447582e-01,   2.70505726e-01,
                          2.70563841e-01,   2.70447582e-01,   2.70447582e-01,
                          2.70389467e-01,   2.70331353e-01,   2.69924492e-01,
                          2.69517630e-01,   2.69459486e-01,   2.69168884e-01,
                          2.68820137e-01,   2.68529534e-01,   2.68122673e-01,
                          2.67890155e-01,   2.67425179e-01,   2.66843945e-01,
                          2.66320825e-01,   2.65797734e-01,   2.65216500e-01,
                          2.64635265e-01,   2.64112145e-01,   2.63589054e-01,
                          2.62949675e-01,   2.62310326e-01,   2.61438489e-01,
                          2.60682881e-01,   2.59927273e-01,   2.59113550e-01,
                          2.58299828e-01,   2.57544219e-01,   2.56614238e-01,
                          2.55742401e-01,   2.54812419e-01,   2.53940582e-01,
                          2.52952486e-01,   2.52080649e-01,   2.51325041e-01,
                          2.50162572e-01,   2.49116346e-01,   2.48360753e-01,
                          2.47314528e-01,   2.46326432e-01,   2.45163962e-01,
                          2.43943378e-01,   2.43013412e-01,   2.41734698e-01,
                          2.40514100e-01,   2.39467889e-01,   2.38305420e-01,
                          2.37142950e-01,   2.35747993e-01,   2.34353036e-01,
                          2.33132452e-01,   2.31737494e-01,   2.30284408e-01,
                          2.28715077e-01,   2.27320120e-01,   2.26041406e-01,
                          2.24413961e-01,   2.23019004e-01,   2.21449673e-01,
                          2.19531611e-01,   2.17962280e-01,   2.16160446e-01,
                          2.14533001e-01,   2.13079914e-01,   2.11103722e-01,
                          2.09360033e-01,   2.07616329e-01,   2.05523893e-01,
                          2.03838319e-01,   2.01978371e-01,   1.99944064e-01,
                          1.98142245e-01,   1.95991680e-01,   1.93841115e-01,
                          1.91981167e-01,   1.89888731e-01,   1.87738180e-01,
                          1.85587615e-01,   1.83495179e-01,   1.81286484e-01,
                          1.79135934e-01,   1.77043498e-01,   1.74776688e-01,
                          1.72567993e-01,   1.70301184e-01,   1.67976260e-01,
                          1.65709451e-01,   1.63442641e-01,   1.61175832e-01,
                          1.59083396e-01,   1.56700343e-01,   1.54259175e-01,
                          1.51934236e-01,   1.49667427e-01,   1.47168130e-01,
                          1.44843191e-01,   1.42518267e-01,   1.40018970e-01,
                          1.37635916e-01,   1.35252863e-01,   1.32695436e-01,
                          1.30312383e-01,   1.27871200e-01,   1.25255659e-01,
                          1.22814476e-01,   1.20431423e-01,   1.17873996e-01,
                          1.15200326e-01,   1.12584777e-01,   1.09969236e-01,
                          1.07353687e-01,   1.04680017e-01,   1.01948224e-01,
                          9.93326753e-02,   9.64846313e-02,   9.36365947e-02,
                          9.10791680e-02,   8.81148800e-02,   8.53249654e-02,
                          8.26512948e-02,   7.94545114e-02,   7.64902309e-02,
                          7.37003088e-02,   7.06778988e-02,   6.78298622e-02,
                          6.48074523e-02,   6.16687946e-02,   5.86463846e-02,
                          5.54496013e-02,   5.23690693e-02,   4.94629070e-02,
                          4.64986190e-02,   4.33599614e-02,   4.01050597e-02,
                          3.69664021e-02,   3.37114967e-02,   3.05728409e-02,
                          2.74923090e-02,   2.41211578e-02,   2.09825020e-02,
                          1.79600921e-02,   1.46470647e-02,   1.13921613e-02,
                          8.13725870e-03,   5.05672488e-03,   1.97619130e-03,
                         -1.51120510e-03,  -4.76610847e-03,  -7.78851844e-03,
                         -1.09852990e-02,  -1.43564483e-02,  -1.76113527e-02,
                         -2.07500085e-02,  -2.40630358e-02,  -2.73179393e-02,
                         -3.04565951e-02,  -3.37696224e-02,  -3.70826498e-02,
                         -4.03956734e-02,  -4.37668264e-02,  -4.70217280e-02,
                         -5.02766334e-02,  -5.37059046e-02,  -5.71933016e-02,
                         -6.04482032e-02,  -6.37031049e-02,  -6.71323836e-02,
                         -7.02710375e-02,  -7.37584308e-02,  -7.73620754e-02,
                         -8.05007368e-02,  -8.39300081e-02,  -8.75917748e-02,
                         -9.10210460e-02,  -9.45665687e-02,  -9.78795961e-02,
                         -1.01366989e-01,  -1.05145000e-01,  -1.08632401e-01,
                         -1.12294167e-01,  -1.16014056e-01,  -1.19675823e-01,
                         -1.23453833e-01,  -1.26999348e-01,  -1.30486742e-01,
                         -1.34206638e-01,  -1.37926534e-01,  -1.41646415e-01,
                         -1.45424426e-01,  -1.49318695e-01,  -1.53096706e-01,
                         -1.56874716e-01,  -1.60710856e-01,  -1.64430737e-01,
                         -1.68266878e-01,  -1.72161132e-01,  -1.75881028e-01,
                         -1.79717168e-01,  -1.83553293e-01,  -1.87273189e-01,
                         -1.90993071e-01,  -1.94829211e-01,  -1.98781595e-01,
                         -2.02559605e-01,  -2.06395745e-01,  -2.10290000e-01,
                         -2.13951766e-01,  -2.17729777e-01,  -2.21624047e-01,
                         -2.25518301e-01,  -2.29354441e-01,  -2.33016208e-01,
                         -2.36968592e-01,  -2.40920961e-01,  -2.44698986e-01,
                         -2.48535112e-01,  -2.52429366e-01,  -2.56207377e-01,
                         -2.59985387e-01,  -2.63937771e-01,  -2.67890155e-01,
                         -2.71668166e-01,  -2.75504321e-01,  -2.79456705e-01,
                         -2.83292830e-01,  -2.87128985e-01,  -2.91081339e-01,
                         -2.95033723e-01,  -2.98869878e-01,  -3.02938491e-01,
                         -3.07123363e-01,  -3.10901403e-01,  -3.14795643e-01,
                         -3.18922400e-01,  -3.22816670e-01,  -3.26943427e-01,
                         -3.31012040e-01,  -3.34848166e-01,  -3.38916808e-01,
                         -3.42985451e-01,  -3.47054064e-01,  -3.51006448e-01,
                         -3.54842573e-01,  -3.58969331e-01,  -3.63096088e-01,
                         -3.67048472e-01,  -3.71117115e-01,  -3.75069469e-01,
                         -3.79196227e-01,  -3.83206755e-01,  -3.87042880e-01,
                         -3.91169637e-01,  -3.95063877e-01,  -3.98900032e-01,
                         -4.03026789e-01,  -4.06862915e-01,  -4.10640925e-01,
                         -4.14360821e-01,  -4.18196946e-01,  -4.22149330e-01,
                         -4.25869226e-01,  -4.29589123e-01,  -4.33483362e-01,
                         -4.37319517e-01,  -4.40923154e-01,  -4.44584906e-01,
                         -4.48479176e-01,  -4.52024698e-01,  -4.55628335e-01,
                         -4.59464490e-01,  -4.62777495e-01,  -4.66323018e-01,
                         -4.70217288e-01,  -4.73704666e-01,  -4.77366447e-01,
                         -4.80911970e-01,  -4.84108746e-01,  -4.87770498e-01,
                         -4.91490394e-01,  -4.94861543e-01,  -4.98232692e-01,
                         -5.01487613e-01,  -5.04858732e-01,  -5.08346140e-01,
                         -5.11833549e-01,  -5.15262842e-01,  -5.18575847e-01,
                         -5.22005141e-01,  -5.25318146e-01,  -5.28689265e-01,
                         -5.32176673e-01,  -5.35547853e-01,  -5.38802743e-01,
                         -5.41999519e-01,  -5.45196295e-01,  -5.48509359e-01,
                         -5.51647961e-01,  -5.54786623e-01,  -5.57983398e-01,
                         -5.61063945e-01,  -5.64086378e-01,  -5.67225039e-01,
                         -5.70479929e-01,  -5.73502362e-01,  -5.76350391e-01,
                         -5.79198420e-01,  -5.82046449e-01,  -5.84836364e-01,
                         -5.87626278e-01,  -5.90532482e-01,  -5.93322396e-01,
                         -5.95879793e-01,  -5.98553479e-01,  -6.01168990e-01,
                         -6.03610218e-01,  -6.06109500e-01,  -6.08376324e-01,
                         -6.10759377e-01,  -6.13142431e-01,  -6.15351081e-01,
                         -6.17850423e-01,  -6.20117188e-01,  -6.22093379e-01,
                         -6.24185860e-01,  -6.26103878e-01,  -6.28196359e-01,
                         -6.30230665e-01,  -6.32032454e-01,  -6.34008646e-01,
                         -6.35752380e-01,  -6.37554169e-01,  -6.39356017e-01,
                         -6.40925348e-01,  -6.42669022e-01,  -6.44354582e-01,
                         -6.45807683e-01,  -6.47551417e-01,  -6.49120688e-01,
                         -6.50399446e-01,  -6.51736259e-01,  -6.53131247e-01,
                         -6.54526174e-01,  -6.55863047e-01,  -6.57199860e-01,
                         -6.58246100e-01,  -6.59466684e-01,  -6.60977840e-01,
                         -6.61849737e-01,  -6.62721574e-01,  -6.63942158e-01,
                         -6.64872110e-01,  -6.65860236e-01,  -6.66732073e-01,
                         -6.67313278e-01,  -6.68185174e-01,  -6.69057012e-01,
                         -6.69754505e-01,  -6.70335710e-01,  -6.70858800e-01,
                         -6.71381950e-01,  -6.71730697e-01,  -6.72195673e-01,
                         -6.72602534e-01,  -6.72834992e-01,  -6.73125625e-01,
                         -6.73241854e-01,  -6.73300028e-01,  -6.73416257e-01,
                         -6.73532486e-01,  -6.73416257e-01,  -6.73241854e-01,
                         -6.73009396e-01,  -6.72602534e-01,  -6.72195673e-01,
                         -6.71614408e-01,  -6.70916975e-01,  -6.70451939e-01,
                         -6.69754505e-01,  -6.68824494e-01,  -6.68301404e-01,
                         -6.67487681e-01,  -6.66325212e-01,  -6.65395260e-01,
                         -6.64290905e-01,  -6.63186550e-01,  -6.62024081e-01,
                         -6.60570979e-01,  -6.59234166e-01,  -6.57664835e-01,
                         -6.56153619e-01,  -6.54700577e-01,  -6.52898729e-01,
                         -6.51387513e-01,  -6.49818182e-01,  -6.47725761e-01,
                         -6.45865798e-01,  -6.44005895e-01,  -6.42087817e-01,
                         -6.40053511e-01,  -6.37786686e-01,  -6.35868609e-01,
                         -6.33718073e-01,  -6.31218731e-01,  -6.28951967e-01,
                         -6.26568913e-01,  -6.24185860e-01,  -6.21919036e-01,
                         -6.19129121e-01,  -6.16513550e-01,  -6.14130497e-01,
                         -6.11514986e-01,  -6.08608782e-01,  -6.05993271e-01,
                         -6.03203356e-01,  -6.00122809e-01,  -5.97100377e-01,
                         -5.94194233e-01,  -5.91055572e-01,  -5.87975025e-01,
                         -5.84894478e-01,  -5.81697702e-01,  -5.78384697e-01,
                         -5.75013518e-01,  -5.71700513e-01,  -5.68271220e-01,
                         -5.64900100e-01,  -5.61354578e-01,  -5.57634711e-01,
                         -5.53914785e-01,  -5.50020516e-01,  -5.46358764e-01,
                         -5.42697012e-01,  -5.38802743e-01,  -5.35082877e-01,
                         -5.31130493e-01,  -5.27178109e-01,  -5.23341954e-01,
                         -5.19215226e-01,  -5.15088439e-01,  -5.10787308e-01,
                         -5.06369948e-01,  -5.02185106e-01,  -4.97883946e-01,
                         -4.93524700e-01,  -4.89223599e-01,  -4.85038728e-01,
                         -4.80737597e-01,  -4.76029605e-01,  -4.71437871e-01,
                         -4.66904253e-01,  -4.62196261e-01,  -4.57662642e-01,
                         -4.53012794e-01,  -4.48246688e-01,  -4.43480581e-01,
                         -4.38540101e-01,  -4.33773994e-01,  -4.29124117e-01,
                         -4.24299896e-01,  -4.19417530e-01,  -4.14418936e-01,
                         -4.09536570e-01,  -4.04654235e-01,  -3.99713755e-01,
                         -3.94831389e-01,  -3.89716536e-01,  -3.84717941e-01,
                         -3.79893720e-01,  -3.74836981e-01,  -3.69780272e-01,
                         -3.64723533e-01,  -3.59492451e-01,  -3.54435712e-01,
                         -3.49262744e-01,  -3.44089776e-01,  -3.39091182e-01,
                         -3.33976328e-01,  -3.28803360e-01,  -3.23688507e-01,
                         -3.18457425e-01,  -3.13168198e-01,  -3.07937115e-01,
                         -3.02764118e-01,  -2.97474921e-01,  -2.92243809e-01,
                         -2.87070841e-01,  -2.81723499e-01,  -2.76376158e-01,
                         -2.71203190e-01,  -2.65797734e-01,  -2.60217905e-01,
                         -2.54870564e-01,  -2.49697581e-01,  -2.44408369e-01,
                         -2.38886654e-01,  -2.33423069e-01,  -2.28133842e-01,
                         -2.22844630e-01,  -2.17497289e-01,  -2.12033704e-01,
                         -2.06511989e-01,  -2.01222777e-01,  -1.95759192e-01,
                         -1.90004975e-01,  -1.84657633e-01,  -1.79426551e-01,
                         -1.73730463e-01,  -1.68383121e-01,  -1.62919536e-01,
                         -1.57397822e-01,  -1.52108610e-01,  -1.46586895e-01,
                         -1.41239554e-01,  -1.35950342e-01,  -1.30486742e-01,
                         -1.25197530e-01,  -1.19850188e-01,  -1.14619099e-01,
                         -1.09504245e-01,  -1.03982538e-01,  -9.87514406e-02,
                         -9.36365947e-02,  -8.83473754e-02,  -8.31744075e-02,
                         -7.79433101e-02,  -7.28284642e-02,  -6.75973669e-02,
                         -6.24243952e-02,  -5.73095493e-02,  -5.21946996e-02,
                         -4.70798500e-02,  -4.19650041e-02,  -3.69664021e-02,
                         -3.19096781e-02,  -2.67948285e-02,  -2.19124742e-02,
                         -1.69138722e-02,  -1.16827777e-02,  -6.80042291e-03,
                         -1.91806804e-03,   3.13865673e-03,   8.07913486e-03,
                          1.29033662e-02,   1.76113527e-02,   2.25518309e-02,
                          2.74923090e-02,   3.22002918e-02,   3.70245241e-02,
                          4.18487564e-02,   4.65567410e-02,   5.13228513e-02,
                          5.60308360e-02,   6.06806986e-02,   6.52724355e-02,
                          6.98641762e-02,   7.46302828e-02,   7.92801455e-02,
                          8.36975127e-02,   8.83473754e-02,   9.28228647e-02,
                          9.72402394e-02,   1.01831973e-01,   1.06249347e-01,
                          1.10492341e-01,   1.14851587e-01,   1.19094588e-01,
                          1.23395711e-01,   1.27580583e-01,   1.31765455e-01,
                          1.35892212e-01,   1.40018970e-01,   1.44145712e-01,
                          1.48214340e-01,   1.52108610e-01,   1.56002864e-01,
                          1.59839004e-01,   1.63675144e-01,   1.67627513e-01,
                          1.71521783e-01,   1.75125420e-01,   1.78845316e-01,
                          1.82565197e-01,   1.86226964e-01,   1.89830616e-01,
                          1.93259880e-01,   1.96747273e-01,   2.00350925e-01,
                          2.03605831e-01,   2.07093224e-01,   2.10638747e-01,
                          2.14009896e-01,   2.17497289e-01,   2.20926568e-01,
                          2.24123344e-01,   2.27145746e-01,   2.30284408e-01,
                          2.33597443e-01,   2.36677974e-01,   2.39467889e-01,
                          2.42490292e-01,   2.45628953e-01,   2.48709485e-01,
                          2.51615644e-01,   2.54521817e-01,   2.57369846e-01,
                          2.60159761e-01,   2.62949675e-01,   2.65507102e-01,
                          2.68238902e-01,   2.71028817e-01,   2.73586243e-01,
                          2.76143670e-01,   2.78642982e-01,   2.81084150e-01,
                          2.83583462e-01,   2.85966516e-01,   2.88465798e-01,
                          2.90732622e-01,   2.92941302e-01,   2.95149982e-01,
                          2.97242433e-01,   2.99567342e-01,   3.01717907e-01,
                          3.03577870e-01,   3.05728406e-01,   3.07762742e-01,
                          3.09622675e-01,   3.11540753e-01,   3.13284457e-01,
                          3.15144390e-01,   3.16713721e-01,   3.18166792e-01,
                          3.20084870e-01,   3.21828574e-01,   3.23223531e-01,
                          3.24676603e-01,   3.26071560e-01,   3.27524632e-01,
                          3.28977734e-01,   3.30198318e-01,   3.31418902e-01,
                          3.32755744e-01,   3.33918214e-01,   3.35022539e-01,
                          3.36301267e-01,   3.37463737e-01,   3.38393688e-01,
                          3.39381784e-01,   3.40428025e-01,   3.41299862e-01,
                          3.42113584e-01,   3.43101680e-01,   3.44031662e-01,
                          3.44787270e-01,   3.45426619e-01,   3.46182227e-01,
                          3.46879691e-01,   3.47519040e-01,   3.48158419e-01,
                          3.48913997e-01,   3.49611491e-01,   3.49902093e-01,
                          3.50250840e-01,   3.50832075e-01,   3.51355195e-01,
                          3.51820171e-01,   3.52285147e-01,   3.52575779e-01,
                          3.52750152e-01,   3.52924526e-01,   3.53215128e-01,
                          3.53447616e-01,   3.53680104e-01,   3.53912622e-01,
                          3.54086995e-01,   3.54377598e-01,   3.54493856e-01,
                          3.54435712e-01,   3.54551971e-01,   3.54493856e-01,
                          3.54435712e-01,   3.54493856e-01,   3.54261339e-01,
                          3.54203224e-01,   3.54203224e-01,   3.53912622e-01,
                          3.53738248e-01,   3.53505760e-01,   3.53331387e-01,
                          3.53215128e-01,   3.52866381e-01,   3.52575779e-01,
                          3.52285147e-01,   3.52052659e-01,   3.51645797e-01,
                          3.51180822e-01,   3.50948334e-01,   3.50541472e-01,
                          3.50134611e-01,   3.49611491e-01,   3.48972142e-01,
                          3.48623395e-01,   3.48158419e-01,   3.47635299e-01,
                          3.47228438e-01,   3.46647203e-01,   3.46124083e-01,
                          3.45659107e-01,   3.45077872e-01,   3.44612896e-01,
                          3.44089776e-01,   3.43450427e-01,   3.42869192e-01,
                          3.42287958e-01,   3.41764838e-01,   3.41067374e-01,
                          3.40311766e-01,   3.39730531e-01,   3.39265555e-01,
                          3.38800550e-01,   3.38161200e-01,   3.37521851e-01,
                          3.36940616e-01,   3.36243123e-01,   3.35545659e-01,
                          3.34964424e-01,   3.34325075e-01,   3.33743840e-01,
                          3.33104491e-01,   3.32406998e-01,   3.31825763e-01,
                          3.31302673e-01,   3.30663294e-01,   3.29965830e-01,
                          3.29442710e-01,   3.28803360e-01,   3.28105867e-01,
                          3.27466518e-01,   3.26652795e-01,   3.26013446e-01,
                          3.25548440e-01,   3.24850976e-01,   3.24211627e-01,
                          3.23688507e-01,   3.22932899e-01,   3.22119176e-01,
                          3.21363568e-01,   3.20840478e-01,   3.20259243e-01,
                          3.19561750e-01,   3.18806142e-01,   3.17992419e-01,
                          3.17411184e-01,   3.16771835e-01,   3.16016227e-01,
                          3.15434992e-01,   3.14679414e-01,   3.14040035e-01,
                          3.13458800e-01,   3.12645078e-01,   3.12005728e-01,
                          3.11424494e-01,   3.10727030e-01,   3.09913307e-01,
                          3.09215814e-01,   3.08692694e-01,   3.07937115e-01,
                          3.07297736e-01,   3.06716502e-01,   3.05960923e-01,
                          3.05321544e-01,   3.04798454e-01,   3.04217219e-01,
                          3.03577870e-01,   3.02880377e-01,   3.02415401e-01,
                          3.01776022e-01,   3.01078558e-01,   3.00729811e-01,
                          3.00148576e-01,   2.99567342e-01,   2.99160480e-01,
                          2.98521131e-01,   2.97998011e-01,   2.97416776e-01,
                          2.96951801e-01,   2.96661198e-01,   2.96196193e-01,
                          2.95789331e-01,   2.95382470e-01,   2.94859380e-01,
                          2.94452488e-01,   2.94045627e-01,   2.93522537e-01,
                          2.93057531e-01,   2.92534441e-01,   2.92185694e-01,
                          2.91895092e-01,   2.91430086e-01,   2.91081339e-01,
                          2.90674478e-01,   2.90267617e-01,   2.89802641e-01,
                          2.89453894e-01,   2.89163291e-01,   2.88582057e-01,
                          2.88233310e-01,   2.87884563e-01,   2.87361473e-01,
                          2.86896467e-01,   2.86489606e-01,   2.86431491e-01,
                          2.86082745e-01,   2.85443395e-01,   2.85210907e-01,
                          2.84745902e-01,   2.84048438e-01,   2.83815950e-01,
                          2.83350945e-01,   2.83118457e-01,   2.82885969e-01,
                          2.82304734e-01,   2.81955987e-01,   2.81549126e-01,
                          2.81142265e-01,   2.80909777e-01,   2.80444801e-01,
                          2.80212313e-01,   2.79921681e-01,   2.79572934e-01,
                          2.79224217e-01,   2.78875470e-01,   2.78584838e-01,
                          2.78410494e-01,   2.78119862e-01,   2.77771115e-01,
                          2.77480513e-01,   2.77364254e-01,   2.76899278e-01,
                          2.76608646e-01,   2.76376158e-01,   2.76085556e-01,
                          2.75969297e-01,   2.75620550e-01,   2.75329947e-01,
                          2.75155574e-01,   2.74864972e-01,   2.74806827e-01,
                          2.74458110e-01,   2.74109364e-01,   2.74225593e-01,
                          2.74051219e-01,   2.73644358e-01,   2.73586243e-01,
                          2.73644358e-01,   2.73295641e-01,   2.72888780e-01,
                          2.72888780e-01,   2.72598147e-01,   2.72423774e-01,
                          2.72540033e-01,   2.72133172e-01,   2.71958798e-01,
                          2.71958798e-01,   2.71610051e-01,   2.71551937e-01,
                          2.71377563e-01,   2.71145076e-01,   2.71261305e-01,
                          2.71203190e-01,   2.70912588e-01,   2.70854443e-01,
                          2.70854443e-01,   2.70563841e-01,   2.70447582e-01,
                          2.70389467e-01,   2.70331353e-01,   2.70331353e-01,
                          2.70273209e-01,   2.70156980e-01,   2.70273209e-01,
                          2.70215094e-01,   2.70098865e-01,   2.70156980e-01,
                          2.70098865e-01,   2.70098865e-01,   2.70273209e-01,
                          2.70331353e-01,   2.70389467e-01,   2.70389467e-01,
                          2.70447582e-01,   2.70738214e-01,   2.70912588e-01,
                          2.70796329e-01,   2.70912588e-01,   2.71203190e-01,
                          2.71435678e-01,   2.71435678e-01,   2.71668166e-01,
                          2.72133172e-01,   2.72249401e-01,   2.72423774e-01,
                          2.72772521e-01,   2.73005009e-01,   2.73237497e-01,
                          2.73644358e-01,   2.73993105e-01,   2.74283737e-01,
                          2.74574339e-01,   2.74923086e-01,   2.75155574e-01,
                          2.75620550e-01,   2.76085556e-01,   2.76376158e-01,
                          2.76783019e-01,   2.76957393e-01,   2.77364254e-01,
                          2.77771115e-01,   2.78003603e-01,   2.78642982e-01,
                          2.78991699e-01,   2.79224217e-01,   2.79805452e-01,
                          2.80096054e-01,   2.80444801e-01,   2.80851662e-01,
                          2.81316638e-01,   2.81723499e-01,   2.81955987e-01,
                          2.82420993e-01,   2.82711595e-01,   2.82944083e-01,
                          2.83467203e-01,   2.83874065e-01,   2.84222811e-01,
                          2.84571558e-01,   2.84862161e-01,   2.85385281e-01,
                          2.85675883e-01,   2.85966516e-01,   2.86315233e-01,
                          2.86373377e-01,   2.86780238e-01,   2.87245214e-01,
                          2.87593961e-01,   2.87942708e-01,   2.87884563e-01,
                          2.88175195e-01,   2.88582057e-01,   2.88640171e-01,
                          2.89105147e-01,   2.89395779e-01,   2.89570153e-01,
                          2.89802641e-01,   2.89918900e-01,   2.90209502e-01,
                          2.90500134e-01,   2.90558249e-01,   2.90732622e-01,
                          2.90790737e-01,   2.90965110e-01,   2.91139483e-01,
                          2.91139483e-01,   2.91371971e-01,   2.91604459e-01,
                          2.91778833e-01,   2.91895092e-01,   2.91895092e-01,
                          2.92069435e-01,   2.92185694e-01,   2.92301953e-01,
                          2.92301953e-01,   2.92185694e-01,   2.92360067e-01,
                          2.92476326e-01,   2.92243809e-01,   2.92243809e-01,
                          2.92127579e-01,   2.91953206e-01,   2.91836947e-01,
                          2.91836947e-01,   2.91836947e-01,   2.91546345e-01,
                          2.91255713e-01,   2.91139483e-01,   2.90906996e-01,
                          2.90616363e-01,   2.90267617e-01,   2.90093243e-01,
                          2.89860755e-01,   2.89337665e-01,   2.88988918e-01,
                          2.88640171e-01,   2.88233310e-01,   2.87884563e-01,
                          2.87245214e-01,   2.86838353e-01,   2.86431491e-01,
                          2.85908371e-01,   2.85385281e-01,   2.84920275e-01,
                          2.84455299e-01,   2.83641577e-01,   2.82885969e-01,
                          2.82420993e-01,   2.81723499e-01,   2.81316638e-01,
                          2.80793548e-01,   2.79689193e-01,   2.79107958e-01,
                          2.78526723e-01,   2.77480513e-01,   2.76666790e-01,
                          2.75911182e-01,   2.74981201e-01,   2.74109364e-01,
                          2.73353755e-01,   2.72540033e-01,   2.71784425e-01,
                          2.70912588e-01,   2.69808233e-01,   2.69052625e-01,
                          2.68006414e-01,   2.66727716e-01,   2.65972108e-01,
                          2.64984012e-01,   2.63763428e-01,   2.62717187e-01,
                          2.61554718e-01,   2.60508507e-01,   2.59287924e-01,
                          2.57951081e-01,   2.57079244e-01,   2.55742401e-01,
                          2.54463702e-01,   2.53475606e-01,   2.52254993e-01,
                          2.50860035e-01,   2.49465093e-01,   2.48186380e-01,
                          2.46849537e-01,   2.45222092e-01,   2.43827134e-01,
                          2.42432177e-01,   2.40804717e-01,   2.39467889e-01,
                          2.37898558e-01,   2.36329228e-01,   2.34701782e-01,
                          2.33016208e-01,   2.31563121e-01,   2.29935676e-01,
                          2.28191972e-01,   2.26506397e-01,   2.24704579e-01,
                          2.23077118e-01,   2.21275300e-01,   2.19647855e-01,
                          2.17962280e-01,   2.15927958e-01,   2.14242384e-01,
                          2.12382436e-01,   2.10406244e-01,   2.08662555e-01,
                          2.06918851e-01,   2.05000788e-01,   2.02850223e-01,
                          2.00990275e-01,   1.99188456e-01,   1.97096020e-01,
                          1.95294201e-01,   1.93376124e-01,   1.91167444e-01,
                          1.89191252e-01,   1.87156945e-01,   1.85238868e-01,
                          1.83204561e-01,   1.81053996e-01,   1.79135934e-01,
                          1.76985368e-01,   1.74834803e-01,   1.72858611e-01,
                          1.70649931e-01,   1.68673739e-01,   1.66523173e-01,
                          1.64256364e-01,   1.62163928e-01,   1.59897119e-01,
                          1.57688439e-01,   1.55421630e-01,   1.53038576e-01,
                          1.50888011e-01,   1.48504958e-01,   1.46180034e-01,
                          1.43913224e-01,   1.41413927e-01,   1.39088988e-01,
                          1.36647820e-01,   1.34090394e-01,   1.31707340e-01,
                          1.29208043e-01,   1.26824990e-01,   1.24267556e-01,
                          1.21652015e-01,   1.19152710e-01,   1.16653413e-01,
                          1.14095986e-01,   1.11538559e-01,   1.08923018e-01,
                          1.06191218e-01,   1.03343181e-01,   1.00727633e-01,
                          9.81120840e-02,   9.54384133e-02,   9.28228647e-02,
                          9.00329500e-02,   8.73011574e-02,   8.46274868e-02,
                          8.17794427e-02,   7.91057721e-02,   7.63739794e-02,
                          7.35259429e-02,   7.07941502e-02,   6.80042282e-02,
                          6.52143136e-02,   6.24243952e-02,   5.94019853e-02,
                          5.66120669e-02,   5.38221523e-02,   5.10322340e-02,
                          4.81841937e-02,   4.52780314e-02,   4.23718654e-02,
                          3.96400727e-02,   3.67920324e-02,   3.39439921e-02,
                          3.09797041e-02,   2.82479115e-02,   2.53998712e-02,
                          2.24355832e-02,   1.94712970e-02,   1.66232567e-02,
                          1.37752155e-02,   1.06365588e-02,   7.43977912e-03,
                          4.70798509e-03,   1.74369826e-03,  -1.39495858e-03,
                         -4.41736868e-03,  -7.32353237e-03,  -1.01715727e-02,
                         -1.34264762e-02,  -1.64488871e-02,  -1.94131732e-02,
                         -2.27262005e-02,  -2.58067325e-02,  -2.88872663e-02,
                         -3.20840478e-02,  -3.51645797e-02,  -3.84776071e-02,
                         -4.16162647e-02,  -4.46386747e-02,  -4.77773324e-02,
                         -5.09741120e-02,  -5.44033833e-02,  -5.77164106e-02,
                         -6.09713122e-02,  -6.42843395e-02,  -6.74229935e-02,
                         -7.07360208e-02,  -7.40490481e-02,  -7.72458315e-02,
                         -8.06751028e-02,  -8.39881301e-02,  -8.73011574e-02,
                         -9.06141847e-02,  -9.38690901e-02,  -9.71821100e-02,
                         -1.00553267e-01,  -1.03924416e-01,  -1.07237436e-01,
                         -1.10550463e-01,  -1.13805369e-01,  -1.17002152e-01,
                         -1.20547667e-01,  -1.23976946e-01,  -1.27289966e-01,
                         -1.30719244e-01,  -1.33974150e-01,  -1.37519658e-01,
                         -1.40832692e-01,  -1.43971354e-01,  -1.47574991e-01,
                         -1.50829896e-01,  -1.54084802e-01,  -1.57630324e-01,
                         -1.60827100e-01,  -1.64372623e-01,  -1.67918131e-01,
                         -1.71231166e-01,  -1.74776688e-01,  -1.78147838e-01,
                         -1.81518987e-01,  -1.85180753e-01,  -1.88610017e-01,
                         -1.92097425e-01,  -1.95759192e-01,  -1.99246585e-01,
                         -2.02617735e-01,  -2.06221372e-01,  -2.09941268e-01,
                         -2.13486791e-01,  -2.17090428e-01,  -2.20810309e-01,
                         -2.24239588e-01,  -2.27726981e-01,  -2.31504992e-01,
                         -2.35108644e-01,  -2.38770410e-01,  -2.42432177e-01,
                         -2.46093944e-01,  -2.49930069e-01,  -2.53533721e-01,
                         -2.57195473e-01,  -2.60915369e-01,  -2.64577150e-01,
                         -2.68238902e-01,  -2.71958798e-01,  -2.75853068e-01,
                         -2.79572934e-01,  -2.83060342e-01,  -2.86838353e-01,
                         -2.90674478e-01,  -2.94452488e-01,  -2.98114270e-01,
                         -3.01659793e-01,  -3.05379689e-01,  -3.09041440e-01,
                         -3.12645078e-01,  -3.16481233e-01,  -3.20026755e-01,
                         -3.23688507e-01,  -3.27466518e-01,  -3.30953926e-01,
                         -3.34731936e-01,  -3.38393688e-01,  -3.41822982e-01,
                         -3.45600992e-01,  -3.49262744e-01,  -3.52750152e-01,
                         -3.56470048e-01,  -3.60073686e-01,  -3.63561064e-01,
                         -3.67222846e-01,  -3.70710224e-01,  -3.74197632e-01,
                         -3.77743155e-01,  -3.81114304e-01,  -3.84485453e-01,
                         -3.88147205e-01,  -3.91750872e-01,  -3.95122021e-01,
                         -3.98725659e-01,  -4.02154922e-01,  -4.05526072e-01,
                         -4.09187853e-01,  -4.12675232e-01,  -4.16220754e-01,
                         -4.19533789e-01,  -4.22788680e-01,  -4.26334202e-01,
                         -4.29821610e-01,  -4.33192760e-01,  -4.36680168e-01,
                         -4.40051317e-01,  -4.43364322e-01,  -4.46793616e-01,
                         -4.50280994e-01,  -4.53710258e-01,  -4.57023293e-01,
                         -4.60336328e-01,  -4.63765591e-01,  -4.67194885e-01,
                         -4.70507890e-01,  -4.73704666e-01,  -4.76959586e-01,
                         -4.80214477e-01,  -4.83527511e-01,  -4.86724287e-01,
                         -4.89979208e-01,  -4.93350357e-01,  -4.96547133e-01,
                         -4.99453276e-01,  -5.02475679e-01,  -5.05788743e-01,
                         -5.08869231e-01,  -5.11601031e-01,  -5.14681578e-01,
                         -5.17645895e-01,  -5.20435810e-01,  -5.23690701e-01,
                         -5.26596844e-01,  -5.29096186e-01,  -5.32002330e-01,
                         -5.34850359e-01,  -5.37640274e-01,  -5.40430188e-01,
                         -5.42987645e-01,  -5.45661271e-01,  -5.48451185e-01,
                         -5.51008642e-01,  -5.53275466e-01,  -5.55716634e-01,
                         -5.58332145e-01,  -5.60657084e-01,  -5.63156366e-01,
                         -5.65655708e-01,  -5.67922533e-01,  -5.70363700e-01,
                         -5.72572351e-01,  -5.74722946e-01,  -5.76989710e-01,
                         -5.79024076e-01,  -5.81232727e-01,  -5.83383322e-01,
                         -5.85417628e-01,  -5.87510049e-01,  -5.89253724e-01,
                         -5.91346204e-01,  -5.93554854e-01,  -5.95240414e-01,
                         -5.97332895e-01,  -5.99309087e-01,  -6.00994647e-01,
                         -6.02854609e-01,  -6.04714513e-01,  -6.06632590e-01,
                         -6.08376324e-01,  -6.09887481e-01,  -6.11631215e-01,
                         -6.12909913e-01,  -6.14363015e-01,  -6.15990460e-01,
                         -6.17501676e-01,  -6.18896604e-01,  -6.20117188e-01,
                         -6.21454060e-01,  -6.22848988e-01,  -6.23953342e-01,
                         -6.25290155e-01,  -6.26394510e-01,  -6.27382636e-01,
                         -6.28603220e-01,  -6.29591286e-01,  -6.30521297e-01,
                         -6.31276846e-01,  -6.32148743e-01,  -6.33020580e-01,
                         -6.33427441e-01,  -6.34183049e-01,  -6.34822369e-01,
                         -6.35229230e-01,  -6.35810494e-01,  -6.36159241e-01,
                         -6.36333585e-01,  -6.36566103e-01,  -6.36972964e-01,
                         -6.37205422e-01,  -6.37147307e-01,  -6.37263596e-01,
                         -6.37321711e-01,  -6.37321711e-01,  -6.37321711e-01,
                         -6.37031078e-01,  -6.36914849e-01,  -6.36682332e-01,
                         -6.36217356e-01,  -6.35984838e-01,  -6.35519862e-01,
                         -6.35054886e-01,  -6.34822369e-01,  -6.34066761e-01,
                         -6.33369327e-01,  -6.32613719e-01,  -6.31567478e-01,
                         -6.30928159e-01,  -6.30230665e-01,  -6.29126310e-01,
                         -6.28196359e-01,  -6.27092004e-01,  -6.25871420e-01,
                         -6.24883294e-01,  -6.23778999e-01,  -6.22442126e-01,
                         -6.21105313e-01,  -6.19652212e-01,  -6.18199110e-01,
                         -6.17036700e-01,  -6.15525484e-01,  -6.13781750e-01,
                         -6.12270534e-01,  -6.10526860e-01,  -6.08492553e-01,
                         -6.06516361e-01,  -6.04598284e-01,  -6.02622092e-01,
                         -6.00471556e-01,  -5.98320961e-01,  -5.96228540e-01,
                         -5.93787372e-01,  -5.91404319e-01,  -5.88963151e-01,
                         -5.86405694e-01,  -5.84080756e-01,  -5.81290841e-01,
                         -5.78442812e-01,  -5.75885415e-01,  -5.73037326e-01,
                         -5.70014954e-01,  -5.66992521e-01,  -5.63970149e-01,
                         -5.61063945e-01,  -5.57925284e-01,  -5.54612279e-01,
                         -5.51182985e-01,  -5.47928095e-01,  -5.44673204e-01,
                         -5.41011453e-01,  -5.37640274e-01,  -5.34269154e-01,
                         -5.30607343e-01,  -5.27236223e-01,  -5.23574471e-01,
                         -5.19796431e-01,  -5.16134679e-01,  -5.12298524e-01,
                         -5.08404255e-01,  -5.04509985e-01,  -5.00790119e-01,
                         -4.97012109e-01,  -4.92943496e-01,  -4.89107341e-01,
                         -4.85096842e-01,  -4.80970085e-01,  -4.77017701e-01,
                         -4.72774714e-01,  -4.68531698e-01,  -4.64463085e-01,
                         -4.60161954e-01,  -4.55977082e-01,  -4.51850325e-01,
                         -4.47491080e-01,  -4.43015575e-01,  -4.38714474e-01,
                         -4.34238970e-01,  -4.29589123e-01,  -4.25287992e-01,
                         -4.20696259e-01,  -4.15755779e-01,  -4.11047786e-01,
                         -4.06339794e-01,  -4.01689947e-01,  -3.97156328e-01,
                         -3.92332107e-01,  -3.87507856e-01,  -3.82625520e-01,
                         -3.77510667e-01,  -3.72628301e-01,  -3.67804080e-01,
                         -3.62863600e-01,  -3.57806861e-01,  -3.52750152e-01,
                         -3.47635299e-01,  -3.42636704e-01,  -3.37638110e-01,
                         -3.32523257e-01,  -3.27350289e-01,  -3.22177291e-01,
                         -3.16888094e-01,  -3.11831355e-01,  -3.06658387e-01,
                         -3.01136672e-01,  -2.96021819e-01,  -2.90906996e-01,
                         -2.85559654e-01,  -2.80154169e-01,  -2.74690598e-01,
                         -2.69459486e-01,  -2.64112145e-01,  -2.58648574e-01,
                         -2.53301233e-01,  -2.48012006e-01,  -2.42897153e-01,
                         -2.37433568e-01,  -2.32144356e-01,  -2.26971388e-01,
                         -2.21565917e-01,  -2.16334820e-01,  -2.11219981e-01,
                         -2.05930755e-01,  -2.00641543e-01,  -1.95410445e-01,
                         -1.90179348e-01,  -1.85006380e-01,  -1.79659039e-01,
                         -1.74427941e-01,  -1.69254974e-01,  -1.64082006e-01,
                         -1.58850908e-01,  -1.53445438e-01,  -1.48214340e-01,
                         -1.43041372e-01,  -1.37868404e-01,  -1.32753551e-01,
                         -1.27522469e-01,  -1.22291364e-01,  -1.17002152e-01,
                         -1.11771055e-01,  -1.06598087e-01,  -1.01192616e-01,
                         -9.60777700e-02,  -9.09048021e-02,  -8.57318267e-02,
                         -8.06169808e-02,  -7.52696395e-02,  -7.01547936e-02,
                         -6.51561916e-02,  -5.98669723e-02,  -5.48683703e-02,
                         -4.98697683e-02,  -4.46967967e-02,  -3.96981947e-02,
                         -3.45833488e-02,  -2.95266230e-02,  -2.45280210e-02,
                         -1.94712970e-02,  -1.45889418e-02,  -9.70658660e-03,
                         -4.64986172e-03,   2.90616357e-04,   5.11484826e-03,
                          9.99720301e-03,   1.48214344e-02,   1.97037905e-02,
                          2.45861448e-02,   2.93522533e-02,   3.40021141e-02,
                          3.88263464e-02,   4.35343310e-02,   4.81260717e-02,
                          5.28921783e-02,   5.73095493e-02,   6.16687946e-02,
                          6.62024096e-02,   7.06778988e-02,   7.50371441e-02,
                          7.93382674e-02,   8.36393908e-02,   8.78823921e-02,
                          9.20091420e-02,   9.63102654e-02,   1.00553267e-01,
                          1.04796261e-01,   1.08748645e-01,   1.12642907e-01,
                          1.16944022e-01,   1.20896406e-01,   1.24732547e-01,
                          1.28801167e-01,   1.32404819e-01,   1.36182830e-01,
                          1.40193328e-01,   1.43913224e-01,   1.47691235e-01,
                          1.51353002e-01,   1.55014768e-01,   1.58734664e-01,
                          1.62222058e-01,   1.66000068e-01,   1.69661835e-01,
                          1.73032984e-01,   1.76636621e-01,   1.80124030e-01,
                          1.83437049e-01,   1.86691955e-01,   1.90121233e-01,
                          1.93608627e-01,   1.96805403e-01,   2.00002179e-01,
                          2.03257084e-01,   2.06279501e-01,   2.09534407e-01,
                          2.12731183e-01,   2.15695471e-01,   2.18776003e-01,
                          2.21798405e-01,   2.24646449e-01,   2.27552623e-01,
                          2.30516896e-01,   2.33481184e-01,   2.36329228e-01,
                          2.39061028e-01,   2.41734698e-01,   2.44524613e-01,
                          2.47140154e-01,   2.49581337e-01,   2.52196878e-01,
                          2.54812419e-01,   2.57195473e-01,   2.59578526e-01,
                          2.61903465e-01,   2.64054030e-01,   2.66378969e-01,
                          2.68762022e-01,   2.70854443e-01,   2.72888780e-01,
                          2.75097460e-01,   2.77073652e-01,   2.78991699e-01,
                          2.81142265e-01,   2.83118457e-01,   2.84687787e-01,
                          2.86547750e-01,   2.88291425e-01,   2.89860755e-01,
                          2.91604459e-01,   2.93290049e-01,   2.94859380e-01,
                          2.96312451e-01,   2.97881782e-01,   2.99567342e-01,
                          3.00846070e-01,   3.02182913e-01,   3.03694099e-01,
                          3.04972827e-01,   3.06309640e-01,   3.07530254e-01,
                          3.08983326e-01,   3.10320169e-01,   3.11366379e-01,
                          3.12645078e-01,   3.13691318e-01,   3.14679414e-01,
                          3.15783739e-01,   3.16539347e-01,   3.17643702e-01,
                          3.18806142e-01,   3.19678009e-01,   3.20724219e-01,
                          3.21596086e-01,   3.22584182e-01,   3.23339760e-01,
                          3.24037254e-01,   3.25083464e-01,   3.25780958e-01,
                          3.26304048e-01,   3.27001542e-01,   3.27640891e-01,
                          3.28280240e-01,   3.28803360e-01,   3.29442710e-01,
                          3.30023944e-01,   3.30547065e-01,   3.30953926e-01,
                          3.31244528e-01,   3.31651390e-01,   3.32174510e-01,
                          3.32232624e-01,   3.32465112e-01,   3.32813859e-01,
                          3.32930118e-01,   3.32871974e-01,   3.32813859e-01,
                          3.33046347e-01,   3.33162606e-01,   3.33104491e-01,
                          3.33162606e-01,   3.33104491e-01,   3.33104491e-01,
                          3.33104491e-01,   3.32813859e-01,   3.32639486e-01,
                          3.32581371e-01,   3.32523257e-01,   3.32290769e-01,
                          3.32000136e-01,   3.32000136e-01,   3.31709534e-01,
                          3.31244528e-01,   3.31128299e-01,   3.30721438e-01,
                          3.30547065e-01,   3.30430806e-01,   3.30023944e-01,
                          3.29733342e-01,   3.29326481e-01,   3.28977734e-01,
                          3.28628987e-01,   3.28222126e-01,   3.27989638e-01,
                          3.27640891e-01,   3.27350289e-01,   3.27059656e-01,
                          3.26710910e-01,   3.26478422e-01,   3.26013446e-01,
                          3.25606585e-01,   3.25432211e-01,   3.25025350e-01,
                          3.24850976e-01,   3.24502230e-01,   3.23862880e-01,
                          3.23572248e-01,   3.23223531e-01,   3.22991043e-01,
                          3.22642297e-01,   3.22119176e-01,   3.21886688e-01,
                          3.21363568e-01,   3.20840478e-01,   3.20549846e-01,
                          3.19968611e-01,   3.19561750e-01,   3.19213003e-01,
                          3.18631798e-01,   3.18108678e-01,   3.17585558e-01,
                          3.17120582e-01,   3.16539347e-01,   3.15783739e-01,
                          3.15260649e-01,   3.14853758e-01,   3.14446896e-01,
                          3.13923806e-01,   3.13284457e-01,   3.12761337e-01,
                          3.12238216e-01,   3.11656982e-01,   3.11075747e-01,
                          3.10436398e-01,   3.09971422e-01,   3.09506416e-01,
                          3.09157699e-01,   3.08692694e-01,   3.07995230e-01,
                          3.07472110e-01,   3.07007134e-01,   3.06658387e-01,
                          3.06251526e-01,   3.05786550e-01,   3.05379689e-01,
                          3.04914683e-01,   3.04449707e-01,   3.04159075e-01,
                          3.03810358e-01,   3.03461611e-01,   3.03054750e-01,
                          3.02706003e-01,   3.02357256e-01,   3.02066654e-01,
                          3.01776022e-01,   3.01485419e-01,   3.01078558e-01,
                          3.00671697e-01,   3.00497323e-01,   3.00381064e-01,
                          2.99974203e-01,   2.99741715e-01,   2.99625486e-01,
                          2.99218625e-01,   2.98927993e-01,   2.98695505e-01,
                          2.98404872e-01,   2.98230529e-01,   2.97881782e-01,
                          2.97533035e-01,   2.97358662e-01,   2.97009915e-01,
                          2.96777427e-01,   2.96544939e-01,   2.96138078e-01,
                          2.95963705e-01,   2.95731217e-01,   2.95382470e-01,
                          2.95208097e-01,   2.95091867e-01,   2.94917494e-01,
                          2.94685006e-01,   2.94278145e-01,   2.93813139e-01,
                          2.93638766e-01,   2.93638766e-01,   2.93348163e-01,
                          2.93173790e-01,   2.92883188e-01,   2.92476326e-01,
                          2.92301953e-01,   2.92069435e-01,   2.91778833e-01,
                          2.91488230e-01,   2.91139483e-01,   2.91081339e-01,
                          2.90906996e-01,   2.90616363e-01,   2.90500134e-01,
                          2.90267617e-01,   2.90093243e-01,   2.90035129e-01,
                          2.89918900e-01,   2.89860755e-01,   2.89628267e-01,
                          2.89570153e-01,   2.89453894e-01,   2.89047033e-01,
                          2.88988918e-01,   2.88988918e-01,   2.88756430e-01,
                          2.88698286e-01,   2.88698286e-01,   2.88698286e-01,
                          2.88582057e-01,   2.88582057e-01,   2.88756430e-01,
                          2.88523942e-01,   2.88465798e-01,   2.88523942e-01,
                          2.88291425e-01,   2.88349569e-01,   2.88349569e-01,
                          2.88175195e-01,   2.88117081e-01,   2.88058937e-01,
                          2.88175195e-01,   2.88058937e-01,   2.87942708e-01,
                          2.87942708e-01,   2.87652075e-01,   2.87535846e-01,
                          2.87535846e-01,   2.87419587e-01,   2.87419587e-01,
                          2.87303329e-01,   2.87187099e-01,   2.87012726e-01,
                          2.86838353e-01,   2.86780238e-01,   2.86547750e-01,
                          2.86431491e-01,   2.86373377e-01,   2.86140889e-01,
                          2.86024630e-01,   2.85675883e-01,   2.85501510e-01,
                          2.85559654e-01,   2.85327137e-01,   2.85036534e-01,
                          2.84804046e-01,   2.84513414e-01,   2.84455299e-01,
                          2.84455299e-01,   2.84339041e-01,   2.84048438e-01,
                          2.83874065e-01,   2.83874065e-01,   2.83641577e-01,
                          2.83525318e-01,   2.83409089e-01,   2.83409089e-01,
                          2.83409089e-01,   2.83118457e-01,   2.83118457e-01,
                          2.83060342e-01,   2.82827854e-01,   2.83002228e-01,
                          2.83002228e-01,   2.82885969e-01,   2.83002228e-01,
                          2.82769740e-01,   2.82827854e-01,   2.83060342e-01,
                          2.82944083e-01,   2.83060342e-01,   2.83118457e-01,
                          2.83060342e-01,   2.83002228e-01,   2.83060342e-01,
                          2.83292830e-01,   2.83292830e-01,   2.83350945e-01,
                          2.83467203e-01,   2.83467203e-01,   2.83583462e-01,
                          2.83641577e-01,   2.83757836e-01,   2.83990324e-01,
                          2.83932179e-01,   2.83990324e-01,   2.84164697e-01,
                          2.84280926e-01,   2.84339041e-01,   2.84397185e-01,
                          2.84687787e-01,   2.84745902e-01,   2.84745902e-01,
                          2.84920275e-01,   2.84920275e-01,   2.85152793e-01,
                          2.85269022e-01,   2.85152793e-01,   2.85327137e-01,
                          2.85385281e-01,   2.85443395e-01,   2.85733998e-01,
                          2.85792142e-01,   2.85908371e-01,   2.86082745e-01,
                          2.86257118e-01,   2.86489606e-01,   2.86722094e-01,
                          2.86954612e-01,   2.87070841e-01,   2.87303329e-01,
                          2.87535846e-01,   2.87768334e-01,   2.88175195e-01,
                          2.88349569e-01,   2.88582057e-01,   2.89105147e-01,
                          2.89395779e-01,   2.89686382e-01,   2.89918900e-01,
                          2.90035129e-01,   2.90558249e-01,   2.91139483e-01,
                          2.91371971e-01,   2.91720718e-01,   2.92301953e-01,
                          2.92708814e-01,   2.93057531e-01,   2.93464422e-01,
                          2.93813139e-01,   2.94161886e-01,   2.94568747e-01,
                          2.94917494e-01,   2.95266241e-01,   2.95614958e-01,
                          2.95847476e-01,   2.96254337e-01,   2.96661198e-01,
                          2.96893686e-01,   2.97300547e-01,   2.97533035e-01,
                          2.97707409e-01,   2.98056155e-01,   2.98172385e-01,
                          2.98404872e-01,   2.98695505e-01,   2.98753619e-01,
                          2.98869878e-01,   2.99102366e-01,   2.99218625e-01,
                          2.99218625e-01,   2.99392968e-01,   2.99567342e-01,
                          2.99509227e-01,   2.99567342e-01,   2.99509227e-01,
                          2.99392968e-01,   2.99509227e-01,   2.99451113e-01,
                          2.99451113e-01,   2.99509227e-01,   2.99392968e-01,
                          2.99334854e-01,   2.99102366e-01,   2.98869878e-01,
                          2.98986107e-01,   2.98869878e-01,   2.98637390e-01,
                          2.98579246e-01,   2.98463017e-01,   2.98346758e-01,
                          2.98172385e-01,   2.97998011e-01,   2.97765523e-01,
                          2.97591150e-01,   2.97358662e-01,   2.97184289e-01,
                          2.97068059e-01,   2.96719313e-01,   2.96428680e-01,
                          2.96254337e-01,   2.95847476e-01,   2.95614958e-01,
                          2.95382470e-01,   2.95091867e-01,   2.94917494e-01,
                          2.94568747e-01,   2.93929398e-01,   2.93522537e-01,
                          2.93231905e-01,   2.92941302e-01,   2.92360067e-01,
                          2.91720718e-01,   2.91255713e-01,   2.90674478e-01,
                          2.90093243e-01,   2.89570153e-01,   2.88988918e-01,
                          2.88523942e-01,   2.87942708e-01,   2.87187099e-01,
                          2.86547750e-01,   2.85850257e-01,   2.85094649e-01,
                          2.84280926e-01,   2.83409089e-01,   2.82537222e-01,
                          2.81607270e-01,   2.80735403e-01,   2.79921681e-01,
                          2.78875470e-01,   2.77887374e-01,   2.77015507e-01,
                          2.75969297e-01,   2.74923086e-01,   2.73760617e-01,
                          2.72656262e-01,   2.71435678e-01,   2.70273209e-01,
                          2.69168884e-01,   2.67890155e-01,   2.66785830e-01,
                          2.65448987e-01,   2.64112145e-01,   2.63065934e-01,
                          2.61845350e-01,   2.60624766e-01,   2.59287924e-01,
                          2.57776707e-01,   2.56439894e-01,   2.55219281e-01,
                          2.53882468e-01,   2.52487510e-01,   2.51150668e-01,
                          2.49755710e-01,   2.48244494e-01,   2.46849537e-01,
                          2.45338336e-01,   2.43885249e-01,   2.42780909e-01,
                          2.41211578e-01,   2.39584133e-01,   2.38305420e-01,
                          2.36736089e-01,   2.35166758e-01,   2.33597443e-01,
                          2.31969982e-01,   2.30342537e-01,   2.28598833e-01,
                          2.27087632e-01,   2.25692675e-01,   2.23948970e-01,
                          2.22147152e-01,   2.20403448e-01,   2.18543515e-01,
                          2.16857940e-01,   2.14997992e-01,   2.13138044e-01,
                          2.11278096e-01,   2.09418148e-01,   2.07616329e-01,
                          2.05640137e-01,   2.03431457e-01,   2.01397136e-01,
                          1.99537203e-01,   1.97561011e-01,   1.95468575e-01,
                          1.93376124e-01,   1.91341817e-01,   1.89075008e-01,
                          1.86924443e-01,   1.84948251e-01,   1.82681441e-01,
                          1.80414647e-01,   1.78205952e-01,   1.75939143e-01,
                          1.73730463e-01,   1.71521783e-01,   1.69371217e-01,
                          1.67046294e-01,   1.64663240e-01,   1.62454545e-01,
                          1.60129622e-01,   1.57688439e-01,   1.55305386e-01,
                          1.52980462e-01,   1.50597408e-01,   1.48388714e-01,
                          1.46121904e-01,   1.43564492e-01,   1.41065180e-01,
                          1.38798371e-01,   1.36415318e-01,   1.34090394e-01,
                          1.31591097e-01,   1.29091784e-01,   1.26650617e-01,
                          1.24267556e-01,   1.21942624e-01,   1.19617693e-01,
                          1.17002152e-01,   1.14560969e-01,   1.12061672e-01,
                          1.09620497e-01,   1.07237436e-01,   1.04563765e-01,
                          1.02006346e-01,   9.95070413e-02,   9.68915001e-02,
                          9.43340734e-02,   9.17185247e-02,   8.91029760e-02,
                          8.66036788e-02,   8.39300081e-02,   8.11982155e-02,
                          7.86407888e-02,   7.59671181e-02,   7.31772035e-02,
                          7.03291595e-02,   6.75973669e-02,   6.49236962e-02,
                          6.20756559e-02,   5.92276156e-02,   5.67864366e-02,
                          5.40546440e-02,   5.10322340e-02,   4.82423156e-02,
                          4.53361534e-02,   4.24881130e-02,   3.98144424e-02,
                          3.67339104e-02,   3.39439921e-02,   3.13284434e-02,
                          2.82479115e-02,   2.52836235e-02,   2.24937070e-02,
                          1.96456667e-02,   1.68557484e-02,   1.37170926e-02,
                          1.06946826e-02,   7.84664229e-03,   4.99860151e-03,
                          1.91806804e-03,  -9.88095650e-04,  -3.77801270e-03,
                         -6.68417662e-03,  -9.64846369e-03,  -1.25546269e-02,
                         -1.55189140e-02,  -1.83088314e-02,  -2.11568717e-02,
                         -2.41792817e-02,  -2.70273220e-02,  -3.00497320e-02,
                         -3.29558961e-02,  -3.57458144e-02,  -3.85938548e-02,
                         -4.15000170e-02,  -4.45805490e-02,  -4.75448370e-02,
                         -5.03347553e-02,  -5.33571653e-02,  -5.60889579e-02,
                         -5.89951240e-02,  -6.19594082e-02,  -6.49236962e-02,
                         -6.80042282e-02,  -7.09103942e-02,  -7.39328042e-02,
                         -7.68970922e-02,  -7.95707628e-02,  -8.26512948e-02,
                         -8.58480781e-02,  -8.87542367e-02,  -9.16604027e-02,
                         -9.45665687e-02,  -9.77052227e-02,  -1.00727633e-01,
                         -1.03633799e-01,  -1.06888697e-01,  -1.09911107e-01,
                         -1.12875395e-01,  -1.16072178e-01,  -1.19036466e-01,
                         -1.22175120e-01,  -1.25313774e-01,  -1.28219947e-01,
                         -1.31416723e-01,  -1.34671628e-01,  -1.37694031e-01,
                         -1.40948936e-01,  -1.44029468e-01,  -1.47051886e-01,
                         -1.50306791e-01,  -1.53387323e-01,  -1.56467855e-01,
                         -1.59722760e-01,  -1.62745163e-01,  -1.65941939e-01,
                         -1.69254974e-01,  -1.72219262e-01,  -1.75416037e-01,
                         -1.78729072e-01,  -1.81693345e-01,  -1.84890136e-01,
                         -1.88028783e-01,  -1.90934956e-01,  -1.94247976e-01,
                         -1.97502881e-01,  -2.00641543e-01,  -2.03896448e-01,
                         -2.06976980e-01,  -2.10290000e-01,  -2.13486791e-01,
                         -2.16392949e-01,  -2.19647855e-01,  -2.22844630e-01,
                         -2.25925162e-01,  -2.29238197e-01,  -2.32260600e-01,
                         -2.35631749e-01,  -2.38886654e-01,  -2.41909057e-01,
                         -2.45222092e-01,  -2.48476997e-01,  -2.51673788e-01,
                         -2.54870564e-01,  -2.58067340e-01,  -2.61496603e-01,
                         -2.64577150e-01,  -2.67541438e-01,  -2.70912588e-01,
                         -2.73993105e-01,  -2.77248025e-01,  -2.80619174e-01,
                         -2.83815950e-01,  -2.87187099e-01,  -2.90500134e-01,
                         -2.93696910e-01,  -2.97009915e-01,  -3.00264835e-01,
                         -3.03577870e-01,  -3.07007134e-01,  -3.10145795e-01,
                         -3.13400686e-01,  -3.16829950e-01,  -3.19968611e-01,
                         -3.23281646e-01,  -3.26710910e-01,  -3.29791456e-01,
                         -3.33104491e-01,  -3.36591870e-01,  -3.39672416e-01,
                         -3.42752934e-01,  -3.45949709e-01,  -3.49146515e-01,
                         -3.52575779e-01,  -3.55772555e-01,  -3.58736843e-01,
                         -3.61875504e-01,  -3.65072280e-01,  -3.68269056e-01,
                         -3.71175230e-01,  -3.74139518e-01,  -3.77278179e-01,
                         -3.80358696e-01,  -3.83497357e-01,  -3.86577904e-01,
                         -3.89600307e-01,  -3.92680824e-01,  -3.95703256e-01,
                         -3.98783773e-01,  -4.01689947e-01,  -4.04712349e-01,
                         -4.07792896e-01,  -4.10524666e-01,  -4.13430840e-01,
                         -4.16569501e-01,  -4.19533789e-01,  -4.22381818e-01,
                         -4.25229877e-01,  -4.28194165e-01,  -4.31100309e-01,
                         -4.33948368e-01,  -4.36912656e-01,  -4.39586312e-01,
                         -4.42434371e-01,  -4.45514888e-01,  -4.48304802e-01,
                         -4.51094717e-01,  -4.53884631e-01,  -4.56616431e-01,
                         -4.59464490e-01,  -4.62254405e-01,  -4.64986175e-01,
                         -4.67717975e-01,  -4.70507890e-01,  -4.73297805e-01,
                         -4.75855231e-01,  -4.78587031e-01,  -4.81318831e-01,
                         -4.83818114e-01,  -4.86491799e-01,  -4.88991112e-01,
                         -4.91432279e-01,  -4.93931592e-01,  -4.96430874e-01,
                         -4.99046415e-01,  -5.01371384e-01,  -5.03754437e-01,
                         -5.06311834e-01,  -5.08404255e-01,  -5.10729194e-01,
                         -5.13112247e-01,  -5.15146554e-01,  -5.17413378e-01,
                         -5.19563913e-01,  -5.21714509e-01,  -5.23923159e-01,
                         -5.25957525e-01,  -5.28049946e-01,  -5.30026138e-01,
                         -5.32118559e-01,  -5.34094751e-01,  -5.35780311e-01,
                         -5.37872791e-01,  -5.39848983e-01,  -5.41476429e-01,
                         -5.43278217e-01,  -5.44905663e-01,  -5.46765625e-01,
                         -5.48567474e-01,  -5.49962401e-01,  -5.51706135e-01,
                         -5.53333580e-01,  -5.54728508e-01,  -5.56355953e-01,
                         -5.57925284e-01,  -5.59320271e-01,  -5.60715199e-01,
                         -5.62110186e-01,  -5.63446999e-01,  -5.64609468e-01,
                         -5.66120684e-01,  -5.67341268e-01,  -5.68445623e-01,
                         -5.69724321e-01,  -5.70712447e-01,  -5.71758628e-01,
                         -5.72921097e-01,  -5.73967338e-01,  -5.75013518e-01,
                         -5.75885415e-01,  -5.76931596e-01,  -5.77919722e-01,
                         -5.78617215e-01,  -5.79430938e-01,  -5.79954028e-01,
                         -5.80651522e-01,  -5.81523359e-01,  -5.81930220e-01,
                         -5.82511425e-01,  -5.83150804e-01,  -5.83557665e-01,
                         -5.84080756e-01,  -5.84487617e-01,  -5.84720135e-01,
                         -5.85126996e-01,  -5.85359514e-01,  -5.85475743e-01,
                         -5.85650086e-01,  -5.85882604e-01,  -5.85766375e-01,
                         -5.85708201e-01,  -5.85766375e-01,  -5.85533857e-01,
                         -5.85475743e-01,  -5.85301340e-01,  -5.84894478e-01,
                         -5.84487617e-01,  -5.83964527e-01,  -5.83557665e-01,
                         -5.82918286e-01,  -5.82395196e-01,  -5.81930220e-01,
                         -5.81058383e-01,  -5.80360889e-01,  -5.79663396e-01,
                         -5.78559041e-01,  -5.77745318e-01,  -5.76699138e-01,
                         -5.75362265e-01,  -5.74432313e-01,  -5.73327959e-01,
                         -5.72049260e-01,  -5.70770562e-01,  -5.69433689e-01,
                         -5.68154991e-01,  -5.66643775e-01,  -5.64900100e-01,
                         -5.63214540e-01,  -5.61645210e-01,  -5.60075879e-01,
                         -5.58274031e-01,  -5.56472242e-01,  -5.54612279e-01,
                         -5.52636087e-01,  -5.50834239e-01,  -5.48683703e-01,
                         -5.46533167e-01,  -5.44673204e-01,  -5.42406380e-01,
                         -5.40197730e-01,  -5.37989020e-01,  -5.35489738e-01,
                         -5.33164799e-01,  -5.30839860e-01,  -5.28398693e-01,
                         -5.26015639e-01,  -5.23458183e-01,  -5.20958900e-01,
                         -5.18110871e-01,  -5.15204668e-01,  -5.12647271e-01,
                         -5.09741127e-01,  -5.06951213e-01,  -5.04393756e-01,
                         -5.01429498e-01,  -4.98348951e-01,  -4.95384663e-01,
                         -4.92478490e-01,  -4.89281714e-01,  -4.86084938e-01,
                         -4.83062536e-01,  -4.79749501e-01,  -4.76436466e-01,
                         -4.73239690e-01,  -4.69810426e-01,  -4.66555506e-01,
                         -4.63068128e-01,  -4.59406346e-01,  -4.55977082e-01,
                         -4.52431560e-01,  -4.48886037e-01,  -4.45224285e-01,
                         -4.41446275e-01,  -4.37842607e-01,  -4.34122741e-01,
                         -4.30344731e-01,  -4.26508576e-01,  -4.22614306e-01,
                         -4.18661952e-01,  -4.14651424e-01,  -4.10815299e-01,
                         -4.06921029e-01,  -4.02794272e-01,  -3.98725659e-01,
                         -3.94598901e-01,  -3.90414029e-01,  -3.86345387e-01,
                         -3.82102400e-01,  -3.77975643e-01,  -3.73732656e-01,
                         -3.69373411e-01,  -3.65246654e-01,  -3.61003637e-01,
                         -3.56702536e-01,  -3.52459520e-01,  -3.48216534e-01,
                         -3.43857288e-01,  -3.39498043e-01,  -3.35255027e-01,
                         -3.30953926e-01,  -3.26420307e-01,  -3.22002947e-01,
                         -3.17643702e-01,  -3.13284457e-01,  -3.08925211e-01,
                         -3.04507822e-01,  -3.00148576e-01,  -2.95673102e-01,
                         -2.91255713e-01,  -2.86838353e-01,  -2.82362849e-01,
                         -2.78003603e-01,  -2.73528129e-01,  -2.68936396e-01,
                         -2.64577150e-01,  -2.59985387e-01,  -2.55451798e-01,
                         -2.50976294e-01,  -2.46384561e-01,  -2.41909057e-01,
                         -2.37433568e-01,  -2.32841834e-01,  -2.28366345e-01,
                         -2.23890856e-01,  -2.19415352e-01,  -2.14881748e-01,
                         -2.10173756e-01,  -2.05640137e-01,  -2.01106533e-01,
                         -1.96514785e-01,  -1.91923052e-01,  -1.87331304e-01,
                         -1.82913944e-01,  -1.78264081e-01,  -1.73497975e-01,
                         -1.68906227e-01,  -1.64256364e-01,  -1.59722760e-01,
                         -1.55189142e-01,  -1.50655523e-01,  -1.46121904e-01,
                         -1.41646415e-01,  -1.37345299e-01,  -1.32869810e-01,
                         -1.28336191e-01,  -1.23802572e-01,  -1.19327083e-01,
                         -1.14967838e-01,  -1.10492341e-01,  -1.06016852e-01,
                         -1.01541355e-01,  -9.71239880e-02,  -9.27066207e-02,
                         -8.81148800e-02,  -8.38718861e-02,  -7.95707628e-02,
                         -7.50371441e-02,  -7.07360208e-02,  -6.65511489e-02,
                         -6.22500256e-02,  -5.81232719e-02,  -5.38221523e-02,
                         -4.96953987e-02,  -4.55105230e-02,  -4.10931557e-02,
                         -3.70245241e-02,  -3.28977741e-02,  -2.87710205e-02,
                         -2.47605145e-02,  -2.06337627e-02,  -1.66813787e-02,
                         -1.27289966e-02,  -8.66036769e-03,  -4.64986172e-03,
                         -6.39356032e-04,   3.31302662e-03,   7.20728608e-03,
                          1.12759154e-02,   1.51120508e-02,   1.88900642e-02,
                          2.27843225e-02,   2.65623368e-02,   3.01659796e-02,
                          3.38277444e-02,   3.76638807e-02,   4.13256474e-02,
                          4.49292921e-02,   4.86491807e-02,   5.23109473e-02,
                          5.59145883e-02,   5.94019853e-02,   6.31799996e-02,
                          6.68417662e-02,   7.01547936e-02,   7.37584308e-02,
                          7.73620754e-02,   8.06169808e-02,   8.41043741e-02,
                          8.75917748e-02,   9.09629241e-02,   9.43921953e-02,
                          9.77052227e-02,   1.01076372e-01,   1.04273155e-01,
                          1.07469931e-01,   1.10724837e-01,   1.13921613e-01,
                          1.17060274e-01,   1.20140806e-01,   1.23105094e-01,
                          1.26185626e-01,   1.29149914e-01,   1.32114202e-01,
                          1.35078490e-01,   1.37984648e-01,   1.40890822e-01,
                          1.43738851e-01,   1.46645024e-01,   1.49493054e-01,
                          1.52166724e-01,   1.54956654e-01,   1.57630324e-01,
                          1.60071492e-01,   1.62803292e-01,   1.65593207e-01,
                          1.68208748e-01,   1.70708060e-01,   1.73091114e-01,
                          1.75706655e-01,   1.78380325e-01,   1.80763379e-01,
                          1.83146432e-01,   1.85529485e-01,   1.88028783e-01,
                          1.90411851e-01,   1.92562401e-01,   1.94887340e-01,
                          1.97154149e-01,   1.99362829e-01,   2.01745883e-01,
                          2.03954563e-01,   2.05930755e-01,   2.08023190e-01,
                          2.10290000e-01,   2.12498695e-01,   2.14533001e-01,
                          2.16567323e-01,   2.18543515e-01,   2.20577821e-01,
                          2.22495884e-01,   2.24355832e-01,   2.26273909e-01,
                          2.28250101e-01,   2.30051920e-01,   2.31853738e-01,
                          2.33539313e-01,   2.35457376e-01,   2.37375453e-01,
                          2.39002898e-01,   2.40630358e-01,   2.42315933e-01,
                          2.44001508e-01,   2.45570824e-01,   2.47198284e-01,
                          2.48825729e-01,   2.50453174e-01,   2.51906276e-01,
                          2.53243089e-01,   2.54812419e-01,   2.56323636e-01,
                          2.57602334e-01,   2.58997321e-01,   2.60217905e-01,
                          2.61438489e-01,   2.62775332e-01,   2.63879657e-01,
                          2.65158385e-01,   2.66378969e-01,   2.67250806e-01,
                          2.68413275e-01,   2.69691974e-01,   2.70738214e-01,
                          2.71610051e-01,   2.72598147e-01,   2.73586243e-01,
                          2.74399966e-01,   2.75271833e-01,   2.76376158e-01,
                          2.77306139e-01,   2.78236121e-01,   2.79166073e-01,
                          2.79979795e-01,   2.80619174e-01,   2.81549126e-01,
                          2.82479107e-01,   2.83118457e-01,   2.83874065e-01,
                          2.84804046e-01,   2.85501510e-01,   2.86199003e-01,
                          2.87012726e-01,   2.87768334e-01,   2.88407683e-01,
                          2.89047033e-01,   2.89744526e-01,   2.90441990e-01,
                          2.91023225e-01,   2.91662574e-01,   2.92360067e-01,
                          2.92941302e-01,   2.93522537e-01,   2.94103771e-01,
                          2.94685006e-01,   2.95324355e-01,   2.95789331e-01,
                          2.96428680e-01,   2.97068059e-01,   2.97533035e-01,
                          2.98056155e-01,   2.98521131e-01,   2.98986107e-01,
                          2.99392968e-01,   2.99857974e-01,   3.00322950e-01,
                          3.00555438e-01,   3.01078558e-01,   3.01543534e-01,
                          3.01834166e-01,   3.02357256e-01,   3.02531630e-01,
                          3.02880377e-01,   3.03345352e-01,   3.03519726e-01,
                          3.03984731e-01,   3.04217219e-01,   3.04449707e-01,
                          3.04972827e-01,   3.05147171e-01,   3.05379689e-01,
                          3.05670291e-01,   3.05844665e-01,   3.06193411e-01,
                          3.06251526e-01,   3.06484014e-01,   3.06774646e-01,
                          3.06890875e-01,   3.07297736e-01,   3.07530254e-01,
                          3.07704598e-01,   3.07995230e-01,   3.08111459e-01,
                          3.08634579e-01,   3.08983326e-01,   3.08925211e-01,
                          3.09273928e-01,   3.09564561e-01,   3.09797049e-01,
                          3.10029536e-01,   3.10262024e-01,   3.10668886e-01,
                          3.11017632e-01,   3.11366379e-01,   3.11598867e-01,
                          3.11947614e-01,   3.12354475e-01,   3.12470704e-01,
                          3.12761337e-01,   3.13284457e-01,   3.13516945e-01,
                          3.13923806e-01,   3.14098179e-01,   3.14446896e-01,
                          3.15028131e-01,   3.15086275e-01,   3.15260649e-01,
                          3.15783739e-01,   3.16016227e-01,   3.16364974e-01,
                          3.16771835e-01,   3.17004323e-01,   3.17236841e-01,
                          3.17469329e-01,   3.17818046e-01,   3.18050563e-01,
                          3.18283051e-01,   3.18573654e-01,   3.18864286e-01,
                          3.19213003e-01,   3.19271147e-01,   3.19329262e-01,
                          3.19619894e-01,   3.19910496e-01,   3.20142984e-01,
                          3.20375472e-01,   3.20666105e-01,   3.20782334e-01,
                          3.20898592e-01,   3.21131080e-01,   3.21305454e-01,
                          3.21537942e-01,   3.21770430e-01,   3.21828574e-01,
                          3.22061062e-01,   3.22235435e-01,   3.22293550e-01,
                          3.22642297e-01,   3.22816670e-01,   3.22991043e-01,
                          3.23397905e-01,   3.23572248e-01,   3.23746622e-01,
                          3.23979139e-01,   3.24095368e-01,   3.24444115e-01,
                          3.24792862e-01,   3.24909091e-01,   3.25257838e-01,
                          3.25490326e-01,   3.25606585e-01,   3.25664699e-01,
                          3.25955331e-01,   3.26362193e-01,   3.26594681e-01,
                          3.26885283e-01,   3.27059656e-01,   3.27234030e-01,
                          3.27466518e-01,   3.27815264e-01,   3.27989638e-01,
                          3.28164011e-01,   3.28338385e-01,   3.28570873e-01,
                          3.28687102e-01,   3.28861475e-01,   3.29035848e-01,
                          3.29210222e-01,   3.29326481e-01,   3.29442710e-01,
                          3.29733342e-01,   3.29965830e-01,   3.30082059e-01,
                          3.30198318e-01,   3.30198318e-01,   3.30256432e-01,
                          3.30372691e-01,   3.30372691e-01,   3.30488920e-01,
                          3.30488920e-01,   3.30430806e-01,   3.30488920e-01,
                          3.30663294e-01,   3.30779552e-01,   3.30605179e-01,
                          3.30605179e-01,   3.30779552e-01,   3.30547065e-01,
                          3.30430806e-01,   3.30430806e-01,   3.30430806e-01,
                          3.30430806e-01,   3.30198318e-01,   3.30198318e-01,
                          3.30198318e-01,   3.30082059e-01,   3.30023944e-01,
                          3.29965830e-01,   3.30140203e-01,   3.29965830e-01,
                          3.29617083e-01,   3.29733342e-01,   3.29558969e-01,
                          3.29442710e-01,   3.29617083e-01,   3.29326481e-01,
                          3.29326481e-01,   3.29268336e-01,   3.29035848e-01,
                          3.29035848e-01,   3.28919590e-01,   3.29035848e-01,
                          3.28919590e-01,   3.28570873e-01,   3.28454614e-01,
                          3.28280240e-01,   3.28222126e-01,   3.28280240e-01,
                          3.27931523e-01,   3.27699006e-01,   3.27699006e-01,
                          3.27524632e-01,   3.27234030e-01,   3.27234030e-01,
                          3.27117771e-01,   3.26710910e-01,   3.26478422e-01,
                          3.26420307e-01,   3.26304048e-01,   3.26245934e-01,
                          3.26129675e-01,   3.26071560e-01,   3.25897187e-01,
                          3.25490326e-01,   3.25199723e-01,   3.24909091e-01,
                          3.24734718e-01,   3.24734718e-01,   3.24327856e-01,
                          3.23920995e-01,   3.23920995e-01,   3.23630393e-01,
                          3.23456019e-01,   3.23339760e-01,   3.22874784e-01,
                          3.22700411e-01,   3.22758526e-01,   3.22526038e-01,
                          3.22293550e-01,   3.22119176e-01,   3.22002947e-01,
                          3.21886688e-01,   3.21596086e-01,   3.21363568e-01,
                          3.21189195e-01,   3.21072966e-01,   3.21131080e-01,
                          3.21072966e-01,   3.20898592e-01,   3.20840478e-01,
                          3.20782334e-01,   3.20724219e-01,   3.20782334e-01,
                          3.20666105e-01,   3.20549846e-01,   3.20607990e-01,
                          3.20666105e-01,   3.20666105e-01,   3.20666105e-01,
                          3.20666105e-01,   3.20782334e-01,   3.20840478e-01,
                          3.20666105e-01,   3.20782334e-01,   3.20956707e-01,
                          3.20840478e-01,   3.20898592e-01,   3.21072966e-01,
                          3.21189195e-01,   3.21072966e-01,   3.21189195e-01,
                          3.21363568e-01,   3.21305454e-01,   3.21363568e-01,
                          3.21596086e-01,   3.21654201e-01,   3.21828574e-01,
                          3.21886688e-01,   3.21828574e-01,   3.21828574e-01,
                          3.22002947e-01,   3.22119176e-01,   3.22177291e-01,
                          3.22235435e-01,   3.22119176e-01,   3.22119176e-01,
                          3.22235435e-01,   3.22351664e-01,   3.22467923e-01,
                          3.22409809e-01,   3.22467923e-01,   3.22526038e-01,
                          3.22293550e-01,   3.22467923e-01,   3.22584182e-01,
                          3.22351664e-01,   3.22584182e-01,   3.22467923e-01,
                          3.22351664e-01,   3.22642297e-01,   3.22467923e-01,
                          3.22351664e-01,   3.22467923e-01,   3.22235435e-01,
                          3.22235435e-01,   3.22351664e-01,   3.22119176e-01,
                          3.22061062e-01,   3.22119176e-01,   3.22061062e-01,
                          3.21828574e-01,   3.21770430e-01,   3.21828574e-01,
                          3.21596086e-01,   3.21363568e-01,   3.21305454e-01,
                          3.21247339e-01,   3.21014851e-01,   3.20782334e-01,
                          3.20782334e-01,   3.20549846e-01,   3.20317358e-01,
                          3.20142984e-01,   3.19852382e-01,   3.19619894e-01,
                          3.19445521e-01,   3.19154888e-01,   3.18922400e-01,
                          3.18515539e-01,   3.18166792e-01,   3.17759931e-01,
                          3.17120582e-01,   3.16946208e-01,   3.16539347e-01,
                          3.16016227e-01,   3.15783739e-01,   3.15144390e-01,
                          3.14737529e-01,   3.14446896e-01,   3.13691318e-01,
                          3.13284457e-01,   3.12703222e-01,   3.11889499e-01,
                          3.11308265e-01,   3.10785145e-01,   3.10262024e-01,
                          3.09506416e-01,   3.08750838e-01,   3.07995230e-01,
                          3.07297736e-01,   3.06716502e-01,   3.05960923e-01,
                          3.05089056e-01,   3.04333448e-01,   3.03577870e-01,
                          3.02822262e-01,   3.01892281e-01,   3.01078558e-01,
                          3.00381064e-01,   2.99334854e-01,   2.98288643e-01,
                          2.97358662e-01,   2.96428680e-01,   2.95673102e-01,
                          2.94685006e-01,   2.93755025e-01,   2.92766929e-01,
                          2.91662574e-01,   2.90616363e-01,   2.89512038e-01,
                          2.88523942e-01,   2.87419587e-01,   2.86199003e-01,
                          2.85269022e-01,   2.84164697e-01,   2.83002228e-01,
                          2.81781644e-01,   2.80502915e-01,   2.79398561e-01,
                          2.78061748e-01,   2.76724905e-01,   2.75504321e-01,
                          2.74167478e-01,   2.73005009e-01,   2.71726310e-01,
                          2.70215094e-01,   2.68878251e-01,   2.67483294e-01,
                          2.66088337e-01,   2.64693379e-01,   2.63298422e-01,
                          2.62019724e-01,   2.60334134e-01,   2.58822948e-01,
                          2.57486105e-01,   2.55684286e-01,   2.54114956e-01,
                          2.52603740e-01,   2.50627548e-01,   2.49174476e-01,
                          2.47430772e-01,   2.45454580e-01,   2.44059622e-01,
                          2.42432177e-01,   2.40514100e-01,   2.38770410e-01,
                          2.36852333e-01,   2.35050514e-01,   2.33248696e-01,
                          2.31272504e-01,   2.29412556e-01,   2.27552623e-01,
                          2.25634545e-01,   2.23658353e-01,   2.21798405e-01,
                          2.19705969e-01,   2.17729777e-01,   2.15986088e-01,
                          2.13719279e-01,   2.11626843e-01,   2.09825024e-01,
                          2.07732573e-01,   2.05698267e-01,   2.03663945e-01,
                          2.01397136e-01,   1.99246585e-01,   1.97212264e-01,
                          1.95236072e-01,   1.93085521e-01,   1.90934956e-01,
                          1.88842520e-01,   1.86401337e-01,   1.84250772e-01,
                          1.82158336e-01,   1.79775283e-01,   1.77566603e-01,
                          1.75299793e-01,   1.72974855e-01,   1.70475557e-01,
                          1.68092504e-01,   1.65883824e-01,   1.63617015e-01,
                          1.61350206e-01,   1.59083396e-01,   1.56525970e-01,
                          1.54026672e-01,   1.51411131e-01,   1.48853704e-01,
                          1.46412522e-01,   1.43855095e-01,   1.41413927e-01,
                          1.38798371e-01,   1.36240959e-01,   1.33567289e-01,
                          1.30835488e-01,   1.28394306e-01,   1.25720635e-01,
                          1.23163216e-01,   1.20547667e-01,   1.17525257e-01,
                          1.14735343e-01,   1.12119794e-01,   1.09504245e-01,
                          1.06714331e-01,   1.03808165e-01,   1.01134494e-01,
                          9.83445793e-02,   9.54384133e-02,   9.27066207e-02,
                          8.98585841e-02,   8.70105401e-02,   8.41625035e-02,
                          8.13725814e-02,   7.85826668e-02,   7.55602568e-02,
                          7.26540908e-02,   6.98641762e-02,   6.68998882e-02,
                          6.39937222e-02,   6.12619296e-02,   5.82976416e-02,
                          5.53914793e-02,   5.23690693e-02,   4.94047813e-02,
                          4.66729887e-02,   4.37087007e-02,   4.07444164e-02,
                          3.77801284e-02,   3.45833488e-02,   3.15609388e-02,
                          2.85966508e-02,   2.56904867e-02,   2.27262005e-02,
                          1.96456667e-02,   1.66232567e-02,   1.35427229e-02,
                          1.04621891e-02,   7.49790249e-03,   4.24299901e-03,
                          1.10434217e-03,  -1.91806804e-03,  -5.17297117e-03,
                         -8.36975127e-03,  -1.13340383e-02,  -1.44145722e-02,
                         -1.76694747e-02,  -2.08662543e-02,  -2.39467882e-02,
                         -2.72016916e-02,  -3.03403493e-02,  -3.35952528e-02,
                         -3.69082801e-02,  -4.00469340e-02,  -4.33599614e-02,
                         -4.64986190e-02,  -4.96372767e-02,  -5.30084260e-02,
                         -5.62633276e-02,  -5.94601072e-02,  -6.27731383e-02,
                         -6.60280362e-02,  -6.93410635e-02,  -7.25378469e-02,
                         -7.57927522e-02,  -7.89895281e-02,  -8.22444335e-02,
                         -8.56737047e-02,  -8.89867321e-02,  -9.21835080e-02,
                         -9.55546647e-02,  -9.87514406e-02,  -1.01948224e-01,
                         -1.05319373e-01,  -1.08632401e-01,  -1.11887299e-01,
                         -1.15084082e-01,  -1.18455231e-01,  -1.21826380e-01,
                         -1.25023156e-01,  -1.28394306e-01,  -1.31881714e-01,
                         -1.35078490e-01,  -1.38333395e-01,  -1.41820788e-01,
                         -1.44959450e-01,  -1.48156226e-01,  -1.51469246e-01,
                         -1.54666036e-01,  -1.58153430e-01,  -1.61466449e-01,
                         -1.64605111e-01,  -1.68092504e-01,  -1.71347409e-01,
                         -1.74544185e-01,  -1.77973464e-01,  -1.81228369e-01,
                         -1.84483275e-01,  -1.87854424e-01,  -1.91225573e-01,
                         -1.94654837e-01,  -1.97793499e-01,  -2.01164648e-01,
                         -2.04710171e-01,  -2.08081320e-01,  -2.11394340e-01,
                         -2.14823619e-01,  -2.18311012e-01,  -2.21624047e-01,
                         -2.24937066e-01,  -2.28540704e-01,  -2.31911868e-01,
                         -2.35166758e-01,  -2.38596037e-01,  -2.41909057e-01,
                         -2.45396465e-01,  -2.48883858e-01,  -2.52196878e-01,
                         -2.55742401e-01,  -2.59229809e-01,  -2.62600958e-01,
                         -2.66030222e-01,  -2.69401371e-01,  -2.72888780e-01,
                         -2.76259929e-01,  -2.79514819e-01,  -2.82885969e-01,
                         -2.86199003e-01,  -2.89686382e-01,  -2.93115675e-01,
                         -2.96370566e-01,  -2.99857974e-01,  -3.03229123e-01,
                         -3.06309640e-01,  -3.09738934e-01,  -3.13051939e-01,
                         -3.16423088e-01,  -3.19736123e-01,  -3.22991043e-01,
                         -3.26362193e-01,  -3.29617083e-01,  -3.32755744e-01,
                         -3.36126894e-01,  -3.39381784e-01,  -3.42520446e-01,
                         -3.45717221e-01,  -3.49030256e-01,  -3.52110803e-01,
                         -3.55307579e-01,  -3.58562469e-01,  -3.61701131e-01,
                         -3.64897907e-01,  -3.68094683e-01,  -3.71233344e-01,
                         -3.74430120e-01,  -3.77510667e-01,  -3.80707443e-01,
                         -3.83904219e-01,  -3.86984766e-01,  -3.90181541e-01,
                         -3.93320203e-01,  -3.96342605e-01,  -3.99597496e-01,
                         -4.02503669e-01,  -4.05467957e-01,  -4.08664733e-01,
                         -4.11629021e-01,  -4.14767683e-01,  -4.17906344e-01,
                         -4.20696259e-01,  -4.23834920e-01,  -4.26857322e-01,
                         -4.29705352e-01,  -4.32727784e-01,  -4.35750186e-01,
                         -4.38772589e-01,  -4.41562504e-01,  -4.44236189e-01,
                         -4.47142333e-01,  -4.50048506e-01,  -4.52896535e-01,
                         -4.55918968e-01,  -4.58766997e-01,  -4.61266309e-01,
                         -4.64172453e-01,  -4.67020512e-01,  -4.69636053e-01,
                         -4.72367853e-01,  -4.75041509e-01,  -4.77715194e-01,
                         -4.80505109e-01,  -4.82888162e-01,  -4.85503703e-01,
                         -4.88177359e-01,  -4.90560442e-01,  -4.93175983e-01,
                         -4.95733410e-01,  -4.98174578e-01,  -5.00615776e-01,
                         -5.03056943e-01,  -5.05323768e-01,  -5.07416189e-01,
                         -5.09915471e-01,  -5.12414753e-01,  -5.14449120e-01,
                         -5.16657770e-01,  -5.18924594e-01,  -5.20958900e-01,
                         -5.23283839e-01,  -5.25376260e-01,  -5.27352452e-01,
                         -5.29503047e-01,  -5.31653583e-01,  -5.33746004e-01,
                         -5.35605967e-01,  -5.37640274e-01,  -5.39558351e-01,
                         -5.41476429e-01,  -5.43510735e-01,  -5.45312524e-01,
                         -5.47056258e-01,  -5.48799932e-01,  -5.50659895e-01,
                         -5.52636087e-01,  -5.54205418e-01,  -5.55949092e-01,
                         -5.57750940e-01,  -5.59145868e-01,  -5.61063945e-01,
                         -5.62807679e-01,  -5.64086378e-01,  -5.65655708e-01,
                         -5.67283154e-01,  -5.68794370e-01,  -5.70305586e-01,
                         -5.71526170e-01,  -5.73037326e-01,  -5.74548542e-01,
                         -5.75827241e-01,  -5.77105999e-01,  -5.78268468e-01,
                         -5.79489052e-01,  -5.80709636e-01,  -5.81755817e-01,
                         -5.82918286e-01,  -5.83848298e-01,  -5.85010767e-01,
                         -5.85998833e-01,  -5.86638212e-01,  -5.87684393e-01,
                         -5.88381886e-01,  -5.88904977e-01,  -5.89834988e-01,
                         -5.90358078e-01,  -5.90997458e-01,  -5.91811180e-01,
                         -5.92276156e-01,  -5.92857361e-01,  -5.93438625e-01,
                         -5.93729258e-01,  -5.94019830e-01,  -5.94368577e-01,
                         -5.94717324e-01,  -5.94891727e-01,  -5.95066071e-01,
                         -5.95356703e-01,  -5.95472932e-01,  -5.95531046e-01,
                         -5.95531046e-01,  -5.95589161e-01,  -5.95531046e-01,
                         -5.95298588e-01,  -5.95298588e-01,  -5.95124185e-01,
                         -5.94949841e-01,  -5.94833553e-01,  -5.94368577e-01,
                         -5.94136119e-01,  -5.93612969e-01,  -5.92799246e-01,
                         -5.92450500e-01,  -5.92101812e-01,  -5.91404319e-01,
                         -5.90706825e-01,  -5.90067446e-01,  -5.89428127e-01,
                         -5.88730633e-01,  -5.87975025e-01,  -5.86986959e-01,
                         -5.86231351e-01,  -5.85301340e-01,  -5.84080756e-01,
                         -5.83092690e-01,  -5.82046449e-01,  -5.80709636e-01,
                         -5.79489052e-01,  -5.78152180e-01,  -5.76931596e-01,
                         -5.75594783e-01,  -5.73967338e-01,  -5.72339892e-01,
                         -5.70596159e-01,  -5.69084942e-01,  -5.67399383e-01,
                         -5.65539479e-01,  -5.63970149e-01,  -5.61993957e-01,
                         -5.59901476e-01,  -5.58332145e-01,  -5.56239724e-01,
                         -5.54205418e-01,  -5.52229226e-01,  -5.49904287e-01,
                         -5.47869980e-01,  -5.45603156e-01,  -5.43103874e-01,
                         -5.40895164e-01,  -5.38628399e-01,  -5.36012828e-01,
                         -5.33339143e-01,  -5.30897975e-01,  -5.28573036e-01,
                         -5.25957525e-01,  -5.23283839e-01,  -5.20610154e-01,
                         -5.17936468e-01,  -5.15320957e-01,  -5.12298524e-01,
                         -5.09566724e-01,  -5.06834924e-01,  -5.03754437e-01,
                         -5.00964522e-01,  -4.98000205e-01,  -4.94745314e-01,
                         -4.91606653e-01,  -4.88642365e-01,  -4.85736191e-01,
                         -4.82539415e-01,  -4.79284525e-01,  -4.76087719e-01,
                         -4.72542226e-01,  -4.69287306e-01,  -4.66206789e-01,
                         -4.62719381e-01,  -4.59522605e-01,  -4.56035197e-01,
                         -4.52431560e-01,  -4.49060410e-01,  -4.45456773e-01,
                         -4.42085624e-01,  -4.38656330e-01,  -4.34878320e-01,
                         -4.31158453e-01,  -4.27380443e-01,  -4.23660547e-01,
                         -4.19882536e-01,  -4.16046381e-01,  -4.12268370e-01,
                         -4.08548474e-01,  -4.04886723e-01,  -4.00992453e-01,
                         -3.97040069e-01,  -3.93320203e-01,  -3.89193445e-01,
                         -3.85241061e-01,  -3.81404907e-01,  -3.77336293e-01,
                         -3.73500168e-01,  -3.69547784e-01,  -3.65362883e-01,
                         -3.61468643e-01,  -3.57283771e-01,  -3.53040755e-01,
                         -3.48972142e-01,  -3.44903499e-01,  -3.40776742e-01,
                         -3.36591870e-01,  -3.32523257e-01,  -3.28454614e-01,
                         -3.24153483e-01,  -3.19794238e-01,  -3.15609366e-01,
                         -3.11366379e-01,  -3.07065248e-01,  -3.02996635e-01,
                         -2.98869878e-01,  -2.94510633e-01,  -2.90209502e-01,
                         -2.85908371e-01,  -2.81723499e-01,  -2.77538627e-01,
                         -2.73237497e-01,  -2.68994510e-01,  -2.64751524e-01,
                         -2.60392278e-01,  -2.55974889e-01,  -2.51673788e-01,
                         -2.47372657e-01,  -2.42897153e-01,  -2.38712281e-01,
                         -2.34411165e-01,  -2.29877546e-01,  -2.25634545e-01,
                         -2.21333429e-01,  -2.16857940e-01,  -2.12440565e-01,
                         -2.08139449e-01,  -2.03896448e-01,  -1.99479073e-01,
                         -1.95119828e-01,  -1.90818712e-01,  -1.86343208e-01,
                         -1.82042092e-01,  -1.77799091e-01,  -1.73207358e-01,
                         -1.68848112e-01,  -1.64488867e-01,  -1.60013378e-01,
                         -1.55537874e-01,  -1.51236758e-01,  -1.47051886e-01,
                         -1.42518267e-01,  -1.38042778e-01,  -1.33857906e-01,
                         -1.29440531e-01,  -1.25023156e-01,  -1.20722041e-01,
                         -1.16304673e-01,  -1.11887299e-01,  -1.07586183e-01,
                         -1.03343181e-01,  -9.90420580e-02,  -9.45084393e-02,
                         -9.02073234e-02,  -8.59062001e-02,  -8.16631988e-02,
                         -7.75364488e-02,  -7.31772035e-02,  -6.88179582e-02,
                         -6.46912009e-02,  -6.05644509e-02,  -5.63795753e-02,
                         -5.20784520e-02,  -4.78935763e-02,  -4.38249484e-02,
                         -3.96400727e-02,  -3.53970751e-02,  -3.13284434e-02,
                         -2.73179393e-02,  -2.33655553e-02,  -1.92969274e-02,
                         -1.53445443e-02,  -1.12177916e-02,  -7.14916270e-03,
                         -3.31302662e-03,   6.39356032e-04,   4.53361543e-03,
                          8.36975127e-03,   1.23221343e-02,   1.60420239e-02,
                          1.98781602e-02,   2.38305423e-02,   2.76085548e-02,
                          3.15609388e-02,   3.52227055e-02,   3.89425941e-02,
                          4.26624827e-02,   4.62080017e-02,   4.99860160e-02,
                          5.37059046e-02,   5.71933016e-02,   6.08550683e-02,
                          6.44005835e-02,   6.80042282e-02,   7.16659948e-02,
                          7.50952661e-02,   7.86407888e-02,   8.21863115e-02,
                          8.56155828e-02,   8.91029760e-02,   9.24160033e-02,
                          9.57871526e-02,   9.92745534e-02,   1.02645703e-01,
                          1.06191218e-01,   1.09562367e-01,   1.12701029e-01,
                          1.15839683e-01,   1.19094588e-01,   1.22465737e-01,
                          1.25604391e-01,   1.28743052e-01,   1.31997958e-01,
                          1.35078490e-01,   1.38159022e-01,   1.41297683e-01,
                          1.44261971e-01,   1.47226244e-01,   1.50306791e-01,
                          1.53445438e-01,   1.56235352e-01,   1.59025282e-01,
                          1.62163928e-01,   1.65070102e-01,   1.67801887e-01,
                          1.70533687e-01,   1.73323601e-01,   1.76113516e-01,
                          1.78729072e-01,   1.81518987e-01,   1.84250772e-01,
                          1.86691955e-01,   1.89423755e-01,   1.92097425e-01,
                          1.94712967e-01,   1.97328508e-01,   1.99653447e-01,
                          2.01920256e-01,   2.04535797e-01,   2.07035094e-01,
                          2.09418148e-01,   2.11684957e-01,   2.14068010e-01,
                          2.16509193e-01,   2.18834117e-01,   2.21100926e-01,
                          2.23483980e-01,   2.25750789e-01,   2.27668867e-01,
                          2.29761302e-01,   2.31911868e-01,   2.34004304e-01,
                          2.36154854e-01,   2.38131046e-01,   2.40281612e-01,
                          2.42548421e-01,   2.44350240e-01,   2.46384561e-01,
                          2.48418868e-01,   2.50162572e-01,   2.52138764e-01,
                          2.54056841e-01,   2.55916774e-01,   2.57718593e-01,
                          2.59520411e-01,   2.61380374e-01,   2.63007820e-01,
                          2.64751524e-01,   2.66553342e-01,   2.68122673e-01,
                          2.69866347e-01,   2.71435678e-01,   2.72946894e-01,
                          2.74632454e-01,   2.76143670e-01,   2.77654886e-01,
                          2.79107958e-01,   2.80561030e-01,   2.82014132e-01,
                          2.83176601e-01,   2.84629673e-01,   2.86082745e-01,
                          2.87303329e-01,   2.88814545e-01,   2.89918900e-01,
                          2.91023225e-01,   2.92476326e-01,   2.93638766e-01,
                          2.94917494e-01,   2.96079963e-01,   2.97184289e-01,
                          2.98404872e-01,   2.99509227e-01,   3.00555438e-01,
                          3.01543534e-01,   3.02531630e-01,   3.03577870e-01,
                          3.04507822e-01,   3.05554062e-01,   3.06542158e-01,
                          3.07413995e-01,   3.08460206e-01,   3.09273928e-01,
                          3.10145795e-01,   3.11133891e-01,   3.11947614e-01,
                          3.12761337e-01,   3.13575059e-01,   3.14505041e-01,
                          3.15434992e-01,   3.16132486e-01,   3.17004323e-01,
                          3.17818046e-01,   3.18515539e-01,   3.19271147e-01,
                          3.19910496e-01,   3.20666105e-01,   3.21421713e-01,
                          3.22061062e-01,   3.22874784e-01,   3.23572248e-01,
                          3.24269742e-01,   3.25025350e-01,   3.25664699e-01,
                          3.26245934e-01,   3.26769054e-01,   3.27466518e-01,
                          3.28222126e-01,   3.28803360e-01,   3.29442710e-01,
                          3.30198318e-01,   3.30721438e-01,   3.31128299e-01,
                          3.31709534e-01,   3.32348883e-01,   3.32755744e-01,
                          3.33220720e-01,   3.33801955e-01,   3.34150702e-01,
                          3.34673822e-01,   3.35255027e-01,   3.35603774e-01,
                          3.36185008e-01,   3.36650014e-01,   3.37056875e-01,
                          3.37579966e-01,   3.37870598e-01,   3.38451833e-01,
                          3.38916808e-01,   3.39207411e-01,   3.39672416e-01,
                          3.40021163e-01,   3.40544254e-01,   3.41009259e-01,
                          3.41125488e-01,   3.41532350e-01,   3.41997355e-01,
                          3.42404217e-01,   3.42869192e-01,   3.43159795e-01,
                          3.43682915e-01,   3.44089776e-01,   3.44438523e-01,
                          3.44961613e-01,   3.45310360e-01,   3.45600992e-01,
                          3.45833480e-01,   3.46182227e-01,   3.46705317e-01,
                          3.47054064e-01,   3.47460926e-01,   3.47809672e-01,
                          3.48100275e-01,   3.48565280e-01,   3.48913997e-01,
                          3.49320859e-01,   3.49727750e-01,   3.50076467e-01,
                          3.50541472e-01,   3.50890189e-01,   3.51064563e-01,
                          3.51297051e-01,   3.51587683e-01,   3.51936430e-01,
                          3.52168918e-01,   3.52459520e-01,   3.52866381e-01,
                          3.52982640e-01,   3.53215128e-01,   3.53563875e-01,
                          3.53680104e-01,   3.53912622e-01,   3.54145110e-01,
                          3.54203224e-01,   3.54377598e-01,   3.54551971e-01,
                          3.54784459e-01,   3.55075091e-01,   3.55249435e-01,
                          3.55540067e-01,   3.55714440e-01,   3.55830669e-01,
                          3.56005043e-01,   3.56237531e-01,   3.56470048e-01,
                          3.56644392e-01,   3.56818765e-01,   3.56935024e-01,
                          3.57109398e-01,   3.57225627e-01,   3.57400000e-01,
                          3.57632488e-01,   3.57690632e-01,   3.57516259e-01,
                          3.57748747e-01,   3.57981235e-01,   3.58097494e-01,
                          3.58271867e-01,   3.58388096e-01,   3.58388096e-01,
                          3.58329982e-01,   3.58504355e-01,   3.58620584e-01,
                          3.58678728e-01,   3.58969331e-01,   3.58969331e-01,
                          3.58911216e-01,   3.58969331e-01,   3.59085590e-01,
                          3.59318078e-01,   3.59318078e-01,   3.59259963e-01,
                          3.59259963e-01,   3.59201819e-01,   3.59376192e-01,
                          3.59259963e-01,   3.59318078e-01,   3.59492451e-01,
                          3.59318078e-01,   3.59376192e-01,   3.59259963e-01,
                          3.59085590e-01,   3.59318078e-01,   3.59085590e-01,
                          3.58969331e-01,   3.59085590e-01,   3.58853102e-01,
                          3.58853102e-01,   3.58678728e-01,   3.58678728e-01,
                          3.58736843e-01,   3.58562469e-01,   3.58504355e-01,
                          3.58271867e-01,   3.58097494e-01,   3.58097494e-01,
                          3.57632488e-01,   3.57400000e-01,   3.57167512e-01,
                          3.56935024e-01,   3.56876910e-01,   3.56586277e-01,
                          3.56411904e-01,   3.56237531e-01,   3.55888814e-01,
                          3.55714440e-01,   3.55423808e-01,   3.55191320e-01,
                          3.55075091e-01,   3.54551971e-01,   3.54319483e-01,
                          3.54203224e-01,   3.53621989e-01,   3.53447616e-01,
                          3.53273243e-01,   3.52924526e-01,   3.52575779e-01,
                          3.52227032e-01,   3.51994544e-01,   3.51587683e-01,
                          3.51238936e-01,   3.51064563e-01,   3.50599587e-01,
                          3.50308955e-01,   3.49960238e-01,   3.49553376e-01,
                          3.49379003e-01,   3.48913997e-01,   3.48507136e-01,
                          3.48332763e-01,   3.47751558e-01,   3.47519040e-01,
                          3.47344697e-01,   3.46879691e-01,   3.46530944e-01,
                          3.46240342e-01,   3.45891595e-01,   3.45426619e-01,
                          3.45135987e-01,   3.44729125e-01,   3.44322264e-01,
                          3.44031662e-01,   3.43624800e-01,   3.43217939e-01,
                          3.43043566e-01,   3.42520446e-01,   3.41939211e-01,
                          3.41764838e-01,   3.41474235e-01,   3.40893000e-01,
                          3.40544254e-01,   3.40369880e-01,   3.39904904e-01,
                          3.39614272e-01,   3.39381784e-01,   3.38742435e-01,
                          3.38335574e-01,   3.38044971e-01,   3.37638110e-01,
                          3.37347478e-01,   3.37056875e-01,   3.36591870e-01,
                          3.36068779e-01,   3.35836262e-01,   3.35661918e-01,
                          3.35196912e-01,   3.34848166e-01,   3.34615678e-01,
                          3.34034443e-01,   3.33743840e-01,   3.33569467e-01,
                          3.33046347e-01,   3.32813859e-01,   3.32581371e-01,
                          3.32116395e-01,   3.31825763e-01,   3.31825763e-01,
                          3.31535161e-01,   3.31128299e-01,   3.31012040e-01,
                          3.30663294e-01,   3.30140203e-01,   3.30023944e-01,
                          3.29791456e-01,   3.29442710e-01,   3.29210222e-01,
                          3.29035848e-01,   3.28687102e-01,   3.28338385e-01,
                          3.27931523e-01,   3.27640891e-01,   3.27466518e-01,
                          3.27292144e-01,   3.27059656e-01,   3.26710910e-01,
                          3.26478422e-01,   3.26129675e-01,   3.25722814e-01,
                          3.25374097e-01,   3.25025350e-01,   3.24734718e-01,
                          3.24502230e-01,   3.24037254e-01,   3.23572248e-01,
                          3.23339760e-01,   3.22991043e-01,   3.22467923e-01,
                          3.22061062e-01,   3.21596086e-01,   3.21014851e-01,
                          3.20666105e-01,   3.20317358e-01,   3.19736123e-01,
                          3.19154888e-01,   3.18457425e-01,   3.17992419e-01,
                          3.17527443e-01,   3.16888094e-01,   3.16306859e-01,
                          3.15667510e-01,   3.15086275e-01,   3.14621270e-01,
                          3.13981920e-01,   3.13342571e-01,   3.12645078e-01,
                          3.12005728e-01,   3.11482608e-01,   3.10668886e-01,
                          3.09971422e-01,   3.09273928e-01,   3.08402091e-01,
                          3.07646483e-01,   3.06832761e-01,   3.06077152e-01,
                          3.05321544e-01,   3.04391593e-01,   3.03635985e-01,
                          3.02880377e-01,   3.02008539e-01,   3.01252931e-01,
                          3.00497323e-01,   2.99625486e-01,   2.98579246e-01,
                          2.97591150e-01,   2.96777427e-01,   2.95789331e-01,
                          2.94917494e-01,   2.94045627e-01,   2.92941302e-01,
                          2.92011321e-01,   2.91139483e-01,   2.90035129e-01,
                          2.88930804e-01,   2.88058937e-01,   2.87012726e-01,
                          2.85792142e-01,   2.84745902e-01,   2.83583462e-01,
                          2.82304734e-01,   2.81142265e-01,   2.79863566e-01,
                          2.78817356e-01,   2.77596742e-01,   2.75969297e-01,
                          2.74748713e-01,   2.73760617e-01,   2.72365659e-01,
                          2.70912588e-01,   2.69575745e-01,   2.68297017e-01,
                          2.66843945e-01,   2.65448987e-01,   2.64170289e-01,
                          2.62659073e-01,   2.61147857e-01,   2.59811044e-01,
                          2.58299828e-01,   2.56846756e-01,   2.55568027e-01,
                          2.53882468e-01,   2.52254993e-01,   2.50801921e-01,
                          2.49290720e-01,   2.47837633e-01,   2.46384561e-01,
                          2.44698986e-01,   2.43129656e-01,   2.41560325e-01,
                          2.39874750e-01,   2.38305420e-01,   2.36794218e-01,
                          2.35108644e-01,   2.33597443e-01,   2.31969982e-01,
                          2.30226293e-01,   2.28540704e-01,   2.26680771e-01,
                          2.25111440e-01,   2.23716483e-01,   2.21856534e-01,
                          2.20054716e-01,   2.18369141e-01,   2.16509193e-01,
                          2.14823619e-01,   2.13138044e-01,   2.11394340e-01,
                          2.09592521e-01,   2.07732573e-01,   2.06105128e-01,
                          2.04361424e-01,   2.02501491e-01,   2.00583413e-01,
                          1.98781595e-01,   1.97096020e-01,   1.95003584e-01,
                          1.93027392e-01,   1.91109329e-01,   1.89133137e-01,
                          1.87331304e-01,   1.85296997e-01,   1.83320805e-01,
                          1.81402743e-01,   1.79368421e-01,   1.77508473e-01,
                          1.75416037e-01,   1.73207358e-01,   1.71289280e-01,
                          1.69196844e-01,   1.67162538e-01,   1.65186346e-01,
                          1.63035780e-01,   1.60885215e-01,   1.58676535e-01,
                          1.56525970e-01,   1.54317290e-01,   1.52166724e-01,
                          1.49958044e-01,   1.47807479e-01,   1.45831287e-01,
                          1.43506363e-01,   1.41239554e-01,   1.39263362e-01,
                          1.36938438e-01,   1.34729743e-01,   1.32637307e-01,
                          1.30370498e-01,   1.28219947e-01,   1.25895008e-01,
                          1.23570077e-01,   1.21477641e-01,   1.19327083e-01,
                          1.17060274e-01,   1.14735343e-01,   1.12410411e-01,
                          1.10201724e-01,   1.07934922e-01,   1.05726235e-01,
                          1.03401303e-01,   1.00960128e-01,   9.86351967e-02,
                          9.63683873e-02,   9.41015780e-02,   9.17185247e-02,
                          8.94517154e-02,   8.71267840e-02,   8.46856087e-02,
                          8.24769214e-02,   8.02682415e-02,   7.78851882e-02,
                          7.55021349e-02,   7.31190816e-02,   7.06778988e-02,
                          6.83529675e-02,   6.57955483e-02,   6.33543655e-02,
                          6.10875599e-02,   5.85301369e-02,   5.59727140e-02,
                          5.36477827e-02,   5.10322340e-02,   4.84748110e-02,
                          4.60336320e-02,   4.34762090e-02,   4.08606604e-02,
                          3.82451154e-02,   3.57458144e-02,   3.32465135e-02,
                          3.06890886e-02,   2.81316638e-02,   2.55742408e-02,
                          2.29586922e-02,   2.04593930e-02,   1.79019682e-02,
                          1.53445443e-02,   1.27289966e-02,   1.00553259e-02,
                          7.49790249e-03,   4.94047813e-03,   2.38305423e-03,
                         -5.81232744e-05,  -2.61554727e-03,  -5.28921792e-03,
                         -7.96288811e-03,  -1.07528055e-02,  -1.33102294e-02,
                         -1.58676542e-02,  -1.85413249e-02,  -2.10987478e-02,
                         -2.35980488e-02,  -2.64460891e-02,  -2.90616360e-02,
                         -3.16771828e-02,  -3.43508534e-02,  -3.67339104e-02,
                         -3.94075811e-02,  -4.21393737e-02,  -4.47549187e-02,
                         -4.74867150e-02,  -5.00441380e-02,  -5.27759306e-02,
                         -5.55077270e-02,  -5.78907803e-02,  -6.05063289e-02,
                         -6.32381216e-02,  -6.59117922e-02,  -6.85854629e-02,
                         -7.12591335e-02,  -7.40490481e-02,  -7.67227188e-02,
                         -7.93963894e-02,  -8.21863115e-02,  -8.48599821e-02,
                         -8.76498967e-02,  -9.04979333e-02,  -9.31716040e-02,
                         -9.60196480e-02,  -9.86351967e-02,  -1.01366989e-01,
                         -1.04215026e-01,  -1.06888697e-01,  -1.09736741e-01,
                         -1.12468533e-01,  -1.15258448e-01,  -1.18222736e-01,
                         -1.20896406e-01,  -1.23628199e-01,  -1.26592487e-01,
                         -1.29498661e-01,  -1.32288575e-01,  -1.35020360e-01,
                         -1.37752160e-01,  -1.40716448e-01,  -1.43564492e-01,
                         -1.46238163e-01,  -1.49086192e-01,  -1.52050480e-01,
                         -1.54898524e-01,  -1.57630324e-01,  -1.60478354e-01,
                         -1.63558885e-01,  -1.66523173e-01,  -1.69196844e-01,
                         -1.72161132e-01,  -1.75183550e-01,  -1.77915335e-01,
                         -1.80763379e-01,  -1.83843911e-01,  -1.86691955e-01,
                         -1.89481869e-01,  -1.92504287e-01,  -1.95468575e-01,
                         -1.98432863e-01,  -2.01280892e-01,  -2.04187065e-01,
                         -2.07267597e-01,  -2.09941268e-01,  -2.12847427e-01,
                         -2.16218576e-01,  -2.19066620e-01,  -2.21972778e-01,
                         -2.25169554e-01,  -2.28075728e-01,  -2.30981886e-01,
                         -2.34120548e-01,  -2.37201080e-01,  -2.40281612e-01,
                         -2.43362144e-01,  -2.46326432e-01,  -2.49406964e-01,
                         -2.52603740e-01,  -2.55626142e-01,  -2.58764803e-01,
                         -2.61961579e-01,  -2.64984012e-01,  -2.68238902e-01,
                         -2.71435678e-01,  -2.74399966e-01,  -2.77596742e-01,
                         -2.80909777e-01,  -2.84106553e-01,  -2.87128985e-01,
                         -2.90325761e-01,  -2.93464422e-01,  -2.96370566e-01,
                         -2.99683601e-01,  -3.02938491e-01,  -3.06077152e-01,
                         -3.09448302e-01,  -3.12586963e-01,  -3.15551251e-01,
                         -3.18748027e-01,  -3.21944803e-01,  -3.24967235e-01,
                         -3.28105867e-01,  -3.31535161e-01,  -3.34499449e-01,
                         -3.37579966e-01,  -3.40834886e-01,  -3.43857288e-01,
                         -3.47054064e-01,  -3.50367099e-01,  -3.53331387e-01,
                         -3.56586277e-01,  -3.59783053e-01,  -3.62631112e-01,
                         -3.65827888e-01,  -3.68966550e-01,  -3.71988952e-01,
                         -3.75069469e-01,  -3.78150016e-01,  -3.81230563e-01,
                         -3.84369195e-01,  -3.87391627e-01,  -3.90414029e-01,
                         -3.93552691e-01,  -3.96575093e-01,  -3.99365008e-01,
                         -4.02445555e-01,  -4.05584216e-01,  -4.08664733e-01,
                         -4.11687136e-01,  -4.14709568e-01,  -4.17673856e-01,
                         -4.20638144e-01,  -4.23660547e-01,  -4.26799208e-01,
                         -4.29647237e-01,  -4.32611525e-01,  -4.35633928e-01,
                         -4.38481987e-01,  -4.41388130e-01,  -4.44236189e-01,
                         -4.47258592e-01,  -4.50280994e-01,  -4.53070909e-01,
                         -4.55977082e-01,  -4.58766997e-01,  -4.61556911e-01,
                         -4.64521199e-01,  -4.67427373e-01,  -4.70275402e-01,
                         -4.72774714e-01,  -4.75448370e-01,  -4.78354543e-01,
                         -4.81086344e-01,  -4.83818114e-01,  -4.86491799e-01,
                         -4.88932967e-01,  -4.91664767e-01,  -4.94164079e-01,
                         -4.96837735e-01,  -4.99511421e-01,  -5.01778245e-01,
                         -5.04219413e-01,  -5.06776810e-01,  -5.09276092e-01,
                         -5.11717319e-01,  -5.13867855e-01,  -5.16250908e-01,
                         -5.18633962e-01,  -5.20726383e-01,  -5.22993207e-01,
                         -5.25027514e-01,  -5.27178109e-01,  -5.29677391e-01,
                         -5.31886101e-01,  -5.33862293e-01,  -5.35954714e-01,
                         -5.37930906e-01,  -5.39907098e-01,  -5.41883290e-01,
                         -5.43917596e-01,  -5.45835674e-01,  -5.47695577e-01,
                         -5.49613655e-01,  -5.51357388e-01,  -5.53217292e-01,
                         -5.55135369e-01,  -5.56820989e-01,  -5.58622777e-01,
                         -5.60308337e-01,  -5.61993957e-01,  -5.63737631e-01,
                         -5.65423191e-01,  -5.67050636e-01,  -5.68561852e-01,
                         -5.70073068e-01,  -5.71584284e-01,  -5.73037326e-01,
                         -5.74490428e-01,  -5.75769126e-01,  -5.77047884e-01,
                         -5.78500926e-01,  -5.79605281e-01,  -5.80883980e-01,
                         -5.82162678e-01,  -5.83267033e-01,  -5.84487617e-01,
                         -5.85533857e-01,  -5.86405694e-01,  -5.87393820e-01,
                         -5.88498116e-01,  -5.89428127e-01,  -5.90067446e-01,
                         -5.90881169e-01,  -5.91636777e-01,  -5.92334270e-01,
                         -5.93147993e-01,  -5.93671143e-01,  -5.94310462e-01,
                         -5.94949841e-01,  -5.95298588e-01,  -5.95879793e-01,
                         -5.96170425e-01,  -5.96461058e-01,  -5.96926033e-01,
                         -5.96984148e-01,  -5.96984148e-01,  -5.97100377e-01,
                         -5.97216606e-01,  -5.97332895e-01,  -5.97216606e-01,
                         -5.97216606e-01,  -5.97158492e-01,  -5.96867919e-01,
                         -5.96867919e-01,  -5.96635401e-01,  -5.96344769e-01,
                         -5.95996022e-01,  -5.95472932e-01,  -5.95182300e-01,
                         -5.94659209e-01,  -5.94019830e-01,  -5.93612969e-01,
                         -5.92915535e-01,  -5.92043638e-01,  -5.91171801e-01,
                         -5.90416193e-01,  -5.89776874e-01,  -5.88788748e-01,
                         -5.87742567e-01,  -5.86870670e-01,  -5.85650086e-01,
                         -5.84487617e-01,  -5.83267033e-01,  -5.81930220e-01,
                         -5.80709636e-01,  -5.79372764e-01,  -5.78035951e-01,
                         -5.76641023e-01,  -5.75129807e-01,  -5.73676705e-01,
                         -5.71933031e-01,  -5.70247412e-01,  -5.68678081e-01,
                         -5.66992521e-01,  -5.65190732e-01,  -5.63272655e-01,
                         -5.61354578e-01,  -5.59494615e-01,  -5.57460308e-01,
                         -5.55484116e-01,  -5.53449810e-01,  -5.51124871e-01,
                         -5.49032450e-01,  -5.46881855e-01,  -5.44556975e-01,
                         -5.42173922e-01,  -5.39790869e-01,  -5.37407815e-01,
                         -5.34850359e-01,  -5.32351077e-01,  -5.29793620e-01,
                         -5.27236223e-01,  -5.24795055e-01,  -5.21888852e-01,
                         -5.19040823e-01,  -5.16309023e-01,  -5.13402879e-01,
                         -5.10554850e-01,  -5.07648647e-01,  -5.04684389e-01,
                         -5.01720071e-01,  -4.98523325e-01,  -4.95384663e-01,
                         -4.92304116e-01,  -4.89165455e-01,  -4.85968679e-01,
                         -4.82597530e-01,  -4.79284525e-01,  -4.75855231e-01,
                         -4.72716570e-01,  -4.69519794e-01,  -4.65974271e-01,
                         -4.62603122e-01,  -4.59057599e-01,  -4.55337733e-01,
                         -4.52140957e-01,  -4.48537290e-01,  -4.44817424e-01,
                         -4.41330016e-01,  -4.37610120e-01,  -4.33773994e-01,
                         -4.29995984e-01,  -4.26276088e-01,  -4.22788680e-01,
                         -4.19126928e-01,  -4.15290803e-01,  -4.11629021e-01,
                         -4.07792896e-01,  -4.03840512e-01,  -4.00120616e-01,
                         -3.96168232e-01,  -3.92041475e-01,  -3.88205349e-01,
                         -3.84369195e-01,  -3.80358696e-01,  -3.76522571e-01,
                         -3.72570187e-01,  -3.68501544e-01,  -3.64607304e-01,
                         -3.60538661e-01,  -3.56411904e-01,  -3.52459520e-01,
                         -3.48332763e-01,  -3.44089776e-01,  -3.39788646e-01,
                         -3.35778147e-01,  -3.31883878e-01,  -3.27640891e-01,
                         -3.23397905e-01,  -3.19271147e-01,  -3.14970016e-01,
                         -3.10785145e-01,  -3.06774646e-01,  -3.02473515e-01,
                         -2.98230529e-01,  -2.94045627e-01,  -2.89802641e-01,
                         -2.85443395e-01,  -2.81200409e-01,  -2.76957393e-01,
                         -2.72714406e-01,  -2.68413275e-01,  -2.64054030e-01,
                         -2.59811044e-01,  -2.55509913e-01,  -2.51208782e-01,
                         -2.47140154e-01,  -2.42780909e-01,  -2.38363549e-01,
                         -2.34294921e-01,  -2.30110034e-01,  -2.25576431e-01,
                         -2.21275300e-01,  -2.17148542e-01,  -2.12905556e-01,
                         -2.08604425e-01,  -2.04361424e-01,  -2.00176552e-01,
                         -1.95875436e-01,  -1.91516191e-01,  -1.87215060e-01,
                         -1.83146432e-01,  -1.78845316e-01,  -1.74427941e-01,
                         -1.70301184e-01,  -1.66116312e-01,  -1.61931440e-01,
                         -1.57804683e-01,  -1.53619811e-01,  -1.49609312e-01,
                         -1.45366311e-01,  -1.41007066e-01,  -1.36705935e-01,
                         -1.32579193e-01,  -1.28510565e-01,  -1.24267556e-01,
                         -1.20024562e-01,  -1.15897804e-01,  -1.11596689e-01,
                         -1.07469931e-01,  -1.03517547e-01,  -9.93326753e-02,
                         -9.52640474e-02,  -9.11954194e-02,  -8.71267840e-02,
                         -8.28837901e-02,  -7.84664154e-02,  -7.44559169e-02,
                         -7.05616549e-02,  -6.64930269e-02,  -6.24825172e-02,
                         -5.82395196e-02,  -5.42871356e-02,  -5.04510030e-02,
                         -4.63823713e-02,  -4.24881130e-02,  -3.85357291e-02,
                         -3.46414708e-02,  -3.06890886e-02,  -2.67948285e-02,
                         -2.31330637e-02,  -1.91225577e-02,  -1.52282976e-02,
                         -1.15084080e-02,  -7.55602540e-03,  -3.95238260e-03,
                         -2.32493097e-04,   3.66176618e-03,   7.14916270e-03,
                          1.08690523e-02,   1.45889418e-02,   1.79600921e-02,
                          2.16218568e-02,   2.52255015e-02,   2.88872663e-02,
                          3.24327871e-02,   3.58039364e-02,   3.93494554e-02,
                          4.27787304e-02,   4.62661274e-02,   4.98116463e-02,
                          5.31246737e-02,   5.64376973e-02,   5.97507246e-02,
                          6.30637482e-02,   6.65511489e-02,   6.97479248e-02,
                          7.30028301e-02,   7.63158575e-02,   7.94545114e-02,
                          8.26512948e-02,   8.58480781e-02,   8.89867321e-02,
                          9.20091420e-02,   9.52640474e-02,   9.85189453e-02,
                          1.01541355e-01,   1.04563765e-01,   1.07644305e-01,
                          1.10608593e-01,   1.13689125e-01,   1.16595283e-01,
                          1.19559571e-01,   1.22523859e-01,   1.25313774e-01,
                          1.28103688e-01,   1.30893618e-01,   1.33741647e-01,
                          1.36647820e-01,   1.39495850e-01,   1.42285779e-01,
                          1.45075694e-01,   1.47807479e-01,   1.50364906e-01,
                          1.52864203e-01,   1.55537874e-01,   1.58269674e-01,
                          1.60885215e-01,   1.63558885e-01,   1.65941939e-01,
                          1.68441251e-01,   1.70998678e-01,   1.73439845e-01,
                          1.75997272e-01,   1.78438455e-01,   1.80763379e-01,
                          1.83204561e-01,   1.85529485e-01,   1.87738180e-01,
                          1.90063104e-01,   1.92388028e-01,   1.94596723e-01,
                          1.96863532e-01,   1.99130341e-01,   2.01106533e-01,
                          2.03140840e-01,   2.05349520e-01,   2.07441956e-01,
                          2.09534407e-01,   2.11626843e-01,   2.13661149e-01,
                          2.15695471e-01,   2.17671663e-01,   2.19531611e-01,
                          2.21449673e-01,   2.23251492e-01,   2.25227684e-01,
                          2.27087632e-01,   2.28831321e-01,   2.30749398e-01,
                          2.32609347e-01,   2.34411165e-01,   2.36154854e-01,
                          2.37782314e-01,   2.39409760e-01,   2.41153464e-01,
                          2.42955282e-01,   2.44524613e-01,   2.46152058e-01,
                          2.47895762e-01,   2.49406964e-01,   2.50976294e-01,
                          2.52545625e-01,   2.53998697e-01,   2.55568027e-01,
                          2.57021129e-01,   2.58357942e-01,   2.59869158e-01,
                          2.61322230e-01,   2.62717187e-01,   2.63995916e-01,
                          2.65448987e-01,   2.66843945e-01,   2.68006414e-01,
                          2.69401371e-01,   2.70680070e-01,   2.71958798e-01,
                          2.73411870e-01,   2.74574339e-01,   2.75736809e-01,
                          2.76841164e-01,   2.78003603e-01,   2.79398561e-01,
                          2.80444801e-01,   2.81549126e-01,   2.82769740e-01,
                          2.83874065e-01,   2.85036534e-01,   2.86082745e-01,
                          2.87070841e-01,   2.88175195e-01,   2.89105147e-01,
                          2.90093243e-01,   2.91139483e-01,   2.92069435e-01,
                          2.93057531e-01,   2.94103771e-01,   2.95091867e-01,
                          2.96021819e-01,   2.96777427e-01,   2.97591150e-01,
                          2.98637390e-01,   2.99625486e-01,   3.00322950e-01,
                          3.01020443e-01,   3.01776022e-01,   3.02531630e-01,
                          3.03752214e-01,   3.04565966e-01,   3.05147171e-01,
                          3.06251526e-01,   3.06949019e-01,   3.07530254e-01,
                          3.08518350e-01,   3.09332073e-01,   3.10145795e-01,
                          3.10901403e-01,   3.11656982e-01,   3.12412590e-01,
                          3.12935710e-01,   3.13691318e-01,   3.14563155e-01,
                          3.15144390e-01,   3.15958112e-01,   3.16597462e-01,
                          3.17353070e-01,   3.18224937e-01,   3.18864286e-01,
                          3.19736123e-01,   3.20375472e-01,   3.20956707e-01,
                          3.21944803e-01,   3.22351664e-01,   3.23049158e-01,
                          3.24037254e-01,   3.24618489e-01,   3.25315952e-01,
                          3.26071560e-01,   3.26827168e-01,   3.27582777e-01,
                          3.28047752e-01,   3.28628987e-01,   3.29558969e-01,
                          3.30314577e-01,   3.30779552e-01,   3.31418902e-01,
                          3.32116395e-01,   3.32639486e-01,   3.33395094e-01,
                          3.33918214e-01,   3.34325075e-01,   3.35080683e-01,
                          3.35778147e-01,   3.36243123e-01,   3.36824358e-01,
                          3.37521851e-01,   3.38044971e-01,   3.38509947e-01,
                          3.39149296e-01,   3.39730531e-01,   3.40137392e-01,
                          3.40660512e-01,   3.41067374e-01,   3.41648608e-01,
                          3.42229843e-01,   3.42578560e-01,   3.43101680e-01,
                          3.43566656e-01,   3.44031662e-01,   3.44729125e-01,
                          3.45135987e-01,   3.45542848e-01,   3.46124083e-01,
                          3.46472830e-01,   3.46705317e-01,   3.47112179e-01,
                          3.47809672e-01,   3.48274648e-01,   3.48623395e-01,
                          3.49204630e-01,   3.49611491e-01,   3.50134611e-01,
                          3.50715846e-01,   3.51180822e-01,   3.51587683e-01,
                          3.51878285e-01,   3.52285147e-01,   3.52808267e-01,
                          3.53040755e-01,   3.53389502e-01,   3.53854477e-01,
                          3.54203224e-01,   3.54610085e-01,   3.54958832e-01,
                          3.55249435e-01,   3.55598181e-01,   3.56005043e-01,
                          3.56470048e-01,   3.56528163e-01,   3.56935024e-01,
                          3.57400000e-01,   3.57458144e-01,   3.57923120e-01,
                          3.58213723e-01,   3.58213723e-01,   3.58678728e-01,
                          3.58853102e-01,   3.59085590e-01,   3.59434336e-01,
                          3.59434336e-01,   3.59841198e-01,   3.60131800e-01,
                          3.60073686e-01,   3.60306174e-01,   3.60364288e-01,
                          3.60538661e-01,   3.60771149e-01,   3.60829294e-01,
                          3.61061782e-01,   3.61003637e-01,   3.61061782e-01,
                          3.61294270e-01,   3.61294270e-01,   3.61410528e-01,
                          3.61410528e-01,   3.61294270e-01,   3.61468643e-01,
                          3.61410528e-01,   3.61410528e-01,   3.61410528e-01,
                          3.61352384e-01,   3.61468643e-01,   3.61352384e-01,
                          3.61410528e-01,   3.61352384e-01,   3.61236155e-01,
                          3.61352384e-01,   3.61061782e-01,   3.60945523e-01,
                          3.60945523e-01,   3.60771149e-01,   3.60887408e-01,
                          3.60945523e-01,   3.60771149e-01,   3.60654920e-01,
                          3.60480547e-01,   3.60480547e-01,   3.60538661e-01,
                          3.60306174e-01,   3.60073686e-01,   3.59957427e-01,
                          3.59783053e-01,   3.59550565e-01,   3.59318078e-01,
                          3.59201819e-01,   3.59085590e-01,   3.58911216e-01,
                          3.58678728e-01,   3.58504355e-01,   3.58329982e-01,
                          3.58097494e-01,   3.57865006e-01,   3.57574373e-01,
                          3.57341886e-01,   3.57283771e-01,   3.57051283e-01,
                          3.56818765e-01,   3.56470048e-01,   3.56121302e-01,
                          3.55830669e-01,   3.55481952e-01,   3.55249435e-01,
                          3.55133206e-01,   3.54726344e-01,   3.54435712e-01,
                          3.54145110e-01,   3.53738248e-01,   3.53563875e-01,
                          3.53215128e-01,   3.52808267e-01,   3.52633893e-01,
                          3.52343291e-01,   3.51878285e-01,   3.51529568e-01,
                          3.51297051e-01,   3.51180822e-01,   3.50773960e-01,
                          3.50367099e-01,   3.50076467e-01,   3.49843979e-01,
                          3.49611491e-01,   3.49262744e-01,   3.48855883e-01,
                          3.48449022e-01,   3.48100275e-01,   3.47809672e-01,
                          3.47635299e-01,   3.47286552e-01,   3.46995950e-01,
                          3.46821576e-01,   3.46472830e-01,   3.46240342e-01,
                          3.46240342e-01,   3.45891595e-01,   3.45542848e-01,
                          3.45368505e-01,   3.45077872e-01,   3.44729125e-01,
                          3.44612896e-01,   3.44380409e-01,   3.44147891e-01,
                          3.43799174e-01,   3.43566656e-01,   3.43508542e-01,
                          3.43392313e-01,   3.43159795e-01,   3.42811078e-01,
                          3.42811078e-01,   3.42752934e-01,   3.42404217e-01,
                          3.42287958e-01,   3.41997355e-01,   3.41881096e-01,
                          3.41881096e-01,   3.41590464e-01,   3.41299862e-01,
                          3.41125488e-01,   3.41009259e-01,   3.41009259e-01,
                          3.40602368e-01,   3.40311766e-01,   3.40195507e-01,
                          3.39788646e-01,   3.39788646e-01,   3.39614272e-01,
                          3.39207411e-01,   3.39265555e-01,   3.39091182e-01,
                          3.38800550e-01,   3.38626176e-01,   3.38277459e-01,
                          3.38044971e-01,   3.37928712e-01,   3.37754339e-01,
                          3.37579966e-01,   3.37347478e-01,   3.37114990e-01,
                          3.36708128e-01,   3.36359382e-01,   3.36243123e-01,
                          3.35894406e-01,   3.35545659e-01,   3.35371286e-01,
                          3.35022539e-01,   3.34615678e-01,   3.34208816e-01,
                          3.33918214e-01,   3.33569467e-01,   3.33046347e-01,
                          3.32871974e-01,   3.32465112e-01,   3.32000136e-01,
                          3.31709534e-01,   3.31128299e-01,   3.30779552e-01,
                          3.30372691e-01,   3.29558969e-01,   3.29093963e-01,
                          3.28803360e-01,   3.28222126e-01,   3.27757150e-01,
                          3.27234030e-01,   3.26594681e-01,   3.26071560e-01,
                          3.25432211e-01,   3.24909091e-01,   3.24327856e-01,
                          3.23456019e-01,   3.22758526e-01,   3.22293550e-01,
                          3.21537942e-01,   3.20840478e-01,   3.20142984e-01,
                          3.19329262e-01,   3.18689913e-01,   3.17876190e-01,
                          3.16888094e-01,   3.16132486e-01,   3.15318763e-01,
                          3.14330667e-01,   3.13400686e-01,   3.12470704e-01,
                          3.11540753e-01,   3.10494512e-01,   3.09506416e-01,
                          3.08634579e-01,   3.07472110e-01,   3.06425899e-01,
                          3.05379689e-01,   3.04159075e-01,   3.02996635e-01,
                          3.01950395e-01,   3.00671697e-01,   2.99451113e-01,
                          2.98288643e-01,   2.97068059e-01,   2.95905590e-01,
                          2.94626862e-01,   2.93290049e-01,   2.91836947e-01,
                          2.90500134e-01,   2.89337665e-01,   2.87768334e-01,
                          2.86315233e-01,   2.85094649e-01,   2.83525318e-01,
                          2.82188505e-01,   2.80851662e-01,   2.79224217e-01,
                          2.77771115e-01,   2.76318043e-01,   2.74806827e-01,
                          2.73179382e-01,   2.71610051e-01,   2.70215094e-01,
                          2.68529534e-01,   2.66727716e-01,   2.65158385e-01,
                          2.63530910e-01,   2.61845350e-01,   2.60276020e-01,
                          2.58648574e-01,   2.56846756e-01,   2.55219281e-01,
                          2.53417462e-01,   2.51673788e-01,   2.50046313e-01,
                          2.48186380e-01,   2.46442676e-01,   2.44698986e-01,
                          2.42664665e-01,   2.40862846e-01,   2.38886654e-01,
                          2.36968592e-01,   2.35166758e-01,   2.32958078e-01,
                          2.31040016e-01,   2.29180068e-01,   2.27029502e-01,
                          2.24995196e-01,   2.22844630e-01,   2.20926568e-01,
                          2.18834117e-01,   2.16683567e-01,   2.14765489e-01,
                          2.12440565e-01,   2.10348129e-01,   2.08255693e-01,
                          2.05872640e-01,   2.03896448e-01,   2.01571509e-01,
                          1.99246585e-01,   1.97212264e-01,   1.94829211e-01,
                          1.92620531e-01,   1.90411851e-01,   1.88145041e-01,
                          1.85994476e-01,   1.83611423e-01,   1.81228369e-01,
                          1.78845316e-01,   1.76520377e-01,   1.74137324e-01,
                          1.71754271e-01,   1.69545591e-01,   1.67220652e-01,
                          1.64721355e-01,   1.62396431e-01,   1.59955248e-01,
                          1.57514066e-01,   1.55131012e-01,   1.52689844e-01,
                          1.50306791e-01,   1.47807479e-01,   1.45250067e-01,
                          1.42808884e-01,   1.40367702e-01,   1.38042778e-01,
                          1.35485351e-01,   1.32927924e-01,   1.30486742e-01,
                          1.27754956e-01,   1.25139400e-01,   1.22756355e-01,
                          1.20082684e-01,   1.17525257e-01,   1.14909708e-01,
                          1.12236038e-01,   1.09794863e-01,   1.07179314e-01,
                          1.04447521e-01,   1.02006346e-01,   9.94489193e-02,
                          9.66008827e-02,   9.38690901e-02,   9.12535414e-02,
                          8.85217488e-02,   8.59062001e-02,   8.33487734e-02,
                          8.05588588e-02,   7.78851882e-02,   7.51533955e-02,
                          7.24215955e-02,   6.97479248e-02,   6.68417662e-02,
                          6.39937222e-02,   6.12619296e-02,   5.84720112e-02,
                          5.58564663e-02,   5.30665480e-02,   5.02766334e-02,
                          4.74867150e-02,   4.45805490e-02,   4.17906344e-02,
                          3.90007161e-02,   3.63851674e-02,   3.35952528e-02,
                          3.05147190e-02,   2.77829245e-02,   2.50511300e-02,
                          2.22030897e-02,   1.93550494e-02,   1.65070090e-02,
                          1.38914622e-02,   1.09852990e-02,   8.19538161e-03,
                          5.52171096e-03,   2.67367065e-03,   0.00000000e+00,
                         -2.84804031e-03,  -5.63795771e-03,  -8.36975127e-03,
                         -1.12759154e-02,  -1.39495861e-02,  -1.66813787e-02,
                         -1.97037905e-02,  -2.22612135e-02,  -2.49930080e-02,
                         -2.78991722e-02,  -3.06890886e-02,  -3.34790051e-02,
                         -3.60945538e-02,  -3.89425941e-02,  -4.19068784e-02,
                         -4.45224270e-02,  -4.72542197e-02,  -5.01603857e-02,
                         -5.28921783e-02,  -5.56820966e-02,  -5.84720112e-02,
                         -6.13200553e-02,  -6.41099736e-02,  -6.67836443e-02,
                         -6.95735589e-02,  -7.24797249e-02,  -7.53277615e-02,
                         -7.81176761e-02,  -8.09657201e-02,  -8.38137567e-02,
                         -8.66036788e-02,  -8.93935934e-02,  -9.22416374e-02,
                         -9.49153081e-02,  -9.78795961e-02,  -1.00785755e-01,
                         -1.03575677e-01,  -1.06423713e-01,  -1.09213628e-01,
                         -1.11945428e-01,  -1.14735343e-01,  -1.17583379e-01,
                         -1.20489545e-01,  -1.23163216e-01,  -1.25836894e-01,
                         -1.28684923e-01,  -1.31358594e-01,  -1.33974150e-01,
                         -1.36822179e-01,  -1.39553979e-01,  -1.42285779e-01,
                         -1.45075694e-01,  -1.47923738e-01,  -1.50713652e-01,
                         -1.53387323e-01,  -1.56119108e-01,  -1.58850908e-01,
                         -1.61640823e-01,  -1.64314494e-01,  -1.67104408e-01,
                         -1.69894323e-01,  -1.72626123e-01,  -1.75416037e-01,
                         -1.77973464e-01,  -1.80589005e-01,  -1.83378935e-01,
                         -1.86052606e-01,  -1.88784391e-01,  -1.91516191e-01,
                         -1.94189861e-01,  -1.97037891e-01,  -1.99711561e-01,
                         -2.02385232e-01,  -2.05000788e-01,  -2.07674459e-01,
                         -2.10464373e-01,  -2.13079914e-01,  -2.15811715e-01,
                         -2.18834117e-01,  -2.21565917e-01,  -2.24413961e-01,
                         -2.27145746e-01,  -2.29935676e-01,  -2.32783705e-01,
                         -2.35399261e-01,  -2.38247290e-01,  -2.41269708e-01,
                         -2.43943378e-01,  -2.46675178e-01,  -2.49697581e-01,
                         -2.52661884e-01,  -2.55451798e-01,  -2.58299828e-01,
                         -2.61147857e-01,  -2.63821542e-01,  -2.66553342e-01,
                         -2.69401371e-01,  -2.72423774e-01,  -2.75504321e-01,
                         -2.78236121e-01,  -2.81142265e-01,  -2.84106553e-01,
                         -2.86722094e-01,  -2.89570153e-01,  -2.92418182e-01,
                         -2.95091867e-01,  -2.97881782e-01,  -3.00846070e-01,
                         -3.03810358e-01,  -3.06600273e-01,  -3.09506416e-01,
                         -3.12412590e-01,  -3.15028131e-01,  -3.17934304e-01,
                         -3.20724219e-01,  -3.23456019e-01,  -3.26304048e-01,
                         -3.29035848e-01,  -3.31883878e-01,  -3.34615678e-01,
                         -3.37463737e-01,  -3.40369880e-01,  -3.42985451e-01,
                         -3.45891595e-01,  -3.48623395e-01,  -3.51238936e-01,
                         -3.54319483e-01,  -3.57167512e-01,  -3.59783053e-01,
                         -3.62572968e-01,  -3.65246654e-01,  -3.68210942e-01,
                         -3.71000856e-01,  -3.73616397e-01,  -3.76406312e-01,
                         -3.79138112e-01,  -3.81986141e-01,  -3.84717941e-01,
                         -3.87507856e-01,  -3.90414029e-01,  -3.93087685e-01,
                         -3.95819485e-01,  -3.98725659e-01,  -4.01457459e-01,
                         -4.04189229e-01,  -4.07037288e-01,  -4.09769088e-01,
                         -4.12500858e-01,  -4.15174544e-01,  -4.17790085e-01,
                         -4.20580000e-01,  -4.23428059e-01,  -4.26159829e-01,
                         -4.28775400e-01,  -4.31565315e-01,  -4.34413344e-01,
                         -4.37028885e-01,  -4.39760685e-01,  -4.42492485e-01,
                         -4.44991767e-01,  -4.47665453e-01,  -4.50339109e-01,
                         -4.53129053e-01,  -4.55802709e-01,  -4.58243877e-01,
                         -4.60917562e-01,  -4.63474989e-01,  -4.65799928e-01,
                         -4.68415469e-01,  -4.70856637e-01,  -4.73181576e-01,
                         -4.75622743e-01,  -4.78180170e-01,  -4.80505109e-01,
                         -4.82713789e-01,  -4.85154957e-01,  -4.87421781e-01,
                         -4.89688575e-01,  -4.92013514e-01,  -4.94164079e-01,
                         -4.96430874e-01,  -4.98697698e-01,  -5.00790119e-01,
                         -5.02882540e-01,  -5.04800618e-01,  -5.06951213e-01,
                         -5.09159863e-01,  -5.11136055e-01,  -5.13286650e-01,
                         -5.15262842e-01,  -5.17355263e-01,  -5.19389570e-01,
                         -5.21249533e-01,  -5.23283839e-01,  -5.25085628e-01,
                         -5.27003706e-01,  -5.29096186e-01,  -5.30956089e-01,
                         -5.32757938e-01,  -5.34559727e-01,  -5.36303461e-01,
                         -5.38221538e-01,  -5.40081441e-01,  -5.41941404e-01,
                         -5.43626964e-01,  -5.45196295e-01,  -5.46940029e-01,
                         -5.48567474e-01,  -5.50136805e-01,  -5.51880479e-01,
                         -5.53449810e-01,  -5.54902911e-01,  -5.56530356e-01,
                         -5.57983398e-01,  -5.59494615e-01,  -5.61005831e-01,
                         -5.62342644e-01,  -5.63795745e-01,  -5.65190732e-01,
                         -5.66469431e-01,  -5.67690015e-01,  -5.68852484e-01,
                         -5.70073068e-01,  -5.71235538e-01,  -5.72281778e-01,
                         -5.73386073e-01,  -5.74257970e-01,  -5.75071692e-01,
                         -5.76175988e-01,  -5.77047884e-01,  -5.77687204e-01,
                         -5.78500926e-01,  -5.79489052e-01,  -5.80302775e-01,
                         -5.80883980e-01,  -5.81465244e-01,  -5.81988335e-01,
                         -5.82569540e-01,  -5.83092690e-01,  -5.83557665e-01,
                         -5.84080756e-01,  -5.84371388e-01,  -5.84545732e-01,
                         -5.84894478e-01,  -5.85126996e-01,  -5.85359514e-01,
                         -5.85533857e-01,  -5.85591972e-01,  -5.85766375e-01,
                         -5.85882604e-01,  -5.85824490e-01,  -5.85940719e-01,
                         -5.85940719e-01,  -5.85650086e-01,  -5.85591972e-01,
                         -5.85591972e-01,  -5.85301340e-01,  -5.84952652e-01,
                         -5.84487617e-01,  -5.84138870e-01,  -5.83790183e-01,
                         -5.83441436e-01,  -5.83150804e-01,  -5.82627714e-01,
                         -5.81872106e-01,  -5.81232727e-01,  -5.80593407e-01,
                         -5.79954028e-01,  -5.79024076e-01,  -5.78094065e-01,
                         -5.77396572e-01,  -5.76292276e-01,  -5.75536668e-01,
                         -5.74839175e-01,  -5.73560476e-01,  -5.72456121e-01,
                         -5.71293652e-01,  -5.70131183e-01,  -5.68910599e-01,
                         -5.67341268e-01,  -5.66004455e-01,  -5.64783871e-01,
                         -5.63156366e-01,  -5.61528921e-01,  -5.60017765e-01,
                         -5.58506548e-01,  -5.56762815e-01,  -5.54961026e-01,
                         -5.53159177e-01,  -5.51182985e-01,  -5.49381196e-01,
                         -5.47521234e-01,  -5.45486927e-01,  -5.43452621e-01,
                         -5.41302025e-01,  -5.39267719e-01,  -5.37291527e-01,
                         -5.34908473e-01,  -5.32757938e-01,  -5.30491114e-01,
                         -5.28049946e-01,  -5.25666893e-01,  -5.23225725e-01,
                         -5.20784557e-01,  -5.18343329e-01,  -5.15727818e-01,
                         -5.13228476e-01,  -5.10496736e-01,  -5.07939279e-01,
                         -5.05556226e-01,  -5.02650082e-01,  -4.99918282e-01,
                         -4.97244596e-01,  -4.94396567e-01,  -4.91606653e-01,
                         -4.88700479e-01,  -4.85794306e-01,  -4.82830018e-01,
                         -4.79865760e-01,  -4.76959586e-01,  -4.73820925e-01,
                         -4.70856637e-01,  -4.67776090e-01,  -4.64521199e-01,
                         -4.61556911e-01,  -4.58534509e-01,  -4.55163360e-01,
                         -4.52082813e-01,  -4.48827922e-01,  -4.45398659e-01,
                         -4.42201853e-01,  -4.38946962e-01,  -4.35517699e-01,
                         -4.32204664e-01,  -4.28949744e-01,  -4.25287992e-01,
                         -4.21858728e-01,  -4.18313205e-01,  -4.14709568e-01,
                         -4.11396533e-01,  -4.07967269e-01,  -4.04363602e-01,
                         -4.00759965e-01,  -3.96981955e-01,  -3.93320203e-01,
                         -3.89658421e-01,  -3.85938525e-01,  -3.82218659e-01,
                         -3.78324389e-01,  -3.74546379e-01,  -3.70826483e-01,
                         -3.66932213e-01,  -3.63270462e-01,  -3.59550565e-01,
                         -3.55714440e-01,  -3.51878285e-01,  -3.47984046e-01,
                         -3.44089776e-01,  -3.39963019e-01,  -3.36068779e-01,
                         -3.32406998e-01,  -3.28396499e-01,  -3.24618489e-01,
                         -3.20840478e-01,  -3.16713721e-01,  -3.12819451e-01,
                         -3.09041440e-01,  -3.05321544e-01,  -3.01427305e-01,
                         -2.97358662e-01,  -2.93464422e-01,  -2.89453894e-01,
                         -2.85501510e-01,  -2.81723499e-01,  -2.77771115e-01,
                         -2.73818731e-01,  -2.70040721e-01,  -2.66204596e-01,
                         -2.62310326e-01,  -2.58416086e-01,  -2.54579931e-01,
                         -2.50743806e-01,  -2.46791422e-01,  -2.42955282e-01,
                         -2.38944784e-01,  -2.35166758e-01,  -2.31330633e-01,
                         -2.27320120e-01,  -2.23542109e-01,  -2.19589725e-01,
                         -2.15521097e-01,  -2.11684957e-01,  -2.07906947e-01,
                         -2.04070807e-01,  -2.00118437e-01,  -1.96107924e-01,
                         -1.92213669e-01,  -1.88261285e-01,  -1.84425145e-01,
                         -1.80472761e-01,  -1.76462263e-01,  -1.72393635e-01,
                         -1.68441251e-01,  -1.64663240e-01,  -1.60885215e-01,
                         -1.56874716e-01,  -1.52864203e-01,  -1.49144322e-01,
                         -1.45250067e-01,  -1.41123310e-01,  -1.37403414e-01,
                         -1.33451030e-01,  -1.29382402e-01,  -1.25720635e-01,
                         -1.21826380e-01,  -1.17815875e-01,  -1.14154108e-01,
                         -1.10317975e-01,  -1.06481835e-01,  -1.02820069e-01,
                         -9.91583019e-02,  -9.53802913e-02,  -9.16022807e-02,
                         -8.79986361e-02,  -8.43949914e-02,  -8.05588588e-02,
                         -7.70133361e-02,  -7.34096915e-02,  -6.96898028e-02,
                         -6.62024096e-02,  -6.27150089e-02,  -5.91694936e-02,
                         -5.56239709e-02,  -5.20784520e-02,  -4.85329330e-02,
                         -4.51036617e-02,  -4.16743867e-02,  -3.83032374e-02,
                         -3.50483321e-02,  -3.16771828e-02,  -2.83060335e-02,
                         -2.49930080e-02,  -2.16218568e-02,  -1.81925837e-02,
                         -1.49376811e-02,  -1.16827777e-02,  -8.36975127e-03,
                         -5.23109455e-03,  -1.80182152e-03,   1.51120510e-03,
                          4.64986172e-03,   7.90476520e-03,   1.11015448e-02,
                          1.44726951e-02,   1.77857224e-02,   2.08662543e-02,
                          2.41211578e-02,   2.73760613e-02,   3.05728409e-02,
                          3.37696224e-02,   3.68501544e-02,   4.00469340e-02,
                          4.32437137e-02,   4.63242494e-02,   4.95210290e-02,
                          5.26015610e-02,   5.57983443e-02,   5.89369982e-02,
                          6.19594082e-02,   6.50980696e-02,   6.81204796e-02,
                          7.11428896e-02,   7.42234215e-02,   7.72458315e-02,
                          8.02682415e-02,   8.31744075e-02,   8.59643221e-02,
                          8.88704881e-02,   9.17766467e-02,   9.45665687e-02,
                          9.72983614e-02,   1.00146398e-01,   1.02878191e-01,
                          1.05551861e-01,   1.08167410e-01,   1.10666715e-01,
                          1.13398507e-01,   1.16072178e-01,   1.18571475e-01,
                          1.21245146e-01,   1.23744451e-01,   1.26069382e-01,
                          1.28684923e-01,   1.31242350e-01,   1.33799776e-01,
                          1.36182830e-01,   1.38565883e-01,   1.41123310e-01,
                          1.43448234e-01,   1.45540670e-01,   1.47865608e-01,
                          1.50190532e-01,   1.52457342e-01,   1.54782280e-01,
                          1.57107204e-01,   1.59315899e-01,   1.61582693e-01,
                          1.63849503e-01,   1.66000068e-01,   1.68266878e-01,
                          1.70417443e-01,   1.72626123e-01,   1.74892932e-01,
                          1.76927239e-01,   1.79077804e-01,   1.81228369e-01,
                          1.83204561e-01,   1.85471371e-01,   1.87680051e-01,
                          1.89598113e-01,   1.91806808e-01,   1.93783000e-01,
                          1.95817307e-01,   1.97967872e-01,   1.99944064e-01,
                          2.01862127e-01,   2.03896448e-01,   2.05872640e-01,
                          2.07732573e-01,   2.09534407e-01,   2.11510599e-01,
                          2.13312417e-01,   2.15056106e-01,   2.16916054e-01,
                          2.18659759e-01,   2.20519707e-01,   2.22379640e-01,
                          2.24007100e-01,   2.25808918e-01,   2.27378249e-01,
                          2.29063824e-01,   2.30691269e-01,   2.32144356e-01,
                          2.33888045e-01,   2.35341132e-01,   2.36677974e-01,
                          2.38189176e-01,   2.39467889e-01,   2.41037220e-01,
                          2.42722794e-01,   2.44001508e-01,   2.45338336e-01,
                          2.46733293e-01,   2.48070136e-01,   2.49348849e-01,
                          2.50801921e-01,   2.52254993e-01,   2.53417462e-01,
                          2.54754305e-01,   2.56207377e-01,   2.57253617e-01,
                          2.58474201e-01,   2.59811044e-01,   2.61147857e-01,
                          2.62426585e-01,   2.63589054e-01,   2.64867753e-01,
                          2.66146481e-01,   2.67483294e-01,   2.68820137e-01,
                          2.69982606e-01,   2.71261305e-01,   2.72307545e-01,
                          2.73470014e-01,   2.75039315e-01,   2.76259929e-01,
                          2.77480513e-01,   2.78759211e-01,   2.79863566e-01,
                          2.81258523e-01,   2.82537222e-01,   2.83583462e-01,
                          2.84745902e-01,   2.85850257e-01,   2.87245214e-01,
                          2.88407683e-01,   2.89453894e-01,   2.90790737e-01,
                          2.91836947e-01,   2.93057531e-01,   2.94103771e-01,
                          2.94975609e-01,   2.96312451e-01,   2.97358662e-01,
                          2.98172385e-01,   2.99451113e-01,   3.00555438e-01,
                          3.01543534e-01,   3.02706003e-01,   3.03577870e-01,
                          3.04624081e-01,   3.05728406e-01,   3.06658387e-01,
                          3.07646483e-01,   3.08518350e-01,   3.09390187e-01,
                          3.10436398e-01,   3.11366379e-01,   3.12121987e-01,
                          3.12993824e-01,   3.14040035e-01,   3.14970016e-01,
                          3.15783739e-01,   3.16713721e-01,   3.17701817e-01,
                          3.18631798e-01,   3.19387376e-01,   3.20201099e-01,
                          3.21189195e-01,   3.22119176e-01,   3.23107272e-01,
                          3.24153483e-01,   3.24909091e-01,   3.25780958e-01,
                          3.26769054e-01,   3.27699006e-01,   3.28512728e-01,
                          3.29384595e-01,   3.30547065e-01,   3.31593275e-01,
                          3.32406998e-01,   3.33220720e-01,   3.34325075e-01,
                          3.35603774e-01,   3.36359382e-01,   3.37173104e-01,
                          3.38219315e-01,   3.39091182e-01,   3.39963019e-01,
                          3.40951115e-01,   3.41764838e-01,   3.42752934e-01,
                          3.43682915e-01,   3.44554752e-01,   3.45368505e-01,
                          3.46356601e-01,   3.47402811e-01,   3.48042160e-01,
                          3.48972142e-01,   3.49843979e-01,   3.50425214e-01,
                          3.51297051e-01,   3.52052659e-01,   3.52808267e-01,
                          3.53621989e-01,   3.54261339e-01,   3.55075091e-01,
                          3.55714440e-01,   3.56411904e-01,   3.57341886e-01,
                          3.57865006e-01,   3.58504355e-01,   3.59259963e-01,
                          3.59608680e-01,   3.60189915e-01,   3.60887408e-01,
                          3.61352384e-01,   3.61759245e-01,   3.62340480e-01,
                          3.63037974e-01,   3.63561064e-01,   3.64200443e-01,
                          3.64723533e-01,   3.65130395e-01,   3.65769774e-01,
                          3.66176635e-01,   3.66699725e-01,   3.67339075e-01,
                          3.67920309e-01,   3.68385315e-01,   3.68850291e-01,
                          3.69431525e-01,   3.70012760e-01,   3.70477736e-01,
                          3.71000856e-01,   3.71291459e-01,   3.71988952e-01,
                          3.72628301e-01,   3.72918934e-01,   3.73674512e-01,
                          3.74139518e-01,   3.74313891e-01,   3.74895126e-01,
                          3.75243843e-01,   3.75708848e-01,   3.76290083e-01,
                          3.76696944e-01,   3.77161920e-01,   3.77510667e-01,
                          3.77917528e-01,   3.78324389e-01,   3.78556877e-01,
                          3.79021853e-01,   3.79370600e-01,   3.79661232e-01,
                          3.79951835e-01,   3.80242467e-01,   3.80591184e-01,
                          3.80533069e-01,   3.80765557e-01,   3.81288677e-01,
                          3.81230563e-01,   3.81404907e-01,   3.81695539e-01,
                          3.81695539e-01,   3.81811798e-01,   3.81811798e-01,
                          3.81811798e-01,   3.81928027e-01,   3.81869912e-01,
                          3.81869912e-01,   3.81928027e-01,   3.81986141e-01,
                          3.81986141e-01,   3.81753653e-01,   3.81753653e-01,
                          3.81753653e-01,   3.81579280e-01,   3.81637424e-01,
                          3.81463051e-01,   3.81463051e-01,   3.81346792e-01,
                          3.81114304e-01,   3.81288677e-01,   3.81114304e-01,
                          3.80765557e-01,   3.80881816e-01,   3.80823702e-01,
                          3.80765557e-01,   3.80649328e-01,   3.80300581e-01,
                          3.80300581e-01,   3.80184323e-01,   3.79835606e-01,
                          3.79719347e-01,   3.79661232e-01,   3.79661232e-01,
                          3.79544973e-01,   3.79428715e-01,   3.79312485e-01,
                          3.79196227e-01,   3.79138112e-01,   3.78963739e-01,
                          3.78847510e-01,   3.78731251e-01,   3.78440619e-01,
                          3.78324389e-01,   3.78324389e-01,   3.78033757e-01,
                          3.77859414e-01,   3.77917528e-01,   3.77917528e-01,
                          3.77568781e-01,   3.77220035e-01,   3.77103806e-01,
                          3.76755059e-01,   3.76522571e-01,   3.76290083e-01,
                          3.75825077e-01,   3.75592589e-01,   3.75360101e-01,
                          3.75185728e-01,   3.74895126e-01,   3.74313891e-01,
                          3.74081373e-01,   3.74023259e-01,   3.73558283e-01,
                          3.73093277e-01,   3.72744560e-01,   3.72337699e-01,
                          3.71988952e-01,   3.71582091e-01,   3.71117115e-01,
                          3.70826483e-01,   3.70477736e-01,   3.70070875e-01,
                          3.69838387e-01,   3.69431525e-01,   3.68908405e-01,
                          3.68792176e-01,   3.68559688e-01,   3.68210942e-01,
                          3.67978454e-01,   3.67513448e-01,   3.67280960e-01,
                          3.67048472e-01,   3.66467237e-01,   3.66350979e-01,
                          3.65944117e-01,   3.65537256e-01,   3.65595400e-01,
                          3.65246654e-01,   3.64781678e-01,   3.64665419e-01,
                          3.64491045e-01,   3.64142299e-01,   3.63851696e-01,
                          3.63735437e-01,   3.63502949e-01,   3.63154203e-01,
                          3.62921715e-01,   3.62514853e-01,   3.62282366e-01,
                          3.62049878e-01,   3.61584872e-01,   3.61236155e-01,
                          3.60829294e-01,   3.60422432e-01,   3.60131800e-01,
                          3.59608680e-01,   3.59201819e-01,   3.58736843e-01,
                          3.58213723e-01,   3.57748747e-01,   3.57225627e-01,
                          3.56702536e-01,   3.56121302e-01,   3.55598181e-01,
                          3.55133206e-01,   3.54435712e-01,   3.53912622e-01,
                          3.53447616e-01,   3.52459520e-01,   3.51878285e-01,
                          3.51355195e-01,   3.50483328e-01,   3.50076467e-01,
                          3.49320859e-01,   3.48274648e-01,   3.47519040e-01,
                          3.46763462e-01,   3.46124083e-01,   3.45484734e-01,
                          3.44729125e-01,   3.43915403e-01,   3.42985451e-01,
                          3.42229843e-01,   3.41416121e-01,   3.40544254e-01,
                          3.39846790e-01,   3.38974923e-01,   3.37986827e-01,
                          3.37056875e-01,   3.36068779e-01,   3.35255027e-01,
                          3.34499449e-01,   3.33685726e-01,   3.32697630e-01,
                          3.31651390e-01,   3.30779552e-01,   3.29907686e-01,
                          3.28861475e-01,   3.27582777e-01,   3.26420307e-01,
                          3.25374097e-01,   3.24386001e-01,   3.23397905e-01,
                          3.22293550e-01,   3.21131080e-01,   3.20026755e-01,
                          3.18689913e-01,   3.17411184e-01,   3.16190600e-01,
                          3.14737529e-01,   3.13400686e-01,   3.12121987e-01,
                          3.10785145e-01,   3.09448302e-01,   3.07820857e-01,
                          3.06484014e-01,   3.05147171e-01,   3.03577870e-01,
                          3.02066654e-01,   3.00381064e-01,   2.98695505e-01,
                          2.97242433e-01,   2.95673102e-01,   2.93871284e-01,
                          2.92185694e-01,   2.90558249e-01,   2.88698286e-01,
                          2.86896467e-01,   2.85327137e-01,   2.83525318e-01,
                          2.81607270e-01,   2.79863566e-01,   2.78003603e-01,
                          2.76201785e-01,   2.74341851e-01,   2.72598147e-01,
                          2.70796329e-01,   2.68820137e-01,   2.67076433e-01,
                          2.65042126e-01,   2.63240308e-01,   2.61670977e-01,
                          2.59636670e-01,   2.57834852e-01,   2.55916774e-01,
                          2.53824323e-01,   2.52196878e-01,   2.50336945e-01,
                          2.48535112e-01,   2.46675178e-01,   2.44524613e-01,
                          2.42722794e-01,   2.40862846e-01,   2.38770410e-01,
                          2.36852333e-01,   2.34876141e-01,   2.33016208e-01,
                          2.31040016e-01,   2.29180068e-01,   2.27262005e-01,
                          2.25111440e-01,   2.23193377e-01,   2.21217185e-01,
                          2.19299108e-01,   2.17381045e-01,   2.15114236e-01,
                          2.13196173e-01,   2.11161852e-01,   2.08720669e-01,
                          2.06860736e-01,   2.04826415e-01,   2.02675849e-01,
                          2.00467169e-01,   1.98258489e-01,   1.96224168e-01,
                          1.93957359e-01,   1.91690549e-01,   1.89539999e-01,
                          1.87273189e-01,   1.85122624e-01,   1.82855815e-01,
                          1.80356517e-01,   1.78147838e-01,   1.75939143e-01,
                          1.73556089e-01,   1.71173036e-01,   1.68848112e-01,
                          1.66523173e-01,   1.64023876e-01,   1.61524579e-01,
                          1.59141526e-01,   1.56816587e-01,   1.54549778e-01,
                          1.52108610e-01,   1.49667427e-01,   1.47284374e-01,
                          1.44726947e-01,   1.42285779e-01,   1.40018970e-01,
                          1.37577787e-01,   1.35369107e-01,   1.32986054e-01,
                          1.30370498e-01,   1.27987444e-01,   1.25778764e-01,
                          1.23511955e-01,   1.21012658e-01,   1.18629605e-01,
                          1.16304673e-01,   1.13921613e-01,   1.11480437e-01,
                          1.09097384e-01,   1.06830575e-01,   1.04563765e-01,
                          1.02122590e-01,   9.97976586e-02,   9.74146053e-02,
                          9.50896740e-02,   9.26484987e-02,   9.00329500e-02,
                          8.78242627e-02,   8.53249654e-02,   8.27094167e-02,
                          8.04426074e-02,   7.78270662e-02,   7.52115175e-02,
                          7.27122128e-02,   7.00966641e-02,   6.76554888e-02,
                          6.50980696e-02,   6.26568869e-02,   5.99832200e-02,
                          5.71351759e-02,   5.45777529e-02,   5.19622080e-02,
                          4.92304116e-02,   4.66148667e-02,   4.38830703e-02,
                          4.13837694e-02,   3.85357291e-02,   3.55714448e-02,
                          3.29558961e-02,   3.02241016e-02,   2.76085548e-02,
                          2.49930080e-02,   2.20287200e-02,   1.91806797e-02,
                          1.64488871e-02,   1.38914622e-02,   1.11596687e-02,
                          8.19538161e-03,   5.40546421e-03,   2.55742413e-03,
                         -1.16246549e-04,  -2.73179379e-03,  -5.63795771e-03,
                         -8.42787419e-03,  -1.12759154e-02,  -1.40658319e-02,
                         -1.66813787e-02,  -1.95875429e-02,  -2.23193374e-02,
                         -2.49930080e-02,  -2.77248006e-02,  -3.04565951e-02,
                         -3.33627574e-02,  -3.61526757e-02,  -3.88844684e-02,
                         -4.16162647e-02,  -4.44643050e-02,  -4.73123454e-02,
                         -4.99860160e-02,  -5.28340563e-02,  -5.56820966e-02,
                         -5.82976416e-02,  -6.12038076e-02,  -6.40518442e-02,
                         -6.67836443e-02,  -6.96316808e-02,  -7.24215955e-02,
                         -7.52696395e-02,  -7.81758055e-02,  -8.10819641e-02,
                         -8.39881301e-02,  -8.66036788e-02,  -8.94517154e-02,
                         -9.25322548e-02,  -9.54965353e-02,  -9.85189453e-02,
                         -1.01366989e-01,  -1.04273155e-01,  -1.07295565e-01,
                         -1.10143602e-01,  -1.13224134e-01,  -1.16188422e-01,
                         -1.19210832e-01,  -1.22407615e-01,  -1.25139400e-01,
                         -1.28045574e-01,  -1.31300479e-01,  -1.34090394e-01,
                         -1.36996552e-01,  -1.40135214e-01,  -1.43157616e-01,
                         -1.46121904e-01,  -1.49144322e-01,  -1.52341098e-01,
                         -1.55421630e-01,  -1.58269674e-01,  -1.61233962e-01,
                         -1.64256364e-01,  -1.67336911e-01,  -1.70301184e-01,
                         -1.73207358e-01,  -1.76229760e-01,  -1.79019675e-01,
                         -1.82100222e-01,  -1.85122624e-01,  -1.87854424e-01,
                         -1.90876827e-01,  -1.93841115e-01,  -1.96747273e-01,
                         -1.99769691e-01,  -2.02617735e-01,  -2.05640137e-01,
                         -2.08488181e-01,  -2.11336225e-01,  -2.14416757e-01,
                         -2.17090428e-01,  -2.20054716e-01,  -2.23193377e-01,
                         -2.26215780e-01,  -2.29238197e-01,  -2.32028112e-01,
                         -2.34992400e-01,  -2.37956688e-01,  -2.40804717e-01,
                         -2.43885249e-01,  -2.46849537e-01,  -2.49755710e-01,
                         -2.53010601e-01,  -2.56033033e-01,  -2.59113550e-01,
                         -2.62194097e-01,  -2.65216500e-01,  -2.68355161e-01,
                         -2.71261305e-01,  -2.74283737e-01,  -2.77422398e-01,
                         -2.80444801e-01,  -2.83641577e-01,  -2.86780238e-01,
                         -2.89802641e-01,  -2.92825043e-01,  -2.96079963e-01,
                         -2.99334854e-01,  -3.02241027e-01,  -3.05263430e-01,
                         -3.08402091e-01,  -3.11424494e-01,  -3.14621270e-01,
                         -3.17818046e-01,  -3.20898592e-01,  -3.24037254e-01,
                         -3.27001542e-01,  -3.30140203e-01,  -3.33278835e-01,
                         -3.36243123e-01,  -3.39265555e-01,  -3.42287958e-01,
                         -3.45310360e-01,  -3.48449022e-01,  -3.51471424e-01,
                         -3.54319483e-01,  -3.57283771e-01,  -3.60422432e-01,
                         -3.63386691e-01,  -3.66350979e-01,  -3.69431525e-01,
                         -3.72279555e-01,  -3.75127614e-01,  -3.78091902e-01,
                         -3.81056190e-01,  -3.83962333e-01,  -3.86752248e-01,
                         -3.89658421e-01,  -3.92564595e-01,  -3.95354509e-01,
                         -3.98376912e-01,  -4.01283085e-01,  -4.04014885e-01,
                         -4.06921029e-01,  -4.09827203e-01,  -4.12675232e-01,
                         -4.15581405e-01,  -4.18371320e-01,  -4.21277493e-01,
                         -4.24125522e-01,  -4.26857322e-01,  -4.29995984e-01,
                         -4.32727784e-01,  -4.35401440e-01,  -4.38307613e-01,
                         -4.41097528e-01,  -4.43829328e-01,  -4.46735471e-01,
                         -4.49467272e-01,  -4.52257186e-01,  -4.55163360e-01,
                         -4.57778901e-01,  -4.60394442e-01,  -4.63242501e-01,
                         -4.66032416e-01,  -4.68764186e-01,  -4.71379757e-01,
                         -4.74053413e-01,  -4.76785213e-01,  -4.79342639e-01,
                         -4.81958181e-01,  -4.84573722e-01,  -4.87014920e-01,
                         -4.89688575e-01,  -4.92187887e-01,  -4.94512796e-01,
                         -4.97128367e-01,  -4.99569535e-01,  -5.01836360e-01,
                         -5.04335642e-01,  -5.06660581e-01,  -5.08985519e-01,
                         -5.11310458e-01,  -5.13519108e-01,  -5.15785933e-01,
                         -5.17994642e-01,  -5.20261407e-01,  -5.22470117e-01,
                         -5.24504423e-01,  -5.26654959e-01,  -5.28631151e-01,
                         -5.30839860e-01,  -5.33281028e-01,  -5.35082877e-01,
                         -5.37059069e-01,  -5.39209604e-01,  -5.41127682e-01,
                         -5.43161988e-01,  -5.44963837e-01,  -5.46765625e-01,
                         -5.48625588e-01,  -5.50311148e-01,  -5.52171111e-01,
                         -5.54031014e-01,  -5.56007206e-01,  -5.57750940e-01,
                         -5.59262156e-01,  -5.61005831e-01,  -5.62749505e-01,
                         -5.64435124e-01,  -5.66236913e-01,  -5.67631900e-01,
                         -5.69259346e-01,  -5.70886791e-01,  -5.72223604e-01,
                         -5.73851049e-01,  -5.75478554e-01,  -5.76641023e-01,
                         -5.78035951e-01,  -5.79547167e-01,  -5.80942094e-01,
                         -5.82220852e-01,  -5.83557665e-01,  -5.84952652e-01,
                         -5.86231351e-01,  -5.87277532e-01,  -5.88498116e-01,
                         -5.89544356e-01,  -5.90474308e-01,  -5.91811180e-01,
                         -5.92973650e-01,  -5.93787372e-01,  -5.94717324e-01,
                         -5.95589161e-01,  -5.96402884e-01,  -5.97332895e-01,
                         -5.98030388e-01,  -5.98727822e-01,  -5.99367201e-01,
                         -5.99774063e-01,  -6.00297153e-01,  -6.00936532e-01,
                         -6.01517737e-01,  -6.01924598e-01,  -6.02099001e-01,
                         -6.02389634e-01,  -6.02680206e-01,  -6.02912724e-01,
                         -6.03145182e-01,  -6.03203356e-01,  -6.03087068e-01,
                         -6.03028953e-01,  -6.03145182e-01,  -6.03087068e-01,
                         -6.02970839e-01,  -6.02796495e-01,  -6.02563977e-01,
                         -6.02389634e-01,  -6.02157116e-01,  -6.01575851e-01,
                         -6.01168990e-01,  -6.00820303e-01,  -6.00355268e-01,
                         -5.99948406e-01,  -5.99309087e-01,  -5.98727822e-01,
                         -5.98088503e-01,  -5.97274780e-01,  -5.96577287e-01,
                         -5.95879793e-01,  -5.95066071e-01,  -5.94484866e-01,
                         -5.93496740e-01,  -5.92334270e-01,  -5.91346204e-01,
                         -5.90299964e-01,  -5.89311898e-01,  -5.88207543e-01,
                         -5.87045074e-01,  -5.85940719e-01,  -5.84603906e-01,
                         -5.83208919e-01,  -5.81930220e-01,  -5.80360889e-01,
                         -5.78965902e-01,  -5.77396572e-01,  -5.75827241e-01,
                         -5.74374199e-01,  -5.72572351e-01,  -5.70712447e-01,
                         -5.69143116e-01,  -5.67399383e-01,  -5.65423191e-01,
                         -5.63621402e-01,  -5.61587095e-01,  -5.59436500e-01,
                         -5.57402194e-01,  -5.55309772e-01,  -5.53159177e-01,
                         -5.50950527e-01,  -5.48509359e-01,  -5.46126306e-01,
                         -5.43859482e-01,  -5.41418314e-01,  -5.38918972e-01,
                         -5.36303461e-01,  -5.33920407e-01,  -5.31362951e-01,
                         -5.28573036e-01,  -5.26073754e-01,  -5.23400068e-01,
                         -5.20435810e-01,  -5.17820239e-01,  -5.14797807e-01,
                         -5.11775434e-01,  -5.09101748e-01,  -5.06195605e-01,
                         -5.03289402e-01,  -5.00267029e-01,  -4.97244596e-01,
                         -4.94280308e-01,  -4.91083533e-01,  -4.88061130e-01,
                         -4.85154957e-01,  -4.81900066e-01,  -4.78703290e-01,
                         -4.75680858e-01,  -4.72484082e-01,  -4.69229192e-01,
                         -4.66148645e-01,  -4.62951869e-01,  -4.59522605e-01,
                         -4.56209570e-01,  -4.52954680e-01,  -4.49583530e-01,
                         -4.46270496e-01,  -4.42841232e-01,  -4.39411938e-01,
                         -4.36098933e-01,  -4.32669640e-01,  -4.29298490e-01,
                         -4.25985485e-01,  -4.22439963e-01,  -4.18894440e-01,
                         -4.15290803e-01,  -4.11861509e-01,  -4.08548474e-01,
                         -4.04944837e-01,  -4.01457459e-01,  -3.97970051e-01,
                         -3.94308299e-01,  -3.90704632e-01,  -3.86926621e-01,
                         -3.83148611e-01,  -3.79661232e-01,  -3.75883222e-01,
                         -3.72221440e-01,  -3.68559688e-01,  -3.64665419e-01,
                         -3.60945523e-01,  -3.57225627e-01,  -3.53447616e-01,
                         -3.49669605e-01,  -3.45891595e-01,  -3.41997355e-01,
                         -3.38103086e-01,  -3.34325075e-01,  -3.30547065e-01,
                         -3.26827168e-01,  -3.22991043e-01,  -3.19096774e-01,
                         -3.15434992e-01,  -3.11540753e-01,  -3.07704598e-01,
                         -3.03810358e-01,  -2.99741715e-01,  -2.96021819e-01,
                         -2.92185694e-01,  -2.88349569e-01,  -2.84571558e-01,
                         -2.80677289e-01,  -2.77015507e-01,  -2.73179382e-01,
                         -2.69226998e-01,  -2.65623361e-01,  -2.61845350e-01,
                         -2.58009225e-01,  -2.54173070e-01,  -2.50278801e-01,
                         -2.46617049e-01,  -2.42722794e-01,  -2.39002898e-01,
                         -2.35283017e-01,  -2.31388748e-01,  -2.27726981e-01,
                         -2.24007100e-01,  -2.20170960e-01,  -2.16392949e-01,
                         -2.12556809e-01,  -2.08836928e-01,  -2.05058903e-01,
                         -2.01339021e-01,  -1.97619125e-01,  -1.93841115e-01,
                         -1.90179348e-01,  -1.86517581e-01,  -1.82681441e-01,
                         -1.78961560e-01,  -1.75009176e-01,  -1.71347409e-01,
                         -1.67743772e-01,  -1.63907632e-01,  -1.60187736e-01,
                         -1.56525970e-01,  -1.52747959e-01,  -1.48969948e-01,
                         -1.45250067e-01,  -1.41530171e-01,  -1.37810275e-01,
                         -1.34148508e-01,  -1.30486742e-01,  -1.26592487e-01,
                         -1.22988850e-01,  -1.19385205e-01,  -1.15607187e-01,
                         -1.12061672e-01,  -1.08458027e-01,  -1.04796261e-01,
                         -1.01192616e-01,  -9.75889787e-02,  -9.39853340e-02,
                         -9.04398113e-02,  -8.68361741e-02,  -8.31744075e-02,
                         -7.96288848e-02,  -7.63739794e-02,  -7.28284642e-02,
                         -6.92829415e-02,  -6.58536702e-02,  -6.24243952e-02,
                         -5.89951240e-02,  -5.54496013e-02,  -5.20784520e-02,
                         -4.87654246e-02,  -4.53361534e-02,  -4.19650041e-02,
                         -3.87100987e-02,  -3.53389494e-02,  -3.19678001e-02,
                         -2.87128966e-02,  -2.56323628e-02,  -2.23193374e-02,
                         -1.88900642e-02,  -1.58095304e-02,  -1.24965040e-02,
                         -9.24160052e-03,  -6.10294379e-03,  -2.78991717e-03,
                          2.90616357e-04,   3.42927314e-03,   6.68417662e-03,
                          9.70658660e-03,   1.29033662e-02,   1.60420239e-02,
                          1.91225577e-02,   2.23193374e-02,   2.52255015e-02,
                          2.83641573e-02,   3.16190608e-02,   3.46995927e-02,
                          3.77801284e-02,   4.08606604e-02,   4.39411961e-02,
                          4.69636060e-02,   4.99278903e-02,   5.29503003e-02,
                          5.58564663e-02,   5.86463846e-02,   6.15525469e-02,
                          6.46912009e-02,   6.75392449e-02,   7.03291595e-02,
                          7.34096915e-02,   7.63158575e-02,   7.90476501e-02,
                          8.20119381e-02,   8.47437307e-02,   8.76498967e-02,
                          9.05560628e-02,   9.31134820e-02,   9.59615260e-02,
                          9.86933187e-02,   1.01250745e-01,   1.04098782e-01,
                          1.06946826e-01,   1.09562367e-01,   1.12061672e-01,
                          1.14619099e-01,   1.17292769e-01,   1.19792067e-01,
                          1.22291364e-01,   1.24965034e-01,   1.27464339e-01,
                          1.29963636e-01,   1.32462934e-01,   1.34904116e-01,
                          1.37461543e-01,   1.39902726e-01,   1.42111406e-01,
                          1.44610703e-01,   1.47051886e-01,   1.49318695e-01,
                          1.51701748e-01,   1.53968558e-01,   1.56177238e-01,
                          1.58444047e-01,   1.60594597e-01,   1.62861407e-01,
                          1.65186346e-01,   1.67395025e-01,   1.69545591e-01,
                          1.71754271e-01,   1.73846707e-01,   1.76113516e-01,
                          1.78322196e-01,   1.80356517e-01,   1.82565197e-01,
                          1.84657633e-01,   1.86808199e-01,   1.89075008e-01,
                          1.90993071e-01,   1.93027392e-01,   1.95061699e-01,
                          1.96805403e-01,   1.98781595e-01,   2.00932160e-01,
                          2.02966467e-01,   2.04826415e-01,   2.06628233e-01,
                          2.08604425e-01,   2.10464373e-01,   2.12324321e-01,
                          2.14358628e-01,   2.16218576e-01,   2.18020394e-01,
                          2.19880342e-01,   2.21565917e-01,   2.23367736e-01,
                          2.25169554e-01,   2.26797014e-01,   2.28540704e-01,
                          2.30342537e-01,   2.31969982e-01,   2.33539313e-01,
                          2.35166758e-01,   2.36736089e-01,   2.38479793e-01,
                          2.40049124e-01,   2.41502196e-01,   2.43304029e-01,
                          2.44931474e-01,   2.46210188e-01,   2.47779518e-01,
                          2.49348849e-01,   2.50860035e-01,   2.52313137e-01,
                          2.53708094e-01,   2.55161166e-01,   2.56556123e-01,
                          2.58067340e-01,   2.59578526e-01,   2.60915369e-01,
                          2.62368470e-01,   2.63879657e-01,   2.65158385e-01,
                          2.66553342e-01,   2.67948300e-01,   2.69343257e-01,
                          2.70796329e-01,   2.72191286e-01,   2.73528129e-01,
                          2.74748713e-01,   2.76143670e-01,   2.77771115e-01,
                          2.78991699e-01,   2.80270427e-01,   2.81665385e-01,
                          2.82944083e-01,   2.84455299e-01,   2.85850257e-01,
                          2.87128985e-01,   2.88582057e-01,   2.89860755e-01,
                          2.91255713e-01,   2.92708814e-01,   2.93871284e-01,
                          2.95324355e-01,   2.96777427e-01,   2.97823668e-01,
                          2.99160480e-01,   3.00497323e-01,   3.01717907e-01,
                          3.03171009e-01,   3.04449707e-01,   3.05554062e-01,
                          3.06832761e-01,   3.08169603e-01,   3.09448302e-01,
                          3.10610771e-01,   3.11831355e-01,   3.13110083e-01,
                          3.14330667e-01,   3.15434992e-01,   3.16597462e-01,
                          3.17876190e-01,   3.18980515e-01,   3.20084870e-01,
                          3.21363568e-01,   3.22526038e-01,   3.23456019e-01,
                          3.24676603e-01,   3.25955331e-01,   3.27001542e-01,
                          3.28222126e-01,   3.29268336e-01,   3.30256432e-01,
                          3.31360787e-01,   3.32406998e-01,   3.33627582e-01,
                          3.34848166e-01,   3.35778147e-01,   3.36824358e-01,
                          3.37928712e-01,   3.38800550e-01,   3.39846790e-01,
                          3.40951115e-01,   3.41997355e-01,   3.42927307e-01,
                          3.44031662e-01,   3.45077872e-01,   3.46007854e-01,
                          3.47112179e-01,   3.48100275e-01,   3.48972142e-01,
                          3.50018352e-01,   3.51006448e-01,   3.52052659e-01,
                          3.52924526e-01,   3.53680104e-01,   3.54668200e-01,
                          3.55598181e-01,   3.56586277e-01,   3.57458144e-01,
                          3.58329982e-01,   3.59376192e-01,   3.60073686e-01,
                          3.60887408e-01,   3.61933619e-01,   3.62689227e-01,
                          3.63677323e-01,   3.64549160e-01,   3.65188539e-01,
                          3.66176635e-01,   3.66874099e-01,   3.67571592e-01,
                          3.68559688e-01,   3.69257152e-01,   3.70012760e-01,
                          3.70710224e-01,   3.71175230e-01,   3.71988952e-01,
                          3.72628301e-01,   3.73209536e-01,   3.74081373e-01,
                          3.74604493e-01,   3.75011355e-01,   3.75592589e-01,
                          3.76348197e-01,   3.77103806e-01,   3.77626896e-01,
                          3.78033757e-01,   3.78498763e-01,   3.79079998e-01,
                          3.79661232e-01,   3.80184323e-01,   3.80707443e-01,
                          3.81230563e-01,   3.81753653e-01,   3.82218659e-01,
                          3.82683635e-01,   3.83381099e-01,   3.83846104e-01,
                          3.84020478e-01,   3.84485453e-01,   3.84950429e-01,
                          3.85415435e-01,   3.85706037e-01,   3.86054784e-01,
                          3.86636019e-01,   3.86984766e-01,   3.87275368e-01,
                          3.87624115e-01,   3.87856603e-01,   3.88612211e-01,
                          3.89135301e-01,   3.89135301e-01,   3.89658421e-01,
                          3.90007168e-01,   3.90355915e-01,   3.90879005e-01,
                          3.91111493e-01,   3.91344011e-01,   3.91692728e-01,
                          3.92041475e-01,   3.92390221e-01,   3.92622709e-01,
                          3.92913342e-01,   3.93262058e-01,   3.93494546e-01,
                          3.93727064e-01,   3.93959552e-01,   3.94250154e-01,
                          3.94424528e-01,   3.94715160e-01,   3.94889534e-01,
                          3.95063877e-01,   3.95296395e-01,   3.95354509e-01,
                          3.95470738e-01,   3.95819485e-01,   3.95993859e-01,
                          3.96226346e-01,   3.96284491e-01,   3.96284491e-01,
                          3.96458834e-01,   3.96458834e-01,   3.96516979e-01,
                          3.96633208e-01,   3.96749467e-01,   3.96865726e-01,
                          3.96865726e-01,   3.96865726e-01,   3.97098213e-01,
                          3.97098213e-01,   3.97040069e-01,   3.97156328e-01,
                          3.97098213e-01,   3.97098213e-01,   3.97214442e-01,
                          3.97388816e-01,   3.97563189e-01,   3.97563189e-01,
                          3.97563189e-01,   3.97737563e-01,   3.97911936e-01,
                          3.97970051e-01,   3.98028165e-01,   3.98086309e-01,
                          3.98086309e-01,   3.98202538e-01,   3.98260683e-01,
                          3.98202538e-01,   3.98260683e-01,   3.98318797e-01,
                          3.98493171e-01,   3.98551285e-01,   3.98493171e-01,
                          3.98667544e-01,   3.98667544e-01,   3.98667544e-01,
                          3.98958147e-01,   3.98667544e-01,   3.98609400e-01,
                          3.99016261e-01,   3.98958147e-01,   3.98841888e-01,
                          3.99074405e-01,   3.99016261e-01,   3.99248779e-01,
                          3.99481267e-01,   3.99306893e-01,   3.99365008e-01,
                          3.99423122e-01,   3.99423122e-01,   3.99365008e-01,
                          3.99306893e-01,   3.99481267e-01,   3.99713755e-01,
                          3.99713755e-01,   3.99597496e-01,   3.99423122e-01,
                          3.99539381e-01,   3.99771869e-01,   3.99597496e-01,
                          3.99423122e-01,   3.99365008e-01,   3.99365008e-01,
                          3.99423122e-01,   3.99365008e-01,   3.99132520e-01,
                          3.98958147e-01,   3.98900032e-01,   3.98783773e-01,
                          3.98725659e-01,   3.98725659e-01,   3.98551285e-01,
                          3.98493171e-01,   3.98376912e-01,   3.98086309e-01,
                          3.98028165e-01,   3.97911936e-01,   3.97737563e-01,
                          3.97621304e-01,   3.97330701e-01,   3.97098213e-01,
                          3.96923840e-01,   3.96691352e-01,   3.96458834e-01,
                          3.96226346e-01,   3.96110117e-01,   3.95761371e-01,
                          3.95412624e-01,   3.95180136e-01,   3.95005763e-01,
                          3.94831389e-01,   3.94657016e-01,   3.94133925e-01,
                          3.93610805e-01,   3.93320203e-01,   3.93029571e-01,
                          3.92680824e-01,   3.92215848e-01,   3.91808987e-01,
                          3.91285866e-01,   3.90820891e-01,   3.90297771e-01,
                          3.89832795e-01,   3.89425933e-01,   3.88844699e-01,
                          3.88147205e-01,   3.87449741e-01,   3.86810392e-01,
                          3.86229157e-01,   3.85531664e-01,   3.84950429e-01,
                          3.84311080e-01,   3.83497357e-01,   3.82625520e-01,
                          3.81869912e-01,   3.81114304e-01,   3.80358696e-01,
                          3.79544973e-01,   3.78556877e-01,   3.77568781e-01,
                          3.76813173e-01,   3.75825077e-01,   3.74720752e-01,
                          3.73732656e-01,   3.72628301e-01,   3.71698320e-01,
                          3.70710224e-01,   3.69431525e-01,   3.68152827e-01,
                          3.66874099e-01,   3.65711629e-01,   3.64607304e-01,
                          3.63386691e-01,   3.62107992e-01,   3.60945523e-01,
                          3.59666824e-01,   3.58213723e-01,   3.56818765e-01,
                          3.55598181e-01,   3.54086995e-01,   3.52575779e-01,
                          3.51413310e-01,   3.49960238e-01,   3.48274648e-01,
                          3.46879691e-01,   3.45310360e-01,   3.43799174e-01,
                          3.42229843e-01,   3.40660512e-01,   3.39149296e-01,
                          3.37289363e-01,   3.35371286e-01,   3.33918214e-01,
                          3.32290769e-01,   3.30430806e-01,   3.28745246e-01,
                          3.27001542e-01,   3.25199723e-01,   3.23339760e-01,
                          3.21479827e-01,   3.19678009e-01,   3.17934304e-01,
                          3.16132486e-01,   3.14040035e-01,   3.11947614e-01,
                          3.10145795e-01,   3.08227718e-01,   3.06077152e-01,
                          3.04042846e-01,   3.02008539e-01,   2.99974203e-01,
                          2.97998011e-01,   2.95847476e-01,   2.93638766e-01,
                          2.91546345e-01,   2.89337665e-01,   2.87128985e-01,
                          2.85094649e-01,   2.82885969e-01,   2.80793548e-01,
                          2.78642982e-01,   2.76201785e-01,   2.73876876e-01,
                          2.71551937e-01,   2.69226998e-01,   2.67018318e-01,
                          2.64693379e-01,   2.62426585e-01,   2.59985387e-01,
                          2.57544219e-01,   2.55277425e-01,   2.52894372e-01,
                          2.50627548e-01,   2.48360753e-01,   2.45628953e-01,
                          2.43129656e-01,   2.40746602e-01,   2.38247290e-01,
                          2.35806122e-01,   2.33423069e-01,   2.30923772e-01,
                          2.28308216e-01,   2.25867033e-01,   2.23367736e-01,
                          2.20694065e-01,   2.18136638e-01,   2.15579227e-01,
                          2.12905556e-01,   2.10464373e-01,   2.07906947e-01,
                          2.05291405e-01,   2.02908352e-01,   2.00292796e-01,
                          1.97677255e-01,   1.95003584e-01,   1.92329913e-01,
                          1.89772487e-01,   1.87040687e-01,   1.84250772e-01,
                          1.81577101e-01,   1.79019675e-01,   1.76346019e-01,
                          1.73556089e-01,   1.70824304e-01,   1.68208748e-01,
                          1.65418833e-01,   1.62687048e-01,   1.59839004e-01,
                          1.57049090e-01,   1.54375419e-01,   1.51585504e-01,
                          1.48795575e-01,   1.46005660e-01,   1.43331990e-01,
                          1.40483946e-01,   1.37577787e-01,   1.34787872e-01,
                          1.31823584e-01,   1.28859296e-01,   1.26011252e-01,
                          1.23105094e-01,   1.20257050e-01,   1.17467135e-01,
                          1.14270352e-01,   1.11247942e-01,   1.08516149e-01,
                          1.05551861e-01,   1.02587581e-01,   9.97395366e-02,
                          9.67171267e-02,   9.38109607e-02,   9.10791680e-02,
                          8.80567580e-02,   8.49762261e-02,   8.21863115e-02,
                          7.90476501e-02,   7.58508742e-02,   7.31190816e-02,
                          7.01547936e-02,   6.70742542e-02,   6.39937222e-02,
                          6.09131902e-02,   5.78907803e-02,   5.48102483e-02,
                          5.18459603e-02,   4.88816723e-02,   4.58011404e-02,
                          4.28368524e-02,   3.98144424e-02,   3.67339104e-02,
                          3.37114967e-02,   3.05728409e-02,   2.74923090e-02,
                          2.44117752e-02,   2.15056110e-02,   1.85413249e-02,
                          1.52282976e-02,   1.22058876e-02,   9.12535377e-03,
                          5.92857366e-03,   3.08053358e-03,  -1.16246549e-04,
                         -3.37114977e-03,  -6.45168312e-03,  -9.64846369e-03,
                         -1.26708737e-02,  -1.58095304e-02,  -1.88319404e-02,
                         -2.19705980e-02,  -2.53998712e-02,  -2.85966508e-02,
                         -3.16771828e-02,  -3.47577184e-02,  -3.79544981e-02,
                         -4.12675254e-02,  -4.43480574e-02,  -4.75448370e-02,
                         -5.09159863e-02,  -5.38802743e-02,  -5.69608063e-02,
                         -6.02738336e-02,  -6.34706169e-02,  -6.66092709e-02,
                         -6.98060542e-02,  -7.29447082e-02,  -7.62577355e-02,
                         -7.94545114e-02,  -8.25350508e-02,  -8.58480781e-02,
                         -8.89867321e-02,  -9.20091420e-02,  -9.53221694e-02,
                         -9.84608233e-02,  -1.01425111e-01,  -1.04563765e-01,
                         -1.07760549e-01,  -1.11015454e-01,  -1.14095986e-01,
                         -1.17176518e-01,  -1.20431423e-01,  -1.23628199e-01,
                         -1.26883104e-01,  -1.30079880e-01,  -1.32927924e-01,
                         -1.36066586e-01,  -1.39263362e-01,  -1.42169520e-01,
                         -1.45308182e-01,  -1.48446843e-01,  -1.51411131e-01,
                         -1.54607907e-01,  -1.57688439e-01,  -1.60652727e-01,
                         -1.63849503e-01,  -1.67046294e-01,  -1.70126826e-01,
                         -1.73265472e-01,  -1.76462263e-01,  -1.79426551e-01,
                         -1.82681441e-01,  -1.86110720e-01,  -1.89133137e-01,
                         -1.92097425e-01,  -1.95352316e-01,  -1.98432863e-01,
                         -2.01629639e-01,  -2.04710171e-01,  -2.07848832e-01,
                         -2.11103722e-01,  -2.14126140e-01,  -2.17322916e-01,
                         -2.20694065e-01,  -2.23890856e-01,  -2.26913258e-01,
                         -2.29935676e-01,  -2.33248696e-01,  -2.36445472e-01,
                         -2.39526004e-01,  -2.42839038e-01,  -2.45861441e-01,
                         -2.48941973e-01,  -2.52138764e-01,  -2.55219281e-01,
                         -2.58474201e-01,  -2.61670977e-01,  -2.64751524e-01,
                         -2.67890155e-01,  -2.70912588e-01,  -2.74051219e-01,
                         -2.77306139e-01,  -2.80502915e-01,  -2.83525318e-01,
                         -2.86722094e-01,  -2.89977014e-01,  -2.92883188e-01,
                         -2.95847476e-01,  -2.99044251e-01,  -3.02241027e-01,
                         -3.05321544e-01,  -3.08227718e-01,  -3.11366379e-01,
                         -3.14505041e-01,  -3.17411184e-01,  -3.20491731e-01,
                         -3.23688507e-01,  -3.26710910e-01,  -3.29907686e-01,
                         -3.32871974e-01,  -3.35778147e-01,  -3.38974923e-01,
                         -3.41881096e-01,  -3.45077872e-01,  -3.48274648e-01,
                         -3.50948334e-01,  -3.54145110e-01,  -3.57283771e-01,
                         -3.60073686e-01,  -3.63270462e-01,  -3.66409123e-01,
                         -3.69315267e-01,  -3.72279555e-01,  -3.75301987e-01,
                         -3.78382504e-01,  -3.81346792e-01,  -3.84369195e-01,
                         -3.87333483e-01,  -3.90414029e-01,  -3.93552691e-01,
                         -3.96458834e-01,  -3.99597496e-01,  -4.02678043e-01,
                         -4.05467957e-01,  -4.08432245e-01,  -4.11280274e-01,
                         -4.14302707e-01,  -4.17325109e-01,  -4.20115024e-01,
                         -4.23195541e-01,  -4.26159829e-01,  -4.29007888e-01,
                         -4.32088405e-01,  -4.34762090e-01,  -4.37493891e-01,
                         -4.40400034e-01,  -4.43131834e-01,  -4.45921749e-01,
                         -4.48711663e-01,  -4.51559722e-01,  -4.54233378e-01,
                         -4.56848919e-01,  -4.59580719e-01,  -4.62254405e-01,
                         -4.64753687e-01,  -4.67311114e-01,  -4.70101029e-01,
                         -4.72716570e-01,  -4.75273997e-01,  -4.77889568e-01,
                         -4.80505109e-01,  -4.83004391e-01,  -4.85561818e-01,
                         -4.88003016e-01,  -4.90327924e-01,  -4.92769122e-01,
                         -4.95268404e-01,  -4.97709602e-01,  -4.99976397e-01,
                         -5.02359450e-01,  -5.04451871e-01,  -5.06718695e-01,
                         -5.09450495e-01,  -5.11659205e-01,  -5.13693511e-01,
                         -5.16018450e-01,  -5.18227100e-01,  -5.20435810e-01,
                         -5.22760749e-01,  -5.25027514e-01,  -5.27178109e-01,
                         -5.29328644e-01,  -5.31595469e-01,  -5.33513546e-01,
                         -5.35547853e-01,  -5.37814677e-01,  -5.39616466e-01,
                         -5.41592658e-01,  -5.43801367e-01,  -5.45545042e-01,
                         -5.47521234e-01,  -5.49671769e-01,  -5.51531732e-01,
                         -5.53507924e-01,  -5.55367887e-01,  -5.57227850e-01,
                         -5.59029639e-01,  -5.60831487e-01,  -5.62575161e-01,
                         -5.64318836e-01,  -5.66062570e-01,  -5.67457497e-01,
                         -5.69026828e-01,  -5.70770562e-01,  -5.72107375e-01,
                         -5.73676705e-01,  -5.75420380e-01,  -5.76699138e-01,
                         -5.78035951e-01,  -5.79430938e-01,  -5.80709636e-01,
                         -5.81930220e-01,  -5.83208919e-01,  -5.84487617e-01,
                         -5.85417628e-01,  -5.86521924e-01,  -5.87858796e-01,
                         -5.88730633e-01,  -5.89834988e-01,  -5.90997458e-01,
                         -5.91869295e-01,  -5.92857361e-01,  -5.93671143e-01,
                         -5.94484866e-01,  -5.95356703e-01,  -5.95996022e-01,
                         -5.96867919e-01,  -5.97565353e-01,  -5.97972214e-01,
                         -5.98611593e-01,  -5.99425316e-01,  -6.00006580e-01,
                         -6.00413442e-01,  -6.00878417e-01,  -6.01285279e-01,
                         -6.01634026e-01,  -6.02157116e-01,  -6.02447748e-01,
                         -6.02738321e-01,  -6.02970839e-01,  -6.03087068e-01,
                         -6.03377700e-01,  -6.03493929e-01,  -6.03552043e-01,
                         -6.03610218e-01,  -6.03435814e-01,  -6.03493929e-01,
                         -6.03435814e-01,  -6.03377700e-01,  -6.03435814e-01,
                         -6.03145182e-01,  -6.02796495e-01,  -6.02389634e-01,
                         -6.01866484e-01,  -6.01692140e-01,  -6.01227164e-01,
                         -6.00471556e-01,  -5.99890292e-01,  -5.99250972e-01,
                         -5.98727822e-01,  -5.97972214e-01,  -5.96984148e-01,
                         -5.96170425e-01,  -5.95182300e-01,  -5.94310462e-01,
                         -5.93380511e-01,  -5.92218041e-01,  -5.91346204e-01,
                         -5.90067446e-01,  -5.88672519e-01,  -5.87626278e-01,
                         -5.86173236e-01,  -5.84836364e-01,  -5.83557665e-01,
                         -5.82162678e-01,  -5.80883980e-01,  -5.79198420e-01,
                         -5.77454746e-01,  -5.76059759e-01,  -5.74316084e-01,
                         -5.72514236e-01,  -5.70886791e-01,  -5.69084942e-01,
                         -5.67225039e-01,  -5.65248847e-01,  -5.63446999e-01,
                         -5.61587095e-01,  -5.59552729e-01,  -5.57576537e-01,
                         -5.55484116e-01,  -5.53275466e-01,  -5.50950527e-01,
                         -5.48683703e-01,  -5.46591282e-01,  -5.44440687e-01,
                         -5.42115748e-01,  -5.39732695e-01,  -5.37349641e-01,
                         -5.34908473e-01,  -5.32583535e-01,  -5.30142367e-01,
                         -5.27410567e-01,  -5.24853170e-01,  -5.22470117e-01,
                         -5.19738317e-01,  -5.17006516e-01,  -5.14507234e-01,
                         -5.11833549e-01,  -5.08927405e-01,  -5.06079316e-01,
                         -5.03405690e-01,  -5.00557601e-01,  -4.97651458e-01,
                         -4.94861543e-01,  -4.91839141e-01,  -4.88758594e-01,
                         -4.85852450e-01,  -4.82655674e-01,  -4.79691386e-01,
                         -4.76610839e-01,  -4.73297805e-01,  -4.70042914e-01,
                         -4.66787994e-01,  -4.63533103e-01,  -4.60336328e-01,
                         -4.57139552e-01,  -4.53942776e-01,  -4.50513482e-01,
                         -4.47084218e-01,  -4.43713069e-01,  -4.40225661e-01,
                         -4.36854511e-01,  -4.33483362e-01,  -4.29995984e-01,
                         -4.26508576e-01,  -4.23021197e-01,  -4.19650048e-01,
                         -4.16162640e-01,  -4.12500858e-01,  -4.09187853e-01,
                         -4.05816704e-01,  -4.02213067e-01,  -3.98667544e-01,
                         -3.95122021e-01,  -3.91518384e-01,  -3.88030976e-01,
                         -3.84601712e-01,  -3.81056190e-01,  -3.77452552e-01,
                         -3.73965144e-01,  -3.70361507e-01,  -3.66815984e-01,
                         -3.63270462e-01,  -3.59783053e-01,  -3.56295675e-01,
                         -3.52750152e-01,  -3.49262744e-01,  -3.45659107e-01,
                         -3.41881096e-01,  -3.38393688e-01,  -3.34848166e-01,
                         -3.31302673e-01,  -3.27931523e-01,  -3.24386001e-01,
                         -3.20782334e-01,  -3.17178696e-01,  -3.13749433e-01,
                         -3.10378283e-01,  -3.06716502e-01,  -3.03171009e-01,
                         -2.99741715e-01,  -2.96079963e-01,  -2.92534441e-01,
                         -2.89047033e-01,  -2.85443395e-01,  -2.81955987e-01,
                         -2.78294235e-01,  -2.74748713e-01,  -2.71319449e-01,
                         -2.67657667e-01,  -2.64054030e-01,  -2.60508507e-01,
                         -2.56962985e-01,  -2.53417462e-01,  -2.49755710e-01,
                         -2.46500805e-01,  -2.43071526e-01,  -2.39409760e-01,
                         -2.36038610e-01,  -2.32376844e-01,  -2.28773206e-01,
                         -2.25343928e-01,  -2.21682161e-01,  -2.18252897e-01,
                         -2.14765489e-01,  -2.11103722e-01,  -2.07732573e-01,
                         -2.04361424e-01,  -2.00815916e-01,  -1.97386637e-01,
                         -1.94073603e-01,  -1.90644339e-01,  -1.87040687e-01,
                         -1.83669537e-01,  -1.80182144e-01,  -1.76869124e-01,
                         -1.73614219e-01,  -1.70068696e-01,  -1.66697547e-01,
                         -1.63384527e-01,  -1.60187736e-01,  -1.56990960e-01,
                         -1.53677940e-01,  -1.50481150e-01,  -1.47226244e-01,
                         -1.43855095e-01,  -1.40600204e-01,  -1.37461543e-01,
                         -1.34322882e-01,  -1.31184235e-01,  -1.27987444e-01,
                         -1.24965034e-01,  -1.21652015e-01,  -1.18397109e-01,
                         -1.15258448e-01,  -1.12061672e-01,  -1.08981140e-01,
                         -1.05784357e-01,  -1.02471329e-01,  -9.95070413e-02,
                         -9.64265093e-02,  -9.32878554e-02,  -9.01491940e-02,
                         -8.69524181e-02,  -8.38718861e-02,  -8.07332247e-02,
                         -7.74783269e-02,  -7.45721608e-02,  -7.16078728e-02,
                         -6.84110895e-02,  -6.52143136e-02,  -6.21337779e-02,
                         -5.90532459e-02,  -5.59727140e-02,  -5.30084260e-02,
                         -4.98697683e-02,  -4.66729887e-02,  -4.35924567e-02,
                         -4.04537991e-02,  -3.74313891e-02,  -3.45833488e-02,
                         -3.17353085e-02,  -2.87128966e-02,  -2.55742408e-02,
                         -2.25518309e-02,  -1.94712970e-02,  -1.65070090e-02,
                         -1.36589697e-02,  -1.05784358e-02,  -7.78851844e-03,
                         -4.82423184e-03,  -1.74369826e-03,   1.04621891e-03,
                          3.95238260e-03,   6.91666966e-03,   9.76470951e-03,
                          1.25546269e-02,   1.52282976e-02,   1.81344617e-02,
                          2.10987478e-02,   2.37724185e-02,   2.65623368e-02,
                          2.93522533e-02,   3.21421698e-02,   3.48158404e-02,
                          3.74895111e-02,   4.03375514e-02,   4.29531001e-02,
                          4.56848927e-02,   4.85329330e-02,   5.12066036e-02,
                          5.38802743e-02,   5.64376973e-02,   5.91694936e-02,
                          6.20756559e-02,   6.46912009e-02,   6.73067495e-02,
                          6.99804202e-02,   7.25959688e-02,   7.51533955e-02,
                          7.78270662e-02,   8.06751028e-02,   8.32906514e-02,
                          8.58480781e-02,   8.86379927e-02,   9.10791680e-02,
                          9.36365947e-02,   9.64846313e-02,   9.89258140e-02,
                          1.01657607e-01,   1.04447521e-01,   1.06714331e-01,
                          1.09388001e-01,   1.12061672e-01,   1.14386603e-01,
                          1.17060274e-01,   1.19675823e-01,   1.22116998e-01,
                          1.24732547e-01,   1.27289966e-01,   1.29789263e-01,
                          1.32404819e-01,   1.34904116e-01,   1.37519658e-01,
                          1.40018970e-01,   1.42227650e-01,   1.44668832e-01,
                          1.47284374e-01,   1.49551183e-01,   1.51817992e-01,
                          1.54375419e-01,   1.56816587e-01,   1.59025282e-01,
                          1.61175832e-01,   1.63442641e-01,   1.65883824e-01,
                          1.68208748e-01,   1.70475557e-01,   1.72858611e-01,
                          1.75009176e-01,   1.77392229e-01,   1.79659039e-01,
                          1.81925848e-01,   1.84308901e-01,   1.86401337e-01,
                          1.88551903e-01,   1.90760583e-01,   1.93027392e-01,
                          1.95177957e-01,   1.97212264e-01,   1.99420944e-01,
                          2.01629639e-01,   2.03780189e-01,   2.05930755e-01,
                          2.07965076e-01,   2.10057512e-01,   2.12149948e-01,
                          2.14242384e-01,   2.16334820e-01,   2.18311012e-01,
                          2.20577821e-01,   2.22670257e-01,   2.24588335e-01,
                          2.26913258e-01,   2.28889450e-01,   2.30749398e-01,
                          2.33016208e-01,   2.35108644e-01,   2.37142950e-01,
                          2.39061028e-01,   2.41037220e-01,   2.43187770e-01,
                          2.45047718e-01,   2.47082040e-01,   2.49290720e-01,
                          2.51150668e-01,   2.53126860e-01,   2.55451798e-01,
                          2.57486105e-01,   2.59287924e-01,   2.61147857e-01,
                          2.63065934e-01,   2.64984012e-01,   2.67076433e-01,
                          2.68936396e-01,   2.70680070e-01,   2.72714406e-01,
                          2.74458110e-01,   2.76259929e-01,   2.78236121e-01,
                          2.80037940e-01,   2.81897873e-01,   2.83641577e-01,
                          2.85269022e-01,   2.87012726e-01,   2.88814545e-01,
                          2.90616363e-01,   2.92360067e-01,   2.94220001e-01,
                          2.96138078e-01,   2.97707409e-01,   2.99451113e-01,
                          3.01311046e-01,   3.02938491e-01,   3.04740310e-01,
                          3.06542158e-01,   3.08343977e-01,   3.10145795e-01,
                          3.11831355e-01,   3.13516945e-01,   3.15202504e-01,
                          3.16888094e-01,   3.18689913e-01,   3.20317358e-01,
                          3.21886688e-01,   3.23572248e-01,   3.25374097e-01,
                          3.27059656e-01,   3.28687102e-01,   3.30547065e-01,
                          3.32232624e-01,   3.33627582e-01,   3.35371286e-01,
                          3.37114990e-01,   3.38626176e-01,   3.40311766e-01,
                          3.41997355e-01,   3.43799174e-01,   3.45368505e-01,
                          3.46937805e-01,   3.48681509e-01,   3.50192726e-01,
                          3.51994544e-01,   3.53796363e-01,   3.55191320e-01,
                          3.56993139e-01,   3.58620584e-01,   3.59899312e-01,
                          3.61643016e-01,   3.63328576e-01,   3.64839792e-01,
                          3.66467237e-01,   3.67920309e-01,   3.69315267e-01,
                          3.70710224e-01,   3.72163326e-01,   3.73674512e-01,
                          3.75301987e-01,   3.76638800e-01,   3.77975643e-01,
                          3.79428715e-01,   3.80881816e-01,   3.82334888e-01,
                          3.83671731e-01,   3.84717941e-01,   3.86229157e-01,
                          3.87682229e-01,   3.88844699e-01,   3.90123397e-01,
                          3.91402125e-01,   3.92738968e-01,   3.93959552e-01,
                          3.95180136e-01,   3.96633208e-01,   3.97853792e-01,
                          3.99016261e-01,   4.00236875e-01,   4.01457459e-01,
                          4.02678043e-01,   4.03666139e-01,   4.04828608e-01,
                          4.06223565e-01,   4.07386035e-01,   4.08315986e-01,
                          4.09362227e-01,   4.10524666e-01,   4.11629021e-01,
                          4.12675232e-01,   4.13895816e-01,   4.14883912e-01,
                          4.15697664e-01,   4.16801989e-01,   4.17673856e-01,
                          4.18603808e-01,   4.19708163e-01,   4.20580000e-01,
                          4.21626240e-01,   4.22556192e-01,   4.23486173e-01,
                          4.24706757e-01,   4.25404251e-01,   4.26217973e-01,
                          4.27147925e-01,   4.27903533e-01,   4.28891629e-01,
                          4.29472864e-01,   4.30054098e-01,   4.31100309e-01,
                          4.31623429e-01,   4.32262778e-01,   4.33018386e-01,
                          4.33599621e-01,   4.34355229e-01,   4.34820205e-01,
                          4.35517699e-01,   4.36157048e-01,   4.36447650e-01,
                          4.37145144e-01,   4.37610120e-01,   4.37900752e-01,
                          4.38423842e-01,   4.38772589e-01,   4.39237565e-01,
                          4.39644426e-01,   4.39935058e-01,   4.40283805e-01,
                          4.40516293e-01,   4.40865040e-01,   4.40981269e-01,
                          4.41097528e-01,   4.41504389e-01,   4.41562504e-01,
                          4.41678762e-01,   4.41911250e-01,   4.41911250e-01,
                          4.42143738e-01,   4.42318112e-01,   4.42434371e-01,
                          4.42492485e-01,   4.42376226e-01,   4.42492485e-01,
                          4.42608714e-01,   4.42434371e-01,   4.42376226e-01,
                          4.42608714e-01,   4.42608714e-01,   4.42724973e-01,
                          4.42724973e-01,   4.42376226e-01,   4.42434371e-01,
                          4.42550600e-01,   4.42259997e-01,   4.42318112e-01,
                          4.42201853e-01,   4.41794991e-01,   4.41969365e-01,
                          4.41853136e-01,   4.41388130e-01,   4.41388130e-01,
                          4.41155642e-01,   4.40865040e-01,   4.40748781e-01,
                          4.40458179e-01,   4.40109432e-01,   4.39935058e-01,
                          4.39702570e-01,   4.39237565e-01,   4.38772589e-01,
                          4.38598216e-01,   4.38307613e-01,   4.37900752e-01,
                          4.37493891e-01,   4.36970770e-01,   4.36622024e-01,
                          4.36040789e-01,   4.35633928e-01,   4.35343325e-01,
                          4.34645832e-01,   4.34006482e-01,   4.33483362e-01,
                          4.32960272e-01,   4.32495266e-01,   4.31914032e-01,
                          4.31216568e-01,   4.30577219e-01,   4.30054098e-01,
                          4.29647237e-01,   4.29007888e-01,   4.28542882e-01,
                          4.27903533e-01,   4.27264184e-01,   4.26799208e-01,
                          4.26159829e-01,   4.25636739e-01,   4.25055504e-01,
                          4.24358010e-01,   4.24067408e-01,   4.23486173e-01,
                          4.22904938e-01,   4.22381818e-01,   4.21626240e-01,
                          4.21335608e-01,   4.20870632e-01,   4.20115024e-01,
                          4.19475675e-01,   4.18720067e-01,   4.18313205e-01,
                          4.17906344e-01,   4.17208850e-01,   4.16685760e-01,
                          4.15988266e-01,   4.15232658e-01,   4.14767683e-01,
                          4.14186448e-01,   4.13605213e-01,   4.13023978e-01,
                          4.12500858e-01,   4.11919653e-01,   4.11105901e-01,
                          4.10582811e-01,   4.09885317e-01,   4.09013480e-01,
                          4.08432245e-01,   4.07851011e-01,   4.07095402e-01,
                          4.06514168e-01,   4.05932933e-01,   4.05061096e-01,
                          4.04421747e-01,   4.03724253e-01,   4.02794272e-01,
                          4.02213067e-01,   4.01573688e-01,   4.00527477e-01,
                          3.99946243e-01,   3.99306893e-01,   3.98260683e-01,
                          3.97505075e-01,   3.96691352e-01,   3.95703256e-01,
                          3.95005763e-01,   3.94133925e-01,   3.93320203e-01,
                          3.92506450e-01,   3.91518384e-01,   3.90704632e-01,
                          3.89832795e-01,   3.88670325e-01,   3.87856603e-01,
                          3.86984766e-01,   3.85822296e-01,   3.85066688e-01,
                          3.84020478e-01,   3.82916123e-01,   3.82044286e-01,
                          3.81114304e-01,   3.80068094e-01,   3.79196227e-01,
                          3.78266275e-01,   3.77103806e-01,   3.75941336e-01,
                          3.75011355e-01,   3.74081373e-01,   3.72918934e-01,
                          3.71814579e-01,   3.70710224e-01,   3.69547784e-01,
                          3.68385315e-01,   3.67339075e-01,   3.66292864e-01,
                          3.65014166e-01,   3.63967925e-01,   3.62747341e-01,
                          3.61584872e-01,   3.60422432e-01,   3.59085590e-01,
                          3.57923120e-01,   3.56702536e-01,   3.55249435e-01,
                          3.53970736e-01,   3.52517664e-01,   3.51180822e-01,
                          3.49785864e-01,   3.48274648e-01,   3.46995950e-01,
                          3.45484734e-01,   3.43915403e-01,   3.42462331e-01,
                          3.40893000e-01,   3.39439929e-01,   3.37870598e-01,
                          3.36301267e-01,   3.34673822e-01,   3.32813859e-01,
                          3.31244528e-01,   3.29558969e-01,   3.27873379e-01,
                          3.26071560e-01,   3.24153483e-01,   3.22409809e-01,
                          3.20549846e-01,   3.18864286e-01,   3.17120582e-01,
                          3.15086275e-01,   3.13284457e-01,   3.11540753e-01,
                          3.09448302e-01,   3.07472110e-01,   3.05612177e-01,
                          3.03752214e-01,   3.01717907e-01,   2.99799830e-01,
                          2.97765523e-01,   2.95614958e-01,   2.93813139e-01,
                          2.91836947e-01,   2.89686382e-01,   2.87710190e-01,
                          2.85559654e-01,   2.83525318e-01,   2.81491011e-01,
                          2.79224217e-01,   2.77015507e-01,   2.74864972e-01,
                          2.72656262e-01,   2.70447582e-01,   2.68238902e-01,
                          2.66146481e-01,   2.63879657e-01,   2.61554718e-01,
                          2.59404182e-01,   2.57253617e-01,   2.55044937e-01,
                          2.52719998e-01,   2.50453174e-01,   2.48186380e-01,
                          2.45861441e-01,   2.43478388e-01,   2.41095334e-01,
                          2.38770410e-01,   2.36445472e-01,   2.33829930e-01,
                          2.31388748e-01,   2.29005694e-01,   2.26390153e-01,
                          2.23948970e-01,   2.21449673e-01,   2.18776003e-01,
                          2.16276705e-01,   2.13777393e-01,   2.11161852e-01,
                          2.08430052e-01,   2.05698267e-01,   2.03082711e-01,
                          2.00525299e-01,   1.97851628e-01,   1.94887340e-01,
                          1.92155540e-01,   1.89714357e-01,   1.86808199e-01,
                          1.84134528e-01,   1.81577101e-01,   1.78612813e-01,
                          1.75822899e-01,   1.73149228e-01,   1.70359313e-01,
                          1.67627513e-01,   1.64837599e-01,   1.61989570e-01,
                          1.59083396e-01,   1.56293482e-01,   1.53503567e-01,
                          1.50597408e-01,   1.47923738e-01,   1.45075694e-01,
                          1.42343894e-01,   1.39553979e-01,   1.36473447e-01,
                          1.33857906e-01,   1.31126106e-01,   1.28103688e-01,
                          1.25313774e-01,   1.22349493e-01,   1.19559571e-01,
                          1.16769657e-01,   1.13631003e-01,   1.10957332e-01,
                          1.08225532e-01,   1.05145000e-01,   1.02296963e-01,
                          9.94489193e-02,   9.66008827e-02,   9.35784727e-02,
                          9.04979333e-02,   8.75336528e-02,   8.46274868e-02,
                          8.18375722e-02,   7.88151622e-02,   7.56765008e-02,
                          7.27703348e-02,   6.98060542e-02,   6.68998882e-02,
                          6.38774782e-02,   6.07388206e-02,   5.79489022e-02,
                          5.49264923e-02,   5.17297126e-02,   4.87654246e-02,
                          4.56848927e-02,   4.25462350e-02,   3.92913334e-02,
                          3.62689234e-02,   3.33046354e-02,   3.00497320e-02,
                          2.69110762e-02,   2.38305423e-02,   2.08662543e-02,
                          1.79019682e-02,   1.45889418e-02,   1.16246548e-02,
                          8.48599803e-03,   5.11484826e-03,   2.15056119e-03,
                         -1.04621891e-03,  -4.18487564e-03,  -7.20728608e-03,
                         -1.03459423e-02,  -1.31939827e-02,  -1.61582697e-02,
                         -1.93550494e-02,  -2.24937070e-02,  -2.56904867e-02,
                         -2.86547747e-02,  -3.17353085e-02,  -3.48739624e-02,
                         -3.78382504e-02,  -4.09769081e-02,  -4.39993180e-02,
                         -4.68473583e-02,  -4.98697683e-02,  -5.28340563e-02,
                         -5.59145883e-02,  -5.89951240e-02,  -6.19012862e-02,
                         -6.48655742e-02,  -6.78298622e-02,  -7.07941502e-02,
                         -7.38165602e-02,  -7.68970922e-02,  -7.99195021e-02,
                         -8.29419121e-02,  -8.59643221e-02,  -8.89286101e-02,
                         -9.17766467e-02,  -9.47990566e-02,  -9.78214666e-02,
                         -1.00785755e-01,  -1.03691921e-01,  -1.06656209e-01,
                         -1.09678619e-01,  -1.12526655e-01,  -1.15665317e-01,
                         -1.18920214e-01,  -1.21826380e-01,  -1.24965034e-01,
                         -1.27929330e-01,  -1.30661115e-01,  -1.33567289e-01,
                         -1.36531577e-01,  -1.39612108e-01,  -1.42634511e-01,
                         -1.45656928e-01,  -1.48737460e-01,  -1.51701748e-01,
                         -1.54666036e-01,  -1.57688439e-01,  -1.60478354e-01,
                         -1.63442641e-01,  -1.66523173e-01,  -1.69545591e-01,
                         -1.72451749e-01,  -1.75357923e-01,  -1.78438455e-01,
                         -1.81286484e-01,  -1.83960155e-01,  -1.86982572e-01,
                         -1.89830616e-01,  -1.92678645e-01,  -1.95526689e-01,
                         -1.98316604e-01,  -2.01222777e-01,  -2.04012692e-01,
                         -2.06918851e-01,  -2.09766895e-01,  -2.12440565e-01,
                         -2.15346724e-01,  -2.18194768e-01,  -2.20984682e-01,
                         -2.23774597e-01,  -2.26564527e-01,  -2.29354441e-01,
                         -2.32086226e-01,  -2.34876141e-01,  -2.37666070e-01,
                         -2.40165368e-01,  -2.42839038e-01,  -2.45687082e-01,
                         -2.48476997e-01,  -2.51266897e-01,  -2.54056841e-01,
                         -2.56904870e-01,  -2.59636670e-01,  -2.62426585e-01,
                         -2.65274614e-01,  -2.68064529e-01,  -2.70738214e-01,
                         -2.73470014e-01,  -2.76143670e-01,  -2.78991699e-01,
                         -2.81897873e-01,  -2.84745902e-01,  -2.87593961e-01,
                         -2.90383875e-01,  -2.93231905e-01,  -2.96021819e-01,
                         -2.98637390e-01,  -3.01369160e-01,  -3.04275334e-01,
                         -3.07123363e-01,  -3.10029536e-01,  -3.12761337e-01,
                         -3.15434992e-01,  -3.18283051e-01,  -3.21131080e-01,
                         -3.23920995e-01,  -3.26536536e-01,  -3.29268336e-01,
                         -3.32058251e-01,  -3.34731936e-01,  -3.37347478e-01,
                         -3.40021163e-01,  -3.42811078e-01,  -3.45600992e-01,
                         -3.48332763e-01,  -3.50948334e-01,  -3.53621989e-01,
                         -3.56179416e-01,  -3.58736843e-01,  -3.61526757e-01,
                         -3.64200443e-01,  -3.66874099e-01,  -3.69547784e-01,
                         -3.72047067e-01,  -3.74720752e-01,  -3.77336293e-01,
                         -3.79777461e-01,  -3.82451147e-01,  -3.85124803e-01,
                         -3.87566000e-01,  -3.90065283e-01,  -3.92564595e-01,
                         -3.95354509e-01,  -3.97970051e-01,  -4.00353104e-01,
                         -4.02968645e-01,  -4.05409843e-01,  -4.07967269e-01,
                         -4.10466552e-01,  -4.12791491e-01,  -4.15407032e-01,
                         -4.17906344e-01,  -4.20405626e-01,  -4.23079312e-01,
                         -4.25520480e-01,  -4.28136021e-01,  -4.30751592e-01,
                         -4.33134645e-01,  -4.35517699e-01,  -4.37842607e-01,
                         -4.40400034e-01,  -4.43015575e-01,  -4.45631146e-01,
                         -4.48130429e-01,  -4.50339109e-01,  -4.52780306e-01,
                         -4.55221474e-01,  -4.57488298e-01,  -4.59929466e-01,
                         -4.62138146e-01,  -4.64404941e-01,  -4.66962367e-01,
                         -4.69287306e-01,  -4.71554130e-01,  -4.73820925e-01,
                         -4.75971490e-01,  -4.78238285e-01,  -4.80214477e-01,
                         -4.82423156e-01,  -4.84864354e-01,  -4.86840546e-01,
                         -4.88932967e-01,  -4.91199791e-01,  -4.93059725e-01,
                         -4.95152175e-01,  -4.97244596e-01,  -4.99104559e-01,
                         -5.01138866e-01,  -5.03115058e-01,  -5.04975021e-01,
                         -5.06951213e-01,  -5.08869231e-01,  -5.10787308e-01,
                         -5.12589157e-01,  -5.14507234e-01,  -5.16309023e-01,
                         -5.18052757e-01,  -5.20028949e-01,  -5.21772623e-01,
                         -5.23458183e-01,  -5.25260031e-01,  -5.26945591e-01,
                         -5.28689265e-01,  -5.30432999e-01,  -5.32176673e-01,
                         -5.33804119e-01,  -5.35373449e-01,  -5.36942780e-01,
                         -5.38570225e-01,  -5.40023327e-01,  -5.41534543e-01,
                         -5.43220103e-01,  -5.44847548e-01,  -5.46300650e-01,
                         -5.48044324e-01,  -5.49439311e-01,  -5.50659895e-01,
                         -5.52287340e-01,  -5.53624153e-01,  -5.54902911e-01,
                         -5.56355953e-01,  -5.57576537e-01,  -5.58622777e-01,
                         -5.59959590e-01,  -5.61296463e-01,  -5.62458932e-01,
                         -5.63563287e-01,  -5.64841986e-01,  -5.65946341e-01,
                         -5.66876292e-01,  -5.67922533e-01,  -5.68794370e-01,
                         -5.69840550e-01,  -5.70886791e-01,  -5.71758628e-01,
                         -5.72746754e-01,  -5.73502362e-01,  -5.74199796e-01,
                         -5.75187922e-01,  -5.75769126e-01,  -5.76175988e-01,
                         -5.76931596e-01,  -5.77687204e-01,  -5.78152180e-01,
                         -5.78675330e-01,  -5.79198420e-01,  -5.79605281e-01,
                         -5.80070257e-01,  -5.80477118e-01,  -5.80709636e-01,
                         -5.81174612e-01,  -5.81523359e-01,  -5.81581473e-01,
                         -5.81813991e-01,  -5.81988335e-01,  -5.82162678e-01,
                         -5.82220852e-01,  -5.82278967e-01,  -5.82278967e-01,
                         -5.82104564e-01,  -5.82104564e-01,  -5.82046449e-01,
                         -5.81755817e-01,  -5.81697702e-01,  -5.81465244e-01,
                         -5.81232727e-01,  -5.81058383e-01,  -5.80593407e-01,
                         -5.80244660e-01,  -5.79954028e-01,  -5.79779625e-01,
                         -5.79489052e-01,  -5.78733444e-01,  -5.78210294e-01,
                         -5.77512860e-01,  -5.76699138e-01,  -5.76175988e-01,
                         -5.75478554e-01,  -5.74839175e-01,  -5.74141681e-01,
                         -5.73327959e-01,  -5.72572351e-01,  -5.71526170e-01,
                         -5.70596159e-01,  -5.69782436e-01,  -5.68561852e-01,
                         -5.67399383e-01,  -5.66236913e-01,  -5.65132558e-01,
                         -5.64144492e-01,  -5.62865794e-01,  -5.61587095e-01,
                         -5.60366452e-01,  -5.59029639e-01,  -5.57692826e-01,
                         -5.56181610e-01,  -5.54786623e-01,  -5.53275466e-01,
                         -5.51531732e-01,  -5.49962401e-01,  -5.48393071e-01,
                         -5.46649396e-01,  -5.44847548e-01,  -5.42987645e-01,
                         -5.41127682e-01,  -5.39151490e-01,  -5.37233412e-01,
                         -5.35315335e-01,  -5.33222914e-01,  -5.31421065e-01,
                         -5.29386759e-01,  -5.27061820e-01,  -5.25143802e-01,
                         -5.22935092e-01,  -5.20493925e-01,  -5.18285215e-01,
                         -5.16018450e-01,  -5.13693511e-01,  -5.11252284e-01,
                         -5.09043634e-01,  -5.06776810e-01,  -5.04103124e-01,
                         -5.01778245e-01,  -4.99395162e-01,  -4.96721506e-01,
                         -4.94396567e-01,  -4.91839141e-01,  -4.89281714e-01,
                         -4.86724287e-01,  -4.84108746e-01,  -4.81551319e-01,
                         -4.78761405e-01,  -4.76087719e-01,  -4.73297805e-01,
                         -4.70449775e-01,  -4.67776090e-01,  -4.64928061e-01,
                         -4.62312520e-01,  -4.59696978e-01,  -4.56732690e-01,
                         -4.54000890e-01,  -4.50920343e-01,  -4.48014200e-01,
                         -4.45282400e-01,  -4.42143738e-01,  -4.39295709e-01,
                         -4.36331421e-01,  -4.33192760e-01,  -4.30402845e-01,
                         -4.27206069e-01,  -4.23951149e-01,  -4.20928746e-01,
                         -4.17731971e-01,  -4.14593309e-01,  -4.11512762e-01,
                         -4.08315986e-01,  -4.05061096e-01,  -4.01864320e-01,
                         -3.98783773e-01,  -3.95412624e-01,  -3.92157733e-01,
                         -3.88960958e-01,  -3.85473549e-01,  -3.82102400e-01,
                         -3.78789365e-01,  -3.75476360e-01,  -3.72163326e-01,
                         -3.68734032e-01,  -3.65304768e-01,  -3.61875504e-01,
                         -3.58562469e-01,  -3.55249435e-01,  -3.51762056e-01,
                         -3.48390907e-01,  -3.44961613e-01,  -3.41474235e-01,
                         -3.38103086e-01,  -3.34731936e-01,  -3.31477016e-01,
                         -3.28047752e-01,  -3.24502230e-01,  -3.21247339e-01,
                         -3.17818046e-01,  -3.14388782e-01,  -3.11075747e-01,
                         -3.07530254e-01,  -3.04159075e-01,  -3.00787926e-01,
                         -2.97184289e-01,  -2.93813139e-01,  -2.90441990e-01,
                         -2.86954612e-01,  -2.83583462e-01,  -2.80270427e-01,
                         -2.76899278e-01,  -2.73470014e-01,  -2.70040721e-01,
                         -2.66611457e-01,  -2.63182193e-01,  -2.59694785e-01,
                         -2.56091148e-01,  -2.52661884e-01,  -2.49290720e-01,
                         -2.45803326e-01,  -2.42374048e-01,  -2.38770410e-01,
                         -2.35166758e-01,  -2.31737494e-01,  -2.28250101e-01,
                         -2.24878952e-01,  -2.21159056e-01,  -2.17613533e-01,
                         -2.14416757e-01,  -2.10754991e-01,  -2.07151353e-01,
                         -2.03722075e-01,  -2.00060308e-01,  -1.96572915e-01,
                         -1.93143636e-01,  -1.89539999e-01,  -1.86052606e-01,
                         -1.82448953e-01,  -1.78903431e-01,  -1.75416037e-01,
                         -1.71812400e-01,  -1.68557495e-01,  -1.65128216e-01,
                         -1.61524579e-01,  -1.58153430e-01,  -1.54607907e-01,
                         -1.51120514e-01,  -1.47691235e-01,  -1.44320086e-01,
                         -1.40832692e-01,  -1.37229055e-01,  -1.33799776e-01,
                         -1.30370498e-01,  -1.26824990e-01,  -1.23511955e-01,
                         -1.20140806e-01,  -1.16711535e-01,  -1.13340385e-01,
                         -1.09969236e-01,  -1.06656209e-01,  -1.03110686e-01,
                         -9.96232927e-02,  -9.63683873e-02,  -9.29972380e-02,
                         -8.96260887e-02,  -8.63130614e-02,  -8.29419121e-02,
                         -7.97451288e-02,  -7.64321014e-02,  -7.30609521e-02,
                         -6.98060542e-02,  -6.64349049e-02,  -6.30637482e-02,
                         -5.97507246e-02,  -5.64376973e-02,  -5.31246737e-02,
                         -4.99278903e-02,  -4.66148667e-02,  -4.31855917e-02,
                         -3.98725644e-02,  -3.67920324e-02,  -3.36533748e-02,
                         -3.03403493e-02,  -2.69691981e-02,  -2.37724185e-02,
                         -2.05175150e-02,  -1.72626115e-02,  -1.40077090e-02,
                         -1.06365588e-02,  -7.43977912e-03,  -4.24299901e-03,
                         -9.88095650e-04,   2.15056119e-03,   5.40546421e-03,
                          8.66036769e-03,   1.17990244e-02,   1.49958050e-02,
                          1.81344617e-02,   2.13312414e-02,   2.43536513e-02,
                          2.73179393e-02,   3.05728409e-02,   3.35952528e-02,
                          3.65595408e-02,   3.98144424e-02,   4.27206047e-02,
                          4.59173843e-02,   4.89397980e-02,   5.17297126e-02,
                          5.48683703e-02,   5.78907803e-02,   6.07388206e-02,
                          6.37031049e-02,   6.66673928e-02,   6.96316808e-02,
                          7.24797249e-02,   7.53858835e-02,   7.82920495e-02,
                          8.09657201e-02,   8.39300081e-02,   8.66618007e-02,
                          8.94517154e-02,   9.24160033e-02,   9.52059254e-02,
                          9.79377180e-02,   1.00669511e-01,   1.03575677e-01,
                          1.06423713e-01,   1.08981140e-01,   1.11654811e-01,
                          1.14270352e-01,   1.16944022e-01,   1.19733945e-01,
                          1.22291364e-01,   1.24965034e-01,   1.27813071e-01,
                          1.30312383e-01,   1.32986054e-01,   1.35543481e-01,
                          1.38100892e-01,   1.40716448e-01,   1.43331990e-01,
                          1.45889416e-01,   1.48330599e-01,   1.50829896e-01,
                          1.53503567e-01,   1.56119108e-01,   1.58502162e-01,
                          1.61117718e-01,   1.63675144e-01,   1.66000068e-01,
                          1.68325007e-01,   1.70882419e-01,   1.73439845e-01,
                          1.75822899e-01,   1.78205952e-01,   1.80705264e-01,
                          1.82972059e-01,   1.85296997e-01,   1.87680051e-01,
                          1.90063104e-01,   1.92446157e-01,   1.94712967e-01,
                          1.96979776e-01,   1.99362829e-01,   2.01687753e-01,
                          2.03722075e-01,   2.05988884e-01,   2.08255693e-01,
                          2.10231885e-01,   2.12498695e-01,   2.14823619e-01,
                          2.16916054e-01,   2.19182864e-01,   2.21275300e-01,
                          2.23193377e-01,   2.25285813e-01,   2.27262005e-01,
                          2.29238197e-01,   2.31330633e-01,   2.33481184e-01,
                          2.35573635e-01,   2.37491697e-01,   2.39526004e-01,
                          2.41385952e-01,   2.43362144e-01,   2.45512709e-01,
                          2.47314528e-01,   2.49174476e-01,   2.51208782e-01,
                          2.53184974e-01,   2.55044937e-01,   2.56962985e-01,
                          2.58997321e-01,   2.60915369e-01,   2.62775332e-01,
                          2.64925867e-01,   2.66843945e-01,   2.68703908e-01,
                          2.70680070e-01,   2.72656262e-01,   2.74574339e-01,
                          2.76492417e-01,   2.78294235e-01,   2.80154169e-01,
                          2.82014132e-01,   2.83874065e-01,   2.85792142e-01,
                          2.87826449e-01,   2.89570153e-01,   2.91430086e-01,
                          2.93290049e-01,   2.94975609e-01,   2.96951801e-01,
                          2.98869878e-01,   3.00497323e-01,   3.02589774e-01,
                          3.04333448e-01,   3.05902779e-01,   3.07704598e-01,
                          3.09448302e-01,   3.11192006e-01,   3.12935710e-01,
                          3.14505041e-01,   3.16190600e-01,   3.17701817e-01,
                          3.19445521e-01,   3.21131080e-01,   3.22642297e-01,
                          3.24444115e-01,   3.26129675e-01,   3.27524632e-01,
                          3.29152107e-01,   3.30663294e-01,   3.32232624e-01,
                          3.33918214e-01,   3.35545659e-01,   3.36940616e-01,
                          3.38277459e-01,   3.39904904e-01,   3.41474235e-01,
                          3.42811078e-01,   3.44322264e-01,   3.45833480e-01,
                          3.47286552e-01,   3.48739654e-01,   3.50250840e-01,
                          3.51820171e-01,   3.53215128e-01,   3.54493856e-01,
                          3.55830669e-01,   3.57283771e-01,   3.58678728e-01,
                          3.60015541e-01,   3.61410528e-01,   3.62921715e-01,
                          3.64258558e-01,   3.65537256e-01,   3.66874099e-01,
                          3.68269056e-01,   3.69605899e-01,   3.70884597e-01,
                          3.72337699e-01,   3.73790771e-01,   3.75127614e-01,
                          3.76348197e-01,   3.77626896e-01,   3.78963739e-01,
                          3.80300581e-01,   3.81463051e-01,   3.82567376e-01,
                          3.83729845e-01,   3.85124803e-01,   3.86403531e-01,
                          3.87391627e-01,   3.88437837e-01,   3.89600307e-01,
                          3.90646517e-01,   3.91750872e-01,   3.92797083e-01,
                          3.93843293e-01,   3.94889534e-01,   3.95935744e-01,
                          3.96981955e-01,   3.98028165e-01,   3.98900032e-01,
                          3.99771869e-01,   4.00759965e-01,   4.01864320e-01,
                          4.02736157e-01,   4.03666139e-01,   4.04654235e-01,
                          4.05467957e-01,   4.06456053e-01,   4.07327890e-01,
                          4.08083498e-01,   4.09013480e-01,   4.09710944e-01,
                          4.10466552e-01,   4.11338419e-01,   4.12035882e-01,
                          4.12791491e-01,   4.13605213e-01,   4.14418936e-01,
                          4.15174544e-01,   4.15813893e-01,   4.16627616e-01,
                          4.17441338e-01,   4.18313205e-01,   4.19010669e-01,
                          4.19533789e-01,   4.20231253e-01,   4.20928746e-01,
                          4.21684355e-01,   4.22498077e-01,   4.23137426e-01,
                          4.23776776e-01,   4.24358010e-01,   4.25055504e-01,
                          4.25694853e-01,   4.26101714e-01,   4.26741064e-01,
                          4.27554786e-01,   4.28136021e-01,   4.28542882e-01,
                          4.29007888e-01,   4.29763496e-01,   4.30170357e-01,
                          4.30635333e-01,   4.31274682e-01,   4.31681544e-01,
                          4.32030290e-01,   4.32437152e-01,   4.32844013e-01,
                          4.33250874e-01,   4.33599621e-01,   4.34006482e-01,
                          4.34413344e-01,   4.34645832e-01,   4.34936464e-01,
                          4.35227066e-01,   4.35517699e-01,   4.35808301e-01,
                          4.36040789e-01,   4.36098933e-01,   4.36273277e-01,
                          4.36622024e-01,   4.36738282e-01,   4.36796397e-01,
                          4.37028885e-01,   4.37261373e-01,   4.37319517e-01,
                          4.37435746e-01,   4.37726378e-01,   4.38016981e-01,
                          4.38016981e-01,   4.38016981e-01,   4.38133240e-01,
                          4.38249469e-01,   4.38307613e-01,   4.38307613e-01,
                          4.38481987e-01,   4.38656330e-01,   4.38423842e-01,
                          4.38365728e-01,   4.38656330e-01,   4.38598216e-01,
                          4.38656330e-01,   4.38772589e-01,   4.38656330e-01,
                          4.38772589e-01,   4.38830703e-01,   4.38656330e-01,
                          4.38772589e-01,   4.38888848e-01,   4.39005077e-01,
                          4.39005077e-01,   4.38772589e-01,   4.38772589e-01,
                          4.38830703e-01,   4.38830703e-01,   4.38830703e-01,
                          4.38656330e-01,   4.38714474e-01,   4.38714474e-01,
                          4.38540101e-01,   4.38540101e-01,   4.38423842e-01,
                          4.38249469e-01,   4.38133240e-01,   4.37958866e-01,
                          4.38016981e-01,   4.37958866e-01,   4.37784493e-01,
                          4.37668234e-01,   4.37493891e-01,   4.37203258e-01,
                          4.36970770e-01,   4.36970770e-01,   4.36796397e-01,
                          4.36389536e-01,   4.36157048e-01,   4.35982674e-01,
                          4.35866416e-01,   4.35750186e-01,   4.35517699e-01,
                          4.35459554e-01,   4.35343325e-01,   4.34936464e-01,
                          4.34587717e-01,   4.34355229e-01,   4.34180856e-01,
                          4.34006482e-01,   4.33657736e-01,   4.33425248e-01,
                          4.33076501e-01,   4.32611525e-01,   4.32320893e-01,
                          4.32088405e-01,   4.31914032e-01,   4.31507170e-01,
                          4.31158453e-01,   4.31042194e-01,   4.30635333e-01,
                          4.30286586e-01,   4.30112213e-01,   4.29763496e-01,
                          4.29472864e-01,   4.29066002e-01,   4.28833514e-01,
                          4.28717256e-01,   4.28252280e-01,   4.27903533e-01,
                          4.27496672e-01,   4.27206069e-01,   4.26915437e-01,
                          4.26508576e-01,   4.26276088e-01,   4.25811112e-01,
                          4.25287992e-01,   4.25113618e-01,   4.24764872e-01,
                          4.24358010e-01,   4.23951149e-01,   4.23486173e-01,
                          4.23079312e-01,   4.22556192e-01,   4.21974957e-01,
                          4.21509981e-01,   4.20986861e-01,   4.20521885e-01,
                          4.19940650e-01,   4.19243157e-01,   4.18720067e-01,
                          4.18138832e-01,   4.17615712e-01,   4.16976362e-01,
                          4.16337013e-01,   4.15872008e-01,   4.15348917e-01,
                          4.14535195e-01,   4.13721472e-01,   4.12907720e-01,
                          4.12093997e-01,   4.11338419e-01,   4.10466552e-01,
                          4.09652829e-01,   4.09013480e-01,   4.08141613e-01,
                          4.07095402e-01,   4.06339794e-01,   4.05293584e-01,
                          4.04363602e-01,   4.03608024e-01,   4.02561784e-01,
                          4.01689947e-01,   4.00759965e-01,   3.99539381e-01,
                          3.98493171e-01,   3.97388816e-01,   3.96400720e-01,
                          3.95528883e-01,   3.94308299e-01,   3.93320203e-01,
                          3.92332107e-01,   3.91053379e-01,   3.90065283e-01,
                          3.89019072e-01,   3.87914717e-01,   3.86752248e-01,
                          3.85473549e-01,   3.84194851e-01,   3.82916123e-01,
                          3.81811798e-01,   3.80707443e-01,   3.79312485e-01,
                          3.77859414e-01,   3.76522571e-01,   3.75301987e-01,
                          3.73848885e-01,   3.72221440e-01,   3.71058971e-01,
                          3.69722128e-01,   3.68036568e-01,   3.66699725e-01,
                          3.65246654e-01,   3.63619208e-01,   3.62107992e-01,
                          3.60480547e-01,   3.58853102e-01,   3.57225627e-01,
                          3.55423808e-01,   3.53621989e-01,   3.51994544e-01,
                          3.50367099e-01,   3.48507136e-01,   3.46705317e-01,
                          3.44903499e-01,   3.42927307e-01,   3.41009259e-01,
                          3.39207411e-01,   3.37289363e-01,   3.35255027e-01,
                          3.33278835e-01,   3.31360787e-01,   3.29268336e-01,
                          3.27175915e-01,   3.25257838e-01,   3.23049158e-01,
                          3.20782334e-01,   3.18806142e-01,   3.16713721e-01,
                          3.14505041e-01,   3.12296361e-01,   3.09913307e-01,
                          3.07820857e-01,   3.05670291e-01,   3.03345352e-01,
                          3.01194817e-01,   2.98986107e-01,   2.96661198e-01,
                          2.94278145e-01,   2.92011321e-01,   2.89802641e-01,
                          2.87535846e-01,   2.85210907e-01,   2.82944083e-01,
                          2.80735403e-01,   2.78177977e-01,   2.75562435e-01,
                          2.73121268e-01,   2.70621955e-01,   2.68180788e-01,
                          2.65681475e-01,   2.63182193e-01,   2.60799140e-01,
                          2.58299828e-01,   2.55916774e-01,   2.53301233e-01,
                          2.50511318e-01,   2.47837633e-01,   2.45338336e-01,
                          2.42722794e-01,   2.40049124e-01,   2.37375453e-01,
                          2.34643653e-01,   2.31737494e-01,   2.28889450e-01,
                          2.26157650e-01,   2.23425865e-01,   2.20810309e-01,
                          2.17962280e-01,   2.14997992e-01,   2.12149948e-01,
                          2.09301904e-01,   2.06570119e-01,   2.03605831e-01,
                          2.00467169e-01,   1.97561011e-01,   1.94480479e-01,
                          1.91516191e-01,   1.88668147e-01,   1.85471371e-01,
                          1.82448953e-01,   1.79484665e-01,   1.76404133e-01,
                          1.73323601e-01,   1.70068696e-01,   1.67104408e-01,
                          1.64198250e-01,   1.60827100e-01,   1.57746568e-01,
                          1.54840395e-01,   1.51469246e-01,   1.48330599e-01,
                          1.45424426e-01,   1.42169520e-01,   1.39030874e-01,
                          1.36066586e-01,   1.32986054e-01,   1.29731148e-01,
                          1.26650617e-01,   1.23628199e-01,   1.20431423e-01,
                          1.17118396e-01,   1.13863491e-01,   1.10899203e-01,
                          1.07760549e-01,   1.04563765e-01,   1.01541355e-01,
                          9.84027013e-02,   9.50896740e-02,   9.18928981e-02,
                          8.87542367e-02,   8.54993388e-02,   8.22444335e-02,
                          7.89895281e-02,   7.58508742e-02,   7.23634735e-02,
                          6.89342022e-02,   6.59117922e-02,   6.26568869e-02,
                          5.92857376e-02,   5.60889579e-02,   5.26596867e-02,
                          4.91141677e-02,   4.58011404e-02,   4.26043607e-02,
                          3.91750857e-02,   3.57458144e-02,   3.24327871e-02,
                          2.90035140e-02,   2.55161170e-02,   2.21449677e-02,
                          1.88900642e-02,   1.54607911e-02,   1.19733941e-02,
                          8.66036769e-03,   5.23109455e-03,   1.85994478e-03,
                         -1.62745162e-03,  -5.34734130e-03,  -8.60224478e-03,
                         -1.19152712e-02,  -1.55770369e-02,  -1.88319404e-02,
                         -2.20868438e-02,  -2.55742408e-02,  -2.90035140e-02,
                         -3.25490348e-02,  -3.58039364e-02,  -3.91169637e-02,
                         -4.25462350e-02,  -4.58592623e-02,  -4.93466593e-02,
                         -5.28921783e-02,  -5.61470836e-02,  -5.94019853e-02,
                         -6.27731383e-02,  -6.60861582e-02,  -6.93410635e-02,
                         -7.27703348e-02,  -7.61414915e-02,  -7.93382674e-02,
                         -8.26512948e-02,  -8.59062001e-02,  -8.91029760e-02,
                         -9.24741253e-02,  -9.59034041e-02,  -9.91583019e-02,
                         -1.02296963e-01,  -1.05609991e-01,  -1.08806767e-01,
                         -1.12061672e-01,  -1.15490943e-01,  -1.18803971e-01,
                         -1.22175120e-01,  -1.25488147e-01,  -1.28626809e-01,
                         -1.31939828e-01,  -1.35136604e-01,  -1.38391510e-01,
                         -1.41820788e-01,  -1.45191938e-01,  -1.48563087e-01,
                         -1.51876107e-01,  -1.55189142e-01,  -1.58618420e-01,
                         -1.61873311e-01,  -1.65186346e-01,  -1.68615609e-01,
                         -1.71754271e-01,  -1.75009176e-01,  -1.78264081e-01,
                         -1.81460857e-01,  -1.84948251e-01,  -1.88377529e-01,
                         -1.91632435e-01,  -1.94829211e-01,  -1.97967872e-01,
                         -2.01397136e-01,  -2.04768285e-01,  -2.07965076e-01,
                         -2.11219981e-01,  -2.14474872e-01,  -2.17787907e-01,
                         -2.21100926e-01,  -2.24413961e-01,  -2.27668867e-01,
                         -2.30749398e-01,  -2.34062418e-01,  -2.37259209e-01,
                         -2.40223482e-01,  -2.43420273e-01,  -2.46617049e-01,
                         -2.49581337e-01,  -2.52836227e-01,  -2.56091148e-01,
                         -2.59055436e-01,  -2.62252212e-01,  -2.65448987e-01,
                         -2.68413275e-01,  -2.71493822e-01,  -2.74690598e-01,
                         -2.77654886e-01,  -2.80735403e-01,  -2.83815950e-01,
                         -2.86780238e-01,  -2.89860755e-01,  -2.92999417e-01,
                         -2.96079963e-01,  -2.99160480e-01,  -3.02008539e-01,
                         -3.05147171e-01,  -3.08227718e-01,  -3.11250120e-01,
                         -3.14330667e-01,  -3.17353070e-01,  -3.20375472e-01,
                         -3.23397905e-01,  -3.26420307e-01,  -3.29500824e-01,
                         -3.32348883e-01,  -3.35545659e-01,  -3.38742435e-01,
                         -3.41416121e-01,  -3.44554752e-01,  -3.47635299e-01,
                         -3.50657701e-01,  -3.53912622e-01,  -3.56876910e-01,
                         -3.59666824e-01,  -3.62747341e-01,  -3.65769774e-01,
                         -3.68850291e-01,  -3.71930838e-01,  -3.74778867e-01,
                         -3.77568781e-01,  -3.80649328e-01,  -3.83787960e-01,
                         -3.86636019e-01,  -3.89425933e-01,  -3.92332107e-01,
                         -3.95354509e-01,  -3.98376912e-01,  -4.01108712e-01,
                         -4.03956741e-01,  -4.06804800e-01,  -4.09362227e-01,
                         -4.12326515e-01,  -4.15174544e-01,  -4.17731971e-01,
                         -4.20521885e-01,  -4.23021197e-01,  -4.25752968e-01,
                         -4.28601027e-01,  -4.31158453e-01,  -4.33832109e-01,
                         -4.36389536e-01,  -4.38946962e-01,  -4.41678762e-01,
                         -4.44178045e-01,  -4.46851730e-01,  -4.49467272e-01,
                         -4.51908439e-01,  -4.54524010e-01,  -4.56907064e-01,
                         -4.59406346e-01,  -4.61963773e-01,  -4.64230597e-01,
                         -4.66671765e-01,  -4.68996704e-01,  -4.71495986e-01,
                         -4.74053413e-01,  -4.76378351e-01,  -4.78703290e-01,
                         -4.81086344e-01,  -4.83527511e-01,  -4.86026824e-01,
                         -4.88003016e-01,  -4.90153551e-01,  -4.92652863e-01,
                         -4.94861543e-01,  -4.97012109e-01,  -4.99395162e-01,
                         -5.01661956e-01,  -5.03638148e-01,  -5.05963087e-01,
                         -5.08288026e-01,  -5.10206103e-01,  -5.12472928e-01,
                         -5.14797807e-01,  -5.16541541e-01,  -5.18692076e-01,
                         -5.20842671e-01,  -5.22760749e-01,  -5.24911284e-01,
                         -5.26887476e-01,  -5.28863668e-01,  -5.30607343e-01,
                         -5.32409191e-01,  -5.34443498e-01,  -5.36187172e-01,
                         -5.38105249e-01,  -5.39907098e-01,  -5.41592658e-01,
                         -5.43510735e-01,  -5.45080066e-01,  -5.46765625e-01,
                         -5.48509359e-01,  -5.50020516e-01,  -5.51647961e-01,
                         -5.53159177e-01,  -5.54670393e-01,  -5.56239724e-01,
                         -5.57576537e-01,  -5.59087753e-01,  -5.60424626e-01,
                         -5.61645210e-01,  -5.63098252e-01,  -5.64377010e-01,
                         -5.65597594e-01,  -5.66876292e-01,  -5.68096876e-01,
                         -5.69201231e-01,  -5.70421815e-01,  -5.71642399e-01,
                         -5.72746754e-01,  -5.73909223e-01,  -5.75013518e-01,
                         -5.75943530e-01,  -5.76989710e-01,  -5.77803433e-01,
                         -5.78675330e-01,  -5.79837799e-01,  -5.80651522e-01,
                         -5.81523359e-01,  -5.82511425e-01,  -5.83325148e-01,
                         -5.84080756e-01,  -5.84836364e-01,  -5.85591972e-01,
                         -5.86231351e-01,  -5.86754441e-01,  -5.87393820e-01,
                         -5.88091254e-01,  -5.88788748e-01,  -5.89253724e-01,
                         -5.89834988e-01,  -5.90358078e-01,  -5.90590596e-01,
                         -5.91055572e-01,  -5.91636777e-01,  -5.91985524e-01,
                         -5.92218041e-01,  -5.92392385e-01,  -5.92683017e-01,
                         -5.92857361e-01,  -5.92799246e-01,  -5.92973650e-01,
                         -5.93031764e-01,  -5.93031764e-01,  -5.93264222e-01,
                         -5.92973650e-01,  -5.92683017e-01,  -5.92624903e-01,
                         -5.92508674e-01,  -5.92276156e-01,  -5.91811180e-01,
                         -5.91288090e-01,  -5.90939343e-01,  -5.90590596e-01,
                         -5.90067446e-01,  -5.89428127e-01,  -5.88963151e-01,
                         -5.88672519e-01,  -5.88033140e-01,  -5.87103188e-01,
                         -5.86231351e-01,  -5.85533857e-01,  -5.84952652e-01,
                         -5.84080756e-01,  -5.83208919e-01,  -5.82511425e-01,
                         -5.81523359e-01,  -5.80593407e-01,  -5.79605281e-01,
                         -5.78559041e-01,  -5.77570975e-01,  -5.76292276e-01,
                         -5.75304151e-01,  -5.74432313e-01,  -5.73269844e-01,
                         -5.72049260e-01,  -5.70770562e-01,  -5.69608092e-01,
                         -5.68271220e-01,  -5.66818178e-01,  -5.65655708e-01,
                         -5.64202607e-01,  -5.62575161e-01,  -5.61296463e-01,
                         -5.59785247e-01,  -5.58099687e-01,  -5.56704700e-01,
                         -5.55251658e-01,  -5.53391695e-01,  -5.51647961e-01,
                         -5.50194919e-01,  -5.48509359e-01,  -5.46707511e-01,
                         -5.44905663e-01,  -5.42813241e-01,  -5.40895164e-01,
                         -5.39093375e-01,  -5.37059069e-01,  -5.35024703e-01,
                         -5.33048570e-01,  -5.31014204e-01,  -5.28921783e-01,
                         -5.26771247e-01,  -5.24620652e-01,  -5.22237599e-01,
                         -5.19970775e-01,  -5.17936468e-01,  -5.15495300e-01,
                         -5.12996018e-01,  -5.10612965e-01,  -5.08229911e-01,
                         -5.05904973e-01,  -5.03347576e-01,  -5.01022637e-01,
                         -4.98523325e-01,  -4.95849639e-01,  -4.93408471e-01,
                         -4.90792930e-01,  -4.88177359e-01,  -4.85678077e-01,
                         -4.82888162e-01,  -4.80098248e-01,  -4.77424562e-01,
                         -4.74692762e-01,  -4.71960992e-01,  -4.69229192e-01,
                         -4.66497391e-01,  -4.63707477e-01,  -4.60917562e-01,
                         -4.58127648e-01,  -4.55221474e-01,  -4.52431560e-01,
                         -4.49641645e-01,  -4.46793616e-01,  -4.43945557e-01,
                         -4.40806895e-01,  -4.37958866e-01,  -4.35285181e-01,
                         -4.32320893e-01,  -4.29472864e-01,  -4.26508576e-01,
                         -4.23486173e-01,  -4.20638144e-01,  -4.17731971e-01,
                         -4.14825797e-01,  -4.11803395e-01,  -4.08722848e-01,
                         -4.05700445e-01,  -4.02794272e-01,  -3.99829984e-01,
                         -3.96691352e-01,  -3.93843293e-01,  -3.91053379e-01,
                         -3.87682229e-01,  -3.84485453e-01,  -3.81579280e-01,
                         -3.78440619e-01,  -3.75360101e-01,  -3.72105211e-01,
                         -3.68966550e-01,  -3.65827888e-01,  -3.62572968e-01,
                         -3.59492451e-01,  -3.56295675e-01,  -3.53157014e-01,
                         -3.50018352e-01,  -3.46647203e-01,  -3.43334168e-01,
                         -3.40079278e-01,  -3.36824358e-01,  -3.33685726e-01,
                         -3.30314577e-01,  -3.26943427e-01,  -3.23746622e-01,
                         -3.20666105e-01,  -3.17411184e-01,  -3.13865662e-01,
                         -3.10727030e-01,  -3.07413995e-01,  -3.03984731e-01,
                         -3.00846070e-01,  -2.97707409e-01,  -2.94626862e-01,
                         -2.91371971e-01,  -2.87942708e-01,  -2.84804046e-01,
                         -2.81665385e-01,  -2.78468609e-01,  -2.75271833e-01,
                         -2.71900684e-01,  -2.68820137e-01,  -2.65507102e-01,
                         -2.62077838e-01,  -2.59055436e-01,  -2.55916774e-01,
                         -2.52836227e-01,  -2.49581337e-01,  -2.46210188e-01,
                         -2.43187770e-01,  -2.39990994e-01,  -2.36736089e-01,
                         -2.33771801e-01,  -2.30516896e-01,  -2.27320120e-01,
                         -2.24181458e-01,  -2.20926568e-01,  -2.17787907e-01,
                         -2.14707375e-01,  -2.11510599e-01,  -2.08255693e-01,
                         -2.05349520e-01,  -2.02152744e-01,  -1.98723465e-01,
                         -1.95701063e-01,  -1.92620531e-01,  -1.89481869e-01,
                         -1.86459467e-01,  -1.83204561e-01,  -1.80124030e-01,
                         -1.76985368e-01,  -1.73614219e-01,  -1.70475557e-01,
                         -1.67220652e-01,  -1.63965762e-01,  -1.60652727e-01,
                         -1.57397822e-01,  -1.54375419e-01,  -1.51120514e-01,
                         -1.47633120e-01,  -1.44552574e-01,  -1.41355798e-01,
                         -1.38042778e-01,  -1.34845987e-01,  -1.31591097e-01,
                         -1.28336191e-01,  -1.24965034e-01,  -1.21826380e-01,
                         -1.18687727e-01,  -1.15432821e-01,  -1.12352289e-01,
                         -1.09039262e-01,  -1.05668113e-01,  -1.02645703e-01,
                         -9.95070413e-02,  -9.64265093e-02,  -9.32878554e-02,
                         -9.00329500e-02,  -8.69524181e-02,  -8.38137567e-02,
                         -8.05588588e-02,  -7.74783269e-02,  -7.42234215e-02,
                         -7.12010115e-02,  -6.80623502e-02,  -6.48074523e-02,
                         -6.16687946e-02,  -5.85301369e-02,  -5.55077270e-02,
                         -5.24271913e-02,  -4.92885374e-02,  -4.64404970e-02,
                         -4.32437137e-02,  -4.00469340e-02,  -3.70245241e-02,
                         -3.38858701e-02,  -3.08634583e-02,  -2.77829245e-02,
                         -2.46442687e-02,  -2.15637349e-02,  -1.84250772e-02,
                         -1.53445443e-02,  -1.22640105e-02,  -9.18347761e-03,
                         -6.10294379e-03,  -2.96428683e-03,   1.74369823e-04,
                          3.31302662e-03,   6.56792987e-03,   9.64846369e-03,
                          1.26127508e-02,   1.56932846e-02,   1.88319404e-02,
                          2.20287200e-02,   2.52836235e-02,   2.84222811e-02,
                          3.13284434e-02,   3.45252231e-02,   3.77220027e-02,
                          4.08025384e-02,   4.39993180e-02,   4.69054803e-02,
                          4.98697683e-02,   5.32990433e-02,   5.63795753e-02,
                          5.94601072e-02,   6.25987649e-02,   6.57955483e-02,
                          6.89923242e-02,   7.19566122e-02,   7.50371441e-02,
                          7.80014321e-02,   8.07332247e-02,   8.38718861e-02,
                          8.69524181e-02,   8.99167061e-02,   9.28228647e-02,
                          9.57290307e-02,   9.86933187e-02,   1.01715729e-01,
                          1.04563765e-01,   1.07411809e-01,   1.10376097e-01,
                          1.13282263e-01,   1.16130300e-01,   1.18978344e-01,
                          1.21942624e-01,   1.24732547e-01,   1.27464339e-01,
                          1.30196139e-01,   1.33102298e-01,   1.36124700e-01,
                          1.38972744e-01,   1.41762659e-01,   1.44378215e-01,
                          1.47226244e-01,   1.50248662e-01,   1.52922332e-01,
                          1.55654132e-01,   1.58502162e-01,   1.61175832e-01,
                          1.64140120e-01,   1.66813791e-01,   1.69487461e-01,
                          1.72277376e-01,   1.74892932e-01,   1.77682847e-01,
                          1.80530891e-01,   1.83262676e-01,   1.86052606e-01,
                          1.88726276e-01,   1.91399932e-01,   1.94073603e-01,
                          1.96805403e-01,   1.99595317e-01,   2.02210873e-01,
                          2.05000788e-01,   2.07616329e-01,   2.10290000e-01,
                          2.13196173e-01,   2.15753585e-01,   2.18427256e-01,
                          2.21159056e-01,   2.23716483e-01,   2.26390153e-01,
                          2.28831321e-01,   2.31330633e-01,   2.34062418e-01,
                          2.36445472e-01,   2.39119142e-01,   2.41676569e-01,
                          2.44059622e-01,   2.46617049e-01,   2.49000102e-01,
                          2.51499414e-01,   2.54114956e-01,   2.56556123e-01,
                          2.59171665e-01,   2.61496603e-01,   2.63879657e-01,
                          2.66437083e-01,   2.68703908e-01,   2.71086961e-01,
                          2.73586243e-01,   2.75911182e-01,   2.78236121e-01,
                          2.80386657e-01,   2.82711595e-01,   2.85152793e-01,
                          2.87303329e-01,   2.89744526e-01,   2.92127579e-01,
                          2.94394374e-01,   2.96777427e-01,   2.98869878e-01,
                          3.01311046e-01,   3.03810358e-01,   3.05960923e-01,
                          3.08169603e-01,   3.10494512e-01,   3.12877595e-01,
                          3.15318763e-01,   3.17469329e-01,   3.19619894e-01,
                          3.21828574e-01,   3.23920995e-01,   3.26013446e-01,
                          3.28338385e-01,   3.30779552e-01,   3.32930118e-01,
                          3.35080683e-01,   3.37231219e-01,   3.39207411e-01,
                          3.41357976e-01,   3.43566656e-01,   3.45775366e-01,
                          3.47867787e-01,   3.49843979e-01,   3.52052659e-01,
                          3.54086995e-01,   3.56179416e-01,   3.58504355e-01,
                          3.60422432e-01,   3.62514853e-01,   3.64781678e-01,
                          3.66757870e-01,   3.68675917e-01,   3.70652109e-01,
                          3.72512072e-01,   3.74430120e-01,   3.76522571e-01,
                          3.78673136e-01,   3.80474955e-01,   3.82218659e-01,
                          3.84078592e-01,   3.85938525e-01,   3.87856603e-01,
                          3.89484048e-01,   3.91227752e-01,   3.93320203e-01,
                          3.95005763e-01,   3.96691352e-01,   3.98493171e-01,
                          4.00062501e-01,   4.01806176e-01,   4.03491765e-01,
                          4.05061096e-01,   4.06630427e-01,   4.08315986e-01,
                          4.09943461e-01,   4.11454648e-01,   4.13023978e-01,
                          4.14651424e-01,   4.16337013e-01,   4.17848200e-01,
                          4.19243157e-01,   4.20986861e-01,   4.22614306e-01,
                          4.23893034e-01,   4.25520480e-01,   4.26915437e-01,
                          4.28310394e-01,   4.29995984e-01,   4.31332827e-01,
                          4.32727784e-01,   4.34064597e-01,   4.35459554e-01,
                          4.36970770e-01,   4.38075125e-01,   4.39411938e-01,
                          4.40865040e-01,   4.41853136e-01,   4.43131834e-01,
                          4.44410563e-01,   4.45689261e-01,   4.46909845e-01,
                          4.48072314e-01,   4.49409157e-01,   4.50629741e-01,
                          4.51792210e-01,   4.52780306e-01,   4.53652143e-01,
                          4.54698354e-01,   4.55802709e-01,   4.56965178e-01,
                          4.57953274e-01,   4.58941370e-01,   4.59871352e-01,
                          4.60510701e-01,   4.61440682e-01,   4.62428749e-01,
                          4.62951869e-01,   4.63765591e-01,   4.64521199e-01,
                          4.65276808e-01,   4.66323018e-01,   4.66846138e-01,
                          4.67485487e-01,   4.68299210e-01,   4.68706071e-01,
                          4.69287306e-01,   4.69926655e-01,   4.70333517e-01,
                          4.70914751e-01,   4.71437871e-01,   4.71960992e-01,
                          4.72309709e-01,   4.72716570e-01,   4.73297805e-01,
                          4.73704666e-01,   4.74285901e-01,   4.74750906e-01,
                          4.74809021e-01,   4.75273997e-01,   4.75739002e-01,
                          4.76029605e-01,   4.76436466e-01,   4.76610839e-01,
                          4.76843327e-01,   4.77133960e-01,   4.77482677e-01,
                          4.77715194e-01,   4.77831423e-01,   4.77947682e-01,
                          4.78238285e-01,   4.78354543e-01,   4.78528917e-01,
                          4.78819519e-01,   4.78935778e-01,   4.79052007e-01,
                          4.78993893e-01,   4.78935778e-01,   4.79052007e-01,
                          4.78877664e-01,   4.78877664e-01,   4.79052007e-01,
                          4.78935778e-01,   4.78935778e-01,   4.78935778e-01,
                          4.78819519e-01,   4.78993893e-01,   4.78935778e-01,
                          4.78703290e-01,   4.78470773e-01,   4.78122056e-01,
                          4.78005797e-01,   4.77947682e-01,   4.77540821e-01,
                          4.77424562e-01,   4.77308333e-01,   4.76901472e-01,
                          4.76785213e-01,   4.76552725e-01,   4.76145864e-01,
                          4.75855231e-01,   4.75622743e-01,   4.75273997e-01,
                          4.74809021e-01,   4.74344045e-01,   4.74053413e-01,
                          4.73588437e-01,   4.73239690e-01,   4.72890943e-01,
                          4.72251594e-01,   4.71728474e-01,   4.71437871e-01,
                          4.70914751e-01,   4.70449775e-01,   4.70159173e-01,
                          4.69636053e-01,   4.68938559e-01,   4.68589842e-01,
                          4.68357325e-01,   4.67776090e-01,   4.67311114e-01,
                          4.66846138e-01,   4.66264904e-01,   4.65974271e-01,
                          4.65509295e-01,   4.64869946e-01,   4.64521199e-01,
                          4.64056224e-01,   4.63533103e-01,   4.63126242e-01,
                          4.62661266e-01,   4.62312520e-01,   4.61731285e-01,
                          4.61208165e-01,   4.60801303e-01,   4.60336328e-01,
                          4.59987581e-01,   4.59406346e-01,   4.58708882e-01,
                          4.58185762e-01,   4.57662642e-01,   4.57197666e-01,
                          4.56616431e-01,   4.55977082e-01,   4.55512106e-01,
                          4.54814613e-01,   4.54175264e-01,   4.53652143e-01,
                          4.52954680e-01,   4.52373445e-01,   4.51850325e-01,
                          4.51385349e-01,   4.50687855e-01,   4.49874133e-01,
                          4.49351013e-01,   4.48537290e-01,   4.47781712e-01,
                          4.47084218e-01,   4.46154237e-01,   4.45456773e-01,
                          4.44875538e-01,   4.44119930e-01,   4.43422467e-01,
                          4.42434371e-01,   4.41620618e-01,   4.40806895e-01,
                          4.39993173e-01,   4.39295709e-01,   4.38365728e-01,
                          4.37552005e-01,   4.36796397e-01,   4.35750186e-01,
                          4.34994578e-01,   4.34297085e-01,   4.33425248e-01,
                          4.32495266e-01,   4.31507170e-01,   4.30751592e-01,
                          4.29763496e-01,   4.28775400e-01,   4.28019792e-01,
                          4.27089810e-01,   4.26159829e-01,   4.25171733e-01,
                          4.24358010e-01,   4.23602402e-01,   4.22381818e-01,
                          4.21451867e-01,   4.20638144e-01,   4.19533789e-01,
                          4.18603808e-01,   4.17557597e-01,   4.16511387e-01,
                          4.15581405e-01,   4.14651424e-01,   4.13721472e-01,
                          4.12500858e-01,   4.11280274e-01,   4.10175949e-01,
                          4.08955365e-01,   4.07909125e-01,   4.06746656e-01,
                          4.05526072e-01,   4.04421747e-01,   4.03201133e-01,
                          4.01864320e-01,   4.00585592e-01,   3.99365008e-01,
                          3.98144424e-01,   3.96633208e-01,   3.95296395e-01,
                          3.93901438e-01,   3.92390221e-01,   3.90937150e-01,
                          3.89658421e-01,   3.88379723e-01,   3.86519760e-01,
                          3.84659827e-01,   3.83381099e-01,   3.81811798e-01,
                          3.80242467e-01,   3.78789365e-01,   3.77045661e-01,
                          3.75592589e-01,   3.73907030e-01,   3.72105211e-01,
                          3.70652109e-01,   3.68966550e-01,   3.67222846e-01,
                          3.65479141e-01,   3.63851696e-01,   3.62340480e-01,
                          3.60480547e-01,   3.58736843e-01,   3.57051283e-01,
                          3.55075091e-01,   3.53447616e-01,   3.51645797e-01,
                          3.49785864e-01,   3.48042160e-01,   3.46124083e-01,
                          3.44322264e-01,   3.42404217e-01,   3.40369880e-01,
                          3.38626176e-01,   3.36940616e-01,   3.35022539e-01,
                          3.32988232e-01,   3.31012040e-01,   3.29210222e-01,
                          3.27292144e-01,   3.25374097e-01,   3.23281646e-01,
                          3.21072966e-01,   3.19154888e-01,   3.17120582e-01,
                          3.14911902e-01,   3.12877595e-01,   3.10727030e-01,
                          3.08576465e-01,   3.06425899e-01,   3.04217219e-01,
                          3.02008539e-01,   2.99857974e-01,   2.97707409e-01,
                          2.95382470e-01,   2.92999417e-01,   2.90790737e-01,
                          2.88523942e-01,   2.86257118e-01,   2.83932179e-01,
                          2.81374753e-01,   2.78991699e-01,   2.76724905e-01,
                          2.74341851e-01,   2.71726310e-01,   2.69285113e-01,
                          2.66902059e-01,   2.64286518e-01,   2.61845350e-01,
                          2.59287924e-01,   2.56556123e-01,   2.54289329e-01,
                          2.51731902e-01,   2.49116346e-01,   2.46733293e-01,
                          2.44059622e-01,   2.41444081e-01,   2.39002898e-01,
                          2.36503601e-01,   2.33888045e-01,   2.31098130e-01,
                          2.28540704e-01,   2.25808918e-01,   2.23135248e-01,
                          2.20519707e-01,   2.17787907e-01,   2.15172365e-01,
                          2.12440565e-01,   2.09534407e-01,   2.06860736e-01,
                          2.04303309e-01,   2.01571509e-01,   1.99014083e-01,
                          1.96340412e-01,   1.93434253e-01,   1.90644339e-01,
                          1.87912539e-01,   1.85122624e-01,   1.82390839e-01,
                          1.79775283e-01,   1.76927239e-01,   1.73904836e-01,
                          1.71114922e-01,   1.68266878e-01,   1.65418833e-01,
                          1.62512675e-01,   1.59606501e-01,   1.56700343e-01,
                          1.53736055e-01,   1.51004270e-01,   1.48098096e-01,
                          1.44901320e-01,   1.42111406e-01,   1.39205247e-01,
                          1.36299074e-01,   1.33334786e-01,   1.30138010e-01,
                          1.27231851e-01,   1.24267556e-01,   1.21187024e-01,
                          1.18280858e-01,   1.15142204e-01,   1.12177916e-01,
                          1.09097384e-01,   1.05900601e-01,   1.02936320e-01,
                          9.97395366e-02,   9.68333706e-02,   9.39272121e-02,
                          9.05560628e-02,   8.75917748e-02,   8.45693648e-02,
                          8.13144594e-02,   7.83501714e-02,   7.52115175e-02,
                          7.21891075e-02,   6.91666976e-02,   6.59117922e-02,
                          6.29475042e-02,   5.98669723e-02,   5.66701926e-02,
                          5.37059046e-02,   5.05672470e-02,   4.76029627e-02,
                          4.45805490e-02,   4.13256474e-02,   3.84776071e-02,
                          3.53970751e-02,   3.22002918e-02,   2.92941295e-02,
                          2.60973498e-02,   2.28424463e-02,   1.99362822e-02,
                          1.67395025e-02,   1.35427229e-02,   1.06946826e-02,
                          7.78851844e-03,   4.59173881e-03,   1.56932836e-03,
                         -1.51120510e-03,  -4.64986172e-03,  -7.61414878e-03,
                         -1.06365588e-02,  -1.37752155e-02,  -1.68557484e-02,
                         -1.99944060e-02,  -2.30749398e-02,  -2.61554737e-02,
                         -2.92360056e-02,  -3.23746651e-02,  -3.56295668e-02,
                         -3.87682244e-02,  -4.19068784e-02,  -4.49292921e-02,
                         -4.80679460e-02,  -5.13228513e-02,  -5.43452613e-02,
                         -5.75420409e-02,  -6.06806986e-02,  -6.38193563e-02,
                         -6.70742542e-02,  -7.00385422e-02,  -7.30609521e-02,
                         -7.63158575e-02,  -7.93382674e-02,  -8.23606774e-02,
                         -8.54993388e-02,  -8.86379927e-02,  -9.18347687e-02,
                         -9.48571786e-02,  -9.79958400e-02,  -1.01076372e-01,
                         -1.04040660e-01,  -1.07121192e-01,  -1.10259853e-01,
                         -1.13282263e-01,  -1.16304673e-01,  -1.19385205e-01,
                         -1.22233242e-01,  -1.25313774e-01,  -1.28684923e-01,
                         -1.31591097e-01,  -1.34555385e-01,  -1.37635916e-01,
                         -1.40600204e-01,  -1.43796980e-01,  -1.46819383e-01,
                         -1.49783671e-01,  -1.53038576e-01,  -1.55828491e-01,
                         -1.58792779e-01,  -1.61873311e-01,  -1.64837599e-01,
                         -1.67918131e-01,  -1.70824304e-01,  -1.73904836e-01,
                         -1.77043498e-01,  -1.79833412e-01,  -1.82972059e-01,
                         -1.86052606e-01,  -1.88842520e-01,  -1.92039296e-01,
                         -1.95294201e-01,  -1.98200360e-01,  -2.01222777e-01,
                         -2.04303309e-01,  -2.07383841e-01,  -2.10522503e-01,
                         -2.13661149e-01,  -2.16857940e-01,  -2.19880342e-01,
                         -2.23019004e-01,  -2.26099536e-01,  -2.29063824e-01,
                         -2.32318729e-01,  -2.35341132e-01,  -2.38421664e-01,
                         -2.41618454e-01,  -2.44582728e-01,  -2.47721389e-01,
                         -2.50976294e-01,  -2.54056841e-01,  -2.57195473e-01,
                         -2.60159761e-01,  -2.63356566e-01,  -2.66611457e-01,
                         -2.69633859e-01,  -2.72714406e-01,  -2.75678694e-01,
                         -2.78642982e-01,  -2.81665385e-01,  -2.84862161e-01,
                         -2.87942708e-01,  -2.90848851e-01,  -2.93987513e-01,
                         -2.97009915e-01,  -2.99974203e-01,  -3.03171009e-01,
                         -3.06193411e-01,  -3.09273928e-01,  -3.12354475e-01,
                         -3.15202504e-01,  -3.18283051e-01,  -3.21363568e-01,
                         -3.24211627e-01,  -3.27292144e-01,  -3.30372691e-01,
                         -3.33336979e-01,  -3.36301267e-01,  -3.39381784e-01,
                         -3.42462331e-01,  -3.45252246e-01,  -3.48332763e-01,
                         -3.51587683e-01,  -3.54493856e-01,  -3.57516259e-01,
                         -3.60422432e-01,  -3.63386691e-01,  -3.66467237e-01,
                         -3.69431525e-01,  -3.72512072e-01,  -3.75592589e-01,
                         -3.78382504e-01,  -3.81463051e-01,  -3.84485453e-01,
                         -3.87449741e-01,  -3.90530288e-01,  -3.93552691e-01,
                         -3.96633208e-01,  -3.99713755e-01,  -4.02445555e-01,
                         -4.05584216e-01,  -4.08722848e-01,  -4.11570907e-01,
                         -4.14535195e-01,  -4.17615712e-01,  -4.20463771e-01,
                         -4.23311800e-01,  -4.26334202e-01,  -4.29124117e-01,
                         -4.32030290e-01,  -4.35052693e-01,  -4.37726378e-01,
                         -4.40574408e-01,  -4.43596810e-01,  -4.46386755e-01,
                         -4.49176669e-01,  -4.51908439e-01,  -4.54756498e-01,
                         -4.57372040e-01,  -4.60161954e-01,  -4.63009983e-01,
                         -4.65509295e-01,  -4.68182981e-01,  -4.70972896e-01,
                         -4.73530322e-01,  -4.76262093e-01,  -4.78761405e-01,
                         -4.81376946e-01,  -4.84166861e-01,  -4.86549914e-01,
                         -4.89107341e-01,  -4.91490394e-01,  -4.93757218e-01,
                         -4.96605247e-01,  -4.99046415e-01,  -5.01371384e-01,
                         -5.03812551e-01,  -5.06079316e-01,  -5.08636773e-01,
                         -5.10961711e-01,  -5.13170362e-01,  -5.15727818e-01,
                         -5.17878354e-01,  -5.20319521e-01,  -5.22818863e-01,
                         -5.24911284e-01,  -5.27352452e-01,  -5.29735506e-01,
                         -5.32002330e-01,  -5.34385383e-01,  -5.36361575e-01,
                         -5.38570225e-01,  -5.40895164e-01,  -5.42987645e-01,
                         -5.45196295e-01,  -5.47230601e-01,  -5.49090564e-01,
                         -5.51357388e-01,  -5.53275466e-01,  -5.55193484e-01,
                         -5.57402194e-01,  -5.59262156e-01,  -5.61063945e-01,
                         -5.63156366e-01,  -5.64958215e-01,  -5.66643775e-01,
                         -5.68619967e-01,  -5.70421815e-01,  -5.71991146e-01,
                         -5.73734820e-01,  -5.75478554e-01,  -5.77280343e-01,
                         -5.78791559e-01,  -5.80302775e-01,  -5.81755817e-01,
                         -5.83267033e-01,  -5.84836364e-01,  -5.86115062e-01,
                         -5.87510049e-01,  -5.88963151e-01,  -5.90241849e-01,
                         -5.91520548e-01,  -5.92741132e-01,  -5.93961716e-01,
                         -5.95182300e-01,  -5.96228540e-01,  -5.97391009e-01,
                         -5.98320961e-01,  -5.99367201e-01,  -6.00471556e-01,
                         -6.01343393e-01,  -6.02389634e-01,  -6.03435814e-01,
                         -6.04249537e-01,  -6.05063260e-01,  -6.05760753e-01,
                         -6.06400132e-01,  -6.07155740e-01,  -6.08027577e-01,
                         -6.08725071e-01,  -6.09190047e-01,  -6.09771252e-01,
                         -6.10294342e-01,  -6.10701263e-01,  -6.11224353e-01,
                         -6.11631215e-01,  -6.11979961e-01,  -6.12386823e-01,
                         -6.12619281e-01,  -6.12909913e-01,  -6.13200545e-01,
                         -6.13433003e-01,  -6.13549292e-01,  -6.13665521e-01,
                         -6.13898039e-01,  -6.13956153e-01,  -6.13898039e-01,
                         -6.14014268e-01,  -6.13956153e-01,  -6.13781750e-01,
                         -6.13607407e-01,  -6.13433003e-01,  -6.13316774e-01,
                         -6.12968028e-01,  -6.12677395e-01,  -6.12328708e-01,
                         -6.11979961e-01,  -6.11863673e-01,  -6.11224353e-01,
                         -6.10526860e-01,  -6.10294342e-01,  -6.09538794e-01,
                         -6.08783185e-01,  -6.08201921e-01,  -6.07330084e-01,
                         -6.06458247e-01,  -6.05644524e-01,  -6.04888916e-01,
                         -6.03958905e-01,  -6.02796495e-01,  -6.01924598e-01,
                         -6.00936532e-01,  -5.99832177e-01,  -5.98727822e-01,
                         -5.97158492e-01,  -5.96112311e-01,  -5.95066071e-01,
                         -5.93671143e-01,  -5.92508674e-01,  -5.91113687e-01,
                         -5.89544356e-01,  -5.88091254e-01,  -5.86463809e-01,
                         -5.85185111e-01,  -5.83732009e-01,  -5.82046449e-01,
                         -5.80767751e-01,  -5.79198420e-01,  -5.77280343e-01,
                         -5.75652897e-01,  -5.73792934e-01,  -5.71991146e-01,
                         -5.70305586e-01,  -5.68445623e-01,  -5.66760063e-01,
                         -5.64841986e-01,  -5.62749505e-01,  -5.60831487e-01,
                         -5.58913410e-01,  -5.57053447e-01,  -5.54902911e-01,
                         -5.52752316e-01,  -5.50659895e-01,  -5.48567474e-01,
                         -5.46416879e-01,  -5.44208229e-01,  -5.42057633e-01,
                         -5.39732695e-01,  -5.37524045e-01,  -5.35199106e-01,
                         -5.32699823e-01,  -5.30491114e-01,  -5.27991831e-01,
                         -5.25376260e-01,  -5.22935092e-01,  -5.20552039e-01,
                         -5.17994642e-01,  -5.15553415e-01,  -5.12937903e-01,
                         -5.10206103e-01,  -5.07474303e-01,  -5.04742503e-01,
                         -5.02010703e-01,  -4.99278933e-01,  -4.96430874e-01,
                         -4.93640959e-01,  -4.90676671e-01,  -4.87944871e-01,
                         -4.84980583e-01,  -4.82074440e-01,  -4.79342639e-01,
                         -4.76320237e-01,  -4.73239690e-01,  -4.70333517e-01,
                         -4.67369229e-01,  -4.64404941e-01,  -4.61324424e-01,
                         -4.58127648e-01,  -4.54988986e-01,  -4.51908439e-01,
                         -4.48827922e-01,  -4.45514888e-01,  -4.42434371e-01,
                         -4.39295709e-01,  -4.36040789e-01,  -4.33018386e-01,
                         -4.29879725e-01,  -4.26624835e-01,  -4.23428059e-01,
                         -4.20231253e-01,  -4.16918248e-01,  -4.13605213e-01,
                         -4.10408437e-01,  -4.07153517e-01,  -4.03840512e-01,
                         -4.00643736e-01,  -3.97272587e-01,  -3.94017667e-01,
                         -3.90704632e-01,  -3.87333483e-01,  -3.84078592e-01,
                         -3.80707443e-01,  -3.77394408e-01,  -3.74081373e-01,
                         -3.70419621e-01,  -3.67106587e-01,  -3.63793582e-01,
                         -3.60306174e-01,  -3.56876910e-01,  -3.53447616e-01,
                         -3.50018352e-01,  -3.46530944e-01,  -3.43217939e-01,
                         -3.39614272e-01,  -3.35778147e-01,  -3.32406998e-01,
                         -3.28977734e-01,  -3.25374097e-01,  -3.21886688e-01,
                         -3.18224937e-01,  -3.14853758e-01,  -3.11424494e-01,
                         -3.07646483e-01,  -3.04333448e-01,  -3.00671697e-01,
                         -2.96835572e-01,  -2.93406278e-01,  -2.89860755e-01,
                         -2.86082745e-01,  -2.82479107e-01,  -2.78701097e-01,
                         -2.75155574e-01,  -2.71610051e-01,  -2.68064529e-01,
                         -2.64635265e-01,  -2.61089742e-01,  -2.57660478e-01,
                         -2.53882468e-01,  -2.50278801e-01,  -2.46965796e-01,
                         -2.43129656e-01,  -2.39526004e-01,  -2.36154854e-01,
                         -2.32551217e-01,  -2.29180068e-01,  -2.25634545e-01,
                         -2.21972778e-01,  -2.18543515e-01,  -2.14997992e-01,
                         -2.11568713e-01,  -2.07965076e-01,  -2.04419553e-01,
                         -2.00932160e-01,  -1.97270393e-01,  -1.93957359e-01,
                         -1.90586209e-01,  -1.86982572e-01,  -1.83495179e-01,
                         -1.80182144e-01,  -1.76869124e-01,  -1.73207358e-01,
                         -1.69603705e-01,  -1.66174442e-01,  -1.62628919e-01,
                         -1.59257770e-01,  -1.55770376e-01,  -1.52224854e-01,
                         -1.48795575e-01,  -1.45191938e-01,  -1.41820788e-01,
                         -1.38391510e-01,  -1.34729743e-01,  -1.31474838e-01,
                         -1.28045574e-01,  -1.24383807e-01,  -1.20896406e-01,
                         -1.17350891e-01,  -1.13863491e-01,  -1.10376097e-01,
                         -1.06714331e-01,  -1.03285059e-01,  -9.97976586e-02,
                         -9.63102654e-02,  -9.28228647e-02,  -8.93935934e-02,
                         -8.58480781e-02,  -8.23606774e-02,  -7.90476501e-02,
                         -7.56183788e-02,  -7.20728561e-02,  -6.86435848e-02,
                         -6.50399402e-02,  -6.15525469e-02,  -5.81232719e-02,
                         -5.46940006e-02,  -5.13228513e-02,  -4.80098240e-02,
                         -4.46386747e-02,  -4.13256474e-02,  -3.80126201e-02,
                         -3.46995927e-02,  -3.12703215e-02,  -2.80154180e-02,
                         -2.47023907e-02,  -2.12731175e-02,  -1.80763379e-02,
                         -1.47633115e-02,  -1.13921613e-02,  -8.31162836e-03,
                         -4.99860151e-03,  -1.68557488e-03,   1.62745162e-03,
                          4.88235475e-03,   8.07913486e-03,   1.13340383e-02,
                          1.46470647e-02,   1.79600921e-02,   2.11568717e-02,
                          2.43536513e-02,   2.76666787e-02,   3.07472125e-02,
                          3.39439921e-02,   3.73732634e-02,   4.03956734e-02,
                          4.35924567e-02,   4.70217280e-02,   5.00441380e-02,
                          5.32409176e-02,   5.64376973e-02,   5.95763549e-02,
                          6.28312603e-02,   6.59699142e-02,   6.92248195e-02,
                          7.24797249e-02,   7.55021349e-02,   7.87570328e-02,
                          8.19538161e-02,   8.51505920e-02,   8.84054974e-02,
                          9.14279073e-02,   9.45084393e-02,   9.76471007e-02,
                          1.00785755e-01,   1.04098782e-01,   1.07237436e-01,
                          1.10317975e-01,   1.13456629e-01,   1.16420917e-01,
                          1.19443327e-01,   1.22523859e-01,   1.25546277e-01,
                          1.28510565e-01,   1.31474838e-01,   1.34613499e-01,
                          1.37461543e-01,   1.40309587e-01,   1.43390119e-01,
                          1.46180034e-01,   1.49028078e-01,   1.52050480e-01,
                          1.54898524e-01,   1.57862812e-01,   1.60652727e-01,
                          1.63384527e-01,   1.66116312e-01,   1.68848112e-01,
                          1.71579897e-01,   1.74311697e-01,   1.77217856e-01,
                          1.79891527e-01,   1.82623327e-01,   1.85413241e-01,
                          1.87970668e-01,   1.90760583e-01,   1.93492383e-01,
                          1.95991680e-01,   1.98723465e-01,   2.01339021e-01,
                          2.04070807e-01,   2.06802607e-01,   2.09243789e-01,
                          2.11626843e-01,   2.14416757e-01,   2.17148542e-01,
                          2.19531611e-01,   2.22089022e-01,   2.24704579e-01,
                          2.27203876e-01,   2.29935676e-01,   2.32434973e-01,
                          2.34876141e-01,   2.37491697e-01,   2.39816621e-01,
                          2.42490292e-01,   2.45163962e-01,   2.47314528e-01,
                          2.49871954e-01,   2.52429366e-01,   2.54812419e-01,
                          2.57137358e-01,   2.59346038e-01,   2.61729091e-01,
                          2.64112145e-01,   2.66378969e-01,   2.68820137e-01,
                          2.71203190e-01,   2.73528129e-01,   2.75794923e-01,
                          2.77945489e-01,   2.80212313e-01,   2.82246619e-01,
                          2.84513414e-01,   2.86838353e-01,   2.88872659e-01,
                          2.91139483e-01,   2.93231905e-01,   2.95324355e-01,
                          2.97533035e-01,   2.99509227e-01,   3.01543534e-01,
                          3.03694099e-01,   3.05612177e-01,   3.07704598e-01,
                          3.09680790e-01,   3.11831355e-01,   3.13981920e-01,
                          3.15783739e-01,   3.17585558e-01,   3.19619894e-01,
                          3.21537942e-01,   3.23339760e-01,   3.25141579e-01,
                          3.27234030e-01,   3.29210222e-01,   3.31070155e-01,
                          3.32988232e-01,   3.34848166e-01,   3.36708128e-01,
                          3.38626176e-01,   3.40369880e-01,   3.42229843e-01,
                          3.44089776e-01,   3.45949709e-01,   3.47751558e-01,
                          3.49553376e-01,   3.51413310e-01,   3.53215128e-01,
                          3.55075091e-01,   3.56876910e-01,   3.58620584e-01,
                          3.60364288e-01,   3.62049878e-01,   3.63967925e-01,
                          3.65711629e-01,   3.67222846e-01,   3.69199038e-01,
                          3.70884597e-01,   3.72453928e-01,   3.74372005e-01,
                          3.75941336e-01,   3.77510667e-01,   3.79312485e-01,
                          3.80765557e-01,   3.82393003e-01,   3.84078592e-01,
                          3.85589808e-01,   3.87100995e-01,   3.88670325e-01,
                          3.90414029e-01,   3.91808987e-01,   3.93378317e-01,
                          3.95063877e-01,   3.96458834e-01,   3.97970051e-01,
                          3.99306893e-01,   4.00585592e-01,   4.02154922e-01,
                          4.03375506e-01,   4.04712349e-01,   4.06107306e-01,
                          4.07269776e-01,   4.08780992e-01,   4.10234064e-01,
                          4.11396533e-01,   4.12791491e-01,   4.13953960e-01,
                          4.15290803e-01,   4.16685760e-01,   4.17964458e-01,
                          4.19359416e-01,   4.20463771e-01,   4.21800584e-01,
                          4.23079312e-01,   4.24299896e-01,   4.25636739e-01,
                          4.26741064e-01,   4.27961648e-01,   4.29356635e-01,
                          4.30519074e-01,   4.31797802e-01,   4.33076501e-01,
                          4.34297085e-01,   4.35459554e-01,   4.36680168e-01,
                          4.38016981e-01,   4.38946962e-01,   4.40051317e-01,
                          4.41271901e-01,   4.42318112e-01,   4.43596810e-01,
                          4.44759279e-01,   4.45805520e-01,   4.47026104e-01,
                          4.48072314e-01,   4.49118525e-01,   4.50222880e-01,
                          4.51385349e-01,   4.52373445e-01,   4.53245282e-01,
                          4.54349637e-01,   4.55279589e-01,   4.56209570e-01,
                          4.57488298e-01,   4.58302021e-01,   4.59231973e-01,
                          4.60161954e-01,   4.60743189e-01,   4.61789399e-01,
                          4.62719381e-01,   4.63416845e-01,   4.64404941e-01,
                          4.65044320e-01,   4.65916157e-01,   4.66787994e-01,
                          4.67253000e-01,   4.68124837e-01,   4.68938559e-01,
                          4.69403565e-01,   4.70159173e-01,   4.70856637e-01,
                          4.71495986e-01,   4.72193480e-01,   4.72774714e-01,
                          4.73472178e-01,   4.74169672e-01,   4.74634647e-01,
                          4.75041509e-01,   4.75680858e-01,   4.76436466e-01,
                          4.77017701e-01,   4.77598935e-01,   4.78063911e-01,
                          4.78645146e-01,   4.79226381e-01,   4.79633242e-01,
                          4.80272621e-01,   4.80911970e-01,   4.81260717e-01,
                          4.81783807e-01,   4.82365042e-01,   4.82713789e-01,
                          4.83236909e-01,   4.83818114e-01,   4.84283119e-01,
                          4.84689981e-01,   4.85271215e-01,   4.85678077e-01,
                          4.85968679e-01,   4.86549914e-01,   4.86898661e-01,
                          4.87247407e-01,   4.87654269e-01,   4.88061130e-01,
                          4.88409877e-01,   4.88758594e-01,   4.89049226e-01,
                          4.89223599e-01,   4.89339828e-01,   4.89804834e-01,
                          4.90037322e-01,   4.90211695e-01,   4.90502298e-01,
                          4.90502298e-01,   4.90676671e-01,   4.90851045e-01,
                          4.91025418e-01,   4.91257906e-01,   4.91374165e-01,
                          4.91548508e-01,   4.91548508e-01,   4.91548508e-01,
                          4.91781026e-01,   4.91839141e-01,   4.91839141e-01,
                          4.91897255e-01,   4.91722882e-01,   4.91606653e-01,
                          4.91664767e-01,   4.91722882e-01,   4.91781026e-01,
                          4.91839141e-01,   4.91897255e-01,   4.91781026e-01,
                          4.91722882e-01,   4.91664767e-01,   4.91432279e-01,
                          4.91432279e-01,   4.91374165e-01,   4.91199791e-01,
                          4.91141647e-01,   4.91025418e-01,   4.91025418e-01,
                          4.90909159e-01,   4.90618557e-01,   4.90618557e-01,
                          4.90560442e-01,   4.90327924e-01,   4.90327924e-01,
                          4.90269810e-01,   4.90037322e-01,   4.89804834e-01,
                          4.89514202e-01,   4.89456087e-01,   4.89339828e-01,
                          4.89049226e-01,   4.88932967e-01,   4.88700479e-01,
                          4.88584250e-01,   4.88293618e-01,   4.87944871e-01,
                          4.87712383e-01,   4.87305522e-01,   4.87073034e-01,
                          4.86724287e-01,   4.86259311e-01,   4.86026824e-01,
                          4.85619962e-01,   4.85213101e-01,   4.85038728e-01,
                          4.84515607e-01,   4.83876258e-01,   4.83353138e-01,
                          4.82888162e-01,   4.82481301e-01,   4.82016295e-01,
                          4.81493205e-01,   4.80853856e-01,   4.80272621e-01,
                          4.79807615e-01,   4.79226381e-01,   4.78761405e-01,
                          4.78296429e-01,   4.77598935e-01,   4.76843327e-01,
                          4.76145864e-01,   4.75448370e-01,   4.74750906e-01,
                          4.74111527e-01,   4.73355949e-01,   4.72425967e-01,
                          4.71786618e-01,   4.71031010e-01,   4.70159173e-01,
                          4.69636053e-01,   4.68938559e-01,   4.68008608e-01,
                          4.67253000e-01,   4.66381133e-01,   4.65567410e-01,
                          4.64811832e-01,   4.63823736e-01,   4.62893754e-01,
                          4.61905658e-01,   4.61033791e-01,   4.60161954e-01,
                          4.59348232e-01,   4.58418250e-01,   4.57255781e-01,
                          4.56325829e-01,   4.55395848e-01,   4.54349637e-01,
                          4.53419656e-01,   4.52373445e-01,   4.51094717e-01,
                          4.50164765e-01,   4.49060410e-01,   4.47723567e-01,
                          4.46677357e-01,   4.45514888e-01,   4.44178045e-01,
                          4.42899346e-01,   4.41620618e-01,   4.40167546e-01,
                          4.38772589e-01,   4.37552005e-01,   4.36215162e-01,
                          4.34703976e-01,   4.33076501e-01,   4.31681544e-01,
                          4.30344731e-01,   4.28775400e-01,   4.27147925e-01,
                          4.25578594e-01,   4.24009293e-01,   4.22381818e-01,
                          4.20638144e-01,   4.19068813e-01,   4.17499483e-01,
                          4.15755779e-01,   4.13895816e-01,   4.11977768e-01,
                          4.10292178e-01,   4.08606619e-01,   4.06688541e-01,
                          4.04944837e-01,   4.03084904e-01,   4.01050597e-01,
                          3.99190634e-01,   3.97330701e-01,   3.95412624e-01,
                          3.93494546e-01,   3.91518384e-01,   3.89832795e-01,
                          3.87566000e-01,   3.85357291e-01,   3.83555472e-01,
                          3.81230563e-01,   3.79196227e-01,   3.77220035e-01,
                          3.75069469e-01,   3.73035163e-01,   3.70710224e-01,
                          3.68675917e-01,   3.66699725e-01,   3.64200443e-01,
                          3.61933619e-01,   3.59666824e-01,   3.57341886e-01,
                          3.55191320e-01,   3.52808267e-01,   3.50483328e-01,
                          3.48216534e-01,   3.45775366e-01,   3.43392313e-01,
                          3.40951115e-01,   3.38626176e-01,   3.36185008e-01,
                          3.33511353e-01,   3.31012040e-01,   3.28338385e-01,
                          3.25780958e-01,   3.23397905e-01,   3.20666105e-01,
                          3.17992419e-01,   3.15376878e-01,   3.12645078e-01,
                          3.10087651e-01,   3.07239622e-01,   3.04391593e-01,
                          3.01601678e-01,   2.98811734e-01,   2.96021819e-01,
                          2.93231905e-01,   2.90383875e-01,   2.87477702e-01,
                          2.84629673e-01,   2.81723499e-01,   2.78759211e-01,
                          2.75969297e-01,   2.72946894e-01,   2.69808233e-01,
                          2.66960204e-01,   2.63937771e-01,   2.60857254e-01,
                          2.58009225e-01,   2.55103052e-01,   2.52080649e-01,
                          2.48883858e-01,   2.45803326e-01,   2.42839038e-01,
                          2.39758506e-01,   2.36677974e-01,   2.33481184e-01,
                          2.30458781e-01,   2.27494493e-01,   2.24239588e-01,
                          2.21100926e-01,   2.18078524e-01,   2.14823619e-01,
                          2.11684957e-01,   2.08662555e-01,   2.05523893e-01,
                          2.02327117e-01,   1.99072212e-01,   1.95875436e-01,
                          1.92736775e-01,   1.89481869e-01,   1.86226964e-01,
                          1.82972059e-01,   1.79717168e-01,   1.76404133e-01,
                          1.73091114e-01,   1.69778079e-01,   1.66639417e-01,
                          1.63442641e-01,   1.59839004e-01,   1.56525970e-01,
                          1.53445438e-01,   1.49958044e-01,   1.46528766e-01,
                          1.43273875e-01,   1.39728352e-01,   1.36299074e-01,
                          1.33044168e-01,   1.29556775e-01,   1.25778764e-01,
                          1.22407615e-01,   1.19094588e-01,   1.15374699e-01,
                          1.11945428e-01,   1.08574271e-01,   1.04854383e-01,
                          1.01483233e-01,   9.81702060e-02,   9.45665687e-02,
                          9.11954194e-02,   8.76498967e-02,   8.41625035e-02,
                          8.07332247e-02,   7.73620754e-02,   7.39909261e-02,
                          7.02710375e-02,   6.66673928e-02,   6.33543655e-02,
                          5.98088466e-02,   5.62633276e-02,   5.27178086e-02,
                          4.91722897e-02,   4.58011404e-02,   4.24881130e-02,
                          3.90588380e-02,   3.55714448e-02,   3.20840478e-02,
                          2.85966508e-02,   2.50511300e-02,   2.16218568e-02,
                          1.81925837e-02,   1.47633115e-02,   1.13340383e-02,
                          7.73039553e-03,   4.41736868e-03,   1.10434217e-03,
                         -2.55742413e-03,  -5.87045075e-03,  -9.29972343e-03,
                         -1.29033662e-02,  -1.62163936e-02,  -1.98200364e-02,
                         -2.32493095e-02,  -2.65623368e-02,  -3.01078558e-02,
                         -3.34790051e-02,  -3.69082801e-02,  -4.05700430e-02,
                         -4.40574400e-02,  -4.74285893e-02,  -5.07997423e-02,
                         -5.42871356e-02,  -5.78907803e-02,  -6.13781773e-02,
                         -6.48655742e-02,  -6.83529675e-02,  -7.17822462e-02,
                         -7.53277615e-02,  -7.88151622e-02,  -8.23025554e-02,
                         -8.57899487e-02,  -8.92192274e-02,  -9.25903767e-02,
                         -9.61940140e-02,  -9.97976586e-02,  -1.03110686e-01,
                         -1.06539957e-01,  -1.09911107e-01,  -1.13282263e-01,
                         -1.16944022e-01,  -1.20373301e-01,  -1.23860694e-01,
                         -1.27289966e-01,  -1.30661115e-01,  -1.34148508e-01,
                         -1.37519658e-01,  -1.40948936e-01,  -1.44320086e-01,
                         -1.47458747e-01,  -1.51004270e-01,  -1.54433534e-01,
                         -1.57746568e-01,  -1.61175832e-01,  -1.64314494e-01,
                         -1.67801887e-01,  -1.71231166e-01,  -1.74486071e-01,
                         -1.77799091e-01,  -1.81053996e-01,  -1.84483275e-01,
                         -1.87912539e-01,  -1.91167444e-01,  -1.94538593e-01,
                         -1.97851628e-01,  -2.01280892e-01,  -2.04710171e-01,
                         -2.07965076e-01,  -2.11394340e-01,  -2.14649245e-01,
                         -2.17962280e-01,  -2.21507788e-01,  -2.24878952e-01,
                         -2.28191972e-01,  -2.31388748e-01,  -2.34701782e-01,
                         -2.38072932e-01,  -2.41444081e-01,  -2.44873345e-01,
                         -2.48186380e-01,  -2.51499414e-01,  -2.54870564e-01,
                         -2.57951081e-01,  -2.61147857e-01,  -2.64635265e-01,
                         -2.67890155e-01,  -2.71203190e-01,  -2.74458110e-01,
                         -2.77829260e-01,  -2.81200409e-01,  -2.84280926e-01,
                         -2.87535846e-01,  -2.90965110e-01,  -2.94220001e-01,
                         -2.97533035e-01,  -3.00787926e-01,  -3.04042846e-01,
                         -3.07297736e-01,  -3.10494512e-01,  -3.13749433e-01,
                         -3.16946208e-01,  -3.20201099e-01,  -3.23456019e-01,
                         -3.26478422e-01,  -3.29617083e-01,  -3.32930118e-01,
                         -3.36185008e-01,  -3.39265555e-01,  -3.42229843e-01,
                         -3.45310360e-01,  -3.48623395e-01,  -3.51820171e-01,
                         -3.54900718e-01,  -3.57981235e-01,  -3.60945523e-01,
                         -3.64084184e-01,  -3.67280960e-01,  -3.70477736e-01,
                         -3.73616397e-01,  -3.76638800e-01,  -3.79603088e-01,
                         -3.82567376e-01,  -3.85647923e-01,  -3.88612211e-01,
                         -3.91634613e-01,  -3.94715160e-01,  -3.97679448e-01,
                         -4.00818080e-01,  -4.03782368e-01,  -4.06630427e-01,
                         -4.09769088e-01,  -4.12791491e-01,  -4.15697664e-01,
                         -4.18836296e-01,  -4.21742469e-01,  -4.24764872e-01,
                         -4.27903533e-01,  -4.30809706e-01,  -4.33483362e-01,
                         -4.36331421e-01,  -4.39295709e-01,  -4.42027479e-01,
                         -4.44991767e-01,  -4.47897941e-01,  -4.50687855e-01,
                         -4.53594029e-01,  -4.56209570e-01,  -4.59057599e-01,
                         -4.62138146e-01,  -4.64869946e-01,  -4.67485487e-01,
                         -4.70042914e-01,  -4.72890943e-01,  -4.75855231e-01,
                         -4.78587031e-01,  -4.81318831e-01,  -4.83759999e-01,
                         -4.86375540e-01,  -4.89107341e-01,  -4.91316020e-01,
                         -4.94047821e-01,  -4.96721506e-01,  -4.98988301e-01,
                         -5.01778245e-01,  -5.04103124e-01,  -5.06311834e-01,
                         -5.08985519e-01,  -5.11194170e-01,  -5.13577223e-01,
                         -5.16134679e-01,  -5.18401504e-01,  -5.20784557e-01,
                         -5.23051322e-01,  -5.25260031e-01,  -5.27584970e-01,
                         -5.29735506e-01,  -5.32176673e-01,  -5.34443498e-01,
                         -5.36652207e-01,  -5.38860857e-01,  -5.40778935e-01,
                         -5.43161988e-01,  -5.45370698e-01,  -5.47230601e-01,
                         -5.49439311e-01,  -5.51531732e-01,  -5.53566039e-01,
                         -5.55658519e-01,  -5.57634711e-01,  -5.59610903e-01,
                         -5.61412692e-01,  -5.63388884e-01,  -5.65306962e-01,
                         -5.67166924e-01,  -5.69201231e-01,  -5.70944905e-01,
                         -5.72572351e-01,  -5.74490428e-01,  -5.76175988e-01,
                         -5.78094065e-01,  -5.79895914e-01,  -5.81348956e-01,
                         -5.83034575e-01,  -5.84487617e-01,  -5.86173236e-01,
                         -5.87742567e-01,  -5.88963151e-01,  -5.90648711e-01,
                         -5.92159927e-01,  -5.93496740e-01,  -5.95124185e-01,
                         -5.96519172e-01,  -5.97681642e-01,  -5.99018455e-01,
                         -6.00355268e-01,  -6.01634026e-01,  -6.02912724e-01,
                         -6.04191422e-01,  -6.05295777e-01,  -6.06225729e-01,
                         -6.07446313e-01,  -6.08376324e-01,  -6.09364390e-01,
                         -6.10526860e-01,  -6.11398697e-01,  -6.12270534e-01,
                         -6.13142431e-01,  -6.13839865e-01,  -6.14479244e-01,
                         -6.15292966e-01,  -6.15932345e-01,  -6.16571665e-01,
                         -6.17211044e-01,  -6.17734134e-01,  -6.18431628e-01,
                         -6.19012833e-01,  -6.19419754e-01,  -6.19942844e-01,
                         -6.20349705e-01,  -6.20698452e-01,  -6.21105313e-01,
                         -6.21454060e-01,  -6.21802807e-01,  -6.22093379e-01,
                         -6.22151494e-01,  -6.22209668e-01,  -6.22500241e-01,
                         -6.22732759e-01,  -6.22790873e-01,  -6.22790873e-01,
                         -6.22674644e-01,  -6.22674644e-01,  -6.22790873e-01,
                         -6.22616529e-01,  -6.22384012e-01,  -6.22209668e-01,
                         -6.22093379e-01,  -6.21744633e-01,  -6.21279657e-01,
                         -6.20930910e-01,  -6.20698452e-01,  -6.20175302e-01,
                         -6.19768441e-01,  -6.19361579e-01,  -6.18605971e-01,
                         -6.18140996e-01,  -6.17617905e-01,  -6.16804183e-01,
                         -6.16164804e-01,  -6.15467370e-01,  -6.14537358e-01,
                         -6.13781750e-01,  -6.12851799e-01,  -6.11921847e-01,
                         -6.10991836e-01,  -6.10061884e-01,  -6.09073758e-01,
                         -6.07678831e-01,  -6.06632590e-01,  -6.05586410e-01,
                         -6.04075193e-01,  -6.02970839e-01,  -6.01692140e-01,
                         -6.00355268e-01,  -5.99192798e-01,  -5.97623467e-01,
                         -5.96170425e-01,  -5.94659209e-01,  -5.93147993e-01,
                         -5.91636777e-01,  -5.89893103e-01,  -5.88440001e-01,
                         -5.86928844e-01,  -5.85126996e-01,  -5.83499551e-01,
                         -5.81639588e-01,  -5.79779625e-01,  -5.78035951e-01,
                         -5.76175988e-01,  -5.74316084e-01,  -5.72223604e-01,
                         -5.70305586e-01,  -5.68445623e-01,  -5.66062570e-01,
                         -5.64028263e-01,  -5.62052071e-01,  -5.59901476e-01,
                         -5.57983398e-01,  -5.55832863e-01,  -5.53624153e-01,
                         -5.51357388e-01,  -5.49148679e-01,  -5.46823740e-01,
                         -5.44324458e-01,  -5.42173922e-01,  -5.39965212e-01,
                         -5.37349641e-01,  -5.34966588e-01,  -5.32699823e-01,
                         -5.30142367e-01,  -5.27526855e-01,  -5.24969399e-01,
                         -5.22528231e-01,  -5.19912660e-01,  -5.17239034e-01,
                         -5.14681578e-01,  -5.12007892e-01,  -5.09276092e-01,
                         -5.06602466e-01,  -5.04045010e-01,  -5.01313210e-01,
                         -4.98348951e-01,  -4.95500892e-01,  -4.92652863e-01,
                         -4.89862949e-01,  -4.87014920e-01,  -4.84225005e-01,
                         -4.81376946e-01,  -4.78354543e-01,  -4.75506514e-01,
                         -4.72658455e-01,  -4.69519794e-01,  -4.66555506e-01,
                         -4.63649362e-01,  -4.60568815e-01,  -4.57778901e-01,
                         -4.54698354e-01,  -4.51501578e-01,  -4.48595434e-01,
                         -4.45631146e-01,  -4.42492485e-01,  -4.39353824e-01,
                         -4.36273277e-01,  -4.33134645e-01,  -4.30112213e-01,
                         -4.27147925e-01,  -4.23951149e-01,  -4.20638144e-01,
                         -4.17499483e-01,  -4.14360821e-01,  -4.11280274e-01,
                         -4.08083498e-01,  -4.04712349e-01,  -4.01806176e-01,
                         -3.98667544e-01,  -3.95354509e-01,  -3.92332107e-01,
                         -3.89135301e-01,  -3.85938525e-01,  -3.82858008e-01,
                         -3.79603088e-01,  -3.76464456e-01,  -3.73267651e-01,
                         -3.69838387e-01,  -3.66641611e-01,  -3.63502949e-01,
                         -3.60306174e-01,  -3.57051283e-01,  -3.53680104e-01,
                         -3.50367099e-01,  -3.47054064e-01,  -3.43915403e-01,
                         -3.40718627e-01,  -3.37405592e-01,  -3.34150702e-01,
                         -3.30663294e-01,  -3.27350289e-01,  -3.24211627e-01,
                         -3.20840478e-01,  -3.17527443e-01,  -3.14330667e-01,
                         -3.11017632e-01,  -3.07646483e-01,  -3.04217219e-01,
                         -3.01078558e-01,  -2.97823668e-01,  -2.94452488e-01,
                         -2.91081339e-01,  -2.87768334e-01,  -2.84397185e-01,
                         -2.81200409e-01,  -2.78061748e-01,  -2.74806827e-01,
                         -2.71493822e-01,  -2.68238902e-01,  -2.64809638e-01,
                         -2.61554718e-01,  -2.58416086e-01,  -2.55044937e-01,
                         -2.51731902e-01,  -2.48535112e-01,  -2.45163962e-01,
                         -2.41909057e-01,  -2.38654166e-01,  -2.35515505e-01,
                         -2.32318729e-01,  -2.29005694e-01,  -2.25867033e-01,
                         -2.22612143e-01,  -2.19357237e-01,  -2.16160446e-01,
                         -2.12731183e-01,  -2.09592521e-01,  -2.06570119e-01,
                         -2.03315213e-01,  -2.00002179e-01,  -1.96689159e-01,
                         -1.93608627e-01,  -1.90528095e-01,  -1.87215060e-01,
                         -1.84018284e-01,  -1.80763379e-01,  -1.77566603e-01,
                         -1.74369827e-01,  -1.71056792e-01,  -1.67860016e-01,
                         -1.64605111e-01,  -1.61292091e-01,  -1.58211544e-01,
                         -1.55014768e-01,  -1.51701748e-01,  -1.48504958e-01,
                         -1.45250067e-01,  -1.41937032e-01,  -1.38682127e-01,
                         -1.35543481e-01,  -1.32288575e-01,  -1.28975540e-01,
                         -1.25720635e-01,  -1.22465737e-01,  -1.19210832e-01,
                         -1.16072178e-01,  -1.12875395e-01,  -1.09678619e-01,
                         -1.06365591e-01,  -1.03168808e-01,  -9.99720320e-02,
                         -9.67752486e-02,  -9.35784727e-02,  -9.03235674e-02,
                         -8.71267840e-02,  -8.39300081e-02,  -8.07332247e-02,
                         -7.74783269e-02,  -7.42234215e-02,  -7.11428896e-02,
                         -6.80042282e-02,  -6.46912009e-02,  -6.14944249e-02,
                         -5.84138893e-02,  -5.52171096e-02,  -5.20784520e-02,
                         -4.90560420e-02,  -4.59173843e-02,  -4.26624827e-02,
                         -3.95238250e-02,  -3.64432931e-02,  -3.31883878e-02,
                         -3.01078558e-02,  -2.70854458e-02,  -2.38886662e-02,
                         -2.07500085e-02,  -1.76113527e-02,  -1.45308180e-02,
                         -1.14502851e-02,  -8.19538161e-03,  -5.17297117e-03,
                         -1.97619130e-03,   1.22058869e-03,   4.30112239e-03,
                          7.43977912e-03,   1.05784358e-02,   1.37752155e-02,
                          1.67976264e-02,   1.96456667e-02,   2.30168160e-02,
                          2.61554737e-02,   2.91197598e-02,   3.23165394e-02,
                          3.52227055e-02,   3.83032374e-02,   4.16162647e-02,
                          4.45224270e-02,   4.76610847e-02,   5.08578643e-02,
                          5.38802743e-02,   5.70189320e-02,   5.99832200e-02,
                          6.30637482e-02,   6.62024096e-02,   6.92829415e-02,
                          7.22472295e-02,   7.53277615e-02,   7.84664154e-02,
                          8.14307034e-02,   8.45693648e-02,   8.76498967e-02,
                          9.04979333e-02,   9.34622213e-02,   9.66008827e-02,
                          9.96232927e-02,   1.02703825e-01,   1.05609991e-01,
                          1.08574271e-01,   1.11480437e-01,   1.14386603e-01,
                          1.17467135e-01,   1.20373301e-01,   1.23279460e-01,
                          1.26127496e-01,   1.28917426e-01,   1.31997958e-01,
                          1.34904116e-01,   1.37694031e-01,   1.40658319e-01,
                          1.43506363e-01,   1.46412522e-01,   1.49376810e-01,
                          1.52166724e-01,   1.55072898e-01,   1.57979056e-01,
                          1.60827100e-01,   1.63791388e-01,   1.66523173e-01,
                          1.69313088e-01,   1.72219262e-01,   1.75125420e-01,
                          1.77857220e-01,   1.80589005e-01,   1.83495179e-01,
                          1.86226964e-01,   1.88900635e-01,   1.91690549e-01,
                          1.94480479e-01,   1.97386637e-01,   2.00176552e-01,
                          2.02792108e-01,   2.05582023e-01,   2.08255693e-01,
                          2.11045608e-01,   2.13893652e-01,   2.16567323e-01,
                          2.19299108e-01,   2.21914664e-01,   2.24762693e-01,
                          2.27668867e-01,   2.30342537e-01,   2.33248696e-01,
                          2.36038610e-01,   2.38712281e-01,   2.41560325e-01,
                          2.44059622e-01,   2.46791422e-01,   2.49523208e-01,
                          2.51848131e-01,   2.54521817e-01,   2.57195473e-01,
                          2.59694785e-01,   2.62426585e-01,   2.65100241e-01,
                          2.67657667e-01,   2.70273209e-01,   2.72830635e-01,
                          2.75329947e-01,   2.77713001e-01,   2.80328542e-01,
                          2.82885969e-01,   2.85501510e-01,   2.88117081e-01,
                          2.90558249e-01,   2.92999417e-01,   2.95556843e-01,
                          2.97881782e-01,   3.00322950e-01,   3.02706003e-01,
                          3.05089056e-01,   3.07472110e-01,   3.09855163e-01,
                          3.12412590e-01,   3.14737529e-01,   3.16946208e-01,
                          3.19503635e-01,   3.21828574e-01,   3.24153483e-01,
                          3.26652795e-01,   3.28977734e-01,   3.31244528e-01,
                          3.33511353e-01,   3.35836262e-01,   3.38044971e-01,
                          3.40311766e-01,   3.42752934e-01,   3.44845384e-01,
                          3.46879691e-01,   3.49204630e-01,   3.51529568e-01,
                          3.53680104e-01,   3.55772555e-01,   3.58097494e-01,
                          3.60422432e-01,   3.62572968e-01,   3.64665419e-01,
                          3.66757870e-01,   3.69024664e-01,   3.71233344e-01,
                          3.73267651e-01,   3.75301987e-01,   3.77220035e-01,
                          3.79428715e-01,   3.81695539e-01,   3.83555472e-01,
                          3.85706037e-01,   3.87566000e-01,   3.89484048e-01,
                          3.91867101e-01,   3.93785179e-01,   3.95645112e-01,
                          3.97795677e-01,   3.99597496e-01,   4.01457459e-01,
                          4.03433651e-01,   4.05235469e-01,   4.07211661e-01,
                          4.09129709e-01,   4.10815299e-01,   4.12442744e-01,
                          4.14418936e-01,   4.16220754e-01,   4.17906344e-01,
                          4.19708163e-01,   4.21393722e-01,   4.23137426e-01,
                          4.24939245e-01,   4.26450461e-01,   4.28136021e-01,
                          4.29879725e-01,   4.31507170e-01,   4.33076501e-01,
                          4.34703976e-01,   4.36389536e-01,   4.37900752e-01,
                          4.39411938e-01,   4.40923154e-01,   4.42550600e-01,
                          4.44236189e-01,   4.45631146e-01,   4.47084218e-01,
                          4.48711663e-01,   4.50164765e-01,   4.51559722e-01,
                          4.52896535e-01,   4.54175264e-01,   4.55628335e-01,
                          4.56965178e-01,   4.58418250e-01,   4.59755093e-01,
                          4.60975677e-01,   4.62370634e-01,   4.63591218e-01,
                          4.64928061e-01,   4.66381133e-01,   4.67485487e-01,
                          4.68822330e-01,   4.70101029e-01,   4.71321613e-01,
                          4.72542226e-01,   4.73472178e-01,   4.74809021e-01,
                          4.76145864e-01,   4.76901472e-01,   4.78180170e-01,
                          4.79342639e-01,   4.80214477e-01,   4.81493205e-01,
                          4.82423156e-01,   4.83411252e-01,   4.84515607e-01,
                          4.85329330e-01,   4.86375540e-01,   4.87363636e-01,
                          4.88351732e-01,   4.89281714e-01,   4.89979208e-01,
                          4.91025418e-01,   4.92071629e-01,   4.92827237e-01,
                          4.93640959e-01,   4.94338453e-01,   4.95035917e-01,
                          4.95791525e-01,   4.96605247e-01,   4.97593343e-01,
                          4.98174578e-01,   4.98813927e-01,   4.99569535e-01,
                          5.00150740e-01,   5.00906348e-01,   5.01603842e-01,
                          5.02243221e-01,   5.02824426e-01,   5.03289402e-01,
                          5.03986895e-01,   5.04509985e-01,   5.05033135e-01,
                          5.05614340e-01,   5.06021202e-01,   5.06486177e-01,
                          5.06951213e-01,   5.07416189e-01,   5.07706821e-01,
                          5.08171797e-01,   5.08753002e-01,   5.09101748e-01,
                          5.09508610e-01,   5.10031700e-01,   5.10206103e-01,
                          5.10612965e-01,   5.11019826e-01,   5.11136055e-01,
                          5.11368573e-01,   5.11601031e-01,   5.11949778e-01,
                          5.12356639e-01,   5.12531042e-01,   5.12589157e-01,
                          5.12763500e-01,   5.12996018e-01,   5.13112247e-01,
                          5.13286650e-01,   5.13577223e-01,   5.13577223e-01,
                          5.13751626e-01,   5.13867855e-01,   5.14042258e-01,
                          5.14274716e-01,   5.14216602e-01,   5.14216602e-01,
                          5.14449120e-01,   5.14274716e-01,   5.14332831e-01,
                          5.14332831e-01,   5.14216602e-01,   5.14332831e-01,
                          5.14274716e-01,   5.14158487e-01,   5.14158487e-01,
                          5.14042258e-01,   5.14100373e-01,   5.13984084e-01,
                          5.13867855e-01,   5.13867855e-01,   5.13577223e-01,
                          5.13460994e-01,   5.13170362e-01,   5.12996018e-01,
                          5.12996018e-01,   5.12647271e-01,   5.12414753e-01,
                          5.12182295e-01,   5.11833549e-01,   5.11659205e-01,
                          5.11310458e-01,   5.11077940e-01,   5.11077940e-01,
                          5.10612965e-01,   5.10206103e-01,   5.09857357e-01,
                          5.09392381e-01,   5.09159863e-01,   5.08869231e-01,
                          5.08520544e-01,   5.07997394e-01,   5.07474303e-01,
                          5.07299960e-01,   5.06834924e-01,   5.06369948e-01,
                          5.06021202e-01,   5.05498111e-01,   5.05091250e-01,
                          5.04626274e-01,   5.04045010e-01,   5.03638148e-01,
                          5.02998829e-01,   5.02359450e-01,   5.01894474e-01,
                          5.01429498e-01,   5.01022637e-01,   5.00441372e-01,
                          4.99685794e-01,   4.99162674e-01,   4.98697698e-01,
                          4.98116463e-01,   4.97535229e-01,   4.96895850e-01,
                          4.96198386e-01,   4.95500892e-01,   4.94861543e-01,
                          4.94105935e-01,   4.93408471e-01,   4.92710978e-01,
                          4.92013514e-01,   4.91374165e-01,   4.90502298e-01,
                          4.89746690e-01,   4.89223599e-01,   4.88351732e-01,
                          4.87421781e-01,   4.86608058e-01,   4.85678077e-01,
                          4.84689981e-01,   4.84050632e-01,   4.83295023e-01,
                          4.82365042e-01,   4.81318831e-01,   4.80388850e-01,
                          4.79458869e-01,   4.78470773e-01,   4.77540821e-01,
                          4.76610839e-01,   4.75622743e-01,   4.74460274e-01,
                          4.73414063e-01,   4.72309709e-01,   4.71205384e-01,
                          4.70217288e-01,   4.69171077e-01,   4.67950463e-01,
                          4.66787994e-01,   4.65625554e-01,   4.64579314e-01,
                          4.63358730e-01,   4.62080032e-01,   4.60917562e-01,
                          4.59580719e-01,   4.58302021e-01,   4.57197666e-01,
                          4.55918968e-01,   4.54698354e-01,   4.53419656e-01,
                          4.51966584e-01,   4.50746000e-01,   4.49467272e-01,
                          4.47897941e-01,   4.46502984e-01,   4.45166141e-01,
                          4.43654954e-01,   4.42201853e-01,   4.40806895e-01,
                          4.39295709e-01,   4.37784493e-01,   4.36389536e-01,
                          4.34878320e-01,   4.33483362e-01,   4.31914032e-01,
                          4.30112213e-01,   4.28659141e-01,   4.27147925e-01,
                          4.25404251e-01,   4.23718661e-01,   4.22149330e-01,
                          4.20347512e-01,   4.18603808e-01,   4.16976362e-01,
                          4.15232658e-01,   4.13488954e-01,   4.11745280e-01,
                          4.09652829e-01,   4.07851011e-01,   4.06281680e-01,
                          4.04421747e-01,   4.02503669e-01,   4.00469363e-01,
                          3.98667544e-01,   3.96923840e-01,   3.94715160e-01,
                          3.92797083e-01,   3.90879005e-01,   3.88670325e-01,
                          3.86752248e-01,   3.84601712e-01,   3.82509261e-01,
                          3.80533069e-01,   3.78382504e-01,   3.76348197e-01,
                          3.74023259e-01,   3.71756464e-01,   3.69722128e-01,
                          3.67339075e-01,   3.65130395e-01,   3.63096088e-01,
                          3.60713035e-01,   3.58504355e-01,   3.56295675e-01,
                          3.53970736e-01,   3.51529568e-01,   3.48972142e-01,
                          3.46705317e-01,   3.44322264e-01,   3.41764838e-01,
                          3.39381784e-01,   3.36998731e-01,   3.34441304e-01,
                          3.31942022e-01,   3.29442710e-01,   3.27059656e-01,
                          3.24560344e-01,   3.21828574e-01,   3.19387376e-01,
                          3.16946208e-01,   3.14388782e-01,   3.11773241e-01,
                          3.09041440e-01,   3.06425899e-01,   3.03926587e-01,
                          3.01136672e-01,   2.98404872e-01,   2.95847476e-01,
                          2.93057531e-01,   2.90325761e-01,   2.87710190e-01,
                          2.84862161e-01,   2.82072246e-01,   2.79282331e-01,
                          2.76318043e-01,   2.73353755e-01,   2.70447582e-01,
                          2.67657667e-01,   2.64809638e-01,   2.61787236e-01,
                          2.58939177e-01,   2.56091148e-01,   2.53184974e-01,
                          2.50336945e-01,   2.47256398e-01,   2.44059622e-01,
                          2.40979090e-01,   2.38014802e-01,   2.35050514e-01,
                          2.31795609e-01,   2.28598833e-01,   2.25518301e-01,
                          2.22205281e-01,   2.19124734e-01,   2.16102332e-01,
                          2.12789297e-01,   2.09708765e-01,   2.06453860e-01,
                          2.03024596e-01,   1.99827820e-01,   1.96747273e-01,
                          1.93608627e-01,   1.90237477e-01,   1.86808199e-01,
                          1.83495179e-01,   1.80182144e-01,   1.76985368e-01,
                          1.73672348e-01,   1.70126826e-01,   1.66813791e-01,
                          1.63500771e-01,   1.60013378e-01,   1.56525970e-01,
                          1.53271079e-01,   1.49958044e-01,   1.46412522e-01,
                          1.43041372e-01,   1.39612108e-01,   1.36066586e-01,
                          1.32695436e-01,   1.29149914e-01,   1.25662521e-01,
                          1.22233242e-01,   1.18803971e-01,   1.15200326e-01,
                          1.11596689e-01,   1.08225532e-01,   1.04796261e-01,
                          1.01018250e-01,   9.72983614e-02,   9.38690901e-02,
                          9.02654454e-02,   8.66618007e-02,   8.31744075e-02,
                          7.96288848e-02,   7.60252401e-02,   7.23634735e-02,
                          6.87017068e-02,   6.51561916e-02,   6.15525469e-02,
                          5.77745326e-02,   5.41708916e-02,   5.04510030e-02,
                          4.67892364e-02,   4.31274697e-02,   3.92332077e-02,
                          3.55133191e-02,   3.18515524e-02,   2.81316638e-02,
                          2.45861448e-02,   2.08662543e-02,   1.70882419e-02,
                          1.34264762e-02,   9.53221694e-03,   5.75420400e-03,
                          1.97619130e-03,  -1.97619130e-03,  -5.57983434e-03,
                         -9.12535377e-03,  -1.29033662e-02,  -1.67395025e-02,
                         -2.06337627e-02,  -2.44117752e-02,  -2.80735418e-02,
                         -3.16771828e-02,  -3.53970751e-02,  -3.91750857e-02,
                         -4.29531001e-02,  -4.67311107e-02,  -5.05091250e-02,
                         -5.42290136e-02,  -5.79489022e-02,  -6.14362992e-02,
                         -6.51561916e-02,  -6.91085756e-02,  -7.27122128e-02,
                         -7.64321014e-02,  -8.03263634e-02,  -8.38718861e-02,
                         -8.75336528e-02,  -9.12535414e-02,  -9.50315520e-02,
                         -9.89258140e-02,  -1.02355085e-01,  -1.06074974e-01,
                         -1.09969236e-01,  -1.13514751e-01,  -1.17234640e-01,
                         -1.21012658e-01,  -1.24674425e-01,  -1.28626809e-01,
                         -1.32521063e-01,  -1.36182830e-01,  -1.39902726e-01,
                         -1.43506363e-01,  -1.47051886e-01,  -1.50771767e-01,
                         -1.54607907e-01,  -1.58153430e-01,  -1.61989570e-01,
                         -1.65767580e-01,  -1.69313088e-01,  -1.72974855e-01,
                         -1.76578507e-01,  -1.80472761e-01,  -1.84308901e-01,
                         -1.87680051e-01,  -1.91458061e-01,  -1.95177957e-01,
                         -1.98723465e-01,  -2.02443361e-01,  -2.06105128e-01,
                         -2.09883139e-01,  -2.13544905e-01,  -2.16916054e-01,
                         -2.20752195e-01,  -2.24413961e-01,  -2.27843225e-01,
                         -2.31504992e-01,  -2.35108644e-01,  -2.38886654e-01,
                         -2.42374048e-01,  -2.45803326e-01,  -2.49465093e-01,
                         -2.53010601e-01,  -2.56556123e-01,  -2.60101646e-01,
                         -2.63647169e-01,  -2.67308921e-01,  -2.70738214e-01,
                         -2.74167478e-01,  -2.77654886e-01,  -2.81026036e-01,
                         -2.84513414e-01,  -2.88117081e-01,  -2.91778833e-01,
                         -2.95208097e-01,  -2.98521131e-01,  -3.02008539e-01,
                         -3.05612177e-01,  -3.08925211e-01,  -3.12296361e-01,
                         -3.15841854e-01,  -3.19213003e-01,  -3.22526038e-01,
                         -3.26013446e-01,  -3.29384595e-01,  -3.32697630e-01,
                         -3.36185008e-01,  -3.39788646e-01,  -3.43159795e-01,
                         -3.46298456e-01,  -3.49611491e-01,  -3.53098899e-01,
                         -3.56411904e-01,  -3.59841198e-01,  -3.63270462e-01,
                         -3.66467237e-01,  -3.69722128e-01,  -3.73093277e-01,
                         -3.76348197e-01,  -3.79603088e-01,  -3.82741749e-01,
                         -3.86054784e-01,  -3.89658421e-01,  -3.93029571e-01,
                         -3.96400720e-01,  -3.99597496e-01,  -4.02619928e-01,
                         -4.05874819e-01,  -4.09129709e-01,  -4.12268370e-01,
                         -4.15407032e-01,  -4.18487579e-01,  -4.21568096e-01,
                         -4.24706757e-01,  -4.27845418e-01,  -4.30809706e-01,
                         -4.33948368e-01,  -4.37087029e-01,  -4.39876944e-01,
                         -4.42899346e-01,  -4.45979863e-01,  -4.48827922e-01,
                         -4.51792210e-01,  -4.54814613e-01,  -4.57662642e-01,
                         -4.60510701e-01,  -4.63416845e-01,  -4.66206789e-01,
                         -4.68996704e-01,  -4.71844733e-01,  -4.74634647e-01,
                         -4.77308333e-01,  -4.80098248e-01,  -4.82713789e-01,
                         -4.85387444e-01,  -4.88235503e-01,  -4.90792930e-01,
                         -4.93350357e-01,  -4.96024013e-01,  -4.98581439e-01,
                         -5.01196980e-01,  -5.03696263e-01,  -5.06311834e-01,
                         -5.08927405e-01,  -5.11252284e-01,  -5.13809741e-01,
                         -5.16657770e-01,  -5.19098938e-01,  -5.21307647e-01,
                         -5.23748815e-01,  -5.26248097e-01,  -5.28514922e-01,
                         -5.30781746e-01,  -5.33164799e-01,  -5.35431623e-01,
                         -5.37756503e-01,  -5.39965212e-01,  -5.41999519e-01,
                         -5.44382572e-01,  -5.46533167e-01,  -5.48625588e-01,
                         -5.50950527e-01,  -5.52984834e-01,  -5.55019140e-01,
                         -5.57285964e-01,  -5.59320271e-01,  -5.61412692e-01,
                         -5.63446999e-01,  -5.65306962e-01,  -5.67108750e-01,
                         -5.68968713e-01,  -5.70770562e-01,  -5.72630465e-01,
                         -5.74490428e-01,  -5.76175988e-01,  -5.78152180e-01,
                         -5.79895914e-01,  -5.81290841e-01,  -5.83034575e-01,
                         -5.84836364e-01,  -5.86347580e-01,  -5.87975025e-01,
                         -5.89370012e-01,  -5.90648711e-01,  -5.91927409e-01,
                         -5.93438625e-01,  -5.95007956e-01,  -5.96286654e-01,
                         -5.97565353e-01,  -5.99018455e-01,  -6.00239038e-01,
                         -6.01343393e-01,  -6.02563977e-01,  -6.03842676e-01,
                         -6.04947031e-01,  -6.05993271e-01,  -6.07213855e-01,
                         -6.08260036e-01,  -6.09190047e-01,  -6.10352516e-01,
                         -6.11166239e-01,  -6.12038076e-01,  -6.13026142e-01,
                         -6.13839865e-01,  -6.14711761e-01,  -6.15583599e-01,
                         -6.16397321e-01,  -6.17036700e-01,  -6.17617905e-01,
                         -6.18547857e-01,  -6.19012833e-01,  -6.19419754e-01,
                         -6.20175302e-01,  -6.20872796e-01,  -6.21395946e-01,
                         -6.21919036e-01,  -6.22151494e-01,  -6.22616529e-01,
                         -6.22790873e-01,  -6.23081505e-01,  -6.23430252e-01,
                         -6.23488367e-01,  -6.23778999e-01,  -6.23953342e-01,
                         -6.24127686e-01,  -6.24418318e-01,  -6.24302089e-01,
                         -6.24360204e-01,  -6.24360204e-01,  -6.24185860e-01,
                         -6.24302089e-01,  -6.24011457e-01,  -6.24011457e-01,
                         -6.23895228e-01,  -6.23488367e-01,  -6.23488367e-01,
                         -6.23139620e-01,  -6.22558355e-01,  -6.22267783e-01,
                         -6.21860921e-01,  -6.21454060e-01,  -6.20814681e-01,
                         -6.20349705e-01,  -6.19826615e-01,  -6.19071007e-01,
                         -6.18722260e-01,  -6.17908537e-01,  -6.16978526e-01,
                         -6.16397321e-01,  -6.15467370e-01,  -6.14711761e-01,
                         -6.13956153e-01,  -6.12851799e-01,  -6.12038076e-01,
                         -6.11166239e-01,  -6.10294342e-01,  -6.09131932e-01,
                         -6.07911289e-01,  -6.07039452e-01,  -6.05702639e-01,
                         -6.04423940e-01,  -6.03493929e-01,  -6.02040887e-01,
                         -6.00820303e-01,  -5.99541545e-01,  -5.98088503e-01,
                         -5.96809745e-01,  -5.95414817e-01,  -5.94078004e-01,
                         -5.92508674e-01,  -5.90939343e-01,  -5.89602470e-01,
                         -5.87858796e-01,  -5.86115062e-01,  -5.84487617e-01,
                         -5.82627714e-01,  -5.81058383e-01,  -5.79314649e-01,
                         -5.77454746e-01,  -5.75769126e-01,  -5.73792934e-01,
                         -5.71874917e-01,  -5.70189297e-01,  -5.68154991e-01,
                         -5.66120684e-01,  -5.64260721e-01,  -5.62110186e-01,
                         -5.60075879e-01,  -5.58041573e-01,  -5.55949092e-01,
                         -5.53972900e-01,  -5.51473618e-01,  -5.49032450e-01,
                         -5.47172487e-01,  -5.45021951e-01,  -5.42348266e-01,
                         -5.39907098e-01,  -5.37582159e-01,  -5.35199106e-01,
                         -5.32932281e-01,  -5.30432999e-01,  -5.27701199e-01,
                         -5.25143802e-01,  -5.22702575e-01,  -5.20203292e-01,
                         -5.17645895e-01,  -5.14972210e-01,  -5.12124181e-01,
                         -5.09566724e-01,  -5.06893039e-01,  -5.04045010e-01,
                         -5.01313210e-01,  -4.98523325e-01,  -4.95559037e-01,
                         -4.92885351e-01,  -4.90095437e-01,  -4.87131149e-01,
                         -4.84225005e-01,  -4.81318831e-01,  -4.78470773e-01,
                         -4.75680858e-01,  -4.72774714e-01,  -4.69868541e-01,
                         -4.66904253e-01,  -4.63765591e-01,  -4.60917562e-01,
                         -4.58185762e-01,  -4.55105245e-01,  -4.52024698e-01,
                         -4.49176669e-01,  -4.45979863e-01,  -4.42724973e-01,
                         -4.39993173e-01,  -4.37087029e-01,  -4.33773994e-01,
                         -4.30867821e-01,  -4.27903533e-01,  -4.24706757e-01,
                         -4.21742469e-01,  -4.18603808e-01,  -4.15348917e-01,
                         -4.12210256e-01,  -4.09071594e-01,  -4.05874819e-01,
                         -4.02794272e-01,  -3.99597496e-01,  -3.96400720e-01,
                         -3.93320203e-01,  -3.90007168e-01,  -3.86577904e-01,
                         -3.83381099e-01,  -3.80184323e-01,  -3.77045661e-01,
                         -3.73965144e-01,  -3.70477736e-01,  -3.67164731e-01,
                         -3.63793582e-01,  -3.60073686e-01,  -3.56876910e-01,
                         -3.53738248e-01,  -3.50192726e-01,  -3.46879691e-01,
                         -3.43682915e-01,  -3.40311766e-01,  -3.36998731e-01,
                         -3.33743840e-01,  -3.30547065e-01,  -3.27175915e-01,
                         -3.23804766e-01,  -3.20607990e-01,  -3.17353070e-01,
                         -3.13981920e-01,  -3.10727030e-01,  -3.07297736e-01,
                         -3.03810358e-01,  -3.00613582e-01,  -2.97358662e-01,
                         -2.94045627e-01,  -2.90790737e-01,  -2.87593961e-01,
                         -2.84280926e-01,  -2.81084150e-01,  -2.77771115e-01,
                         -2.74458110e-01,  -2.71203190e-01,  -2.68064529e-01,
                         -2.64867753e-01,  -2.61438489e-01,  -2.58299828e-01,
                         -2.55277425e-01,  -2.51906276e-01,  -2.48593241e-01,
                         -2.45338336e-01,  -2.42083430e-01,  -2.38828525e-01,
                         -2.35515505e-01,  -2.32318729e-01,  -2.29121938e-01,
                         -2.25808918e-01,  -2.22612143e-01,  -2.19299108e-01,
                         -2.16044202e-01,  -2.12905556e-01,  -2.09708765e-01,
                         -2.06511989e-01,  -2.03257084e-01,  -1.99885935e-01,
                         -1.96572915e-01,  -1.93318009e-01,  -1.90295592e-01,
                         -1.87156945e-01,  -1.83902040e-01,  -1.80821508e-01,
                         -1.77566603e-01,  -1.74195454e-01,  -1.70940548e-01,
                         -1.67627513e-01,  -1.64372623e-01,  -1.61117718e-01,
                         -1.57979056e-01,  -1.54782280e-01,  -1.51643619e-01,
                         -1.48679331e-01,  -1.45366311e-01,  -1.42111406e-01,
                         -1.38972744e-01,  -1.35659724e-01,  -1.32637307e-01,
                         -1.29556775e-01,  -1.26301870e-01,  -1.23105094e-01,
                         -1.19850188e-01,  -1.16827779e-01,  -1.13689125e-01,
                         -1.10434219e-01,  -1.07469931e-01,  -1.04215026e-01,
                         -1.01076372e-01,  -9.81120840e-02,  -9.47990566e-02,
                         -9.18347687e-02,  -8.88123587e-02,  -8.56155828e-02,
                         -8.26512948e-02,  -7.95126408e-02,  -7.63158575e-02,
                         -7.33515695e-02,  -7.03291595e-02,  -6.72486275e-02,
                         -6.41680956e-02,  -6.12619296e-02,  -5.82395196e-02,
                         -5.50427400e-02,  -5.20784520e-02,  -4.89979200e-02,
                         -4.59173843e-02,  -4.28949744e-02,  -3.99306901e-02,
                         -3.70245241e-02,  -3.37696224e-02,  -3.08634583e-02,
                         -2.80154180e-02,  -2.48186383e-02,  -2.17381045e-02,
                         -1.88319404e-02,  -1.59257762e-02,  -1.28452433e-02,
                         -9.70658660e-03,  -7.09103933e-03,  -4.06862935e-03,
                         -9.29972390e-04,   1.80182152e-03,   4.94047813e-03,
                          7.78851844e-03,   1.07528055e-02,   1.41820787e-02,
                          1.70301199e-02,   1.99362822e-02,   2.28424463e-02,
                          2.56904867e-02,   2.89453901e-02,   3.18515524e-02,
                          3.46995927e-02,   3.77220027e-02,   4.05119210e-02,
                          4.35343310e-02,   4.63823713e-02,   4.92885374e-02,
                          5.21946996e-02,   5.50427400e-02,   5.80651499e-02,
                          6.08550683e-02,   6.37612343e-02,   6.66673928e-02,
                          6.92829415e-02,   7.24215955e-02,   7.53277615e-02,
                          7.79433101e-02,   8.07913467e-02,   8.34650174e-02,
                          8.63130614e-02,   8.92773494e-02,   9.20672640e-02,
                          9.49734300e-02,   9.76471007e-02,   1.00378893e-01,
                          1.03168808e-01,   1.05958730e-01,   1.08806767e-01,
                          1.11364193e-01,   1.13979742e-01,   1.16885900e-01,
                          1.19559571e-01,   1.22175120e-01,   1.24906912e-01,
                          1.27696827e-01,   1.30428627e-01,   1.33102298e-01,
                          1.35892212e-01,   1.38682127e-01,   1.41413927e-01,
                          1.44203842e-01,   1.46819383e-01,   1.49434939e-01,
                          1.52166724e-01,   1.54956654e-01,   1.57572195e-01,
                          1.60245866e-01,   1.63035780e-01,   1.65651336e-01,
                          1.68325007e-01,   1.71173036e-01,   1.73730463e-01,
                          1.76346019e-01,   1.79135934e-01,   1.81751475e-01,
                          1.84308901e-01,   1.86982572e-01,   1.89714357e-01,
                          1.92388028e-01,   1.95119828e-01,   1.97677255e-01,
                          2.00234681e-01,   2.02966467e-01,   2.05640137e-01,
                          2.08255693e-01,   2.10754991e-01,   2.13196173e-01,
                          2.15811715e-01,   2.18427256e-01,   2.20868438e-01,
                          2.23367736e-01,   2.26041406e-01,   2.28424460e-01,
                          2.30865642e-01,   2.33597443e-01,   2.35980496e-01,
                          2.38305420e-01,   2.40979090e-01,   2.43594632e-01,
                          2.45977700e-01,   2.48418868e-01,   2.50918180e-01,
                          2.53359348e-01,   2.55800515e-01,   2.58125454e-01,
                          2.60624766e-01,   2.63298422e-01,   2.65565246e-01,
                          2.67890155e-01,   2.70505726e-01,   2.72772521e-01,
                          2.75213689e-01,   2.77771115e-01,   2.80154169e-01,
                          2.82362849e-01,   2.84745902e-01,   2.87187099e-01,
                          2.89628267e-01,   2.92011321e-01,   2.94394374e-01,
                          2.96777427e-01,   2.99160480e-01,   3.01543534e-01,
                          3.03868473e-01,   3.06251526e-01,   3.08634579e-01,
                          3.10959518e-01,   3.13284457e-01,   3.15551251e-01,
                          3.17992419e-01,   3.20317358e-01,   3.22409809e-01,
                          3.24792862e-01,   3.27059656e-01,   3.29326481e-01,
                          3.31651390e-01,   3.33918214e-01,   3.36126894e-01,
                          3.38393688e-01,   3.40544254e-01,   3.42694819e-01,
                          3.44961613e-01,   3.47228438e-01,   3.49262744e-01,
                          3.51529568e-01,   3.53680104e-01,   3.55656296e-01,
                          3.57923120e-01,   3.60015541e-01,   3.62166107e-01,
                          3.64200443e-01,   3.66176635e-01,   3.68385315e-01,
                          3.70303363e-01,   3.72221440e-01,   3.74430120e-01,
                          3.76464456e-01,   3.78498763e-01,   3.80591184e-01,
                          3.82567376e-01,   3.84659827e-01,   3.86461645e-01,
                          3.88263464e-01,   3.90297771e-01,   3.92332107e-01,
                          3.94366413e-01,   3.96168232e-01,   3.97970051e-01,
                          4.00062501e-01,   4.02038693e-01,   4.03840512e-01,
                          4.05816704e-01,   4.07618523e-01,   4.09478456e-01,
                          4.11454648e-01,   4.13256466e-01,   4.15058285e-01,
                          4.17092621e-01,   4.19010669e-01,   4.20638144e-01,
                          4.22323704e-01,   4.24241781e-01,   4.26101714e-01,
                          4.27787304e-01,   4.29472864e-01,   4.31390941e-01,
                          4.33250874e-01,   4.34762090e-01,   4.36563909e-01,
                          4.38307613e-01,   4.39818799e-01,   4.41504389e-01,
                          4.43189949e-01,   4.44991767e-01,   4.46735471e-01,
                          4.48188573e-01,   4.49641645e-01,   4.51094717e-01,
                          4.52605933e-01,   4.54175264e-01,   4.55744594e-01,
                          4.57430154e-01,   4.58825111e-01,   4.60278213e-01,
                          4.61789399e-01,   4.62835640e-01,   4.64172453e-01,
                          4.65741783e-01,   4.67020512e-01,   4.68415469e-01,
                          4.69752282e-01,   4.71031010e-01,   4.72367853e-01,
                          4.73646551e-01,   4.74983394e-01,   4.76320237e-01,
                          4.77424562e-01,   4.78412658e-01,   4.79633242e-01,
                          4.80853856e-01,   4.82016295e-01,   4.83295023e-01,
                          4.84457493e-01,   4.85445589e-01,   4.86608058e-01,
                          4.87654269e-01,   4.88758594e-01,   4.89804834e-01,
                          4.90792930e-01,   4.91897255e-01,   4.92827237e-01,
                          4.93989706e-01,   4.95152175e-01,   4.95907784e-01,
                          4.96895850e-01,   4.97825831e-01,   4.98581439e-01,
                          4.99685794e-01,   5.00557601e-01,   5.01255095e-01,
                          5.02126932e-01,   5.02882540e-01,   5.03696263e-01,
                          5.04509985e-01,   5.05498111e-01,   5.06195605e-01,
                          5.06660581e-01,   5.07474303e-01,   5.08171797e-01,
                          5.08811116e-01,   5.09624839e-01,   5.10147989e-01,
                          5.10729194e-01,   5.11310458e-01,   5.11833549e-01,
                          5.12472928e-01,   5.12996018e-01,   5.13402879e-01,
                          5.13693511e-01,   5.14158487e-01,   5.14739692e-01,
                          5.14972210e-01,   5.15379071e-01,   5.15960276e-01,
                          5.16134679e-01,   5.16483426e-01,   5.16832173e-01,
                          5.16948402e-01,   5.17413378e-01,   5.17529607e-01,
                          5.17587721e-01,   5.17936468e-01,   5.17936468e-01,
                          5.18285215e-01,   5.18517733e-01,   5.18575847e-01,
                          5.18808365e-01,   5.18866479e-01,   5.19040823e-01,
                          5.19098938e-01,   5.19040823e-01,   5.19215226e-01,
                          5.19273341e-01,   5.19331455e-01,   5.19447684e-01,
                          5.19505799e-01,   5.19563913e-01,   5.19273341e-01,
                          5.19273341e-01,   5.19447684e-01,   5.19273341e-01,
                          5.19273341e-01,   5.19040823e-01,   5.18924594e-01,
                          5.18866479e-01,   5.18517733e-01,   5.18517733e-01,
                          5.18168986e-01,   5.17820239e-01,   5.17994642e-01,
                          5.17762125e-01,   5.17529607e-01,   5.17413378e-01,
                          5.17180860e-01,   5.16948402e-01,   5.16483426e-01,
                          5.16309023e-01,   5.16134679e-01,   5.15669703e-01,
                          5.15437186e-01,   5.14972210e-01,   5.14623463e-01,
                          5.14390945e-01,   5.13809741e-01,   5.13402879e-01,
                          5.13054132e-01,   5.12531042e-01,   5.12007892e-01,
                          5.11542916e-01,   5.11194170e-01,   5.10671079e-01,
                          5.10031700e-01,   5.09566724e-01,   5.09043634e-01,
                          5.08462369e-01,   5.07823050e-01,   5.07125556e-01,
                          5.06602466e-01,   5.06079316e-01,   5.05498111e-01,
                          5.04684389e-01,   5.03812551e-01,   5.03289402e-01,
                          5.02650082e-01,   5.01952589e-01,   5.01255095e-01,
                          5.00383258e-01,   4.99627650e-01,   4.98872042e-01,
                          4.98290837e-01,   4.97651458e-01,   4.96779621e-01,
                          4.96082127e-01,   4.95326549e-01,   4.94338453e-01,
                          4.93582845e-01,   4.92885351e-01,   4.92071629e-01,
                          4.91083533e-01,   4.90386069e-01,   4.89804834e-01,
                          4.88642365e-01,   4.87712383e-01,   4.86898661e-01,
                          4.85852450e-01,   4.84864354e-01,   4.83818114e-01,
                          4.82888162e-01,   4.81900066e-01,   4.80911970e-01,
                          4.80040103e-01,   4.78877664e-01,   4.77715194e-01,
                          4.76668954e-01,   4.75564629e-01,   4.74518418e-01,
                          4.73472178e-01,   4.72251594e-01,   4.71147269e-01,
                          4.69984800e-01,   4.68706071e-01,   4.67369229e-01,
                          4.66206789e-01,   4.65044320e-01,   4.63649362e-01,
                          4.62254405e-01,   4.60975677e-01,   4.59755093e-01,
                          4.58476394e-01,   4.57139552e-01,   4.55860823e-01,
                          4.54407752e-01,   4.52896535e-01,   4.51559722e-01,
                          4.50164765e-01,   4.48827922e-01,   4.47432965e-01,
                          4.45805520e-01,   4.44352418e-01,   4.42783087e-01,
                          4.41097528e-01,   4.39702570e-01,   4.38075125e-01,
                          4.36563909e-01,   4.34936464e-01,   4.33192760e-01,
                          4.31797802e-01,   4.30286586e-01,   4.28601027e-01,
                          4.26857322e-01,   4.25055504e-01,   4.23486173e-01,
                          4.21742469e-01,   4.19998765e-01,   4.18371320e-01,
                          4.16453242e-01,   4.14651424e-01,   4.12791491e-01,
                          4.11047786e-01,   4.09420341e-01,   4.07560378e-01,
                          4.05758560e-01,   4.03840512e-01,   4.01748061e-01,
                          3.99946243e-01,   3.98028165e-01,   3.96051973e-01,
                          3.94133925e-01,   3.92041475e-01,   3.89949054e-01,
                          3.88030976e-01,   3.85996670e-01,   3.83846104e-01,
                          3.81753653e-01,   3.79835606e-01,   3.77685040e-01,
                          3.75360101e-01,   3.73209536e-01,   3.71058971e-01,
                          3.68734032e-01,   3.66409123e-01,   3.64142299e-01,
                          3.61875504e-01,   3.59550565e-01,   3.57109398e-01,
                          3.54726344e-01,   3.52517664e-01,   3.50018352e-01,
                          3.47519040e-01,   3.45194131e-01,   3.42694819e-01,
                          3.40311766e-01,   3.37812454e-01,   3.35255027e-01,
                          3.32813859e-01,   3.30198318e-01,   3.27466518e-01,
                          3.25025350e-01,   3.22642297e-01,   3.20026755e-01,
                          3.17411184e-01,   3.14679414e-01,   3.12063843e-01,
                          3.09448302e-01,   3.06832761e-01,   3.04159075e-01,
                          3.01485419e-01,   2.98811734e-01,   2.96079963e-01,
                          2.93290049e-01,   2.90790737e-01,   2.88058937e-01,
                          2.85094649e-01,   2.82420993e-01,   2.79572934e-01,
                          2.76724905e-01,   2.73993105e-01,   2.71086961e-01,
                          2.68180788e-01,   2.65216500e-01,   2.62310326e-01,
                          2.59578526e-01,   2.56846756e-01,   2.53824323e-01,
                          2.50569433e-01,   2.47721389e-01,   2.44931474e-01,
                          2.41792813e-01,   2.38828525e-01,   2.35864237e-01,
                          2.32841834e-01,   2.29703173e-01,   2.26564527e-01,
                          2.23542109e-01,   2.20287204e-01,   2.17206672e-01,
                          2.14242384e-01,   2.10987478e-01,   2.07906947e-01,
                          2.04768285e-01,   2.01397136e-01,   1.98258489e-01,
                          1.94887340e-01,   1.91632435e-01,   1.88435659e-01,
                          1.85064510e-01,   1.82042092e-01,   1.78670943e-01,
                          1.75357923e-01,   1.72335505e-01,   1.68906227e-01,
                          1.65709451e-01,   1.62628919e-01,   1.59315899e-01,
                          1.55886620e-01,   1.52341098e-01,   1.49086192e-01,
                          1.45831287e-01,   1.42343894e-01,   1.39030874e-01,
                          1.35543481e-01,   1.32172316e-01,   1.28917426e-01,
                          1.25371903e-01,   1.22000754e-01,   1.18513353e-01,
                          1.15084082e-01,   1.11887299e-01,   1.08516149e-01,
                          1.05145000e-01,   1.01657607e-01,   9.82864574e-02,
                          9.48571786e-02,   9.12535414e-02,   8.77661407e-02,
                          8.42206255e-02,   8.07332247e-02,   7.73620754e-02,
                          7.38165602e-02,   7.03872815e-02,   6.68417662e-02,
                          6.31799996e-02,   5.97507246e-02,   5.61470836e-02,
                          5.28340563e-02,   4.92885374e-02,   4.54524010e-02,
                          4.20231260e-02,   3.86519767e-02,   3.49902101e-02,
                          3.13865691e-02,   2.78410483e-02,   2.42374055e-02,
                          2.06918847e-02,   1.70882419e-02,   1.33683532e-02,
                          9.70658660e-03,   6.04482042e-03,   2.26680771e-03,
                         -1.22058869e-03,  -4.88235475e-03,  -8.60224478e-03,
                         -1.20896408e-02,  -1.59257762e-02,  -1.96456667e-02,
                         -2.30749398e-02,  -2.67948285e-02,  -3.04565951e-02,
                         -3.40021141e-02,  -3.77220027e-02,  -4.12093997e-02,
                         -4.48711663e-02,  -4.85910550e-02,  -5.21946996e-02,
                         -5.59727140e-02,  -5.96926026e-02,  -6.32381216e-02,
                         -6.68998882e-02,  -7.04454109e-02,  -7.41652995e-02,
                         -7.77108148e-02,  -8.12563375e-02,  -8.50343481e-02,
                         -8.86379927e-02,  -9.21835080e-02,  -9.57290307e-02,
                         -9.93326753e-02,  -1.03168808e-01,  -1.06656209e-01,
                         -1.10201724e-01,  -1.13979742e-01,  -1.17583379e-01,
                         -1.21245146e-01,  -1.24965034e-01,  -1.28684923e-01,
                         -1.32346690e-01,  -1.35775968e-01,  -1.39437735e-01,
                         -1.43215746e-01,  -1.46645024e-01,  -1.50306791e-01,
                         -1.54026672e-01,  -1.57688439e-01,  -1.61292091e-01,
                         -1.64953843e-01,  -1.68731868e-01,  -1.72277376e-01,
                         -1.75881028e-01,  -1.79484665e-01,  -1.83088318e-01,
                         -1.86866328e-01,  -1.90528095e-01,  -1.94189861e-01,
                         -1.97851628e-01,  -2.01164648e-01,  -2.05000788e-01,
                         -2.08836928e-01,  -2.12208077e-01,  -2.15811715e-01,
                         -2.19299108e-01,  -2.22844630e-01,  -2.26448268e-01,
                         -2.29993790e-01,  -2.33655557e-01,  -2.37084836e-01,
                         -2.40630358e-01,  -2.44350240e-01,  -2.47837633e-01,
                         -2.51383156e-01,  -2.55103052e-01,  -2.58648574e-01,
                         -2.62077838e-01,  -2.65565246e-01,  -2.69052625e-01,
                         -2.72423774e-01,  -2.76085556e-01,  -2.79572934e-01,
                         -2.82769740e-01,  -2.86373377e-01,  -2.89918900e-01,
                         -2.93173790e-01,  -2.96719313e-01,  -3.00264835e-01,
                         -3.03635985e-01,  -3.07239622e-01,  -3.10668886e-01,
                         -3.14040035e-01,  -3.17353070e-01,  -3.20724219e-01,
                         -3.24211627e-01,  -3.27524632e-01,  -3.31012040e-01,
                         -3.34499449e-01,  -3.37754339e-01,  -3.41241747e-01,
                         -3.44612896e-01,  -3.47925901e-01,  -3.51355195e-01,
                         -3.54610085e-01,  -3.57981235e-01,  -3.61294270e-01,
                         -3.64665419e-01,  -3.67978454e-01,  -3.71349603e-01,
                         -3.74778867e-01,  -3.77975643e-01,  -3.81230563e-01,
                         -3.84601712e-01,  -3.87856603e-01,  -3.91111493e-01,
                         -3.94366413e-01,  -3.97679448e-01,  -4.00992453e-01,
                         -4.04247373e-01,  -4.07502264e-01,  -4.10582811e-01,
                         -4.13779587e-01,  -4.16918248e-01,  -4.20115024e-01,
                         -4.23311800e-01,  -4.26334202e-01,  -4.29647237e-01,
                         -4.32785898e-01,  -4.35517699e-01,  -4.38656330e-01,
                         -4.41853136e-01,  -4.44875538e-01,  -4.47839826e-01,
                         -4.50746000e-01,  -4.53826517e-01,  -4.56790805e-01,
                         -4.59580719e-01,  -4.62661266e-01,  -4.65509295e-01,
                         -4.68473583e-01,  -4.71554130e-01,  -4.74344045e-01,
                         -4.77075815e-01,  -4.79865760e-01,  -4.82713789e-01,
                         -4.85678077e-01,  -4.88351732e-01,  -4.91025418e-01,
                         -4.93757218e-01,  -4.96430874e-01,  -4.99220788e-01,
                         -5.01836360e-01,  -5.04568160e-01,  -5.07299960e-01,
                         -5.09799242e-01,  -5.12472928e-01,  -5.15088439e-01,
                         -5.17645895e-01,  -5.20319521e-01,  -5.22644460e-01,
                         -5.25143802e-01,  -5.27759314e-01,  -5.30084252e-01,
                         -5.32525420e-01,  -5.35024703e-01,  -5.37582159e-01,
                         -5.39907098e-01,  -5.42173922e-01,  -5.44556975e-01,
                         -5.46940029e-01,  -5.49439311e-01,  -5.51647961e-01,
                         -5.53624153e-01,  -5.55949092e-01,  -5.58157802e-01,
                         -5.60424626e-01,  -5.62633276e-01,  -5.64667583e-01,
                         -5.66818178e-01,  -5.68910599e-01,  -5.70828676e-01,
                         -5.73037326e-01,  -5.74955404e-01,  -5.76873481e-01,
                         -5.79024076e-01,  -5.80883980e-01,  -5.82569540e-01,
                         -5.84487617e-01,  -5.86289465e-01,  -5.88033140e-01,
                         -5.89951217e-01,  -5.91694951e-01,  -5.93264222e-01,
                         -5.94949841e-01,  -5.96635401e-01,  -5.98146617e-01,
                         -5.99715948e-01,  -6.01227164e-01,  -6.02738321e-01,
                         -6.04307652e-01,  -6.05702639e-01,  -6.06981337e-01,
                         -6.08492553e-01,  -6.09887481e-01,  -6.11166239e-01,
                         -6.12444937e-01,  -6.13665521e-01,  -6.14769876e-01,
                         -6.15990460e-01,  -6.17211044e-01,  -6.18315399e-01,
                         -6.19187236e-01,  -6.20291591e-01,  -6.21570289e-01,
                         -6.22500241e-01,  -6.23372078e-01,  -6.24476433e-01,
                         -6.25406444e-01,  -6.26278281e-01,  -6.27266347e-01,
                         -6.28021955e-01,  -6.28777564e-01,  -6.29649401e-01,
                         -6.30405009e-01,  -6.31044388e-01,  -6.31567478e-01,
                         -6.32264972e-01,  -6.32904351e-01,  -6.33427441e-01,
                         -6.34241164e-01,  -6.34473681e-01,  -6.34880543e-01,
                         -6.35461748e-01,  -6.35810494e-01,  -6.36101127e-01,
                         -6.36333585e-01,  -6.36507988e-01,  -6.36856735e-01,
                         -6.37031078e-01,  -6.37147307e-01,  -6.37205422e-01,
                         -6.37321711e-01,  -6.37554169e-01,  -6.37554169e-01,
                         -6.37612283e-01,  -6.37554169e-01,  -6.37379825e-01,
                         -6.37205422e-01,  -6.36856735e-01,  -6.36682332e-01,
                         -6.36449873e-01,  -6.36042953e-01,  -6.35752380e-01,
                         -6.35461748e-01,  -6.34938657e-01,  -6.34473681e-01,
                         -6.33950531e-01,  -6.33427441e-01,  -6.32962465e-01,
                         -6.32206857e-01,  -6.31567478e-01,  -6.30869985e-01,
                         -6.30114436e-01,  -6.29358828e-01,  -6.28545105e-01,
                         -6.27673209e-01,  -6.26685143e-01,  -6.25755191e-01,
                         -6.25057697e-01,  -6.23953342e-01,  -6.22790873e-01,
                         -6.21686518e-01,  -6.20524049e-01,  -6.19477868e-01,
                         -6.18257284e-01,  -6.17094815e-01,  -6.15874231e-01,
                         -6.14595473e-01,  -6.13491178e-01,  -6.12154305e-01,
                         -6.10759377e-01,  -6.09306276e-01,  -6.07678831e-01,
                         -6.06342018e-01,  -6.04656398e-01,  -6.02912724e-01,
                         -6.01575851e-01,  -5.99948406e-01,  -5.98262846e-01,
                         -5.96635401e-01,  -5.94833553e-01,  -5.93147993e-01,
                         -5.91404319e-01,  -5.89602470e-01,  -5.87684393e-01,
                         -5.85766375e-01,  -5.84080756e-01,  -5.82162678e-01,
                         -5.80186486e-01,  -5.78210294e-01,  -5.76001644e-01,
                         -5.74025452e-01,  -5.72049260e-01,  -5.69898725e-01,
                         -5.67864358e-01,  -5.65655708e-01,  -5.63388884e-01,
                         -5.61122060e-01,  -5.58913410e-01,  -5.56820989e-01,
                         -5.54321647e-01,  -5.51822364e-01,  -5.49555540e-01,
                         -5.46998143e-01,  -5.44498801e-01,  -5.41941404e-01,
                         -5.39325833e-01,  -5.37000895e-01,  -5.34327269e-01,
                         -5.31653583e-01,  -5.29270530e-01,  -5.26596844e-01,
                         -5.24039447e-01,  -5.21540105e-01,  -5.18750191e-01,
                         -5.16018450e-01,  -5.13402879e-01,  -5.10729194e-01,
                         -5.08055508e-01,  -5.05381882e-01,  -5.02359450e-01,
                         -4.99569535e-01,  -4.96953994e-01,  -4.93989706e-01,
                         -4.91316020e-01,  -4.88642365e-01,  -4.85619962e-01,
                         -4.82946277e-01,  -4.80040103e-01,  -4.76959586e-01,
                         -4.73995298e-01,  -4.70914751e-01,  -4.68066722e-01,
                         -4.65102434e-01,  -4.61963773e-01,  -4.59115744e-01,
                         -4.56267685e-01,  -4.53187168e-01,  -4.50280994e-01,
                         -4.47374821e-01,  -4.44236189e-01,  -4.41039413e-01,
                         -4.37900752e-01,  -4.34645832e-01,  -4.31507170e-01,
                         -4.28542882e-01,  -4.25404251e-01,  -4.22207445e-01,
                         -4.19010669e-01,  -4.15755779e-01,  -4.12675232e-01,
                         -4.09594715e-01,  -4.06223565e-01,  -4.02968645e-01,
                         -3.99655640e-01,  -3.96342605e-01,  -3.93262058e-01,
                         -3.90007168e-01,  -3.86636019e-01,  -3.83439243e-01,
                         -3.80126208e-01,  -3.76871318e-01,  -3.73616397e-01,
                         -3.70303363e-01,  -3.66932213e-01,  -3.63677323e-01,
                         -3.60364288e-01,  -3.57051283e-01,  -3.53912622e-01,
                         -3.50657701e-01,  -3.47170323e-01,  -3.43857288e-01,
                         -3.40428025e-01,  -3.37114990e-01,  -3.33801955e-01,
                         -3.30488920e-01,  -3.27117771e-01,  -3.23746622e-01,
                         -3.20433617e-01,  -3.17120582e-01,  -3.13749433e-01,
                         -3.10378283e-01,  -3.07007134e-01,  -3.03752214e-01,
                         -3.00439209e-01,  -2.97009915e-01,  -2.93580651e-01,
                         -2.90325761e-01,  -2.87187099e-01,  -2.83757836e-01,
                         -2.80386657e-01,  -2.77189881e-01,  -2.73818731e-01,
                         -2.70563841e-01,  -2.67250806e-01,  -2.63705283e-01,
                         -2.60217905e-01,  -2.56672382e-01,  -2.53301233e-01,
                         -2.50104457e-01,  -2.46617049e-01,  -2.43187770e-01,
                         -2.39932880e-01,  -2.36387357e-01,  -2.32841834e-01,
                         -2.29528800e-01,  -2.26215780e-01,  -2.22728387e-01,
                         -2.19240993e-01,  -2.15753585e-01,  -2.12382436e-01,
                         -2.09127530e-01,  -2.05698267e-01,  -2.02094615e-01,
                         -1.98723465e-01,  -1.95352316e-01,  -1.91748679e-01,
                         -1.88319400e-01,  -1.84948251e-01,  -1.81518987e-01,
                         -1.78031594e-01,  -1.74427941e-01,  -1.71056792e-01,
                         -1.67685643e-01,  -1.64198250e-01,  -1.60885215e-01,
                         -1.57455951e-01,  -1.54026672e-01,  -1.50655523e-01,
                         -1.47110000e-01,  -1.43796980e-01,  -1.40425831e-01,
                         -1.36996552e-01,  -1.33625403e-01,  -1.30254254e-01,
                         -1.26766860e-01,  -1.23279460e-01,  -1.19966440e-01,
                         -1.16595283e-01,  -1.13166012e-01,  -1.09911107e-01,
                         -1.06539957e-01,  -1.03168808e-01,  -9.99139100e-02,
                         -9.64846313e-02,  -9.31134820e-02,  -8.96260887e-02,
                         -8.63130614e-02,  -8.30581561e-02,  -7.97451288e-02,
                         -7.63158575e-02,  -7.30028301e-02,  -6.96898028e-02,
                         -6.64349049e-02,  -6.31218776e-02,  -5.98088466e-02,
                         -5.63795753e-02,  -5.29503003e-02,  -4.96953987e-02,
                         -4.62661274e-02,  -4.28368524e-02,  -3.95238250e-02,
                         -3.62107977e-02,  -3.28396484e-02,  -2.95266230e-02,
                         -2.61554737e-02,  -2.29586922e-02,  -1.97037905e-02,
                         -1.64488871e-02,  -1.30777368e-02,  -9.64846369e-03,
                         -6.39356021e-03,  -2.96428683e-03,   4.06862906e-04,
                          3.66176618e-03,   7.03291595e-03,   1.02296965e-02,
                          1.34845991e-02,   1.68557484e-02,   2.01106519e-02,
                          2.34236792e-02,   2.66204588e-02,   2.98753623e-02,
                          3.30721438e-02,   3.62107977e-02,   3.95819508e-02,
                          4.27787304e-02,   4.60336320e-02,   4.92885374e-02,
                          5.24853170e-02,   5.56820966e-02,   5.87626286e-02,
                          6.19012862e-02,   6.51561916e-02,   6.83529675e-02,
                          7.15497509e-02,   7.45140389e-02,   7.76526928e-02,
                          8.08494762e-02,   8.38718861e-02,   8.71267840e-02,
                          9.01491940e-02,   9.31134820e-02,   9.63683873e-02,
                          9.93326753e-02,   1.02413207e-01,   1.05435617e-01,
                          1.08458027e-01,   1.11654811e-01,   1.14677221e-01,
                          1.17815875e-01,   1.20780163e-01,   1.23686329e-01,
                          1.26824990e-01,   1.29789263e-01,   1.32695436e-01,
                          1.35717839e-01,   1.38624012e-01,   1.41646415e-01,
                          1.44610703e-01,   1.47633120e-01,   1.50597408e-01,
                          1.53445438e-01,   1.56642228e-01,   1.59606501e-01,
                          1.62396431e-01,   1.65535077e-01,   1.68441251e-01,
                          1.71347409e-01,   1.74253568e-01,   1.77101612e-01,
                          1.80124030e-01,   1.82913944e-01,   1.85761988e-01,
                          1.88668147e-01,   1.91399932e-01,   1.94422349e-01,
                          1.97444767e-01,   2.00234681e-01,   2.03140840e-01,
                          2.05988884e-01,   2.08836928e-01,   2.11626843e-01,
                          2.14300513e-01,   2.17090428e-01,   2.19764099e-01,
                          2.22612143e-01,   2.25460172e-01,   2.28133842e-01,
                          2.30923772e-01,   2.33597443e-01,   2.36271113e-01,
                          2.39177272e-01,   2.41734698e-01,   2.44350240e-01,
                          2.47023910e-01,   2.49523208e-01,   2.52313137e-01,
                          2.54986793e-01,   2.57486105e-01,   2.60043532e-01,
                          2.62600958e-01,   2.65274614e-01,   2.67890155e-01,
                          2.70505726e-01,   2.73005009e-01,   2.75504321e-01,
                          2.78177977e-01,   2.80561030e-01,   2.83060342e-01,
                          2.85733998e-01,   2.88175195e-01,   2.90674478e-01,
                          2.93115675e-01,   2.95673102e-01,   2.98230529e-01,
                          3.00613582e-01,   3.03054750e-01,   3.05495918e-01,
                          3.07878971e-01,   3.10262024e-01,   3.12703222e-01,
                          3.15260649e-01,   3.17585558e-01,   3.20026755e-01,
                          3.22584182e-01,   3.24676603e-01,   3.27175915e-01,
                          3.29675198e-01,   3.31709534e-01,   3.34150702e-01,
                          3.36475641e-01,   3.38742435e-01,   3.41125488e-01,
                          3.43217939e-01,   3.45542848e-01,   3.47867787e-01,
                          3.49960238e-01,   3.52110803e-01,   3.54261339e-01,
                          3.56644392e-01,   3.58853102e-01,   3.60887408e-01,
                          3.63037974e-01,   3.65130395e-01,   3.67280960e-01,
                          3.69489640e-01,   3.71582091e-01,   3.73674512e-01,
                          3.75650704e-01,   3.77801269e-01,   3.79719347e-01,
                          3.81579280e-01,   3.83787960e-01,   3.85822296e-01,
                          3.87856603e-01,   3.90123397e-01,   3.91867101e-01,
                          3.93785179e-01,   3.95819485e-01,   3.97679448e-01,
                          3.99771869e-01,   4.01515573e-01,   4.03317392e-01,
                          4.05177325e-01,   4.06862915e-01,   4.08955365e-01,
                          4.10815299e-01,   4.12500858e-01,   4.14360821e-01,
                          4.16162640e-01,   4.18022573e-01,   4.19708163e-01,
                          4.21219349e-01,   4.23137426e-01,   4.24939245e-01,
                          4.26508576e-01,   4.28252280e-01,   4.29995984e-01,
                          4.31739688e-01,   4.33541507e-01,   4.35285181e-01,
                          4.36796397e-01,   4.38423842e-01,   4.40225661e-01,
                          4.41911250e-01,   4.43538696e-01,   4.44991767e-01,
                          4.46561098e-01,   4.48304802e-01,   4.49816018e-01,
                          4.51385349e-01,   4.52954680e-01,   4.54407752e-01,
                          4.55918968e-01,   4.57255781e-01,   4.58650738e-01,
                          4.60220069e-01,   4.61615026e-01,   4.63068128e-01,
                          4.64521199e-01,   4.65799928e-01,   4.67078626e-01,
                          4.68357325e-01,   4.69694167e-01,   4.71089125e-01,
                          4.72367853e-01,   4.73414063e-01,   4.74576533e-01,
                          4.75913376e-01,   4.76959586e-01,   4.78122056e-01,
                          4.79284525e-01,   4.80446965e-01,   4.81725693e-01,
                          4.82713789e-01,   4.83876258e-01,   4.85213101e-01,
                          4.86201197e-01,   4.87363636e-01,   4.88467991e-01,
                          4.89456087e-01,   4.90502298e-01,   4.91432279e-01,
                          4.92652863e-01,   4.93582845e-01,   4.94396567e-01,
                          4.95733410e-01,   4.96547133e-01,   4.97360855e-01,
                          4.98348951e-01,   4.99162674e-01,   5.00208914e-01,
                          5.01080751e-01,   5.01836360e-01,   5.02824426e-01,
                          5.03638148e-01,   5.04393756e-01,   5.05323768e-01,
                          5.06137490e-01,   5.06951213e-01,   5.07706821e-01,
                          5.08578658e-01,   5.09450495e-01,   5.10147989e-01,
                          5.10845423e-01,   5.11601031e-01,   5.12298524e-01,
                          5.12879789e-01,   5.13751626e-01,   5.14332831e-01,
                          5.14914095e-01,   5.15611529e-01,   5.16076565e-01,
                          5.16599655e-01,   5.17180860e-01,   5.17704010e-01,
                          5.18227100e-01,   5.18633962e-01,   5.18982708e-01,
                          5.19563913e-01,   5.20145178e-01,   5.20668268e-01,
                          5.21133244e-01,   5.21540105e-01,   5.22063255e-01,
                          5.22412002e-01,   5.22644460e-01,   5.23051322e-01,
                          5.23341954e-01,   5.23516297e-01,   5.23981333e-01,
                          5.24330020e-01,   5.24504423e-01,   5.24736941e-01,
                          5.25085628e-01,   5.25550663e-01,   5.25608778e-01,
                          5.25608778e-01,   5.26015639e-01,   5.26248097e-01,
                          5.26306212e-01,   5.26480615e-01,   5.26771247e-01,
                          5.26829362e-01,   5.27003706e-01,   5.27352452e-01,
                          5.27526855e-01,   5.27584970e-01,   5.27643085e-01,
                          5.27817428e-01,   5.27933717e-01,   5.28049946e-01,
                          5.28224289e-01,   5.28398693e-01,   5.28398693e-01,
                          5.28340578e-01,   5.28398693e-01,   5.28282404e-01,
                          5.28456807e-01,   5.28689265e-01,   5.28573036e-01,
                          5.28456807e-01,   5.28514922e-01,   5.28514922e-01,
                          5.28514922e-01,   5.28514922e-01,   5.28398693e-01,
                          5.28340578e-01,   5.28224289e-01,   5.28166175e-01,
                          5.27875543e-01,   5.27701199e-01,   5.27643085e-01,
                          5.27352452e-01,   5.27294338e-01,   5.27119994e-01,
                          5.26887476e-01,   5.26654959e-01,   5.26422501e-01,
                          5.26189983e-01,   5.25783122e-01,   5.25492489e-01,
                          5.25260031e-01,   5.24969399e-01,   5.24620652e-01,
                          5.24388194e-01,   5.24039447e-01,   5.23574471e-01,
                          5.23167610e-01,   5.22876978e-01,   5.22586346e-01,
                          5.22179484e-01,   5.21714509e-01,   5.21133244e-01,
                          5.20842671e-01,   5.20261407e-01,   5.19622087e-01,
                          5.19331455e-01,   5.18750191e-01,   5.18343329e-01,
                          5.17878354e-01,   5.17180860e-01,   5.16657770e-01,
                          5.16076565e-01,   5.15495300e-01,   5.15146554e-01,
                          5.14390945e-01,   5.13519108e-01,   5.13112247e-01,
                          5.12531042e-01,   5.11833549e-01,   5.11310458e-01,
                          5.10554850e-01,   5.09683013e-01,   5.09101748e-01,
                          5.08462369e-01,   5.07532418e-01,   5.06834924e-01,
                          5.06021202e-01,   5.05149364e-01,   5.04335642e-01,
                          5.03463805e-01,   5.02708197e-01,   5.01778245e-01,
                          5.00732005e-01,   4.99802023e-01,   4.98930186e-01,
                          4.97883946e-01,   4.96953994e-01,   4.96082127e-01,
                          4.95210290e-01,   4.93989706e-01,   4.92710978e-01,
                          4.91839141e-01,   4.90676671e-01,   4.89397973e-01,
                          4.88293618e-01,   4.87189263e-01,   4.85968679e-01,
                          4.84689981e-01,   4.83469397e-01,   4.82248813e-01,
                          4.81086344e-01,   4.79923874e-01,   4.78587031e-01,
                          4.77250189e-01,   4.76029605e-01,   4.74576533e-01,
                          4.73181576e-01,   4.71728474e-01,   4.70217288e-01,
                          4.68822330e-01,   4.67253000e-01,   4.65799928e-01,
                          4.64346826e-01,   4.63009983e-01,   4.61440682e-01,
                          4.59696978e-01,   4.58418250e-01,   4.56848919e-01,
                          4.55105245e-01,   4.53477770e-01,   4.51675951e-01,
                          4.50106621e-01,   4.48711663e-01,   4.46735471e-01,
                          4.45049912e-01,   4.43538696e-01,   4.41620618e-01,
                          4.39935058e-01,   4.38075125e-01,   4.36215162e-01,
                          4.34355229e-01,   4.32495266e-01,   4.30751592e-01,
                          4.28833514e-01,   4.26799208e-01,   4.24881130e-01,
                          4.22846824e-01,   4.21045005e-01,   4.19068813e-01,
                          4.16918248e-01,   4.15000170e-01,   4.12675232e-01,
                          4.10582811e-01,   4.08780992e-01,   4.06630427e-01,
                          4.04363602e-01,   4.02096808e-01,   4.00004357e-01,
                          3.97737563e-01,   3.95354509e-01,   3.93203944e-01,
                          3.90879005e-01,   3.88495952e-01,   3.86054784e-01,
                          3.83613616e-01,   3.81288677e-01,   3.78963739e-01,
                          3.76580685e-01,   3.74081373e-01,   3.71465832e-01,
                          3.69024664e-01,   3.66525352e-01,   3.63851696e-01,
                          3.61410528e-01,   3.58911216e-01,   3.56121302e-01,
                          3.53389502e-01,   3.50773960e-01,   3.48158419e-01,
                          3.45542848e-01,   3.42811078e-01,   3.39904904e-01,
                          3.37289363e-01,   3.34557563e-01,   3.31709534e-01,
                          3.28977734e-01,   3.26304048e-01,   3.23514134e-01,
                          3.20666105e-01,   3.17759931e-01,   3.14853758e-01,
                          3.12005728e-01,   3.09215814e-01,   3.06425899e-01,
                          3.03403497e-01,   3.00555438e-01,   2.97533035e-01,
                          2.94278145e-01,   2.91488230e-01,   2.88407683e-01,
                          2.85327137e-01,   2.82362849e-01,   2.79282331e-01,
                          2.76376158e-01,   2.73470014e-01,   2.70331353e-01,
                          2.67250806e-01,   2.64112145e-01,   2.60973483e-01,
                          2.57776707e-01,   2.54579931e-01,   2.51499414e-01,
                          2.48244494e-01,   2.44989604e-01,   2.41676569e-01,
                          2.38363549e-01,   2.35224888e-01,   2.31853738e-01,
                          2.28482589e-01,   2.25227684e-01,   2.21798405e-01,
                          2.18427256e-01,   2.14939862e-01,   2.11568713e-01,
                          2.08430052e-01,   2.05058903e-01,   2.01571509e-01,
                          1.98025987e-01,   1.94596723e-01,   1.91283688e-01,
                          1.87854424e-01,   1.84425145e-01,   1.80879623e-01,
                          1.77334100e-01,   1.74079210e-01,   1.70417443e-01,
                          1.66755676e-01,   1.63442641e-01,   1.59722760e-01,
                          1.56060994e-01,   1.52573586e-01,   1.49260566e-01,
                          1.46005660e-01,   1.42343894e-01,   1.38565883e-01,
                          1.35020360e-01,   1.31474838e-01,   1.27929330e-01,
                          1.24267556e-01,   1.20663919e-01,   1.17118396e-01,
                          1.13398507e-01,   1.09852985e-01,   1.06365591e-01,
                          1.02703825e-01,   9.91583019e-02,   9.55546647e-02,
                          9.18928981e-02,   8.81730095e-02,   8.45112428e-02,
                          8.09075981e-02,   7.71295875e-02,   7.35259429e-02,
                          6.98641762e-02,   6.62024096e-02,   6.25987649e-02,
                          5.87626286e-02,   5.51589876e-02,   5.14390953e-02,
                          4.75448370e-02,   4.39411961e-02,   4.01631817e-02,
                          3.63851674e-02,   3.27234045e-02,   2.87128966e-02,
                          2.51092538e-02,   2.13893652e-02,   1.75532289e-02,
                          1.38333393e-02,   9.82283335e-03,   6.21919008e-03,
                          2.49930075e-03,  -1.33683532e-03,  -4.88235475e-03,
                         -8.71849060e-03,  -1.26708737e-02,  -1.65070090e-02,
                         -2.02850215e-02,  -2.40049120e-02,  -2.78410483e-02,
                         -3.16190608e-02,  -3.55133191e-02,  -3.92913334e-02,
                         -4.28368524e-02,  -4.67892364e-02,  -5.06834947e-02,
                         -5.44033833e-02,  -5.82976416e-02,  -6.20756559e-02,
                         -6.57955483e-02,  -6.95735589e-02,  -7.33515695e-02,
                         -7.73039535e-02,  -8.10238421e-02,  -8.46856087e-02,
                         -8.85798708e-02,  -9.24741253e-02,  -9.60777700e-02,
                         -9.99720320e-02,  -1.03866287e-01,  -1.07586183e-01,
                         -1.11480437e-01,  -1.15258448e-01,  -1.19036466e-01,
                         -1.22930720e-01,  -1.26708731e-01,  -1.30428627e-01,
                         -1.34264767e-01,  -1.38159022e-01,  -1.41820788e-01,
                         -1.45540670e-01,  -1.49434939e-01,  -1.53212950e-01,
                         -1.57049090e-01,  -1.60943344e-01,  -1.64721355e-01,
                         -1.68557495e-01,  -1.72509879e-01,  -1.76287889e-01,
                         -1.80065900e-01,  -1.83902040e-01,  -1.87680051e-01,
                         -1.91399932e-01,  -1.95294201e-01,  -1.99130341e-01,
                         -2.02966467e-01,  -2.06860736e-01,  -2.10638747e-01,
                         -2.14474872e-01,  -2.18311012e-01,  -2.22089022e-01,
                         -2.25808918e-01,  -2.29703173e-01,  -2.33539313e-01,
                         -2.37142950e-01,  -2.41037220e-01,  -2.44757101e-01,
                         -2.48360753e-01,  -2.52254993e-01,  -2.55858660e-01,
                         -2.59520411e-01,  -2.63240308e-01,  -2.66843945e-01,
                         -2.70621955e-01,  -2.74458110e-01,  -2.78177977e-01,
                         -2.81955987e-01,  -2.85617769e-01,  -2.89279521e-01,
                         -2.92941302e-01,  -2.96603054e-01,  -3.00439209e-01,
                         -3.03984731e-01,  -3.07588369e-01,  -3.11308265e-01,
                         -3.14853758e-01,  -3.18573654e-01,  -3.22235435e-01,
                         -3.25664699e-01,  -3.29384595e-01,  -3.33220720e-01,
                         -3.36650014e-01,  -3.40195507e-01,  -3.43799174e-01,
                         -3.47344697e-01,  -3.50948334e-01,  -3.54726344e-01,
                         -3.58271867e-01,  -3.61643016e-01,  -3.65362883e-01,
                         -3.69024664e-01,  -3.72512072e-01,  -3.76057565e-01,
                         -3.79603088e-01,  -3.83264869e-01,  -3.86577904e-01,
                         -3.90007168e-01,  -3.93668920e-01,  -3.97214442e-01,
                         -4.00585592e-01,  -4.03956741e-01,  -4.07444149e-01,
                         -4.11280274e-01,  -4.14709568e-01,  -4.18022573e-01,
                         -4.21509981e-01,  -4.24939245e-01,  -4.28426653e-01,
                         -4.31623429e-01,  -4.34936464e-01,  -4.38365728e-01,
                         -4.41678762e-01,  -4.45108026e-01,  -4.48421061e-01,
                         -4.51792210e-01,  -4.55047101e-01,  -4.58243877e-01,
                         -4.61673170e-01,  -4.64986175e-01,  -4.68008608e-01,
                         -4.71147269e-01,  -4.74344045e-01,  -4.77715194e-01,
                         -4.80853856e-01,  -4.83876258e-01,  -4.87073034e-01,
                         -4.90095437e-01,  -4.93350357e-01,  -4.96488988e-01,
                         -4.99511421e-01,  -5.02650082e-01,  -5.05556226e-01,
                         -5.08636773e-01,  -5.11484802e-01,  -5.14216602e-01,
                         -5.17413378e-01,  -5.20319521e-01,  -5.23167610e-01,
                         -5.26189983e-01,  -5.28921783e-01,  -5.31944215e-01,
                         -5.34850359e-01,  -5.37640274e-01,  -5.40837049e-01,
                         -5.43452621e-01,  -5.46126306e-01,  -5.48974335e-01,
                         -5.51647961e-01,  -5.54496050e-01,  -5.57111561e-01,
                         -5.59843361e-01,  -5.62633276e-01,  -5.65306962e-01,
                         -5.67980647e-01,  -5.70479929e-01,  -5.73153615e-01,
                         -5.75711012e-01,  -5.78152180e-01,  -5.80651522e-01,
                         -5.82918286e-01,  -5.85359514e-01,  -5.88033140e-01,
                         -5.90299964e-01,  -5.92741132e-01,  -5.95182300e-01,
                         -5.97507238e-01,  -5.99948406e-01,  -6.01982772e-01,
                         -6.04307652e-01,  -6.06574476e-01,  -6.08550668e-01,
                         -6.10875607e-01,  -6.13142431e-01,  -6.15234852e-01,
                         -6.17211044e-01,  -6.19071007e-01,  -6.21047199e-01,
                         -6.23139620e-01,  -6.25057697e-01,  -6.26917601e-01,
                         -6.28777564e-01,  -6.30637527e-01,  -6.32264972e-01,
                         -6.33950531e-01,  -6.35926723e-01,  -6.37379825e-01,
                         -6.38949156e-01,  -6.40576601e-01,  -6.42087817e-01,
                         -6.43424630e-01,  -6.44877732e-01,  -6.46621406e-01,
                         -6.47900105e-01,  -6.49178863e-01,  -6.50864422e-01,
                         -6.52085006e-01,  -6.53073072e-01,  -6.54584289e-01,
                         -6.55979276e-01,  -6.57199860e-01,  -6.58304214e-01,
                         -6.59408510e-01,  -6.60629153e-01,  -6.61617219e-01,
                         -6.62663460e-01,  -6.63767755e-01,  -6.64697766e-01,
                         -6.65685833e-01,  -6.66615844e-01,  -6.67487681e-01,
                         -6.68243289e-01,  -6.69173241e-01,  -6.69986963e-01,
                         -6.70451939e-01,  -6.71265662e-01,  -6.72079384e-01,
                         -6.72428131e-01,  -6.73125625e-01,  -6.73648715e-01,
                         -6.73823118e-01,  -6.74578726e-01,  -6.74869299e-01,
                         -6.75218046e-01,  -6.75392449e-01,  -6.75799310e-01,
                         -6.76148057e-01,  -6.76031768e-01,  -6.76148057e-01,
                         -6.76206172e-01,  -6.76089942e-01,  -6.76264286e-01,
                         -6.76206172e-01,  -6.76031768e-01,  -6.75973654e-01,
                         -6.75857425e-01,  -6.75566792e-01,  -6.75218046e-01,
                         -6.74927473e-01,  -6.74694955e-01,  -6.74346209e-01,
                         -6.73939347e-01,  -6.73358142e-01,  -6.72834992e-01,
                         -6.72311902e-01,  -6.71730697e-01,  -6.71265662e-01,
                         -6.70393825e-01,  -6.69521987e-01,  -6.68940783e-01,
                         -6.68359518e-01,  -6.67487681e-01,  -6.66615844e-01,
                         -6.65802121e-01,  -6.64755881e-01,  -6.63825929e-01,
                         -6.62895918e-01,  -6.61791563e-01,  -6.60687268e-01,
                         -6.59699142e-01,  -6.58594787e-01,  -6.57490492e-01,
                         -6.56269908e-01,  -6.54933035e-01,  -6.53712451e-01,
                         -6.52433753e-01,  -6.51038766e-01,  -6.49469435e-01,
                         -6.47841990e-01,  -6.46621406e-01,  -6.45284593e-01,
                         -6.43773377e-01,  -6.42320275e-01,  -6.40692830e-01,
                         -6.39007270e-01,  -6.37437940e-01,  -6.35577977e-01,
                         -6.34124935e-01,  -6.32381201e-01,  -6.30172551e-01,
                         -6.28545105e-01,  -6.26685143e-01,  -6.24767065e-01,
                         -6.23023391e-01,  -6.21105313e-01,  -6.19129121e-01,
                         -6.17036700e-01,  -6.14944220e-01,  -6.12968028e-01,
                         -6.10875607e-01,  -6.08725071e-01,  -6.06458247e-01,
                         -6.04249537e-01,  -6.02040887e-01,  -5.99774063e-01,
                         -5.97565353e-01,  -5.95240414e-01,  -5.92799246e-01,
                         -5.90648711e-01,  -5.88149428e-01,  -5.85766375e-01,
                         -5.83499551e-01,  -5.81116498e-01,  -5.78442812e-01,
                         -5.75769126e-01,  -5.73327959e-01,  -5.70770562e-01,
                         -5.68271220e-01,  -5.65597594e-01,  -5.62923908e-01,
                         -5.60308337e-01,  -5.57634711e-01,  -5.54902911e-01,
                         -5.52345455e-01,  -5.49788058e-01,  -5.46940029e-01,
                         -5.44208229e-01,  -5.41534543e-01,  -5.38686514e-01,
                         -5.35954714e-01,  -5.33339143e-01,  -5.30374885e-01,
                         -5.27410567e-01,  -5.24736941e-01,  -5.21656394e-01,
                         -5.18750191e-01,  -5.16134679e-01,  -5.13054132e-01,
                         -5.10089874e-01,  -5.07358074e-01,  -5.04277527e-01,
                         -5.01313210e-01,  -4.98348951e-01,  -4.95326549e-01,
                         -4.92362261e-01,  -4.89223599e-01,  -4.86317426e-01,
                         -4.83062536e-01,  -4.79749501e-01,  -4.76843327e-01,
                         -4.73588437e-01,  -4.70566034e-01,  -4.67543602e-01,
                         -4.64230597e-01,  -4.61208165e-01,  -4.58069503e-01,
                         -4.54930872e-01,  -4.51792210e-01,  -4.48304802e-01,
                         -4.45049912e-01,  -4.41911250e-01,  -4.38598216e-01,
                         -4.35343325e-01,  -4.32088405e-01,  -4.28659141e-01,
                         -4.25229877e-01,  -4.22149330e-01,  -4.19126928e-01,
                         -4.15581405e-01,  -4.12268370e-01,  -4.08839107e-01,
                         -4.05409843e-01,  -4.02213067e-01,  -3.98783773e-01,
                         -3.95296395e-01,  -3.91867101e-01,  -3.88554096e-01,
                         -3.85124803e-01,  -3.81811798e-01,  -3.78440619e-01,
                         -3.75011355e-01,  -3.71582091e-01,  -3.68327171e-01,
                         -3.64897907e-01,  -3.61468643e-01,  -3.58039349e-01,
                         -3.54551971e-01,  -3.51180822e-01,  -3.47809672e-01,
                         -3.44206035e-01,  -3.40660512e-01,  -3.37405592e-01,
                         -3.33918214e-01,  -3.30256432e-01,  -3.26885283e-01,
                         -3.23456019e-01,  -3.19852382e-01,  -3.16423088e-01,
                         -3.12935710e-01,  -3.09448302e-01,  -3.06077152e-01,
                         -3.02473515e-01,  -2.98986107e-01,  -2.95498729e-01,
                         -2.91720718e-01,  -2.88291425e-01,  -2.84745902e-01,
                         -2.81200409e-01,  -2.77596742e-01,  -2.73760617e-01,
                         -2.70215094e-01,  -2.66669571e-01,  -2.63007820e-01,
                         -2.59462297e-01,  -2.55858660e-01,  -2.52254993e-01,
                         -2.48651370e-01,  -2.44989604e-01,  -2.41385952e-01,
                         -2.37549812e-01,  -2.33888045e-01,  -2.30342537e-01,
                         -2.26564527e-01,  -2.22960874e-01,  -2.19299108e-01,
                         -2.15579227e-01,  -2.11917460e-01,  -2.08197564e-01,
                         -2.04477683e-01,  -2.00699657e-01,  -1.96921647e-01,
                         -1.93318009e-01,  -1.89598113e-01,  -1.85936347e-01,
                         -1.82216465e-01,  -1.78438455e-01,  -1.74892932e-01,
                         -1.71231166e-01,  -1.67336911e-01,  -1.63675144e-01,
                         -1.60013378e-01,  -1.56351611e-01,  -1.52631715e-01,
                         -1.48969948e-01,  -1.45308182e-01,  -1.41472042e-01,
                         -1.37694031e-01,  -1.33916020e-01,  -1.30254254e-01,
                         -1.26592487e-01,  -1.22872598e-01,  -1.19210832e-01,
                         -1.15490943e-01,  -1.11712933e-01,  -1.07876793e-01,
                         -1.04215026e-01,  -1.00553267e-01,  -9.68333706e-02,
                         -9.32297334e-02,  -8.96260887e-02,  -8.59643221e-02,
                         -8.22444335e-02,  -7.84664154e-02,  -7.48046562e-02,
                         -7.13172555e-02,  -6.74229935e-02,  -6.37612343e-02,
                         -6.02738336e-02,  -5.64958230e-02,  -5.27759306e-02,
                         -4.92304116e-02,  -4.55105230e-02,  -4.17906344e-02,
                         -3.80707458e-02,  -3.43508534e-02,  -3.05728409e-02,
                         -2.69691981e-02,  -2.34236792e-02,  -1.97037905e-02,
                         -1.60420239e-02,  -1.24965040e-02,  -8.77661444e-03,
                         -5.05672488e-03,  -1.27871206e-03,   2.32493086e-03,
                          5.98669704e-03,   9.76470951e-03,   1.31939827e-02,
                          1.69138722e-02,   2.06918847e-02,   2.41211578e-02,
                          2.78991722e-02,   3.15609388e-02,   3.51064578e-02,
                          3.88263464e-02,   4.22556214e-02,   4.58592623e-02,
                          4.95210290e-02,   5.30665480e-02,   5.66120669e-02,
                          6.00994639e-02,   6.37612343e-02,   6.73648715e-02,
                          7.07360208e-02,   7.42815435e-02,   7.78270662e-02,
                          8.13144594e-02,   8.48018527e-02,   8.82311314e-02,
                          9.18928981e-02,   9.53802913e-02,   9.87514406e-02,
                          1.02180712e-01,   1.05435617e-01,   1.09039262e-01,
                          1.12410411e-01,   1.15723439e-01,   1.19443327e-01,
                          1.22698233e-01,   1.26011252e-01,   1.29614905e-01,
                          1.32927924e-01,   1.36182830e-01,   1.39612108e-01,
                          1.43041372e-01,   1.46296278e-01,   1.49667427e-01,
                          1.53154820e-01,   1.56351611e-01,   1.59780875e-01,
                          1.63210154e-01,   1.66348815e-01,   1.69778079e-01,
                          1.73207358e-01,   1.76404133e-01,   1.79775283e-01,
                          1.83030188e-01,   1.86285093e-01,   1.89423755e-01,
                          1.92794904e-01,   1.96107924e-01,   1.99304700e-01,
                          2.02501491e-01,   2.05756381e-01,   2.09069416e-01,
                          2.12382436e-01,   2.15521097e-01,   2.18717873e-01,
                          2.21740291e-01,   2.24762693e-01,   2.28191972e-01,
                          2.31330633e-01,   2.34411165e-01,   2.37549812e-01,
                          2.40688473e-01,   2.43710890e-01,   2.46675178e-01,
                          2.49755710e-01,   2.52836227e-01,   2.55742401e-01,
                          2.58764803e-01,   2.61961579e-01,   2.64925867e-01,
                          2.67773926e-01,   2.70796329e-01,   2.73876876e-01,
                          2.76724905e-01,   2.79514819e-01,   2.82537222e-01,
                          2.85443395e-01,   2.88175195e-01,   2.91197598e-01,
                          2.94045627e-01,   2.96777427e-01,   2.99741715e-01,
                          3.02706003e-01,   3.05379689e-01,   3.08169603e-01,
                          3.11017632e-01,   3.13691318e-01,   3.16423088e-01,
                          3.19271147e-01,   3.22177291e-01,   3.24967235e-01,
                          3.27524632e-01,   3.30198318e-01,   3.33046347e-01,
                          3.35720032e-01,   3.38568062e-01,   3.41299862e-01,
                          3.43973517e-01,   3.46821576e-01,   3.49320859e-01,
                          3.51878285e-01,   3.54610085e-01,   3.57225627e-01,
                          3.59899312e-01,   3.62631112e-01,   3.65188539e-01,
                          3.67745966e-01,   3.70303363e-01,   3.72918934e-01,
                          3.75418216e-01,   3.77917528e-01,   3.80649328e-01,
                          3.83032382e-01,   3.85531664e-01,   3.88147205e-01,
                          3.90588403e-01,   3.93087685e-01,   3.95354509e-01,
                          3.97737563e-01,   4.00294989e-01,   4.02619928e-01,
                          4.04886723e-01,   4.07327890e-01,   4.09594715e-01,
                          4.12035882e-01,   4.14593309e-01,   4.16801989e-01,
                          4.18952554e-01,   4.21277493e-01,   4.23544288e-01,
                          4.25811112e-01,   4.28019792e-01,   4.30228472e-01,
                          4.32379037e-01,   4.34703976e-01,   4.36854511e-01,
                          4.39121336e-01,   4.41271901e-01,   4.43364322e-01,
                          4.45631146e-01,   4.47781712e-01,   4.49932247e-01,
                          4.52082813e-01,   4.54117149e-01,   4.56209570e-01,
                          4.58360136e-01,   4.60220069e-01,   4.62486893e-01,
                          4.64404941e-01,   4.66323018e-01,   4.68531698e-01,
                          4.70333517e-01,   4.72367853e-01,   4.74518418e-01,
                          4.76494581e-01,   4.78412658e-01,   4.80272621e-01,
                          4.82248813e-01,   4.84166861e-01,   4.85968679e-01,
                          4.87828642e-01,   4.89688575e-01,   4.91432279e-01,
                          4.93117839e-01,   4.95035917e-01,   4.96953994e-01,
                          4.98581439e-01,   5.00499487e-01,   5.02359450e-01,
                          5.03870666e-01,   5.05730629e-01,   5.07358074e-01,
                          5.08869231e-01,   5.10612965e-01,   5.12298524e-01,
                          5.13925970e-01,   5.15553415e-01,   5.17122746e-01,
                          5.18692076e-01,   5.20145178e-01,   5.21656394e-01,
                          5.23225725e-01,   5.24678767e-01,   5.26073754e-01,
                          5.27468681e-01,   5.28863668e-01,   5.30316770e-01,
                          5.31653583e-01,   5.32874167e-01,   5.34094751e-01,
                          5.35605967e-01,   5.36768436e-01,   5.38047135e-01,
                          5.39500237e-01,   5.40430188e-01,   5.41592658e-01,
                          5.42755127e-01,   5.44033825e-01,   5.45428813e-01,
                          5.46416879e-01,   5.47521234e-01,   5.48799932e-01,
                          5.49788058e-01,   5.50776124e-01,   5.51880479e-01,
                          5.52926719e-01,   5.53972900e-01,   5.54844797e-01,
                          5.55890977e-01,   5.56879103e-01,   5.57809055e-01,
                          5.58855295e-01,   5.59669018e-01,   5.60482740e-01,
                          5.61354578e-01,   5.62168300e-01,   5.63098252e-01,
                          5.63911974e-01,   5.64783871e-01,   5.65597594e-01,
                          5.66353202e-01,   5.66992521e-01,   5.67690015e-01,
                          5.68445623e-01,   5.69201231e-01,   5.69782436e-01,
                          5.70421815e-01,   5.71119308e-01,   5.71700513e-01,
                          5.72456121e-01,   5.72979212e-01,   5.73502362e-01,
                          5.73909223e-01,   5.74316084e-01,   5.74839175e-01,
                          5.75187922e-01,   5.75536668e-01,   5.76001644e-01,
                          5.76466620e-01,   5.76873481e-01,   5.77105999e-01,
                          5.77512860e-01,   5.77861607e-01,   5.78094065e-01,
                          5.78500926e-01,   5.78675330e-01,   5.78791559e-01,
                          5.79314649e-01,   5.79489052e-01,   5.79721510e-01,
                          5.79779625e-01,   5.79663396e-01,   5.79895914e-01,
                          5.80012143e-01,   5.80012143e-01,   5.80186486e-01,
                          5.80128372e-01,   5.80128372e-01,   5.80302775e-01,
                          5.80302775e-01,   5.80186486e-01,   5.80070257e-01,
                          5.80186486e-01,   5.80186486e-01,   5.80070257e-01,
                          5.80128372e-01,   5.79954028e-01,   5.79954028e-01,
                          5.79895914e-01,   5.79663396e-01,   5.79663396e-01,
                          5.79430938e-01,   5.79314649e-01,   5.79140306e-01,
                          5.79024076e-01,   5.78907788e-01,   5.78559041e-01,
                          5.78326583e-01,   5.78152180e-01,   5.77687204e-01,
                          5.77570975e-01,   5.77280343e-01,   5.76699138e-01,
                          5.76641023e-01,   5.76059759e-01,   5.75478554e-01,
                          5.75246036e-01,   5.74722946e-01,   5.74316084e-01,
                          5.73909223e-01,   5.73444188e-01,   5.72746754e-01,
                          5.72165489e-01,   5.71816742e-01,   5.71177423e-01,
                          5.70305586e-01,   5.69666207e-01,   5.68910599e-01,
                          5.68445623e-01,   5.67980647e-01,   5.67283154e-01,
                          5.66701889e-01,   5.65713823e-01,   5.64841986e-01,
                          5.64493239e-01,   5.63737631e-01,   5.62923908e-01,
                          5.62168300e-01,   5.61470807e-01,   5.60598969e-01,
                          5.59785247e-01,   5.59029639e-01,   5.57983398e-01,
                          5.56995332e-01,   5.56239724e-01,   5.55367887e-01,
                          5.54321647e-01,   5.53449810e-01,   5.52577972e-01,
                          5.51706135e-01,   5.50834239e-01,   5.49904287e-01,
                          5.48799932e-01,   5.47753751e-01,   5.46881855e-01,
                          5.45777559e-01,   5.44673204e-01,   5.43626964e-01,
                          5.42522609e-01,   5.41418314e-01,   5.40430188e-01,
                          5.39383948e-01,   5.38221538e-01,   5.37000895e-01,
                          5.35780311e-01,   5.34443498e-01,   5.33222914e-01,
                          5.32176673e-01,   5.30781746e-01,   5.29503047e-01,
                          5.28282404e-01,   5.26887476e-01,   5.25608778e-01,
                          5.24271905e-01,   5.22876978e-01,   5.21656394e-01,
                          5.20261407e-01,   5.18692076e-01,   5.17355263e-01,
                          5.16018450e-01,   5.14332831e-01,   5.12821615e-01,
                          5.11484802e-01,   5.09915471e-01,   5.08113682e-01,
                          5.06428063e-01,   5.05033135e-01,   5.03580034e-01,
                          5.01952589e-01,   5.00441372e-01,   4.98639554e-01,
                          4.96779621e-01,   4.95268404e-01,   4.93524700e-01,
                          4.91781026e-01,   4.90153551e-01,   4.88235503e-01,
                          4.86433685e-01,   4.84631866e-01,   4.82771903e-01,
                          4.81202573e-01,   4.79226381e-01,   4.77192074e-01,
                          4.75390255e-01,   4.73472178e-01,   4.71670359e-01,
                          4.69868541e-01,   4.67776090e-01,   4.65741783e-01,
                          4.63765591e-01,   4.62021887e-01,   4.59929466e-01,
                          4.57662642e-01,   4.55802709e-01,   4.53768402e-01,
                          4.51617837e-01,   4.49525386e-01,   4.47374821e-01,
                          4.45224285e-01,   4.43015575e-01,   4.40806895e-01,
                          4.38714474e-01,   4.36505795e-01,   4.34297085e-01,
                          4.32088405e-01,   4.29879725e-01,   4.27671045e-01,
                          4.25229877e-01,   4.22963053e-01,   4.20754373e-01,
                          4.18255061e-01,   4.15872008e-01,   4.13605213e-01,
                          4.11222160e-01,   4.08548474e-01,   4.06049192e-01,
                          4.03782368e-01,   4.01283085e-01,   3.98725659e-01,
                          3.96342605e-01,   3.93552691e-01,   3.90879005e-01,
                          3.88495952e-01,   3.85764152e-01,   3.83090496e-01,
                          3.80474955e-01,   3.77685040e-01,   3.74953240e-01,
                          3.72279555e-01,   3.69664013e-01,   3.66932213e-01,
                          3.64026070e-01,   3.61352384e-01,   3.58678728e-01,
                          3.55830669e-01,   3.52924526e-01,   3.50134611e-01,
                          3.47460926e-01,   3.44554752e-01,   3.41474235e-01,
                          3.38509947e-01,   3.35778147e-01,   3.32930118e-01,
                          3.29791456e-01,   3.26885283e-01,   3.23979139e-01,
                          3.21072966e-01,   3.18224937e-01,   3.15144390e-01,
                          3.12296361e-01,   3.09390187e-01,   3.06251526e-01,
                          3.03229123e-01,   3.00090462e-01,   2.96951801e-01,
                          2.93813139e-01,   2.90732622e-01,   2.87710190e-01,
                          2.84571558e-01,   2.81374753e-01,   2.78119862e-01,
                          2.74981201e-01,   2.71842539e-01,   2.68471390e-01,
                          2.65332729e-01,   2.62194097e-01,   2.58822948e-01,
                          2.55509913e-01,   2.52138764e-01,   2.48883858e-01,
                          2.45745197e-01,   2.42257804e-01,   2.38770410e-01,
                          2.35399261e-01,   2.32086226e-01,   2.28831321e-01,
                          2.25518301e-01,   2.22205281e-01,   2.18601629e-01,
                          2.15056106e-01,   2.11626843e-01,   2.08197564e-01,
                          2.04768285e-01,   2.01164648e-01,   1.97619125e-01,
                          1.94247976e-01,   1.90528095e-01,   1.86866328e-01,
                          1.83553293e-01,   1.79891527e-01,   1.76229760e-01,
                          1.72742367e-01,   1.69022486e-01,   1.65360719e-01,
                          1.61757067e-01,   1.58095300e-01,   1.54433534e-01,
                          1.50713652e-01,   1.47051886e-01,   1.43448234e-01,
                          1.39844596e-01,   1.36008456e-01,   1.32404819e-01,
                          1.28917426e-01,   1.25081286e-01,   1.21361397e-01,
                          1.17757753e-01,   1.13863491e-01,   1.10201724e-01,
                          1.06365591e-01,   1.02587581e-01,   9.90420580e-02,
                          9.52059254e-02,   9.14279073e-02,   8.78242627e-02,
                          8.40462521e-02,   8.02101195e-02,   7.61996135e-02,
                          7.23053515e-02,   6.84692189e-02,   6.46912009e-02,
                          6.09131902e-02,   5.67283146e-02,   5.28340563e-02,
                          4.90560420e-02,   4.50455360e-02,   4.13256474e-02,
                          3.74895111e-02,   3.35371271e-02,   2.96428688e-02,
                          2.55742408e-02,   2.17962284e-02,   1.80182140e-02,
                          1.39495861e-02,   9.88095626e-03,   5.87045075e-03,
                          1.85994478e-03,  -2.09243782e-03,  -5.98669704e-03,
                         -9.99720301e-03,  -1.42402016e-02,  -1.82507075e-02,
                         -2.23774593e-02,  -2.65042130e-02,  -3.03984713e-02,
                         -3.45833488e-02,  -3.85357291e-02,  -4.24299911e-02,
                         -4.66729887e-02,  -5.06834947e-02,  -5.46940006e-02,
                         -5.88207543e-02,  -6.28312603e-02,  -6.71323836e-02,
                         -7.11428896e-02,  -7.51533955e-02,  -7.92801455e-02,
                         -8.31744075e-02,  -8.73592794e-02,  -9.16022807e-02,
                         -9.56127867e-02,  -9.97395366e-02,  -1.03866287e-01,
                         -1.07993044e-01,  -1.12061672e-01,  -1.16072178e-01,
                         -1.20198928e-01,  -1.24151312e-01,  -1.28219947e-01,
                         -1.32462934e-01,  -1.36473447e-01,  -1.40425831e-01,
                         -1.44378215e-01,  -1.48563087e-01,  -1.52806088e-01,
                         -1.56816587e-01,  -1.60943344e-01,  -1.64953843e-01,
                         -1.69080600e-01,  -1.73323601e-01,  -1.77217856e-01,
                         -1.81344613e-01,  -1.85471371e-01,  -1.89539999e-01,
                         -1.93608627e-01,  -1.97619125e-01,  -2.01629639e-01,
                         -2.05872640e-01,  -2.09999382e-01,  -2.13951766e-01,
                         -2.18078524e-01,  -2.22321525e-01,  -2.26273909e-01,
                         -2.30342537e-01,  -2.34585539e-01,  -2.38479793e-01,
                         -2.42548421e-01,  -2.46733293e-01,  -2.50685692e-01,
                         -2.54696190e-01,  -2.58764803e-01,  -2.63007820e-01,
                         -2.67134577e-01,  -2.71028817e-01,  -2.75097460e-01,
                         -2.79166073e-01,  -2.83118457e-01,  -2.87303329e-01,
                         -2.91313857e-01,  -2.95208097e-01,  -2.99334854e-01,
                         -3.03229123e-01,  -3.07065248e-01,  -3.11017632e-01,
                         -3.15144390e-01,  -3.19096774e-01,  -3.22932899e-01,
                         -3.26769054e-01,  -3.30663294e-01,  -3.34557563e-01,
                         -3.38509947e-01,  -3.42520446e-01,  -3.46530944e-01,
                         -3.50308955e-01,  -3.54086995e-01,  -3.57923120e-01,
                         -3.61759245e-01,  -3.65537256e-01,  -3.69257152e-01,
                         -3.73093277e-01,  -3.76813173e-01,  -3.80533069e-01,
                         -3.84485453e-01,  -3.88089091e-01,  -3.91750872e-01,
                         -3.95645112e-01,  -3.99132520e-01,  -4.02678043e-01,
                         -4.06572312e-01,  -4.10234064e-01,  -4.13895816e-01,
                         -4.17441338e-01,  -4.20986861e-01,  -4.24706757e-01,
                         -4.28194165e-01,  -4.31681544e-01,  -4.35285181e-01,
                         -4.38888848e-01,  -4.42550600e-01,  -4.45979863e-01,
                         -4.49525386e-01,  -4.53245282e-01,  -4.56674546e-01,
                         -4.60103840e-01,  -4.63533103e-01,  -4.66904253e-01,
                         -4.70333517e-01,  -4.73704666e-01,  -4.77192074e-01,
                         -4.80621338e-01,  -4.83759999e-01,  -4.87189263e-01,
                         -4.90676671e-01,  -4.93989706e-01,  -4.97244596e-01,
                         -5.00325143e-01,  -5.03405690e-01,  -5.06776810e-01,
                         -5.10147989e-01,  -5.13170362e-01,  -5.16425312e-01,
                         -5.19680202e-01,  -5.22528231e-01,  -5.25666893e-01,
                         -5.29038012e-01,  -5.31827927e-01,  -5.34792244e-01,
                         -5.37930906e-01,  -5.41011453e-01,  -5.43801367e-01,
                         -5.46649396e-01,  -5.49788058e-01,  -5.52636087e-01,
                         -5.55251658e-01,  -5.58332145e-01,  -5.60947716e-01,
                         -5.63737631e-01,  -5.66643775e-01,  -5.68968713e-01,
                         -5.71700513e-01,  -5.74432313e-01,  -5.76757252e-01,
                         -5.79430938e-01,  -5.81930220e-01,  -5.84371388e-01,
                         -5.86986959e-01,  -5.89486241e-01,  -5.91985524e-01,
                         -5.94368577e-01,  -5.96693516e-01,  -5.99134684e-01,
                         -6.01459622e-01,  -6.03610218e-01,  -6.05702639e-01,
                         -6.08085692e-01,  -6.10410631e-01,  -6.12386823e-01,
                         -6.14595473e-01,  -6.16804183e-01,  -6.18838489e-01,
                         -6.20930910e-01,  -6.22907102e-01,  -6.24883294e-01,
                         -6.26859486e-01,  -6.28835678e-01,  -6.30753756e-01,
                         -6.32555604e-01,  -6.34357393e-01,  -6.36217356e-01,
                         -6.37902915e-01,  -6.39646649e-01,  -6.41506553e-01,
                         -6.43308401e-01,  -6.44993961e-01,  -6.46563292e-01,
                         -6.48074508e-01,  -6.49701953e-01,  -6.51387513e-01,
                         -6.52956843e-01,  -6.54468060e-01,  -6.55688643e-01,
                         -6.56967342e-01,  -6.58536673e-01,  -6.59641027e-01,
                         -6.60861611e-01,  -6.62256598e-01,  -6.63244665e-01,
                         -6.64581537e-01,  -6.65860236e-01,  -6.66790187e-01,
                         -6.67952657e-01,  -6.68824494e-01,  -6.70045078e-01,
                         -6.71091318e-01,  -6.71498179e-01,  -6.72602534e-01,
                         -6.73590600e-01,  -6.74055576e-01,  -6.75159931e-01,
                         -6.75799310e-01,  -6.76322401e-01,  -6.77078009e-01,
                         -6.77542984e-01,  -6.78298593e-01,  -6.78821683e-01,
                         -6.79228544e-01,  -6.79867923e-01,  -6.80332899e-01,
                         -6.80914164e-01,  -6.81204736e-01,  -6.81379139e-01,
                         -6.81902230e-01,  -6.82250977e-01,  -6.82425380e-01,
                         -6.82599723e-01,  -6.82774067e-01,  -6.83006585e-01,
                         -6.83122814e-01,  -6.83355331e-01,  -6.83471560e-01,
                         -6.83297217e-01,  -6.83180928e-01,  -6.83180928e-01,
                         -6.83064699e-01,  -6.83006585e-01,  -6.82715952e-01,
                         -6.82541609e-01,  -6.82309091e-01,  -6.81960344e-01,
                         -6.81786001e-01,  -6.81495368e-01,  -6.81146622e-01,
                         -6.80623531e-01,  -6.80216670e-01,  -6.79984152e-01,
                         -6.79519176e-01,  -6.78879857e-01,  -6.78298593e-01,
                         -6.77659273e-01,  -6.76903665e-01,  -6.76264286e-01,
                         -6.75683081e-01,  -6.74869299e-01,  -6.74055576e-01,
                         -6.73358142e-01,  -6.72428131e-01,  -6.71556294e-01,
                         -6.70800686e-01,  -6.69812620e-01,  -6.68940783e-01,
                         -6.67952657e-01,  -6.66790187e-01,  -6.65802121e-01,
                         -6.64755881e-01,  -6.63651526e-01,  -6.62489057e-01,
                         -6.61326587e-01,  -6.60164118e-01,  -6.58885419e-01,
                         -6.57664835e-01,  -6.56328022e-01,  -6.54991150e-01,
                         -6.53596222e-01,  -6.52085006e-01,  -6.50748193e-01,
                         -6.49469435e-01,  -6.47958279e-01,  -6.46737635e-01,
                         -6.45168364e-01,  -6.43424630e-01,  -6.41971529e-01,
                         -6.40402198e-01,  -6.38832927e-01,  -6.37089193e-01,
                         -6.35287404e-01,  -6.33718073e-01,  -6.31974339e-01,
                         -6.30230665e-01,  -6.28545105e-01,  -6.26743257e-01,
                         -6.24999583e-01,  -6.23081505e-01,  -6.21221542e-01,
                         -6.19477868e-01,  -6.17501676e-01,  -6.15525484e-01,
                         -6.13433003e-01,  -6.11573100e-01,  -6.09655023e-01,
                         -6.07504427e-01,  -6.05412006e-01,  -6.03435814e-01,
                         -6.01459622e-01,  -5.99425316e-01,  -5.97158492e-01,
                         -5.95007956e-01,  -5.92683017e-01,  -5.90358078e-01,
                         -5.88381886e-01,  -5.86173236e-01,  -5.83964527e-01,
                         -5.81755817e-01,  -5.79372764e-01,  -5.76931596e-01,
                         -5.74722946e-01,  -5.72456121e-01,  -5.70073068e-01,
                         -5.67631900e-01,  -5.65248847e-01,  -5.62807679e-01,
                         -5.60366452e-01,  -5.57983398e-01,  -5.55367887e-01,
                         -5.52868605e-01,  -5.50311148e-01,  -5.47753751e-01,
                         -5.45312524e-01,  -5.42697012e-01,  -5.39965212e-01,
                         -5.37407815e-01,  -5.34792244e-01,  -5.32118559e-01,
                         -5.29444873e-01,  -5.26713133e-01,  -5.24097562e-01,
                         -5.21540105e-01,  -5.18924594e-01,  -5.16192794e-01,
                         -5.13577223e-01,  -5.10903597e-01,  -5.07997394e-01,
                         -5.05323768e-01,  -5.02766311e-01,  -4.99802023e-01,
                         -4.97070223e-01,  -4.94338453e-01,  -4.91316020e-01,
                         -4.88584250e-01,  -4.85794306e-01,  -4.82830018e-01,
                         -4.80040103e-01,  -4.77075815e-01,  -4.73995298e-01,
                         -4.71205384e-01,  -4.68241096e-01,  -4.65102434e-01,
                         -4.62254405e-01,  -4.59348232e-01,  -4.56267685e-01,
                         -4.53361541e-01,  -4.50280994e-01,  -4.47200477e-01,
                         -4.44468677e-01,  -4.41388130e-01,  -4.38133240e-01,
                         -4.35110837e-01,  -4.31797802e-01,  -4.28659141e-01,
                         -4.25752968e-01,  -4.22614306e-01,  -4.19359416e-01,
                         -4.16104525e-01,  -4.12965864e-01,  -4.09827203e-01,
                         -4.06572312e-01,  -4.03433651e-01,  -4.00178730e-01,
                         -3.96923840e-01,  -3.93668920e-01,  -3.90239656e-01,
                         -3.86926621e-01,  -3.83671731e-01,  -3.80358696e-01,
                         -3.76987547e-01,  -3.73616397e-01,  -3.70361507e-01,
                         -3.66990358e-01,  -3.63619208e-01,  -3.60422432e-01,
                         -3.56935024e-01,  -3.53389502e-01,  -3.50134611e-01,
                         -3.46647203e-01,  -3.43043566e-01,  -3.39556158e-01,
                         -3.36126894e-01,  -3.32697630e-01,  -3.29442710e-01,
                         -3.25955331e-01,  -3.22467923e-01,  -3.19096774e-01,
                         -3.15493137e-01,  -3.11947614e-01,  -3.08576465e-01,
                         -3.04914683e-01,  -3.01311046e-01,  -2.97998011e-01,
                         -2.94510633e-01,  -2.91023225e-01,  -2.87419587e-01,
                         -2.83874065e-01,  -2.80270427e-01,  -2.76608646e-01,
                         -2.73063153e-01,  -2.69575745e-01,  -2.66030222e-01,
                         -2.62368470e-01,  -2.58706689e-01,  -2.55277425e-01,
                         -2.51673788e-01,  -2.48070136e-01,  -2.44582728e-01,
                         -2.40746602e-01,  -2.37026706e-01,  -2.33481184e-01,
                         -2.29703173e-01,  -2.26041406e-01,  -2.22379640e-01,
                         -2.18717873e-01,  -2.15230480e-01,  -2.11568713e-01,
                         -2.07848832e-01,  -2.04187065e-01,  -2.00409040e-01,
                         -1.96689159e-01,  -1.93085521e-01,  -1.89365625e-01,
                         -1.85703859e-01,  -1.81983963e-01,  -1.78147838e-01,
                         -1.74544185e-01,  -1.70940548e-01,  -1.66988164e-01,
                         -1.63210154e-01,  -1.59548387e-01,  -1.55712247e-01,
                         -1.52050480e-01,  -1.48388714e-01,  -1.44610703e-01,
                         -1.40774563e-01,  -1.36996552e-01,  -1.33276671e-01,
                         -1.29556775e-01,  -1.25662521e-01,  -1.22000754e-01,
                         -1.18280858e-01,  -1.14502847e-01,  -1.10724837e-01,
                         -1.07004948e-01,  -1.03226930e-01,  -9.95070413e-02,
                         -9.57871526e-02,  -9.21253860e-02,  -8.84054974e-02,
                         -8.48018527e-02,  -8.10238421e-02,  -7.71877095e-02,
                         -7.35259429e-02,  -6.98641762e-02,  -6.61442876e-02,
                         -6.24243952e-02,  -5.87626286e-02,  -5.51008619e-02,
                         -5.13228513e-02,  -4.77192067e-02,  -4.40574400e-02,
                         -4.02213037e-02,  -3.66176628e-02,  -3.28977741e-02,
                         -2.93522533e-02,  -2.56904867e-02,  -2.17962284e-02,
                         -1.81344617e-02,  -1.45308180e-02,  -1.08109284e-02,
                         -7.26540899e-03,  -3.48739652e-03,   5.81232744e-05,
                          3.71988956e-03,   7.61414878e-03,   1.12177916e-02,
                          1.48795582e-02,   1.84250772e-02,   2.19705980e-02,
                          2.59229802e-02,   2.96428688e-02,   3.31883878e-02,
                          3.68501544e-02,   4.05700430e-02,   4.42899354e-02,
                          4.78935763e-02,   5.13809733e-02,   5.51589876e-02,
                          5.87045066e-02,   6.22500256e-02,   6.60280362e-02,
                          6.96316808e-02,   7.32353255e-02,   7.68389702e-02,
                          8.05007368e-02,   8.39881301e-02,   8.74174014e-02,
                          9.10210460e-02,   9.45665687e-02,   9.81702060e-02,
                          1.01715729e-01,   1.05145000e-01,   1.08748645e-01,
                          1.12177916e-01,   1.15549065e-01,   1.19210832e-01,
                          1.22581981e-01,   1.26069382e-01,   1.29556775e-01,
                          1.32927924e-01,   1.36473447e-01,   1.39844596e-01,
                          1.43157616e-01,   1.46703139e-01,   1.50190532e-01,
                          1.53503567e-01,   1.56874716e-01,   1.60245866e-01,
                          1.63558885e-01,   1.67046294e-01,   1.70417443e-01,
                          1.73614219e-01,   1.77159742e-01,   1.80589005e-01,
                          1.83727667e-01,   1.87098816e-01,   1.90353721e-01,
                          1.93841115e-01,   1.97328508e-01,   2.00467169e-01,
                          2.03896448e-01,   2.07093224e-01,   2.10231885e-01,
                          2.13603035e-01,   2.16857940e-01,   2.20170960e-01,
                          2.23367736e-01,   2.26680771e-01,   2.30051920e-01,
                          2.33132452e-01,   2.36387357e-01,   2.39584133e-01,
                          2.42897153e-01,   2.46268302e-01,   2.49232590e-01,
                          2.52545625e-01,   2.55916774e-01,   2.58822948e-01,
                          2.62135953e-01,   2.65274614e-01,   2.68238902e-01,
                          2.71493822e-01,   2.74574339e-01,   2.77596742e-01,
                          2.80793548e-01,   2.83990324e-01,   2.86954612e-01,
                          2.89918900e-01,   2.93115675e-01,   2.96138078e-01,
                          2.99218625e-01,   3.02299142e-01,   3.05147171e-01,
                          3.08285832e-01,   3.11250120e-01,   3.14098179e-01,
                          3.17236841e-01,   3.20201099e-01,   3.23165387e-01,
                          3.26129675e-01,   3.28919590e-01,   3.31883878e-01,
                          3.34790051e-01,   3.37579966e-01,   3.40544254e-01,
                          3.43508542e-01,   3.46356601e-01,   3.49088371e-01,
                          3.51994544e-01,   3.54958832e-01,   3.57748747e-01,
                          3.60654920e-01,   3.63561064e-01,   3.66234750e-01,
                          3.69140923e-01,   3.71988952e-01,   3.74778867e-01,
                          3.77568781e-01,   3.80242467e-01,   3.82858008e-01,
                          3.85764152e-01,   3.88554096e-01,   3.91111493e-01,
                          3.93901438e-01,   3.96807581e-01,   3.99365008e-01,
                          4.02038693e-01,   4.04770464e-01,   4.07269776e-01,
                          4.10117805e-01,   4.12849605e-01,   4.15290803e-01,
                          4.18080717e-01,   4.20521885e-01,   4.23137426e-01,
                          4.25811112e-01,   4.28194165e-01,   4.30867821e-01,
                          4.33483362e-01,   4.36215162e-01,   4.38714474e-01,
                          4.40923154e-01,   4.43654954e-01,   4.46270496e-01,
                          4.48537290e-01,   4.51152861e-01,   4.53594029e-01,
                          4.55977082e-01,   4.58302021e-01,   4.60510701e-01,
                          4.63126242e-01,   4.65276808e-01,   4.67427373e-01,
                          4.69984800e-01,   4.72135335e-01,   4.74576533e-01,
                          4.76901472e-01,   4.78935778e-01,   4.81435061e-01,
                          4.83643770e-01,   4.85678077e-01,   4.87886757e-01,
                          4.90037322e-01,   4.92187887e-01,   4.94222194e-01,
                          4.96430874e-01,   4.98581439e-01,   5.00557601e-01,
                          5.02708197e-01,   5.04742503e-01,   5.06893039e-01,
                          5.09159863e-01,   5.11136055e-01,   5.13170362e-01,
                          5.15146554e-01,   5.17064631e-01,   5.19157052e-01,
                          5.21191418e-01,   5.23341954e-01,   5.25143802e-01,
                          5.26887476e-01,   5.28979897e-01,   5.30839860e-01,
                          5.32641649e-01,   5.34676015e-01,   5.36535919e-01,
                          5.38395882e-01,   5.40255845e-01,   5.41941404e-01,
                          5.43743193e-01,   5.45428813e-01,   5.47172487e-01,
                          5.48974335e-01,   5.50718009e-01,   5.52345455e-01,
                          5.54031014e-01,   5.55949092e-01,   5.57692826e-01,
                          5.59145868e-01,   5.60657084e-01,   5.62284529e-01,
                          5.63795745e-01,   5.65306962e-01,   5.66818178e-01,
                          5.68445623e-01,   5.69898725e-01,   5.71467996e-01,
                          5.73095500e-01,   5.74257970e-01,   5.75711012e-01,
                          5.77164114e-01,   5.78384697e-01,   5.79837799e-01,
                          5.81116498e-01,   5.82569540e-01,   5.83964527e-01,
                          5.85068882e-01,   5.86231351e-01,   5.87626278e-01,
                          5.88730633e-01,   5.89893103e-01,   5.91055572e-01,
                          5.92159927e-01,   5.93554854e-01,   5.94833553e-01,
                          5.95705450e-01,   5.96809745e-01,   5.98262846e-01,
                          5.99192798e-01,   6.00064695e-01,   6.01052761e-01,
                          6.02040887e-01,   6.03377700e-01,   6.04365826e-01,
                          6.05295777e-01,   6.06225729e-01,   6.07330084e-01,
                          6.08376324e-01,   6.09190047e-01,   6.10236228e-01,
                          6.11224353e-01,   6.12038076e-01,   6.12968028e-01,
                          6.13781750e-01,   6.14595473e-01,   6.15525484e-01,
                          6.16164804e-01,   6.17211044e-01,   6.18024766e-01,
                          6.18547857e-01,   6.19594097e-01,   6.20175302e-01,
                          6.20872796e-01,   6.21860921e-01,   6.22325897e-01,
                          6.23255849e-01,   6.24069571e-01,   6.24534547e-01,
                          6.25290155e-01,   6.25871420e-01,   6.26452625e-01,
                          6.27033889e-01,   6.27382636e-01,   6.28021955e-01,
                          6.28428817e-01,   6.28893793e-01,   6.29533172e-01,
                          6.29940033e-01,   6.30521297e-01,   6.30928159e-01,
                          6.31218731e-01,   6.31741881e-01,   6.32090569e-01,
                          6.32497489e-01,   6.32904351e-01,   6.33020580e-01,
                          6.33194923e-01,   6.33485556e-01,   6.33834302e-01,
                          6.34183049e-01,   6.34415507e-01,   6.34706140e-01,
                          6.34648025e-01,   6.34706140e-01,   6.35054886e-01,
                          6.35287404e-01,   6.35636091e-01,   6.35694265e-01,
                          6.35752380e-01,   6.35926723e-01,   6.36101127e-01,
                          6.36391699e-01,   6.36507988e-01,   6.36449873e-01,
                          6.36391699e-01,   6.36333585e-01,   6.36391699e-01,
                          6.36391699e-01,   6.36217356e-01,   6.36333585e-01,
                          6.36275470e-01,   6.36101127e-01,   6.35984838e-01,
                          6.35810494e-01,   6.35636091e-01,   6.35287404e-01,
                          6.35229230e-01,   6.34996772e-01,   6.34648025e-01,
                          6.34415507e-01,   6.33892417e-01,   6.33718073e-01,
                          6.33369327e-01,   6.32904351e-01,   6.32671833e-01,
                          6.32206857e-01,   6.31683707e-01,   6.31335020e-01,
                          6.30928159e-01,   6.30579412e-01,   6.29881918e-01,
                          6.29300654e-01,   6.28893793e-01,   6.27963841e-01,
                          6.27440751e-01,   6.26801372e-01,   6.25813305e-01,
                          6.25406444e-01,   6.24592721e-01,   6.23604596e-01,
                          6.23023391e-01,   6.22151494e-01,   6.21105313e-01,
                          6.20175302e-01,   6.19187236e-01,   6.18257284e-01,
                          6.17385387e-01,   6.16455436e-01,   6.15525484e-01,
                          6.14421129e-01,   6.13374889e-01,   6.12212420e-01,
                          6.11049950e-01,   6.09771252e-01,   6.08608782e-01,
                          6.07562602e-01,   6.06283844e-01,   6.05121374e-01,
                          6.03784561e-01,   6.02505863e-01,   6.01459622e-01,
                          6.00122809e-01,   5.98611593e-01,   5.97391009e-01,
                          5.96112311e-01,   5.94426692e-01,   5.92857361e-01,
                          5.91578662e-01,   5.90009332e-01,   5.88323772e-01,
                          5.86928844e-01,   5.85243225e-01,   5.83499551e-01,
                          5.81988335e-01,   5.80186486e-01,   5.78500926e-01,
                          5.76699138e-01,   5.74781060e-01,   5.73095500e-01,
                          5.71235538e-01,   5.69317460e-01,   5.67341268e-01,
                          5.65423191e-01,   5.63563287e-01,   5.61528921e-01,
                          5.59494615e-01,   5.57576537e-01,   5.55367887e-01,
                          5.53101063e-01,   5.50950527e-01,   5.48799932e-01,
                          5.46707511e-01,   5.44150114e-01,   5.41941404e-01,
                          5.39790869e-01,   5.37349641e-01,   5.35082877e-01,
                          5.32699823e-01,   5.30258596e-01,   5.27991831e-01,
                          5.25492489e-01,   5.22818863e-01,   5.20377696e-01,
                          5.17762125e-01,   5.15088439e-01,   5.12589157e-01,
                          5.10089874e-01,   5.07299960e-01,   5.04568160e-01,
                          5.02010703e-01,   4.99337047e-01,   4.96605247e-01,
                          4.93873447e-01,   4.90909159e-01,   4.88061130e-01,
                          4.85213101e-01,   4.82481301e-01,   4.79691386e-01,
                          4.76727098e-01,   4.73704666e-01,   4.70798522e-01,
                          4.67892349e-01,   4.64986175e-01,   4.61847544e-01,
                          4.58766997e-01,   4.55744594e-01,   4.52489674e-01,
                          4.49292898e-01,   4.46154237e-01,   4.43073720e-01,
                          4.39702570e-01,   4.36331421e-01,   4.33192760e-01,
                          4.29763496e-01,   4.26450461e-01,   4.23195541e-01,
                          4.19650048e-01,   4.16162640e-01,   4.12791491e-01,
                          4.09187853e-01,   4.05584216e-01,   4.02271181e-01,
                          3.98841888e-01,   3.95238250e-01,   3.91634613e-01,
                          3.88030976e-01,   3.84369195e-01,   3.80649328e-01,
                          3.77161920e-01,   3.73558283e-01,   3.69896501e-01,
                          3.66002262e-01,   3.62282366e-01,   3.58562469e-01,
                          3.54726344e-01,   3.50832075e-01,   3.46937805e-01,
                          3.43217939e-01,   3.39265555e-01,   3.35429400e-01,
                          3.31651390e-01,   3.27582777e-01,   3.23630393e-01,
                          3.19794238e-01,   3.15609366e-01,   3.11540753e-01,
                          3.07530254e-01,   3.03345352e-01,   2.99334854e-01,
                          2.95382470e-01,   2.91371971e-01,   2.87361473e-01,
                          2.83234715e-01,   2.79107958e-01,   2.74981201e-01,
                          2.70796329e-01,   2.66611457e-01,   2.62368470e-01,
                          2.58183569e-01,   2.53940582e-01,   2.49581337e-01,
                          2.45338336e-01,   2.41037220e-01,   2.36794218e-01,
                          2.32609347e-01,   2.28308216e-01,   2.23832726e-01,
                          2.19473481e-01,   2.15288609e-01,   2.10754991e-01,
                          2.06453860e-01,   2.02327117e-01,   1.97677255e-01,
                          1.93318009e-01,   1.89016879e-01,   1.84425145e-01,
                          1.80007771e-01,   1.75474167e-01,   1.71114922e-01,
                          1.66813791e-01,   1.62105814e-01,   1.57572195e-01,
                          1.53038576e-01,   1.48504958e-01,   1.44320086e-01,
                          1.39670223e-01,   1.35020360e-01,   1.30486742e-01,
                          1.25778764e-01,   1.21303275e-01,   1.16769657e-01,
                          1.12236038e-01,   1.07469931e-01,   1.02820069e-01,
                          9.84027013e-02,   9.36947167e-02,   8.89867321e-02,
                          8.45112428e-02,   7.99195021e-02,   7.52115175e-02,
                          7.05035329e-02,   6.59117922e-02,   6.14362992e-02,
                          5.67283146e-02,   5.21946996e-02,   4.76029627e-02,
                          4.29531001e-02,   3.84776071e-02,   3.36533748e-02,
                          2.90035140e-02,   2.43536513e-02,   1.96456667e-02,
                          1.51701747e-02,   1.03459423e-02,   5.69608063e-03,
                          1.22058869e-03,  -3.77801270e-03,  -8.31162836e-03,
                         -1.28452433e-02,  -1.77275985e-02,  -2.22030897e-02,
                         -2.67948285e-02,  -3.15609388e-02,  -3.62107977e-02,
                         -4.09769081e-02,  -4.55686450e-02,  -5.03347553e-02,
                         -5.51008619e-02,  -5.96926026e-02,  -6.42262176e-02,
                         -6.88179582e-02,  -7.35259429e-02,  -7.81758055e-02,
                         -8.28256682e-02,  -8.75917748e-02,  -9.21835080e-02,
                         -9.67752486e-02,  -1.01308867e-01,  -1.06016852e-01,
                         -1.10724837e-01,  -1.15200326e-01,  -1.19733945e-01,
                         -1.24267556e-01,  -1.28917426e-01,  -1.33683532e-01,
                         -1.38159022e-01,  -1.42750755e-01,  -1.47400618e-01,
                         -1.51759863e-01,  -1.56351611e-01,  -1.61117718e-01,
                         -1.65767580e-01,  -1.70243070e-01,  -1.74718559e-01,
                         -1.79368421e-01,  -1.83960155e-01,  -1.88493773e-01,
                         -1.93085521e-01,  -1.97502881e-01,  -2.02036500e-01,
                         -2.06686363e-01,  -2.10987478e-01,  -2.15404853e-01,
                         -2.19996586e-01,  -2.24472076e-01,  -2.28947580e-01,
                         -2.33364940e-01,  -2.37724185e-01,  -2.42199674e-01,
                         -2.46733293e-01,  -2.51266897e-01,  -2.55626142e-01,
                         -2.59985387e-01,  -2.64460891e-01,  -2.68878251e-01,
                         -2.73295641e-01,  -2.77654886e-01,  -2.81897873e-01,
                         -2.86199003e-01,  -2.90616363e-01,  -2.94859380e-01,
                         -2.99218625e-01,  -3.03577870e-01,  -3.07820857e-01,
                         -3.12121987e-01,  -3.16481233e-01,  -3.20666105e-01,
                         -3.24909091e-01,  -3.29268336e-01,  -3.33453208e-01,
                         -3.37870598e-01,  -3.41939211e-01,  -3.46007854e-01,
                         -3.50192726e-01,  -3.54203224e-01,  -3.58620584e-01,
                         -3.62921715e-01,  -3.67048472e-01,  -3.71407717e-01,
                         -3.75418216e-01,  -3.79312485e-01,  -3.83439243e-01,
                         -3.87624115e-01,  -3.91692728e-01,  -3.95703256e-01,
                         -3.99771869e-01,  -4.03724253e-01,  -4.07560378e-01,
                         -4.11745280e-01,  -4.15872008e-01,  -4.19708163e-01,
                         -4.23660547e-01,  -4.27554786e-01,  -4.31449056e-01,
                         -4.35285181e-01,  -4.39237565e-01,  -4.43131834e-01,
                         -4.46909845e-01,  -4.50862229e-01,  -4.54640239e-01,
                         -4.58243877e-01,  -4.61963773e-01,  -4.65799928e-01,
                         -4.69636053e-01,  -4.73355949e-01,  -4.76959586e-01,
                         -4.80679482e-01,  -4.84399348e-01,  -4.88061130e-01,
                         -4.91839141e-01,  -4.95210290e-01,  -4.98930186e-01,
                         -5.02591968e-01,  -5.05963087e-01,  -5.09566724e-01,
                         -5.13054132e-01,  -5.16657770e-01,  -5.20319521e-01,
                         -5.23632586e-01,  -5.27061820e-01,  -5.30432999e-01,
                         -5.33687890e-01,  -5.37233412e-01,  -5.40604591e-01,
                         -5.44033825e-01,  -5.47521234e-01,  -5.50659895e-01,
                         -5.53914785e-01,  -5.57053447e-01,  -5.60366452e-01,
                         -5.63563287e-01,  -5.66701889e-01,  -5.69956839e-01,
                         -5.72862983e-01,  -5.75885415e-01,  -5.79082191e-01,
                         -5.82162678e-01,  -5.85068882e-01,  -5.87975025e-01,
                         -5.90823054e-01,  -5.93845487e-01,  -5.96693516e-01,
                         -5.99541545e-01,  -6.02622092e-01,  -6.05470121e-01,
                         -6.08143806e-01,  -6.10817492e-01,  -6.13607407e-01,
                         -6.16281092e-01,  -6.19012833e-01,  -6.21628404e-01,
                         -6.24069571e-01,  -6.26801372e-01,  -6.29416943e-01,
                         -6.31916225e-01,  -6.34473681e-01,  -6.36856735e-01,
                         -6.39181614e-01,  -6.41680956e-01,  -6.43889606e-01,
                         -6.46272659e-01,  -6.48830116e-01,  -6.51096880e-01,
                         -6.53305590e-01,  -6.55456126e-01,  -6.57722950e-01,
                         -6.59815371e-01,  -6.61791563e-01,  -6.63884044e-01,
                         -6.65802121e-01,  -6.67952657e-01,  -6.70045078e-01,
                         -6.71963155e-01,  -6.73939347e-01,  -6.75973654e-01,
                         -6.77891731e-01,  -6.79635465e-01,  -6.81379139e-01,
                         -6.83239102e-01,  -6.85040891e-01,  -6.86784625e-01,
                         -6.88470185e-01,  -6.90039515e-01,  -6.91783190e-01,
                         -6.93236291e-01,  -6.94863737e-01,  -6.96549296e-01,
                         -6.97944283e-01,  -6.99571729e-01,  -7.00850427e-01,
                         -7.02129126e-01,  -7.03582227e-01,  -7.04919040e-01,
                         -7.06139624e-01,  -7.07360208e-01,  -7.08522677e-01,
                         -7.09801435e-01,  -7.11138248e-01,  -7.12184489e-01,
                         -7.13172555e-01,  -7.14160681e-01,  -7.15206861e-01,
                         -7.16136873e-01,  -7.17008710e-01,  -7.17938662e-01,
                         -7.18926787e-01,  -7.19798625e-01,  -7.20263600e-01,
                         -7.21193552e-01,  -7.22123563e-01,  -7.22646654e-01,
                         -7.23402262e-01,  -7.23867238e-01,  -7.24390328e-01,
                         -7.25204110e-01,  -7.25552797e-01,  -7.25901544e-01,
                         -7.26540923e-01,  -7.26889670e-01,  -7.27296531e-01,
                         -7.27528989e-01,  -7.27761507e-01,  -7.28110254e-01,
                         -7.28110254e-01,  -7.28400886e-01,  -7.28575230e-01,
                         -7.28691459e-01,  -7.28865862e-01,  -7.28691459e-01,
                         -7.28865862e-01,  -7.29040205e-01,  -7.28865862e-01,
                         -7.28749573e-01,  -7.28400886e-01,  -7.28110254e-01,
                         -7.28226483e-01,  -7.28052139e-01,  -7.27587163e-01,
                         -7.27354646e-01,  -7.27238417e-01,  -7.26831555e-01,
                         -7.26250291e-01,  -7.25843430e-01,  -7.25436568e-01,
                         -7.24913478e-01,  -7.24448502e-01,  -7.23809123e-01,
                         -7.23169744e-01,  -7.22356021e-01,  -7.21774817e-01,
                         -7.21135437e-01,  -7.20147371e-01,  -7.19507992e-01,
                         -7.18810499e-01,  -7.17764318e-01,  -7.17008710e-01,
                         -7.16078699e-01,  -7.14800000e-01,  -7.13986278e-01,
                         -7.12940097e-01,  -7.11835742e-01,  -7.10731387e-01,
                         -7.09510803e-01,  -7.08348334e-01,  -7.07243979e-01,
                         -7.06139624e-01,  -7.04860926e-01,  -7.03465998e-01,
                         -7.02245414e-01,  -7.00966656e-01,  -6.99571729e-01,
                         -6.98293030e-01,  -6.96898043e-01,  -6.95212483e-01,
                         -6.93759382e-01,  -6.92364454e-01,  -6.90795124e-01,
                         -6.89167678e-01,  -6.87540174e-01,  -6.85796499e-01,
                         -6.84227169e-01,  -6.82715952e-01,  -6.80972278e-01,
                         -6.79344833e-01,  -6.77426755e-01,  -6.75799310e-01,
                         -6.73997462e-01,  -6.72137558e-01,  -6.70510054e-01,
                         -6.68417633e-01,  -6.66673958e-01,  -6.64988399e-01,
                         -6.62954032e-01,  -6.60919726e-01,  -6.59001648e-01,
                         -6.57141745e-01,  -6.55165553e-01,  -6.52898729e-01,
                         -6.50806308e-01,  -6.48772001e-01,  -6.46679521e-01,
                         -6.44761443e-01,  -6.42494678e-01,  -6.40402198e-01,
                         -6.38309777e-01,  -6.36042953e-01,  -6.33834302e-01,
                         -6.31393135e-01,  -6.29184425e-01,  -6.26859486e-01,
                         -6.24360204e-01,  -6.22093379e-01,  -6.19884729e-01,
                         -6.17501676e-01,  -6.15118623e-01,  -6.12677395e-01,
                         -6.10178113e-01,  -6.07736945e-01,  -6.05121374e-01,
                         -6.02680206e-01,  -6.00122809e-01,  -5.97681642e-01,
                         -5.95066071e-01,  -5.92334270e-01,  -5.89951217e-01,
                         -5.87335706e-01,  -5.84778249e-01,  -5.82220852e-01,
                         -5.79547167e-01,  -5.76931596e-01,  -5.74199796e-01,
                         -5.71526170e-01,  -5.69026828e-01,  -5.66295028e-01,
                         -5.63388884e-01,  -5.60657084e-01,  -5.57925284e-01,
                         -5.55309772e-01,  -5.52403569e-01,  -5.49671769e-01,
                         -5.46881855e-01,  -5.43801367e-01,  -5.41185796e-01,
                         -5.38512111e-01,  -5.35722196e-01,  -5.32932281e-01,
                         -5.29968023e-01,  -5.27061820e-01,  -5.24213791e-01,
                         -5.21365762e-01,  -5.18517733e-01,  -5.15553415e-01,
                         -5.12647271e-01,  -5.09741127e-01,  -5.06660581e-01,
                         -5.03870666e-01,  -5.00906348e-01,  -4.97651458e-01,
                         -4.94745314e-01,  -4.91664767e-01,  -4.88526106e-01,
                         -4.85445589e-01,  -4.82481301e-01,  -4.79517013e-01,
                         -4.76436466e-01,  -4.73297805e-01,  -4.70333517e-01,
                         -4.67136741e-01,  -4.63881850e-01,  -4.60859448e-01,
                         -4.57604527e-01,  -4.54407752e-01,  -4.51327205e-01,
                         -4.48130429e-01,  -4.44759279e-01,  -4.41446275e-01,
                         -4.38133240e-01,  -4.34878320e-01,  -4.31507170e-01,
                         -4.28019792e-01,  -4.24939245e-01,  -4.21568096e-01,
                         -4.18138832e-01,  -4.14825797e-01,  -4.11338419e-01,
                         -4.07967269e-01,  -4.04596120e-01,  -4.01224971e-01,
                         -3.97970051e-01,  -3.94482642e-01,  -3.91053379e-01,
                         -3.87740344e-01,  -3.84194851e-01,  -3.80765557e-01,
                         -3.77394408e-01,  -3.73848885e-01,  -3.70535880e-01,
                         -3.67106587e-01,  -3.63502949e-01,  -3.60015541e-01,
                         -3.56470048e-01,  -3.52982640e-01,  -3.49495232e-01,
                         -3.45949709e-01,  -3.42346072e-01,  -3.38800550e-01,
                         -3.35138798e-01,  -3.31477016e-01,  -3.27989638e-01,
                         -3.24444115e-01,  -3.20724219e-01,  -3.17178696e-01,
                         -3.13691318e-01,  -3.10029536e-01,  -3.06425899e-01,
                         -3.02706003e-01,  -2.98986107e-01,  -2.95324355e-01,
                         -2.91604459e-01,  -2.88000822e-01,  -2.84339041e-01,
                         -2.80619174e-01,  -2.76899278e-01,  -2.73121268e-01,
                         -2.69226998e-01,  -2.65448987e-01,  -2.61670977e-01,
                         -2.57834852e-01,  -2.54056841e-01,  -2.50220686e-01,
                         -2.46268302e-01,  -2.42432177e-01,  -2.38596037e-01,
                         -2.34527409e-01,  -2.30749398e-01,  -2.26971388e-01,
                         -2.23019004e-01,  -2.19182864e-01,  -2.15230480e-01,
                         -2.11452469e-01,  -2.07500085e-01,  -2.03431457e-01,
                         -1.99711561e-01,  -1.95642933e-01,  -1.91574305e-01,
                         -1.87796295e-01,  -1.83785796e-01,  -1.79717168e-01,
                         -1.75706655e-01,  -1.71870515e-01,  -1.67918131e-01,
                         -1.63849503e-01,  -1.60013378e-01,  -1.56119108e-01,
                         -1.52050480e-01,  -1.48156226e-01,  -1.44261971e-01,
                         -1.40309587e-01,  -1.36240959e-01,  -1.32114202e-01,
                         -1.28161818e-01,  -1.24151312e-01,  -1.20024562e-01,
                         -1.15955934e-01,  -1.11945428e-01,  -1.08051166e-01,
                         -1.03982538e-01,  -9.97976586e-02,  -9.57871526e-02,
                         -9.18347687e-02,  -8.79405141e-02,  -8.36975127e-02,
                         -7.94545114e-02,  -7.56765008e-02,  -7.15497509e-02,
                         -6.74229935e-02,  -6.35287389e-02,  -5.94019853e-02,
                         -5.54496013e-02,  -5.13228513e-02,  -4.71379757e-02,
                         -4.32437137e-02,  -3.91750857e-02,  -3.49902101e-02,
                         -3.07472125e-02,  -2.66204588e-02,  -2.26099528e-02,
                         -1.84832010e-02,  -1.43564483e-02,  -1.02296965e-02,
                         -6.10294379e-03,  -2.15056119e-03,   1.91806804e-03,
                          6.04482042e-03,   1.01715727e-02,   1.44145722e-02,
                          1.85994469e-02,   2.26680767e-02,   2.66785827e-02,
                          3.09215821e-02,   3.51064578e-02,   3.89425941e-02,
                          4.31274697e-02,   4.72542197e-02,   5.11484817e-02,
                          5.53914793e-02,   5.96344769e-02,   6.36449829e-02,
                          6.77136108e-02,   7.17822462e-02,   7.59671181e-02,
                          8.00938681e-02,   8.41043741e-02,   8.82892534e-02,
                          9.25903767e-02,   9.66008827e-02,   1.00611389e-01,
                          1.04680017e-01,   1.08690523e-01,   1.12584777e-01,
                          1.16769657e-01,   1.20838284e-01,   1.24790668e-01,
                          1.28917426e-01,   1.32869810e-01,   1.36822179e-01,
                          1.40948936e-01,   1.45133808e-01,   1.49144322e-01,
                          1.52980462e-01,   1.56932831e-01,   1.61175832e-01,
                          1.65070102e-01,   1.68906227e-01,   1.72916740e-01,
                          1.76869124e-01,   1.80879623e-01,   1.84890136e-01,
                          1.88842520e-01,   1.92853019e-01,   1.96805403e-01,
                          2.00757787e-01,   2.04710171e-01,   2.08953172e-01,
                          2.12963670e-01,   2.16683567e-01,   2.20519707e-01,
                          2.24530205e-01,   2.28598833e-01,   2.32551217e-01,
                          2.36387357e-01,   2.40281612e-01,   2.44175866e-01,
                          2.48012006e-01,   2.51848131e-01,   2.55800515e-01,
                          2.59578526e-01,   2.63298422e-01,   2.67192692e-01,
                          2.71086961e-01,   2.74806827e-01,   2.78526723e-01,
                          2.82304734e-01,   2.86082745e-01,   2.89860755e-01,
                          2.93580651e-01,   2.97474921e-01,   3.01136672e-01,
                          3.04740310e-01,   3.08576465e-01,   3.12238216e-01,
                          3.15899998e-01,   3.19678009e-01,   3.23397905e-01,
                          3.27175915e-01,   3.30779552e-01,   3.34208816e-01,
                          3.37928712e-01,   3.41590464e-01,   3.45194131e-01,
                          3.48681509e-01,   3.52052659e-01,   3.55598181e-01,
                          3.59201819e-01,   3.62747341e-01,   3.66234750e-01,
                          3.69664013e-01,   3.73093277e-01,   3.76522571e-01,
                          3.79893720e-01,   3.83322984e-01,   3.86694133e-01,
                          3.90065283e-01,   3.93436432e-01,   3.96923840e-01,
                          4.00469363e-01,   4.03724253e-01,   4.07037288e-01,
                          4.10350323e-01,   4.13547099e-01,   4.16801989e-01,
                          4.19998765e-01,   4.23311800e-01,   4.26624835e-01,
                          4.29879725e-01,   4.32902128e-01,   4.36040789e-01,
                          4.39586312e-01,   4.42724973e-01,   4.45573002e-01,
                          4.48827922e-01,   4.51966584e-01,   4.54988986e-01,
                          4.58243877e-01,   4.61382538e-01,   4.64463085e-01,
                          4.67427373e-01,   4.70391661e-01,   4.73414063e-01,
                          4.76320237e-01,   4.79342639e-01,   4.82306927e-01,
                          4.85096842e-01,   4.88061130e-01,   4.91025418e-01,
                          4.93873447e-01,   4.96721506e-01,   4.99453276e-01,
                          5.02243221e-01,   5.05033135e-01,   5.07764935e-01,
                          5.10554850e-01,   5.13112247e-01,   5.15844047e-01,
                          5.18517733e-01,   5.21133244e-01,   5.23865044e-01,
                          5.26422501e-01,   5.29212415e-01,   5.31711698e-01,
                          5.33920407e-01,   5.36652207e-01,   5.39209604e-01,
                          5.41708887e-01,   5.44266343e-01,   5.46533167e-01,
                          5.48858047e-01,   5.51357388e-01,   5.53624153e-01,
                          5.56007206e-01,   5.58506548e-01,   5.60598969e-01,
                          5.62865794e-01,   5.65423191e-01,   5.67631900e-01,
                          5.69840550e-01,   5.72165489e-01,   5.74257970e-01,
                          5.76582849e-01,   5.78791559e-01,   5.80825865e-01,
                          5.82976460e-01,   5.84894478e-01,   5.87045074e-01,
                          5.89137495e-01,   5.91171801e-01,   5.93322396e-01,
                          5.95240414e-01,   5.97100377e-01,   5.99134684e-01,
                          6.01110876e-01,   6.03028953e-01,   6.04947031e-01,
                          6.06632590e-01,   6.08550668e-01,   6.10468745e-01,
                          6.12096190e-01,   6.13839865e-01,   6.15699828e-01,
                          6.17443562e-01,   6.19071007e-01,   6.20814681e-01,
                          6.22616529e-01,   6.24302089e-01,   6.25813305e-01,
                          6.27498865e-01,   6.29126310e-01,   6.30637527e-01,
                          6.32148743e-01,   6.33543670e-01,   6.35113001e-01,
                          6.36566103e-01,   6.37961030e-01,   6.39414132e-01,
                          6.40809119e-01,   6.42145932e-01,   6.43540859e-01,
                          6.44935846e-01,   6.46098316e-01,   6.47609532e-01,
                          6.48772001e-01,   6.49760067e-01,   6.51155055e-01,
                          6.52317524e-01,   6.53421819e-01,   6.54700577e-01,
                          6.55921161e-01,   6.57025456e-01,   6.58071697e-01,
                          6.58943534e-01,   6.60164118e-01,   6.61326587e-01,
                          6.62547171e-01,   6.63419068e-01,   6.64174616e-01,
                          6.65337086e-01,   6.66150808e-01,   6.67080820e-01,
                          6.68243289e-01,   6.69057012e-01,   6.69928849e-01,
                          6.70800686e-01,   6.71498179e-01,   6.72486246e-01,
                          6.73474371e-01,   6.74113750e-01,   6.75043702e-01,
                          6.75741196e-01,   6.76438630e-01,   6.77194238e-01,
                          6.77775502e-01,   6.78472996e-01,   6.79228544e-01,
                          6.79809809e-01,   6.80274785e-01,   6.81088507e-01,
                          6.81786001e-01,   6.82309091e-01,   6.82890356e-01,
                          6.83180928e-01,   6.83529675e-01,   6.84052825e-01,
                          6.84459686e-01,   6.85099006e-01,   6.85563982e-01,
                          6.85796499e-01,   6.86203361e-01,   6.86377764e-01,
                          6.86610222e-01,   6.87075198e-01,   6.87133312e-01,
                          6.87482059e-01,   6.87714577e-01,   6.87714577e-01,
                          6.88005209e-01,   6.88121438e-01,   6.88295782e-01,
                          6.88702643e-01,   6.88760817e-01,   6.88528299e-01,
                          6.88586414e-01,   6.88644528e-01,   6.88702643e-01,
                          6.88760817e-01,   6.88586414e-01,   6.88470185e-01,
                          6.88470185e-01,   6.88237667e-01,   6.88121438e-01,
                          6.88121438e-01,   6.88005209e-01,   6.87888920e-01,
                          6.87714577e-01,   6.87365830e-01,   6.87017083e-01,
                          6.86784625e-01,   6.86726451e-01,   6.86203361e-01,
                          6.85680270e-01,   6.85563982e-01,   6.85331523e-01,
                          6.84866548e-01,   6.84459686e-01,   6.83936536e-01,
                          6.83471560e-01,   6.83122814e-01,   6.82541609e-01,
                          6.81902230e-01,   6.81437254e-01,   6.80856049e-01,
                          6.80100441e-01,   6.79577291e-01,   6.79054201e-01,
                          6.78298593e-01,   6.77659273e-01,   6.76787376e-01,
                          6.75973654e-01,   6.75334334e-01,   6.74288094e-01,
                          6.73590600e-01,   6.72834992e-01,   6.71672523e-01,
                          6.70858800e-01,   6.69812620e-01,   6.68766379e-01,
                          6.68010771e-01,   6.66732073e-01,   6.65627718e-01,
                          6.64581537e-01,   6.63302779e-01,   6.62198424e-01,
                          6.60861611e-01,   6.59699142e-01,   6.58594787e-01,
                          6.57316089e-01,   6.55921161e-01,   6.54293716e-01,
                          6.53131247e-01,   6.52026892e-01,   6.50457561e-01,
                          6.49178863e-01,   6.47609532e-01,   6.45749569e-01,
                          6.44470870e-01,   6.43017769e-01,   6.41332209e-01,
                          6.39704764e-01,   6.37961030e-01,   6.36333585e-01,
                          6.34648025e-01,   6.32904351e-01,   6.31044388e-01,
                          6.29126310e-01,   6.27498865e-01,   6.25697017e-01,
                          6.23720825e-01,   6.21802807e-01,   6.19884729e-01,
                          6.18082881e-01,   6.16164804e-01,   6.14072382e-01,
                          6.12096190e-01,   6.09829366e-01,   6.07795060e-01,
                          6.05876982e-01,   6.03552043e-01,   6.01517737e-01,
                          5.99309087e-01,   5.96809745e-01,   5.94659209e-01,
                          5.92566788e-01,   5.90299964e-01,   5.88091254e-01,
                          5.85766375e-01,   5.83150804e-01,   5.80709636e-01,
                          5.78500926e-01,   5.76001644e-01,   5.73269844e-01,
                          5.70886791e-01,   5.68329394e-01,   5.65771937e-01,
                          5.63214540e-01,   5.60366452e-01,   5.57809055e-01,
                          5.55135369e-01,   5.52287340e-01,   5.49613655e-01,
                          5.46707511e-01,   5.43801367e-01,   5.41069567e-01,
                          5.38337767e-01,   5.35431623e-01,   5.32409191e-01,
                          5.29561162e-01,   5.26713133e-01,   5.23574471e-01,
                          5.20668268e-01,   5.17645895e-01,   5.14449120e-01,
                          5.11426687e-01,   5.08229911e-01,   5.05149364e-01,
                          5.02068818e-01,   4.98872042e-01,   4.95675266e-01,
                          4.92420375e-01,   4.89456087e-01,   4.86375540e-01,
                          4.83062536e-01,   4.79749501e-01,   4.76378351e-01,
                          4.73065317e-01,   4.69636053e-01,   4.66148645e-01,
                          4.62893754e-01,   4.59696978e-01,   4.56267685e-01,
                          4.52838421e-01,   4.49351013e-01,   4.45805520e-01,
                          4.42376226e-01,   4.39063221e-01,   4.35459554e-01,
                          4.31681544e-01,   4.28077906e-01,   4.24299896e-01,
                          4.20696259e-01,   4.17266965e-01,   4.13488954e-01,
                          4.09769088e-01,   4.06107306e-01,   4.02445555e-01,
                          3.98783773e-01,   3.95063877e-01,   3.91402125e-01,
                          3.87682229e-01,   3.83787960e-01,   3.79835606e-01,
                          3.76115710e-01,   3.72337699e-01,   3.68327171e-01,
                          3.64549160e-01,   3.60713035e-01,   3.56586277e-01,
                          3.52750152e-01,   3.48855883e-01,   3.44845384e-01,
                          3.41009259e-01,   3.37056875e-01,   3.32988232e-01,
                          3.28977734e-01,   3.25083464e-01,   3.21131080e-01,
                          3.16946208e-01,   3.12993824e-01,   3.08867067e-01,
                          3.04624081e-01,   3.00671697e-01,   2.96544939e-01,
                          2.92476326e-01,   2.88407683e-01,   2.84048438e-01,
                          2.79921681e-01,   2.75969297e-01,   2.71726310e-01,
                          2.67541438e-01,   2.63240308e-01,   2.59113550e-01,
                          2.55044937e-01,   2.50743806e-01,   2.46558920e-01,
                          2.42432177e-01,   2.38363549e-01,   2.34004304e-01,
                          2.29470685e-01,   2.25402057e-01,   2.20984682e-01,
                          2.16451064e-01,   2.12440565e-01,   2.08255693e-01,
                          2.03896448e-01,   1.99479073e-01,   1.95061699e-01,
                          1.90934956e-01,   1.86633825e-01,   1.82100222e-01,
                          1.77857220e-01,   1.73497975e-01,   1.68964356e-01,
                          1.64663240e-01,   1.60362110e-01,   1.56060994e-01,
                          1.51759863e-01,   1.47342503e-01,   1.42808884e-01,
                          1.38449639e-01,   1.34032264e-01,   1.29498661e-01,
                          1.25197530e-01,   1.20896406e-01,   1.16362795e-01,
                          1.12003550e-01,   1.07586183e-01,   1.03285059e-01,
                          9.89258140e-02,   9.42178294e-02,   8.98004547e-02,
                          8.54412094e-02,   8.09075981e-02,   7.65483528e-02,
                          7.20147341e-02,   6.76554888e-02,   6.33543655e-02,
                          5.87045066e-02,   5.42290136e-02,   4.98697683e-02,
                          4.52780314e-02,   4.07444164e-02,   3.62689234e-02,
                          3.18515524e-02,   2.73179393e-02,   2.29005702e-02,
                          1.85994469e-02,   1.41239557e-02,   9.59033985e-03,
                          4.94047813e-03,   5.23109455e-04,  -3.71988956e-03,
                         -8.36975127e-03,  -1.29033662e-02,  -1.73788592e-02,
                         -2.17381045e-02,  -2.60973498e-02,  -3.07472125e-02,
                         -3.52808274e-02,  -3.96400727e-02,  -4.40574400e-02,
                         -4.84748110e-02,  -5.31246737e-02,  -5.74839190e-02,
                         -6.16687946e-02,  -6.63186535e-02,  -7.06778988e-02,
                         -7.49209002e-02,  -7.94545114e-02,  -8.38137567e-02,
                         -8.82311314e-02,  -9.25903767e-02,  -9.68915001e-02,
                         -1.01425111e-01,  -1.06074974e-01,  -1.10492341e-01,
                         -1.14793465e-01,  -1.19268954e-01,  -1.23744451e-01,
                         -1.28103688e-01,  -1.32404819e-01,  -1.36822179e-01,
                         -1.41239554e-01,  -1.45598799e-01,  -1.50074288e-01,
                         -1.54549778e-01,  -1.58792779e-01,  -1.63152024e-01,
                         -1.67685643e-01,  -1.72044888e-01,  -1.76404133e-01,
                         -1.80705264e-01,  -1.85064510e-01,  -1.89481869e-01,
                         -1.93783000e-01,  -1.98258489e-01,  -2.02559605e-01,
                         -2.06744477e-01,  -2.11045608e-01,  -2.15288609e-01,
                         -2.19705969e-01,  -2.24065214e-01,  -2.28250101e-01,
                         -2.32725590e-01,  -2.36968592e-01,  -2.41211578e-01,
                         -2.45628953e-01,  -2.49755710e-01,  -2.54114956e-01,
                         -2.58648574e-01,  -2.62833446e-01,  -2.67018318e-01,
                         -2.71261305e-01,  -2.75504321e-01,  -2.79805452e-01,
                         -2.83990324e-01,  -2.88233310e-01,  -2.92476326e-01,
                         -2.96719313e-01,  -3.00904185e-01,  -3.04972827e-01,
                         -3.09157699e-01,  -3.13342571e-01,  -3.17585558e-01,
                         -3.21828574e-01,  -3.25839072e-01,  -3.30082059e-01,
                         -3.34383190e-01,  -3.38509947e-01,  -3.42636704e-01,
                         -3.46763462e-01,  -3.50948334e-01,  -3.54958832e-01,
                         -3.59027445e-01,  -3.63154203e-01,  -3.67048472e-01,
                         -3.71175230e-01,  -3.75301987e-01,  -3.79254371e-01,
                         -3.83381099e-01,  -3.87159139e-01,  -3.91227752e-01,
                         -3.95586997e-01,  -3.99481267e-01,  -4.03491765e-01,
                         -4.07502264e-01,  -4.11164045e-01,  -4.15174544e-01,
                         -4.19185042e-01,  -4.23021197e-01,  -4.26973581e-01,
                         -4.30925936e-01,  -4.34878320e-01,  -4.38656330e-01,
                         -4.42492485e-01,  -4.46444869e-01,  -4.50280994e-01,
                         -4.54117149e-01,  -4.57895160e-01,  -4.61673170e-01,
                         -4.65625554e-01,  -4.69519794e-01,  -4.73181576e-01,
                         -4.76959586e-01,  -4.80737597e-01,  -4.84341234e-01,
                         -4.87886757e-01,  -4.91722882e-01,  -4.95268404e-01,
                         -4.98872042e-01,  -5.02708197e-01,  -5.06369948e-01,
                         -5.10031700e-01,  -5.13635337e-01,  -5.17122746e-01,
                         -5.20726383e-01,  -5.24155676e-01,  -5.27526855e-01,
                         -5.31072378e-01,  -5.34559727e-01,  -5.38163364e-01,
                         -5.41476429e-01,  -5.44731319e-01,  -5.48334956e-01,
                         -5.51531732e-01,  -5.54670393e-01,  -5.58274031e-01,
                         -5.61645210e-01,  -5.64783871e-01,  -5.68154991e-01,
                         -5.71293652e-01,  -5.74199796e-01,  -5.77454746e-01,
                         -5.80709636e-01,  -5.83790183e-01,  -5.87045074e-01,
                         -5.90241849e-01,  -5.93206108e-01,  -5.96286654e-01,
                         -5.99250972e-01,  -6.02273345e-01,  -6.05295777e-01,
                         -6.08085692e-01,  -6.10875607e-01,  -6.13839865e-01,
                         -6.16862297e-01,  -6.19652212e-01,  -6.22384012e-01,
                         -6.25232041e-01,  -6.28080070e-01,  -6.30869985e-01,
                         -6.33601785e-01,  -6.36275470e-01,  -6.38949156e-01,
                         -6.41448438e-01,  -6.44064009e-01,  -6.46853924e-01,
                         -6.49236977e-01,  -6.51561916e-01,  -6.54235542e-01,
                         -6.56676769e-01,  -6.59117937e-01,  -6.61500990e-01,
                         -6.63709641e-01,  -6.66034579e-01,  -6.68533862e-01,
                         -6.70800686e-01,  -6.72776878e-01,  -6.74985588e-01,
                         -6.77252352e-01,  -6.79344833e-01,  -6.81379139e-01,
                         -6.83471560e-01,  -6.85563982e-01,  -6.87482059e-01,
                         -6.89225793e-01,  -6.91201985e-01,  -6.93061888e-01,
                         -6.94805622e-01,  -6.96723700e-01,  -6.98409259e-01,
                         -7.00211048e-01,  -7.01954782e-01,  -7.03465998e-01,
                         -7.05209672e-01,  -7.06837118e-01,  -7.08232105e-01,
                         -7.09801435e-01,  -7.11312592e-01,  -7.12998211e-01,
                         -7.14335024e-01,  -7.15555608e-01,  -7.17008710e-01,
                         -7.18229294e-01,  -7.19624221e-01,  -7.20786691e-01,
                         -7.21949160e-01,  -7.23460376e-01,  -7.24448502e-01,
                         -7.25320339e-01,  -7.26599038e-01,  -7.27470875e-01,
                         -7.28517115e-01,  -7.29563355e-01,  -7.30435193e-01,
                         -7.31307030e-01,  -7.32004523e-01,  -7.32760131e-01,
                         -7.33748198e-01,  -7.34561920e-01,  -7.35259414e-01,
                         -7.35666275e-01,  -7.36305654e-01,  -7.37061203e-01,
                         -7.37642467e-01,  -7.38107443e-01,  -7.38572419e-01,
                         -7.39095569e-01,  -7.39502430e-01,  -7.39793003e-01,
                         -7.40374267e-01,  -7.40548611e-01,  -7.40606725e-01,
                         -7.41013587e-01,  -7.41246104e-01,  -7.41304219e-01,
                         -7.41478622e-01,  -7.41594851e-01,  -7.41769195e-01,
                         -7.41652966e-01,  -7.41478622e-01,  -7.41362333e-01,
                         -7.41071761e-01,  -7.41013587e-01,  -7.40897357e-01,
                         -7.40548611e-01,  -7.40374267e-01,  -7.40199864e-01,
                         -7.39909291e-01,  -7.39560544e-01,  -7.39037395e-01,
                         -7.38630533e-01,  -7.38165557e-01,  -7.37642467e-01,
                         -7.37061203e-01,  -7.36363769e-01,  -7.35724390e-01,
                         -7.35259414e-01,  -7.34678149e-01,  -7.33748198e-01,
                         -7.33108819e-01,  -7.32353270e-01,  -7.31597662e-01,
                         -7.30725765e-01,  -7.29795814e-01,  -7.28923976e-01,
                         -7.27877736e-01,  -7.26831555e-01,  -7.26075947e-01,
                         -7.25145936e-01,  -7.23925352e-01,  -7.22879171e-01,
                         -7.21716702e-01,  -7.20496118e-01,  -7.19566107e-01,
                         -7.18171179e-01,  -7.16776192e-01,  -7.15788126e-01,
                         -7.14509428e-01,  -7.13056326e-01,  -7.11777627e-01,
                         -7.10557044e-01,  -7.08987713e-01,  -7.07418382e-01,
                         -7.06139624e-01,  -7.04570293e-01,  -7.03233480e-01,
                         -7.02012897e-01,  -7.00327337e-01,  -6.98525488e-01,
                         -6.96956158e-01,  -6.95503116e-01,  -6.93933785e-01,
                         -6.92190051e-01,  -6.90562606e-01,  -6.88818932e-01,
                         -6.86900854e-01,  -6.84982777e-01,  -6.83122814e-01,
                         -6.81379139e-01,  -6.79519176e-01,  -6.77601099e-01,
                         -6.75566792e-01,  -6.73358142e-01,  -6.71614408e-01,
                         -6.69870734e-01,  -6.67662024e-01,  -6.65569603e-01,
                         -6.63477182e-01,  -6.61326587e-01,  -6.59234166e-01,
                         -6.56851113e-01,  -6.54758692e-01,  -6.52608097e-01,
                         -6.50341332e-01,  -6.48132622e-01,  -6.45807683e-01,
                         -6.43773377e-01,  -6.41506553e-01,  -6.39007270e-01,
                         -6.36798561e-01,  -6.34357393e-01,  -6.31916225e-01,
                         -6.29823804e-01,  -6.27266347e-01,  -6.24767065e-01,
                         -6.22325897e-01,  -6.20000958e-01,  -6.17617905e-01,
                         -6.15060508e-01,  -6.12677395e-01,  -6.10119998e-01,
                         -6.07504427e-01,  -6.05005145e-01,  -6.02215230e-01,
                         -5.99715948e-01,  -5.97158492e-01,  -5.94368577e-01,
                         -5.91927409e-01,  -5.89253724e-01,  -5.86521924e-01,
                         -5.83906412e-01,  -5.81174612e-01,  -5.78500926e-01,
                         -5.75769126e-01,  -5.73037326e-01,  -5.70421815e-01,
                         -5.67399383e-01,  -5.64493239e-01,  -5.61819553e-01,
                         -5.59029639e-01,  -5.56239724e-01,  -5.53275466e-01,
                         -5.50601780e-01,  -5.47753751e-01,  -5.44556975e-01,
                         -5.41708887e-01,  -5.38918972e-01,  -5.36012828e-01,
                         -5.33106685e-01,  -5.29909909e-01,  -5.27003706e-01,
                         -5.24097562e-01,  -5.20842671e-01,  -5.17878354e-01,
                         -5.14972210e-01,  -5.11891663e-01,  -5.08694887e-01,
                         -5.05614340e-01,  -5.02591968e-01,  -4.99278933e-01,
                         -4.96140271e-01,  -4.93175983e-01,  -4.89921063e-01,
                         -4.86782402e-01,  -4.83527511e-01,  -4.80214477e-01,
                         -4.77133960e-01,  -4.73995298e-01,  -4.70682263e-01,
                         -4.67427373e-01,  -4.64230597e-01,  -4.60975677e-01,
                         -4.57720786e-01,  -4.54465866e-01,  -4.51094717e-01,
                         -4.47956055e-01,  -4.44759279e-01,  -4.41388130e-01,
                         -4.37842607e-01,  -4.34529603e-01,  -4.31390941e-01,
                         -4.27903533e-01,  -4.24474269e-01,  -4.21393722e-01,
                         -4.17964458e-01,  -4.14535195e-01,  -4.11164045e-01,
                         -4.07734752e-01,  -4.04479861e-01,  -4.01108712e-01,
                         -3.97679448e-01,  -3.94250154e-01,  -3.90588403e-01,
                         -3.87217253e-01,  -3.83904219e-01,  -3.80300581e-01,
                         -3.77045661e-01,  -3.73558283e-01,  -3.70012760e-01,
                         -3.66583496e-01,  -3.62979829e-01,  -3.59550565e-01,
                         -3.56121302e-01,  -3.52459520e-01,  -3.49088371e-01,
                         -3.45600992e-01,  -3.41881096e-01,  -3.38335574e-01,
                         -3.34848166e-01,  -3.31070155e-01,  -3.27292144e-01,
                         -3.23746622e-01,  -3.20084870e-01,  -3.16306859e-01,
                         -3.12703222e-01,  -3.08925211e-01,  -3.05321544e-01,
                         -3.01776022e-01,  -2.97881782e-01,  -2.94220001e-01,
                         -2.90383875e-01,  -2.86547750e-01,  -2.83176601e-01,
                         -2.79398561e-01,  -2.75562435e-01,  -2.71842539e-01,
                         -2.67948300e-01,  -2.64228404e-01,  -2.60508507e-01,
                         -2.56614238e-01,  -2.53010601e-01,  -2.49290720e-01,
                         -2.45454580e-01,  -2.41560325e-01,  -2.37782314e-01,
                         -2.34062418e-01,  -2.30284408e-01,  -2.26448268e-01,
                         -2.22612143e-01,  -2.19008490e-01,  -2.15346724e-01,
                         -2.11394340e-01,  -2.07558215e-01,  -2.03838319e-01,
                         -2.00002179e-01,  -1.96224168e-01,  -1.92446157e-01,
                         -1.88784391e-01,  -1.85064510e-01,  -1.81112126e-01,
                         -1.77275985e-01,  -1.73207358e-01,  -1.69371217e-01,
                         -1.65941939e-01,  -1.61931440e-01,  -1.57979056e-01,
                         -1.54317290e-01,  -1.50423035e-01,  -1.46528766e-01,
                         -1.42750755e-01,  -1.38972744e-01,  -1.34962246e-01,
                         -1.31009862e-01,  -1.27348095e-01,  -1.23395711e-01,
                         -1.19385205e-01,  -1.15665317e-01,  -1.11596689e-01,
                         -1.07760549e-01,  -1.03866287e-01,  -9.98557806e-02,
                         -9.59034041e-02,  -9.18928981e-02,  -8.80567580e-02,
                         -8.42206255e-02,  -8.01519975e-02,  -7.61996135e-02,
                         -7.23053515e-02,  -6.84110895e-02,  -6.44587129e-02,
                         -6.03900813e-02,  -5.64958230e-02,  -5.24853170e-02,
                         -4.87073027e-02,  -4.46967967e-02,  -4.05700430e-02,
                         -3.69664021e-02,  -3.31302658e-02,  -2.90035140e-02,
                         -2.50511300e-02,  -2.11568717e-02,  -1.72626115e-02,
                         -1.32521065e-02,  -9.47409403e-03,  -5.52171096e-03,
                         -1.33683532e-03,   2.26680771e-03,   6.21919008e-03,
                          1.03459423e-02,   1.41820787e-02,   1.82507075e-02,
                          2.19705980e-02,   2.57486105e-02,   2.99334861e-02,
                          3.36533748e-02,   3.74313891e-02,   4.15000170e-02,
                          4.53361534e-02,   4.93466593e-02,   5.32990433e-02,
                          5.71933016e-02,   6.11456819e-02,   6.50980696e-02,
                          6.90504462e-02,   7.29447082e-02,   7.67808408e-02,
                          8.06751028e-02,   8.46274868e-02,   8.86961147e-02,
                          9.25322548e-02,   9.63102654e-02,   1.00204520e-01,
                          1.04156904e-01,   1.08225532e-01,   1.12236038e-01,
                          1.16188422e-01,   1.19966440e-01,   1.23802572e-01,
                          1.27929330e-01,   1.31939828e-01,   1.35717839e-01,
                          1.39553979e-01,   1.43506363e-01,   1.47633120e-01,
                          1.51643619e-01,   1.55596003e-01,   1.59548387e-01,
                          1.63384527e-01,   1.67336911e-01,   1.71463653e-01,
                          1.75299793e-01,   1.79194048e-01,   1.83204561e-01,
                          1.87040687e-01,   1.90934956e-01,   1.94945455e-01,
                          1.98839724e-01,   2.02617735e-01,   2.06395745e-01,
                          2.10464373e-01,   2.14358628e-01,   2.18136638e-01,
                          2.21972778e-01,   2.25750789e-01,   2.29586929e-01,
                          2.33423069e-01,   2.37259209e-01,   2.41211578e-01,
                          2.44989604e-01,   2.48709485e-01,   2.52487510e-01,
                          2.56381750e-01,   2.60159761e-01,   2.63879657e-01,
                          2.67773926e-01,   2.71493822e-01,   2.75155574e-01,
                          2.78933585e-01,   2.82595366e-01,   2.86431491e-01,
                          2.90325761e-01,   2.93929398e-01,   2.97649294e-01,
                          3.01427305e-01,   3.05205315e-01,   3.08983326e-01,
                          3.12703222e-01,   3.16597462e-01,   3.20375472e-01,
                          3.23979139e-01,   3.27757150e-01,   3.31360787e-01,
                          3.35080683e-01,   3.38916808e-01,   3.42636704e-01,
                          3.46298456e-01,   3.49843979e-01,   3.53505760e-01,
                          3.57167512e-01,   3.60945523e-01,   3.64549160e-01,
                          3.68094683e-01,   3.71814579e-01,   3.75243843e-01,
                          3.78673136e-01,   3.82625520e-01,   3.86229157e-01,
                          3.89716536e-01,   3.93320203e-01,   3.96749467e-01,
                          4.00353104e-01,   4.03956741e-01,   4.07327890e-01,
                          4.10873413e-01,   4.14360821e-01,   4.17906344e-01,
                          4.21393722e-01,   4.24823016e-01,   4.28194165e-01,
                          4.31449056e-01,   4.34994578e-01,   4.38191354e-01,
                          4.41388130e-01,   4.44875538e-01,   4.48014200e-01,
                          4.51152861e-01,   4.54465866e-01,   4.57720786e-01,
                          4.61033791e-01,   4.64114338e-01,   4.67311114e-01,
                          4.70682263e-01,   4.73646551e-01,   4.76785213e-01,
                          4.79981989e-01,   4.83120650e-01,   4.86259311e-01,
                          4.89281714e-01,   4.92420375e-01,   4.95500892e-01,
                          4.98290837e-01,   5.01371384e-01,   5.04451871e-01,
                          5.07416189e-01,   5.10322332e-01,   5.13286650e-01,
                          5.16309023e-01,   5.19215226e-01,   5.22005141e-01,
                          5.24969399e-01,   5.27875543e-01,   5.30723631e-01,
                          5.33513546e-01,   5.36303461e-01,   5.39151490e-01,
                          5.41883290e-01,   5.44498801e-01,   5.47114372e-01,
                          5.50078630e-01,   5.52868605e-01,   5.55367887e-01,
                          5.58041573e-01,   5.60831487e-01,   5.63621402e-01,
                          5.66469431e-01,   5.69026828e-01,   5.71409881e-01,
                          5.73967338e-01,   5.76350391e-01,   5.78733444e-01,
                          5.81348956e-01,   5.83732009e-01,   5.86056948e-01,
                          5.88730633e-01,   5.90939343e-01,   5.93031764e-01,
                          5.95589161e-01,   5.97739756e-01,   5.99890292e-01,
                          6.02273345e-01,   6.04423940e-01,   6.06574476e-01,
                          6.08608782e-01,   6.10468745e-01,   6.12735569e-01,
                          6.14827991e-01,   6.16804183e-01,   6.18954718e-01,
                          6.20872796e-01,   6.22965217e-01,   6.24941409e-01,
                          6.26801372e-01,   6.28893793e-01,   6.30695641e-01,
                          6.32497489e-01,   6.34357393e-01,   6.35984838e-01,
                          6.37961030e-01,   6.39820993e-01,   6.41448438e-01,
                          6.43250287e-01,   6.44819617e-01,   6.46505177e-01,
                          6.48306966e-01,   6.49818182e-01,   6.51503801e-01,
                          6.53131247e-01,   6.54700577e-01,   6.56328022e-01,
                          6.57664835e-01,   6.59292281e-01,   6.60919726e-01,
                          6.62430942e-01,   6.63942158e-01,   6.65220857e-01,
                          6.66732073e-01,   6.68127000e-01,   6.69521987e-01,
                          6.71033204e-01,   6.72137558e-01,   6.73474371e-01,
                          6.74753070e-01,   6.75799310e-01,   6.77136123e-01,
                          6.78356707e-01,   6.79519176e-01,   6.80856049e-01,
                          6.81902230e-01,   6.82890356e-01,   6.83994710e-01,
                          6.85157120e-01,   6.86203361e-01,   6.87133312e-01,
                          6.88295782e-01,   6.89342022e-01,   6.90097630e-01,
                          6.90969467e-01,   6.91783190e-01,   6.92655027e-01,
                          6.93468750e-01,   6.94340646e-01,   6.95270598e-01,
                          6.95793688e-01,   6.96491182e-01,   6.97363019e-01,
                          6.97886169e-01,   6.98525488e-01,   6.99339211e-01,
                          6.99920475e-01,   7.00501680e-01,   7.01141059e-01,
                          7.01547921e-01,   7.02129126e-01,   7.02652276e-01,
                          7.03117251e-01,   7.03698456e-01,   7.04221606e-01,
                          7.04512179e-01,   7.04919040e-01,   7.05209672e-01,
                          7.05558419e-01,   7.06139624e-01,   7.06430256e-01,
                          7.06779003e-01,   7.07127750e-01,   7.07185864e-01,
                          7.07418382e-01,   7.07883358e-01,   7.08115816e-01,
                          7.08406448e-01,   7.08638966e-01,   7.08580852e-01,
                          7.08755195e-01,   7.08929539e-01,   7.08987713e-01,
                          7.09103942e-01,   7.09103942e-01,   7.09103942e-01,
                          7.09045827e-01,   7.08929539e-01,   7.08697081e-01,
                          7.08871424e-01,   7.08929539e-01,   7.08522677e-01,
                          7.08290219e-01,   7.07999587e-01,   7.07708955e-01,
                          7.07767129e-01,   7.07476497e-01,   7.07011521e-01,
                          7.06779003e-01,   7.06430256e-01,   7.05907166e-01,
                          7.05558419e-01,   7.05209672e-01,   7.04686582e-01,
                          7.04047203e-01,   7.03465998e-01,   7.03000963e-01,
                          7.02594101e-01,   7.02245414e-01,   7.01664150e-01,
                          7.00966656e-01,   7.00152934e-01,   6.99397326e-01,
                          6.99048638e-01,   6.98525488e-01,   6.97537422e-01,
                          6.96665525e-01,   6.95968091e-01,   6.95154369e-01,
                          6.94340646e-01,   6.93643153e-01,   6.92887545e-01,
                          6.91899419e-01,   6.90911353e-01,   6.90039515e-01,
                          6.89109504e-01,   6.88063323e-01,   6.86900854e-01,
                          6.85912728e-01,   6.84924662e-01,   6.83704078e-01,
                          6.82657838e-01,   6.81669772e-01,   6.80623531e-01,
                          6.79577291e-01,   6.78298593e-01,   6.76903665e-01,
                          6.75624907e-01,   6.74346209e-01,   6.73183739e-01,
                          6.71905041e-01,   6.70393825e-01,   6.68882608e-01,
                          6.67662024e-01,   6.66325212e-01,   6.64755881e-01,
                          6.63419068e-01,   6.62082195e-01,   6.60396636e-01,
                          6.58652961e-01,   6.57025456e-01,   6.55398011e-01,
                          6.53770566e-01,   6.52085006e-01,   6.50341332e-01,
                          6.48481369e-01,   6.46679521e-01,   6.44703329e-01,
                          6.42901540e-01,   6.41215980e-01,   6.39123499e-01,
                          6.37205422e-01,   6.35229230e-01,   6.33136809e-01,
                          6.31160617e-01,   6.29010081e-01,   6.26975775e-01,
                          6.24941409e-01,   6.22442126e-01,   6.20407820e-01,
                          6.18199110e-01,   6.16048574e-01,   6.14072382e-01,
                          6.11573100e-01,   6.09248161e-01,   6.07097566e-01,
                          6.04598284e-01,   6.02447748e-01,   6.00180924e-01,
                          5.97681642e-01,   5.95298588e-01,   5.92973650e-01,
                          5.90590596e-01,   5.88207543e-01,   5.85824490e-01,
                          5.83208919e-01,   5.80709636e-01,   5.78384697e-01,
                          5.75827241e-01,   5.73327959e-01,   5.70828676e-01,
                          5.68096876e-01,   5.65423191e-01,   5.62749505e-01,
                          5.60017765e-01,   5.57460308e-01,   5.54786623e-01,
                          5.52054822e-01,   5.49264908e-01,   5.46300650e-01,
                          5.43510735e-01,   5.40662706e-01,   5.37930906e-01,
                          5.35199106e-01,   5.32060444e-01,   5.29038012e-01,
                          5.26248097e-01,   5.23167610e-01,   5.20087063e-01,
                          5.17064631e-01,   5.14042258e-01,   5.10961711e-01,
                          5.07764935e-01,   5.04568160e-01,   5.01138866e-01,
                          4.97825831e-01,   4.94629055e-01,   4.91374165e-01,
                          4.88177359e-01,   4.84864354e-01,   4.81551319e-01,
                          4.78354543e-01,   4.74925280e-01,   4.71554130e-01,
                          4.68124837e-01,   4.64579314e-01,   4.61208165e-01,
                          4.57604527e-01,   4.54175264e-01,   4.50804114e-01,
                          4.47200477e-01,   4.43771183e-01,   4.40283805e-01,
                          4.36563909e-01,   4.33192760e-01,   4.29763496e-01,
                          4.26159829e-01,   4.22381818e-01,   4.18545693e-01,
                          4.15000170e-01,   4.11512762e-01,   4.07734752e-01,
                          4.03956741e-01,   4.00411218e-01,   3.96691352e-01,
                          3.92738968e-01,   3.89135301e-01,   3.85473549e-01,
                          3.81637424e-01,   3.77859414e-01,   3.74023259e-01,
                          3.70012760e-01,   3.66234750e-01,   3.62514853e-01,
                          3.58562469e-01,   3.54726344e-01,   3.50890189e-01,
                          3.46821576e-01,   3.42869192e-01,   3.38974923e-01,
                          3.35022539e-01,   3.31070155e-01,   3.26885283e-01,
                          3.22816670e-01,   3.18922400e-01,   3.14795643e-01,
                          3.10843259e-01,   3.06774646e-01,   3.02473515e-01,
                          2.98463017e-01,   2.94161886e-01,   2.89802641e-01,
                          2.85850257e-01,   2.81549126e-01,   2.77131766e-01,
                          2.73121268e-01,   2.68936396e-01,   2.64635265e-01,
                          2.60334134e-01,   2.56091148e-01,   2.51790017e-01,
                          2.47547016e-01,   2.43362144e-01,   2.38886654e-01,
                          2.34411165e-01,   2.30110034e-01,   2.25692675e-01,
                          2.21391544e-01,   2.16974184e-01,   2.12556809e-01,
                          2.08197564e-01,   2.03663945e-01,   1.99304700e-01,
                          1.94945455e-01,   1.90469965e-01,   1.86052606e-01,
                          1.81460857e-01,   1.77101612e-01,   1.72858611e-01,
                          1.68266878e-01,   1.63791388e-01,   1.59315899e-01,
                          1.54782280e-01,   1.50423035e-01,   1.45889416e-01,
                          1.41472042e-01,   1.36938438e-01,   1.32288575e-01,
                          1.27813071e-01,   1.23163216e-01,   1.18571475e-01,
                          1.13979742e-01,   1.09504245e-01,   1.05028756e-01,
                          1.00262649e-01,   9.57871526e-02,   9.11372900e-02,
                          8.64293054e-02,   8.19538161e-02,   7.72458315e-02,
                          7.25378469e-02,   6.78298622e-02,   6.31218776e-02,
                          5.86463846e-02,   5.38221523e-02,   4.91141677e-02,
                          4.45805490e-02,   3.98144424e-02,   3.51064578e-02,
                          3.03984713e-02,   2.55161170e-02,   2.08662543e-02,
                          1.61001459e-02,   1.13921613e-02,   6.56792987e-03,
                          1.62745162e-03,  -2.96428683e-03,  -7.67227216e-03,
                         -1.26127508e-02,  -1.73207354e-02,  -2.22030897e-02,
                         -2.70854458e-02,  -3.18515524e-02,  -3.67339104e-02,
                         -4.16743867e-02,  -4.63823713e-02,  -5.09741120e-02,
                         -5.58564663e-02,  -6.06806986e-02,  -6.53305575e-02,
                         -7.00385422e-02,  -7.48627782e-02,  -7.97451288e-02,
                         -8.45693648e-02,  -8.93354714e-02,  -9.42178294e-02,
                         -9.89258140e-02,  -1.03633799e-01,  -1.08516149e-01,
                         -1.13340385e-01,  -1.18106492e-01,  -1.22872598e-01,
                         -1.27696827e-01,  -1.32462934e-01,  -1.37229055e-01,
                         -1.41995162e-01,  -1.46819383e-01,  -1.51469246e-01,
                         -1.56177238e-01,  -1.60943344e-01,  -1.65825695e-01,
                         -1.70649931e-01,  -1.75416037e-01,  -1.80124030e-01,
                         -1.84832007e-01,  -1.89539999e-01,  -1.94364220e-01,
                         -1.99072212e-01,  -2.03954563e-01,  -2.08895043e-01,
                         -2.13544905e-01,  -2.18194768e-01,  -2.23019004e-01,
                         -2.27726981e-01,  -2.32434973e-01,  -2.37259209e-01,
                         -2.41967186e-01,  -2.46558920e-01,  -2.51441270e-01,
                         -2.56439894e-01,  -2.61031628e-01,  -2.65797734e-01,
                         -2.70621955e-01,  -2.75388062e-01,  -2.80212313e-01,
                         -2.85036534e-01,  -2.89628267e-01,  -2.94103771e-01,
                         -2.98811734e-01,  -3.03577870e-01,  -3.08285832e-01,
                         -3.12993824e-01,  -3.17585558e-01,  -3.22061062e-01,
                         -3.26769054e-01,  -3.31186414e-01,  -3.35720032e-01,
                         -3.40428025e-01,  -3.45019758e-01,  -3.49669605e-01,
                         -3.54028851e-01,  -3.58504355e-01,  -3.63212347e-01,
                         -3.67629707e-01,  -3.72163326e-01,  -3.76638800e-01,
                         -3.81056190e-01,  -3.85647923e-01,  -3.89890909e-01,
                         -3.94250154e-01,  -3.98783773e-01,  -4.03143018e-01,
                         -4.07560378e-01,  -4.11745280e-01,  -4.16046381e-01,
                         -4.20638144e-01,  -4.24881130e-01,  -4.29414749e-01,
                         -4.33773994e-01,  -4.38016981e-01,  -4.42376226e-01,
                         -4.46386755e-01,  -4.50571626e-01,  -4.54930872e-01,
                         -4.59115744e-01,  -4.63300616e-01,  -4.67485487e-01,
                         -4.71670359e-01,  -4.75739002e-01,  -4.79749501e-01,
                         -4.83934373e-01,  -4.88119245e-01,  -4.92246002e-01,
                         -4.96314645e-01,  -5.00267029e-01,  -5.04393756e-01,
                         -5.08636773e-01,  -5.12589157e-01,  -5.16541541e-01,
                         -5.20552039e-01,  -5.24562538e-01,  -5.28514922e-01,
                         -5.32409191e-01,  -5.36245346e-01,  -5.40081441e-01,
                         -5.43743193e-01,  -5.47521234e-01,  -5.51415503e-01,
                         -5.55251658e-01,  -5.58855295e-01,  -5.62458932e-01,
                         -5.66236913e-01,  -5.69956839e-01,  -5.73444188e-01,
                         -5.76931596e-01,  -5.80535233e-01,  -5.84138870e-01,
                         -5.87568164e-01,  -5.90997458e-01,  -5.94426692e-01,
                         -5.97739756e-01,  -6.00994647e-01,  -6.04365826e-01,
                         -6.07795060e-01,  -6.11049950e-01,  -6.14304900e-01,
                         -6.17676020e-01,  -6.20814681e-01,  -6.23837113e-01,
                         -6.26975775e-01,  -6.30172551e-01,  -6.33543670e-01,
                         -6.36682332e-01,  -6.39588475e-01,  -6.42669022e-01,
                         -6.45633340e-01,  -6.48481369e-01,  -6.51329398e-01,
                         -6.54409945e-01,  -6.57316089e-01,  -6.59989774e-01,
                         -6.62779689e-01,  -6.65627718e-01,  -6.68533862e-01,
                         -6.71440065e-01,  -6.73997462e-01,  -6.76554918e-01,
                         -6.79054201e-01,  -6.81727886e-01,  -6.84401572e-01,
                         -6.87017083e-01,  -6.89690769e-01,  -6.92073822e-01,
                         -6.94398761e-01,  -6.96898043e-01,  -6.99164867e-01,
                         -7.01664150e-01,  -7.04279721e-01,  -7.06604660e-01,
                         -7.08813310e-01,  -7.10847616e-01,  -7.13230669e-01,
                         -7.15555608e-01,  -7.17415571e-01,  -7.19566107e-01,
                         -7.21600413e-01,  -7.23692894e-01,  -7.25901544e-01,
                         -7.27645278e-01,  -7.29563355e-01,  -7.31481373e-01,
                         -7.33108819e-01,  -7.35026896e-01,  -7.36770630e-01,
                         -7.38630533e-01,  -7.40432382e-01,  -7.42001712e-01,
                         -7.43745387e-01,  -7.45140374e-01,  -7.46535301e-01,
                         -7.48279035e-01,  -7.49790251e-01,  -7.51243293e-01,
                         -7.52463877e-01,  -7.53858864e-01,  -7.55370080e-01,
                         -7.56416261e-01,  -7.57695019e-01,  -7.59089947e-01,
                         -7.60194302e-01,  -7.61473000e-01,  -7.62344837e-01,
                         -7.63507307e-01,  -7.64727890e-01,  -7.65425384e-01,
                         -7.66471624e-01,  -7.67634094e-01,  -7.68389702e-01,
                         -7.69319654e-01,  -7.70075262e-01,  -7.70888984e-01,
                         -7.71760821e-01,  -7.72342086e-01,  -7.73039520e-01,
                         -7.73853242e-01,  -7.74666965e-01,  -7.75073826e-01,
                         -7.75538862e-01,  -7.76643157e-01,  -7.77166307e-01,
                         -7.77515054e-01,  -7.78328776e-01,  -7.78386891e-01,
                         -7.78677523e-01,  -7.79433072e-01,  -7.79607475e-01,
                         -7.79956222e-01,  -7.80363083e-01,  -7.80304968e-01,
                         -7.80479312e-01,  -7.80711830e-01,  -7.80769944e-01,
                         -7.80886173e-01,  -7.81002402e-01,  -7.80944288e-01,
                         -7.80944288e-01,  -7.80828059e-01,  -7.80595541e-01,
                         -7.80421197e-01,  -7.80188680e-01,  -7.80014336e-01,
                         -7.79781818e-01,  -7.79549360e-01,  -7.79549360e-01,
                         -7.79258728e-01,  -7.78677523e-01,  -7.78212488e-01,
                         -7.77921915e-01,  -7.77515054e-01,  -7.77050018e-01,
                         -7.76468813e-01,  -7.75945723e-01,  -7.75190115e-01,
                         -7.74841368e-01,  -7.74201989e-01,  -7.73272038e-01,
                         -7.72865176e-01,  -7.72109568e-01,  -7.71121442e-01,
                         -7.70424008e-01,  -7.69610286e-01,  -7.68854678e-01,
                         -7.68215299e-01,  -7.67169058e-01,  -7.66297221e-01,
                         -7.65483499e-01,  -7.64495432e-01,  -7.63449192e-01,
                         -7.62461126e-01,  -7.61531115e-01,  -7.60310531e-01,
                         -7.59031832e-01,  -7.58043706e-01,  -7.56939411e-01,
                         -7.55776942e-01,  -7.54498184e-01,  -7.53277600e-01,
                         -7.51998901e-01,  -7.50545800e-01,  -7.49267101e-01,
                         -7.47988403e-01,  -7.46651590e-01,  -7.45489120e-01,
                         -7.44210422e-01,  -7.42641091e-01,  -7.41304219e-01,
                         -7.39793003e-01,  -7.38165557e-01,  -7.36596227e-01,
                         -7.35085011e-01,  -7.33457565e-01,  -7.31655777e-01,
                         -7.29970217e-01,  -7.28284597e-01,  -7.26599038e-01,
                         -7.24913478e-01,  -7.22937286e-01,  -7.21019208e-01,
                         -7.19333649e-01,  -7.17473686e-01,  -7.15788126e-01,
                         -7.13811934e-01,  -7.11603224e-01,  -7.09743321e-01,
                         -7.07767129e-01,  -7.05616534e-01,  -7.03698456e-01,
                         -7.01664150e-01,  -6.99455500e-01,  -6.97363019e-01,
                         -6.95270598e-01,  -6.92945659e-01,  -6.90911353e-01,
                         -6.88818932e-01,  -6.86435878e-01,  -6.84110940e-01,
                         -6.81786001e-01,  -6.79344833e-01,  -6.77194238e-01,
                         -6.75043702e-01,  -6.72544420e-01,  -6.70103192e-01,
                         -6.67720139e-01,  -6.65278971e-01,  -6.62837803e-01,
                         -6.60338521e-01,  -6.57839179e-01,  -6.55223668e-01,
                         -6.52666211e-01,  -6.50166929e-01,  -6.47551417e-01,
                         -6.45110190e-01,  -6.42378390e-01,  -6.39588475e-01,
                         -6.36914849e-01,  -6.34183049e-01,  -6.31509364e-01,
                         -6.28777564e-01,  -6.25987649e-01,  -6.23255849e-01,
                         -6.20291591e-01,  -6.17443562e-01,  -6.14537358e-01,
                         -6.11631215e-01,  -6.08899415e-01,  -6.05818868e-01,
                         -6.02796495e-01,  -5.99890292e-01,  -5.96926033e-01,
                         -5.94019830e-01,  -5.90881169e-01,  -5.87742567e-01,
                         -5.84662020e-01,  -5.81407130e-01,  -5.78384697e-01,
                         -5.75129807e-01,  -5.71874917e-01,  -5.68736255e-01,
                         -5.65306962e-01,  -5.62110186e-01,  -5.59029639e-01,
                         -5.55716634e-01,  -5.52403569e-01,  -5.48974335e-01,
                         -5.45428813e-01,  -5.42057633e-01,  -5.38628399e-01,
                         -5.35257220e-01,  -5.31886101e-01,  -5.28398693e-01,
                         -5.25027514e-01,  -5.21540105e-01,  -5.17936468e-01,
                         -5.14507234e-01,  -5.10845423e-01,  -5.07299960e-01,
                         -5.03986895e-01,  -5.00325143e-01,  -4.96547133e-01,
                         -4.92827237e-01,  -4.89165455e-01,  -4.85736191e-01,
                         -4.82248813e-01,  -4.78412658e-01,  -4.74518418e-01,
                         -4.70856637e-01,  -4.67078626e-01,  -4.63358730e-01,
                         -4.59580719e-01,  -4.55628335e-01,  -4.51850325e-01,
                         -4.48130429e-01,  -4.44236189e-01,  -4.40400034e-01,
                         -4.36563909e-01,  -4.32727784e-01,  -4.28891629e-01,
                         -4.24823016e-01,  -4.20638144e-01,  -4.16685760e-01,
                         -4.12849605e-01,  -4.08955365e-01,  -4.04944837e-01,
                         -4.00934339e-01,  -3.96865726e-01,  -3.92913342e-01,
                         -3.89019072e-01,  -3.84892315e-01,  -3.80649328e-01,
                         -3.76522571e-01,  -3.72570187e-01,  -3.68327171e-01,
                         -3.64026070e-01,  -3.59841198e-01,  -3.55656296e-01,
                         -3.51413310e-01,  -3.47228438e-01,  -3.42985451e-01,
                         -3.38626176e-01,  -3.34150702e-01,  -3.29907686e-01,
                         -3.25722814e-01,  -3.21189195e-01,  -3.16946208e-01,
                         -3.12703222e-01,  -3.08402091e-01,  -3.04217219e-01,
                         -2.99741715e-01,  -2.95208097e-01,  -2.90906996e-01,
                         -2.86547750e-01,  -2.82246619e-01,  -2.77771115e-01,
                         -2.73237497e-01,  -2.68878251e-01,  -2.64460891e-01,
                         -2.59927273e-01,  -2.55509913e-01,  -2.51150668e-01,
                         -2.46733293e-01,  -2.42257804e-01,  -2.37782314e-01,
                         -2.33306825e-01,  -2.28715077e-01,  -2.24181458e-01,
                         -2.19822213e-01,  -2.15288609e-01,  -2.10696861e-01,
                         -2.06337616e-01,  -2.01804012e-01,  -1.97328508e-01,
                         -1.93027392e-01,  -1.88377529e-01,  -1.83785796e-01,
                         -1.79368421e-01,  -1.74776688e-01,  -1.70301184e-01,
                         -1.65825695e-01,  -1.61233962e-01,  -1.56816587e-01,
                         -1.52224854e-01,  -1.47749364e-01,  -1.43273875e-01,
                         -1.38507754e-01,  -1.34090394e-01,  -1.29556775e-01,
                         -1.24732547e-01,  -1.20315179e-01,  -1.15955934e-01,
                         -1.11306071e-01,  -1.06598087e-01,  -1.01948224e-01,
                         -9.74146053e-02,  -9.29972380e-02,  -8.83473754e-02,
                         -8.36975127e-02,  -7.91057721e-02,  -7.45140389e-02,
                         -6.98060542e-02,  -6.52143136e-02,  -6.07969426e-02,
                         -5.63795753e-02,  -5.17878383e-02,  -4.70798500e-02,
                         -4.26043607e-02,  -3.79544981e-02,  -3.33627574e-02,
                         -2.90616360e-02,  -2.44698990e-02,  -1.99944060e-02,
                         -1.55770369e-02,  -1.09271752e-02,  -6.50980650e-03,
                         -2.03431468e-03,   2.55742413e-03,   6.97479304e-03,
                          1.15084080e-02,   1.59257762e-02,   2.02268995e-02,
                          2.47605145e-02,   2.91197598e-02,   3.35371271e-02,
                          3.80707458e-02,   4.24299911e-02,   4.68473583e-02,
                          5.11484817e-02,   5.54496013e-02,   5.99832200e-02,
                          6.43424615e-02,   6.85854629e-02,   7.30609521e-02,
                          7.75364488e-02,   8.18375722e-02,   8.61386880e-02,
                          9.04979333e-02,   9.47990566e-02,   9.89839360e-02,
                          1.03168808e-01,   1.07528053e-01,   1.11945428e-01,
                          1.16246544e-01,   1.20780163e-01,   1.25139400e-01,
                          1.29208043e-01,   1.33625403e-01,   1.37926534e-01,
                          1.42053276e-01,   1.46296278e-01,   1.50539279e-01,
                          1.54898524e-01,   1.59199640e-01,   1.63442641e-01,
                          1.67743772e-01,   1.71754271e-01,   1.76113516e-01,
                          1.80472761e-01,   1.84425145e-01,   1.88610017e-01,
                          1.92736775e-01,   1.96747273e-01,   2.00932160e-01,
                          2.04884544e-01,   2.09127530e-01,   2.13312417e-01,
                          2.17322916e-01,   2.21565917e-01,   2.25576431e-01,
                          2.29586929e-01,   2.33655557e-01,   2.37607941e-01,
                          2.41792813e-01,   2.45861441e-01,   2.49813825e-01,
                          2.53824323e-01,   2.57892966e-01,   2.62019724e-01,
                          2.65913963e-01,   2.69808233e-01,   2.73818731e-01,
                          2.77771115e-01,   2.81839758e-01,   2.85675883e-01,
                          2.89453894e-01,   2.93638766e-01,   2.97358662e-01,
                          3.01136672e-01,   3.05205315e-01,   3.09041440e-01,
                          3.12877595e-01,   3.16539347e-01,   3.20317358e-01,
                          3.24327856e-01,   3.27989638e-01,   3.31825763e-01,
                          3.35661918e-01,   3.39265555e-01,   3.43101680e-01,
                          3.46879691e-01,   3.50657701e-01,   3.54377598e-01,
                          3.58039349e-01,   3.61759245e-01,   3.65537256e-01,
                          3.69257152e-01,   3.72918934e-01,   3.76464456e-01,
                          3.80126208e-01,   3.83671731e-01,   3.87275368e-01,
                          3.90879005e-01,   3.94308299e-01,   3.98028165e-01,
                          4.01806176e-01,   4.05119210e-01,   4.08722848e-01,
                          4.12442744e-01,   4.15930152e-01,   4.19243157e-01,
                          4.22614306e-01,   4.26159829e-01,   4.29472864e-01,
                          4.32902128e-01,   4.36505795e-01,   4.39876944e-01,
                          4.43073720e-01,   4.46386755e-01,   4.49816018e-01,
                          4.53187168e-01,   4.56500202e-01,   4.59813207e-01,
                          4.63009983e-01,   4.66323018e-01,   4.69694167e-01,
                          4.72890943e-01,   4.75971490e-01,   4.79110152e-01,
                          4.82306927e-01,   4.85503703e-01,   4.88467991e-01,
                          4.91664767e-01,   4.94861543e-01,   4.97709602e-01,
                          5.00673890e-01,   5.03870666e-01,   5.06893039e-01,
                          5.09973586e-01,   5.13054132e-01,   5.15902162e-01,
                          5.18866479e-01,   5.22179484e-01,   5.25027514e-01,
                          5.27759314e-01,   5.30839860e-01,   5.33746004e-01,
                          5.36652207e-01,   5.39558351e-01,   5.42232037e-01,
                          5.45196295e-01,   5.48102438e-01,   5.50659895e-01,
                          5.53566039e-01,   5.56530356e-01,   5.59262156e-01,
                          5.61877668e-01,   5.64551353e-01,   5.67283154e-01,
                          5.70073068e-01,   5.72746754e-01,   5.75246036e-01,
                          5.77803433e-01,   5.80419004e-01,   5.83150804e-01,
                          5.85940719e-01,   5.88556290e-01,   5.90997458e-01,
                          5.93612969e-01,   5.96228540e-01,   5.98553479e-01,
                          6.00820303e-01,   6.03261471e-01,   6.05760753e-01,
                          6.08201921e-01,   6.10817492e-01,   6.13026142e-01,
                          6.15118623e-01,   6.17617905e-01,   6.19942844e-01,
                          6.22384012e-01,   6.24708951e-01,   6.26801372e-01,
                          6.29126310e-01,   6.31393135e-01,   6.33543670e-01,
                          6.35868609e-01,   6.38019145e-01,   6.40053511e-01,
                          6.42262161e-01,   6.44354582e-01,   6.46563292e-01,
                          6.48423254e-01,   6.50283158e-01,   6.52491868e-01,
                          6.54468060e-01,   6.56560481e-01,   6.58769190e-01,
                          6.60629153e-01,   6.62489057e-01,   6.64465249e-01,
                          6.66325212e-01,   6.68301404e-01,   6.70277596e-01,
                          6.72021270e-01,   6.73765004e-01,   6.75508678e-01,
                          6.77426755e-01,   6.79170430e-01,   6.80972278e-01,
                          6.82541609e-01,   6.84343398e-01,   6.86203361e-01,
                          6.87656462e-01,   6.89574540e-01,   6.91318214e-01,
                          6.92713201e-01,   6.94398761e-01,   6.96026206e-01,
                          6.97595537e-01,   6.99222982e-01,   7.00734198e-01,
                          7.02187240e-01,   7.03640342e-01,   7.05093443e-01,
                          7.06662774e-01,   7.07883358e-01,   7.09394574e-01,
                          7.10963905e-01,   7.12184489e-01,   7.13695645e-01,
                          7.14974403e-01,   7.16194987e-01,   7.17531800e-01,
                          7.18752384e-01,   7.20031083e-01,   7.21309841e-01,
                          7.22414136e-01,   7.23751009e-01,   7.24971592e-01,
                          7.25843430e-01,   7.26947784e-01,   7.28226483e-01,
                          7.29447067e-01,   7.30377078e-01,   7.31248915e-01,
                          7.32178867e-01,   7.33108819e-01,   7.34213173e-01,
                          7.35201299e-01,   7.36189365e-01,   7.36944973e-01,
                          7.37816811e-01,   7.38804936e-01,   7.39618659e-01,
                          7.40432382e-01,   7.41304219e-01,   7.41885483e-01,
                          7.42408574e-01,   7.43106067e-01,   7.43803501e-01,
                          7.44500995e-01,   7.45198488e-01,   7.45954096e-01,
                          7.46477187e-01,   7.46942163e-01,   7.47523427e-01,
                          7.47988403e-01,   7.48627782e-01,   7.49267101e-01,
                          7.49732077e-01,   7.50022709e-01,   7.50429571e-01,
                          7.51068950e-01,   7.51592040e-01,   7.51998901e-01,
                          7.52405763e-01,   7.52754509e-01,   7.52870739e-01,
                          7.53335774e-01,   7.53684461e-01,   7.53916979e-01,
                          7.54207611e-01,   7.54323840e-01,   7.54440069e-01,
                          7.54672587e-01,   7.55021334e-01,   7.55021334e-01,
                          7.55021334e-01,   7.55021334e-01,   7.54963219e-01,
                          7.55021334e-01,   7.55079448e-01,   7.54905105e-01,
                          7.54730701e-01,   7.54730701e-01,   7.54498184e-01,
                          7.54207611e-01,   7.53975093e-01,   7.53626347e-01,
                          7.53393888e-01,   7.53219485e-01,   7.52812624e-01,
                          7.52405763e-01,   7.51998901e-01,   7.51417696e-01,
                          7.50894547e-01,   7.50545800e-01,   7.50080824e-01,
                          7.49383390e-01,   7.48685896e-01,   7.48162746e-01,
                          7.47465312e-01,   7.46651590e-01,   7.45895982e-01,
                          7.45198488e-01,   7.44559109e-01,   7.43687272e-01,
                          7.42699206e-01,   7.41769195e-01,   7.41071761e-01,
                          7.40258038e-01,   7.39269912e-01,   7.38165557e-01,
                          7.37235606e-01,   7.36247480e-01,   7.35026896e-01,
                          7.34096944e-01,   7.32876360e-01,   7.31539547e-01,
                          7.30551422e-01,   7.29272723e-01,   7.27994025e-01,
                          7.26889670e-01,   7.25378454e-01,   7.23983467e-01,
                          7.22762883e-01,   7.21251726e-01,   7.19972968e-01,
                          7.18287408e-01,   7.16601849e-01,   7.15323150e-01,
                          7.13811934e-01,   7.12358832e-01,   7.10789502e-01,
                          7.09336400e-01,   7.07592726e-01,   7.05674648e-01,
                          7.04047203e-01,   7.02303529e-01,   7.00501680e-01,
                          6.98758006e-01,   6.96723700e-01,   6.94805622e-01,
                          6.92887545e-01,   6.90737009e-01,   6.88818932e-01,
                          6.86668336e-01,   6.84750259e-01,   6.82832241e-01,
                          6.80274785e-01,   6.78124249e-01,   6.76031768e-01,
                          6.73706889e-01,   6.71498179e-01,   6.69289470e-01,
                          6.66848302e-01,   6.64290905e-01,   6.62024081e-01,
                          6.59815371e-01,   6.57199860e-01,   6.54642403e-01,
                          6.52317524e-01,   6.49585724e-01,   6.47028267e-01,
                          6.44412756e-01,   6.41680956e-01,   6.39297903e-01,
                          6.36566103e-01,   6.33427441e-01,   6.30695641e-01,
                          6.28138244e-01,   6.25232041e-01,   6.22500241e-01,
                          6.19652212e-01,   6.16513550e-01,   6.13549292e-01,
                          6.10410631e-01,   6.07388198e-01,   6.04482055e-01,
                          6.01401508e-01,   5.98437250e-01,   5.95414817e-01,
                          5.92276156e-01,   5.89079380e-01,   5.85766375e-01,
                          5.82569540e-01,   5.79314649e-01,   5.75943530e-01,
                          5.72688639e-01,   5.69201231e-01,   5.65946341e-01,
                          5.62807679e-01,   5.59494615e-01,   5.56239724e-01,
                          5.52694201e-01,   5.49439311e-01,   5.46184421e-01,
                          5.42813241e-01,   5.39442122e-01,   5.35896599e-01,
                          5.32351077e-01,   5.28805554e-01,   5.25260031e-01,
                          5.21830738e-01,   5.18227100e-01,   5.14449120e-01,
                          5.10845423e-01,   5.07125556e-01,   5.03580034e-01,
                          4.99860138e-01,   4.96024013e-01,   4.92536604e-01,
                          4.88526106e-01,   4.84689981e-01,   4.80970085e-01,
                          4.76959586e-01,   4.73239690e-01,   4.69287306e-01,
                          4.65218693e-01,   4.61324424e-01,   4.57255781e-01,
                          4.53303397e-01,   4.49525386e-01,   4.45340514e-01,
                          4.41388130e-01,   4.37435746e-01,   4.33134645e-01,
                          4.29124117e-01,   4.25171733e-01,   4.21103120e-01,
                          4.16860104e-01,   4.12733376e-01,   4.08606619e-01,
                          4.04305488e-01,   4.00178730e-01,   3.96110117e-01,
                          3.91925246e-01,   3.87624115e-01,   3.83264869e-01,
                          3.78847510e-01,   3.74778867e-01,   3.70477736e-01,
                          3.66002262e-01,   3.61584872e-01,   3.57225627e-01,
                          3.52924526e-01,   3.48565280e-01,   3.44322264e-01,
                          3.39904904e-01,   3.35487545e-01,   3.30953926e-01,
                          3.26420307e-01,   3.22119176e-01,   3.17527443e-01,
                          3.12993824e-01,   3.08634579e-01,   3.03810358e-01,
                          2.99392968e-01,   2.95091867e-01,   2.90325761e-01,
                          2.85966516e-01,   2.81432897e-01,   2.76608646e-01,
                          2.72249401e-01,   2.67657667e-01,   2.62949675e-01,
                          2.58474201e-01,   2.53824323e-01,   2.49116346e-01,
                          2.44350240e-01,   2.39758506e-01,   2.34992400e-01,
                          2.30226293e-01,   2.25518301e-01,   2.20810309e-01,
                          2.15986088e-01,   2.11103722e-01,   2.06337616e-01,
                          2.01629639e-01,   1.96863532e-01,   1.91981167e-01,
                          1.87156945e-01,   1.82448953e-01,   1.77566603e-01,
                          1.72509879e-01,   1.67860016e-01,   1.62919536e-01,
                          1.57979056e-01,   1.53271079e-01,   1.48156226e-01,
                          1.43273875e-01,   1.38449639e-01,   1.33567289e-01,
                          1.28743052e-01,   1.23628199e-01,   1.18803971e-01,
                          1.13921613e-01,   1.08806767e-01,   1.04215026e-01,
                          9.93907973e-02,   9.42178294e-02,   8.93935934e-02,
                          8.43949914e-02,   7.92801455e-02,   7.44559169e-02,
                          6.95735589e-02,   6.44587129e-02,   5.94019853e-02,
                          5.45777529e-02,   4.95210290e-02,   4.43480574e-02,
                          3.94075811e-02,   3.43508534e-02,   2.94103771e-02,
                          2.46442687e-02,   1.94131732e-02,   1.43564483e-02,
                          9.53221694e-03,   4.47549205e-03,  -3.48739646e-04,
                         -5.46358759e-03,  -1.05784358e-02,  -1.55189140e-02,
                         -2.06918847e-02,  -2.57486105e-02,  -3.07472125e-02,
                         -3.59201841e-02,  -4.09769081e-02,  -4.59173843e-02,
                         -5.09741120e-02,  -5.61470836e-02,  -6.12038076e-02,
                         -6.60861582e-02,  -7.13172555e-02,  -7.65483528e-02,
                         -8.14888328e-02,  -8.66036788e-02,  -9.16604027e-02,
                         -9.67171267e-02,  -1.01831973e-01,  -1.07004948e-01,
                         -1.12177916e-01,  -1.17176518e-01,  -1.22233242e-01,
                         -1.27348095e-01,  -1.32521063e-01,  -1.37752160e-01,
                         -1.42808884e-01,  -1.47865608e-01,  -1.52922332e-01,
                         -1.57920927e-01,  -1.63035780e-01,  -1.68150634e-01,
                         -1.73091114e-01,  -1.78205952e-01,  -1.83378935e-01,
                         -1.88377529e-01,  -1.93376124e-01,  -1.98607221e-01,
                         -2.03780189e-01,  -2.08778799e-01,  -2.13719279e-01,
                         -2.18776003e-01,  -2.23890856e-01,  -2.28715077e-01,
                         -2.33597443e-01,  -2.38654166e-01,  -2.43652761e-01,
                         -2.48651370e-01,  -2.53533721e-01,  -2.58416086e-01,
                         -2.63530910e-01,  -2.68413275e-01,  -2.73237497e-01,
                         -2.78352350e-01,  -2.83118457e-01,  -2.88117081e-01,
                         -2.93057531e-01,  -2.97881782e-01,  -3.02996635e-01,
                         -3.07762742e-01,  -3.12528849e-01,  -3.17527443e-01,
                         -3.22293550e-01,  -3.27175915e-01,  -3.32000136e-01,
                         -3.36766243e-01,  -3.41822982e-01,  -3.46530944e-01,
                         -3.51297051e-01,  -3.56179416e-01,  -3.61003637e-01,
                         -3.65827888e-01,  -3.70419621e-01,  -3.75243843e-01,
                         -3.80009949e-01,  -3.84717941e-01,  -3.89542192e-01,
                         -3.94192040e-01,  -3.98958147e-01,  -4.03608024e-01,
                         -4.08315986e-01,  -4.13082093e-01,  -4.17673856e-01,
                         -4.22323704e-01,  -4.27031696e-01,  -4.31623429e-01,
                         -4.36157048e-01,  -4.40690666e-01,  -4.45282400e-01,
                         -4.50048506e-01,  -4.54465866e-01,  -4.58883256e-01,
                         -4.63474989e-01,  -4.67950463e-01,  -4.72484082e-01,
                         -4.77017701e-01,  -4.81435061e-01,  -4.85852450e-01,
                         -4.90211695e-01,  -4.94454682e-01,  -4.98755813e-01,
                         -5.02940714e-01,  -5.07358074e-01,  -5.11659205e-01,
                         -5.15727818e-01,  -5.19970775e-01,  -5.24271905e-01,
                         -5.28398693e-01,  -5.32351077e-01,  -5.36535919e-01,
                         -5.40895164e-01,  -5.44963837e-01,  -5.48858047e-01,
                         -5.52868605e-01,  -5.56937218e-01,  -5.60773313e-01,
                         -5.64609468e-01,  -5.68678081e-01,  -5.72630465e-01,
                         -5.76350391e-01,  -5.80244660e-01,  -5.84080756e-01,
                         -5.87858796e-01,  -5.91869295e-01,  -5.95472932e-01,
                         -5.99076569e-01,  -6.02738321e-01,  -6.06342018e-01,
                         -6.10119998e-01,  -6.13781750e-01,  -6.17385387e-01,
                         -6.20930910e-01,  -6.24302089e-01,  -6.27731323e-01,
                         -6.31451249e-01,  -6.34880543e-01,  -6.38484180e-01,
                         -6.41971529e-01,  -6.45052075e-01,  -6.48539484e-01,
                         -6.51968777e-01,  -6.54991150e-01,  -6.58246100e-01,
                         -6.61559105e-01,  -6.64639652e-01,  -6.67952657e-01,
                         -6.71091318e-01,  -6.74055576e-01,  -6.77194238e-01,
                         -6.80042326e-01,  -6.83006585e-01,  -6.86029017e-01,
                         -6.89109504e-01,  -6.92015707e-01,  -6.94689393e-01,
                         -6.97421134e-01,  -7.00036705e-01,  -7.02884734e-01,
                         -7.05558419e-01,  -7.07999587e-01,  -7.10673273e-01,
                         -7.13288784e-01,  -7.15613723e-01,  -7.18345523e-01,
                         -7.20902979e-01,  -7.23111629e-01,  -7.25727201e-01,
                         -7.27935851e-01,  -7.30260789e-01,  -7.32643843e-01,
                         -7.34678149e-01,  -7.36944973e-01,  -7.39037395e-01,
                         -7.41129875e-01,  -7.43222296e-01,  -7.45198488e-01,
                         -7.47407198e-01,  -7.49499619e-01,  -7.51185179e-01,
                         -7.53219485e-01,  -7.55195677e-01,  -7.57055640e-01,
                         -7.58799314e-01,  -7.60310531e-01,  -7.62228608e-01,
                         -7.64030457e-01,  -7.65657902e-01,  -7.67227232e-01,
                         -7.68796563e-01,  -7.70540237e-01,  -7.71877050e-01,
                         -7.73330152e-01,  -7.75015712e-01,  -7.76236296e-01,
                         -7.77747512e-01,  -7.79374957e-01,  -7.80537426e-01,
                         -7.81874299e-01,  -7.83152997e-01,  -7.84257352e-01,
                         -7.85536051e-01,  -7.86466002e-01,  -7.87628472e-01,
                         -7.88674712e-01,  -7.89720893e-01,  -7.90534616e-01,
                         -7.91406512e-01,  -7.92452693e-01,  -7.93150187e-01,
                         -7.94080138e-01,  -7.94893861e-01,  -7.95649469e-01,
                         -7.96521366e-01,  -7.97102571e-01,  -7.97509432e-01,
                         -7.98265040e-01,  -7.98788130e-01,  -7.99194992e-01,
                         -7.99892485e-01,  -8.00299346e-01,  -8.00764322e-01,
                         -8.00996840e-01,  -8.01287472e-01,  -8.01636159e-01,
                         -8.02159309e-01,  -8.02624285e-01,  -8.02624285e-01,
                         -8.02740514e-01,  -8.02973032e-01,  -8.03089261e-01,
                         -8.03147376e-01,  -8.03263664e-01,  -8.03205490e-01,
                         -8.03205490e-01,  -8.03205490e-01,  -8.03031147e-01,
                         -8.03031147e-01,  -8.02914917e-01,  -8.02856803e-01,
                         -8.02682400e-01,  -8.02391768e-01,  -8.02101195e-01,
                         -8.01926792e-01,  -8.01694334e-01,  -8.01345587e-01,
                         -8.01113069e-01,  -8.00706208e-01,  -8.00357461e-01,
                         -7.99834371e-01,  -7.99311280e-01,  -7.99078763e-01,
                         -7.98497558e-01,  -7.97974408e-01,  -7.97509432e-01,
                         -7.97044456e-01,  -7.96346962e-01,  -7.95649469e-01,
                         -7.95068264e-01,  -7.94719517e-01,  -7.93731451e-01,
                         -7.92917669e-01,  -7.92278349e-01,  -7.91290224e-01,
                         -7.90767133e-01,  -7.89953411e-01,  -7.88849056e-01,
                         -7.88035333e-01,  -7.87105381e-01,  -7.86291659e-01,
                         -7.85303533e-01,  -7.84199178e-01,  -7.83385456e-01,
                         -7.82339275e-01,  -7.81060576e-01,  -7.80304968e-01,
                         -7.79316843e-01,  -7.78038144e-01,  -7.76875675e-01,
                         -7.75596976e-01,  -7.74318278e-01,  -7.72923291e-01,
                         -7.71760821e-01,  -7.70656466e-01,  -7.69261539e-01,
                         -7.67866552e-01,  -7.66297221e-01,  -7.64960408e-01,
                         -7.63681710e-01,  -7.62228608e-01,  -7.60775506e-01,
                         -7.59380579e-01,  -7.57753134e-01,  -7.56358147e-01,
                         -7.54788816e-01,  -7.53103256e-01,  -7.51533926e-01,
                         -7.49732077e-01,  -7.48337150e-01,  -7.46709704e-01,
                         -7.44965971e-01,  -7.43454814e-01,  -7.41827309e-01,
                         -7.40025520e-01,  -7.38107443e-01,  -7.36247480e-01,
                         -7.34620035e-01,  -7.32992589e-01,  -7.31016397e-01,
                         -7.29098320e-01,  -7.27180302e-01,  -7.25552797e-01,
                         -7.23809123e-01,  -7.21891046e-01,  -7.19914854e-01,
                         -7.17764318e-01,  -7.15962470e-01,  -7.13870049e-01,
                         -7.11661339e-01,  -7.09801435e-01,  -7.07825243e-01,
                         -7.05558419e-01,  -7.03349710e-01,  -7.01315403e-01,
                         -6.99106753e-01,  -6.96898043e-01,  -6.94689393e-01,
                         -6.92422569e-01,  -6.90213859e-01,  -6.88005209e-01,
                         -6.85738385e-01,  -6.83355331e-01,  -6.80972278e-01,
                         -6.78531110e-01,  -6.76206172e-01,  -6.73532486e-01,
                         -6.71091318e-01,  -6.68708265e-01,  -6.66092694e-01,
                         -6.63709641e-01,  -6.61036015e-01,  -6.58420444e-01,
                         -6.56037390e-01,  -6.53421819e-01,  -6.50631905e-01,
                         -6.48016393e-01,  -6.45342708e-01,  -6.42610908e-01,
                         -6.40111625e-01,  -6.37263596e-01,  -6.34357393e-01,
                         -6.31625593e-01,  -6.28893793e-01,  -6.26045763e-01,
                         -6.23255849e-01,  -6.20349705e-01,  -6.17501676e-01,
                         -6.14827991e-01,  -6.11805558e-01,  -6.08957529e-01,
                         -6.06109500e-01,  -6.03145182e-01,  -6.00180924e-01,
                         -5.96926033e-01,  -5.94019830e-01,  -5.91171801e-01,
                         -5.87975025e-01,  -5.84894478e-01,  -5.81813991e-01,
                         -5.78500926e-01,  -5.75536668e-01,  -5.72398007e-01,
                         -5.69259346e-01,  -5.66062570e-01,  -5.62517047e-01,
                         -5.59262156e-01,  -5.55949092e-01,  -5.52868605e-01,
                         -5.49497426e-01,  -5.46068132e-01,  -5.42697012e-01,
                         -5.39209604e-01,  -5.35954714e-01,  -5.32525420e-01,
                         -5.28921783e-01,  -5.25550663e-01,  -5.22005141e-01,
                         -5.18459618e-01,  -5.14914095e-01,  -5.11194170e-01,
                         -5.07764935e-01,  -5.04219413e-01,  -5.00441372e-01,
                         -4.96837735e-01,  -4.92943496e-01,  -4.89281714e-01,
                         -4.85503703e-01,  -4.81725693e-01,  -4.78063911e-01,
                         -4.74169672e-01,  -4.70449775e-01,  -4.66613650e-01,
                         -4.62603122e-01,  -4.58592623e-01,  -4.54756498e-01,
                         -4.51152861e-01,  -4.47142333e-01,  -4.43015575e-01,
                         -4.39179450e-01,  -4.35168952e-01,  -4.30984080e-01,
                         -4.27089810e-01,  -4.23195541e-01,  -4.19301301e-01,
                         -4.15232658e-01,  -4.11222160e-01,  -4.07269776e-01,
                         -4.03143018e-01,  -3.99016261e-01,  -3.94947648e-01,
                         -3.90937150e-01,  -3.86810392e-01,  -3.82625520e-01,
                         -3.78382504e-01,  -3.74139518e-01,  -3.70129019e-01,
                         -3.66002262e-01,  -3.61643016e-01,  -3.57458144e-01,
                         -3.53273243e-01,  -3.48913997e-01,  -3.44612896e-01,
                         -3.40486139e-01,  -3.36068779e-01,  -3.31767648e-01,
                         -3.27640891e-01,  -3.23165387e-01,  -3.18631798e-01,
                         -3.14330667e-01,  -3.09913307e-01,  -3.05612177e-01,
                         -3.01369160e-01,  -2.96777427e-01,  -2.92243809e-01,
                         -2.87826449e-01,  -2.83409089e-01,  -2.78875470e-01,
                         -2.74225593e-01,  -2.69633859e-01,  -2.65216500e-01,
                         -2.60682881e-01,  -2.56033033e-01,  -2.51441270e-01,
                         -2.46849537e-01,  -2.42374048e-01,  -2.37724185e-01,
                         -2.33074322e-01,  -2.28540704e-01,  -2.23832726e-01,
                         -2.19357237e-01,  -2.14707375e-01,  -2.09941268e-01,
                         -2.05407649e-01,  -2.00757787e-01,  -1.95991680e-01,
                         -1.91399932e-01,  -1.86691955e-01,  -1.82042092e-01,
                         -1.77450359e-01,  -1.72742367e-01,  -1.68150634e-01,
                         -1.63384527e-01,  -1.58618420e-01,  -1.54084802e-01,
                         -1.49260566e-01,  -1.44494459e-01,  -1.39844596e-01,
                         -1.35020360e-01,  -1.30138010e-01,  -1.25313774e-01,
                         -1.20605789e-01,  -1.15897804e-01,  -1.11364193e-01,
                         -1.06598087e-01,  -1.01831973e-01,  -9.73564833e-02,
                         -9.25903767e-02,  -8.77080187e-02,  -8.31162781e-02,
                         -7.84082934e-02,  -7.36421868e-02,  -6.88760802e-02,
                         -6.40518442e-02,  -5.93438633e-02,  -5.45777529e-02,
                         -4.99278903e-02,  -4.52199057e-02,  -4.03375514e-02,
                         -3.56876887e-02,  -3.09797041e-02,  -2.60392260e-02,
                         -2.12149955e-02,  -1.65070090e-02,  -1.17990244e-02,
                         -6.97479304e-03,  -2.20868434e-03,   2.55742413e-03,
                          7.49790249e-03,   1.22640105e-02,   1.70301199e-02,
                          2.19124742e-02,   2.67367065e-02,   3.15609388e-02,
                          3.62689234e-02,   4.12093997e-02,   4.60917540e-02,
                          5.06834947e-02,   5.54496013e-02,   6.03900813e-02,
                          6.50399402e-02,   6.98060542e-02,   7.46884048e-02,
                          7.94545114e-02,   8.41043741e-02,   8.88704881e-02,
                          9.35784727e-02,   9.83445793e-02,   1.03226930e-01,
                          1.08051166e-01,   1.12642907e-01,   1.17292769e-01,
                          1.22000754e-01,   1.26708731e-01,   1.31358594e-01,
                          1.36008456e-01,   1.40716448e-01,   1.45366311e-01,
                          1.50074288e-01,   1.54666036e-01,   1.59257770e-01,
                          1.63965762e-01,   1.68383121e-01,   1.72800496e-01,
                          1.77334100e-01,   1.81925848e-01,   1.86691955e-01,
                          1.91283688e-01,   1.95817307e-01,   2.00467169e-01,
                          2.04942659e-01,   2.09418148e-01,   2.13893652e-01,
                          2.18427256e-01,   2.23019004e-01,   2.27494493e-01,
                          2.31911868e-01,   2.36387357e-01,   2.40804717e-01,
                          2.45338336e-01,   2.49697581e-01,   2.54056841e-01,
                          2.58590430e-01,   2.62891561e-01,   2.67483294e-01,
                          2.71900684e-01,   2.76143670e-01,   2.80677289e-01,
                          2.85036534e-01,   2.89395779e-01,   2.93813139e-01,
                          2.98172385e-01,   3.02647889e-01,   3.06949019e-01,
                          3.11192006e-01,   3.15609366e-01,   3.19852382e-01,
                          3.24095368e-01,   3.28222126e-01,   3.32639486e-01,
                          3.36998731e-01,   3.41009259e-01,   3.45426619e-01,
                          3.49669605e-01,   3.53563875e-01,   3.57806861e-01,
                          3.61933619e-01,   3.66118491e-01,   3.70245248e-01,
                          3.74255747e-01,   3.78382504e-01,   3.82334888e-01,
                          3.86403531e-01,   3.90472144e-01,   3.94482642e-01,
                          3.98667544e-01,   4.02503669e-01,   4.06223565e-01,
                          4.10234064e-01,   4.14186448e-01,   4.18255061e-01,
                          4.22033101e-01,   4.25752968e-01,   4.29589123e-01,
                          4.33367133e-01,   4.37319517e-01,   4.41271901e-01,
                          4.44991767e-01,   4.48769808e-01,   4.52489674e-01,
                          4.56151456e-01,   4.60045695e-01,   4.63707477e-01,
                          4.67253000e-01,   4.70914751e-01,   4.74634647e-01,
                          4.78180170e-01,   4.81725693e-01,   4.85445589e-01,
                          4.88991112e-01,   4.92710978e-01,   4.96430874e-01,
                          4.99802023e-01,   5.03347576e-01,   5.06776810e-01,
                          5.10264218e-01,   5.13867855e-01,   5.17413378e-01,
                          5.20900786e-01,   5.24446309e-01,   5.27643085e-01,
                          5.31072378e-01,   5.34559727e-01,   5.37698388e-01,
                          5.41243911e-01,   5.44615090e-01,   5.47753751e-01,
                          5.51124871e-01,   5.54437876e-01,   5.57809055e-01,
                          5.61122060e-01,   5.64144492e-01,   5.67341268e-01,
                          5.70479929e-01,   5.73444188e-01,   5.76524734e-01,
                          5.79547167e-01,   5.82511425e-01,   5.85591972e-01,
                          5.88672519e-01,   5.91636777e-01,   5.94542980e-01,
                          5.97391009e-01,   6.00239038e-01,   6.03261471e-01,
                          6.06051385e-01,   6.09015644e-01,   6.11805558e-01,
                          6.14595473e-01,   6.17443562e-01,   6.20000958e-01,
                          6.22790873e-01,   6.25348270e-01,   6.27963841e-01,
                          6.30869985e-01,   6.33369327e-01,   6.35868609e-01,
                          6.38716638e-01,   6.41332209e-01,   6.43773377e-01,
                          6.46388948e-01,   6.48888230e-01,   6.51503801e-01,
                          6.53886855e-01,   6.56386137e-01,   6.58885419e-01,
                          6.61268473e-01,   6.63709641e-01,   6.65802121e-01,
                          6.68185174e-01,   6.70626342e-01,   6.72660649e-01,
                          6.75276220e-01,   6.77833617e-01,   6.79867923e-01,
                          6.82192862e-01,   6.84575915e-01,   6.86900854e-01,
                          6.89283907e-01,   6.91201985e-01,   6.93526924e-01,
                          6.95561230e-01,   6.97479308e-01,   6.99862361e-01,
                          7.01954782e-01,   7.04105318e-01,   7.06197798e-01,
                          7.08232105e-01,   7.10208297e-01,   7.12068200e-01,
                          7.14218795e-01,   7.16369331e-01,   7.18171179e-01,
                          7.20031083e-01,   7.21600413e-01,   7.23344147e-01,
                          7.25436568e-01,   7.27180302e-01,   7.28865862e-01,
                          7.30667651e-01,   7.32178867e-01,   7.33864427e-01,
                          7.35491931e-01,   7.37235606e-01,   7.38804936e-01,
                          7.40374267e-01,   7.41827309e-01,   7.43338525e-01,
                          7.45024145e-01,   7.46360958e-01,   7.47697771e-01,
                          7.49325216e-01,   7.50836432e-01,   7.52115130e-01,
                          7.53510118e-01,   7.54905105e-01,   7.56358147e-01,
                          7.57695019e-01,   7.58857429e-01,   7.60310531e-01,
                          7.61414886e-01,   7.62519240e-01,   7.63856053e-01,
                          7.65018523e-01,   7.66122878e-01,   7.67459691e-01,
                          7.68680274e-01,   7.69668400e-01,   7.70888984e-01,
                          7.71993339e-01,   7.73039520e-01,   7.74318278e-01,
                          7.75248230e-01,   7.76061952e-01,   7.77166307e-01,
                          7.78154373e-01,   7.79258728e-01,   7.80537426e-01,
                          7.81293035e-01,   7.82164872e-01,   7.82920480e-01,
                          7.83734202e-01,   7.84722328e-01,   7.85594165e-01,
                          7.86407888e-01,   7.87047267e-01,   7.87860990e-01,
                          7.88558424e-01,   7.89139688e-01,   7.89837182e-01,
                          7.90418386e-01,   7.90999651e-01,   7.91522741e-01,
                          7.91697085e-01,   7.92278349e-01,   7.92917669e-01,
                          7.93382704e-01,   7.93673277e-01,   7.93963909e-01,
                          7.94196427e-01,   7.94370770e-01,   7.94661403e-01,
                          7.95184493e-01,   7.95068264e-01,   7.95126379e-01,
                          7.95184493e-01,   7.95300722e-01,   7.95358896e-01,
                          7.95300722e-01,   7.95417011e-01,   7.95242608e-01,
                          7.95184493e-01,   7.95358896e-01,   7.94952035e-01,
                          7.94835746e-01,   7.94893861e-01,   7.94487000e-01,
                          7.94370770e-01,   7.94196427e-01,   7.93731451e-01,
                          7.93498933e-01,   7.93208301e-01,   7.92859554e-01,
                          7.92220235e-01,   7.91755259e-01,   7.91638970e-01,
                          7.90941477e-01,   7.90476501e-01,   7.89953411e-01,
                          7.89197803e-01,   7.88790941e-01,   7.88151562e-01,
                          7.87396014e-01,   7.86930978e-01,   7.86001027e-01,
                          7.85071075e-01,   7.84315467e-01,   7.83443630e-01,
                          7.82746136e-01,   7.81583667e-01,   7.80769944e-01,
                          7.79956222e-01,   7.78735638e-01,   7.77863741e-01,
                          7.76643157e-01,   7.75713205e-01,   7.74550736e-01,
                          7.72923291e-01,   7.71935165e-01,   7.70598352e-01,
                          7.69145250e-01,   7.68157184e-01,   7.66529739e-01,
                          7.65251040e-01,   7.63797939e-01,   7.61937976e-01,
                          7.60601163e-01,   7.58915603e-01,   7.57171869e-01,
                          7.55951285e-01,   7.54149497e-01,   7.52521992e-01,
                          7.50603974e-01,   7.48860240e-01,   7.47116566e-01,
                          7.45372832e-01,   7.43512928e-01,   7.41478622e-01,
                          7.39444256e-01,   7.37642467e-01,   7.35608160e-01,
                          7.33573854e-01,   7.31597662e-01,   7.29330838e-01,
                          7.27412760e-01,   7.25378454e-01,   7.23169744e-01,
                          7.21193552e-01,   7.19043016e-01,   7.16659963e-01,
                          7.14393139e-01,   7.12126374e-01,   7.09743321e-01,
                          7.07476497e-01,   7.05267787e-01,   7.02535987e-01,
                          7.00269222e-01,   6.97827995e-01,   6.95212483e-01,
                          6.92771316e-01,   6.90330148e-01,   6.87656462e-01,
                          6.84866548e-01,   6.82192862e-01,   6.79577291e-01,
                          6.76787376e-01,   6.74288094e-01,   6.71556294e-01,
                          6.68650150e-01,   6.65860236e-01,   6.62837803e-01,
                          6.59989774e-01,   6.57141745e-01,   6.54003084e-01,
                          6.51329398e-01,   6.48190737e-01,   6.45052075e-01,
                          6.41971529e-01,   6.38658524e-01,   6.35577977e-01,
                          6.32381201e-01,   6.28951967e-01,   6.25871420e-01,
                          6.22558355e-01,   6.19187236e-01,   6.15990460e-01,
                          6.12561166e-01,   6.09131932e-01,   6.05818868e-01,
                          6.02389634e-01,   5.98960340e-01,   5.95414817e-01,
                          5.91927409e-01,   5.88323772e-01,   5.84720135e-01,
                          5.81058383e-01,   5.77570975e-01,   5.73676705e-01,
                          5.70073068e-01,   5.66585660e-01,   5.62807679e-01,
                          5.59262156e-01,   5.55542231e-01,   5.51764250e-01,
                          5.48218727e-01,   5.44498801e-01,   5.40662706e-01,
                          5.36942780e-01,   5.33164799e-01,   5.29503047e-01,
                          5.25725007e-01,   5.21830738e-01,   5.18110871e-01,
                          5.14390945e-01,   5.10438561e-01,   5.06776810e-01,
                          5.02998829e-01,   4.99220788e-01,   4.95210290e-01,
                          4.91141647e-01,   4.87247407e-01,   4.83469397e-01,
                          4.79458869e-01,   4.75622743e-01,   4.71379757e-01,
                          4.67253000e-01,   4.63358730e-01,   4.59115744e-01,
                          4.54872727e-01,   4.50920343e-01,   4.46851730e-01,
                          4.42783087e-01,   4.38481987e-01,   4.34122741e-01,
                          4.30054098e-01,   4.25811112e-01,   4.21451867e-01,
                          4.17150736e-01,   4.12733376e-01,   4.08374131e-01,
                          4.04131114e-01,   3.99771869e-01,   3.95354509e-01,
                          3.90879005e-01,   3.86519760e-01,   3.82102400e-01,
                          3.77685040e-01,   3.73151422e-01,   3.68675917e-01,
                          3.64200443e-01,   3.59608680e-01,   3.55191320e-01,
                          3.50657701e-01,   3.46007854e-01,   3.41474235e-01,
                          3.36882502e-01,   3.32348883e-01,   3.27873379e-01,
                          3.23223531e-01,   3.18573654e-01,   3.13923806e-01,
                          3.09390187e-01,   3.04856569e-01,   3.00148576e-01,
                          2.95614958e-01,   2.90790737e-01,   2.86024630e-01,
                          2.81665385e-01,   2.77015507e-01,   2.72249401e-01,
                          2.67541438e-01,   2.62717187e-01,   2.58067340e-01,
                          2.53301233e-01,   2.48535112e-01,   2.43885249e-01,
                          2.39119142e-01,   2.34294921e-01,   2.29528800e-01,
                          2.24704579e-01,   2.19938472e-01,   2.15056106e-01,
                          2.10348129e-01,   2.05407649e-01,   2.00292796e-01,
                          1.95352316e-01,   1.90469965e-01,   1.85645729e-01,
                          1.80647135e-01,   1.75590411e-01,   1.70882419e-01,
                          1.65941939e-01,   1.60827100e-01,   1.55770376e-01,
                          1.50829896e-01,   1.45773172e-01,   1.40542075e-01,
                          1.35543481e-01,   1.30603001e-01,   1.25371903e-01,
                          1.20198928e-01,   1.15084082e-01,   1.09911107e-01,
                          1.04970634e-01,   9.99139100e-02,   9.47409347e-02,
                          8.98004547e-02,   8.48018527e-02,   7.95126408e-02,
                          7.43396655e-02,   6.93991855e-02,   6.41099736e-02,
                          5.88788763e-02,   5.39965220e-02,   4.89397980e-02,
                          4.37668264e-02,   3.85357291e-02,   3.33627574e-02,
                          2.83641573e-02,   2.33074334e-02,   1.81344617e-02,
                          1.29614901e-02,   7.84664229e-03,   2.78991717e-03,
                         -2.38305423e-03,  -7.49790249e-03,  -1.24965040e-02,
                         -1.77275985e-02,  -2.30168160e-02,  -2.80735418e-02,
                         -3.31302658e-02,  -3.81869897e-02,  -4.34180871e-02,
                         -4.85329330e-02,  -5.37059046e-02,  -5.88788763e-02,
                         -6.40518442e-02,  -6.93410635e-02,  -7.45721608e-02,
                         -7.98032507e-02,  -8.50343481e-02,  -9.03235674e-02,
                         -9.56127867e-02,  -1.00727633e-01,  -1.05842479e-01,
                         -1.11189820e-01,  -1.16304673e-01,  -1.21477641e-01,
                         -1.26824990e-01,  -1.31997958e-01,  -1.37170926e-01,
                         -1.42227650e-01,  -1.47400618e-01,  -1.52689844e-01,
                         -1.57862812e-01,  -1.63210154e-01,  -1.68499365e-01,
                         -1.73497975e-01,  -1.78729072e-01,  -1.84018284e-01,
                         -1.89307496e-01,  -1.94480479e-01,  -1.99595317e-01,
                         -2.04826415e-01,  -2.09883139e-01,  -2.15056106e-01,
                         -2.20403448e-01,  -2.25343928e-01,  -2.30458781e-01,
                         -2.35573635e-01,  -2.40514100e-01,  -2.45628953e-01,
                         -2.50743806e-01,  -2.55916774e-01,  -2.60799140e-01,
                         -2.65913963e-01,  -2.70854443e-01,  -2.75794923e-01,
                         -2.81026036e-01,  -2.85792142e-01,  -2.90616363e-01,
                         -2.95789331e-01,  -3.00671697e-01,  -3.05437803e-01,
                         -3.10494512e-01,  -3.15434992e-01,  -3.20549846e-01,
                         -3.25432211e-01,  -3.30140203e-01,  -3.35080683e-01,
                         -3.39963019e-01,  -3.44787270e-01,  -3.49553376e-01,
                         -3.54435712e-01,  -3.59434336e-01,  -3.64316672e-01,
                         -3.69024664e-01,  -3.73848885e-01,  -3.78673136e-01,
                         -3.83555472e-01,  -3.88379723e-01,  -3.92971456e-01,
                         -3.97795677e-01,  -4.02503669e-01,  -4.07269776e-01,
                         -4.12035882e-01,  -4.16743875e-01,  -4.21451867e-01,
                         -4.26101714e-01,  -4.30925936e-01,  -4.35692072e-01,
                         -4.40341920e-01,  -4.44991767e-01,  -4.49641645e-01,
                         -4.54349637e-01,  -4.58999485e-01,  -4.63416845e-01,
                         -4.67950463e-01,  -4.72542226e-01,  -4.76843327e-01,
                         -4.81260717e-01,  -4.85852450e-01,  -4.90037322e-01,
                         -4.94512796e-01,  -4.98872042e-01,  -5.03056943e-01,
                         -5.07416189e-01,  -5.11949778e-01,  -5.15902162e-01,
                         -5.20203292e-01,  -5.24388194e-01,  -5.28398693e-01,
                         -5.32525420e-01,  -5.36594033e-01,  -5.40662706e-01,
                         -5.44731319e-01,  -5.48741817e-01,  -5.52752316e-01,
                         -5.56820989e-01,  -5.60715199e-01,  -5.64609468e-01,
                         -5.68445623e-01,  -5.72339892e-01,  -5.76292276e-01,
                         -5.80128372e-01,  -5.84022641e-01,  -5.87800682e-01,
                         -5.91578662e-01,  -5.95414817e-01,  -5.99134684e-01,
                         -6.02970839e-01,  -6.06574476e-01,  -6.10294342e-01,
                         -6.13898039e-01,  -6.17559791e-01,  -6.21221542e-01,
                         -6.24767065e-01,  -6.28312588e-01,  -6.32032454e-01,
                         -6.35461748e-01,  -6.38832927e-01,  -6.42436564e-01,
                         -6.45749569e-01,  -6.49236977e-01,  -6.52666211e-01,
                         -6.55863047e-01,  -6.59292281e-01,  -6.62721574e-01,
                         -6.65976465e-01,  -6.69057012e-01,  -6.72428131e-01,
                         -6.75624907e-01,  -6.78356707e-01,  -6.81495368e-01,
                         -6.84750259e-01,  -6.87714577e-01,  -6.90969467e-01,
                         -6.94050014e-01,  -6.96723700e-01,  -6.99687958e-01,
                         -7.02477872e-01,  -7.05267787e-01,  -7.08290219e-01,
                         -7.11022019e-01,  -7.13753819e-01,  -7.16369331e-01,
                         -7.19043016e-01,  -7.21542299e-01,  -7.24099755e-01,
                         -7.26657152e-01,  -7.29330838e-01,  -7.31713891e-01,
                         -7.34155059e-01,  -7.36479998e-01,  -7.38804936e-01,
                         -7.41246104e-01,  -7.43687272e-01,  -7.45954096e-01,
                         -7.47988403e-01,  -7.50255227e-01,  -7.52231419e-01,
                         -7.54498184e-01,  -7.56823123e-01,  -7.58683085e-01,
                         -7.60717392e-01,  -7.62635469e-01,  -7.64611661e-01,
                         -7.66820371e-01,  -7.68622160e-01,  -7.70482123e-01,
                         -7.72225797e-01,  -7.74085760e-01,  -7.76003838e-01,
                         -7.77921915e-01,  -7.79491246e-01,  -7.81293035e-01,
                         -7.82746136e-01,  -7.84606040e-01,  -7.86175370e-01,
                         -7.87744701e-01,  -7.89430320e-01,  -7.90941477e-01,
                         -7.92510808e-01,  -7.93847680e-01,  -7.95358896e-01,
                         -7.96986341e-01,  -7.98381269e-01,  -7.99834371e-01,
                         -8.01113069e-01,  -8.02275538e-01,  -8.03379893e-01,
                         -8.04484248e-01,  -8.05762947e-01,  -8.06925416e-01,
                         -8.07681024e-01,  -8.08727205e-01,  -8.09715331e-01,
                         -8.10529053e-01,  -8.11517119e-01,  -8.12156498e-01,
                         -8.13144624e-01,  -8.13842058e-01,  -8.14481437e-01,
                         -8.15353274e-01,  -8.15992653e-01,  -8.16399515e-01,
                         -8.16980720e-01,  -8.17503870e-01,  -8.17794442e-01,
                         -8.18259418e-01,  -8.18608165e-01,  -8.19247544e-01,
                         -8.19596291e-01,  -8.19886923e-01,  -8.20235610e-01,
                         -8.20468128e-01,  -8.20874989e-01,  -8.20933104e-01,
                         -8.20874989e-01,  -8.21165621e-01,  -8.21456194e-01,
                         -8.21514368e-01,  -8.21688712e-01,  -8.21688712e-01,
                         -8.21572483e-01,  -8.21630597e-01,  -8.21514368e-01,
                         -8.21514368e-01,  -8.21688712e-01,  -8.21398079e-01,
                         -8.21456194e-01,  -8.21456194e-01,  -8.21165621e-01,
                         -8.21049333e-01,  -8.20933104e-01,  -8.20642471e-01,
                         -8.20816875e-01,  -8.20293784e-01,  -8.20293784e-01,
                         -8.19886923e-01,  -8.19247544e-01,  -8.19015026e-01,
                         -8.18666279e-01,  -8.18259418e-01,  -8.18085074e-01,
                         -8.17678213e-01,  -8.17155123e-01,  -8.16341400e-01,
                         -8.16050768e-01,  -8.15818250e-01,  -8.14946413e-01,
                         -8.14248919e-01,  -8.13551486e-01,  -8.12679589e-01,
                         -8.12156498e-01,  -8.11400890e-01,  -8.10529053e-01,
                         -8.09773445e-01,  -8.08785379e-01,  -8.08087885e-01,
                         -8.06925416e-01,  -8.06169808e-01,  -8.05123568e-01,
                         -8.03844869e-01,  -8.02914917e-01,  -8.01868677e-01,
                         -8.00648093e-01,  -7.99543738e-01,  -7.98265040e-01,
                         -7.97160685e-01,  -7.95881987e-01,  -7.94312656e-01,
                         -7.93266416e-01,  -7.91929603e-01,  -7.90592790e-01,
                         -7.89372206e-01,  -7.87686586e-01,  -7.86407888e-01,
                         -7.84896672e-01,  -7.83269227e-01,  -7.81816125e-01,
                         -7.80363083e-01,  -7.78793752e-01,  -7.77340651e-01,
                         -7.75829434e-01,  -7.73911357e-01,  -7.72109568e-01,
                         -7.70540237e-01,  -7.68738389e-01,  -7.67169058e-01,
                         -7.65599728e-01,  -7.63565421e-01,  -7.61705518e-01,
                         -7.60136187e-01,  -7.58159995e-01,  -7.56474376e-01,
                         -7.54323840e-01,  -7.52289534e-01,  -7.50313342e-01,
                         -7.48395264e-01,  -7.46244729e-01,  -7.44268537e-01,
                         -7.42234230e-01,  -7.40083635e-01,  -7.37874985e-01,
                         -7.35666275e-01,  -7.33399451e-01,  -7.31016397e-01,
                         -7.28865862e-01,  -7.26599038e-01,  -7.24157870e-01,
                         -7.21716702e-01,  -7.19217360e-01,  -7.16834307e-01,
                         -7.14509428e-01,  -7.12010086e-01,  -7.09394574e-01,
                         -7.06662774e-01,  -7.04163432e-01,  -7.01606035e-01,
                         -6.99164867e-01,  -6.96374953e-01,  -6.93701267e-01,
                         -6.90969467e-01,  -6.88295782e-01,  -6.85331523e-01,
                         -6.82774067e-01,  -6.80042326e-01,  -6.77194238e-01,
                         -6.74113750e-01,  -6.71033204e-01,  -6.68475747e-01,
                         -6.65685833e-01,  -6.62663460e-01,  -6.59641027e-01,
                         -6.56618595e-01,  -6.53828681e-01,  -6.50631905e-01,
                         -6.47493243e-01,  -6.44703329e-01,  -6.41506553e-01,
                         -6.38077319e-01,  -6.35171115e-01,  -6.32090569e-01,
                         -6.28835678e-01,  -6.25522673e-01,  -6.22035265e-01,
                         -6.18954718e-01,  -6.15757942e-01,  -6.12444937e-01,
                         -6.09190047e-01,  -6.06051385e-01,  -6.02563977e-01,
                         -5.99192798e-01,  -5.95937908e-01,  -5.92450500e-01,
                         -5.88963151e-01,  -5.85591972e-01,  -5.82162678e-01,
                         -5.78559041e-01,  -5.75013518e-01,  -5.71467996e-01,
                         -5.68096876e-01,  -5.64841986e-01,  -5.60947716e-01,
                         -5.57227850e-01,  -5.53740442e-01,  -5.50078630e-01,
                         -5.46300650e-01,  -5.42755127e-01,  -5.39035261e-01,
                         -5.35257220e-01,  -5.31479239e-01,  -5.27526855e-01,
                         -5.23923159e-01,  -5.20145178e-01,  -5.16076565e-01,
                         -5.12240410e-01,  -5.08229911e-01,  -5.04161298e-01,
                         -5.00441372e-01,  -4.96488988e-01,  -4.92187887e-01,
                         -4.88351732e-01,  -4.84283119e-01,  -4.80446965e-01,
                         -4.76320237e-01,  -4.72077221e-01,  -4.68241096e-01,
                         -4.64230597e-01,  -4.60045695e-01,  -4.56093341e-01,
                         -4.52024698e-01,  -4.47839826e-01,  -4.43771183e-01,
                         -4.39760685e-01,  -4.35692072e-01,  -4.31681544e-01,
                         -4.27496672e-01,  -4.23253685e-01,  -4.19010669e-01,
                         -4.14883912e-01,  -4.10757184e-01,  -4.06572312e-01,
                         -4.02387410e-01,  -3.98202538e-01,  -3.93901438e-01,
                         -3.89658421e-01,  -3.85531664e-01,  -3.81230563e-01,
                         -3.77103806e-01,  -3.72918934e-01,  -3.68559688e-01,
                         -3.64200443e-01,  -3.60015541e-01,  -3.55888814e-01,
                         -3.51529568e-01,  -3.47112179e-01,  -3.42811078e-01,
                         -3.38568062e-01,  -3.34150702e-01,  -3.29907686e-01,
                         -3.25490326e-01,  -3.21014851e-01,  -3.16829950e-01,
                         -3.12412590e-01,  -3.07878971e-01,  -3.03403497e-01,
                         -2.98986107e-01,  -2.94510633e-01,  -2.90035129e-01,
                         -2.85559654e-01,  -2.81026036e-01,  -2.76376158e-01,
                         -2.71900684e-01,  -2.67483294e-01,  -2.62949675e-01,
                         -2.58241713e-01,  -2.53708094e-01,  -2.49290720e-01,
                         -2.44698986e-01,  -2.40107238e-01,  -2.35573635e-01,
                         -2.30807513e-01,  -2.26390153e-01,  -2.21624047e-01,
                         -2.16974184e-01,  -2.12324321e-01,  -2.07732573e-01,
                         -2.03257084e-01,  -1.98549107e-01,  -1.93841115e-01,
                         -1.89307496e-01,  -1.84425145e-01,  -1.79949656e-01,
                         -1.75474167e-01,  -1.70649931e-01,  -1.66058198e-01,
                         -1.61524579e-01,  -1.56816587e-01,  -1.52166724e-01,
                         -1.47458747e-01,  -1.42925128e-01,  -1.38217151e-01,
                         -1.33509159e-01,  -1.28859296e-01,  -1.24325685e-01,
                         -1.19617693e-01,  -1.14735343e-01,  -1.10201724e-01,
                         -1.05551861e-01,  -1.00843877e-01,  -9.63683873e-02,
                         -9.16604027e-02,  -8.68361741e-02,  -8.21281821e-02,
                         -7.73620754e-02,  -7.27703348e-02,  -6.80623502e-02,
                         -6.32381216e-02,  -5.87626286e-02,  -5.39383963e-02,
                         -4.91722897e-02,  -4.44061793e-02,  -3.97563204e-02,
                         -3.51645797e-02,  -3.02241016e-02,  -2.54579931e-02,
                         -2.08081324e-02,  -1.60420239e-02,  -1.12759154e-02,
                         -6.45168312e-03,  -1.68557488e-03,   3.02241021e-03,
                          7.73039553e-03,   1.24383802e-02,   1.73207354e-02,
                          2.21449677e-02,   2.68529523e-02,   3.17353085e-02,
                          3.65014151e-02,   4.12093997e-02,   4.59755100e-02,
                          5.06253727e-02,   5.55077270e-02,   6.02738336e-02,
                          6.50399402e-02,   6.97479248e-02,   7.43977875e-02,
                          7.91057721e-02,   8.37556347e-02,   8.83473754e-02,
                          9.31716040e-02,   9.78795961e-02,   1.02587581e-01,
                          1.07295565e-01,   1.11829177e-01,   1.16362795e-01,
                          1.20954528e-01,   1.25778764e-01,   1.30312383e-01,
                          1.34787872e-01,   1.39670223e-01,   1.44087598e-01,
                          1.48679331e-01,   1.53154820e-01,   1.57688439e-01,
                          1.62454545e-01,   1.66930035e-01,   1.71405539e-01,
                          1.76055402e-01,   1.80356517e-01,   1.85006380e-01,
                          1.89656243e-01,   1.94131732e-01,   1.98839724e-01,
                          2.03489587e-01,   2.07906947e-01,   2.12208077e-01,
                          2.16683567e-01,   2.21275300e-01,   2.25750789e-01,
                          2.30284408e-01,   2.34876141e-01,   2.39409760e-01,
                          2.44001508e-01,   2.48302624e-01,   2.52836227e-01,
                          2.57486105e-01,   2.61845350e-01,   2.66320825e-01,
                          2.70738214e-01,   2.75097460e-01,   2.79689193e-01,
                          2.83932179e-01,   2.88465798e-01,   2.92941302e-01,
                          2.97126174e-01,   3.01659793e-01,   3.05960923e-01,
                          3.10436398e-01,   3.14853758e-01,   3.18922400e-01,
                          3.23397905e-01,   3.27873379e-01,   3.31942022e-01,
                          3.36068779e-01,   3.40428025e-01,   3.44845384e-01,
                          3.48855883e-01,   3.52808267e-01,   3.57051283e-01,
                          3.61119896e-01,   3.65304768e-01,   3.69373411e-01,
                          3.73500168e-01,   3.77743155e-01,   3.81637424e-01,
                          3.85764152e-01,   3.89949054e-01,   3.93727064e-01,
                          3.97853792e-01,   4.01922435e-01,   4.05816704e-01,
                          4.09827203e-01,   4.13663328e-01,   4.17615712e-01,
                          4.21684355e-01,   4.25462365e-01,   4.29356635e-01,
                          4.33250874e-01,   4.37145144e-01,   4.41039413e-01,
                          4.44817424e-01,   4.48595434e-01,   4.52431560e-01,
                          4.56325829e-01,   4.60103840e-01,   4.63881850e-01,
                          4.67717975e-01,   4.71437871e-01,   4.75157768e-01,
                          4.78877664e-01,   4.82481301e-01,   4.86375540e-01,
                          4.90095437e-01,   4.93524700e-01,   4.97070223e-01,
                          5.00557601e-01,   5.04161298e-01,   5.07823050e-01,
                          5.11310458e-01,   5.14972210e-01,   5.18633962e-01,
                          5.22005141e-01,   5.25318146e-01,   5.28863668e-01,
                          5.32292962e-01,   5.35896599e-01,   5.39209604e-01,
                          5.42580783e-01,   5.46068132e-01,   5.49264908e-01,
                          5.52519858e-01,   5.55832863e-01,   5.58855295e-01,
                          5.62400818e-01,   5.65713823e-01,   5.68678081e-01,
                          5.72049260e-01,   5.75304151e-01,   5.78210294e-01,
                          5.81290841e-01,   5.84371388e-01,   5.87510049e-01,
                          5.90416193e-01,   5.93380511e-01,   5.96577287e-01,
                          5.99483430e-01,   6.02331460e-01,   6.05353892e-01,
                          6.08085692e-01,   6.10991836e-01,   6.14188612e-01,
                          6.16920412e-01,   6.19710326e-01,   6.22500241e-01,
                          6.25173926e-01,   6.27963841e-01,   6.30579412e-01,
                          6.33311212e-01,   6.36101127e-01,   6.38716638e-01,
                          6.41332209e-01,   6.44122124e-01,   6.46795809e-01,
                          6.49585724e-01,   6.52549982e-01,   6.55049264e-01,
                          6.57432318e-01,   6.60047889e-01,   6.62605345e-01,
                          6.65337086e-01,   6.68185174e-01,   6.70626342e-01,
                          6.73183739e-01,   6.75741196e-01,   6.78007960e-01,
                          6.80797875e-01,   6.83355331e-01,   6.85622156e-01,
                          6.88295782e-01,   6.90504491e-01,   6.92945659e-01,
                          6.95561230e-01,   6.97886169e-01,   7.00152934e-01,
                          7.02652276e-01,   7.04802811e-01,   7.07127750e-01,
                          7.09162056e-01,   7.11428881e-01,   7.13695645e-01,
                          7.15962470e-01,   7.18345523e-01,   7.20379829e-01,
                          7.22297907e-01,   7.24564731e-01,   7.26715267e-01,
                          7.28807747e-01,   7.30725765e-01,   7.32701957e-01,
                          7.34736323e-01,   7.36712515e-01,   7.38572419e-01,
                          7.40606725e-01,   7.42582917e-01,   7.44326651e-01,
                          7.46186554e-01,   7.47988403e-01,   7.49732077e-01,
                          7.51533926e-01,   7.53452003e-01,   7.54963219e-01,
                          7.56474376e-01,   7.58276224e-01,   7.60194302e-01,
                          7.61647403e-01,   7.63100445e-01,   7.64902294e-01,
                          7.66471624e-01,   7.68040955e-01,   7.69610286e-01,
                          7.71237731e-01,   7.72748947e-01,   7.74201989e-01,
                          7.75596976e-01,   7.76933789e-01,   7.78328776e-01,
                          7.79956222e-01,   7.81351149e-01,   7.82629848e-01,
                          7.83908606e-01,   7.85012901e-01,   7.86466002e-01,
                          7.87977219e-01,   7.89139688e-01,   7.90534616e-01,
                          7.91697085e-01,   7.92859554e-01,   7.94370770e-01,
                          7.95533240e-01,   7.96579480e-01,   7.97974408e-01,
                          7.99136877e-01,   7.99950600e-01,   8.01054955e-01,
                          8.02101195e-01,   8.03147376e-01,   8.04135501e-01,
                          8.05007339e-01,   8.05588543e-01,   8.06634784e-01,
                          8.07506621e-01,   8.08204114e-01,   8.09017837e-01,
                          8.09599102e-01,   8.10238421e-01,   8.10994029e-01,
                          8.11400890e-01,   8.12098384e-01,   8.12737703e-01,
                          8.13144624e-01,   8.13493311e-01,   8.13900173e-01,
                          8.14423323e-01,   8.14713895e-01,   8.15004528e-01,
                          8.15353274e-01,   8.15585792e-01,   8.15702021e-01,
                          8.15934539e-01,   8.15876365e-01,   8.16108882e-01,
                          8.16225111e-01,   8.16225111e-01,   8.16166997e-01,
                          8.16341400e-01,   8.16457629e-01,   8.16166997e-01,
                          8.16108882e-01,   8.16050768e-01,   8.15818250e-01,
                          8.15876365e-01,   8.15702021e-01,   8.15237045e-01,
                          8.15120757e-01,   8.14830184e-01,   8.14539552e-01,
                          8.14248919e-01,   8.13493311e-01,   8.13202739e-01,
                          8.13028336e-01,   8.12505245e-01,   8.11865866e-01,
                          8.11284661e-01,   8.10877800e-01,   8.10296535e-01,
                          8.09715331e-01,   8.09250355e-01,   8.08494747e-01,
                          8.07739139e-01,   8.07099760e-01,   8.06111693e-01,
                          8.05297971e-01,   8.04600477e-01,   8.03379893e-01,
                          8.02449942e-01,   8.01403701e-01,   8.00357461e-01,
                          7.99253106e-01,   7.98206925e-01,   7.97102571e-01,
                          7.95940101e-01,   7.94952035e-01,   7.93557048e-01,
                          7.92103946e-01,   7.90825248e-01,   7.89488435e-01,
                          7.88151562e-01,   7.86698520e-01,   7.85071075e-01,
                          7.83676088e-01,   7.82164872e-01,   7.80479312e-01,
                          7.79084384e-01,   7.77398765e-01,   7.75538862e-01,
                          7.73853242e-01,   7.72167683e-01,   7.70424008e-01,
                          7.68738389e-01,   7.66936600e-01,   7.64902294e-01,
                          7.63274848e-01,   7.61298656e-01,   7.59322464e-01,
                          7.57288158e-01,   7.55021334e-01,   7.53103256e-01,
                          7.51068950e-01,   7.48860240e-01,   7.47000337e-01,
                          7.44849741e-01,   7.42466688e-01,   7.40258038e-01,
                          7.38165557e-01,   7.36131251e-01,   7.33806312e-01,
                          7.31365144e-01,   7.29040205e-01,   7.26482809e-01,
                          7.24274099e-01,   7.21949160e-01,   7.19217360e-01,
                          7.16892481e-01,   7.14451253e-01,   7.11835742e-01,
                          7.09220171e-01,   7.06720889e-01,   7.03989089e-01,
                          7.01199174e-01,   6.98467374e-01,   6.95793688e-01,
                          6.93061888e-01,   6.90213859e-01,   6.87365830e-01,
                          6.84517801e-01,   6.81495368e-01,   6.78356707e-01,
                          6.75450563e-01,   6.72428131e-01,   6.69347644e-01,
                          6.66441441e-01,   6.63302779e-01,   6.60106003e-01,
                          6.56909227e-01,   6.53596222e-01,   6.50341332e-01,
                          6.46970153e-01,   6.43599033e-01,   6.40576601e-01,
                          6.37496054e-01,   6.33892417e-01,   6.30346894e-01,
                          6.26743257e-01,   6.23430252e-01,   6.20059073e-01,
                          6.16339207e-01,   6.12851799e-01,   6.09364390e-01,
                          6.05760753e-01,   6.02157116e-01,   5.98727822e-01,
                          5.95007956e-01,   5.91229916e-01,   5.87393820e-01,
                          5.83673894e-01,   5.79954028e-01,   5.76292276e-01,
                          5.72688639e-01,   5.68968713e-01,   5.64958215e-01,
                          5.61005831e-01,   5.57227850e-01,   5.53217292e-01,
                          5.49439311e-01,   5.45603156e-01,   5.41476429e-01,
                          5.37640274e-01,   5.33513546e-01,   5.29444873e-01,
                          5.25550663e-01,   5.21540105e-01,   5.17587721e-01,
                          5.13460994e-01,   5.09450495e-01,   5.05556226e-01,
                          5.01545727e-01,   4.97477084e-01,   4.93292212e-01,
                          4.89049226e-01,   4.85038728e-01,   4.80737597e-01,
                          4.76378351e-01,   4.72135335e-01,   4.67834234e-01,
                          4.63474989e-01,   4.58999485e-01,   4.54814613e-01,
                          4.50571626e-01,   4.45979863e-01,   4.41678762e-01,
                          4.37261373e-01,   4.32669640e-01,   4.28252280e-01,
                          4.23776776e-01,   4.19068813e-01,   4.14535195e-01,
                          4.10059690e-01,   4.05526072e-01,   4.00759965e-01,
                          3.96051973e-01,   3.91634613e-01,   3.86926621e-01,
                          3.82334888e-01,   3.77685040e-01,   3.72918934e-01,
                          3.68269056e-01,   3.63502949e-01,   3.58853102e-01,
                          3.54203224e-01,   3.49320859e-01,   3.44554752e-01,
                          3.39904904e-01,   3.35138798e-01,   3.30430806e-01,
                          3.25664699e-01,   3.20724219e-01,   3.15841854e-01,
                          3.11192006e-01,   3.06425899e-01,   3.01485419e-01,
                          2.96777427e-01,   2.91836947e-01,   2.86896467e-01,
                          2.82072246e-01,   2.77189881e-01,   2.72249401e-01,
                          2.67192692e-01,   2.62310326e-01,   2.57544219e-01,
                          2.52545625e-01,   2.47605145e-01,   2.42490292e-01,
                          2.37375453e-01,   2.32493088e-01,   2.27320120e-01,
                          2.22263396e-01,   2.17264801e-01,   2.12033704e-01,
                          2.07151353e-01,   2.02036500e-01,   1.96747273e-01,
                          1.91748679e-01,   1.86575711e-01,   1.81286484e-01,
                          1.76229760e-01,   1.71114922e-01,   1.65883824e-01,
                          1.60710856e-01,   1.55421630e-01,   1.50190532e-01,
                          1.45075694e-01,   1.39670223e-01,   1.34264767e-01,
                          1.29208043e-01,   1.23918816e-01,   1.18397109e-01,
                          1.13107890e-01,   1.07818671e-01,   1.02529451e-01,
                          9.71821100e-02,   9.17766467e-02,   8.64874274e-02,
                          8.11400861e-02,   7.59089962e-02,   7.07360208e-02,
                          6.54468089e-02,   6.00413419e-02,   5.46358787e-02,
                          4.94047813e-02,   4.40574400e-02,   3.86519767e-02,
                          3.33046354e-02,   2.80154180e-02,   2.26099528e-02,
                          1.71463657e-02,   1.18571473e-02,   6.68417662e-03,
                          1.22058869e-03,  -4.12675226e-03,  -9.41597018e-03,
                         -1.49376811e-02,  -2.01687757e-02,  -2.55742408e-02,
                         -3.10378280e-02,  -3.62689234e-02,  -4.17325087e-02,
                         -4.69636060e-02,  -5.21946996e-02,  -5.77745326e-02,
                         -6.31799996e-02,  -6.84692189e-02,  -7.40490481e-02,
                         -7.93963894e-02,  -8.46274868e-02,  -9.00329500e-02,
                         -9.55546647e-02,  -1.00902006e-01,  -1.06423713e-01,
                         -1.12061672e-01,  -1.17292769e-01,  -1.22698233e-01,
                         -1.28161818e-01,  -1.33567289e-01,  -1.39030874e-01,
                         -1.44610703e-01,  -1.50248662e-01,  -1.55537874e-01,
                         -1.60827100e-01,  -1.66465059e-01,  -1.71928644e-01,
                         -1.77392229e-01,  -1.82855815e-01,  -1.88086912e-01,
                         -1.93608627e-01,  -1.99014083e-01,  -2.04419553e-01,
                         -2.10115626e-01,  -2.15404853e-01,  -2.20752195e-01,
                         -2.26332024e-01,  -2.31621251e-01,  -2.37084836e-01,
                         -2.42490292e-01,  -2.47721389e-01,  -2.53126860e-01,
                         -2.58416086e-01,  -2.63821542e-01,  -2.69052625e-01,
                         -2.74283737e-01,  -2.79572934e-01,  -2.84571558e-01,
                         -2.89744526e-01,  -2.95149982e-01,  -3.00322950e-01,
                         -3.05612177e-01,  -3.10610771e-01,  -3.15667510e-01,
                         -3.20898592e-01,  -3.25955331e-01,  -3.31128299e-01,
                         -3.36068779e-01,  -3.41067374e-01,  -3.46530944e-01,
                         -3.51413310e-01,  -3.56237531e-01,  -3.61236155e-01,
                         -3.66234750e-01,  -3.71291459e-01,  -3.76348197e-01,
                         -3.81346792e-01,  -3.86054784e-01,  -3.90879005e-01,
                         -3.95993859e-01,  -4.00876224e-01,  -4.05816704e-01,
                         -4.10582811e-01,  -4.15290803e-01,  -4.20231253e-01,
                         -4.24881130e-01,  -4.29647237e-01,  -4.34645832e-01,
                         -4.39353824e-01,  -4.44061816e-01,  -4.48769808e-01,
                         -4.53535914e-01,  -4.58360136e-01,  -4.62893754e-01,
                         -4.67601746e-01,  -4.72251594e-01,  -4.76727098e-01,
                         -4.81376946e-01,  -4.85910565e-01,  -4.90211695e-01,
                         -4.94745314e-01,  -4.99395162e-01,  -5.03521919e-01,
                         -5.07939279e-01,  -5.12531042e-01,  -5.16715884e-01,
                         -5.21017015e-01,  -5.25318146e-01,  -5.29386759e-01,
                         -5.33687890e-01,  -5.37930906e-01,  -5.42115748e-01,
                         -5.46416879e-01,  -5.50194919e-01,  -5.54205418e-01,
                         -5.58274031e-01,  -5.61877668e-01,  -5.66004455e-01,
                         -5.69956839e-01,  -5.73560476e-01,  -5.77745318e-01,
                         -5.81639588e-01,  -5.85185111e-01,  -5.89021266e-01,
                         -5.92741132e-01,  -5.96402884e-01,  -6.00064695e-01,
                         -6.03377700e-01,  -6.06806993e-01,  -6.10352516e-01,
                         -6.14188612e-01,  -6.17850423e-01,  -6.21105313e-01,
                         -6.24476433e-01,  -6.27963841e-01,  -6.31451249e-01,
                         -6.34880543e-01,  -6.38309777e-01,  -6.41739070e-01,
                         -6.44993961e-01,  -6.48074508e-01,  -6.51329398e-01,
                         -6.54758692e-01,  -6.57955468e-01,  -6.61036015e-01,
                         -6.64116502e-01,  -6.67255163e-01,  -6.70335710e-01,
                         -6.73532486e-01,  -6.76438630e-01,  -6.79286718e-01,
                         -6.82367206e-01,  -6.85157120e-01,  -6.88237667e-01,
                         -6.90969467e-01,  -6.93643153e-01,  -6.96607411e-01,
                         -6.99048638e-01,  -7.01664150e-01,  -7.04744697e-01,
                         -7.07302094e-01,  -7.09685147e-01,  -7.12416947e-01,
                         -7.14974403e-01,  -7.17473686e-01,  -7.19856739e-01,
                         -7.22297907e-01,  -7.24797249e-01,  -7.27064013e-01,
                         -7.29388952e-01,  -7.31597662e-01,  -7.33922601e-01,
                         -7.36073136e-01,  -7.38049328e-01,  -7.40141749e-01,
                         -7.42234230e-01,  -7.44384766e-01,  -7.46535301e-01,
                         -7.48453379e-01,  -7.50255227e-01,  -7.52173305e-01,
                         -7.54091322e-01,  -7.56067514e-01,  -7.57753134e-01,
                         -7.59613037e-01,  -7.61473000e-01,  -7.62984216e-01,
                         -7.64844179e-01,  -7.66297221e-01,  -7.68099070e-01,
                         -7.69842744e-01,  -7.71237731e-01,  -7.72865176e-01,
                         -7.74318278e-01,  -7.75713205e-01,  -7.77166307e-01,
                         -7.78561234e-01,  -7.80014336e-01,  -7.81467438e-01,
                         -7.82862365e-01,  -7.84373581e-01,  -7.85477936e-01,
                         -7.86756635e-01,  -7.88151562e-01,  -7.89139688e-01,
                         -7.90534616e-01,  -7.91813374e-01,  -7.93092072e-01,
                         -7.94312656e-01,  -7.95184493e-01,  -7.96230733e-01,
                         -7.97509432e-01,  -7.98497558e-01,  -7.99369395e-01,
                         -8.00531864e-01,  -8.01519930e-01,  -8.02391768e-01,
                         -8.03205490e-01,  -8.04077387e-01,  -8.04891109e-01,
                         -8.05762947e-01,  -8.06576669e-01,  -8.07041645e-01,
                         -8.07739139e-01,  -8.08378458e-01,  -8.09075952e-01,
                         -8.09831560e-01,  -8.10470939e-01,  -8.10761511e-01,
                         -8.11168432e-01,  -8.11749637e-01,  -8.11982155e-01,
                         -8.12505245e-01,  -8.12912107e-01,  -8.13144624e-01,
                         -8.13493311e-01,  -8.13900173e-01,  -8.14074576e-01,
                         -8.14597666e-01,  -8.15004528e-01,  -8.14830184e-01,
                         -8.15004528e-01,  -8.15237045e-01,  -8.15469503e-01,
                         -8.15876365e-01,  -8.15934539e-01,  -8.15876365e-01,
                         -8.15934539e-01,  -8.16225111e-01,  -8.16166997e-01,
                         -8.16225111e-01,  -8.16166997e-01,  -8.15876365e-01,
                         -8.15934539e-01,  -8.15992653e-01,  -8.15760136e-01,
                         -8.15760136e-01,  -8.15527678e-01,  -8.15527678e-01,
                         -8.15702021e-01,  -8.15353274e-01,  -8.15120757e-01,
                         -8.15062642e-01,  -8.14713895e-01,  -8.14772069e-01,
                         -8.14423323e-01,  -8.14132690e-01,  -8.13958347e-01,
                         -8.13435197e-01,  -8.13086450e-01,  -8.12795877e-01,
                         -8.12447131e-01,  -8.12156498e-01,  -8.11517119e-01,
                         -8.11052144e-01,  -8.10645282e-01,  -8.09831560e-01,
                         -8.09366584e-01,  -8.08843493e-01,  -8.08204114e-01,
                         -8.07448506e-01,  -8.06634784e-01,  -8.06111693e-01,
                         -8.05414200e-01,  -8.04774821e-01,  -8.03844869e-01,
                         -8.02856803e-01,  -8.02101195e-01,  -8.01287472e-01,
                         -8.00415576e-01,  -7.99427509e-01,  -7.98555672e-01,
                         -7.97567546e-01,  -7.96405077e-01,  -7.95358896e-01,
                         -7.94370770e-01,  -7.93092072e-01,  -7.92045832e-01,
                         -7.90999651e-01,  -7.89604664e-01,  -7.88384080e-01,
                         -7.87163496e-01,  -7.85884798e-01,  -7.84547925e-01,
                         -7.83385456e-01,  -7.82048643e-01,  -7.80711830e-01,
                         -7.79491246e-01,  -7.77980030e-01,  -7.76585042e-01,
                         -7.75248230e-01,  -7.73678899e-01,  -7.72225797e-01,
                         -7.70830870e-01,  -7.69261539e-01,  -7.67750323e-01,
                         -7.66180992e-01,  -7.64379144e-01,  -7.62867987e-01,
                         -7.61182368e-01,  -7.59554923e-01,  -7.57869363e-01,
                         -7.56125689e-01,  -7.54498184e-01,  -7.52580166e-01,
                         -7.50894547e-01,  -7.49034643e-01,  -7.47000337e-01,
                         -7.45082259e-01,  -7.43164182e-01,  -7.41129875e-01,
                         -7.39211798e-01,  -7.37235606e-01,  -7.35143185e-01,
                         -7.33166993e-01,  -7.31074512e-01,  -7.28749573e-01,
                         -7.26482809e-01,  -7.24506617e-01,  -7.22239792e-01,
                         -7.19914854e-01,  -7.17764318e-01,  -7.15264976e-01,
                         -7.12998211e-01,  -7.10557044e-01,  -7.08115816e-01,
                         -7.05849051e-01,  -7.03233480e-01,  -7.00617909e-01,
                         -6.98118627e-01,  -6.95444942e-01,  -6.92713201e-01,
                         -6.90097630e-01,  -6.87482059e-01,  -6.84924662e-01,
                         -6.82367206e-01,  -6.79577291e-01,  -6.76671147e-01,
                         -6.73939347e-01,  -6.71265662e-01,  -6.68417633e-01,
                         -6.65802121e-01,  -6.62779689e-01,  -6.59931660e-01,
                         -6.57083631e-01,  -6.54235542e-01,  -6.51561916e-01,
                         -6.48365140e-01,  -6.45226479e-01,  -6.42320275e-01,
                         -6.39356017e-01,  -6.36507988e-01,  -6.33601785e-01,
                         -6.30521297e-01,  -6.27498865e-01,  -6.24360204e-01,
                         -6.21337771e-01,  -6.18373513e-01,  -6.15002334e-01,
                         -6.11921847e-01,  -6.08666897e-01,  -6.05470121e-01,
                         -6.02447748e-01,  -5.99076569e-01,  -5.95705450e-01,
                         -5.92566788e-01,  -5.89311898e-01,  -5.85708201e-01,
                         -5.82220852e-01,  -5.79024076e-01,  -5.75652897e-01,
                         -5.72281778e-01,  -5.69026828e-01,  -5.65365076e-01,
                         -5.61703324e-01,  -5.58390260e-01,  -5.54612279e-01,
                         -5.51299274e-01,  -5.47637463e-01,  -5.43743193e-01,
                         -5.40372074e-01,  -5.36710322e-01,  -5.32932281e-01,
                         -5.29212415e-01,  -5.25434375e-01,  -5.21714509e-01,
                         -5.17878354e-01,  -5.14042258e-01,  -5.10322332e-01,
                         -5.06253719e-01,  -5.02301335e-01,  -4.98581439e-01,
                         -4.94512796e-01,  -4.90676671e-01,  -4.86840546e-01,
                         -4.83004391e-01,  -4.78935778e-01,  -4.74925280e-01,
                         -4.71031010e-01,  -4.67136741e-01,  -4.63068128e-01,
                         -4.58941370e-01,  -4.54988986e-01,  -4.50804114e-01,
                         -4.46677357e-01,  -4.42666858e-01,  -4.38423842e-01,
                         -4.34297085e-01,  -4.30286586e-01,  -4.26101714e-01,
                         -4.22091216e-01,  -4.17964458e-01,  -4.13605213e-01,
                         -4.09478456e-01,  -4.05177325e-01,  -4.00934339e-01,
                         -3.96981955e-01,  -3.92622709e-01,  -3.88379723e-01,
                         -3.84311080e-01,  -3.80068094e-01,  -3.75766963e-01,
                         -3.71407717e-01,  -3.66990358e-01,  -3.62805486e-01,
                         -3.58446240e-01,  -3.53912622e-01,  -3.49669605e-01,
                         -3.45310360e-01,  -3.40834886e-01,  -3.36417496e-01,
                         -3.32000136e-01,  -3.27466518e-01,  -3.23165387e-01,
                         -3.18806142e-01,  -3.14040035e-01,  -3.09506416e-01,
                         -3.04972827e-01,  -3.00555438e-01,  -2.96138078e-01,
                         -2.91371971e-01,  -2.86780238e-01,  -2.82304734e-01,
                         -2.77596742e-01,  -2.73121268e-01,  -2.68529534e-01,
                         -2.63763428e-01,  -2.59171665e-01,  -2.54521817e-01,
                         -2.49755710e-01,  -2.44989604e-01,  -2.40397856e-01,
                         -2.35806122e-01,  -2.31098130e-01,  -2.26448268e-01,
                         -2.21507788e-01,  -2.16916054e-01,  -2.12266192e-01,
                         -2.07325712e-01,  -2.02792108e-01,  -1.97909743e-01,
                         -1.92969263e-01,  -1.88435659e-01,  -1.83727667e-01,
                         -1.78961560e-01,  -1.74195454e-01,  -1.69487461e-01,
                         -1.64663240e-01,  -1.59664631e-01,  -1.55131012e-01,
                         -1.50364906e-01,  -1.45366311e-01,  -1.40948936e-01,
                         -1.36182830e-01,  -1.31184235e-01,  -1.26476243e-01,
                         -1.21768259e-01,  -1.17002152e-01,  -1.12119794e-01,
                         -1.07469931e-01,  -1.02820069e-01,  -9.78214666e-02,
                         -9.31134820e-02,  -8.83473754e-02,  -8.34650174e-02,
                         -7.86989108e-02,  -7.38165602e-02,  -6.89923242e-02,
                         -6.41099736e-02,  -5.92857376e-02,  -5.45196310e-02,
                         -4.95791510e-02,  -4.47549187e-02,  -3.99306901e-02,
                         -3.48739624e-02,  -2.99916100e-02,  -2.52255015e-02,
                         -2.02850215e-02,  -1.52282976e-02,  -1.04040662e-02,
                         -5.57983434e-03,  -3.48739646e-04,   4.47549205e-03,
                          9.24160052e-03,   1.44726951e-02,   1.93550494e-02,
                          2.41792817e-02,   2.91197598e-02,   3.40602398e-02,
                          3.90588380e-02,   4.39411961e-02,   4.88235503e-02,
                          5.37640266e-02,   5.86463846e-02,   6.35287389e-02,
                          6.82948455e-02,   7.32353255e-02,   7.82339275e-02,
                          8.30000341e-02,   8.79986361e-02,   9.27066207e-02,
                          9.74146053e-02,   1.02645703e-01,   1.07237436e-01,
                          1.11829177e-01,   1.16885900e-01,   1.21652015e-01,
                          1.26418114e-01,   1.31184235e-01,   1.36008456e-01,
                          1.40716448e-01,   1.45424426e-01,   1.50423035e-01,
                          1.55189142e-01,   1.59839004e-01,   1.64721355e-01,
                          1.69313088e-01,   1.73904836e-01,   1.78787187e-01,
                          1.83437049e-01,   1.88086912e-01,   1.92853019e-01,
                          1.97619125e-01,   2.02268988e-01,   2.06860736e-01,
                          2.11568713e-01,   2.16451064e-01,   2.21159056e-01,
                          2.25634545e-01,   2.30342537e-01,   2.35166758e-01,
                          2.39874750e-01,   2.44524613e-01,   2.49232590e-01,
                          2.53824323e-01,   2.58532315e-01,   2.63182193e-01,
                          2.67773926e-01,   2.72598147e-01,   2.77189881e-01,
                          2.81665385e-01,   2.86489606e-01,   2.91081339e-01,
                          2.95673102e-01,   3.00148576e-01,   3.04798454e-01,
                          3.09506416e-01,   3.13865662e-01,   3.18341166e-01,
                          3.22991043e-01,   3.27466518e-01,   3.32174510e-01,
                          3.36591870e-01,   3.40893000e-01,   3.45542848e-01,
                          3.50076467e-01,   3.54493856e-01,   3.58736843e-01,
                          3.63154203e-01,   3.67745966e-01,   3.72105211e-01,
                          3.76580685e-01,   3.80823702e-01,   3.85182947e-01,
                          3.89542192e-01,   3.93785179e-01,   3.98144424e-01,
                          4.02445555e-01,   4.06572312e-01,   4.10931557e-01,
                          4.15174544e-01,   4.19417530e-01,   4.23660547e-01,
                          4.27729160e-01,   4.32030290e-01,   4.36098933e-01,
                          4.40225661e-01,   4.44584906e-01,   4.48711663e-01,
                          4.52954680e-01,   4.56965178e-01,   4.61033791e-01,
                          4.65160549e-01,   4.69229192e-01,   4.73530322e-01,
                          4.77598935e-01,   4.81551319e-01,   4.85619962e-01,
                          4.89572346e-01,   4.93640959e-01,   4.97825831e-01,
                          5.01661956e-01,   5.05846858e-01,   5.09857357e-01,
                          5.13751626e-01,   5.17878354e-01,   5.21714509e-01,
                          5.25666893e-01,   5.29851735e-01,   5.33687890e-01,
                          5.37465930e-01,   5.41360140e-01,   5.45196295e-01,
                          5.49206793e-01,   5.53333580e-01,   5.57053447e-01,
                          5.60831487e-01,   5.64725697e-01,   5.68445623e-01,
                          5.72339892e-01,   5.76234162e-01,   5.79837799e-01,
                          5.83732009e-01,   5.87393820e-01,   5.90823054e-01,
                          5.94775438e-01,   5.98437250e-01,   6.01982772e-01,
                          6.05528235e-01,   6.09015644e-01,   6.12677395e-01,
                          6.16106689e-01,   6.19652212e-01,   6.23255849e-01,
                          6.26568913e-01,   6.29940033e-01,   6.33543670e-01,
                          6.36972964e-01,   6.40460372e-01,   6.43889606e-01,
                          6.47202671e-01,   6.50515676e-01,   6.53770566e-01,
                          6.57083631e-01,   6.60396636e-01,   6.63767755e-01,
                          6.66906416e-01,   6.69986963e-01,   6.73241854e-01,
                          6.76496804e-01,   6.79926038e-01,   6.83006585e-01,
                          6.86087132e-01,   6.89400136e-01,   6.92538798e-01,
                          6.95735574e-01,   6.98932350e-01,   7.01896667e-01,
                          7.05035329e-01,   7.08057702e-01,   7.10847616e-01,
                          7.14102566e-01,   7.17066824e-01,   7.19856739e-01,
                          7.22995400e-01,   7.25901544e-01,   7.28749573e-01,
                          7.31772006e-01,   7.34620035e-01,   7.37468064e-01,
                          7.40316153e-01,   7.42989779e-01,   7.45837867e-01,
                          7.48511493e-01,   7.50952721e-01,   7.53626347e-01,
                          7.56300032e-01,   7.59031832e-01,   7.61589229e-01,
                          7.64088571e-01,   7.66704082e-01,   7.69145250e-01,
                          7.71702707e-01,   7.74318278e-01,   7.76701331e-01,
                          7.78968096e-01,   7.81176805e-01,   7.83269227e-01,
                          7.85768509e-01,   7.88093448e-01,   7.90069640e-01,
                          7.92336464e-01,   7.94370770e-01,   7.96346962e-01,
                          7.98497558e-01,   8.00589979e-01,   8.02682400e-01,
                          8.04600477e-01,   8.06286037e-01,   8.08262229e-01,
                          8.10122192e-01,   8.11865866e-01,   8.13900173e-01,
                          8.15702021e-01,   8.17736328e-01,   8.19596291e-01,
                          8.21281850e-01,   8.23141813e-01,   8.25001717e-01,
                          8.26861680e-01,   8.28547239e-01,   8.30232859e-01,
                          8.31627786e-01,   8.33197117e-01,   8.34998965e-01,
                          8.36510122e-01,   8.37963223e-01,   8.39648783e-01,
                          8.41101885e-01,   8.42496872e-01,   8.44008029e-01,
                          8.45228612e-01,   8.46623600e-01,   8.47960413e-01,
                          8.49122882e-01,   8.50343466e-01,   8.51505935e-01,
                          8.52726519e-01,   8.53714645e-01,   8.54760885e-01,
                          8.55865180e-01,   8.56795192e-01,   8.57667029e-01,
                          8.58538866e-01,   8.59526992e-01,   8.60515058e-01,
                          8.61096323e-01,   8.61677527e-01,   8.62433136e-01,
                          8.62781882e-01,   8.63421202e-01,   8.64002466e-01,
                          8.64409328e-01,   8.65048707e-01,   8.65397394e-01,
                          8.65571797e-01,   8.65804255e-01,   8.66327405e-01,
                          8.66734266e-01,   8.66734266e-01,   8.66850495e-01,
                          8.66966724e-01,   8.66792381e-01,   8.67024899e-01,
                          8.67199242e-01,   8.66966724e-01,   8.66966724e-01,
                          8.66908610e-01,   8.66850495e-01,   8.66676152e-01,
                          8.66501749e-01,   8.66269290e-01,   8.65688026e-01,
                          8.65455568e-01,   8.65164936e-01,   8.64641786e-01,
                          8.64351213e-01,   8.63828063e-01,   8.63188744e-01,
                          8.62781882e-01,   8.62200618e-01,   8.61561298e-01,
                          8.60863805e-01,   8.60050082e-01,   8.59352589e-01,
                          8.58422637e-01,   8.57783258e-01,   8.57027650e-01,
                          8.56039584e-01,   8.55342090e-01,   8.54412138e-01,
                          8.53307784e-01,   8.52319658e-01,   8.51331592e-01,
                          8.50401640e-01,   8.49413514e-01,   8.48192930e-01,
                          8.46914232e-01,   8.45751762e-01,   8.44414890e-01,
                          8.43019962e-01,   8.41857493e-01,   8.40578794e-01,
                          8.39009464e-01,   8.37498248e-01,   8.36161435e-01,
                          8.34882677e-01,   8.33313346e-01,   8.31627786e-01,
                          8.30116570e-01,   8.28256667e-01,   8.26629221e-01,
                          8.25118005e-01,   8.23374271e-01,   8.21456194e-01,
                          8.19305658e-01,   8.17329466e-01,   8.15295160e-01,
                          8.13377082e-01,   8.11517119e-01,   8.09424698e-01,
                          8.07448506e-01,   8.05414200e-01,   8.03031147e-01,
                          8.00880611e-01,   7.98788130e-01,   7.96637595e-01,
                          7.94661403e-01,   7.92162120e-01,   7.89720893e-01,
                          7.87337840e-01,   7.84838557e-01,   7.82629848e-01,
                          7.80130565e-01,   7.77689397e-01,   7.75364459e-01,
                          7.72748947e-01,   7.70075262e-01,   7.67459691e-01,
                          7.65018523e-01,   7.62577355e-01,   7.59845555e-01,
                          7.57171869e-01,   7.54498184e-01,   7.51766443e-01,
                          7.49325216e-01,   7.46535301e-01,   7.43745387e-01,
                          7.41129875e-01,   7.38339961e-01,   7.35608160e-01,
                          7.32701957e-01,   7.29912043e-01,   7.27122128e-01,
                          7.23983467e-01,   7.21135437e-01,   7.18171179e-01,
                          7.15148747e-01,   7.12358832e-01,   7.09278286e-01,
                          7.06081510e-01,   7.03175366e-01,   7.00036705e-01,
                          6.96839929e-01,   6.93643153e-01,   6.90562606e-01,
                          6.87365830e-01,   6.83820307e-01,   6.80449188e-01,
                          6.77252352e-01,   6.73939347e-01,   6.70568228e-01,
                          6.67138934e-01,   6.63884044e-01,   6.60629153e-01,
                          6.57025456e-01,   6.53538108e-01,   6.50050700e-01,
                          6.46447062e-01,   6.43075883e-01,   6.39530361e-01,
                          6.35926723e-01,   6.32439315e-01,   6.28719449e-01,
                          6.25232041e-01,   6.21512175e-01,   6.17676020e-01,
                          6.14014268e-01,   6.10352516e-01,   6.06574476e-01,
                          6.02912724e-01,   5.99192798e-01,   5.95414817e-01,
                          5.91753066e-01,   5.87858796e-01,   5.84080756e-01,
                          5.80419004e-01,   5.76582849e-01,   5.72630465e-01,
                          5.68794370e-01,   5.64900100e-01,   5.61005831e-01,
                          5.57111561e-01,   5.53101063e-01,   5.49439311e-01,
                          5.45428813e-01,   5.41185796e-01,   5.37175298e-01,
                          5.33222914e-01,   5.29328644e-01,   5.25376260e-01,
                          5.21191418e-01,   5.17180860e-01,   5.13170362e-01,
                          5.08985519e-01,   5.04916847e-01,   5.00848234e-01,
                          4.96837735e-01,   4.92885351e-01,   4.88758594e-01,
                          4.84631866e-01,   4.80505109e-01,   4.76378351e-01,
                          4.72251594e-01,   4.68066722e-01,   4.63765591e-01,
                          4.59580719e-01,   4.55512106e-01,   4.51269090e-01,
                          4.46909845e-01,   4.42666858e-01,   4.38307613e-01,
                          4.34006482e-01,   4.29705352e-01,   4.25287992e-01,
                          4.21045005e-01,   4.16627616e-01,   4.12035882e-01,
                          4.07502264e-01,   4.03084904e-01,   3.98725659e-01,
                          3.94308299e-01,   3.89658421e-01,   3.85008574e-01,
                          3.80416811e-01,   3.75941336e-01,   3.71349603e-01,
                          3.66583496e-01,   3.62049878e-01,   3.57516259e-01,
                          3.52808267e-01,   3.48158419e-01,   3.43508542e-01,
                          3.39033067e-01,   3.34441304e-01,   3.29617083e-01,
                          3.24850976e-01,   3.20201099e-01,   3.15493137e-01,
                          3.10843259e-01,   3.06251526e-01,   3.01601678e-01,
                          2.96835572e-01,   2.92185694e-01,   2.87419587e-01,
                          2.82653481e-01,   2.77887374e-01,   2.73063153e-01,
                          2.68413275e-01,   2.63356566e-01,   2.58416086e-01,
                          2.53824323e-01,   2.48767614e-01,   2.43769005e-01,
                          2.38828525e-01,   2.33771801e-01,   2.29063824e-01,
                          2.24007100e-01,   2.19008490e-01,   2.14184269e-01,
                          2.08953172e-01,   2.03954563e-01,   1.98839724e-01,
                          1.93724871e-01,   1.88842520e-01,   1.83553293e-01,
                          1.78496569e-01,   1.73439845e-01,   1.68325007e-01,
                          1.63558885e-01,   1.58327803e-01,   1.53096706e-01,
                          1.47981852e-01,   1.42692640e-01,   1.37403414e-01,
                          1.32056072e-01,   1.26824990e-01,   1.21593885e-01,
                          1.16188422e-01,   1.11073576e-01,   1.05842479e-01,
                          1.00495137e-01,   9.52640474e-02,   8.98585841e-02,
                          8.45693648e-02,   7.94545114e-02,   7.42815435e-02,
                          6.88760802e-02,   6.32962435e-02,   5.81232719e-02,
                          5.30084260e-02,   4.76610847e-02,   4.23718654e-02,
                          3.69082801e-02,   3.15609388e-02,   2.63298433e-02,
                          2.09825020e-02,   1.56932846e-02,   1.05784358e-02,
                          5.40546421e-03,   1.16246549e-04,  -5.28921792e-03,
                         -1.05203129e-02,  -1.58095304e-02,  -2.12731175e-02,
                         -2.64460891e-02,  -3.17934304e-02,  -3.72570194e-02,
                         -4.25462350e-02,  -4.78354543e-02,  -5.32990433e-02,
                         -5.86463846e-02,  -6.38193563e-02,  -6.92829415e-02,
                         -7.46884048e-02,  -8.00357461e-02,  -8.56155828e-02,
                         -9.10210460e-02,  -9.64265093e-02,  -1.01948224e-01,
                         -1.07179314e-01,  -1.12701029e-01,  -1.18280858e-01,
                         -1.23628199e-01,  -1.29149914e-01,  -1.34555385e-01,
                         -1.39960840e-01,  -1.45598799e-01,  -1.50946140e-01,
                         -1.56351611e-01,  -1.61815196e-01,  -1.67220652e-01,
                         -1.72684252e-01,  -1.78089708e-01,  -1.83553293e-01,
                         -1.89075008e-01,  -1.94538593e-01,  -2.00002179e-01,
                         -2.05407649e-01,  -2.10813120e-01,  -2.16392949e-01,
                         -2.21972778e-01,  -2.27320120e-01,  -2.32667461e-01,
                         -2.38131046e-01,  -2.43536517e-01,  -2.48767614e-01,
                         -2.54173070e-01,  -2.59578526e-01,  -2.64925867e-01,
                         -2.70273209e-01,  -2.75562435e-01,  -2.80909777e-01,
                         -2.86373377e-01,  -2.91546345e-01,  -2.96835572e-01,
                         -3.02182913e-01,  -3.07588369e-01,  -3.12761337e-01,
                         -3.17934304e-01,  -3.23223531e-01,  -3.28454614e-01,
                         -3.33511353e-01,  -3.38742435e-01,  -3.43973517e-01,
                         -3.49146515e-01,  -3.54261339e-01,  -3.59376192e-01,
                         -3.64549160e-01,  -3.69605899e-01,  -3.74778867e-01,
                         -3.80068094e-01,  -3.85182947e-01,  -3.90239656e-01,
                         -3.95296395e-01,  -4.00411218e-01,  -4.05526072e-01,
                         -4.10640925e-01,  -4.15697664e-01,  -4.20638144e-01,
                         -4.25694853e-01,  -4.30809706e-01,  -4.35633928e-01,
                         -4.40516293e-01,  -4.45631146e-01,  -4.50687855e-01,
                         -4.55570221e-01,  -4.60510701e-01,  -4.65334922e-01,
                         -4.70159173e-01,  -4.75041509e-01,  -4.79865760e-01,
                         -4.84689981e-01,  -4.89456087e-01,  -4.94164079e-01,
                         -4.98988301e-01,  -5.03638148e-01,  -5.08288026e-01,
                         -5.13228476e-01,  -5.17820239e-01,  -5.22179484e-01,
                         -5.26771247e-01,  -5.31537354e-01,  -5.36361575e-01,
                         -5.40662706e-01,  -5.44905663e-01,  -5.49671769e-01,
                         -5.53914785e-01,  -5.58157802e-01,  -5.62691391e-01,
                         -5.67050636e-01,  -5.71293652e-01,  -5.75420380e-01,
                         -5.79605281e-01,  -5.83906412e-01,  -5.87975025e-01,
                         -5.92043638e-01,  -5.96170425e-01,  -6.00239038e-01,
                         -6.04423940e-01,  -6.08434439e-01,  -6.12212420e-01,
                         -6.16106689e-01,  -6.20117188e-01,  -6.24069571e-01,
                         -6.27905726e-01,  -6.31799996e-01,  -6.35519862e-01,
                         -6.39239788e-01,  -6.43017769e-01,  -6.46679521e-01,
                         -6.50399446e-01,  -6.54119313e-01,  -6.57606721e-01,
                         -6.61500990e-01,  -6.65046513e-01,  -6.68417633e-01,
                         -6.72079384e-01,  -6.75508678e-01,  -6.79170430e-01,
                         -6.82715952e-01,  -6.85854614e-01,  -6.89342022e-01,
                         -6.92771316e-01,  -6.96026206e-01,  -6.99339211e-01,
                         -7.02710390e-01,  -7.06023395e-01,  -7.09162056e-01,
                         -7.12475061e-01,  -7.15555608e-01,  -7.18519926e-01,
                         -7.21658587e-01,  -7.24622846e-01,  -7.27761507e-01,
                         -7.30725765e-01,  -7.33573854e-01,  -7.36596227e-01,
                         -7.39269912e-01,  -7.41943598e-01,  -7.44849741e-01,
                         -7.47407198e-01,  -7.50138938e-01,  -7.52812624e-01,
                         -7.55253792e-01,  -7.57869363e-01,  -7.60484934e-01,
                         -7.63042331e-01,  -7.65541613e-01,  -7.67866552e-01,
                         -7.70133376e-01,  -7.72574544e-01,  -7.74899483e-01,
                         -7.77166307e-01,  -7.79491246e-01,  -7.81758010e-01,
                         -7.83792317e-01,  -7.85768509e-01,  -7.87860990e-01,
                         -7.90069640e-01,  -7.92162120e-01,  -7.94080138e-01,
                         -7.96114504e-01,  -7.98090696e-01,  -7.99892485e-01,
                         -8.01868677e-01,  -8.03902984e-01,  -8.05704832e-01,
                         -8.07506621e-01,  -8.09250355e-01,  -8.10877800e-01,
                         -8.12679589e-01,  -8.14539552e-01,  -8.16166997e-01,
                         -8.17736328e-01,  -8.19421887e-01,  -8.21049333e-01,
                         -8.22676837e-01,  -8.24246168e-01,  -8.25699210e-01,
                         -8.27268541e-01,  -8.28779757e-01,  -8.30116570e-01,
                         -8.31511557e-01,  -8.33080888e-01,  -8.34650218e-01,
                         -8.35987031e-01,  -8.37265730e-01,  -8.38544488e-01,
                         -8.39706957e-01,  -8.40869367e-01,  -8.42031837e-01,
                         -8.43194306e-01,  -8.44414890e-01,  -8.45344901e-01,
                         -8.46391082e-01,  -8.47727954e-01,  -8.48541677e-01,
                         -8.49355400e-01,  -8.50517869e-01,  -8.51273477e-01,
                         -8.51970971e-01,  -8.52784693e-01,  -8.53540242e-01,
                         -8.54354024e-01,  -8.54993343e-01,  -8.55748951e-01,
                         -8.56562674e-01,  -8.57318282e-01,  -8.57783258e-01,
                         -8.58248234e-01,  -8.58887613e-01,  -8.59468818e-01,
                         -8.59991968e-01,  -8.60747576e-01,  -8.61096323e-01,
                         -8.61503184e-01,  -8.62142503e-01,  -8.62375021e-01,
                         -8.62898111e-01,  -8.63363087e-01,  -8.63595605e-01,
                         -8.64234924e-01,  -8.64351213e-01,  -8.64758074e-01,
                         -8.65339279e-01,  -8.65513682e-01,  -8.65746140e-01,
                         -8.66153002e-01,  -8.66443634e-01,  -8.66617978e-01,
                         -8.66559863e-01,  -8.66617978e-01,  -8.66850495e-01,
                         -8.67024899e-01,  -8.67141128e-01,  -8.67083013e-01,
                         -8.67141128e-01,  -8.67257357e-01,  -8.66966724e-01,
                         -8.66966724e-01,  -8.67141128e-01,  -8.66850495e-01,
                         -8.66734266e-01,  -8.66501749e-01,  -8.66211116e-01,
                         -8.66094887e-01,  -8.65862429e-01,  -8.65513682e-01,
                         -8.65106821e-01,  -8.64990532e-01,  -8.64641786e-01,
                         -8.64060581e-01,  -8.63769948e-01,  -8.63421202e-01,
                         -8.62839997e-01,  -8.62491250e-01,  -8.61851871e-01,
                         -8.60921919e-01,  -8.60224426e-01,  -8.59817564e-01,
                         -8.59178245e-01,  -8.58364522e-01,  -8.57550800e-01,
                         -8.56504560e-01,  -8.55574608e-01,  -8.54993343e-01,
                         -8.53947163e-01,  -8.52726519e-01,  -8.51970971e-01,
                         -8.50982845e-01,  -8.49646032e-01,  -8.48599792e-01,
                         -8.47553551e-01,  -8.46391082e-01,  -8.45403016e-01,
                         -8.44240546e-01,  -8.42903733e-01,  -8.41508746e-01,
                         -8.40055645e-01,  -8.38776946e-01,  -8.37614477e-01,
                         -8.36161435e-01,  -8.34766448e-01,  -8.33371520e-01,
                         -8.31976533e-01,  -8.30523431e-01,  -8.28895986e-01,
                         -8.27559173e-01,  -8.26106071e-01,  -8.24362397e-01,
                         -8.22734952e-01,  -8.20991218e-01,  -8.19538176e-01,
                         -8.18201303e-01,  -8.16341400e-01,  -8.14539552e-01,
                         -8.12737703e-01,  -8.10761511e-01,  -8.09075952e-01,
                         -8.07274163e-01,  -8.05356085e-01,  -8.03263664e-01,
                         -8.01171184e-01,  -7.99253106e-01,  -7.97160685e-01,
                         -7.95126379e-01,  -7.93150187e-01,  -7.90999651e-01,
                         -7.88674712e-01,  -7.86291659e-01,  -7.84141064e-01,
                         -7.81932414e-01,  -7.79549360e-01,  -7.77224422e-01,
                         -7.74841368e-01,  -7.72458315e-01,  -7.69959033e-01,
                         -7.67343462e-01,  -7.65076637e-01,  -7.62344837e-01,
                         -7.59554923e-01,  -7.56997526e-01,  -7.54091322e-01,
                         -7.51533926e-01,  -7.48976529e-01,  -7.46070325e-01,
                         -7.43338525e-01,  -7.40432382e-01,  -7.37584352e-01,
                         -7.34852552e-01,  -7.31830120e-01,  -7.28807747e-01,
                         -7.25785315e-01,  -7.22821057e-01,  -7.19682395e-01,
                         -7.16659963e-01,  -7.13928163e-01,  -7.10789502e-01,
                         -7.07534611e-01,  -7.04628468e-01,  -7.01315403e-01,
                         -6.98118627e-01,  -6.94979966e-01,  -6.91608846e-01,
                         -6.88353956e-01,  -6.85040891e-01,  -6.81727886e-01,
                         -6.78298593e-01,  -6.74811184e-01,  -6.71672523e-01,
                         -6.68301404e-01,  -6.64755881e-01,  -6.61326587e-01,
                         -6.57839179e-01,  -6.54468060e-01,  -6.50922537e-01,
                         -6.47144496e-01,  -6.43715262e-01,  -6.40053511e-01,
                         -6.36275470e-01,  -6.32788062e-01,  -6.29010081e-01,
                         -6.25406444e-01,  -6.21686518e-01,  -6.17792249e-01,
                         -6.14130497e-01,  -6.10410631e-01,  -6.06632590e-01,
                         -6.02912724e-01,  -5.99134684e-01,  -5.95298588e-01,
                         -5.91346204e-01,  -5.87568164e-01,  -5.83790183e-01,
                         -5.79663396e-01,  -5.75652897e-01,  -5.71700513e-01,
                         -5.67399383e-01,  -5.63214540e-01,  -5.59262156e-01,
                         -5.55019140e-01,  -5.50718009e-01,  -5.46823740e-01,
                         -5.42638898e-01,  -5.38279653e-01,  -5.34210980e-01,
                         -5.29968023e-01,  -5.25725007e-01,  -5.21365762e-01,
                         -5.16832173e-01,  -5.12472928e-01,  -5.08055508e-01,
                         -5.03696263e-01,  -4.99569535e-01,  -4.95094031e-01,
                         -4.90618557e-01,  -4.86084938e-01,  -4.81725693e-01,
                         -4.77366447e-01,  -4.72716570e-01,  -4.68299210e-01,
                         -4.63823736e-01,  -4.59057599e-01,  -4.54640239e-01,
                         -4.50222880e-01,  -4.45573002e-01,  -4.41039413e-01,
                         -4.36505795e-01,  -4.31855917e-01,  -4.27147925e-01,
                         -4.22556192e-01,  -4.17790085e-01,  -4.13140237e-01,
                         -4.08839107e-01,  -4.03956741e-01,  -3.99132520e-01,
                         -3.94715160e-01,  -3.89832795e-01,  -3.85124803e-01,
                         -3.80474955e-01,  -3.75418216e-01,  -3.70652109e-01,
                         -3.65886003e-01,  -3.60887408e-01,  -3.56063187e-01,
                         -3.51122707e-01,  -3.46298456e-01,  -3.41532350e-01,
                         -3.36591870e-01,  -3.31593275e-01,  -3.26536536e-01,
                         -3.21537942e-01,  -3.16539347e-01,  -3.11482608e-01,
                         -3.06367785e-01,  -3.01136672e-01,  -2.96021819e-01,
                         -2.91139483e-01,  -2.86024630e-01,  -2.80967891e-01,
                         -2.75969297e-01,  -2.70796329e-01,  -2.65623361e-01,
                         -2.60682881e-01,  -2.55451798e-01,  -2.50104457e-01,
                         -2.45105848e-01,  -2.39990994e-01,  -2.34759897e-01,
                         -2.29645059e-01,  -2.24530205e-01,  -2.19415352e-01,
                         -2.14300513e-01,  -2.09069416e-01,  -2.03780189e-01,
                         -1.98490977e-01,  -1.93376124e-01,  -1.88203156e-01,
                         -1.83030188e-01,  -1.77915335e-01,  -1.72626123e-01,
                         -1.67453155e-01,  -1.62512675e-01,  -1.57281578e-01,
                         -1.52224854e-01,  -1.47110000e-01,  -1.41820788e-01,
                         -1.36705935e-01,  -1.31416723e-01,  -1.26243755e-01,
                         -1.21128902e-01,  -1.15955934e-01,  -1.10782959e-01,
                         -1.05493739e-01,  -1.00204520e-01,  -9.49734300e-02,
                         -8.96260887e-02,  -8.44531134e-02,  -7.92801455e-02,
                         -7.39328042e-02,  -6.87017068e-02,  -6.34124950e-02,
                         -5.81813976e-02,  -5.31246737e-02,  -4.77192067e-02,
                         -4.23718654e-02,  -3.71988937e-02,  -3.18515524e-02,
                         -2.66204588e-02,  -2.14474872e-02,  -1.61582697e-02,
                         -1.08690523e-02,  -5.63795771e-03,  -2.32493097e-04,
                          5.11484826e-03,   1.03459423e-02,   1.55770369e-02,
                          2.08662543e-02,   2.60973498e-02,   3.14446911e-02,
                          3.67339104e-02,   4.20231260e-02,   4.73123454e-02,
                          5.24853170e-02,   5.77745326e-02,   6.29475042e-02,
                          6.82367235e-02,   7.35840648e-02,   7.86407888e-02,
                          8.39300081e-02,   8.91610980e-02,   9.42759514e-02,
                          9.95651707e-02,   1.04738139e-01,   1.09911107e-01,
                          1.15142204e-01,   1.20198928e-01,   1.25430018e-01,
                          1.30544871e-01,   1.35601595e-01,   1.40890822e-01,
                          1.45889416e-01,   1.50771767e-01,   1.55886620e-01,
                          1.60885215e-01,   1.65825695e-01,   1.70940548e-01,
                          1.76055402e-01,   1.81170240e-01,   1.86168849e-01,
                          1.91051200e-01,   1.95933551e-01,   2.00874031e-01,
                          2.05814511e-01,   2.10813120e-01,   2.15811715e-01,
                          2.20810309e-01,   2.25867033e-01,   2.30807513e-01,
                          2.35631749e-01,   2.40455985e-01,   2.45338336e-01,
                          2.50395060e-01,   2.55451798e-01,   2.60392278e-01,
                          2.65216500e-01,   2.70215094e-01,   2.75155574e-01,
                          2.79921681e-01,   2.84745902e-01,   2.89628267e-01,
                          2.94568747e-01,   2.99451113e-01,   3.04333448e-01,
                          3.08925211e-01,   3.13807547e-01,   3.18922400e-01,
                          3.23514134e-01,   3.28222126e-01,   3.33220720e-01,
                          3.37928712e-01,   3.42462331e-01,   3.47170323e-01,
                          3.51878285e-01,   3.56528163e-01,   3.61236155e-01,
                          3.65886003e-01,   3.70535880e-01,   3.75301987e-01,
                          3.80009949e-01,   3.84485453e-01,   3.88902813e-01,
                          3.93436432e-01,   3.97970051e-01,   4.02561784e-01,
                          4.07153517e-01,   4.11745280e-01,   4.16220754e-01,
                          4.20580000e-01,   4.24997389e-01,   4.29414749e-01,
                          4.33773994e-01,   4.38016981e-01,   4.42376226e-01,
                          4.46735471e-01,   4.50920343e-01,   4.55279589e-01,
                          4.59813207e-01,   4.63939965e-01,   4.68182981e-01,
                          4.72600341e-01,   4.76785213e-01,   4.80911970e-01,
                          4.85096842e-01,   4.89397973e-01,   4.93582845e-01,
                          4.97709602e-01,   5.01778245e-01,   5.05904973e-01,
                          5.10206103e-01,   5.14158487e-01,   5.18168986e-01,
                          5.22470117e-01,   5.26596844e-01,   5.30607343e-01,
                          5.34792244e-01,   5.39093375e-01,   5.43045759e-01,
                          5.46940029e-01,   5.51182985e-01,   5.55077255e-01,
                          5.59087753e-01,   5.63272655e-01,   5.66818178e-01,
                          5.70886791e-01,   5.75071692e-01,   5.78733444e-01,
                          5.82802057e-01,   5.86754441e-01,   5.90299964e-01,
                          5.94136119e-01,   5.98204732e-01,   6.01982772e-01,
                          6.05644524e-01,   6.09422505e-01,   6.13142431e-01,
                          6.16746068e-01,   6.20524049e-01,   6.24127686e-01,
                          6.27673209e-01,   6.31335020e-01,   6.34764254e-01,
                          6.38426006e-01,   6.41971529e-01,   6.45458937e-01,
                          6.49120688e-01,   6.52491868e-01,   6.55863047e-01,
                          6.59408510e-01,   6.62721574e-01,   6.66092694e-01,
                          6.69463873e-01,   6.72718763e-01,   6.76031768e-01,
                          6.79170430e-01,   6.82425380e-01,   6.85912728e-01,
                          6.89167678e-01,   6.92364454e-01,   6.95328712e-01,
                          6.98467374e-01,   7.01722264e-01,   7.04744697e-01,
                          7.07941473e-01,   7.11196363e-01,   7.14335024e-01,
                          7.17241168e-01,   7.20147371e-01,   7.23227918e-01,
                          7.26424694e-01,   7.29330838e-01,   7.32062638e-01,
                          7.35259414e-01,   7.38223672e-01,   7.40955472e-01,
                          7.43977904e-01,   7.46825933e-01,   7.49673963e-01,
                          7.52696395e-01,   7.55137563e-01,   7.57811248e-01,
                          7.60543048e-01,   7.63158560e-01,   7.66122878e-01,
                          7.68738389e-01,   7.71121442e-01,   7.73795128e-01,
                          7.76410699e-01,   7.78793752e-01,   7.81293035e-01,
                          7.83908606e-01,   7.86291659e-01,   7.88790941e-01,
                          7.91173995e-01,   7.93382704e-01,   7.95707583e-01,
                          7.97974408e-01,   8.00299346e-01,   8.02624285e-01,
                          8.04658592e-01,   8.06692898e-01,   8.09017837e-01,
                          8.11110258e-01,   8.13144624e-01,   8.15004528e-01,
                          8.16864491e-01,   8.19073141e-01,   8.21049333e-01,
                          8.22734952e-01,   8.24827373e-01,   8.26803565e-01,
                          8.28605413e-01,   8.30523431e-01,   8.32441509e-01,
                          8.34417701e-01,   8.36335778e-01,   8.38137627e-01,
                          8.39881301e-01,   8.41450632e-01,   8.43484938e-01,
                          8.45403016e-01,   8.46681714e-01,   8.48425448e-01,
                          8.50052893e-01,   8.51564050e-01,   8.53249669e-01,
                          8.54935229e-01,   8.56446445e-01,   8.57957661e-01,
                          8.59352589e-01,   8.60805690e-01,   8.62258732e-01,
                          8.63653719e-01,   8.65106821e-01,   8.66327405e-01,
                          8.67547989e-01,   8.68710458e-01,   8.69989157e-01,
                          8.71267855e-01,   8.72430325e-01,   8.73534679e-01,
                          8.74580920e-01,   8.75801504e-01,   8.76789570e-01,
                          8.77777696e-01,   8.78649533e-01,   8.79695714e-01,
                          8.80451322e-01,   8.81032586e-01,   8.81788194e-01,
                          8.82543802e-01,   8.83357525e-01,   8.83996844e-01,
                          8.84578109e-01,   8.84984970e-01,   8.85566175e-01,
                          8.86089325e-01,   8.86438072e-01,   8.86903048e-01,
                          8.87251794e-01,   8.87600482e-01,   8.88007343e-01,
                          8.88181746e-01,   8.88414264e-01,   8.88704836e-01,
                          8.88821125e-01,   8.88995469e-01,   8.88821125e-01,
                          8.88937354e-01,   8.89111698e-01,   8.88704836e-01,
                          8.88879240e-01,   8.88995469e-01,   8.88530493e-01,
                          8.88356090e-01,   8.88356090e-01,   8.88007343e-01,
                          8.87774885e-01,   8.87600482e-01,   8.87368023e-01,
                          8.86844933e-01,   8.86379898e-01,   8.86205554e-01,
                          8.85856807e-01,   8.85333717e-01,   8.84868741e-01,
                          8.84287477e-01,   8.83648098e-01,   8.82950664e-01,
                          8.82369399e-01,   8.81730080e-01,   8.81090701e-01,
                          8.80393207e-01,   8.79579484e-01,   8.78707647e-01,
                          8.77777696e-01,   8.77080202e-01,   8.76150250e-01,
                          8.74987781e-01,   8.74057770e-01,   8.73127818e-01,
                          8.72023463e-01,   8.71035397e-01,   8.69872928e-01,
                          8.68710458e-01,   8.67489874e-01,   8.65978658e-01,
                          8.64699960e-01,   8.63421202e-01,   8.62026274e-01,
                          8.60805690e-01,   8.59294474e-01,   8.57725143e-01,
                          8.56272042e-01,   8.54644597e-01,   8.52959037e-01,
                          8.51447821e-01,   8.49762261e-01,   8.47844183e-01,
                          8.46158624e-01,   8.44414890e-01,   8.42496872e-01,
                          8.40753138e-01,   8.38776946e-01,   8.36626410e-01,
                          8.34766448e-01,   8.32674026e-01,   8.30755949e-01,
                          8.28605413e-01,   8.26396704e-01,   8.24420512e-01,
                          8.22037458e-01,   8.19828749e-01,   8.17794442e-01,
                          8.15527678e-01,   8.13260853e-01,   8.10935915e-01,
                          8.08669090e-01,   8.06344151e-01,   8.03786755e-01,
                          8.01345587e-01,   7.99020648e-01,   7.96405077e-01,
                          7.93905795e-01,   7.91406512e-01,   7.88790941e-01,
                          7.86291659e-01,   7.83792317e-01,   7.81118691e-01,
                          7.78386891e-01,   7.75713205e-01,   7.72923291e-01,
                          7.70191491e-01,   7.67285347e-01,   7.64437318e-01,
                          7.61589229e-01,   7.58566856e-01,   7.55776942e-01,
                          7.52870739e-01,   7.49790251e-01,   7.46767819e-01,
                          7.43745387e-01,   7.40664899e-01,   7.37468064e-01,
                          7.34271288e-01,   7.31074512e-01,   7.27877736e-01,
                          7.24448502e-01,   7.21019208e-01,   7.17648029e-01,
                          7.14276910e-01,   7.10847616e-01,   7.07534611e-01,
                          7.04163432e-01,   7.00676084e-01,   6.97304904e-01,
                          6.93643153e-01,   6.89923227e-01,   6.86435878e-01,
                          6.82890356e-01,   6.79112315e-01,   6.75450563e-01,
                          6.71730697e-01,   6.67894542e-01,   6.64174616e-01,
                          6.60338521e-01,   6.56560481e-01,   6.52608097e-01,
                          6.48830116e-01,   6.44877732e-01,   6.40750945e-01,
                          6.36972964e-01,   6.32962465e-01,   6.28893793e-01,
                          6.24825180e-01,   6.20582163e-01,   6.16629779e-01,
                          6.12793684e-01,   6.08550668e-01,   6.04423940e-01,
                          6.00355268e-01,   5.95937908e-01,   5.91811180e-01,
                          5.87800682e-01,   5.83441436e-01,   5.79140306e-01,
                          5.74781060e-01,   5.70421815e-01,   5.66236913e-01,
                          5.61935782e-01,   5.57518423e-01,   5.53159177e-01,
                          5.48741817e-01,   5.44208229e-01,   5.39732695e-01,
                          5.35373449e-01,   5.30781746e-01,   5.26073754e-01,
                          5.21656394e-01,   5.16948402e-01,   5.12356639e-01,
                          5.07764935e-01,   5.03115058e-01,   4.98465180e-01,
                          4.93815333e-01,   4.89223599e-01,   4.84515607e-01,
                          4.79749501e-01,   4.75157768e-01,   4.70624149e-01,
                          4.65741783e-01,   4.60917562e-01,   4.56209570e-01,
                          4.51443464e-01,   4.46735471e-01,   4.41736877e-01,
                          4.36970770e-01,   4.32204664e-01,   4.27206069e-01,
                          4.22381818e-01,   4.17557597e-01,   4.12442744e-01,
                          4.07618523e-01,   4.02678043e-01,   3.97388816e-01,
                          3.92448336e-01,   3.87449741e-01,   3.82567376e-01,
                          3.77452552e-01,   3.72279555e-01,   3.67339075e-01,
                          3.62282366e-01,   3.57225627e-01,   3.52227032e-01,
                          3.46995950e-01,   3.41764838e-01,   3.36650014e-01,
                          3.31302673e-01,   3.26245934e-01,   3.21072966e-01,
                          3.15899998e-01,   3.10785145e-01,   3.05495918e-01,
                          3.00322950e-01,   2.95033723e-01,   2.89628267e-01,
                          2.84339041e-01,   2.79166073e-01,   2.73934990e-01,
                          2.68471390e-01,   2.63007820e-01,   2.57776707e-01,
                          2.52429366e-01,   2.46849537e-01,   2.41502196e-01,
                          2.36096740e-01,   2.30633155e-01,   2.25111440e-01,
                          2.19705969e-01,   2.14184269e-01,   2.08662555e-01,
                          2.03373328e-01,   1.97619125e-01,   1.91923052e-01,
                          1.86517581e-01,   1.80879623e-01,   1.75357923e-01,
                          1.69952452e-01,   1.64256364e-01,   1.58444047e-01,
                          1.52747959e-01,   1.47110000e-01,   1.41472042e-01,
                          1.35775968e-01,   1.30079880e-01,   1.24441929e-01,
                          1.18745849e-01,   1.13049768e-01,   1.07237436e-01,
                          1.01483233e-01,   9.57290307e-02,   9.00329500e-02,
                          8.42787474e-02,   7.85826668e-02,   7.29447082e-02,
                          6.71323836e-02,   6.13781773e-02,   5.57983443e-02,
                          5.00441380e-02,   4.42318097e-02,   3.84776071e-02,
                          3.27234045e-02,   2.70273220e-02,   2.13312414e-02,
                          1.57514066e-02,   1.00553259e-02,   4.24299901e-03,
                         -1.33683532e-03,  -7.14916270e-03,  -1.29614901e-02,
                         -1.85413249e-02,  -2.42955275e-02,  -2.99916100e-02,
                         -3.57458144e-02,  -4.15000170e-02,  -4.70798500e-02,
                         -5.28340563e-02,  -5.86463846e-02,  -6.42262176e-02,
                         -6.98641762e-02,  -7.55021349e-02,  -8.12563375e-02,
                         -8.69524181e-02,  -9.25322548e-02,  -9.82864574e-02,
                         -1.04040660e-01,  -1.09620497e-01,  -1.15258448e-01,
                         -1.20954528e-01,  -1.26592487e-01,  -1.32346690e-01,
                         -1.38100892e-01,  -1.43564492e-01,  -1.49202436e-01,
                         -1.54898524e-01,  -1.60594597e-01,  -1.66290686e-01,
                         -1.71870515e-01,  -1.77508473e-01,  -1.83204561e-01,
                         -1.88726276e-01,  -1.94364220e-01,  -2.00060308e-01,
                         -2.05465779e-01,  -2.10987478e-01,  -2.16857940e-01,
                         -2.22554013e-01,  -2.27959484e-01,  -2.33423069e-01,
                         -2.39061028e-01,  -2.44524613e-01,  -2.49813825e-01,
                         -2.55393654e-01,  -2.60915369e-01,  -2.66262710e-01,
                         -2.71842539e-01,  -2.77189881e-01,  -2.82537222e-01,
                         -2.87942708e-01,  -2.93173790e-01,  -2.98695505e-01,
                         -3.03984731e-01,  -3.09157699e-01,  -3.14505041e-01,
                         -3.19619894e-01,  -3.24792862e-01,  -3.30082059e-01,
                         -3.35196912e-01,  -3.40428025e-01,  -3.45600992e-01,
                         -3.50715846e-01,  -3.55830669e-01,  -3.60771149e-01,
                         -3.65827888e-01,  -3.70942742e-01,  -3.76057565e-01,
                         -3.81056190e-01,  -3.85996670e-01,  -3.90995264e-01,
                         -3.95993859e-01,  -4.00876224e-01,  -4.05584216e-01,
                         -4.10640925e-01,  -4.15581405e-01,  -4.20347512e-01,
                         -4.25287992e-01,  -4.30054098e-01,  -4.34820205e-01,
                         -4.39702570e-01,  -4.44584906e-01,  -4.49351013e-01,
                         -4.54000890e-01,  -4.58650738e-01,  -4.63591218e-01,
                         -4.68241096e-01,  -4.72716570e-01,  -4.77424562e-01,
                         -4.81958181e-01,  -4.86608058e-01,  -4.91257906e-01,
                         -4.95791525e-01,  -5.00267029e-01,  -5.04626274e-01,
                         -5.09276092e-01,  -5.13867855e-01,  -5.18227100e-01,
                         -5.22586346e-01,  -5.26829362e-01,  -5.31188607e-01,
                         -5.35547853e-01,  -5.39616466e-01,  -5.43975711e-01,
                         -5.48044324e-01,  -5.52054822e-01,  -5.56414068e-01,
                         -5.60424626e-01,  -5.64435124e-01,  -5.68503737e-01,
                         -5.72514236e-01,  -5.76350391e-01,  -5.80186486e-01,
                         -5.84255159e-01,  -5.88265657e-01,  -5.92101812e-01,
                         -5.95763564e-01,  -5.99483430e-01,  -6.03203356e-01,
                         -6.06923223e-01,  -6.10643089e-01,  -6.14363015e-01,
                         -6.17792249e-01,  -6.21395946e-01,  -6.25057697e-01,
                         -6.28428817e-01,  -6.32090569e-01,  -6.35577977e-01,
                         -6.38774753e-01,  -6.42204046e-01,  -6.45749569e-01,
                         -6.49120688e-01,  -6.52317524e-01,  -6.55688643e-01,
                         -6.59001648e-01,  -6.62314713e-01,  -6.65511489e-01,
                         -6.68650150e-01,  -6.71905041e-01,  -6.75159931e-01,
                         -6.78240478e-01,  -6.81088507e-01,  -6.84285283e-01,
                         -6.87423944e-01,  -6.90330148e-01,  -6.93294406e-01,
                         -6.96433067e-01,  -6.99455500e-01,  -7.02303529e-01,
                         -7.05267787e-01,  -7.08057702e-01,  -7.10789502e-01,
                         -7.13521302e-01,  -7.16253102e-01,  -7.19159245e-01,
                         -7.22007275e-01,  -7.24564731e-01,  -7.27064013e-01,
                         -7.29737699e-01,  -7.32178867e-01,  -7.34620035e-01,
                         -7.37119377e-01,  -7.39618659e-01,  -7.41885483e-01,
                         -7.44326651e-01,  -7.46709704e-01,  -7.49092758e-01,
                         -7.51533926e-01,  -7.53626347e-01,  -7.55893171e-01,
                         -7.57985592e-01,  -7.60078073e-01,  -7.62228608e-01,
                         -7.64204800e-01,  -7.66355336e-01,  -7.68564045e-01,
                         -7.70540237e-01,  -7.72574544e-01,  -7.74550736e-01,
                         -7.76410699e-01,  -7.78386891e-01,  -7.80188680e-01,
                         -7.81874299e-01,  -7.83734202e-01,  -7.85594165e-01,
                         -7.87454128e-01,  -7.89139688e-01,  -7.90883362e-01,
                         -7.92510808e-01,  -7.94312656e-01,  -7.95881987e-01,
                         -7.97451317e-01,  -7.99136877e-01,  -8.00415576e-01,
                         -8.02043021e-01,  -8.03728640e-01,  -8.05239856e-01,
                         -8.06809187e-01,  -8.08436632e-01,  -8.09773445e-01,
                         -8.11168432e-01,  -8.12621474e-01,  -8.13958347e-01,
                         -8.15353274e-01,  -8.16573858e-01,  -8.17852557e-01,
                         -8.19073141e-01,  -8.20351899e-01,  -8.21688712e-01,
                         -8.22793067e-01,  -8.24013650e-01,  -8.25234234e-01,
                         -8.26280475e-01,  -8.27268541e-01,  -8.28372896e-01,
                         -8.29477251e-01,  -8.30755949e-01,  -8.31453443e-01,
                         -8.32209051e-01,  -8.33313346e-01,  -8.34068954e-01,
                         -8.34940851e-01,  -8.35696399e-01,  -8.36626410e-01,
                         -8.37382019e-01,  -8.38021338e-01,  -8.38718832e-01,
                         -8.39300096e-01,  -8.40055645e-01,  -8.40636909e-01,
                         -8.41159999e-01,  -8.41624975e-01,  -8.42322469e-01,
                         -8.42903733e-01,  -8.43426824e-01,  -8.43891799e-01,
                         -8.44124317e-01,  -8.44589293e-01,  -8.44763637e-01,
                         -8.45170498e-01,  -8.45577359e-01,  -8.45867991e-01,
                         -8.46100509e-01,  -8.46332967e-01,  -8.46391082e-01,
                         -8.46681714e-01,  -8.46972346e-01,  -8.47030461e-01,
                         -8.47495437e-01,  -8.47437322e-01,  -8.47437322e-01,
                         -8.47495437e-01,  -8.47204804e-01,  -8.47553551e-01,
                         -8.47844183e-01,  -8.47727954e-01,  -8.47669840e-01,
                         -8.47786069e-01,  -8.47553551e-01,  -8.47553551e-01,
                         -8.47611725e-01,  -8.47437322e-01,  -8.47204804e-01,
                         -8.47088575e-01,  -8.46856117e-01,  -8.46449256e-01,
                         -8.46274853e-01,  -8.45926106e-01,  -8.45577359e-01,
                         -8.45228612e-01,  -8.44879925e-01,  -8.44531178e-01,
                         -8.44066203e-01,  -8.43775570e-01,  -8.43136191e-01,
                         -8.42438698e-01,  -8.41857493e-01,  -8.41276288e-01,
                         -8.40636909e-01,  -8.39997530e-01,  -8.39300096e-01,
                         -8.38486314e-01,  -8.37672591e-01,  -8.36684525e-01,
                         -8.35928917e-01,  -8.35115194e-01,  -8.34301472e-01,
                         -8.33487749e-01,  -8.32092762e-01,  -8.31162810e-01,
                         -8.30232859e-01,  -8.29012275e-01,  -8.28024149e-01,
                         -8.26861680e-01,  -8.25582981e-01,  -8.24653029e-01,
                         -8.23490560e-01,  -8.22153687e-01,  -8.20874989e-01,
                         -8.19421887e-01,  -8.18085074e-01,  -8.16864491e-01,
                         -8.15643907e-01,  -8.14190805e-01,  -8.12795877e-01,
                         -8.11342776e-01,  -8.09657216e-01,  -8.08262229e-01,
                         -8.06692898e-01,  -8.05123568e-01,  -8.03612351e-01,
                         -8.02159309e-01,  -8.00473750e-01,  -7.98846245e-01,
                         -7.97218800e-01,  -7.95417011e-01,  -7.93847680e-01,
                         -7.92045832e-01,  -7.90244043e-01,  -7.88442194e-01,
                         -7.86698520e-01,  -7.84780443e-01,  -7.82920480e-01,
                         -7.81176805e-01,  -7.79142499e-01,  -7.77224422e-01,
                         -7.75306344e-01,  -7.73213923e-01,  -7.71005213e-01,
                         -7.68970907e-01,  -7.66994715e-01,  -7.64844179e-01,
                         -7.62577355e-01,  -7.60310531e-01,  -7.58043706e-01,
                         -7.55718827e-01,  -7.53510118e-01,  -7.51068950e-01,
                         -7.48744011e-01,  -7.46535301e-01,  -7.43861675e-01,
                         -7.41420448e-01,  -7.38863051e-01,  -7.36247480e-01,
                         -7.33806312e-01,  -7.31248915e-01,  -7.28517115e-01,
                         -7.26075947e-01,  -7.23576605e-01,  -7.20670462e-01,
                         -7.17880547e-01,  -7.15090632e-01,  -7.12358832e-01,
                         -7.09510803e-01,  -7.06779003e-01,  -7.03930974e-01,
                         -7.01024771e-01,  -6.98118627e-01,  -6.95154369e-01,
                         -6.92306280e-01,  -6.89342022e-01,  -6.86435878e-01,
                         -6.83413446e-01,  -6.80449188e-01,  -6.77368641e-01,
                         -6.74346209e-01,  -6.71381950e-01,  -6.68127000e-01,
                         -6.65104628e-01,  -6.61965966e-01,  -6.58827305e-01,
                         -6.55746758e-01,  -6.52491868e-01,  -6.49411321e-01,
                         -6.46505177e-01,  -6.43250287e-01,  -6.39762878e-01,
                         -6.36566103e-01,  -6.33369327e-01,  -6.30288780e-01,
                         -6.26975775e-01,  -6.23430252e-01,  -6.20117188e-01,
                         -6.16862297e-01,  -6.13491178e-01,  -6.09887481e-01,
                         -6.06516361e-01,  -6.03145182e-01,  -5.99599659e-01,
                         -5.96170425e-01,  -5.92508674e-01,  -5.88846862e-01,
                         -5.85475743e-01,  -5.81872106e-01,  -5.78152180e-01,
                         -5.74490428e-01,  -5.70770562e-01,  -5.67283154e-01,
                         -5.63388884e-01,  -5.59378386e-01,  -5.55832863e-01,
                         -5.51996708e-01,  -5.48160613e-01,  -5.44266343e-01,
                         -5.40372074e-01,  -5.36419690e-01,  -5.32409191e-01,
                         -5.28631151e-01,  -5.24736941e-01,  -5.20552039e-01,
                         -5.16541541e-01,  -5.12589157e-01,  -5.08462369e-01,
                         -5.04684389e-01,  -5.00557601e-01,  -4.96430874e-01,
                         -4.92362261e-01,  -4.88177359e-01,  -4.84166861e-01,
                         -4.80098248e-01,  -4.76029605e-01,  -4.71786618e-01,
                         -4.67601746e-01,  -4.63533103e-01,  -4.59290117e-01,
                         -4.55163360e-01,  -4.50978488e-01,  -4.46561098e-01,
                         -4.42376226e-01,  -4.38249469e-01,  -4.34006482e-01,
                         -4.29763496e-01,  -4.25229877e-01,  -4.21045005e-01,
                         -4.16801989e-01,  -4.12210256e-01,  -4.08025384e-01,
                         -4.03666139e-01,  -3.99190634e-01,  -3.94831389e-01,
                         -3.90472144e-01,  -3.85996670e-01,  -3.81463051e-01,
                         -3.77103806e-01,  -3.72744560e-01,  -3.68210942e-01,
                         -3.63677323e-01,  -3.59201819e-01,  -3.54668200e-01,
                         -3.50134611e-01,  -3.45484734e-01,  -3.40951115e-01,
                         -3.36243123e-01,  -3.31535161e-01,  -3.26943427e-01,
                         -3.22177291e-01,  -3.17469329e-01,  -3.12703222e-01,
                         -3.07937115e-01,  -3.03229123e-01,  -2.98404872e-01,
                         -2.93522537e-01,  -2.88814545e-01,  -2.84048438e-01,
                         -2.79107958e-01,  -2.74225593e-01,  -2.69226998e-01,
                         -2.64402777e-01,  -2.59694785e-01,  -2.54754305e-01,
                         -2.49813825e-01,  -2.44815230e-01,  -2.39932880e-01,
                         -2.35108644e-01,  -2.30110034e-01,  -2.25053310e-01,
                         -2.20112830e-01,  -2.15172365e-01,  -2.10173756e-01,
                         -2.05175161e-01,  -2.00234681e-01,  -1.95410445e-01,
                         -1.90469965e-01,  -1.85413241e-01,  -1.80530891e-01,
                         -1.75532281e-01,  -1.70533687e-01,  -1.65593207e-01,
                         -1.60478354e-01,  -1.55596003e-01,  -1.50597408e-01,
                         -1.45424426e-01,  -1.40483946e-01,  -1.35485351e-01,
                         -1.30486742e-01,  -1.25371903e-01,  -1.20198928e-01,
                         -1.15200326e-01,  -1.10201724e-01,  -1.05145000e-01,
                         -1.00146398e-01,  -9.49734300e-02,  -8.99167061e-02,
                         -8.48599821e-02,  -7.95707628e-02,  -7.45140389e-02,
                         -6.94573149e-02,  -6.42262176e-02,  -5.91694936e-02,
                         -5.39383963e-02,  -4.87654246e-02,  -4.37668264e-02,
                         -3.85938548e-02,  -3.33627574e-02,  -2.81897876e-02,
                         -2.29586922e-02,  -1.77275985e-02,  -1.26127508e-02,
                         -7.49790249e-03,  -2.26680771e-03,   3.08053358e-03,
                          8.25350452e-03,   1.34264762e-02,   1.86575707e-02,
                          2.39467882e-02,   2.91778836e-02,   3.44671011e-02,
                          3.96981947e-02,   4.49292921e-02,   5.01022600e-02,
                          5.49846180e-02,   6.03319593e-02,   6.56211749e-02,
                          7.05616549e-02,   7.59089962e-02,   8.11400861e-02,
                          8.61386880e-02,   9.14860293e-02,   9.67171267e-02,
                          1.01599485e-01,   1.06656209e-01,   1.11771055e-01,
                          1.17118396e-01,   1.22349493e-01,   1.27348095e-01,
                          1.32462934e-01,   1.37403414e-01,   1.42518267e-01,
                          1.47749364e-01,   1.52689844e-01,   1.57804683e-01,
                          1.62919536e-01,   1.67860016e-01,   1.72916740e-01,
                          1.78031594e-01,   1.83030188e-01,   1.87970668e-01,
                          1.92853019e-01,   1.97851628e-01,   2.03024596e-01,
                          2.08139449e-01,   2.13196173e-01,   2.18020394e-01,
                          2.22902760e-01,   2.27901354e-01,   2.32899964e-01,
                          2.37956688e-01,   2.43013412e-01,   2.47953892e-01,
                          2.52952486e-01,   2.57892966e-01,   2.63065934e-01,
                          2.68122673e-01,   2.72830635e-01,   2.77829260e-01,
                          2.82944083e-01,   2.87942708e-01,   2.92766929e-01,
                          2.97765523e-01,   3.02822262e-01,   3.07588369e-01,
                          3.12412590e-01,   3.17353070e-01,   3.22351664e-01,
                          3.27175915e-01,   3.31942022e-01,   3.36882502e-01,
                          3.41706723e-01,   3.46472830e-01,   3.51355195e-01,
                          3.56353790e-01,   3.61119896e-01,   3.65769774e-01,
                          3.70535880e-01,   3.75360101e-01,   3.80068094e-01,
                          3.84776056e-01,   3.89193445e-01,   3.93843293e-01,
                          3.98783773e-01,   4.03259277e-01,   4.07851011e-01,
                          4.12384629e-01,   4.16801989e-01,   4.21393722e-01,
                          4.26217973e-01,   4.30867821e-01,   4.35168952e-01,
                          4.39760685e-01,   4.44468677e-01,   4.48944151e-01,
                          4.53303397e-01,   4.57778901e-01,   4.62196261e-01,
                          4.66497391e-01,   4.70972896e-01,   4.75448370e-01,
                          4.79691386e-01,   4.83934373e-01,   4.88467991e-01,
                          4.92943496e-01,   4.97302741e-01,   5.01603842e-01,
                          5.05904973e-01,   5.10322332e-01,   5.14623463e-01,
                          5.18924594e-01,   5.23283839e-01,   5.27526855e-01,
                          5.31711698e-01,   5.36070943e-01,   5.40313959e-01,
                          5.44382572e-01,   5.48741817e-01,   5.52868605e-01,
                          5.56995332e-01,   5.61180234e-01,   5.65423191e-01,
                          5.69549978e-01,   5.73676705e-01,   5.77745318e-01,
                          5.81755817e-01,   5.85766375e-01,   5.89834988e-01,
                          5.94078004e-01,   5.98030388e-01,   6.01982772e-01,
                          6.05935097e-01,   6.09829366e-01,   6.13839865e-01,
                          6.17734134e-01,   6.21512175e-01,   6.25348270e-01,
                          6.29242539e-01,   6.32904351e-01,   6.36566103e-01,
                          6.40402198e-01,   6.44180238e-01,   6.47725761e-01,
                          6.51329398e-01,   6.55107439e-01,   6.58594787e-01,
                          6.62082195e-01,   6.65569603e-01,   6.69289470e-01,
                          6.72893107e-01,   6.76264286e-01,   6.79751694e-01,
                          6.83180928e-01,   6.86668336e-01,   6.90039515e-01,
                          6.93236291e-01,   6.96607411e-01,   7.00094819e-01,
                          7.03407884e-01,   7.06837118e-01,   7.10092008e-01,
                          7.13172555e-01,   7.16543734e-01,   7.19566107e-01,
                          7.22879171e-01,   7.26250291e-01,   7.29040205e-01,
                          7.32295096e-01,   7.35491931e-01,   7.38339961e-01,
                          7.41536736e-01,   7.44617283e-01,   7.47639656e-01,
                          7.50778317e-01,   7.53626347e-01,   7.56706893e-01,
                          7.59554923e-01,   7.62170494e-01,   7.65192866e-01,
                          7.68040955e-01,   7.70830870e-01,   7.73678899e-01,
                          7.76410699e-01,   7.79084384e-01,   7.81699896e-01,
                          7.84547925e-01,   7.87396014e-01,   7.89837182e-01,
                          7.92452693e-01,   7.94835746e-01,   7.97102571e-01,
                          7.99950600e-01,   8.02333653e-01,   8.04542363e-01,
                          8.06983531e-01,   8.09250355e-01,   8.11517119e-01,
                          8.13783944e-01,   8.16050768e-01,   8.18259418e-01,
                          8.20293784e-01,   8.22444320e-01,   8.24536741e-01,
                          8.26396704e-01,   8.28489125e-01,   8.30639720e-01,
                          8.32615912e-01,   8.34650218e-01,   8.36510122e-01,
                          8.38544488e-01,   8.40578794e-01,   8.42671216e-01,
                          8.44821751e-01,   8.46507370e-01,   8.48309159e-01,
                          8.50052893e-01,   8.51622224e-01,   8.53482127e-01,
                          8.55167747e-01,   8.56737077e-01,   8.58713269e-01,
                          8.60456944e-01,   8.61793756e-01,   8.63304973e-01,
                          8.64816189e-01,   8.66211116e-01,   8.67780447e-01,
                          8.69291663e-01,   8.70512247e-01,   8.71849120e-01,
                          8.73244047e-01,   8.74348402e-01,   8.75801504e-01,
                          8.77196431e-01,   8.78068268e-01,   8.79172623e-01,
                          8.80567610e-01,   8.81613791e-01,   8.82718146e-01,
                          8.83880615e-01,   8.84636223e-01,   8.85449946e-01,
                          8.86321783e-01,   8.87251794e-01,   8.88065517e-01,
                          8.88879240e-01,   8.89576674e-01,   8.90216053e-01,
                          8.90797317e-01,   8.91320407e-01,   8.92134130e-01,
                          8.92657220e-01,   8.93064082e-01,   8.93529058e-01,
                          8.93819690e-01,   8.94226551e-01,   8.94691527e-01,
                          8.94865930e-01,   8.95098388e-01,   8.95156562e-01,
                          8.95040274e-01,   8.95389020e-01,   8.95447135e-01,
                          8.95330906e-01,   8.95563424e-01,   8.95389020e-01,
                          8.95156562e-01,   8.94982159e-01,   8.94924045e-01,
                          8.94865930e-01,   8.94575298e-01,   8.94284666e-01,
                          8.93877804e-01,   8.93587232e-01,   8.93296599e-01,
                          8.93005967e-01,   8.92773509e-01,   8.92366588e-01,
                          8.91669154e-01,   8.91204178e-01,   8.90739143e-01,
                          8.90274167e-01,   8.89518559e-01,   8.88762951e-01,
                          8.88181746e-01,   8.87368023e-01,   8.86728644e-01,
                          8.86089325e-01,   8.85333717e-01,   8.84461880e-01,
                          8.83531868e-01,   8.82834375e-01,   8.81846309e-01,
                          8.80741954e-01,   8.79870117e-01,   8.78940165e-01,
                          8.77893925e-01,   8.76673341e-01,   8.75452757e-01,
                          8.74580920e-01,   8.73534679e-01,   8.71965349e-01,
                          8.70628536e-01,   8.69349778e-01,   8.68129194e-01,
                          8.66734266e-01,   8.65223050e-01,   8.63653719e-01,
                          8.62200618e-01,   8.60805690e-01,   8.58887613e-01,
                          8.57260168e-01,   8.55748951e-01,   8.53947163e-01,
                          8.52377832e-01,   8.50634098e-01,   8.48716021e-01,
                          8.46972346e-01,   8.45054269e-01,   8.43310595e-01,
                          8.41508746e-01,   8.39300096e-01,   8.37207615e-01,
                          8.35115194e-01,   8.32848370e-01,   8.30872178e-01,
                          8.28895986e-01,   8.26803565e-01,   8.24536741e-01,
                          8.22269976e-01,   8.20003152e-01,   8.17678213e-01,
                          8.15527678e-01,   8.13377082e-01,   8.10994029e-01,
                          8.08494747e-01,   8.05762947e-01,   8.03263664e-01,
                          8.01054955e-01,   7.98439384e-01,   7.95940101e-01,
                          7.93440819e-01,   7.90767133e-01,   7.88442194e-01,
                          7.85826683e-01,   7.83152997e-01,   7.80479312e-01,
                          7.77689397e-01,   7.74899483e-01,   7.72225797e-01,
                          7.69435883e-01,   7.66529739e-01,   7.63797939e-01,
                          7.60891795e-01,   7.57927477e-01,   7.55021334e-01,
                          7.51940787e-01,   7.48918355e-01,   7.46128440e-01,
                          7.42815435e-01,   7.39386141e-01,   7.36538112e-01,
                          7.33341336e-01,   7.29970217e-01,   7.26831555e-01,
                          7.23692894e-01,   7.20263600e-01,   7.16834307e-01,
                          7.13463187e-01,   7.09975779e-01,   7.06546485e-01,
                          7.03000963e-01,   6.99339211e-01,   6.95793688e-01,
                          6.92248166e-01,   6.88644528e-01,   6.85099006e-01,
                          6.81379139e-01,   6.77659273e-01,   6.73881233e-01,
                          6.69928849e-01,   6.66208982e-01,   6.62430942e-01,
                          6.58594787e-01,   6.54874921e-01,   6.50864422e-01,
                          6.46912038e-01,   6.43017769e-01,   6.38832927e-01,
                          6.34880543e-01,   6.31102502e-01,   6.26859486e-01,
                          6.22732759e-01,   6.18780375e-01,   6.14711761e-01,
                          6.10643089e-01,   6.06458247e-01,   6.02273345e-01,
                          5.98262846e-01,   5.93845487e-01,   5.89486241e-01,
                          5.85301340e-01,   5.81000268e-01,   5.76757252e-01,
                          5.72514236e-01,   5.67980647e-01,   5.63679516e-01,
                          5.59320271e-01,   5.55135369e-01,   5.50659895e-01,
                          5.46010017e-01,   5.41650772e-01,   5.37059069e-01,
                          5.32467306e-01,   5.28108060e-01,   5.23516297e-01,
                          5.18866479e-01,   5.14274716e-01,   5.09450495e-01,
                          5.04742503e-01,   5.00208914e-01,   4.95442778e-01,
                          4.90676671e-01,   4.85968679e-01,   4.81376946e-01,
                          4.76610839e-01,   4.71960992e-01,   4.67253000e-01,
                          4.62370634e-01,   4.57604527e-01,   4.52780306e-01,
                          4.47897941e-01,   4.43073720e-01,   4.38423842e-01,
                          4.33483362e-01,   4.28484768e-01,   4.23718661e-01,
                          4.18720067e-01,   4.13372725e-01,   4.08432245e-01,
                          4.03782368e-01,   3.98725659e-01,   3.93727064e-01,
                          3.88612211e-01,   3.83439243e-01,   3.78440619e-01,
                          3.73325795e-01,   3.68210942e-01,   3.63154203e-01,
                          3.57923120e-01,   3.52750152e-01,   3.47751558e-01,
                          3.42462331e-01,   3.37405592e-01,   3.32348883e-01,
                          3.27059656e-01,   3.21828574e-01,   3.16597462e-01,
                          3.11424494e-01,   3.06135267e-01,   3.00962299e-01,
                          2.95731217e-01,   2.90383875e-01,   2.85152793e-01,
                          2.79921681e-01,   2.74574339e-01,   2.69343257e-01,
                          2.64112145e-01,   2.58822948e-01,   2.53417462e-01,
                          2.47837633e-01,   2.42432177e-01,   2.37142950e-01,
                          2.31795609e-01,   2.26390153e-01,   2.20810309e-01,
                          2.15462968e-01,   2.10057512e-01,   2.04477683e-01,
                          1.99130341e-01,   1.93666741e-01,   1.87970668e-01,
                          1.82390839e-01,   1.76927239e-01,   1.71463653e-01,
                          1.65883824e-01,   1.60129622e-01,   1.54607907e-01,
                          1.48911834e-01,   1.43273875e-01,   1.37868404e-01,
                          1.32172316e-01,   1.26592487e-01,   1.21012658e-01,
                          1.15316577e-01,   1.09562367e-01,   1.03808165e-01,
                          9.83445793e-02,   9.28228647e-02,   8.70686620e-02,
                          8.13725814e-02,   7.57927522e-02,   7.02129155e-02,
                          6.46330789e-02,   5.89369982e-02,   5.34152873e-02,
                          4.77773324e-02,   4.19068784e-02,   3.63270454e-02,
                          3.06309648e-02,   2.51092538e-02,   1.95875429e-02,
                          1.38914622e-02,   8.36975127e-03,   2.78991717e-03,
                         -2.90616369e-03,  -8.36975127e-03,  -1.39495861e-02,
                         -1.95294190e-02,  -2.50511300e-02,  -3.08053344e-02,
                         -3.62689234e-02,  -4.17325087e-02,  -4.74285893e-02,
                         -5.29503003e-02,  -5.83557673e-02,  -6.39937222e-02,
                         -6.96316808e-02,  -7.52115175e-02,  -8.06751028e-02,
                         -8.61386880e-02,  -9.18928981e-02,  -9.72983614e-02,
                         -1.02703825e-01,  -1.08399905e-01,  -1.13921613e-01,
                         -1.19268954e-01,  -1.24906912e-01,  -1.30603001e-01,
                         -1.36066586e-01,  -1.41530171e-01,  -1.47051886e-01,
                         -1.52515471e-01,  -1.58037186e-01,  -1.63558885e-01,
                         -1.69022486e-01,  -1.74544185e-01,  -1.79949656e-01,
                         -1.85296997e-01,  -1.90934956e-01,  -1.96340412e-01,
                         -2.01571509e-01,  -2.06976980e-01,  -2.12498695e-01,
                         -2.17846036e-01,  -2.23193377e-01,  -2.28715077e-01,
                         -2.34004304e-01,  -2.39293516e-01,  -2.44524613e-01,
                         -2.49697581e-01,  -2.54986793e-01,  -2.60217905e-01,
                         -2.65448987e-01,  -2.70738214e-01,  -2.75969297e-01,
                         -2.81200409e-01,  -2.86373377e-01,  -2.91313857e-01,
                         -2.96486825e-01,  -3.01601678e-01,  -3.06484014e-01,
                         -3.11598867e-01,  -3.16713721e-01,  -3.21654201e-01,
                         -3.26536536e-01,  -3.31535161e-01,  -3.36591870e-01,
                         -3.41416121e-01,  -3.46298456e-01,  -3.51297051e-01,
                         -3.56063187e-01,  -3.60945523e-01,  -3.65886003e-01,
                         -3.70652109e-01,  -3.75418216e-01,  -3.80068094e-01,
                         -3.84776056e-01,  -3.89484048e-01,  -3.94192040e-01,
                         -3.98958147e-01,  -4.03549880e-01,  -4.08315986e-01,
                         -4.13082093e-01,  -4.17557597e-01,  -4.22323704e-01,
                         -4.26915437e-01,  -4.31390941e-01,  -4.36157048e-01,
                         -4.40806895e-01,  -4.45282400e-01,  -4.49816018e-01,
                         -4.54233378e-01,  -4.58708882e-01,  -4.63068128e-01,
                         -4.67601746e-01,  -4.72019106e-01,  -4.76029605e-01,
                         -4.80563223e-01,  -4.84980583e-01,  -4.89165455e-01,
                         -4.93582845e-01,  -4.97825831e-01,  -5.02126932e-01,
                         -5.06486177e-01,  -5.10554850e-01,  -5.14681578e-01,
                         -5.18633962e-01,  -5.22528231e-01,  -5.26887476e-01,
                         -5.30781746e-01,  -5.34734130e-01,  -5.38918972e-01,
                         -5.42755127e-01,  -5.46707511e-01,  -5.50543666e-01,
                         -5.54437876e-01,  -5.58332145e-01,  -5.61993957e-01,
                         -5.65713823e-01,  -5.69549978e-01,  -5.73153615e-01,
                         -5.76873481e-01,  -5.80477118e-01,  -5.84197044e-01,
                         -5.87742567e-01,  -5.91113687e-01,  -5.94891727e-01,
                         -5.98379076e-01,  -6.01982772e-01,  -6.05644524e-01,
                         -6.08841300e-01,  -6.12270534e-01,  -6.15816057e-01,
                         -6.19071007e-01,  -6.22384012e-01,  -6.25697017e-01,
                         -6.28951967e-01,  -6.32323086e-01,  -6.35577977e-01,
                         -6.38716638e-01,  -6.41797185e-01,  -6.45168364e-01,
                         -6.48365140e-01,  -6.51213169e-01,  -6.54409945e-01,
                         -6.57781065e-01,  -6.60919726e-01,  -6.63942158e-01,
                         -6.66906416e-01,  -6.69986963e-01,  -6.73183739e-01,
                         -6.76206172e-01,  -6.79054201e-01,  -6.81960344e-01,
                         -6.84808433e-01,  -6.87772691e-01,  -6.90678835e-01,
                         -6.93585038e-01,  -6.96433067e-01,  -6.99164867e-01,
                         -7.01838553e-01,  -7.04337835e-01,  -7.07069635e-01,
                         -7.09801435e-01,  -7.12475061e-01,  -7.14974403e-01,
                         -7.17473686e-01,  -7.20031083e-01,  -7.22588539e-01,
                         -7.25145936e-01,  -7.27470875e-01,  -7.29912043e-01,
                         -7.32353270e-01,  -7.34678149e-01,  -7.36944973e-01,
                         -7.39211798e-01,  -7.41478622e-01,  -7.43745387e-01,
                         -7.45954096e-01,  -7.48046517e-01,  -7.50255227e-01,
                         -7.52463877e-01,  -7.54614472e-01,  -7.56648779e-01,
                         -7.58624971e-01,  -7.60775506e-01,  -7.62809813e-01,
                         -7.64786005e-01,  -7.66645968e-01,  -7.68505931e-01,
                         -7.70482123e-01,  -7.72458315e-01,  -7.74201989e-01,
                         -7.76003838e-01,  -7.77980030e-01,  -7.79549360e-01,
                         -7.81351149e-01,  -7.83269227e-01,  -7.84896672e-01,
                         -7.86524117e-01,  -7.88267851e-01,  -7.89837182e-01,
                         -7.91522741e-01,  -7.93324530e-01,  -7.94777632e-01,
                         -7.96288848e-01,  -7.97974408e-01,  -7.99718142e-01,
                         -8.01229298e-01,  -8.02624285e-01,  -8.04019213e-01,
                         -8.05530429e-01,  -8.06983531e-01,  -8.08146000e-01,
                         -8.09657216e-01,  -8.11342776e-01,  -8.12621474e-01,
                         -8.13783944e-01,  -8.15120757e-01,  -8.16341400e-01,
                         -8.17445695e-01,  -8.18782568e-01,  -8.19886923e-01,
                         -8.20933104e-01,  -8.21921229e-01,  -8.23083699e-01,
                         -8.24246168e-01,  -8.25059891e-01,  -8.25931728e-01,
                         -8.27036083e-01,  -8.27907920e-01,  -8.28489125e-01,
                         -8.29535365e-01,  -8.30290973e-01,  -8.31162810e-01,
                         -8.32034647e-01,  -8.32732141e-01,  -8.33255231e-01,
                         -8.33952725e-01,  -8.34533930e-01,  -8.35057080e-01,
                         -8.35638285e-01,  -8.36219549e-01,  -8.36800754e-01,
                         -8.37265730e-01,  -8.37788880e-01,  -8.38253856e-01,
                         -8.38486314e-01,  -8.38835061e-01,  -8.39358211e-01,
                         -8.39881301e-01,  -8.39997530e-01,  -8.40288162e-01,
                         -8.40520680e-01,  -8.40578794e-01,  -8.41043770e-01,
                         -8.41218114e-01,  -8.41508746e-01,  -8.41973722e-01,
                         -8.42031837e-01,  -8.42031837e-01,  -8.42264354e-01,
                         -8.42438698e-01,  -8.42496872e-01,  -8.42496872e-01,
                         -8.42554986e-01,  -8.42554986e-01,  -8.42264354e-01,
                         -8.42554986e-01,  -8.42671216e-01,  -8.42438698e-01,
                         -8.42322469e-01,  -8.42322469e-01,  -8.42380583e-01,
                         -8.42090011e-01,  -8.41857493e-01,  -8.41683149e-01,
                         -8.41218114e-01,  -8.40927541e-01,  -8.40753138e-01,
                         -8.40230048e-01,  -8.39706957e-01,  -8.39474440e-01,
                         -8.38893235e-01,  -8.38253856e-01,  -8.37730765e-01,
                         -8.37207615e-01,  -8.36452007e-01,  -8.35870802e-01,
                         -8.35289538e-01,  -8.34301472e-01,  -8.33720207e-01,
                         -8.33022773e-01,  -8.31744015e-01,  -8.30755949e-01,
                         -8.30232859e-01,  -8.29302847e-01,  -8.28489125e-01,
                         -8.27675402e-01,  -8.26396704e-01,  -8.25350463e-01,
                         -8.24304283e-01,  -8.23374271e-01,  -8.22269976e-01,
                         -8.21107507e-01,  -8.20003152e-01,  -8.18724453e-01,
                         -8.17329466e-01,  -8.16050768e-01,  -8.14830184e-01,
                         -8.13551486e-01,  -8.12214613e-01,  -8.10819685e-01,
                         -8.09540927e-01,  -8.08087885e-01,  -8.06634784e-01,
                         -8.05356085e-01,  -8.03844869e-01,  -8.02391768e-01,
                         -8.00706208e-01,  -7.99311280e-01,  -7.97858179e-01,
                         -7.96230733e-01,  -7.94603288e-01,  -7.92975843e-01,
                         -7.91406512e-01,  -7.89662778e-01,  -7.87919104e-01,
                         -7.86291659e-01,  -7.84722328e-01,  -7.82688022e-01,
                         -7.80653656e-01,  -7.78851867e-01,  -7.77050018e-01,
                         -7.75190115e-01,  -7.73213923e-01,  -7.71121442e-01,
                         -7.68854678e-01,  -7.66878486e-01,  -7.64727890e-01,
                         -7.62635469e-01,  -7.60543048e-01,  -7.58218110e-01,
                         -7.55951285e-01,  -7.53626347e-01,  -7.51417696e-01,
                         -7.49208987e-01,  -7.46825933e-01,  -7.44442880e-01,
                         -7.41943598e-01,  -7.39444256e-01,  -7.36886859e-01,
                         -7.34387577e-01,  -7.31830120e-01,  -7.29447067e-01,
                         -7.26773381e-01,  -7.24157870e-01,  -7.21542299e-01,
                         -7.18810499e-01,  -7.16136873e-01,  -7.13405073e-01,
                         -7.10789502e-01,  -7.08115816e-01,  -7.05325902e-01,
                         -7.02652276e-01,  -6.99862361e-01,  -6.96898043e-01,
                         -6.94166243e-01,  -6.91201985e-01,  -6.87947035e-01,
                         -6.85040891e-01,  -6.82076633e-01,  -6.79170430e-01,
                         -6.76264286e-01,  -6.73358142e-01,  -6.70277596e-01,
                         -6.67371452e-01,  -6.64523363e-01,  -6.61268473e-01,
                         -6.58129811e-01,  -6.55223668e-01,  -6.51910663e-01,
                         -6.48772001e-01,  -6.45865798e-01,  -6.42610908e-01,
                         -6.39472246e-01,  -6.36333585e-01,  -6.32962465e-01,
                         -6.29998147e-01,  -6.26743257e-01,  -6.23255849e-01,
                         -6.20059073e-01,  -6.16687953e-01,  -6.13200545e-01,
                         -6.09771252e-01,  -6.06283844e-01,  -6.03028953e-01,
                         -5.99715948e-01,  -5.95996022e-01,  -5.92508674e-01,
                         -5.88904977e-01,  -5.84952652e-01,  -5.81465244e-01,
                         -5.77919722e-01,  -5.74432313e-01,  -5.70712447e-01,
                         -5.66992521e-01,  -5.63272655e-01,  -5.59320271e-01,
                         -5.55716634e-01,  -5.52229226e-01,  -5.48160613e-01,
                         -5.44208229e-01,  -5.40255845e-01,  -5.36187172e-01,
                         -5.32525420e-01,  -5.28456807e-01,  -5.24388194e-01,
                         -5.20610154e-01,  -5.16483426e-01,  -5.12356639e-01,
                         -5.08346140e-01,  -5.04509985e-01,  -5.00499487e-01,
                         -4.96430874e-01,  -4.92478490e-01,  -4.88409877e-01,
                         -4.84283119e-01,  -4.80156362e-01,  -4.75913376e-01,
                         -4.71844733e-01,  -4.67601746e-01,  -4.63416845e-01,
                         -4.59522605e-01,  -4.55221474e-01,  -4.51036602e-01,
                         -4.46909845e-01,  -4.42550600e-01,  -4.38423842e-01,
                         -4.34122741e-01,  -4.29821610e-01,  -4.25636739e-01,
                         -4.21277493e-01,  -4.16860104e-01,  -4.12559003e-01,
                         -4.08315986e-01,  -4.03724253e-01,  -3.99306893e-01,
                         -3.95122021e-01,  -3.90762776e-01,  -3.86112899e-01,
                         -3.81811798e-01,  -3.77220035e-01,  -3.72570187e-01,
                         -3.67978454e-01,  -3.63270462e-01,  -3.58794957e-01,
                         -3.54145110e-01,  -3.49379003e-01,  -3.44787270e-01,
                         -3.40079278e-01,  -3.35371286e-01,  -3.30779552e-01,
                         -3.26013446e-01,  -3.21305454e-01,  -3.16597462e-01,
                         -3.11831355e-01,  -3.07123363e-01,  -3.02357256e-01,
                         -2.97358662e-01,  -2.92534441e-01,  -2.87710190e-01,
                         -2.82885969e-01,  -2.78061748e-01,  -2.73295641e-01,
                         -2.68413275e-01,  -2.63647169e-01,  -2.58706689e-01,
                         -2.53708094e-01,  -2.48825729e-01,  -2.44001508e-01,
                         -2.39061028e-01,  -2.34120548e-01,  -2.29238197e-01,
                         -2.24355832e-01,  -2.19415352e-01,  -2.14591131e-01,
                         -2.09766895e-01,  -2.04652041e-01,  -1.99827820e-01,
                         -1.95119828e-01,  -1.89946860e-01,  -1.84948251e-01,
                         -1.80124030e-01,  -1.75125420e-01,  -1.70184940e-01,
                         -1.65244460e-01,  -1.60245866e-01,  -1.55247256e-01,
                         -1.50306791e-01,  -1.45250067e-01,  -1.40135214e-01,
                         -1.35078490e-01,  -1.30138010e-01,  -1.25197530e-01,
                         -1.20198928e-01,  -1.15084082e-01,  -1.10143602e-01,
                         -1.05203122e-01,  -1.00030154e-01,  -9.50315520e-02,
                         -8.99748281e-02,  -8.47437307e-02,  -7.95707628e-02,
                         -7.45140389e-02,  -6.93991855e-02,  -6.41099736e-02,
                         -5.89369982e-02,  -5.38802743e-02,  -4.87073027e-02,
                         -4.34180871e-02,  -3.82451154e-02,  -3.30721438e-02,
                         -2.78991722e-02,  -2.27262005e-02,  -1.73788592e-02,
                         -1.22058876e-02,  -7.09103933e-03,  -1.91806804e-03,
                          3.31302662e-03,   8.54412094e-03,   1.36589697e-02,
                          1.88900642e-02,   2.41792817e-02,   2.92360056e-02,
                          3.44671011e-02,   3.96400727e-02,   4.47549187e-02,
                          5.01022600e-02,   5.52171096e-02,   6.01575896e-02,
                          6.53886795e-02,   7.05035329e-02,   7.54440054e-02,
                          8.06751028e-02,   8.59062001e-02,   9.08466727e-02,
                          9.59615260e-02,   1.01134494e-01,   1.06133096e-01,
                          1.11306071e-01,   1.16362795e-01,   1.21303275e-01,
                          1.26359999e-01,   1.31300479e-01,   1.36357203e-01,
                          1.41472042e-01,   1.46412522e-01,   1.51469246e-01,
                          1.56525970e-01,   1.61466449e-01,   1.66406929e-01,
                          1.71579897e-01,   1.76810995e-01,   1.81635231e-01,
                          1.86575711e-01,   1.91690549e-01,   1.96631029e-01,
                          2.01745883e-01,   2.06802607e-01,   2.11684957e-01,
                          2.16799811e-01,   2.21856534e-01,   2.26855129e-01,
                          2.32086226e-01,   2.37026706e-01,   2.41909057e-01,
                          2.46965796e-01,   2.52022505e-01,   2.57137358e-01,
                          2.62194097e-01,   2.67134577e-01,   2.72249401e-01,
                          2.77189881e-01,   2.82188505e-01,   2.87187099e-01,
                          2.92069435e-01,   2.97068059e-01,   3.02124768e-01,
                          3.07007134e-01,   3.11889499e-01,   3.16888094e-01,
                          3.21828574e-01,   3.26594681e-01,   3.31418902e-01,
                          3.36359382e-01,   3.41241747e-01,   3.46124083e-01,
                          3.50948334e-01,   3.55656296e-01,   3.60364288e-01,
                          3.65072280e-01,   3.69896501e-01,   3.74720752e-01,
                          3.79370600e-01,   3.84020478e-01,   3.88670325e-01,
                          3.93436432e-01,   3.98144424e-01,   4.02619928e-01,
                          4.07269776e-01,   4.11919653e-01,   4.16627616e-01,
                          4.21277493e-01,   4.25752968e-01,   4.30344731e-01,
                          4.34994578e-01,   4.39528197e-01,   4.44061816e-01,
                          4.48537290e-01,   4.53012794e-01,   4.57662642e-01,
                          4.62080032e-01,   4.66613650e-01,   4.71147269e-01,
                          4.75564629e-01,   4.80040103e-01,   4.84515607e-01,
                          4.88991112e-01,   4.93466586e-01,   4.97825831e-01,
                          5.02185106e-01,   5.06834924e-01,   5.11252284e-01,
                          5.15553415e-01,   5.20028949e-01,   5.24271905e-01,
                          5.28573036e-01,   5.32990396e-01,   5.37349641e-01,
                          5.41708887e-01,   5.45951903e-01,   5.50136805e-01,
                          5.54612279e-01,   5.58855295e-01,   5.62749505e-01,
                          5.66992521e-01,   5.71293652e-01,   5.75362265e-01,
                          5.79372764e-01,   5.83615780e-01,   5.87684393e-01,
                          5.91694951e-01,   5.95705450e-01,   5.99599659e-01,
                          6.03552043e-01,   6.07388198e-01,   6.11398697e-01,
                          6.15351081e-01,   6.18954718e-01,   6.22732759e-01,
                          6.26568913e-01,   6.30288780e-01,   6.34183049e-01,
                          6.37786686e-01,   6.41390324e-01,   6.45342708e-01,
                          6.48772001e-01,   6.52201235e-01,   6.56095505e-01,
                          6.59699142e-01,   6.63186550e-01,   6.66557670e-01,
                          6.70045078e-01,   6.73532486e-01,   6.76961780e-01,
                          6.80449188e-01,   6.83878422e-01,   6.87133312e-01,
                          6.90504491e-01,   6.93933785e-01,   6.97130561e-01,
                          7.00501680e-01,   7.03872859e-01,   7.07011521e-01,
                          7.10266411e-01,   7.13637531e-01,   7.16776192e-01,
                          7.19914854e-01,   7.23227918e-01,   7.26424694e-01,
                          7.29563355e-01,   7.32527614e-01,   7.35550046e-01,
                          7.38572419e-01,   7.41304219e-01,   7.44326651e-01,
                          7.47523427e-01,   7.50371456e-01,   7.53161371e-01,
                          7.56125689e-01,   7.58857429e-01,   7.61647403e-01,
                          7.64611661e-01,   7.67285347e-01,   7.69900858e-01,
                          7.72516429e-01,   7.75073826e-01,   7.77515054e-01,
                          7.80188680e-01,   7.82688022e-01,   7.84954786e-01,
                          7.87454128e-01,   7.89953411e-01,   7.92220235e-01,
                          7.94545174e-01,   7.96870053e-01,   7.99020648e-01,
                          8.00938725e-01,   8.03147376e-01,   8.05414200e-01,
                          8.07332277e-01,   8.09424698e-01,   8.11517119e-01,
                          8.13318968e-01,   8.15295160e-01,   8.17155123e-01,
                          8.19073141e-01,   8.21049333e-01,   8.22967410e-01,
                          8.24885488e-01,   8.26629221e-01,   8.28605413e-01,
                          8.30639720e-01,   8.32150877e-01,   8.33894610e-01,
                          8.35928917e-01,   8.37323904e-01,   8.39009464e-01,
                          8.40869367e-01,   8.42322469e-01,   8.43891799e-01,
                          8.45577359e-01,   8.47204804e-01,   8.48774135e-01,
                          8.50285351e-01,   8.51796567e-01,   8.53307784e-01,
                          8.54586482e-01,   8.55923295e-01,   8.57260168e-01,
                          8.58422637e-01,   8.59875679e-01,   8.61212552e-01,
                          8.62258732e-01,   8.63421202e-01,   8.64699960e-01,
                          8.65746140e-01,   8.66734266e-01,   8.67664218e-01,
                          8.68652344e-01,   8.69466066e-01,   8.70221674e-01,
                          8.71151626e-01,   8.71965349e-01,   8.72720957e-01,
                          8.73476565e-01,   8.74057770e-01,   8.74522746e-01,
                          8.75220239e-01,   8.75917733e-01,   8.76382709e-01,
                          8.76789570e-01,   8.77196431e-01,   8.77545178e-01,
                          8.77835810e-01,   8.78126442e-01,   8.78475130e-01,
                          8.78649533e-01,   8.78940165e-01,   8.79114509e-01,
                          8.79172623e-01,   8.79405141e-01,   8.79405141e-01,
                          8.79347026e-01,   8.79521370e-01,   8.79347026e-01,
                          8.79114509e-01,   8.79172623e-01,   8.78940165e-01,
                          8.78881991e-01,   8.78765762e-01,   8.78475130e-01,
                          8.78242671e-01,   8.77893925e-01,   8.77603292e-01,
                          8.77428949e-01,   8.76847684e-01,   8.76382709e-01,
                          8.75975847e-01,   8.75394642e-01,   8.74871492e-01,
                          8.74464631e-01,   8.74057770e-01,   8.73534679e-01,
                          8.72837186e-01,   8.72197866e-01,   8.71442258e-01,
                          8.70860994e-01,   8.70279789e-01,   8.69291663e-01,
                          8.68245482e-01,   8.67431760e-01,   8.66676152e-01,
                          8.65746140e-01,   8.64583671e-01,   8.63595605e-01,
                          8.62839997e-01,   8.61968160e-01,   8.60689461e-01,
                          8.59352589e-01,   8.58190119e-01,   8.57027650e-01,
                          8.55865180e-01,   8.54702711e-01,   8.53017151e-01,
                          8.51564050e-01,   8.50459754e-01,   8.48716021e-01,
                          8.47204804e-01,   8.45984221e-01,   8.44240546e-01,
                          8.42613101e-01,   8.41043770e-01,   8.39241922e-01,
                          8.37730765e-01,   8.35928917e-01,   8.34185243e-01,
                          8.32615912e-01,   8.30581605e-01,   8.28779757e-01,
                          8.26919794e-01,   8.24769258e-01,   8.23141813e-01,
                          8.21049333e-01,   8.18898797e-01,   8.17096949e-01,
                          8.15004528e-01,   8.12795877e-01,   8.10587168e-01,
                          8.08494747e-01,   8.06634784e-01,   8.04426134e-01,
                          8.02043021e-01,   7.99718142e-01,   7.97567546e-01,
                          7.95300722e-01,   7.92743325e-01,   7.90534616e-01,
                          7.88209736e-01,   7.85768509e-01,   7.83443630e-01,
                          7.80886173e-01,   7.78386891e-01,   7.76003838e-01,
                          7.73330152e-01,   7.70772755e-01,   7.68273413e-01,
                          7.65425384e-01,   7.62693584e-01,   7.60019898e-01,
                          7.57404387e-01,   7.54614472e-01,   7.51766443e-01,
                          7.48860240e-01,   7.45954096e-01,   7.43164182e-01,
                          7.40316153e-01,   7.37061203e-01,   7.34096944e-01,
                          7.31190801e-01,   7.27877736e-01,   7.24739075e-01,
                          7.21600413e-01,   7.18287408e-01,   7.15264976e-01,
                          7.11951971e-01,   7.08464563e-01,   7.05151558e-01,
                          7.01606035e-01,   6.98293030e-01,   6.94979966e-01,
                          6.91434443e-01,   6.88121438e-01,   6.84459686e-01,
                          6.80797875e-01,   6.77252352e-01,   6.73590600e-01,
                          6.69986963e-01,   6.66208982e-01,   6.62372828e-01,
                          6.58827305e-01,   6.54991150e-01,   6.51271284e-01,
                          6.47609532e-01,   6.43715262e-01,   6.39879107e-01,
                          6.35868609e-01,   6.31799996e-01,   6.27963841e-01,
                          6.24069571e-01,   6.20233476e-01,   6.16339207e-01,
                          6.12096190e-01,   6.07911289e-01,   6.04075193e-01,
                          6.00006580e-01,   5.95879793e-01,   5.91985524e-01,
                          5.87684393e-01,   5.83441436e-01,   5.79314649e-01,
                          5.75071692e-01,   5.70944905e-01,   5.66701889e-01,
                          5.62400818e-01,   5.58157802e-01,   5.53624153e-01,
                          5.49264908e-01,   5.45021951e-01,   5.40546417e-01,
                          5.36012828e-01,   5.31421065e-01,   5.26829362e-01,
                          5.22412002e-01,   5.17820239e-01,   5.13228476e-01,
                          5.08520544e-01,   5.03986895e-01,   4.99511421e-01,
                          4.94803429e-01,   4.90211695e-01,   4.85736191e-01,
                          4.81086344e-01,   4.76552725e-01,   4.71844733e-01,
                          4.67136741e-01,   4.62486893e-01,   4.57778901e-01,
                          4.53070909e-01,   4.48246688e-01,   4.43364322e-01,
                          4.38598216e-01,   4.33890224e-01,   4.29066002e-01,
                          4.24183637e-01,   4.19185042e-01,   4.14186448e-01,
                          4.09304082e-01,   4.04421747e-01,   3.99713755e-01,
                          3.94889534e-01,   3.89832795e-01,   3.84834200e-01,
                          3.79951835e-01,   3.74953240e-01,   3.69954646e-01,
                          3.65014166e-01,   3.60015541e-01,   3.54958832e-01,
                          3.49960238e-01,   3.45019758e-01,   3.39904904e-01,
                          3.34790051e-01,   3.29791456e-01,   3.24676603e-01,
                          3.19736123e-01,   3.14679414e-01,   3.09332073e-01,
                          3.04391593e-01,   2.99683601e-01,   2.94336259e-01,
                          2.89163291e-01,   2.83990324e-01,   2.78584838e-01,
                          2.73470014e-01,   2.68355161e-01,   2.63240308e-01,
                          2.58009225e-01,   2.52603740e-01,   2.47314528e-01,
                          2.42025316e-01,   2.36794218e-01,   2.31795609e-01,
                          2.26390153e-01,   2.20868438e-01,   2.15579227e-01,
                          2.10348129e-01,   2.04942659e-01,   1.99537203e-01,
                          1.94073603e-01,   1.88784391e-01,   1.83495179e-01,
                          1.78147838e-01,   1.72800496e-01,   1.67395025e-01,
                          1.61931440e-01,   1.56467855e-01,   1.50946140e-01,
                          1.45598799e-01,   1.40367702e-01,   1.34845987e-01,
                          1.29266158e-01,   1.24035068e-01,   1.18629605e-01,
                          1.13224134e-01,   1.07993044e-01,   1.02587581e-01,
                          9.71821100e-02,   9.17766467e-02,   8.62549394e-02,
                          8.09075981e-02,   7.56183788e-02,   7.00966641e-02,
                          6.46912009e-02,   5.93438633e-02,   5.39965220e-02,
                          4.86491807e-02,   4.32437137e-02,   3.78963761e-02,
                          3.25490348e-02,   2.72016916e-02,   2.18543503e-02,
                          1.64488871e-02,   1.11015448e-02,   5.69608063e-03,
                          4.06862906e-04,  -4.70798509e-03,  -9.99720301e-03,
                         -1.53445443e-02,  -2.05756389e-02,  -2.59229802e-02,
                         -3.12703215e-02,  -3.65014151e-02,  -4.17906344e-02,
                         -4.70798500e-02,  -5.23109473e-02,  -5.77164106e-02,
                         -6.29475042e-02,  -6.81786016e-02,  -7.34096915e-02,
                         -7.86989108e-02,  -8.41043741e-02,  -8.94517154e-02,
                         -9.45665687e-02,  -9.97976586e-02,  -1.05086878e-01,
                         -1.10259853e-01,  -1.15549065e-01,  -1.20896406e-01,
                         -1.26127496e-01,  -1.31300479e-01,  -1.36531577e-01,
                         -1.41646415e-01,  -1.46877512e-01,  -1.52224854e-01,
                         -1.57281578e-01,  -1.62512675e-01,  -1.67918131e-01,
                         -1.72916740e-01,  -1.78089708e-01,  -1.83320805e-01,
                         -1.88319400e-01,  -1.93492383e-01,  -1.98549107e-01,
                         -2.03547701e-01,  -2.08720669e-01,  -2.13603035e-01,
                         -2.18485385e-01,  -2.23542109e-01,  -2.28540704e-01,
                         -2.33423069e-01,  -2.38421664e-01,  -2.43420273e-01,
                         -2.48244494e-01,  -2.53010601e-01,  -2.57892966e-01,
                         -2.62659073e-01,  -2.67541438e-01,  -2.72481918e-01,
                         -2.77248025e-01,  -2.81897873e-01,  -2.86547750e-01,
                         -2.91371971e-01,  -2.96079963e-01,  -3.00555438e-01,
                         -3.05379689e-01,  -3.10145795e-01,  -3.14679414e-01,
                         -3.19213003e-01,  -3.23920995e-01,  -3.28512728e-01,
                         -3.32988232e-01,  -3.37521851e-01,  -3.42171699e-01,
                         -3.46647203e-01,  -3.51180822e-01,  -3.55772555e-01,
                         -3.60189915e-01,  -3.64665419e-01,  -3.69140923e-01,
                         -3.73616397e-01,  -3.78208131e-01,  -3.82509261e-01,
                         -3.86868507e-01,  -3.91518384e-01,  -3.95761371e-01,
                         -4.00004357e-01,  -4.04537976e-01,  -4.08722848e-01,
                         -4.12907720e-01,  -4.17441338e-01,  -4.21742469e-01,
                         -4.25927341e-01,  -4.30112213e-01,  -4.34297085e-01,
                         -4.38772589e-01,  -4.42899346e-01,  -4.46909845e-01,
                         -4.51094717e-01,  -4.54988986e-01,  -4.59115744e-01,
                         -4.63358730e-01,  -4.67253000e-01,  -4.71495986e-01,
                         -4.75332141e-01,  -4.78993893e-01,  -4.83353138e-01,
                         -4.87189263e-01,  -4.90909159e-01,  -4.95035917e-01,
                         -4.98813927e-01,  -5.02591968e-01,  -5.06369948e-01,
                         -5.10206103e-01,  -5.13867855e-01,  -5.17471492e-01,
                         -5.21191418e-01,  -5.24678767e-01,  -5.28224289e-01,
                         -5.32118559e-01,  -5.35605967e-01,  -5.39151490e-01,
                         -5.42929471e-01,  -5.46358764e-01,  -5.49846172e-01,
                         -5.53449810e-01,  -5.56995332e-01,  -5.60482740e-01,
                         -5.63853860e-01,  -5.67225039e-01,  -5.70654273e-01,
                         -5.74141681e-01,  -5.77454746e-01,  -5.80825865e-01,
                         -5.84197044e-01,  -5.87451935e-01,  -5.90764940e-01,
                         -5.93961716e-01,  -5.97158492e-01,  -6.00704014e-01,
                         -6.03900790e-01,  -6.06865108e-01,  -6.10178113e-01,
                         -6.13374889e-01,  -6.16397321e-01,  -6.19594097e-01,
                         -6.22848988e-01,  -6.25929534e-01,  -6.29068196e-01,
                         -6.32090569e-01,  -6.35054886e-01,  -6.38019145e-01,
                         -6.41099691e-01,  -6.44122124e-01,  -6.46970153e-01,
                         -6.49934471e-01,  -6.52840614e-01,  -6.55630529e-01,
                         -6.58420444e-01,  -6.61036015e-01,  -6.63884044e-01,
                         -6.66906416e-01,  -6.69580102e-01,  -6.72311902e-01,
                         -6.75043702e-01,  -6.77542984e-01,  -6.80274785e-01,
                         -6.82832241e-01,  -6.85273409e-01,  -6.87888920e-01,
                         -6.90388262e-01,  -6.93003774e-01,  -6.95619345e-01,
                         -6.97886169e-01,  -7.00327337e-01,  -7.02826619e-01,
                         -7.05151558e-01,  -7.07360208e-01,  -7.09743321e-01,
                         -7.12184489e-01,  -7.14335024e-01,  -7.16543734e-01,
                         -7.18694270e-01,  -7.20786691e-01,  -7.23227918e-01,
                         -7.25320339e-01,  -7.27354646e-01,  -7.29563355e-01,
                         -7.31597662e-01,  -7.33690083e-01,  -7.35898793e-01,
                         -7.37991214e-01,  -7.40083635e-01,  -7.41769195e-01,
                         -7.43629158e-01,  -7.45779693e-01,  -7.47755885e-01,
                         -7.49790251e-01,  -7.51650155e-01,  -7.53510118e-01,
                         -7.55428195e-01,  -7.57229984e-01,  -7.58915603e-01,
                         -7.60601163e-01,  -7.62461126e-01,  -7.64321029e-01,
                         -7.66006649e-01,  -7.67634094e-01,  -7.69261539e-01,
                         -7.71121442e-01,  -7.72807062e-01,  -7.74260104e-01,
                         -7.75713205e-01,  -7.77224422e-01,  -7.78677523e-01,
                         -7.80246794e-01,  -7.81699896e-01,  -7.83094883e-01,
                         -7.84547925e-01,  -7.85884798e-01,  -7.87279725e-01,
                         -7.88732827e-01,  -7.89895296e-01,  -7.91057765e-01,
                         -7.92220235e-01,  -7.93208301e-01,  -7.94254541e-01,
                         -7.95649469e-01,  -7.96928227e-01,  -7.98032522e-01,
                         -7.98788130e-01,  -7.99834371e-01,  -8.00880611e-01,
                         -8.01926792e-01,  -8.03089261e-01,  -8.03728640e-01,
                         -8.04367959e-01,  -8.05297971e-01,  -8.05937290e-01,
                         -8.06867301e-01,  -8.07913482e-01,  -8.08436632e-01,
                         -8.09192240e-01,  -8.09889674e-01,  -8.10412824e-01,
                         -8.11168432e-01,  -8.11749637e-01,  -8.12447131e-01,
                         -8.13144624e-01,  -8.13435197e-01,  -8.14016461e-01,
                         -8.14539552e-01,  -8.14888299e-01,  -8.15585792e-01,
                         -8.15876365e-01,  -8.16283226e-01,  -8.16922605e-01,
                         -8.17213237e-01,  -8.17620099e-01,  -8.17910731e-01,
                         -8.18143189e-01,  -8.18491936e-01,  -8.18608165e-01,
                         -8.18840683e-01,  -8.19015026e-01,  -8.18956912e-01,
                         -8.19305658e-01,  -8.19480002e-01,  -8.19363773e-01,
                         -8.19363773e-01,  -8.19305658e-01,  -8.19247544e-01,
                         -8.19363773e-01,  -8.19538176e-01,  -8.19363773e-01,
                         -8.18956912e-01,  -8.18840683e-01,  -8.18666279e-01,
                         -8.18491936e-01,  -8.18201303e-01,  -8.17852557e-01,
                         -8.17561984e-01,  -8.17155123e-01,  -8.16748261e-01,
                         -8.16341400e-01,  -8.15643907e-01,  -8.15411389e-01,
                         -8.15062642e-01,  -8.14248919e-01,  -8.13725829e-01,
                         -8.13144624e-01,  -8.12330842e-01,  -8.11807752e-01,
                         -8.11168432e-01,  -8.10296535e-01,  -8.09657216e-01,
                         -8.09017837e-01,  -8.08204114e-01,  -8.07332277e-01,
                         -8.06344151e-01,  -8.05646718e-01,  -8.04891109e-01,
                         -8.03786755e-01,  -8.02973032e-01,  -8.02159309e-01,
                         -8.00996840e-01,  -8.00066829e-01,  -7.99078763e-01,
                         -7.97916293e-01,  -7.96811938e-01,  -7.95823872e-01,
                         -7.94777632e-01,  -7.93557048e-01,  -7.92278349e-01,
                         -7.91115880e-01,  -7.89895296e-01,  -7.88674712e-01,
                         -7.87454128e-01,  -7.85942912e-01,  -7.84547925e-01,
                         -7.83327341e-01,  -7.81874299e-01,  -7.80363083e-01,
                         -7.78968096e-01,  -7.77456880e-01,  -7.75945723e-01,
                         -7.74550736e-01,  -7.72923291e-01,  -7.71237731e-01,
                         -7.69493997e-01,  -7.67808437e-01,  -7.66180992e-01,
                         -7.64553547e-01,  -7.62693584e-01,  -7.60775506e-01,
                         -7.59031832e-01,  -7.57404387e-01,  -7.55311966e-01,
                         -7.53277600e-01,  -7.51475811e-01,  -7.49441504e-01,
                         -7.47349024e-01,  -7.45372832e-01,  -7.43280411e-01,
                         -7.41187990e-01,  -7.39037395e-01,  -7.36712515e-01,
                         -7.34561920e-01,  -7.32353270e-01,  -7.30144560e-01,
                         -7.27877736e-01,  -7.25494683e-01,  -7.23053515e-01,
                         -7.20670462e-01,  -7.18403637e-01,  -7.16020584e-01,
                         -7.13521302e-01,  -7.11138248e-01,  -7.08580852e-01,
                         -7.06139624e-01,  -7.03756571e-01,  -7.01257288e-01,
                         -6.98874235e-01,  -6.96316838e-01,  -6.93468750e-01,
                         -6.90853238e-01,  -6.88295782e-01,  -6.85622156e-01,
                         -6.83006585e-01,  -6.80332899e-01,  -6.77659273e-01,
                         -6.74927473e-01,  -6.72079384e-01,  -6.69289470e-01,
                         -6.66615844e-01,  -6.63767755e-01,  -6.60803497e-01,
                         -6.58013582e-01,  -6.55223668e-01,  -6.52491868e-01,
                         -6.49585724e-01,  -6.46505177e-01,  -6.43424630e-01,
                         -6.40402198e-01,  -6.37554169e-01,  -6.34415507e-01,
                         -6.31335020e-01,  -6.28486931e-01,  -6.25173926e-01,
                         -6.21860921e-01,  -6.18896604e-01,  -6.15641713e-01,
                         -6.12444937e-01,  -6.09190047e-01,  -6.05818868e-01,
                         -6.02563977e-01,  -5.99192798e-01,  -5.95879793e-01,
                         -5.92276156e-01,  -5.88672519e-01,  -5.85533857e-01,
                         -5.82046449e-01,  -5.78617215e-01,  -5.75246036e-01,
                         -5.71526170e-01,  -5.68038762e-01,  -5.64435124e-01,
                         -5.60715199e-01,  -5.57169676e-01,  -5.53449810e-01,
                         -5.49729943e-01,  -5.46068132e-01,  -5.42232037e-01,
                         -5.38686514e-01,  -5.35024703e-01,  -5.31130493e-01,
                         -5.27410567e-01,  -5.23690701e-01,  -5.19796431e-01,
                         -5.16018450e-01,  -5.12182295e-01,  -5.08288026e-01,
                         -5.04451871e-01,  -5.00499487e-01,  -4.96605247e-01,
                         -4.92769122e-01,  -4.88700479e-01,  -4.84748095e-01,
                         -4.80911970e-01,  -4.76785213e-01,  -4.72774714e-01,
                         -4.68880445e-01,  -4.64753687e-01,  -4.60568815e-01,
                         -4.56558317e-01,  -4.52373445e-01,  -4.48246688e-01,
                         -4.44294304e-01,  -4.40225661e-01,  -4.35982674e-01,
                         -4.31739688e-01,  -4.27380443e-01,  -4.23253685e-01,
                         -4.19126928e-01,  -4.14651424e-01,  -4.10408437e-01,
                         -4.06165421e-01,  -4.01806176e-01,  -3.97505075e-01,
                         -3.93087685e-01,  -3.88844699e-01,  -3.84659827e-01,
                         -3.80009949e-01,  -3.75476360e-01,  -3.71117115e-01,
                         -3.66583496e-01,  -3.62166107e-01,  -3.57574373e-01,
                         -3.52924526e-01,  -3.48565280e-01,  -3.44089776e-01,
                         -3.39498043e-01,  -3.34848166e-01,  -3.30256432e-01,
                         -3.25664699e-01,  -3.21072966e-01,  -3.16423088e-01,
                         -3.11773241e-01,  -3.07065248e-01,  -3.02241027e-01,
                         -2.97591150e-01,  -2.92999417e-01,  -2.88233310e-01,
                         -2.83641577e-01,  -2.79049844e-01,  -2.74167478e-01,
                         -2.69401371e-01,  -2.64751524e-01,  -2.59869158e-01,
                         -2.55044937e-01,  -2.50395060e-01,  -2.45570824e-01,
                         -2.40920961e-01,  -2.36212984e-01,  -2.31388748e-01,
                         -2.26506397e-01,  -2.21740291e-01,  -2.17032298e-01,
                         -2.12208077e-01,  -2.07383841e-01,  -2.02559605e-01,
                         -1.97735369e-01,  -1.92853019e-01,  -1.87970668e-01,
                         -1.83204561e-01,  -1.78380325e-01,  -1.73323601e-01,
                         -1.68383121e-01,  -1.63500771e-01,  -1.58560291e-01,
                         -1.53561682e-01,  -1.48737460e-01,  -1.43855095e-01,
                         -1.38914630e-01,  -1.34032264e-01,  -1.28975540e-01,
                         -1.23918816e-01,  -1.19036466e-01,  -1.14095986e-01,
                         -1.08981140e-01,  -1.04040660e-01,  -9.90420580e-02,
                         -9.39272121e-02,  -8.89867321e-02,  -8.40462521e-02,
                         -7.91057721e-02,  -7.41652995e-02,  -6.89342022e-02,
                         -6.38774782e-02,  -5.89951240e-02,  -5.38221523e-02,
                         -4.88235503e-02,  -4.38830703e-02,  -3.87682244e-02,
                         -3.37114967e-02,  -2.86547747e-02,  -2.36561727e-02,
                         -1.85994469e-02,  -1.34845991e-02,  -8.60224478e-03,
                         -3.66176618e-03,   1.51120510e-03,   6.50980650e-03,
                          1.15084080e-02,   1.65651329e-02,   2.16799807e-02,
                          2.66785827e-02,   3.17353085e-02,   3.68501544e-02,
                          4.16743867e-02,   4.66729887e-02,   5.17297126e-02,
                          5.67283146e-02,   6.17850386e-02,   6.66673928e-02,
                          7.16078728e-02,   7.67227188e-02,   8.17794427e-02,
                          8.68361741e-02,   9.18928981e-02,   9.67752486e-02,
                          1.01715729e-01,   1.06656209e-01,   1.11654811e-01,
                          1.16653413e-01,   1.21593885e-01,   1.26534373e-01,
                          1.31591097e-01,   1.36415318e-01,   1.41297683e-01,
                          1.46354407e-01,   1.51353002e-01,   1.56293482e-01,
                          1.61175832e-01,   1.66174442e-01,   1.71347409e-01,
                          1.76229760e-01,   1.81112126e-01,   1.86052606e-01,
                          1.90876827e-01,   1.95875436e-01,   2.00932160e-01,
                          2.05698267e-01,   2.10580617e-01,   2.15579227e-01,
                          2.20577821e-01,   2.25460172e-01,   2.30400652e-01,
                          2.35224888e-01,   2.40049124e-01,   2.45222092e-01,
                          2.49988198e-01,   2.54754305e-01,   2.59752899e-01,
                          2.64402777e-01,   2.69343257e-01,   2.74399966e-01,
                          2.79166073e-01,   2.83932179e-01,   2.88988918e-01,
                          2.93987513e-01,   2.98579246e-01,   3.03287238e-01,
                          3.08053344e-01,   3.12877595e-01,   3.17643702e-01,
                          3.22293550e-01,   3.27175915e-01,   3.31942022e-01,
                          3.36533755e-01,   3.41416121e-01,   3.46182227e-01,
                          3.50715846e-01,   3.55365694e-01,   3.60015541e-01,
                          3.64839792e-01,   3.69431525e-01,   3.73907030e-01,
                          3.78498763e-01,   3.83148611e-01,   3.87682229e-01,
                          3.92157733e-01,   3.96749467e-01,   4.01283085e-01,
                          4.05874819e-01,   4.10408437e-01,   4.14942056e-01,
                          4.19359416e-01,   4.23893034e-01,   4.28484768e-01,
                          4.32785898e-01,   4.37145144e-01,   4.41736877e-01,
                          4.46154237e-01,   4.50571626e-01,   4.54930872e-01,
                          4.59290117e-01,   4.63939965e-01,   4.68299210e-01,
                          4.72542226e-01,   4.77075815e-01,   4.81144458e-01,
                          4.85445589e-01,   4.89921063e-01,   4.94105935e-01,
                          4.98465180e-01,   5.02824426e-01,   5.06951213e-01,
                          5.11194170e-01,   5.15379071e-01,   5.19331455e-01,
                          5.23400068e-01,   5.27759314e-01,   5.31769812e-01,
                          5.35896599e-01,   5.39965212e-01,   5.43859482e-01,
                          5.47928095e-01,   5.51938593e-01,   5.55774748e-01,
                          5.59843361e-01,   5.63911974e-01,   5.67864358e-01,
                          5.71700513e-01,   5.75536668e-01,   5.79605281e-01,
                          5.83383322e-01,   5.87161303e-01,   5.90881169e-01,
                          5.94601095e-01,   5.98379076e-01,   6.01982772e-01,
                          6.05586410e-01,   6.09131932e-01,   6.12735569e-01,
                          6.16455436e-01,   6.20117188e-01,   6.23662710e-01,
                          6.27150118e-01,   6.30637527e-01,   6.34124935e-01,
                          6.37496054e-01,   6.40867233e-01,   6.44354582e-01,
                          6.47783875e-01,   6.51213169e-01,   6.54526174e-01,
                          6.57781065e-01,   6.61094129e-01,   6.64174616e-01,
                          6.67429566e-01,   6.70800686e-01,   6.73765004e-01,
                          6.77078009e-01,   6.80449188e-01,   6.83297217e-01,
                          6.86319590e-01,   6.89342022e-01,   6.92364454e-01,
                          6.95561230e-01,   6.98699892e-01,   7.01780379e-01,
                          7.04395950e-01,   7.07127750e-01,   7.10266411e-01,
                          7.12998211e-01,   7.15904355e-01,   7.18694270e-01,
                          7.21367955e-01,   7.24099755e-01,   7.26773381e-01,
                          7.29505181e-01,   7.32178867e-01,   7.34736323e-01,
                          7.37468064e-01,   7.39909291e-01,   7.42292345e-01,
                          7.45140374e-01,   7.47581542e-01,   7.49906480e-01,
                          7.52463877e-01,   7.54730701e-01,   7.56997526e-01,
                          7.59322464e-01,   7.61647403e-01,   7.63856053e-01,
                          7.66006649e-01,   7.68215299e-01,   7.70365894e-01,
                          7.72400200e-01,   7.74492621e-01,   7.76468813e-01,
                          7.78386891e-01,   7.80479312e-01,   7.82281160e-01,
                          7.84141064e-01,   7.86117256e-01,   7.88035333e-01,
                          7.89895296e-01,   7.91580856e-01,   7.93440819e-01,
                          7.95068264e-01,   7.96521366e-01,   7.98265040e-01,
                          8.00008714e-01,   8.01403701e-01,   8.03031147e-01,
                          8.04716706e-01,   8.06111693e-01,   8.07564735e-01,
                          8.09250355e-01,   8.10877800e-01,   8.12389016e-01,
                          8.13958347e-01,   8.15295160e-01,   8.16631973e-01,
                          8.18026960e-01,   8.19305658e-01,   8.20758760e-01,
                          8.22037458e-01,   8.23258042e-01,   8.24420512e-01,
                          8.25524867e-01,   8.26803565e-01,   8.28024149e-01,
                          8.28895986e-01,   8.29942226e-01,   8.31104696e-01,
                          8.32034647e-01,   8.33022773e-01,   8.33778381e-01,
                          8.34708333e-01,   8.35638285e-01,   8.36277664e-01,
                          8.37091386e-01,   8.37905109e-01,   8.38602602e-01,
                          8.39183807e-01,   8.39765072e-01,   8.40462506e-01,
                          8.40811253e-01,   8.41159999e-01,   8.41973722e-01,
                          8.42554986e-01,   8.42787445e-01,   8.43252480e-01,
                          8.43426824e-01,   8.43833685e-01,   8.44066203e-01,
                          8.44008029e-01,   8.44356775e-01,   8.44414890e-01,
                          8.44356775e-01,   8.44531178e-01,   8.44531178e-01,
                          8.44647408e-01,   8.44821751e-01,   8.44531178e-01,
                          8.44414890e-01,   8.44356775e-01,   8.44066203e-01,
                          8.43891799e-01,   8.43659341e-01,   8.43543053e-01,
                          8.43194306e-01,   8.42787445e-01,   8.42380583e-01,
                          8.41857493e-01,   8.41450632e-01,   8.41043770e-01,
                          8.40636909e-01,   8.40113819e-01,   8.39532554e-01,
                          8.39009464e-01,   8.38544488e-01,   8.37846994e-01,
                          8.37149501e-01,   8.36452007e-01,   8.35580170e-01,
                          8.34882677e-01,   8.34068954e-01,   8.33429635e-01,
                          8.32790256e-01,   8.31569672e-01,   8.30465317e-01,
                          8.29825997e-01,   8.28954101e-01,   8.27791631e-01,
                          8.26629221e-01,   8.25524867e-01,   8.24653029e-01,
                          8.23548675e-01,   8.22328091e-01,   8.21107507e-01,
                          8.19828749e-01,   8.18550050e-01,   8.17155123e-01,
                          8.15992653e-01,   8.14597666e-01,   8.12912107e-01,
                          8.11691523e-01,   8.10180306e-01,   8.08494747e-01,
                          8.07041645e-01,   8.05414200e-01,   8.04019213e-01,
                          8.02566171e-01,   8.00589979e-01,   7.98846245e-01,
                          7.96986341e-01,   7.95184493e-01,   7.93557048e-01,
                          7.91522741e-01,   7.89662778e-01,   7.87860990e-01,
                          7.85826683e-01,   7.83792317e-01,   7.81699896e-01,
                          7.79839933e-01,   7.78038144e-01,   7.75829434e-01,
                          7.73678899e-01,   7.71528304e-01,   7.69261539e-01,
                          7.67401576e-01,   7.64960408e-01,   7.62577355e-01,
                          7.60543048e-01,   7.58043706e-01,   7.55660653e-01,
                          7.53510118e-01,   7.51127064e-01,   7.48744011e-01,
                          7.46302843e-01,   7.43629158e-01,   7.41071761e-01,
                          7.38688707e-01,   7.36073136e-01,   7.33341336e-01,
                          7.30958283e-01,   7.28459001e-01,   7.25610971e-01,
                          7.22879171e-01,   7.20031083e-01,   7.17241168e-01,
                          7.14625657e-01,   7.11603224e-01,   7.08813310e-01,
                          7.05965281e-01,   7.02884734e-01,   6.99978590e-01,
                          6.97072446e-01,   6.94050014e-01,   6.91201985e-01,
                          6.88179553e-01,   6.84924662e-01,   6.81902230e-01,
                          6.78821683e-01,   6.75566792e-01,   6.72311902e-01,
                          6.68998897e-01,   6.65627718e-01,   6.62430942e-01,
                          6.59117937e-01,   6.55688643e-01,   6.52259350e-01,
                          6.48830116e-01,   6.45342708e-01,   6.41739070e-01,
                          6.38367891e-01,   6.34822369e-01,   6.31218731e-01,
                          6.27615094e-01,   6.23895228e-01,   6.20349705e-01,
                          6.16571665e-01,   6.12851799e-01,   6.09073758e-01,
                          6.05295777e-01,   6.01750255e-01,   5.97972214e-01,
                          5.93961716e-01,   5.90067446e-01,   5.86231351e-01,
                          5.82395196e-01,   5.78500926e-01,   5.74316084e-01,
                          5.70305586e-01,   5.66469431e-01,   5.62400818e-01,
                          5.58448434e-01,   5.54612279e-01,   5.50427377e-01,
                          5.46300650e-01,   5.42464495e-01,   5.38221538e-01,
                          5.33978522e-01,   5.29909909e-01,   5.25783122e-01,
                          5.21714509e-01,   5.17529607e-01,   5.13460994e-01,
                          5.09392381e-01,   5.05149364e-01,   5.01022637e-01,
                          4.96953994e-01,   4.92827237e-01,   4.88700479e-01,
                          4.84457493e-01,   4.80214477e-01,   4.75797117e-01,
                          4.71321613e-01,   4.67136741e-01,   4.62777495e-01,
                          4.58476394e-01,   4.54175264e-01,   4.49699759e-01,
                          4.45340514e-01,   4.40923154e-01,   4.36447650e-01,
                          4.32030290e-01,   4.27612931e-01,   4.23021197e-01,
                          4.18487579e-01,   4.14012074e-01,   4.09304082e-01,
                          4.04770464e-01,   4.00294989e-01,   3.95586997e-01,
                          3.90820891e-01,   3.86345387e-01,   3.81811798e-01,
                          3.77220035e-01,   3.72628301e-01,   3.67862195e-01,
                          3.63096088e-01,   3.58388096e-01,   3.53680104e-01,
                          3.48972142e-01,   3.44322264e-01,   3.39556158e-01,
                          3.34731936e-01,   3.29965830e-01,   3.25199723e-01,
                          3.20375472e-01,   3.15609366e-01,   3.10959518e-01,
                          3.05902779e-01,   3.01078558e-01,   2.96544939e-01,
                          2.91662574e-01,   2.86722094e-01,   2.82072246e-01,
                          2.77131766e-01,   2.72133172e-01,   2.67308921e-01,
                          2.62368470e-01,   2.57427990e-01,   2.52545625e-01,
                          2.47721389e-01,   2.42839038e-01,   2.37840429e-01,
                          2.33016208e-01,   2.28191972e-01,   2.23251492e-01,
                          2.18369141e-01,   2.13428661e-01,   2.08488181e-01,
                          2.03431457e-01,   1.98432863e-01,   1.93434253e-01,
                          1.88551903e-01,   1.83669537e-01,   1.78729072e-01,
                          1.73730463e-01,   1.68557495e-01,   1.63558885e-01,
                          1.58734664e-01,   1.53677940e-01,   1.48504958e-01,
                          1.43448234e-01,   1.38507754e-01,   1.33509159e-01,
                          1.28452435e-01,   1.23570077e-01,   1.18338987e-01,
                          1.13107890e-01,   1.08225532e-01,   1.03168808e-01,
                          9.80539620e-02,   9.29972380e-02,   8.79405141e-02,
                          8.28837901e-02,   7.78270662e-02,   7.27122128e-02,
                          6.76554888e-02,   6.26568869e-02,   5.76582886e-02,
                          5.24853170e-02,   4.74285893e-02,   4.25462350e-02,
                          3.75476331e-02,   3.26652788e-02,   2.77248006e-02,
                          2.25518309e-02,   1.74951050e-02,   1.26127508e-02,
                          7.61414878e-03,   2.61554727e-03,  -2.26680771e-03,
                         -7.26540899e-03,  -1.23221343e-02,  -1.72626115e-02,
                         -2.20868438e-02,  -2.69110762e-02,  -3.18515524e-02,
                         -3.67339104e-02,  -4.16162647e-02,  -4.64404970e-02,
                         -5.13228513e-02,  -5.62633276e-02,  -6.12038076e-02,
                         -6.59699142e-02,  -7.09103942e-02,  -7.59089962e-02,
                         -8.07332247e-02,  -8.56155828e-02,  -9.04979333e-02,
                         -9.53802913e-02,  -1.00146398e-01,  -1.05145000e-01,
                         -1.09969236e-01,  -1.14619099e-01,  -1.19559571e-01,
                         -1.24441929e-01,  -1.29208043e-01,  -1.34032264e-01,
                         -1.38624012e-01,  -1.43506363e-01,  -1.48563087e-01,
                         -1.53154820e-01,  -1.57862812e-01,  -1.62687048e-01,
                         -1.67511269e-01,  -1.72277376e-01,  -1.76694751e-01,
                         -1.81402743e-01,  -1.86226964e-01,  -1.90760583e-01,
                         -1.95410445e-01,  -2.00176552e-01,  -2.04710171e-01,
                         -2.09360033e-01,  -2.14068010e-01,  -2.18659759e-01,
                         -2.23309621e-01,  -2.27901354e-01,  -2.32376844e-01,
                         -2.36910462e-01,  -2.41385952e-01,  -2.46035814e-01,
                         -2.50453174e-01,  -2.54928678e-01,  -2.59462297e-01,
                         -2.63763428e-01,  -2.68064529e-01,  -2.72598147e-01,
                         -2.76957393e-01,  -2.81374753e-01,  -2.85733998e-01,
                         -2.90035129e-01,  -2.94394374e-01,  -2.98637390e-01,
                         -3.02822262e-01,  -3.06949019e-01,  -3.11308265e-01,
                         -3.15551251e-01,  -3.19678009e-01,  -3.23920995e-01,
                         -3.28164011e-01,  -3.32465112e-01,  -3.36533755e-01,
                         -3.40544254e-01,  -3.44612896e-01,  -3.48855883e-01,
                         -3.53040755e-01,  -3.57051283e-01,  -3.61119896e-01,
                         -3.65130395e-01,  -3.69140923e-01,  -3.73209536e-01,
                         -3.77336293e-01,  -3.81404907e-01,  -3.85182947e-01,
                         -3.89077187e-01,  -3.93203944e-01,  -3.97098213e-01,
                         -4.00934339e-01,  -4.04886723e-01,  -4.08780992e-01,
                         -4.12791491e-01,  -4.16569501e-01,  -4.20405626e-01,
                         -4.24241781e-01,  -4.28019792e-01,  -4.31914032e-01,
                         -4.35633928e-01,  -4.39470083e-01,  -4.43189949e-01,
                         -4.46793616e-01,  -4.50571626e-01,  -4.54233378e-01,
                         -4.57953274e-01,  -4.61615026e-01,  -4.65102434e-01,
                         -4.68764186e-01,  -4.72367853e-01,  -4.75855231e-01,
                         -4.79575127e-01,  -4.82888162e-01,  -4.86317426e-01,
                         -4.89804834e-01,  -4.93175983e-01,  -4.96663362e-01,
                         -4.99976397e-01,  -5.03463805e-01,  -5.06893039e-01,
                         -5.10147989e-01,  -5.13519108e-01,  -5.16832173e-01,
                         -5.20087063e-01,  -5.23283839e-01,  -5.26596844e-01,
                         -5.29793620e-01,  -5.33048570e-01,  -5.36303461e-01,
                         -5.39442122e-01,  -5.42580783e-01,  -5.45777559e-01,
                         -5.48974335e-01,  -5.51938593e-01,  -5.55019140e-01,
                         -5.58215916e-01,  -5.61296463e-01,  -5.64144492e-01,
                         -5.67283154e-01,  -5.70363700e-01,  -5.73386073e-01,
                         -5.76524734e-01,  -5.79198420e-01,  -5.82046449e-01,
                         -5.85126996e-01,  -5.87916911e-01,  -5.90939343e-01,
                         -5.93961716e-01,  -5.96751630e-01,  -5.99715948e-01,
                         -6.02563977e-01,  -6.05353892e-01,  -6.08318150e-01,
                         -6.10991836e-01,  -6.13665521e-01,  -6.16455436e-01,
                         -6.19129121e-01,  -6.21802807e-01,  -6.24476433e-01,
                         -6.27208233e-01,  -6.30056262e-01,  -6.32729948e-01,
                         -6.35113001e-01,  -6.37786686e-01,  -6.40169740e-01,
                         -6.42727137e-01,  -6.45400822e-01,  -6.47725761e-01,
                         -6.50283158e-01,  -6.52608097e-01,  -6.54874921e-01,
                         -6.57490492e-01,  -6.59873545e-01,  -6.62082195e-01,
                         -6.64407134e-01,  -6.66673958e-01,  -6.68940783e-01,
                         -6.71265662e-01,  -6.73416257e-01,  -6.75741196e-01,
                         -6.77891731e-01,  -6.80100441e-01,  -6.82076633e-01,
                         -6.84110940e-01,  -6.86377764e-01,  -6.88237667e-01,
                         -6.90213859e-01,  -6.92248166e-01,  -6.94224358e-01,
                         -6.96200550e-01,  -6.98234856e-01,  -7.00152934e-01,
                         -7.02071011e-01,  -7.03930974e-01,  -7.05790937e-01,
                         -7.07650840e-01,  -7.09336400e-01,  -7.11254478e-01,
                         -7.13114440e-01,  -7.14741886e-01,  -7.16601849e-01,
                         -7.18403637e-01,  -7.20205486e-01,  -7.21891046e-01,
                         -7.23518491e-01,  -7.25320339e-01,  -7.27005899e-01,
                         -7.28517115e-01,  -7.30260789e-01,  -7.31772006e-01,
                         -7.33283222e-01,  -7.34968781e-01,  -7.36421883e-01,
                         -7.37816811e-01,  -7.39153683e-01,  -7.40664899e-01,
                         -7.42176056e-01,  -7.43396640e-01,  -7.44733512e-01,
                         -7.46186554e-01,  -7.47697771e-01,  -7.48744011e-01,
                         -7.49906480e-01,  -7.51359582e-01,  -7.52463877e-01,
                         -7.53568232e-01,  -7.54905105e-01,  -7.55893171e-01,
                         -7.56823123e-01,  -7.58043706e-01,  -7.58915603e-01,
                         -7.59961784e-01,  -7.61066139e-01,  -7.61821747e-01,
                         -7.62751698e-01,  -7.63681710e-01,  -7.64379144e-01,
                         -7.65251040e-01,  -7.66064763e-01,  -7.66704082e-01,
                         -7.67575920e-01,  -7.68157184e-01,  -7.69029021e-01,
                         -7.69726515e-01,  -7.70075262e-01,  -7.70830870e-01,
                         -7.71470189e-01,  -7.72167683e-01,  -7.72807062e-01,
                         -7.73272038e-01,  -7.73853242e-01,  -7.74201989e-01,
                         -7.74666965e-01,  -7.75248230e-01,  -7.75480688e-01,
                         -7.75713205e-01,  -7.76120067e-01,  -7.76352584e-01,
                         -7.76817560e-01,  -7.77108192e-01,  -7.77340651e-01,
                         -7.77631283e-01,  -7.77921915e-01,  -7.78270602e-01,
                         -7.78328776e-01,  -7.78503120e-01,  -7.78503120e-01,
                         -7.78677523e-01,  -7.79026210e-01,  -7.78909981e-01,
                         -7.78793752e-01,  -7.78909981e-01,  -7.78968096e-01,
                         -7.78851867e-01,  -7.78851867e-01,  -7.78735638e-01,
                         -7.78503120e-01,  -7.78270602e-01,  -7.78154373e-01,
                         -7.78038144e-01,  -7.77515054e-01,  -7.77340651e-01,
                         -7.76991904e-01,  -7.76410699e-01,  -7.76061952e-01,
                         -7.75713205e-01,  -7.75248230e-01,  -7.75015712e-01,
                         -7.74608850e-01,  -7.73969531e-01,  -7.73504496e-01,
                         -7.72807062e-01,  -7.72283912e-01,  -7.71702707e-01,
                         -7.70888984e-01,  -7.70249605e-01,  -7.69435883e-01,
                         -7.68564045e-01,  -7.67750323e-01,  -7.67110944e-01,
                         -7.66239107e-01,  -7.65251040e-01,  -7.64321029e-01,
                         -7.63565421e-01,  -7.62402952e-01,  -7.61414886e-01,
                         -7.60717392e-01,  -7.59496808e-01,  -7.58450568e-01,
                         -7.57288158e-01,  -7.56300032e-01,  -7.55311966e-01,
                         -7.54033208e-01,  -7.52870739e-01,  -7.51708269e-01,
                         -7.50487685e-01,  -7.49092758e-01,  -7.47930288e-01,
                         -7.46767819e-01,  -7.45489120e-01,  -7.44268537e-01,
                         -7.42989779e-01,  -7.41478622e-01,  -7.40141749e-01,
                         -7.38804936e-01,  -7.37177491e-01,  -7.35840619e-01,
                         -7.34329462e-01,  -7.32760131e-01,  -7.31248915e-01,
                         -7.29737699e-01,  -7.28226483e-01,  -7.26540923e-01,
                         -7.24913478e-01,  -7.23111629e-01,  -7.21193552e-01,
                         -7.19740510e-01,  -7.18171179e-01,  -7.16136873e-01,
                         -7.14335024e-01,  -7.12475061e-01,  -7.10498869e-01,
                         -7.08638966e-01,  -7.06546485e-01,  -7.04628468e-01,
                         -7.02710390e-01,  -7.00501680e-01,  -6.98467374e-01,
                         -6.96374953e-01,  -6.94282472e-01,  -6.92073822e-01,
                         -6.89923227e-01,  -6.87772691e-01,  -6.85622156e-01,
                         -6.83413446e-01,  -6.81262910e-01,  -6.78879857e-01,
                         -6.76554918e-01,  -6.74113750e-01,  -6.71556294e-01,
                         -6.69347644e-01,  -6.66790187e-01,  -6.64290905e-01,
                         -6.62024081e-01,  -6.59292281e-01,  -6.56618595e-01,
                         -6.54468060e-01,  -6.52143121e-01,  -6.49411321e-01,
                         -6.46737635e-01,  -6.44122124e-01,  -6.41390324e-01,
                         -6.38716638e-01,  -6.36217356e-01,  -6.33543670e-01,
                         -6.30811870e-01,  -6.28080070e-01,  -6.25173926e-01,
                         -6.22442126e-01,  -6.19594097e-01,  -6.16629779e-01,
                         -6.13898039e-01,  -6.11049950e-01,  -6.08143806e-01,
                         -6.05005145e-01,  -6.01982772e-01,  -5.99425316e-01,
                         -5.96402884e-01,  -5.93206108e-01,  -5.90416193e-01,
                         -5.87161303e-01,  -5.84080756e-01,  -5.81290841e-01,
                         -5.77977836e-01,  -5.74839175e-01,  -5.71642399e-01,
                         -5.68387508e-01,  -5.65074444e-01,  -5.61587095e-01,
                         -5.58448434e-01,  -5.55251658e-01,  -5.51764250e-01,
                         -5.48451185e-01,  -5.44963837e-01,  -5.41418314e-01,
                         -5.38163364e-01,  -5.34792244e-01,  -5.31130493e-01,
                         -5.27584970e-01,  -5.24097562e-01,  -5.20435810e-01,
                         -5.16890287e-01,  -5.13635337e-01,  -5.09973586e-01,
                         -5.06137490e-01,  -5.02417564e-01,  -4.98755813e-01,
                         -4.95035917e-01,  -4.91257906e-01,  -4.87596154e-01,
                         -4.83934373e-01,  -4.80214477e-01,  -4.76494581e-01,
                         -4.72542226e-01,  -4.68647957e-01,  -4.64869946e-01,
                         -4.61150050e-01,  -4.57313925e-01,  -4.53477770e-01,
                         -4.49583530e-01,  -4.45573002e-01,  -4.41504389e-01,
                         -4.37668234e-01,  -4.33715880e-01,  -4.29937840e-01,
                         -4.26101714e-01,  -4.21916842e-01,  -4.18022573e-01,
                         -4.14012074e-01,  -4.09885317e-01,  -4.05991077e-01,
                         -4.01922435e-01,  -3.97679448e-01,  -3.93610805e-01,
                         -3.89600307e-01,  -3.85531664e-01,  -3.81404907e-01,
                         -3.77161920e-01,  -3.73093277e-01,  -3.68908405e-01,
                         -3.64665419e-01,  -3.60364288e-01,  -3.56121302e-01,
                         -3.51994544e-01,  -3.47635299e-01,  -3.43392313e-01,
                         -3.39091182e-01,  -3.34848166e-01,  -3.30663294e-01,
                         -3.26245934e-01,  -3.21886688e-01,  -3.17469329e-01,
                         -3.12935710e-01,  -3.08576465e-01,  -3.04217219e-01,
                         -2.99857974e-01,  -2.95440584e-01,  -2.90965110e-01,
                         -2.86489606e-01,  -2.82014132e-01,  -2.77596742e-01,
                         -2.73063153e-01,  -2.68529534e-01,  -2.63995916e-01,
                         -2.59346038e-01,  -2.54754305e-01,  -2.50220686e-01,
                         -2.45687082e-01,  -2.41211578e-01,  -2.36503601e-01,
                         -2.31853738e-01,  -2.27262005e-01,  -2.22670257e-01,
                         -2.18194768e-01,  -2.13661149e-01,  -2.08895043e-01,
                         -2.04245180e-01,  -1.99769691e-01,  -1.95294201e-01,
                         -1.90644339e-01,  -1.85994476e-01,  -1.81344613e-01,
                         -1.76694751e-01,  -1.72161132e-01,  -1.67395025e-01,
                         -1.62745163e-01,  -1.58269674e-01,  -1.53387323e-01,
                         -1.48853704e-01,  -1.44378215e-01,  -1.39553979e-01,
                         -1.34845987e-01,  -1.30196139e-01,  -1.25488147e-01,
                         -1.20780163e-01,  -1.16188422e-01,  -1.11422315e-01,
                         -1.06714331e-01,  -1.02006346e-01,  -9.72402394e-02,
                         -9.26484987e-02,  -8.78242627e-02,  -8.29419121e-02,
                         -7.82920495e-02,  -7.34096915e-02,  -6.87598288e-02,
                         -6.41680956e-02,  -5.92276156e-02,  -5.44033833e-02,
                         -4.96953987e-02,  -4.48711663e-02,  -3.99888121e-02,
                         -3.52227055e-02,  -3.05728409e-02,  -2.56904867e-02,
                         -2.07500085e-02,  -1.59839001e-02,  -1.10434219e-02,
                         -6.27731346e-03,  -1.45308184e-03,   3.54551966e-03,
                          8.31162836e-03,   1.30196130e-02,   1.77857224e-02,
                          2.26099528e-02,   2.73179393e-02,   3.22002918e-02,
                          3.69664021e-02,   4.16162647e-02,   4.64404970e-02,
                          5.13228513e-02,   5.60308360e-02,   6.07969426e-02,
                          6.56211749e-02,   7.05035329e-02,   7.52115175e-02,
                          7.98613802e-02,   8.48018527e-02,   8.96842107e-02,
                          9.42759514e-02,   9.89258140e-02,   1.03691921e-01,
                          1.08341783e-01,   1.12991646e-01,   1.17873996e-01,
                          1.22581981e-01,   1.27173722e-01,   1.31881714e-01,
                          1.36647820e-01,   1.41413927e-01,   1.46121904e-01,
                          1.50888011e-01,   1.55596003e-01,   1.60245866e-01,
                          1.65011972e-01,   1.69661835e-01,   1.74427941e-01,
                          1.79135934e-01,   1.83727667e-01,   1.88319400e-01,
                          1.93027392e-01,   1.97677255e-01,   2.02385232e-01,
                          2.06918851e-01,   2.11684957e-01,   2.16625437e-01,
                          2.21217185e-01,   2.25750789e-01,   2.30400652e-01,
                          2.35108644e-01,   2.39700377e-01,   2.44408369e-01,
                          2.49174476e-01,   2.53708094e-01,   2.58416086e-01,
                          2.63240308e-01,   2.67773926e-01,   2.72307545e-01,
                          2.77015507e-01,   2.81549126e-01,   2.86315233e-01,
                          2.90906996e-01,   2.95208097e-01,   2.99799830e-01,
                          3.04391593e-01,   3.08983326e-01,   3.13458800e-01,
                          3.18050563e-01,   3.22467923e-01,   3.26769054e-01,
                          3.31418902e-01,   3.35894406e-01,   3.40137392e-01,
                          3.44612896e-01,   3.49146515e-01,   3.53621989e-01,
                          3.57981235e-01,   3.62282366e-01,   3.66874099e-01,
                          3.71117115e-01,   3.75185728e-01,   3.79719347e-01,
                          3.84020478e-01,   3.88089091e-01,   3.92332107e-01,
                          3.96575093e-01,   4.00876224e-01,   4.05235469e-01,
                          4.09420341e-01,   4.13547099e-01,   4.17731971e-01,
                          4.21974957e-01,   4.26217973e-01,   4.30228472e-01,
                          4.34355229e-01,   4.38423842e-01,   4.42492485e-01,
                          4.46793616e-01,   4.50746000e-01,   4.54698354e-01,
                          4.58883256e-01,   4.62951869e-01,   4.66904253e-01,
                          4.71031010e-01,   4.75157768e-01,   4.79284525e-01,
                          4.83353138e-01,   4.87247407e-01,   4.91141647e-01,
                          4.94977802e-01,   4.98813927e-01,   5.02766311e-01,
                          5.06718695e-01,   5.10554850e-01,   5.14158487e-01,
                          5.17994642e-01,   5.22005141e-01,   5.25957525e-01,
                          5.29677391e-01,   5.33281028e-01,   5.36826551e-01,
                          5.40546417e-01,   5.44324458e-01,   5.47811866e-01,
                          5.51357388e-01,   5.54902911e-01,   5.58390260e-01,
                          5.61877668e-01,   5.65365076e-01,   5.68852484e-01,
                          5.72398007e-01,   5.75885415e-01,   5.79082191e-01,
                          5.82395196e-01,   5.85708201e-01,   5.89137495e-01,
                          5.92624903e-01,   5.95821679e-01,   5.98785937e-01,
                          6.02040887e-01,   6.05237663e-01,   6.08260036e-01,
                          6.11573100e-01,   6.14711761e-01,   6.17617905e-01,
                          6.20756567e-01,   6.23837113e-01,   6.26685143e-01,
                          6.29765689e-01,   6.32788062e-01,   6.35752380e-01,
                          6.38774753e-01,   6.41506553e-01,   6.44296467e-01,
                          6.47086382e-01,   6.49818182e-01,   6.52724385e-01,
                          6.55398011e-01,   6.58071697e-01,   6.60861611e-01,
                          6.63535297e-01,   6.66208982e-01,   6.68708265e-01,
                          6.71381950e-01,   6.74288094e-01,   6.76787376e-01,
                          6.79112315e-01,   6.81611598e-01,   6.83994710e-01,
                          6.86552107e-01,   6.88993275e-01,   6.91260099e-01,
                          6.93643153e-01,   6.95851803e-01,   6.98118627e-01,
                          7.00385451e-01,   7.02710390e-01,   7.04977155e-01,
                          7.07011521e-01,   7.09103942e-01,   7.11254478e-01,
                          7.13288784e-01,   7.15381265e-01,   7.17415571e-01,
                          7.19217360e-01,   7.21309841e-01,   7.23111629e-01,
                          7.24971592e-01,   7.26831555e-01,   7.28749573e-01,
                          7.30667651e-01,   7.32295096e-01,   7.33922601e-01,
                          7.35666275e-01,   7.37061203e-01,   7.38688707e-01,
                          7.40374267e-01,   7.41711080e-01,   7.43512928e-01,
                          7.45140374e-01,   7.46419072e-01,   7.47988403e-01,
                          7.49383390e-01,   7.50603974e-01,   7.51998901e-01,
                          7.53452003e-01,   7.54788816e-01,   7.56125689e-01,
                          7.57346272e-01,   7.58450568e-01,   7.59613037e-01,
                          7.60659277e-01,   7.61937976e-01,   7.63042331e-01,
                          7.64088571e-01,   7.65076637e-01,   7.66006649e-01,
                          7.67110944e-01,   7.68099070e-01,   7.68970907e-01,
                          7.69900858e-01,   7.70772755e-01,   7.71702707e-01,
                          7.72516429e-01,   7.73213923e-01,   7.74085760e-01,
                          7.75015712e-01,   7.75538862e-01,   7.76178181e-01,
                          7.76933789e-01,   7.77631283e-01,   7.78328776e-01,
                          7.79026210e-01,   7.79665589e-01,   7.80304968e-01,
                          7.80769944e-01,   7.81293035e-01,   7.81990528e-01,
                          7.82339275e-01,   7.82688022e-01,   7.83036768e-01,
                          7.83269227e-01,   7.83734202e-01,   7.84024835e-01,
                          7.84257352e-01,   7.84547925e-01,   7.84722328e-01,
                          7.84838557e-01,   7.84838557e-01,   7.84954786e-01,
                          7.85245419e-01,   7.85361648e-01,   7.85303533e-01,
                          7.85361648e-01,   7.85245419e-01,   7.85129189e-01,
                          7.85129189e-01,   7.85012901e-01,   7.84780443e-01,
                          7.84606040e-01,   7.84315467e-01,   7.83966720e-01,
                          7.83617973e-01,   7.83269227e-01,   7.83211112e-01,
                          7.82920480e-01,   7.82571733e-01,   7.82222986e-01,
                          7.81525552e-01,   7.81293035e-01,   7.81002402e-01,
                          7.80130565e-01,   7.79491246e-01,   7.79084384e-01,
                          7.78445005e-01,   7.77747512e-01,   7.77050018e-01,
                          7.76352584e-01,   7.75771320e-01,   7.74957597e-01,
                          7.74027646e-01,   7.73330152e-01,   7.72574544e-01,
                          7.71586478e-01,   7.70830870e-01,   7.69900858e-01,
                          7.68912792e-01,   7.68040955e-01,   7.66878486e-01,
                          7.65890360e-01,   7.64960408e-01,   7.63565421e-01,
                          7.62519240e-01,   7.61531115e-01,   7.60252416e-01,
                          7.59089947e-01,   7.57869363e-01,   7.56474376e-01,
                          7.55079448e-01,   7.53684461e-01,   7.52405763e-01,
                          7.50778317e-01,   7.49267101e-01,   7.47988403e-01,
                          7.46302843e-01,   7.44733512e-01,   7.43338525e-01,
                          7.41827309e-01,   7.40316153e-01,   7.38514304e-01,
                          7.36770630e-01,   7.35201299e-01,   7.33283222e-01,
                          7.31539547e-01,   7.29795814e-01,   7.27761507e-01,
                          7.26075947e-01,   7.24099755e-01,   7.22007275e-01,
                          7.20321715e-01,   7.18403637e-01,   7.16427445e-01,
                          7.14335024e-01,   7.12184489e-01,   7.10266411e-01,
                          7.08115816e-01,   7.05849051e-01,   7.03872859e-01,
                          7.01722264e-01,   6.99397326e-01,   6.97188675e-01,
                          6.94979966e-01,   6.92596912e-01,   6.90330148e-01,
                          6.88063323e-01,   6.85505867e-01,   6.83122814e-01,
                          6.80856049e-01,   6.78298593e-01,   6.75973654e-01,
                          6.73474371e-01,   6.70742571e-01,   6.68417633e-01,
                          6.65918350e-01,   6.63186550e-01,   6.60629153e-01,
                          6.57839179e-01,   6.55049264e-01,   6.52375638e-01,
                          6.49469435e-01,   6.46795809e-01,   6.44005895e-01,
                          6.41041577e-01,   6.38251662e-01,   6.35345519e-01,
                          6.32264972e-01,   6.29184425e-01,   6.26220167e-01,
                          6.23313963e-01,   6.20059073e-01,   6.16920412e-01,
                          6.13898039e-01,   6.10701263e-01,   6.07446313e-01,
                          6.04307652e-01,   6.01110876e-01,   5.97914100e-01,
                          5.94542980e-01,   5.91171801e-01,   5.87684393e-01,
                          5.84313273e-01,   5.81058383e-01,   5.77745318e-01,
                          5.74374199e-01,   5.70828676e-01,   5.67399383e-01,
                          5.64144492e-01,   5.60889602e-01,   5.57460308e-01,
                          5.53972900e-01,   5.50543666e-01,   5.46940029e-01,
                          5.43510735e-01,   5.40081441e-01,   5.36535919e-01,
                          5.32990396e-01,   5.29444873e-01,   5.25666893e-01,
                          5.21946967e-01,   5.18575847e-01,   5.14972210e-01,
                          5.11136055e-01,   5.07416189e-01,   5.03638148e-01,
                          4.99802023e-01,   4.96140271e-01,   4.92420375e-01,
                          4.88642365e-01,   4.84806210e-01,   4.81028199e-01,
                          4.77308333e-01,   4.73355949e-01,   4.69519794e-01,
                          4.65741783e-01,   4.61673170e-01,   4.57604527e-01,
                          4.53652143e-01,   4.49699759e-01,   4.45747375e-01,
                          4.41736877e-01,   4.37726378e-01,   4.33541507e-01,
                          4.29530978e-01,   4.25694853e-01,   4.21451867e-01,
                          4.17208850e-01,   4.13140237e-01,   4.08897221e-01,
                          4.04654235e-01,   4.00527477e-01,   3.96458834e-01,
                          3.92332107e-01,   3.88089091e-01,   3.83846104e-01,
                          3.79603088e-01,   3.75243843e-01,   3.70826483e-01,
                          3.66583496e-01,   3.62456739e-01,   3.58213723e-01,
                          3.53912622e-01,   3.49379003e-01,   3.44903499e-01,
                          3.40776742e-01,   3.36359382e-01,   3.31883878e-01,
                          3.27524632e-01,   3.23049158e-01,   3.18806142e-01,
                          3.14563155e-01,   3.10087651e-01,   3.05728406e-01,
                          3.01194817e-01,   2.96777427e-01,   2.92418182e-01,
                          2.88000822e-01,   2.83641577e-01,   2.79282331e-01,
                          2.74690598e-01,   2.70040721e-01,   2.65797734e-01,
                          2.61438489e-01,   2.56846756e-01,   2.52487510e-01,
                          2.48012006e-01,   2.43420273e-01,   2.39119142e-01,
                          2.34643653e-01,   2.29935676e-01,   2.25576431e-01,
                          2.21100926e-01,   2.16451064e-01,   2.11917460e-01,
                          2.07383841e-01,   2.02850223e-01,   1.98374733e-01,
                          1.93724871e-01,   1.89191252e-01,   1.84773892e-01,
                          1.80065900e-01,   1.75416037e-01,   1.70940548e-01,
                          1.66232556e-01,   1.61698952e-01,   1.57281578e-01,
                          1.52573586e-01,   1.47923738e-01,   1.43331990e-01,
                          1.38798371e-01,   1.34322882e-01,   1.29614905e-01,
                          1.24965034e-01,   1.20257050e-01,   1.15549065e-01,
                          1.11189820e-01,   1.06772453e-01,   1.02006346e-01,
                          9.74727273e-02,   9.29391161e-02,   8.82311314e-02,
                          8.35812688e-02,   7.92220235e-02,   7.45721608e-02,
                          6.98641762e-02,   6.54468089e-02,   6.09131902e-02,
                          5.62633276e-02,   5.17878383e-02,   4.73704673e-02,
                          4.29531001e-02,   3.84776071e-02,   3.38277444e-02,
                          2.94103771e-02,   2.48767603e-02,   2.02850215e-02,
                          1.59839001e-02,   1.15665318e-02,   6.91666966e-03,
                          2.49930075e-03,  -1.85994478e-03,  -6.45168312e-03,
                         -1.08109284e-02,  -1.52282976e-02,  -1.97037905e-02,
                         -2.41211578e-02,  -2.86547747e-02,  -3.30140181e-02,
                         -3.73151414e-02,  -4.17325087e-02,  -4.62080017e-02,
                         -5.05672470e-02,  -5.48683703e-02,  -5.93438633e-02,
                         -6.37031049e-02,  -6.78879842e-02,  -7.23053515e-02,
                         -7.67227188e-02,  -8.10238421e-02,  -8.53830874e-02,
                         -8.97423327e-02,  -9.41015780e-02,  -9.84027013e-02,
                         -1.02645703e-01,  -1.07004948e-01,  -1.11247942e-01,
                         -1.15665317e-01,  -1.19966440e-01,  -1.24267556e-01,
                         -1.28568679e-01,  -1.32869810e-01,  -1.37287170e-01,
                         -1.41530171e-01,  -1.45598799e-01,  -1.49783671e-01,
                         -1.54026672e-01,  -1.58211544e-01,  -1.62280172e-01,
                         -1.66406929e-01,  -1.70533687e-01,  -1.74776688e-01,
                         -1.78845316e-01,  -1.82797700e-01,  -1.86924443e-01,
                         -1.91051200e-01,  -1.95119828e-01,  -1.99130341e-01,
                         -2.03257084e-01,  -2.07441956e-01,  -2.11336225e-01,
                         -2.15230480e-01,  -2.19415352e-01,  -2.23193377e-01,
                         -2.27087632e-01,  -2.31098130e-01,  -2.34876141e-01,
                         -2.38886654e-01,  -2.42839038e-01,  -2.46675178e-01,
                         -2.50627548e-01,  -2.54579931e-01,  -2.58474201e-01,
                         -2.62252212e-01,  -2.66146481e-01,  -2.69982606e-01,
                         -2.73818731e-01,  -2.77654886e-01,  -2.81374753e-01,
                         -2.85269022e-01,  -2.89163291e-01,  -2.92708814e-01,
                         -2.96486825e-01,  -3.00439209e-01,  -3.04217219e-01,
                         -3.07995230e-01,  -3.11715126e-01,  -3.15376878e-01,
                         -3.19213003e-01,  -3.22932899e-01,  -3.26652795e-01,
                         -3.30430806e-01,  -3.34034443e-01,  -3.37521851e-01,
                         -3.41299862e-01,  -3.44845384e-01,  -3.48390907e-01,
                         -3.52110803e-01,  -3.55772555e-01,  -3.59550565e-01,
                         -3.63096088e-01,  -3.66583496e-01,  -3.70303363e-01,
                         -3.73848885e-01,  -3.77336293e-01,  -3.80998045e-01,
                         -3.84485453e-01,  -3.87914717e-01,  -3.91285866e-01,
                         -3.94657016e-01,  -3.98028165e-01,  -4.01341200e-01,
                         -4.04886723e-01,  -4.08432245e-01,  -4.11570907e-01,
                         -4.14942056e-01,  -4.18371320e-01,  -4.21684355e-01,
                         -4.25055504e-01,  -4.28310394e-01,  -4.31623429e-01,
                         -4.34878320e-01,  -4.38133240e-01,  -4.41213757e-01,
                         -4.44352418e-01,  -4.47723567e-01,  -4.50978488e-01,
                         -4.54000890e-01,  -4.57139552e-01,  -4.60278213e-01,
                         -4.63358730e-01,  -4.66439277e-01,  -4.69694167e-01,
                         -4.72832829e-01,  -4.75797117e-01,  -4.78877664e-01,
                         -4.81900066e-01,  -4.84806210e-01,  -4.87944871e-01,
                         -4.91083533e-01,  -4.93931592e-01,  -4.97012109e-01,
                         -5.00092626e-01,  -5.02940714e-01,  -5.05904973e-01,
                         -5.08811116e-01,  -5.11775434e-01,  -5.14855981e-01,
                         -5.17762125e-01,  -5.20784557e-01,  -5.23690701e-01,
                         -5.26306212e-01,  -5.29154301e-01,  -5.32060444e-01,
                         -5.34908473e-01,  -5.37698388e-01,  -5.40430188e-01,
                         -5.43161988e-01,  -5.45951903e-01,  -5.48567474e-01,
                         -5.51182985e-01,  -5.53914785e-01,  -5.56646585e-01,
                         -5.59145868e-01,  -5.61761439e-01,  -5.64318836e-01,
                         -5.66760063e-01,  -5.69491804e-01,  -5.72107375e-01,
                         -5.74432313e-01,  -5.76873481e-01,  -5.79314649e-01,
                         -5.81930220e-01,  -5.84371388e-01,  -5.86638212e-01,
                         -5.88963151e-01,  -5.91346204e-01,  -5.93612969e-01,
                         -5.95879793e-01,  -5.98146617e-01,  -6.00355268e-01,
                         -6.02680206e-01,  -6.05005145e-01,  -6.06981337e-01,
                         -6.09073758e-01,  -6.11573100e-01,  -6.13549292e-01,
                         -6.15409195e-01,  -6.17734134e-01,  -6.19884729e-01,
                         -6.21919036e-01,  -6.24127686e-01,  -6.26162052e-01,
                         -6.28080070e-01,  -6.30114436e-01,  -6.32148743e-01,
                         -6.34066761e-01,  -6.35984838e-01,  -6.37961030e-01,
                         -6.39879107e-01,  -6.41855299e-01,  -6.43657148e-01,
                         -6.45517051e-01,  -6.47493243e-01,  -6.49236977e-01,
                         -6.51038766e-01,  -6.52898729e-01,  -6.54700577e-01,
                         -6.56502366e-01,  -6.58187926e-01,  -6.59815371e-01,
                         -6.61384702e-01,  -6.63128436e-01,  -6.64755881e-01,
                         -6.66325212e-01,  -6.68010771e-01,  -6.69521987e-01,
                         -6.70858800e-01,  -6.72311902e-01,  -6.73939347e-01,
                         -6.75450563e-01,  -6.76961780e-01,  -6.78298593e-01,
                         -6.79519176e-01,  -6.80914164e-01,  -6.82367206e-01,
                         -6.83704078e-01,  -6.85040891e-01,  -6.86203361e-01,
                         -6.87307715e-01,  -6.88760817e-01,  -6.89865112e-01,
                         -6.90853238e-01,  -6.92131937e-01,  -6.93061888e-01,
                         -6.94050014e-01,  -6.95270598e-01,  -6.96084321e-01,
                         -6.97072446e-01,  -6.98002398e-01,  -6.98932350e-01,
                         -7.00036705e-01,  -7.00850427e-01,  -7.01606035e-01,
                         -7.02361643e-01,  -7.03059137e-01,  -7.03989089e-01,
                         -7.04802811e-01,  -7.05558419e-01,  -7.06197798e-01,
                         -7.06837118e-01,  -7.07592726e-01,  -7.08232105e-01,
                         -7.08987713e-01,  -7.09917665e-01,  -7.10382640e-01,
                         -7.10905731e-01,  -7.11370766e-01,  -7.11777627e-01,
                         -7.12358832e-01,  -7.12881923e-01,  -7.13346958e-01,
                         -7.13753819e-01,  -7.14044392e-01,  -7.14509428e-01,
                         -7.14916289e-01,  -7.15381265e-01,  -7.15846241e-01,
                         -7.15962470e-01,  -7.16311216e-01,  -7.16601849e-01,
                         -7.16601849e-01,  -7.16892481e-01,  -7.17066824e-01,
                         -7.17124939e-01,  -7.17241168e-01,  -7.17299342e-01,
                         -7.17473686e-01,  -7.17531800e-01,  -7.17589915e-01,
                         -7.17648029e-01,  -7.17531800e-01,  -7.17473686e-01,
                         -7.17299342e-01,  -7.16950595e-01,  -7.16892481e-01,
                         -7.16776192e-01,  -7.16427445e-01,  -7.16253102e-01,
                         -7.16020584e-01,  -7.15613723e-01,  -7.15206861e-01,
                         -7.14858115e-01,  -7.14393139e-01,  -7.13986278e-01,
                         -7.13753819e-01,  -7.13346958e-01,  -7.12707579e-01,
                         -7.12126374e-01,  -7.11545110e-01,  -7.11080134e-01,
                         -7.10382640e-01,  -7.09627032e-01,  -7.09103942e-01,
                         -7.08464563e-01,  -7.07650840e-01,  -7.06953347e-01,
                         -7.06488371e-01,  -7.05790937e-01,  -7.04802811e-01,
                         -7.03989089e-01,  -7.03291595e-01,  -7.02419758e-01,
                         -7.01606035e-01,  -7.00734198e-01,  -6.99862361e-01,
                         -6.98874235e-01,  -6.97769880e-01,  -6.96839929e-01,
                         -6.95909977e-01,  -6.94921851e-01,  -6.93759382e-01,
                         -6.92655027e-01,  -6.91899419e-01,  -6.90795124e-01,
                         -6.89516366e-01,  -6.88353956e-01,  -6.87133312e-01,
                         -6.85912728e-01,  -6.84692144e-01,  -6.83355331e-01,
                         -6.82076633e-01,  -6.80623531e-01,  -6.79170430e-01,
                         -6.77833617e-01,  -6.76438630e-01,  -6.75043702e-01,
                         -6.73706889e-01,  -6.72079384e-01,  -6.70393825e-01,
                         -6.69057012e-01,  -6.67487681e-01,  -6.65685833e-01,
                         -6.64174616e-01,  -6.62489057e-01,  -6.60629153e-01,
                         -6.59117937e-01,  -6.57374203e-01,  -6.55398011e-01,
                         -6.53538108e-01,  -6.51736259e-01,  -6.49876297e-01,
                         -6.47958279e-01,  -6.46214545e-01,  -6.44296467e-01,
                         -6.42204046e-01,  -6.40402198e-01,  -6.38484180e-01,
                         -6.36275470e-01,  -6.34124935e-01,  -6.32032454e-01,
                         -6.30114436e-01,  -6.28021955e-01,  -6.25638902e-01,
                         -6.23546481e-01,  -6.21570289e-01,  -6.19303465e-01,
                         -6.17094815e-01,  -6.14944220e-01,  -6.12561166e-01,
                         -6.10236228e-01,  -6.07911289e-01,  -6.05644524e-01,
                         -6.03435814e-01,  -6.01110876e-01,  -5.98669708e-01,
                         -5.96228540e-01,  -5.93845487e-01,  -5.91404319e-01,
                         -5.88904977e-01,  -5.86405694e-01,  -5.84022641e-01,
                         -5.81581473e-01,  -5.78849673e-01,  -5.76292276e-01,
                         -5.73909223e-01,  -5.71061134e-01,  -5.68387508e-01,
                         -5.65888166e-01,  -5.63040137e-01,  -5.60308337e-01,
                         -5.57576537e-01,  -5.54554164e-01,  -5.51822364e-01,
                         -5.49090564e-01,  -5.46242535e-01,  -5.43510735e-01,
                         -5.40488303e-01,  -5.37465930e-01,  -5.34617841e-01,
                         -5.31595469e-01,  -5.28689265e-01,  -5.25492489e-01,
                         -5.22237599e-01,  -5.19331455e-01,  -5.16309023e-01,
                         -5.13170362e-01,  -5.10147989e-01,  -5.06951213e-01,
                         -5.03870666e-01,  -5.00732005e-01,  -4.97360855e-01,
                         -4.94164079e-01,  -4.91141647e-01,  -4.87770498e-01,
                         -4.84457493e-01,  -4.81318831e-01,  -4.77947682e-01,
                         -4.74576533e-01,  -4.71321613e-01,  -4.67892349e-01,
                         -4.64521199e-01,  -4.61266309e-01,  -4.57953274e-01,
                         -4.54582125e-01,  -4.51036602e-01,  -4.47665453e-01,
                         -4.44294304e-01,  -4.40632522e-01,  -4.37319517e-01,
                         -4.33890224e-01,  -4.30344731e-01,  -4.26915437e-01,
                         -4.23253685e-01,  -4.19650048e-01,  -4.16337013e-01,
                         -4.12849605e-01,  -4.09187853e-01,  -4.05526072e-01,
                         -4.01922435e-01,  -3.98318797e-01,  -3.94598901e-01,
                         -3.90995264e-01,  -3.87391627e-01,  -3.83729845e-01,
                         -3.80184323e-01,  -3.76580685e-01,  -3.72802675e-01,
                         -3.69024664e-01,  -3.65362883e-01,  -3.61526757e-01,
                         -3.57632488e-01,  -3.53738248e-01,  -3.49902093e-01,
                         -3.46240342e-01,  -3.42462331e-01,  -3.38509947e-01,
                         -3.34673822e-01,  -3.30605179e-01,  -3.26536536e-01,
                         -3.22700411e-01,  -3.18748027e-01,  -3.14795643e-01,
                         -3.10843259e-01,  -3.06949019e-01,  -3.03112864e-01,
                         -2.98986107e-01,  -2.94975609e-01,  -2.91023225e-01,
                         -2.86838353e-01,  -2.82711595e-01,  -2.78759211e-01,
                         -2.74690598e-01,  -2.70680070e-01,  -2.66553342e-01,
                         -2.62484699e-01,  -2.58357942e-01,  -2.54231185e-01,
                         -2.50104457e-01,  -2.45977700e-01,  -2.41967186e-01,
                         -2.37840429e-01,  -2.33829930e-01,  -2.29645059e-01,
                         -2.25402057e-01,  -2.21391544e-01,  -2.17148542e-01,
                         -2.12963670e-01,  -2.09011286e-01,  -2.04768285e-01,
                         -2.00583413e-01,  -1.96456671e-01,  -1.92329913e-01,
                         -1.88086912e-01,  -1.83902040e-01,  -1.79775283e-01,
                         -1.75416037e-01,  -1.71289280e-01,  -1.67278782e-01,
                         -1.62861407e-01,  -1.58618420e-01,  -1.54375419e-01,
                         -1.50132418e-01,  -1.45889416e-01,  -1.41472042e-01,
                         -1.37170926e-01,  -1.32869810e-01,  -1.28452435e-01,
                         -1.24151312e-01,  -1.19908310e-01,  -1.15607187e-01,
                         -1.11364193e-01,  -1.06830575e-01,  -1.02413207e-01,
                         -9.82283354e-02,  -9.38690901e-02,  -8.92773494e-02,
                         -8.49181041e-02,  -8.06169808e-02,  -7.60833621e-02,
                         -7.17241168e-02,  -6.73067495e-02,  -6.28312603e-02,
                         -5.84138893e-02,  -5.38802743e-02,  -4.94047813e-02,
                         -4.49292921e-02,  -4.05119210e-02,  -3.60945538e-02,
                         -3.17353085e-02,  -2.72598155e-02,  -2.27843225e-02,
                         -1.83669552e-02,  -1.38914622e-02,  -9.47409403e-03,
                         -5.05672488e-03,  -5.81232714e-04,   3.95238260e-03,
                          8.31162836e-03,   1.26127508e-02,   1.72044896e-02,
                          2.17381045e-02,   2.59811040e-02,   3.05728409e-02,
                          3.51064578e-02,   3.92332077e-02,   4.38249484e-02,
                          4.83585633e-02,   5.26015610e-02,   5.71351759e-02,
                          6.16687946e-02,   6.59699142e-02,   7.02129155e-02,
                          7.47465268e-02,   7.93382674e-02,   8.36975127e-02,
                          8.80567580e-02,   9.24741253e-02,   9.69496220e-02,
                          1.01308867e-01,   1.05784357e-01,   1.10143602e-01,
                          1.14560969e-01,   1.19036466e-01,   1.23395711e-01,
                          1.27929330e-01,   1.32346690e-01,   1.36589691e-01,
                          1.41123310e-01,   1.45540670e-01,   1.49899915e-01,
                          1.54491663e-01,   1.58792779e-01,   1.63152024e-01,
                          1.67627513e-01,   1.71928644e-01,   1.76404133e-01,
                          1.80705264e-01,   1.85064510e-01,   1.89481869e-01,
                          1.93783000e-01,   1.98316604e-01,   2.02675849e-01,
                          2.07035094e-01,   2.11510599e-01,   2.15753585e-01,
                          2.19996586e-01,   2.24355832e-01,   2.28656963e-01,
                          2.32958078e-01,   2.37142950e-01,   2.41444081e-01,
                          2.45628953e-01,   2.49930069e-01,   2.54289329e-01,
                          2.58299828e-01,   2.62484699e-01,   2.66785830e-01,
                          2.70854443e-01,   2.75097460e-01,   2.79340446e-01,
                          2.83350945e-01,   2.87361473e-01,   2.91371971e-01,
                          2.95556843e-01,   2.99683601e-01,   3.03635985e-01,
                          3.07820857e-01,   3.11947614e-01,   3.15899998e-01,
                          3.19852382e-01,   3.23746622e-01,   3.27757150e-01,
                          3.31883878e-01,   3.35778147e-01,   3.39614272e-01,
                          3.43624800e-01,   3.47577184e-01,   3.51413310e-01,
                          3.55365694e-01,   3.59259963e-01,   3.63154203e-01,
                          3.67106587e-01,   3.70884597e-01,   3.74488264e-01,
                          3.78324389e-01,   3.82160515e-01,   3.85880411e-01,
                          3.89832795e-01,   3.93610805e-01,   3.97156328e-01,
                          4.00992453e-01,   4.04770464e-01,   4.08432245e-01,
                          4.12210256e-01,   4.15813893e-01,   4.19359416e-01,
                          4.23137426e-01,   4.26682949e-01,   4.30286586e-01,
                          4.33948368e-01,   4.37493891e-01,   4.41039413e-01,
                          4.44584906e-01,   4.48130429e-01,   4.51501578e-01,
                          4.55163360e-01,   4.58534509e-01,   4.61847544e-01,
                          4.65393037e-01,   4.68706071e-01,   4.71902847e-01,
                          4.75390255e-01,   4.78761405e-01,   4.82016295e-01,
                          4.85271215e-01,   4.88467991e-01,   4.91722882e-01,
                          4.94977802e-01,   4.98116463e-01,   5.01138866e-01,
                          5.04277527e-01,   5.07590532e-01,   5.10729194e-01,
                          5.13577223e-01,   5.16541541e-01,   5.19622087e-01,
                          5.22470117e-01,   5.25376260e-01,   5.28514922e-01,
                          5.31421065e-01,   5.34385383e-01,   5.37233412e-01,
                          5.40081441e-01,   5.42929471e-01,   5.45603156e-01,
                          5.48509359e-01,   5.51473618e-01,   5.54031014e-01,
                          5.56704700e-01,   5.59320271e-01,   5.62110186e-01,
                          5.64900100e-01,   5.67399383e-01,   5.70131183e-01,
                          5.72746754e-01,   5.75187922e-01,   5.77861607e-01,
                          5.80360889e-01,   5.82976460e-01,   5.85591972e-01,
                          5.87975025e-01,   5.90358078e-01,   5.92741132e-01,
                          5.95182300e-01,   5.97797871e-01,   6.00297153e-01,
                          6.02563977e-01,   6.04830801e-01,   6.06981337e-01,
                          6.09364390e-01,   6.11573100e-01,   6.13723636e-01,
                          6.16048574e-01,   6.18199110e-01,   6.20233476e-01,
                          6.22384012e-01,   6.24650836e-01,   6.26743257e-01,
                          6.28719449e-01,   6.30753756e-01,   6.32788062e-01,
                          6.34589911e-01,   6.36507988e-01,   6.38426006e-01,
                          6.40227854e-01,   6.42029703e-01,   6.43773377e-01,
                          6.45633340e-01,   6.47377014e-01,   6.49178863e-01,
                          6.51038766e-01,   6.52608097e-01,   6.54177427e-01,
                          6.55804873e-01,   6.57316089e-01,   6.58885419e-01,
                          6.60512865e-01,   6.61965966e-01,   6.63535297e-01,
                          6.65278971e-01,   6.66615844e-01,   6.67778313e-01,
                          6.68998897e-01,   6.70684457e-01,   6.72311902e-01,
                          6.73416257e-01,   6.74636841e-01,   6.75973654e-01,
                          6.77136123e-01,   6.78298593e-01,   6.79577291e-01,
                          6.80797875e-01,   6.82018518e-01,   6.83006585e-01,
                          6.84227169e-01,   6.85389638e-01,   6.86552107e-01,
                          6.87830806e-01,   6.88644528e-01,   6.89458251e-01,
                          6.90330148e-01,   6.91376328e-01,   6.92480683e-01,
                          6.93236291e-01,   6.94050014e-01,   6.95038080e-01,
                          6.95793688e-01,   6.96433067e-01,   6.97188675e-01,
                          6.98002398e-01,   6.98874235e-01,   6.99513614e-01,
                          7.00094819e-01,   7.00676084e-01,   7.01431692e-01,
                          7.02187240e-01,   7.02535987e-01,   7.02884734e-01,
                          7.03465998e-01,   7.03989089e-01,   7.04337835e-01,
                          7.04686582e-01,   7.05209672e-01,   7.05442190e-01,
                          7.05674648e-01,   7.06081510e-01,   7.06255913e-01,
                          7.06430256e-01,   7.06837118e-01,   7.06837118e-01,
                          7.06895232e-01,   7.07185864e-01,   7.07069635e-01,
                          7.07185864e-01,   7.07302094e-01,   7.07302094e-01,
                          7.07360208e-01,   7.07243979e-01,   7.07069635e-01,
                          7.07069635e-01,   7.06953347e-01,   7.06779003e-01,
                          7.06662774e-01,   7.06488371e-01,   7.06372142e-01,
                          7.06197798e-01,   7.05907166e-01,   7.05442190e-01,
                          7.05035329e-01,   7.04802811e-01,   7.04395950e-01,
                          7.03989089e-01,   7.03582227e-01,   7.03349710e-01,
                          7.02884734e-01,   7.02245414e-01,   7.01780379e-01,
                          7.01431692e-01,   7.01024771e-01,   7.00385451e-01,
                          6.99629843e-01,   6.99048638e-01,   6.98467374e-01,
                          6.97711766e-01,   6.97072446e-01,   6.96316838e-01,
                          6.95386827e-01,   6.94631219e-01,   6.93759382e-01,
                          6.92887545e-01,   6.92073822e-01,   6.91085696e-01,
                          6.90213859e-01,   6.89342022e-01,   6.88179553e-01,
                          6.87191486e-01,   6.86145246e-01,   6.84982777e-01,
                          6.84110940e-01,   6.82774067e-01,   6.81495368e-01,
                          6.80391014e-01,   6.78937972e-01,   6.77717388e-01,
                          6.76496804e-01,   6.75334334e-01,   6.73997462e-01,
                          6.72486246e-01,   6.71149433e-01,   6.69754505e-01,
                          6.68417633e-01,   6.67022705e-01,   6.65337086e-01,
                          6.63767755e-01,   6.62082195e-01,   6.60396636e-01,
                          6.59117937e-01,   6.57606721e-01,   6.55863047e-01,
                          6.54235542e-01,   6.52491868e-01,   6.50806308e-01,
                          6.49004459e-01,   6.47318900e-01,   6.45458937e-01,
                          6.43424630e-01,   6.41680956e-01,   6.39937222e-01,
                          6.38019145e-01,   6.36042953e-01,   6.34124935e-01,
                          6.32206857e-01,   6.30288780e-01,   6.28312588e-01,
                          6.26220167e-01,   6.24069571e-01,   6.22209668e-01,
                          6.20175302e-01,   6.17792249e-01,   6.15816057e-01,
                          6.13665521e-01,   6.11224353e-01,   6.09015644e-01,
                          6.06748879e-01,   6.04482055e-01,   6.02273345e-01,
                          5.99948406e-01,   5.97623467e-01,   5.95124185e-01,
                          5.92624903e-01,   5.90358078e-01,   5.87916911e-01,
                          5.85417628e-01,   5.82918286e-01,   5.80419004e-01,
                          5.77919722e-01,   5.75187922e-01,   5.72572351e-01,
                          5.69956839e-01,   5.67166924e-01,   5.64435124e-01,
                          5.61761439e-01,   5.59262156e-01,   5.56588471e-01,
                          5.53682327e-01,   5.50776124e-01,   5.48102438e-01,
                          5.45196295e-01,   5.42232037e-01,   5.39500237e-01,
                          5.36652207e-01,   5.33571661e-01,   5.30723631e-01,
                          5.27875543e-01,   5.24736941e-01,   5.21598279e-01,
                          5.18750191e-01,   5.15727818e-01,   5.12531042e-01,
                          5.09450495e-01,   5.06428063e-01,   5.03289402e-01,
                          5.00150740e-01,   4.97128367e-01,   4.94047821e-01,
                          4.90734786e-01,   4.87596154e-01,   4.84399348e-01,
                          4.81144458e-01,   4.77947682e-01,   4.74460274e-01,
                          4.71089125e-01,   4.67950463e-01,   4.64637458e-01,
                          4.61382538e-01,   4.58127648e-01,   4.54640239e-01,
                          4.51327205e-01,   4.48014200e-01,   4.44643050e-01,
                          4.41271901e-01,   4.37784493e-01,   4.34238970e-01,
                          4.30693448e-01,   4.27322298e-01,   4.23834920e-01,
                          4.20231253e-01,   4.16860104e-01,   4.13256466e-01,
                          4.09652829e-01,   4.06049192e-01,   4.02503669e-01,
                          3.98958147e-01,   3.95238250e-01,   3.91518384e-01,
                          3.87798488e-01,   3.84136707e-01,   3.80416811e-01,
                          3.76696944e-01,   3.72918934e-01,   3.69199038e-01,
                          3.65479141e-01,   3.61875504e-01,   3.57981235e-01,
                          3.54261339e-01,   3.50599587e-01,   3.46705317e-01,
                          3.42927307e-01,   3.39149296e-01,   3.35313171e-01,
                          3.31535161e-01,   3.27640891e-01,   3.23688507e-01,
                          3.19910496e-01,   3.16074371e-01,   3.12063843e-01,
                          3.08285832e-01,   3.04624081e-01,   3.00613582e-01,
                          2.96719313e-01,   2.92825043e-01,   2.88814545e-01,
                          2.85036534e-01,   2.81200409e-01,   2.77480513e-01,
                          2.73586243e-01,   2.69459486e-01,   2.65565246e-01,
                          2.61670977e-01,   2.57660478e-01,   2.53824323e-01,
                          2.49930069e-01,   2.45919570e-01,   2.42025316e-01,
                          2.38014802e-01,   2.34062418e-01,   2.30051920e-01,
                          2.26273909e-01,   2.22495884e-01,   2.18427256e-01,
                          2.14358628e-01,   2.10464373e-01,   2.06511989e-01,
                          2.02559605e-01,   1.98549107e-01,   1.94538593e-01,
                          1.90528095e-01,   1.86633825e-01,   1.82565197e-01,
                          1.78496569e-01,   1.74660429e-01,   1.70708060e-01,
                          1.66523173e-01,   1.62512675e-01,   1.58444047e-01,
                          1.54433534e-01,   1.50481150e-01,   1.46470651e-01,
                          1.42576396e-01,   1.38449639e-01,   1.34322882e-01,
                          1.30486742e-01,   1.26359999e-01,   1.22349493e-01,
                          1.18513353e-01,   1.14270352e-01,   1.10317975e-01,
                          1.06598087e-01,   1.02471329e-01,   9.84027013e-02,
                          9.43921953e-02,   9.04979333e-02,   8.66036788e-02,
                          8.25931728e-02,   7.87570328e-02,   7.48046562e-02,
                          7.07941502e-02,   6.68417662e-02,   6.28312603e-02,
                          5.88207543e-02,   5.49264923e-02,   5.09741120e-02,
                          4.70217280e-02,   4.31855917e-02,   3.92913334e-02,
                          3.54551971e-02,   3.16190608e-02,   2.76085548e-02,
                          2.37142947e-02,   1.98781602e-02,   1.59839001e-02,
                          1.22058876e-02,   8.48599803e-03,   4.64986172e-03,
                          6.97479292e-04,  -3.25490325e-03,  -7.14916270e-03,
                         -1.11015448e-02,  -1.49376811e-02,  -1.85994469e-02,
                         -2.24937070e-02,  -2.63879653e-02,  -3.01659796e-02,
                         -3.39439921e-02,  -3.76057588e-02,  -4.13256474e-02,
                         -4.53361534e-02,  -4.91722897e-02,  -5.28921783e-02,
                         -5.66701926e-02,  -6.05063289e-02,  -6.44005835e-02,
                         -6.81786016e-02,  -7.20147341e-02,  -7.58508742e-02,
                         -7.95126408e-02,  -8.32906514e-02,  -8.70105401e-02,
                         -9.07304287e-02,  -9.45665687e-02,  -9.84608233e-02,
                         -1.02180712e-01,  -1.05900601e-01,  -1.09620497e-01,
                         -1.13340385e-01,  -1.17176518e-01,  -1.20780163e-01,
                         -1.24383807e-01,  -1.28103688e-01,  -1.31881714e-01,
                         -1.35601595e-01,  -1.39205247e-01,  -1.42808884e-01,
                         -1.46470651e-01,  -1.50190532e-01,  -1.53736055e-01,
                         -1.57397822e-01,  -1.60943344e-01,  -1.64605111e-01,
                         -1.68383121e-01,  -1.71812400e-01,  -1.75241664e-01,
                         -1.78787187e-01,  -1.82274580e-01,  -1.85703859e-01,
                         -1.89307496e-01,  -1.92794904e-01,  -1.96398541e-01,
                         -1.99885935e-01,  -2.03373328e-01,  -2.06860736e-01,
                         -2.10290000e-01,  -2.13893652e-01,  -2.17381045e-01,
                         -2.20926568e-01,  -2.24472076e-01,  -2.27843225e-01,
                         -2.31388748e-01,  -2.34876141e-01,  -2.38247290e-01,
                         -2.41618454e-01,  -2.44989604e-01,  -2.48418868e-01,
                         -2.51964390e-01,  -2.55219281e-01,  -2.58648574e-01,
                         -2.62019724e-01,  -2.65390873e-01,  -2.68936396e-01,
                         -2.72249401e-01,  -2.75504321e-01,  -2.78933585e-01,
                         -2.82362849e-01,  -2.85617769e-01,  -2.89105147e-01,
                         -2.92418182e-01,  -2.95614958e-01,  -2.99102366e-01,
                         -3.02299142e-01,  -3.05612177e-01,  -3.09041440e-01,
                         -3.12296361e-01,  -3.15609366e-01,  -3.18864286e-01,
                         -3.21944803e-01,  -3.25199723e-01,  -3.28454614e-01,
                         -3.31593275e-01,  -3.34615678e-01,  -3.37696224e-01,
                         -3.41125488e-01,  -3.44264150e-01,  -3.47228438e-01,
                         -3.50308955e-01,  -3.53389502e-01,  -3.56644392e-01,
                         -3.59783053e-01,  -3.62747341e-01,  -3.65711629e-01,
                         -3.68850291e-01,  -3.71988952e-01,  -3.74895126e-01,
                         -3.77975643e-01,  -3.80823702e-01,  -3.83671731e-01,
                         -3.86752248e-01,  -3.89658421e-01,  -3.92506450e-01,
                         -3.95645112e-01,  -3.98551285e-01,  -4.01515573e-01,
                         -4.04537976e-01,  -4.07153517e-01,  -4.10001576e-01,
                         -4.12965864e-01,  -4.15755779e-01,  -4.18603808e-01,
                         -4.21509981e-01,  -4.24299896e-01,  -4.27089810e-01,
                         -4.29879725e-01,  -4.32553411e-01,  -4.35401440e-01,
                         -4.38133240e-01,  -4.40923154e-01,  -4.43829328e-01,
                         -4.46386755e-01,  -4.49118525e-01,  -4.51908439e-01,
                         -4.54465866e-01,  -4.57139552e-01,  -4.59929466e-01,
                         -4.62428749e-01,  -4.65044320e-01,  -4.67601746e-01,
                         -4.70101029e-01,  -4.72774714e-01,  -4.75157768e-01,
                         -4.77657050e-01,  -4.80272621e-01,  -4.82946277e-01,
                         -4.85387444e-01,  -4.87712383e-01,  -4.90153551e-01,
                         -4.92594749e-01,  -4.95035917e-01,  -4.97477084e-01,
                         -4.99802023e-01,  -5.02010703e-01,  -5.04393756e-01,
                         -5.06834924e-01,  -5.09101748e-01,  -5.11426687e-01,
                         -5.13577223e-01,  -5.15669703e-01,  -5.17878354e-01,
                         -5.20261407e-01,  -5.22412002e-01,  -5.24504423e-01,
                         -5.26654959e-01,  -5.28921783e-01,  -5.31014204e-01,
                         -5.32874167e-01,  -5.35257220e-01,  -5.37349641e-01,
                         -5.39267719e-01,  -5.41302025e-01,  -5.43336332e-01,
                         -5.45312524e-01,  -5.47230601e-01,  -5.49148679e-01,
                         -5.51066756e-01,  -5.53042948e-01,  -5.54902911e-01,
                         -5.56704700e-01,  -5.58564663e-01,  -5.60657084e-01,
                         -5.62342644e-01,  -5.64028263e-01,  -5.65830052e-01,
                         -5.67631900e-01,  -5.69549978e-01,  -5.71177423e-01,
                         -5.72979212e-01,  -5.74722946e-01,  -5.76408505e-01,
                         -5.77977836e-01,  -5.79605281e-01,  -5.81232727e-01,
                         -5.82918286e-01,  -5.84429502e-01,  -5.85882604e-01,
                         -5.87510049e-01,  -5.89079380e-01,  -5.90474308e-01,
                         -5.91985524e-01,  -5.93671143e-01,  -5.95066071e-01,
                         -5.96286654e-01,  -5.97855985e-01,  -5.99076569e-01,
                         -6.00297153e-01,  -6.01634026e-01,  -6.02970839e-01,
                         -6.04365826e-01,  -6.05644524e-01,  -6.06865108e-01,
                         -6.08027577e-01,  -6.09248161e-01,  -6.10352516e-01,
                         -6.11689329e-01,  -6.12851799e-01,  -6.13665521e-01,
                         -6.14595473e-01,  -6.15699828e-01,  -6.16862297e-01,
                         -6.18082881e-01,  -6.19012833e-01,  -6.19710326e-01,
                         -6.20756567e-01,  -6.21686518e-01,  -6.22442126e-01,
                         -6.23255849e-01,  -6.24069571e-01,  -6.25057697e-01,
                         -6.25813305e-01,  -6.26685143e-01,  -6.27382636e-01,
                         -6.28080070e-01,  -6.28777564e-01,  -6.29416943e-01,
                         -6.30230665e-01,  -6.30986273e-01,  -6.31509364e-01,
                         -6.31974339e-01,  -6.32555604e-01,  -6.33194923e-01,
                         -6.34008646e-01,  -6.34299278e-01,  -6.34706140e-01,
                         -6.35345519e-01,  -6.35868609e-01,  -6.36449873e-01,
                         -6.36740446e-01,  -6.37147307e-01,  -6.37496054e-01,
                         -6.37728572e-01,  -6.38193548e-01,  -6.38484180e-01,
                         -6.38774753e-01,  -6.39007270e-01,  -6.39123499e-01,
                         -6.39356017e-01,  -6.39646649e-01,  -6.39879107e-01,
                         -6.40053511e-01,  -6.39937222e-01,  -6.40227854e-01,
                         -6.40518486e-01,  -6.40285969e-01,  -6.40460372e-01,
                         -6.40344083e-01,  -6.40053511e-01,  -6.40111625e-01,
                         -6.39995337e-01,  -6.39820993e-01,  -6.39937222e-01,
                         -6.39879107e-01,  -6.39472246e-01,  -6.39356017e-01,
                         -6.39239788e-01,  -6.38949156e-01,  -6.38774753e-01,
                         -6.38542295e-01,  -6.38135433e-01,  -6.37844801e-01,
                         -6.37379825e-01,  -6.36856735e-01,  -6.36507988e-01,
                         -6.35984838e-01,  -6.35577977e-01,  -6.35113001e-01,
                         -6.34531796e-01,  -6.34008646e-01,  -6.33369327e-01,
                         -6.32904351e-01,  -6.32264972e-01,  -6.31741881e-01,
                         -6.31102502e-01,  -6.30288780e-01,  -6.29707515e-01,
                         -6.29126310e-01,  -6.28254473e-01,  -6.27440751e-01,
                         -6.26627028e-01,  -6.25813305e-01,  -6.25057697e-01,
                         -6.24069571e-01,  -6.23372078e-01,  -6.22674644e-01,
                         -6.21512175e-01,  -6.20524049e-01,  -6.19710326e-01,
                         -6.18780375e-01,  -6.17676020e-01,  -6.16629779e-01,
                         -6.15699828e-01,  -6.14769876e-01,  -6.13491178e-01,
                         -6.12386823e-01,  -6.11398697e-01,  -6.10061884e-01,
                         -6.09015644e-01,  -6.07795060e-01,  -6.06400132e-01,
                         -6.05295777e-01,  -6.04075193e-01,  -6.02622092e-01,
                         -6.01227164e-01,  -5.99832177e-01,  -5.98437250e-01,
                         -5.97100377e-01,  -5.95647335e-01,  -5.94252348e-01,
                         -5.92566788e-01,  -5.90881169e-01,  -5.89370012e-01,
                         -5.87742567e-01,  -5.86173236e-01,  -5.84603906e-01,
                         -5.82976460e-01,  -5.81290841e-01,  -5.79663396e-01,
                         -5.78035951e-01,  -5.76292276e-01,  -5.74490428e-01,
                         -5.72862983e-01,  -5.71235538e-01,  -5.69317460e-01,
                         -5.67457497e-01,  -5.65655708e-01,  -5.63621402e-01,
                         -5.61703324e-01,  -5.59959590e-01,  -5.58041573e-01,
                         -5.56065381e-01,  -5.54031014e-01,  -5.51938593e-01,
                         -5.49962401e-01,  -5.47928095e-01,  -5.45951903e-01,
                         -5.43859482e-01,  -5.41767061e-01,  -5.39732695e-01,
                         -5.37640274e-01,  -5.35489738e-01,  -5.33339143e-01,
                         -5.31130493e-01,  -5.28863668e-01,  -5.26422501e-01,
                         -5.24213791e-01,  -5.22063255e-01,  -5.19680202e-01,
                         -5.17413378e-01,  -5.15088439e-01,  -5.12705386e-01,
                         -5.10438561e-01,  -5.07997394e-01,  -5.05730629e-01,
                         -5.03173172e-01,  -5.00615776e-01,  -4.98290837e-01,
                         -4.95733410e-01,  -4.93292212e-01,  -4.90909159e-01,
                         -4.88293618e-01,  -4.85678077e-01,  -4.83120650e-01,
                         -4.80446965e-01,  -4.77889568e-01,  -4.75157768e-01,
                         -4.72425967e-01,  -4.69752282e-01,  -4.66962367e-01,
                         -4.64288712e-01,  -4.61556911e-01,  -4.58766997e-01,
                         -4.56035197e-01,  -4.53245282e-01,  -4.50339109e-01,
                         -4.47432965e-01,  -4.44584906e-01,  -4.41736877e-01,
                         -4.38888848e-01,  -4.35924560e-01,  -4.33018386e-01,
                         -4.30112213e-01,  -4.27089810e-01,  -4.24183637e-01,
                         -4.21393722e-01,  -4.18371320e-01,  -4.15232658e-01,
                         -4.12268370e-01,  -4.09362227e-01,  -4.06281680e-01,
                         -4.03201133e-01,  -4.00120616e-01,  -3.97156328e-01,
                         -3.94075781e-01,  -3.90704632e-01,  -3.87682229e-01,
                         -3.84659827e-01,  -3.81346792e-01,  -3.78324389e-01,
                         -3.75069469e-01,  -3.71814579e-01,  -3.68792176e-01,
                         -3.65595400e-01,  -3.62282366e-01,  -3.59085590e-01,
                         -3.55888814e-01,  -3.52692038e-01,  -3.49379003e-01,
                         -3.46182227e-01,  -3.42869192e-01,  -3.39439929e-01,
                         -3.36068779e-01,  -3.32755744e-01,  -3.29442710e-01,
                         -3.26129675e-01,  -3.22758526e-01,  -3.19387376e-01,
                         -3.16132486e-01,  -3.12645078e-01,  -3.09215814e-01,
                         -3.05786550e-01,  -3.02182913e-01,  -2.98811734e-01,
                         -2.95382470e-01,  -2.91778833e-01,  -2.88291425e-01,
                         -2.84629673e-01,  -2.81142265e-01,  -2.77771115e-01,
                         -2.74051219e-01,  -2.70563841e-01,  -2.67076433e-01,
                         -2.63240308e-01,  -2.59752899e-01,  -2.56323636e-01,
                         -2.52661884e-01,  -2.49116346e-01,  -2.45338336e-01,
                         -2.41618454e-01,  -2.38072932e-01,  -2.34411165e-01,
                         -2.30749398e-01,  -2.27029502e-01,  -2.23019004e-01,
                         -2.19357237e-01,  -2.15753585e-01,  -2.11917460e-01,
                         -2.08255693e-01,  -2.04710171e-01,  -2.01048404e-01,
                         -1.97270393e-01,  -1.93492383e-01,  -1.89830616e-01,
                         -1.86110720e-01,  -1.82274580e-01,  -1.78380325e-01,
                         -1.74544185e-01,  -1.70882419e-01,  -1.67046294e-01,
                         -1.63268268e-01,  -1.59490258e-01,  -1.55712247e-01,
                         -1.51934236e-01,  -1.48039982e-01,  -1.44029468e-01,
                         -1.40251458e-01,  -1.36415318e-01,  -1.32579193e-01,
                         -1.28917426e-01,  -1.25023156e-01,  -1.21070780e-01,
                         -1.17292769e-01,  -1.13398507e-01,  -1.09329879e-01,
                         -1.05551861e-01,  -1.01657607e-01,  -9.75889787e-02,
                         -9.38690901e-02,  -9.01491940e-02,  -8.60224441e-02,
                         -8.20119381e-02,  -7.81176761e-02,  -7.39909261e-02,
                         -7.00966641e-02,  -6.63186535e-02,  -6.22500256e-02,
                         -5.81813976e-02,  -5.42290136e-02,  -5.02766334e-02,
                         -4.62661274e-02,  -4.22556214e-02,  -3.83613594e-02,
                         -3.43508534e-02,  -3.02241016e-02,  -2.63298433e-02,
                         -2.22612135e-02,  -1.81925837e-02,  -1.41820787e-02,
                         -1.01134498e-02,  -6.16106717e-03,  -2.15056119e-03,
                          1.97619130e-03,   5.92857366e-03,   9.99720301e-03,
                          1.38914622e-02,   1.78438444e-02,   2.19124742e-02,
                          2.59229802e-02,   2.98753623e-02,   3.40021141e-02,
                          3.81288677e-02,   4.19068784e-02,   4.60336320e-02,
                          5.01603857e-02,   5.38802743e-02,   5.79489022e-02,
                          6.20175339e-02,   6.59699142e-02,   7.00385422e-02,
                          7.40490481e-02,   7.80595541e-02,   8.20119381e-02,
                          8.59643221e-02,   9.01491940e-02,   9.39853340e-02,
                          9.78214666e-02,   1.01890095e-01,   1.05726235e-01,
                          1.09736741e-01,   1.13863491e-01,   1.17815875e-01,
                          1.21768259e-01,   1.25720635e-01,   1.29673019e-01,
                          1.33625403e-01,   1.37577787e-01,   1.41646415e-01,
                          1.45540670e-01,   1.49376810e-01,   1.53445438e-01,
                          1.57281578e-01,   1.61117718e-01,   1.65128216e-01,
                          1.68964356e-01,   1.72916740e-01,   1.76985368e-01,
                          1.80937752e-01,   1.84715763e-01,   1.88610017e-01,
                          1.92446157e-01,   1.96282297e-01,   2.00292796e-01,
                          2.04128936e-01,   2.07732573e-01,   2.11626843e-01,
                          2.15695471e-01,   2.19473481e-01,   2.23193377e-01,
                          2.27029502e-01,   2.30807513e-01,   2.34527409e-01,
                          2.38305420e-01,   2.42025316e-01,   2.45687082e-01,
                          2.49581337e-01,   2.53301233e-01,   2.56962985e-01,
                          2.60682881e-01,   2.64402777e-01,   2.68064529e-01,
                          2.71610051e-01,   2.75213689e-01,   2.78817356e-01,
                          2.82711595e-01,   2.86257118e-01,   2.89628267e-01,
                          2.93231905e-01,   2.96835572e-01,   3.00264835e-01,
                          3.03868473e-01,   3.07413995e-01,   3.10785145e-01,
                          3.14330667e-01,   3.17701817e-01,   3.21072966e-01,
                          3.24618489e-01,   3.28164011e-01,   3.31477016e-01,
                          3.34790051e-01,   3.38277459e-01,   3.41590464e-01,
                          3.44729125e-01,   3.47925901e-01,   3.51355195e-01,
                          3.54784459e-01,   3.57923120e-01,   3.61178011e-01,
                          3.64491045e-01,   3.67745966e-01,   3.71000856e-01,
                          3.74313891e-01,   3.77510667e-01,   3.80765557e-01,
                          3.83729845e-01,   3.86810392e-01,   3.90065283e-01,
                          3.93262058e-01,   3.96400720e-01,   3.99306893e-01,
                          4.02445555e-01,   4.05642331e-01,   4.08664733e-01,
                          4.11687136e-01,   4.14709568e-01,   4.17615712e-01,
                          4.20696259e-01,   4.23660547e-01,   4.26508576e-01,
                          4.29298490e-01,   4.32088405e-01,   4.34994578e-01,
                          4.37900752e-01,   4.40690666e-01,   4.43538696e-01,
                          4.46386755e-01,   4.49234784e-01,   4.51908439e-01,
                          4.54640239e-01,   4.57255781e-01,   4.59987581e-01,
                          4.62719381e-01,   4.65276808e-01,   4.67892349e-01,
                          4.70449775e-01,   4.73007202e-01,   4.75506514e-01,
                          4.78063911e-01,   4.80563223e-01,   4.83062536e-01,
                          4.85561818e-01,   4.87886757e-01,   4.90211695e-01,
                          4.92710978e-01,   4.95210290e-01,   4.97477084e-01,
                          4.99802023e-01,   5.02126932e-01,   5.04509985e-01,
                          5.06776810e-01,   5.08927405e-01,   5.11310458e-01,
                          5.13519108e-01,   5.15785933e-01,   5.17936468e-01,
                          5.20087063e-01,   5.22353888e-01,   5.24388194e-01,
                          5.26538730e-01,   5.28689265e-01,   5.30607343e-01,
                          5.32699823e-01,   5.34676015e-01,   5.36594033e-01,
                          5.38744628e-01,   5.40604591e-01,   5.42522609e-01,
                          5.44556975e-01,   5.46358764e-01,   5.48393071e-01,
                          5.50136805e-01,   5.51880479e-01,   5.53798556e-01,
                          5.55426002e-01,   5.57285964e-01,   5.59204042e-01,
                          5.60773313e-01,   5.62517047e-01,   5.64318836e-01,
                          5.65946341e-01,   5.67631900e-01,   5.69201231e-01,
                          5.70770562e-01,   5.72456121e-01,   5.74199796e-01,
                          5.75652897e-01,   5.76989710e-01,   5.78617215e-01,
                          5.80012143e-01,   5.81348956e-01,   5.82860172e-01,
                          5.84138870e-01,   5.85359514e-01,   5.86754441e-01,
                          5.88091254e-01,   5.89311898e-01,   5.90706825e-01,
                          5.91927409e-01,   5.93031764e-01,   5.94310462e-01,
                          5.95647335e-01,   5.96809745e-01,   5.98030388e-01,
                          5.99134684e-01,   6.00064695e-01,   6.01168990e-01,
                          6.02157116e-01,   6.03145182e-01,   6.04191422e-01,
                          6.05237663e-01,   6.06109500e-01,   6.06865108e-01,
                          6.07911289e-01,   6.08899415e-01,   6.09771252e-01,
                          6.10643089e-01,   6.11456811e-01,   6.12154305e-01,
                          6.12909913e-01,   6.13781750e-01,   6.14653587e-01,
                          6.15351081e-01,   6.15874231e-01,   6.16513550e-01,
                          6.17269158e-01,   6.18024766e-01,   6.18547857e-01,
                          6.18896604e-01,   6.19594097e-01,   6.20233476e-01,
                          6.20814681e-01,   6.21395946e-01,   6.21860921e-01,
                          6.22384012e-01,   6.22907102e-01,   6.23313963e-01,
                          6.23604596e-01,   6.23953342e-01,   6.24243975e-01,
                          6.24476433e-01,   6.24708951e-01,   6.24941409e-01,
                          6.25348270e-01,   6.25638902e-01,   6.25464559e-01,
                          6.25697017e-01,   6.25929534e-01,   6.25871420e-01,
                          6.26162052e-01,   6.26220167e-01,   6.25987649e-01,
                          6.26045763e-01,   6.25987649e-01,   6.25813305e-01,
                          6.25755191e-01,   6.25638902e-01,   6.25406444e-01,
                          6.25232041e-01,   6.25173926e-01,   6.24941409e-01,
                          6.24592721e-01,   6.24360204e-01,   6.24011457e-01,
                          6.23662710e-01,   6.23372078e-01,   6.22965217e-01,
                          6.22500241e-01,   6.22035265e-01,   6.21570289e-01,
                          6.21221542e-01,   6.20814681e-01,   6.20291591e-01,
                          6.19652212e-01,   6.19187236e-01,   6.18722260e-01,
                          6.18024766e-01,   6.17443562e-01,   6.16804183e-01,
                          6.16164804e-01,   6.15583599e-01,   6.14827991e-01,
                          6.14014268e-01,   6.13316774e-01,   6.12561166e-01,
                          6.11979961e-01,   6.11166239e-01,   6.10119998e-01,
                          6.09364390e-01,   6.08492553e-01,   6.07562602e-01,
                          6.06632590e-01,   6.05528235e-01,   6.04656398e-01,
                          6.03842676e-01,   6.02680206e-01,   6.01459622e-01,
                          6.00355268e-01,   5.99192798e-01,   5.98088503e-01,
                          5.96926033e-01,   5.95705450e-01,   5.94659209e-01,
                          5.93380511e-01,   5.92043638e-01,   5.90706825e-01,
                          5.89311898e-01,   5.88033140e-01,   5.86696327e-01,
                          5.85185111e-01,   5.83790183e-01,   5.82337081e-01,
                          5.80883980e-01,   5.79256535e-01,   5.77570975e-01,
                          5.76175988e-01,   5.74664831e-01,   5.73095500e-01,
                          5.71467996e-01,   5.69666207e-01,   5.68038762e-01,
                          5.66411316e-01,   5.64725697e-01,   5.62982023e-01,
                          5.61122060e-01,   5.59320271e-01,   5.57576537e-01,
                          5.55658519e-01,   5.53856671e-01,   5.52112997e-01,
                          5.50136805e-01,   5.48160613e-01,   5.46300650e-01,
                          5.44440687e-01,   5.42348266e-01,   5.40372074e-01,
                          5.38453996e-01,   5.36477804e-01,   5.34269154e-01,
                          5.32234788e-01,   5.30142367e-01,   5.28108060e-01,
                          5.26131868e-01,   5.23981333e-01,   5.21656394e-01,
                          5.19563913e-01,   5.17471492e-01,   5.15320957e-01,
                          5.13054132e-01,   5.10729194e-01,   5.08462369e-01,
                          5.06137490e-01,   5.03638148e-01,   5.01313210e-01,
                          4.98988301e-01,   4.96721506e-01,   4.94338453e-01,
                          4.91839141e-01,   4.89397973e-01,   4.86956775e-01,
                          4.84573722e-01,   4.82190669e-01,   4.79633242e-01,
                          4.77075815e-01,   4.74460274e-01,   4.71786618e-01,
                          4.69171077e-01,   4.66613650e-01,   4.63939965e-01,
                          4.61150050e-01,   4.58302021e-01,   4.55570221e-01,
                          4.52896535e-01,   4.50397253e-01,   4.47665453e-01,
                          4.44875538e-01,   4.42143738e-01,   4.39179450e-01,
                          4.36505795e-01,   4.33715880e-01,   4.30635333e-01,
                          4.27845418e-01,   4.24997389e-01,   4.21916842e-01,
                          4.19185042e-01,   4.16278899e-01,   4.13256466e-01,
                          4.10524666e-01,   4.07502264e-01,   4.04421747e-01,
                          4.01457459e-01,   3.98551285e-01,   3.95703256e-01,
                          3.92622709e-01,   3.89542192e-01,   3.86694133e-01,
                          3.83555472e-01,   3.80416811e-01,   3.77626896e-01,
                          3.74546379e-01,   3.71465832e-01,   3.68443429e-01,
                          3.65304768e-01,   3.62224251e-01,   3.59027445e-01,
                          3.55888814e-01,   3.52866381e-01,   3.49611491e-01,
                          3.46356601e-01,   3.43392313e-01,   3.40311766e-01,
                          3.37231219e-01,   3.33976328e-01,   3.30605179e-01,
                          3.27408403e-01,   3.24211627e-01,   3.21014851e-01,
                          3.17934304e-01,   3.14679414e-01,   3.11250120e-01,
                          3.07995230e-01,   3.04798454e-01,   3.01543534e-01,
                          2.98230529e-01,   2.94975609e-01,   2.91662574e-01,
                          2.88407683e-01,   2.85036534e-01,   2.81491011e-01,
                          2.78236121e-01,   2.74981201e-01,   2.71551937e-01,
                          2.68064529e-01,   2.64460891e-01,   2.61089742e-01,
                          2.57834852e-01,   2.54696190e-01,   2.51383156e-01,
                          2.47837633e-01,   2.44408369e-01,   2.41037220e-01,
                          2.37549812e-01,   2.34353036e-01,   2.30923772e-01,
                          2.27320120e-01,   2.24065214e-01,   2.20577821e-01,
                          2.17148542e-01,   2.13893652e-01,   2.10580617e-01,
                          2.07093224e-01,   2.03605831e-01,   2.00292796e-01,
                          1.96863532e-01,   1.93492383e-01,   1.90237477e-01,
                          1.86808199e-01,   1.83204561e-01,   1.79775283e-01,
                          1.76404133e-01,   1.72974855e-01,   1.69545591e-01,
                          1.66232556e-01,   1.62977666e-01,   1.59548387e-01,
                          1.55944750e-01,   1.52515471e-01,   1.49260566e-01,
                          1.45947546e-01,   1.42460138e-01,   1.39147118e-01,
                          1.35717839e-01,   1.32114202e-01,   1.28801167e-01,
                          1.25488147e-01,   1.22116998e-01,   1.18745849e-01,
                          1.15200326e-01,   1.11712933e-01,   1.08341783e-01,
                          1.04912512e-01,   1.01541355e-01,   9.80539620e-02,
                          9.44503173e-02,   9.10791680e-02,   8.77080187e-02,
                          8.41625035e-02,   8.07913467e-02,   7.75364488e-02,
                          7.40490481e-02,   7.05035329e-02,   6.70742542e-02,
                          6.37031049e-02,   6.04482032e-02,   5.70189320e-02,
                          5.34734130e-02,   5.01022600e-02,   4.67892364e-02,
                          4.32437137e-02,   3.98725644e-02,   3.65595408e-02,
                          3.31883878e-02,   2.97591165e-02,   2.61554737e-02,
                          2.28424463e-02,   1.97037905e-02,   1.62745174e-02,
                          1.29614901e-02,   9.64846369e-03,   6.16106717e-03,
                          2.96428683e-03,  -4.06862906e-04,  -3.83613608e-03,
                         -7.03291595e-03,  -1.04040662e-02,  -1.37170926e-02,
                         -1.69719961e-02,  -2.04012692e-02,  -2.36561727e-02,
                         -2.69110762e-02,  -3.02822255e-02,  -3.34208831e-02,
                         -3.66757847e-02,  -3.99888121e-02,  -4.31274697e-02,
                         -4.63823713e-02,  -4.97535206e-02,  -5.30084260e-02,
                         -5.63214533e-02,  -5.95763549e-02,  -6.28312603e-02,
                         -6.60861582e-02,  -6.93410635e-02,  -7.26540908e-02,
                         -7.59089962e-02,  -7.91057721e-02,  -8.23025554e-02,
                         -8.56155828e-02,  -8.89286101e-02,  -9.21835080e-02,
                         -9.53802913e-02,  -9.86933187e-02,  -1.02064468e-01,
                         -1.05319373e-01,  -1.08574271e-01,  -1.11712933e-01,
                         -1.14909708e-01,  -1.18397109e-01,  -1.21710137e-01,
                         -1.24732547e-01,  -1.27987444e-01,  -1.31184235e-01,
                         -1.34322882e-01,  -1.37635916e-01,  -1.40716448e-01,
                         -1.43855095e-01,  -1.47168130e-01,  -1.50190532e-01,
                         -1.53329194e-01,  -1.56525970e-01,  -1.59722760e-01,
                         -1.62977666e-01,  -1.66058198e-01,  -1.69138730e-01,
                         -1.72103018e-01,  -1.75183550e-01,  -1.78438455e-01,
                         -1.81635231e-01,  -1.84657633e-01,  -1.87621921e-01,
                         -1.90644339e-01,  -1.93724871e-01,  -1.96689159e-01,
                         -1.99769691e-01,  -2.02908352e-01,  -2.05930755e-01,
                         -2.08895043e-01,  -2.11859331e-01,  -2.14823619e-01,
                         -2.17846036e-01,  -2.20868438e-01,  -2.23832726e-01,
                         -2.26797014e-01,  -2.29935676e-01,  -2.32725590e-01,
                         -2.35573635e-01,  -2.38712281e-01,  -2.41618454e-01,
                         -2.44640857e-01,  -2.47779518e-01,  -2.50569433e-01,
                         -2.53475606e-01,  -2.56498009e-01,  -2.59404182e-01,
                         -2.62368470e-01,  -2.65216500e-01,  -2.68180788e-01,
                         -2.71203190e-01,  -2.74051219e-01,  -2.76841164e-01,
                         -2.79805452e-01,  -2.82711595e-01,  -2.85559654e-01,
                         -2.88349569e-01,  -2.91197598e-01,  -2.94161886e-01,
                         -2.97009915e-01,  -2.99741715e-01,  -3.02473515e-01,
                         -3.05263430e-01,  -3.07937115e-01,  -3.10785145e-01,
                         -3.13691318e-01,  -3.16423088e-01,  -3.19154888e-01,
                         -3.21828574e-01,  -3.24618489e-01,  -3.27408403e-01,
                         -3.30198318e-01,  -3.32871974e-01,  -3.35429400e-01,
                         -3.37986827e-01,  -3.40544254e-01,  -3.43276054e-01,
                         -3.45891595e-01,  -3.48332763e-01,  -3.50948334e-01,
                         -3.53621989e-01,  -3.56005043e-01,  -3.58446240e-01,
                         -3.61061782e-01,  -3.63619208e-01,  -3.66176635e-01,
                         -3.68617803e-01,  -3.71000856e-01,  -3.73558283e-01,
                         -3.75999451e-01,  -3.78440619e-01,  -3.81056190e-01,
                         -3.83381099e-01,  -3.85589808e-01,  -3.88030976e-01,
                         -3.90355915e-01,  -3.92738968e-01,  -3.95122021e-01,
                         -3.97505075e-01,  -3.99771869e-01,  -4.02038693e-01,
                         -4.04421747e-01,  -4.06688541e-01,  -4.08955365e-01,
                         -4.11396533e-01,  -4.13547099e-01,  -4.15813893e-01,
                         -4.18255061e-01,  -4.20463771e-01,  -4.22672451e-01,
                         -4.24881130e-01,  -4.27147925e-01,  -4.29240376e-01,
                         -4.31390941e-01,  -4.33715880e-01,  -4.35808301e-01,
                         -4.37958866e-01,  -4.40051317e-01,  -4.42027479e-01,
                         -4.44294304e-01,  -4.46328610e-01,  -4.48246688e-01,
                         -4.50280994e-01,  -4.52257186e-01,  -4.54349637e-01,
                         -4.56325829e-01,  -4.58360136e-01,  -4.60452586e-01,
                         -4.62254405e-01,  -4.64172453e-01,  -4.66090530e-01,
                         -4.67892349e-01,  -4.69810426e-01,  -4.71437871e-01,
                         -4.73123431e-01,  -4.75041509e-01,  -4.76901472e-01,
                         -4.78703290e-01,  -4.80330735e-01,  -4.81958181e-01,
                         -4.83643770e-01,  -4.85271215e-01,  -4.87014920e-01,
                         -4.88526106e-01,  -4.90095437e-01,  -4.91897255e-01,
                         -4.93408471e-01,  -4.94861543e-01,  -4.96488988e-01,
                         -4.98116463e-01,  -4.99627650e-01,  -5.01022637e-01,
                         -5.02359450e-01,  -5.03870666e-01,  -5.05265594e-01,
                         -5.06660581e-01,  -5.08171797e-01,  -5.09508610e-01,
                         -5.10903597e-01,  -5.12472928e-01,  -5.13809741e-01,
                         -5.15088439e-01,  -5.16541541e-01,  -5.17936468e-01,
                         -5.19215226e-01,  -5.20377696e-01,  -5.21598279e-01,
                         -5.23109436e-01,  -5.24271905e-01,  -5.25376260e-01,
                         -5.26538730e-01,  -5.27701199e-01,  -5.28805554e-01,
                         -5.30142367e-01,  -5.31304836e-01,  -5.32292962e-01,
                         -5.33339143e-01,  -5.34676015e-01,  -5.35722196e-01,
                         -5.36652207e-01,  -5.37756503e-01,  -5.38628399e-01,
                         -5.39558351e-01,  -5.40604591e-01,  -5.41360140e-01,
                         -5.42348266e-01,  -5.43161988e-01,  -5.43859482e-01,
                         -5.44847548e-01,  -5.45661271e-01,  -5.46358764e-01,
                         -5.47056258e-01,  -5.47695577e-01,  -5.48451185e-01,
                         -5.49206793e-01,  -5.49846172e-01,  -5.50601780e-01,
                         -5.51066756e-01,  -5.51589847e-01,  -5.52287340e-01,
                         -5.52752316e-01,  -5.53333580e-01,  -5.53856671e-01,
                         -5.54321647e-01,  -5.54786623e-01,  -5.55367887e-01,
                         -5.55890977e-01,  -5.56123495e-01,  -5.56414068e-01,
                         -5.56762815e-01,  -5.57053447e-01,  -5.57518423e-01,
                         -5.57867169e-01,  -5.57983398e-01,  -5.58390260e-01,
                         -5.58564663e-01,  -5.58797121e-01,  -5.59145868e-01,
                         -5.59320271e-01,  -5.59436500e-01,  -5.59727132e-01,
                         -5.59843361e-01,  -5.59843361e-01,  -5.60075879e-01,
                         -5.60308337e-01,  -5.60424626e-01,  -5.60657084e-01,
                         -5.60773313e-01,  -5.60540855e-01,  -5.60540855e-01,
                         -5.60715199e-01,  -5.60424626e-01,  -5.60308337e-01,
                         -5.60482740e-01,  -5.60482740e-01,  -5.60366452e-01,
                         -5.60250223e-01,  -5.60017765e-01,  -5.59785247e-01,
                         -5.59552729e-01,  -5.59320271e-01,  -5.59087753e-01,
                         -5.58797121e-01,  -5.58680892e-01,  -5.58274031e-01,
                         -5.57809055e-01,  -5.57518423e-01,  -5.56995332e-01,
                         -5.56588471e-01,  -5.56181610e-01,  -5.55658519e-01,
                         -5.55309772e-01,  -5.54786623e-01,  -5.54147303e-01,
                         -5.53624153e-01,  -5.53042948e-01,  -5.52577972e-01,
                         -5.51938593e-01,  -5.51124871e-01,  -5.50485551e-01,
                         -5.49846172e-01,  -5.49264908e-01,  -5.48683703e-01,
                         -5.47579348e-01,  -5.46707511e-01,  -5.46126306e-01,
                         -5.45254409e-01,  -5.44382572e-01,  -5.43568850e-01,
                         -5.42697012e-01,  -5.41883290e-01,  -5.40895164e-01,
                         -5.39907098e-01,  -5.39035261e-01,  -5.38279653e-01,
                         -5.37349641e-01,  -5.36303461e-01,  -5.35199106e-01,
                         -5.34152865e-01,  -5.33222914e-01,  -5.32176673e-01,
                         -5.31014204e-01,  -5.29909909e-01,  -5.28805554e-01,
                         -5.27701199e-01,  -5.26480615e-01,  -5.25143802e-01,
                         -5.23981333e-01,  -5.22876978e-01,  -5.21598279e-01,
                         -5.20261407e-01,  -5.19098938e-01,  -5.17820239e-01,
                         -5.16425312e-01,  -5.15262842e-01,  -5.13925970e-01,
                         -5.12531042e-01,  -5.11310458e-01,  -5.09624839e-01,
                         -5.08055508e-01,  -5.06776810e-01,  -5.05207479e-01,
                         -5.03754437e-01,  -5.02359450e-01,  -5.00673890e-01,
                         -4.99046415e-01,  -4.97477084e-01,  -4.95965898e-01,
                         -4.94222194e-01,  -4.92536604e-01,  -4.91083533e-01,
                         -4.89281714e-01,  -4.87421781e-01,  -4.85619962e-01,
                         -4.84050632e-01,  -4.82365042e-01,  -4.80388850e-01,
                         -4.78470773e-01,  -4.76668954e-01,  -4.74750906e-01,
                         -4.73007202e-01,  -4.71205384e-01,  -4.69229192e-01,
                         -4.67311114e-01,  -4.65276808e-01,  -4.63242501e-01,
                         -4.61382538e-01,  -4.59406346e-01,  -4.57255781e-01,
                         -4.55395848e-01,  -4.53419656e-01,  -4.51269090e-01,
                         -4.49234784e-01,  -4.47142333e-01,  -4.45049912e-01,
                         -4.43073720e-01,  -4.40806895e-01,  -4.38656330e-01,
                         -4.36622024e-01,  -4.34471458e-01,  -4.32262778e-01,
                         -4.29995984e-01,  -4.27845418e-01,  -4.25694853e-01,
                         -4.23311800e-01,  -4.20986861e-01,  -4.18894440e-01,
                         -4.16627616e-01,  -4.14302707e-01,  -4.11977768e-01,
                         -4.09652829e-01,  -4.07327890e-01,  -4.04944837e-01,
                         -4.02561784e-01,  -4.00236875e-01,  -3.97853792e-01,
                         -3.95296395e-01,  -3.92971456e-01,  -3.90646517e-01,
                         -3.87972862e-01,  -3.85473549e-01,  -3.83090496e-01,
                         -3.80358696e-01,  -3.77859414e-01,  -3.75418216e-01,
                         -3.72744560e-01,  -3.70245248e-01,  -3.67455333e-01,
                         -3.64723533e-01,  -3.62340480e-01,  -3.59608680e-01,
                         -3.56702536e-01,  -3.54086995e-01,  -3.51413310e-01,
                         -3.48681509e-01,  -3.45833480e-01,  -3.43043566e-01,
                         -3.40428025e-01,  -3.37754339e-01,  -3.35138798e-01,
                         -3.32174510e-01,  -3.29152107e-01,  -3.26536536e-01,
                         -3.23746622e-01,  -3.20724219e-01,  -3.17818046e-01,
                         -3.15028131e-01,  -3.12180102e-01,  -3.09390187e-01,
                         -3.06542158e-01,  -3.03577870e-01,  -3.00555438e-01,
                         -2.97707409e-01,  -2.94859380e-01,  -2.91895092e-01,
                         -2.88988918e-01,  -2.85966516e-01,  -2.83060342e-01,
                         -2.80212313e-01,  -2.77131766e-01,  -2.74225593e-01,
                         -2.71261305e-01,  -2.68180788e-01,  -2.65274614e-01,
                         -2.62135953e-01,  -2.59055436e-01,  -2.56207377e-01,
                         -2.53068745e-01,  -2.49813825e-01,  -2.46849537e-01,
                         -2.43827134e-01,  -2.40688473e-01,  -2.37607941e-01,
                         -2.34527409e-01,  -2.31330633e-01,  -2.28075728e-01,
                         -2.24995196e-01,  -2.21856534e-01,  -2.18601629e-01,
                         -2.15404853e-01,  -2.12208077e-01,  -2.09011286e-01,
                         -2.05698267e-01,  -2.02501491e-01,  -1.99304700e-01,
                         -1.95991680e-01,  -1.92794904e-01,  -1.89423755e-01,
                         -1.86226964e-01,  -1.82913944e-01,  -1.79484665e-01,
                         -1.76171646e-01,  -1.72858611e-01,  -1.69429347e-01,
                         -1.66348815e-01,  -1.63035780e-01,  -1.59490258e-01,
                         -1.56177238e-01,  -1.52747959e-01,  -1.49376810e-01,
                         -1.46063790e-01,  -1.42518267e-01,  -1.39205247e-01,
                         -1.35892212e-01,  -1.32404819e-01,  -1.29033670e-01,
                         -1.25662521e-01,  -1.22291364e-01,  -1.18978344e-01,
                         -1.15490943e-01,  -1.12177916e-01,  -1.08864889e-01,
                         -1.05203122e-01,  -1.01948224e-01,  -9.84608233e-02,
                         -9.48571786e-02,  -9.14860293e-02,  -8.79986361e-02,
                         -8.45693648e-02,  -8.11400861e-02,  -7.76526928e-02,
                         -7.43977875e-02,  -7.09103942e-02,  -6.72486275e-02,
                         -6.38193563e-02,  -6.03319593e-02,  -5.68445623e-02,
                         -5.32990433e-02,  -4.97535206e-02,  -4.64404970e-02,
                         -4.28368524e-02,  -3.92332077e-02,  -3.58039364e-02,
                         -3.23165394e-02,  -2.87128966e-02,  -2.52836235e-02,
                         -2.17381045e-02,  -1.82507075e-02,  -1.48214344e-02,
                         -1.13340383e-02,  -7.78851844e-03,  -4.30112239e-03,
                         -6.39356032e-04,   2.84804031e-03,   6.45168312e-03,
                          1.00553259e-02,   1.34845991e-02,   1.71463657e-02,
                          2.08662543e-02,   2.42374055e-02,   2.78991722e-02,
                          3.16190608e-02,   3.51645797e-02,   3.86519767e-02,
                          4.21393737e-02,   4.56267707e-02,   4.92304116e-02,
                          5.27759306e-02,   5.61470836e-02,   5.97507246e-02,
                          6.34706169e-02,   6.67836443e-02,   7.03872815e-02,
                          7.40490481e-02,   7.73620754e-02,   8.09075981e-02,
                          8.45112428e-02,   8.78242627e-02,   9.13697854e-02,
                          9.49734300e-02,   9.82864574e-02,   1.01831973e-01,
                          1.05261251e-01,   1.08574271e-01,   1.12177916e-01,
                          1.15607187e-01,   1.18920214e-01,   1.22465737e-01,
                          1.25895008e-01,   1.29324287e-01,   1.32869810e-01,
                          1.36124700e-01,   1.39553979e-01,   1.43157616e-01,
                          1.46528766e-01,   1.49958044e-01,   1.53387323e-01,
                          1.56700343e-01,   1.60129622e-01,   1.63384527e-01,
                          1.66697547e-01,   1.70126826e-01,   1.73439845e-01,
                          1.76869124e-01,   1.80356517e-01,   1.83669537e-01,
                          1.86924443e-01,   1.90179348e-01,   1.93492383e-01,
                          1.96805403e-01,   2.00060308e-01,   2.03431457e-01,
                          2.06744477e-01,   2.09941268e-01,   2.13196173e-01,
                          2.16567323e-01,   2.19880342e-01,   2.23193377e-01,
                          2.26390153e-01,   2.29470685e-01,   2.32725590e-01,
                          2.35806122e-01,   2.38886654e-01,   2.42025316e-01,
                          2.45222092e-01,   2.48476997e-01,   2.51673788e-01,
                          2.54754305e-01,   2.57660478e-01,   2.60740995e-01,
                          2.63995916e-01,   2.67076433e-01,   2.70040721e-01,
                          2.73005009e-01,   2.75969297e-01,   2.79166073e-01,
                          2.82072246e-01,   2.84978420e-01,   2.88000822e-01,
                          2.90848851e-01,   2.93871284e-01,   2.96835572e-01,
                          2.99625486e-01,   3.02473515e-01,   3.05263430e-01,
                          3.08169603e-01,   3.10959518e-01,   3.13633174e-01,
                          3.16655606e-01,   3.19561750e-01,   3.22293550e-01,
                          3.25199723e-01,   3.27873379e-01,   3.30663294e-01,
                          3.33511353e-01,   3.36126894e-01,   3.38858694e-01,
                          3.41532350e-01,   3.44322264e-01,   3.47054064e-01,
                          3.49320859e-01,   3.51994544e-01,   3.54900718e-01,
                          3.57341886e-01,   3.59957427e-01,   3.62631112e-01,
                          3.65130395e-01,   3.67629707e-01,   3.70187134e-01,
                          3.72744560e-01,   3.75185728e-01,   3.77743155e-01,
                          3.80184323e-01,   3.82509261e-01,   3.85066688e-01,
                          3.87449741e-01,   3.89832795e-01,   3.92273962e-01,
                          3.94657016e-01,   3.97156328e-01,   3.99481267e-01,
                          4.01689947e-01,   4.04131114e-01,   4.06339794e-01,
                          4.08664733e-01,   4.11105901e-01,   4.13023978e-01,
                          4.15232658e-01,   4.17557597e-01,   4.19417530e-01,
                          4.21684355e-01,   4.24009293e-01,   4.26043600e-01,
                          4.28194165e-01,   4.30228472e-01,   4.32146549e-01,
                          4.34297085e-01,   4.36389536e-01,   4.38191354e-01,
                          4.40283805e-01,   4.42434371e-01,   4.44294304e-01,
                          4.46154237e-01,   4.48130429e-01,   4.49990392e-01,
                          4.51792210e-01,   4.53768402e-01,   4.55686450e-01,
                          4.57430154e-01,   4.59290117e-01,   4.61091936e-01,
                          4.62893754e-01,   4.64695573e-01,   4.66497391e-01,
                          4.68241096e-01,   4.69868541e-01,   4.71612245e-01,
                          4.73239690e-01,   4.74867135e-01,   4.76552725e-01,
                          4.78180170e-01,   4.79865760e-01,   4.81493205e-01,
                          4.83004391e-01,   4.84515607e-01,   4.86143053e-01,
                          4.87770498e-01,   4.89281714e-01,   4.90792930e-01,
                          4.92246002e-01,   4.93524700e-01,   4.95152175e-01,
                          4.96547133e-01,   4.97825831e-01,   4.99337047e-01,
                          5.00673890e-01,   5.01894474e-01,   5.03405690e-01,
                          5.04742503e-01,   5.05963087e-01,   5.07241786e-01,
                          5.08462369e-01,   5.09508610e-01,   5.10671079e-01,
                          5.11891663e-01,   5.12937903e-01,   5.14274716e-01,
                          5.15611529e-01,   5.16541541e-01,   5.17471492e-01,
                          5.18459618e-01,   5.19505799e-01,   5.20668268e-01,
                          5.21598279e-01,   5.22586346e-01,   5.23574471e-01,
                          5.24446309e-01,   5.25318146e-01,   5.26364386e-01,
                          5.27236223e-01,   5.27991831e-01,   5.28747439e-01,
                          5.29503047e-01,   5.30258596e-01,   5.31130493e-01,
                          5.32002330e-01,   5.32699823e-01,   5.33339143e-01,
                          5.33978522e-01,   5.34676015e-01,   5.35431623e-01,
                          5.35954714e-01,   5.36652207e-01,   5.37349641e-01,
                          5.37698388e-01,   5.38337767e-01,   5.39093375e-01,
                          5.39558351e-01,   5.40139556e-01,   5.40546417e-01,
                          5.40778935e-01,   5.41418314e-01,   5.41825175e-01,
                          5.42173922e-01,   5.42697012e-01,   5.42987645e-01,
                          5.43161988e-01,   5.43510735e-01,   5.43626964e-01,
                          5.43975711e-01,   5.44324458e-01,   5.44440687e-01,
                          5.44673204e-01,   5.44905663e-01,   5.44847548e-01,
                          5.45080066e-01,   5.45370698e-01,   5.45312524e-01,
                          5.45196295e-01,   5.45312524e-01,   5.45312524e-01,
                          5.45254409e-01,   5.45196295e-01,   5.45080066e-01,
                          5.45021951e-01,   5.45080066e-01,   5.44905663e-01,
                          5.44673204e-01,   5.44324458e-01,   5.44091940e-01,
                          5.44033825e-01,   5.43743193e-01,   5.43394506e-01,
                          5.43220103e-01,   5.42987645e-01,   5.42638898e-01,
                          5.42348266e-01,   5.41941404e-01,   5.41592658e-01,
                          5.41069567e-01,   5.40546417e-01,   5.40197730e-01,
                          5.39674580e-01,   5.38860857e-01,   5.38337767e-01,
                          5.38047135e-01,   5.37407815e-01,   5.36652207e-01,
                          5.36187172e-01,   5.35547853e-01,   5.34676015e-01,
                          5.34094751e-01,   5.33455431e-01,   5.32641649e-01,
                          5.32060444e-01,   5.31246722e-01,   5.30374885e-01,
                          5.29677391e-01,   5.28747439e-01,   5.27875543e-01,
                          5.27178109e-01,   5.26189983e-01,   5.25085628e-01,
                          5.24097562e-01,   5.23283839e-01,   5.22237599e-01,
                          5.21191418e-01,   5.20261407e-01,   5.19215226e-01,
                          5.17936468e-01,   5.16832173e-01,   5.15844047e-01,
                          5.14681578e-01,   5.13519108e-01,   5.12414753e-01,
                          5.11019826e-01,   5.09741127e-01,   5.08462369e-01,
                          5.07299960e-01,   5.06195605e-01,   5.04626274e-01,
                          5.03231287e-01,   5.01894474e-01,   5.00441372e-01,
                          4.99220788e-01,   4.97709602e-01,   4.96140271e-01,
                          4.94687170e-01,   4.92943496e-01,   4.91316020e-01,
                          4.89746690e-01,   4.88235503e-01,   4.86724287e-01,
                          4.85038728e-01,   4.83585626e-01,   4.81900066e-01,
                          4.80156362e-01,   4.78645146e-01,   4.76785213e-01,
                          4.75157768e-01,   4.73530322e-01,   4.71379757e-01,
                          4.69636053e-01,   4.67892349e-01,   4.66090530e-01,
                          4.64463085e-01,   4.62428749e-01,   4.60394442e-01,
                          4.58476394e-01,   4.56500202e-01,   4.54640239e-01,
                          4.52722162e-01,   4.50687855e-01,   4.48769808e-01,
                          4.46793616e-01,   4.44643050e-01,   4.42550600e-01,
                          4.40458179e-01,   4.38423842e-01,   4.36447650e-01,
                          4.34238970e-01,   4.32088405e-01,   4.29937840e-01,
                          4.27729160e-01,   4.25520480e-01,   4.23311800e-01,
                          4.21045005e-01,   4.18778181e-01,   4.16685760e-01,
                          4.14477050e-01,   4.12093997e-01,   4.09943461e-01,
                          4.07618523e-01,   4.05293584e-01,   4.02910531e-01,
                          4.00527477e-01,   3.98202538e-01,   3.95761371e-01,
                          3.93494546e-01,   3.91111493e-01,   3.88554096e-01,
                          3.86054784e-01,   3.83555472e-01,   3.81230563e-01,
                          3.78614992e-01,   3.75999451e-01,   3.73500168e-01,
                          3.70710224e-01,   3.68152827e-01,   3.65769774e-01,
                          3.63212347e-01,   3.60713035e-01,   3.57981235e-01,
                          3.55423808e-01,   3.52866381e-01,   3.50134611e-01,
                          3.47693413e-01,   3.45019758e-01,   3.42055470e-01,
                          3.39498043e-01,   3.36998731e-01,   3.34208816e-01,
                          3.31418902e-01,   3.28628987e-01,   3.25897187e-01,
                          3.23165387e-01,   3.20317358e-01,   3.17469329e-01,
                          3.14795643e-01,   3.12121987e-01,   3.09332073e-01,
                          3.06425899e-01,   3.03403497e-01,   3.00729811e-01,
                          2.98114270e-01,   2.95266241e-01,   2.92418182e-01,
                          2.89628267e-01,   2.86722094e-01,   2.83757836e-01,
                          2.80909777e-01,   2.78352350e-01,   2.75446206e-01,
                          2.72423774e-01,   2.69633859e-01,   2.66727716e-01,
                          2.63879657e-01,   2.61089742e-01,   2.58067340e-01,
                          2.55044937e-01,   2.52138764e-01,   2.49232590e-01,
                          2.46442676e-01,   2.43594632e-01,   2.40630358e-01,
                          2.37607941e-01,   2.34643653e-01,   2.31737494e-01,
                          2.28773206e-01,   2.25925162e-01,   2.23019004e-01,
                          2.19880342e-01,   2.17032298e-01,   2.13893652e-01,
                          2.10813120e-01,   2.08023190e-01,   2.04884544e-01,
                          2.01862127e-01,   1.99014083e-01,   1.95759192e-01,
                          1.92736775e-01,   1.89830616e-01,   1.86982572e-01,
                          1.84018284e-01,   1.80647135e-01,   1.77682847e-01,
                          1.74660429e-01,   1.71638027e-01,   1.68789983e-01,
                          1.65651336e-01,   1.62687048e-01,   1.59780875e-01,
                          1.56758472e-01,   1.53677940e-01,   1.50597408e-01,
                          1.47749364e-01,   1.44843191e-01,   1.41704544e-01,
                          1.38740256e-01,   1.35601595e-01,   1.32637307e-01,
                          1.29614905e-01,   1.26592487e-01,   1.23860694e-01,
                          1.20954528e-01,   1.17815875e-01,   1.14851587e-01,
                          1.11945428e-01,   1.08923018e-01,   1.05900601e-01,
                          1.02878191e-01,   9.99720320e-02,   9.71239880e-02,
                          9.41597000e-02,   9.10791680e-02,   8.82311314e-02,
                          8.53249654e-02,   8.22444335e-02,   7.92220235e-02,
                          7.61414915e-02,   7.31772035e-02,   7.02710375e-02,
                          6.73648715e-02,   6.44005835e-02,   6.13200553e-02,
                          5.84720112e-02,   5.56239709e-02,   5.26015610e-02,
                          4.97535206e-02,   4.68473583e-02,   4.38249484e-02,
                          4.09187861e-02,   3.78963761e-02,   3.49320881e-02,
                          3.20259221e-02,   2.90616360e-02,   2.61554737e-02,
                          2.33074334e-02,   2.03431454e-02,   1.73207354e-02,
                          1.44145722e-02,   1.15665318e-02,   8.71849060e-03,
                          5.75420400e-03,   2.78991717e-03,  -1.74369823e-04,
                         -3.08053358e-03,  -5.98669704e-03,  -8.77661444e-03,
                         -1.16246548e-02,  -1.45308180e-02,  -1.73207354e-02,
                         -2.01687757e-02,  -2.31911857e-02,  -2.59811040e-02,
                         -2.88291443e-02,  -3.17353085e-02,  -3.45252231e-02,
                         -3.73732634e-02,  -4.02213037e-02,  -4.30693440e-02,
                         -4.59173843e-02,  -4.85910550e-02,  -5.14390953e-02,
                         -5.42290136e-02,  -5.69026843e-02,  -5.95763549e-02,
                         -6.23662733e-02,  -6.52724355e-02,  -6.80042282e-02,
                         -7.07360208e-02,  -7.35840648e-02,  -7.61996135e-02,
                         -7.90476501e-02,  -8.19538161e-02,  -8.45693648e-02,
                         -8.72430354e-02,  -8.99748281e-02,  -9.26484987e-02,
                         -9.54384133e-02,  -9.82283354e-02,  -1.00960128e-01,
                         -1.03691921e-01,  -1.06365591e-01,  -1.08923018e-01,
                         -1.11712933e-01,  -1.14502847e-01,  -1.17060274e-01,
                         -1.19908310e-01,  -1.22756355e-01,  -1.25255659e-01,
                         -1.28045574e-01,  -1.30777359e-01,  -1.33276671e-01,
                         -1.36066586e-01,  -1.38624012e-01,  -1.41355798e-01,
                         -1.44087598e-01,  -1.46528766e-01,  -1.49318695e-01,
                         -1.51876107e-01,  -1.54491663e-01,  -1.57223448e-01,
                         -1.59664631e-01,  -1.62338302e-01,  -1.64953843e-01,
                         -1.67511269e-01,  -1.70243070e-01,  -1.72800496e-01,
                         -1.75357923e-01,  -1.77973464e-01,  -1.80414647e-01,
                         -1.83030188e-01,  -1.85703859e-01,  -1.88203156e-01,
                         -1.90586209e-01,  -1.93259880e-01,  -1.96107924e-01,
                         -1.98374733e-01,  -2.00757787e-01,  -2.03373328e-01,
                         -2.05930755e-01,  -2.08255693e-01,  -2.10522503e-01,
                         -2.13079914e-01,  -2.15695471e-01,  -2.17962280e-01,
                         -2.20461577e-01,  -2.22786501e-01,  -2.25285813e-01,
                         -2.27843225e-01,  -2.30051920e-01,  -2.32493088e-01,
                         -2.34934270e-01,  -2.37201080e-01,  -2.39700377e-01,
                         -2.42083430e-01,  -2.44350240e-01,  -2.46617049e-01,
                         -2.48941973e-01,  -2.51150668e-01,  -2.53417462e-01,
                         -2.55916774e-01,  -2.58241713e-01,  -2.60508507e-01,
                         -2.62833446e-01,  -2.65042126e-01,  -2.67367065e-01,
                         -2.69750118e-01,  -2.71900684e-01,  -2.74225593e-01,
                         -2.76434302e-01,  -2.78526723e-01,  -2.80793548e-01,
                         -2.82944083e-01,  -2.85269022e-01,  -2.87535846e-01,
                         -2.89570153e-01,  -2.91778833e-01,  -2.93929398e-01,
                         -2.96021819e-01,  -2.98288643e-01,  -3.00322950e-01,
                         -3.02299142e-01,  -3.04391593e-01,  -3.06309640e-01,
                         -3.08518350e-01,  -3.10610771e-01,  -3.12586963e-01,
                         -3.14563155e-01,  -3.16481233e-01,  -3.18631798e-01,
                         -3.20724219e-01,  -3.22526038e-01,  -3.24502230e-01,
                         -3.26420307e-01,  -3.28338385e-01,  -3.30372691e-01,
                         -3.32348883e-01,  -3.34092587e-01,  -3.35836262e-01,
                         -3.37812454e-01,  -3.39788646e-01,  -3.41532350e-01,
                         -3.43450427e-01,  -3.45194131e-01,  -3.46937805e-01,
                         -3.48855883e-01,  -3.50599587e-01,  -3.52401406e-01,
                         -3.54145110e-01,  -3.55888814e-01,  -3.57516259e-01,
                         -3.59085590e-01,  -3.60887408e-01,  -3.62514853e-01,
                         -3.64142299e-01,  -3.65827888e-01,  -3.67513448e-01,
                         -3.69373411e-01,  -3.70768368e-01,  -3.72279555e-01,
                         -3.74081373e-01,  -3.75476360e-01,  -3.77278179e-01,
                         -3.78963739e-01,  -3.80184323e-01,  -3.81811798e-01,
                         -3.83381099e-01,  -3.84892315e-01,  -3.86519760e-01,
                         -3.87914717e-01,  -3.89425933e-01,  -3.90879005e-01,
                         -3.92215848e-01,  -3.93785179e-01,  -3.95180136e-01,
                         -3.96633208e-01,  -3.98144424e-01,  -3.99306893e-01,
                         -4.00643736e-01,  -4.02154922e-01,  -4.03491765e-01,
                         -4.04712349e-01,  -4.06049192e-01,  -4.07386035e-01,
                         -4.08606619e-01,  -4.10001576e-01,  -4.11222160e-01,
                         -4.12442744e-01,  -4.13547099e-01,  -4.14593309e-01,
                         -4.15755779e-01,  -4.16976362e-01,  -4.17906344e-01,
                         -4.19185042e-01,  -4.20347512e-01,  -4.21277493e-01,
                         -4.22439963e-01,  -4.23486173e-01,  -4.24416155e-01,
                         -4.25520480e-01,  -4.26624835e-01,  -4.27671045e-01,
                         -4.28717256e-01,  -4.29647237e-01,  -4.30344731e-01,
                         -4.31274682e-01,  -4.32437152e-01,  -4.33425248e-01,
                         -4.34355229e-01,  -4.35227066e-01,  -4.36157048e-01,
                         -4.37087029e-01,  -4.37842607e-01,  -4.38772589e-01,
                         -4.39818799e-01,  -4.40516293e-01,  -4.41271901e-01,
                         -4.42027479e-01,  -4.42724973e-01,  -4.43538696e-01,
                         -4.44352418e-01,  -4.45049912e-01,  -4.45573002e-01,
                         -4.46270496e-01,  -4.47142333e-01,  -4.47723567e-01,
                         -4.48421061e-01,  -4.49234784e-01,  -4.49583530e-01,
                         -4.50164765e-01,  -4.50862229e-01,  -4.51443464e-01,
                         -4.51908439e-01,  -4.52489674e-01,  -4.53129053e-01,
                         -4.53535914e-01,  -4.54059005e-01,  -4.54698354e-01,
                         -4.54872727e-01,  -4.55221474e-01,  -4.55802709e-01,
                         -4.56151456e-01,  -4.56674546e-01,  -4.57081407e-01,
                         -4.57372040e-01,  -4.57720786e-01,  -4.58069503e-01,
                         -4.58302021e-01,  -4.58418250e-01,  -4.58766997e-01,
                         -4.59057599e-01,  -4.59115744e-01,  -4.59406346e-01,
                         -4.59638834e-01,  -4.59755093e-01,  -4.59987581e-01,
                         -4.60103840e-01,  -4.60220069e-01,  -4.60336328e-01,
                         -4.60452586e-01,  -4.60626930e-01,  -4.60743189e-01,
                         -4.60801303e-01,  -4.60859448e-01,  -4.60975677e-01,
                         -4.61091936e-01,  -4.60975677e-01,  -4.60917562e-01,
                         -4.61033791e-01,  -4.61091936e-01,  -4.60975677e-01,
                         -4.60743189e-01,  -4.60743189e-01,  -4.60859448e-01,
                         -4.60626930e-01,  -4.60568815e-01,  -4.60394442e-01,
                         -4.60103840e-01,  -4.60045695e-01,  -4.59813207e-01,
                         -4.59580719e-01,  -4.59522605e-01,  -4.59464490e-01,
                         -4.59290117e-01,  -4.58825111e-01,  -4.58650738e-01,
                         -4.58476394e-01,  -4.58069503e-01,  -4.57953274e-01,
                         -4.57604527e-01,  -4.57197666e-01,  -4.56790805e-01,
                         -4.56151456e-01,  -4.55860823e-01,  -4.55628335e-01,
                         -4.55105245e-01,  -4.54640239e-01,  -4.54117149e-01,
                         -4.53768402e-01,  -4.53187168e-01,  -4.52664047e-01,
                         -4.52431560e-01,  -4.51734066e-01,  -4.51152861e-01,
                         -4.50746000e-01,  -4.49990392e-01,  -4.49292898e-01,
                         -4.48595434e-01,  -4.47956055e-01,  -4.47374821e-01,
                         -4.46619242e-01,  -4.45747375e-01,  -4.44991767e-01,
                         -4.44468677e-01,  -4.43713069e-01,  -4.42666858e-01,
                         -4.42085624e-01,  -4.41388130e-01,  -4.40458179e-01,
                         -4.39528197e-01,  -4.38772589e-01,  -4.38016981e-01,
                         -4.37028885e-01,  -4.36331421e-01,  -4.35575813e-01,
                         -4.34180856e-01,  -4.33425248e-01,  -4.32553411e-01,
                         -4.31449056e-01,  -4.30635333e-01,  -4.29472864e-01,
                         -4.28601027e-01,  -4.27787304e-01,  -4.26450461e-01,
                         -4.25578594e-01,  -4.24648643e-01,  -4.23428059e-01,
                         -4.22556192e-01,  -4.21509981e-01,  -4.20347512e-01,
                         -4.19359416e-01,  -4.18196946e-01,  -4.17208850e-01,
                         -4.15930152e-01,  -4.14767683e-01,  -4.13547099e-01,
                         -4.12210256e-01,  -4.11105901e-01,  -4.09769088e-01,
                         -4.08664733e-01,  -4.07560378e-01,  -4.05991077e-01,
                         -4.04654235e-01,  -4.03608024e-01,  -4.02271181e-01,
                         -4.00759965e-01,  -3.99365008e-01,  -3.98202538e-01,
                         -3.96865726e-01,  -3.95412624e-01,  -3.94192040e-01,
                         -3.92680824e-01,  -3.91285866e-01,  -3.89890909e-01,
                         -3.88263464e-01,  -3.86926621e-01,  -3.85473549e-01,
                         -3.83962333e-01,  -3.82509261e-01,  -3.80823702e-01,
                         -3.79370600e-01,  -3.77859414e-01,  -3.76290083e-01,
                         -3.74778867e-01,  -3.73151422e-01,  -3.71523976e-01,
                         -3.69954646e-01,  -3.68385315e-01,  -3.66757870e-01,
                         -3.65072280e-01,  -3.63561064e-01,  -3.61933619e-01,
                         -3.60248059e-01,  -3.58794957e-01,  -3.57051283e-01,
                         -3.55191320e-01,  -3.53505760e-01,  -3.51878285e-01,
                         -3.50076467e-01,  -3.48274648e-01,  -3.46589088e-01,
                         -3.44903499e-01,  -3.43217939e-01,  -3.41357976e-01,
                         -3.39498043e-01,  -3.37812454e-01,  -3.36010635e-01,
                         -3.34150702e-01,  -3.32406998e-01,  -3.30488920e-01,
                         -3.28570873e-01,  -3.26710910e-01,  -3.24909091e-01,
                         -3.23165387e-01,  -3.21131080e-01,  -3.18980515e-01,
                         -3.17178696e-01,  -3.15376878e-01,  -3.13516945e-01,
                         -3.11598867e-01,  -3.09564561e-01,  -3.07472110e-01,
                         -3.05379689e-01,  -3.03345352e-01,  -3.01252931e-01,
                         -2.99218625e-01,  -2.97242433e-01,  -2.95033723e-01,
                         -2.92941302e-01,  -2.90790737e-01,  -2.88640171e-01,
                         -2.86663979e-01,  -2.84397185e-01,  -2.82188505e-01,
                         -2.80096054e-01,  -2.77538627e-01,  -2.75329947e-01,
                         -2.73411870e-01,  -2.71086961e-01,  -2.68878251e-01,
                         -2.66669571e-01,  -2.64402777e-01,  -2.62194097e-01,
                         -2.59869158e-01,  -2.57660478e-01,  -2.55335540e-01,
                         -2.52952486e-01,  -2.50801921e-01,  -2.48476997e-01,
                         -2.46035814e-01,  -2.43710890e-01,  -2.41444081e-01,
                         -2.39061028e-01,  -2.36677974e-01,  -2.34527409e-01,
                         -2.32202470e-01,  -2.29761302e-01,  -2.27494493e-01,
                         -2.25111440e-01,  -2.22728387e-01,  -2.20170960e-01,
                         -2.17613533e-01,  -2.15288609e-01,  -2.12847427e-01,
                         -2.10406244e-01,  -2.07848832e-01,  -2.05349520e-01,
                         -2.02966467e-01,  -2.00176552e-01,  -1.97619125e-01,
                         -1.95352316e-01,  -1.92678645e-01,  -1.90121233e-01,
                         -1.87621921e-01,  -1.85064510e-01,  -1.82507083e-01,
                         -1.79717168e-01,  -1.77101612e-01,  -1.74486071e-01,
                         -1.71638027e-01,  -1.69022486e-01,  -1.66290686e-01,
                         -1.63558885e-01,  -1.60885215e-01,  -1.58037186e-01,
                         -1.55363515e-01,  -1.52515471e-01,  -1.49667427e-01,
                         -1.47168130e-01,  -1.44436330e-01,  -1.41472042e-01,
                         -1.38624012e-01,  -1.35950342e-01,  -1.33218542e-01,
                         -1.30254254e-01,  -1.27406210e-01,  -1.24500051e-01,
                         -1.21593885e-01,  -1.18862092e-01,  -1.15897804e-01,
                         -1.13049768e-01,  -1.10143602e-01,  -1.07353687e-01,
                         -1.04621895e-01,  -1.01541355e-01,  -9.86351967e-02,
                         -9.58452746e-02,  -9.27647427e-02,  -8.99167061e-02,
                         -8.69524181e-02,  -8.39881301e-02,  -8.11982155e-02,
                         -7.81176761e-02,  -7.51533955e-02,  -7.24215955e-02,
                         -6.95154369e-02,  -6.65511489e-02,  -6.35287389e-02,
                         -6.07388206e-02,  -5.77164106e-02,  -5.45777529e-02,
                         -5.17878383e-02,  -4.87654246e-02,  -4.57430147e-02,
                         -4.29531001e-02,  -3.98144424e-02,  -3.67920324e-02,
                         -3.38858701e-02,  -3.08634583e-02,  -2.78410483e-02,
                         -2.47605145e-02,  -2.16799807e-02,  -1.85413249e-02,
                         -1.56932846e-02,  -1.29614901e-02,  -9.70658660e-03,
                         -6.56792987e-03,  -3.66176618e-03,  -6.39356032e-04,
                          2.32493086e-03,   5.57983434e-03,   8.60224478e-03,
                          1.13921613e-02,   1.48214344e-02,   1.79600921e-02,
                          2.10406259e-02,   2.44117752e-02,   2.73760613e-02,
                          3.03984713e-02,   3.34790051e-02,   3.65014151e-02,
                          3.96400727e-02,   4.27787304e-02,   4.58011404e-02,
                          4.88235503e-02,   5.20784520e-02,   5.53333573e-02,
                          5.82395196e-02,   6.13781773e-02,   6.44005835e-02,
                          6.74229935e-02,   7.06778988e-02,   7.35840648e-02,
                          7.66645968e-02,   7.97451288e-02,   8.26512948e-02,
                          8.59643221e-02,   8.89286101e-02,   9.17766467e-02,
                          9.49734300e-02,   9.79377180e-02,   1.00960128e-01,
                          1.04040660e-01,   1.07121192e-01,   1.10201724e-01,
                          1.13049768e-01,   1.16072178e-01,   1.19094588e-01,
                          1.21942624e-01,   1.25081286e-01,   1.28161818e-01,
                          1.31009862e-01,   1.33974150e-01,   1.36938438e-01,
                          1.39844596e-01,   1.42750755e-01,   1.45773172e-01,
                          1.48795575e-01,   1.51759863e-01,   1.54782280e-01,
                          1.57630324e-01,   1.60652727e-01,   1.63617015e-01,
                          1.66290686e-01,   1.69313088e-01,   1.72335505e-01,
                          1.75183550e-01,   1.78322196e-01,   1.81112126e-01,
                          1.83960155e-01,   1.86982572e-01,   1.89772487e-01,
                          1.92678645e-01,   1.95759192e-01,   1.98723465e-01,
                          2.01513395e-01,   2.04303309e-01,   2.07325712e-01,
                          2.10173756e-01,   2.12963670e-01,   2.15869844e-01,
                          2.18543515e-01,   2.21507788e-01,   2.24646449e-01,
                          2.27320120e-01,   2.30168164e-01,   2.32958078e-01,
                          2.35573635e-01,   2.38363549e-01,   2.41153464e-01,
                          2.43827134e-01,   2.46500805e-01,   2.49232590e-01,
                          2.51964390e-01,   2.54579931e-01,   2.57253617e-01,
                          2.59811044e-01,   2.62426585e-01,   2.65158385e-01,
                          2.67832041e-01,   2.70389467e-01,   2.72656262e-01,
                          2.75271833e-01,   2.78003603e-01,   2.80386657e-01,
                          2.83118457e-01,   2.85675883e-01,   2.87884563e-01,
                          2.90441990e-01,   2.92999417e-01,   2.95440584e-01,
                          2.97939897e-01,   3.00322950e-01,   3.02822262e-01,
                          3.05263430e-01,   3.07704598e-01,   3.10262024e-01,
                          3.12645078e-01,   3.15086275e-01,   3.17411184e-01,
                          3.19736123e-01,   3.22177291e-01,   3.24560344e-01,
                          3.27059656e-01,   3.29384595e-01,   3.31593275e-01,
                          3.33976328e-01,   3.36243123e-01,   3.38568062e-01,
                          3.40893000e-01,   3.43159795e-01,   3.45484734e-01,
                          3.47460926e-01,   3.49495232e-01,   3.51820171e-01,
                          3.54086995e-01,   3.56470048e-01,   3.58678728e-01,
                          3.60713035e-01,   3.62921715e-01,   3.65072280e-01,
                          3.66990358e-01,   3.69140923e-01,   3.71291459e-01,
                          3.73325795e-01,   3.75301987e-01,   3.77278179e-01,
                          3.79370600e-01,   3.81637424e-01,   3.83671731e-01,
                          3.85531664e-01,   3.87566000e-01,   3.89367819e-01,
                          3.91053379e-01,   3.92855197e-01,   3.94773275e-01,
                          3.96807581e-01,   3.98667544e-01,   4.00294989e-01,
                          4.02096808e-01,   4.03782368e-01,   4.05526072e-01,
                          4.07386035e-01,   4.08955365e-01,   4.10582811e-01,
                          4.12384629e-01,   4.14128333e-01,   4.15930152e-01,
                          4.17557597e-01,   4.19301301e-01,   4.20928746e-01,
                          4.22381818e-01,   4.24009293e-01,   4.25578594e-01,
                          4.27206069e-01,   4.29007888e-01,   4.30460960e-01,
                          4.31972176e-01,   4.33425248e-01,   4.34994578e-01,
                          4.36796397e-01,   4.38249469e-01,   4.39586312e-01,
                          4.41039413e-01,   4.42434371e-01,   4.43887442e-01,
                          4.45398659e-01,   4.46851730e-01,   4.48130429e-01,
                          4.49409157e-01,   4.50687855e-01,   4.52024698e-01,
                          4.53303397e-01,   4.54640239e-01,   4.56035197e-01,
                          4.57313925e-01,   4.58302021e-01,   4.59638834e-01,
                          4.60859448e-01,   4.61905658e-01,   4.63068128e-01,
                          4.64172453e-01,   4.65334922e-01,   4.66613650e-01,
                          4.67659861e-01,   4.68647957e-01,   4.69752282e-01,
                          4.70624149e-01,   4.71554130e-01,   4.72716570e-01,
                          4.73588437e-01,   4.74402159e-01,   4.75448370e-01,
                          4.76378351e-01,   4.77192074e-01,   4.78063911e-01,
                          4.78645146e-01,   4.79342639e-01,   4.80388850e-01,
                          4.81086344e-01,   4.81609434e-01,   4.82248813e-01,
                          4.82946277e-01,   4.83701885e-01,   4.84341234e-01,
                          4.84806210e-01,   4.85445589e-01,   4.86026824e-01,
                          4.86608058e-01,   4.87189263e-01,   4.87828642e-01,
                          4.88467991e-01,   4.88816738e-01,   4.89223599e-01,
                          4.89862949e-01,   4.90095437e-01,   4.90444183e-01,
                          4.91025418e-01,   4.91374165e-01,   4.91781026e-01,
                          4.92129743e-01,   4.92478490e-01,   4.92710978e-01,
                          4.92943496e-01,   4.93234098e-01,   4.93408471e-01,
                          4.93640959e-01,   4.93873447e-01,   4.94047821e-01,
                          4.94280308e-01,   4.94280308e-01,   4.94280308e-01,
                          4.94396567e-01,   4.94338453e-01,   4.94396567e-01,
                          4.94396567e-01,   4.94222194e-01,   4.94164079e-01,
                          4.94105935e-01,   4.94047821e-01,   4.93815333e-01,
                          4.93640959e-01,   4.93582845e-01,   4.93292212e-01,
                          4.93001610e-01,   4.92652863e-01,   4.92246002e-01,
                          4.92013514e-01,   4.91548508e-01,   4.91257906e-01,
                          4.91025418e-01,   4.90502298e-01,   4.90153551e-01,
                          4.89688575e-01,   4.89165455e-01,   4.88642365e-01,
                          4.87886757e-01,   4.87363636e-01,   4.87014920e-01,
                          4.86375540e-01,   4.85794306e-01,   4.84980583e-01,
                          4.84399348e-01,   4.83876258e-01,   4.82946277e-01,
                          4.82132554e-01,   4.81435061e-01,   4.80621338e-01,
                          4.79807615e-01,   4.79110152e-01,   4.78296429e-01,
                          4.77250189e-01,   4.76378351e-01,   4.75506514e-01,
                          4.74576533e-01,   4.73704666e-01,   4.72658455e-01,
                          4.71786618e-01,   4.70972896e-01,   4.69752282e-01,
                          4.68764186e-01,   4.67950463e-01,   4.66962367e-01,
                          4.65916157e-01,   4.64753687e-01,   4.63533103e-01,
                          4.62312520e-01,   4.61033791e-01,   4.59871352e-01,
                          4.58650738e-01,   4.57372040e-01,   4.56035197e-01,
                          4.54640239e-01,   4.53419656e-01,   4.52082813e-01,
                          4.50862229e-01,   4.49583530e-01,   4.47897941e-01,
                          4.46386755e-01,   4.44933653e-01,   4.43480581e-01,
                          4.42027479e-01,   4.40341920e-01,   4.38830703e-01,
                          4.37203258e-01,   4.35401440e-01,   4.33890224e-01,
                          4.32204664e-01,   4.30460960e-01,   4.28775400e-01,
                          4.27031696e-01,   4.25462365e-01,   4.23660547e-01,
                          4.21800584e-01,   4.19998765e-01,   4.18022573e-01,
                          4.16104525e-01,   4.14070189e-01,   4.12210256e-01,
                          4.10408437e-01,   4.08432245e-01,   4.06572312e-01,
                          4.04537976e-01,   4.02736157e-01,   4.00992453e-01,
                          3.98841888e-01,   3.96807581e-01,   3.94831389e-01,
                          3.92680824e-01,   3.90588403e-01,   3.88495952e-01,
                          3.86519760e-01,   3.84369195e-01,   3.82276773e-01,
                          3.80242467e-01,   3.78091902e-01,   3.76115710e-01,
                          3.74023259e-01,   3.71698320e-01,   3.69664013e-01,
                          3.67397219e-01,   3.65246654e-01,   3.63154203e-01,
                          3.60771149e-01,   3.58562469e-01,   3.56295675e-01,
                          3.53854477e-01,   3.51703942e-01,   3.49204630e-01,
                          3.46937805e-01,   3.44845384e-01,   3.42404217e-01,
                          3.40021163e-01,   3.37638110e-01,   3.35255027e-01,
                          3.32755744e-01,   3.30140203e-01,   3.27815264e-01,
                          3.25432211e-01,   3.22816670e-01,   3.20317358e-01,
                          3.17818046e-01,   3.15376878e-01,   3.12819451e-01,
                          3.10145795e-01,   3.07762742e-01,   3.05263430e-01,
                          3.02531630e-01,   2.99974203e-01,   2.97533035e-01,
                          2.95033723e-01,   2.92301953e-01,   2.89744526e-01,
                          2.87245214e-01,   2.84455299e-01,   2.82014132e-01,
                          2.79456705e-01,   2.76608646e-01,   2.73993105e-01,
                          2.71377563e-01,   2.68820137e-01,   2.66204596e-01,
                          2.63472795e-01,   2.60857254e-01,   2.58067340e-01,
                          2.55393654e-01,   2.52778113e-01,   2.50104457e-01,
                          2.47488901e-01,   2.44640857e-01,   2.41967186e-01,
                          2.39351645e-01,   2.36619845e-01,   2.33946174e-01,
                          2.31214374e-01,   2.28540704e-01,   2.26041406e-01,
                          2.23309621e-01,   2.20577821e-01,   2.17962280e-01,
                          2.15462968e-01,   2.12789297e-01,   2.09999382e-01,
                          2.07383841e-01,   2.04593927e-01,   2.01920256e-01,
                          1.99246585e-01,   1.96340412e-01,   1.93550497e-01,
                          1.90934956e-01,   1.88261285e-01,   1.85529485e-01,
                          1.82623327e-01,   1.79891527e-01,   1.77275985e-01,
                          1.74369827e-01,   1.71579897e-01,   1.68848112e-01,
                          1.66116312e-01,   1.63442641e-01,   1.60652727e-01,
                          1.57630324e-01,   1.54840395e-01,   1.52166724e-01,
                          1.49318695e-01,   1.46586895e-01,   1.43913224e-01,
                          1.41181424e-01,   1.38507754e-01,   1.35775968e-01,
                          1.32753551e-01,   1.30138010e-01,   1.27580583e-01,
                          1.24616295e-01,   1.21768259e-01,   1.19094588e-01,
                          1.16246544e-01,   1.13572873e-01,   1.10841081e-01,
                          1.07993044e-01,   1.05145000e-01,   1.02471329e-01,
                          9.97976586e-02,   9.70077440e-02,   9.42759514e-02,
                          9.14860293e-02,   8.88704881e-02,   8.61968175e-02,
                          8.32906514e-02,   8.07913467e-02,   7.82339275e-02,
                          7.54440054e-02,   7.27122128e-02,   6.99222982e-02,
                          6.72486275e-02,   6.47493303e-02,   6.20756559e-02,
                          5.95182329e-02,   5.69026843e-02,   5.41708916e-02,
                          5.14972210e-02,   4.88235503e-02,   4.62661274e-02,
                          4.34762090e-02,   4.05700430e-02,   3.79544981e-02,
                          3.51645797e-02,   3.23746651e-02,   2.97009926e-02,
                          2.70854458e-02,   2.45280210e-02,   2.17381045e-02,
                          1.89481881e-02,   1.63326394e-02,   1.36008458e-02,
                          1.08109284e-02,   8.02101195e-03,   5.40546421e-03,
                          2.90616369e-03,   1.16246549e-04,  -2.61554727e-03,
                         -5.28921792e-03,  -8.07913486e-03,  -1.07528055e-02,
                         -1.35427229e-02,  -1.63907632e-02,  -1.90063100e-02,
                         -2.16218568e-02,  -2.44117752e-02,  -2.72016916e-02,
                         -2.99334861e-02,  -3.26071568e-02,  -3.55133191e-02,
                         -3.83032374e-02,  -4.09187861e-02,  -4.34762090e-02,
                         -4.62661274e-02,  -4.91141677e-02,  -5.16134650e-02,
                         -5.42871356e-02,  -5.69608063e-02,  -5.95763549e-02,
                         -6.23662733e-02,  -6.49818182e-02,  -6.76554888e-02,
                         -7.03291595e-02,  -7.29447082e-02,  -7.57346228e-02,
                         -7.84664154e-02,  -8.09657201e-02,  -8.35231468e-02,
                         -8.60805660e-02,  -8.88123587e-02,  -9.13697854e-02,
                         -9.39272121e-02,  -9.66008827e-02,  -9.92745534e-02,
                         -1.02122590e-01,  -1.04796261e-01,  -1.07353687e-01,
                         -1.10027358e-01,  -1.12526655e-01,  -1.15084082e-01,
                         -1.17757753e-01,  -1.20315179e-01,  -1.22988850e-01,
                         -1.25604391e-01,  -1.28278062e-01,  -1.31009862e-01,
                         -1.33509159e-01,  -1.36240959e-01,  -1.38798371e-01,
                         -1.41472042e-01,  -1.44261971e-01,  -1.46645024e-01,
                         -1.49318695e-01,  -1.51992366e-01,  -1.54549778e-01,
                         -1.57339707e-01,  -1.59839004e-01,  -1.62454545e-01,
                         -1.65244460e-01,  -1.67743772e-01,  -1.70533687e-01,
                         -1.73149228e-01,  -1.75474167e-01,  -1.78089708e-01,
                         -1.80879623e-01,  -1.83437049e-01,  -1.85878232e-01,
                         -1.88435659e-01,  -1.90934956e-01,  -1.93376124e-01,
                         -1.95933551e-01,  -1.98549107e-01,  -2.00990275e-01,
                         -2.03547701e-01,  -2.06221372e-01,  -2.08720669e-01,
                         -2.11103722e-01,  -2.13661149e-01,  -2.16218576e-01,
                         -2.18427256e-01,  -2.20868438e-01,  -2.23367736e-01,
                         -2.25808918e-01,  -2.28540704e-01,  -2.30923772e-01,
                         -2.33190566e-01,  -2.35864237e-01,  -2.38247290e-01,
                         -2.40688473e-01,  -2.43245900e-01,  -2.45454580e-01,
                         -2.47779518e-01,  -2.50278801e-01,  -2.52603740e-01,
                         -2.54986793e-01,  -2.57369846e-01,  -2.59636670e-01,
                         -2.61903465e-01,  -2.64344633e-01,  -2.66785830e-01,
                         -2.69168884e-01,  -2.71493822e-01,  -2.73876876e-01,
                         -2.76492417e-01,  -2.78933585e-01,  -2.81258523e-01,
                         -2.83932179e-01,  -2.86315233e-01,  -2.88465798e-01,
                         -2.90906996e-01,  -2.93231905e-01,  -2.95673102e-01,
                         -2.98172385e-01,  -3.00497323e-01,  -3.02880377e-01,
                         -3.05205315e-01,  -3.07413995e-01,  -3.09738934e-01,
                         -3.12005728e-01,  -3.14330667e-01,  -3.16771835e-01,
                         -3.19038659e-01,  -3.21305454e-01,  -3.23804766e-01,
                         -3.26245934e-01,  -3.28454614e-01,  -3.30779552e-01,
                         -3.33162606e-01,  -3.35255027e-01,  -3.37521851e-01,
                         -3.39788646e-01,  -3.41881096e-01,  -3.44147891e-01,
                         -3.46472830e-01,  -3.48739654e-01,  -3.50948334e-01,
                         -3.53157014e-01,  -3.55307579e-01,  -3.57516259e-01,
                         -3.60015541e-01,  -3.62107992e-01,  -3.64316672e-01,
                         -3.66641611e-01,  -3.68675917e-01,  -3.70942742e-01,
                         -3.73151422e-01,  -3.75185728e-01,  -3.77510667e-01,
                         -3.79777461e-01,  -3.82044286e-01,  -3.84369195e-01,
                         -3.86461645e-01,  -3.88554096e-01,  -3.90879005e-01,
                         -3.92971456e-01,  -3.95005763e-01,  -3.97156328e-01,
                         -3.99365008e-01,  -4.01457459e-01,  -4.03608024e-01,
                         -4.06049192e-01,  -4.08315986e-01,  -4.10466552e-01,
                         -4.12617117e-01,  -4.14883912e-01,  -4.17325109e-01,
                         -4.19533789e-01,  -4.21509981e-01,  -4.23776776e-01,
                         -4.25985485e-01,  -4.28194165e-01,  -4.30344731e-01,
                         -4.32611525e-01,  -4.34820205e-01,  -4.36912656e-01,
                         -4.39063221e-01,  -4.41388130e-01,  -4.43538696e-01,
                         -4.45747375e-01,  -4.48014200e-01,  -4.50164765e-01,
                         -4.52315301e-01,  -4.54407752e-01,  -4.56500202e-01,
                         -4.58708882e-01,  -4.61033791e-01,  -4.63126242e-01,
                         -4.64986175e-01,  -4.67020512e-01,  -4.69054818e-01,
                         -4.71147269e-01,  -4.73472178e-01,  -4.75506514e-01,
                         -4.77424562e-01,  -4.79575127e-01,  -4.81493205e-01,
                         -4.83469397e-01,  -4.85503703e-01,  -4.87596154e-01,
                         -4.89630461e-01,  -4.91432279e-01,  -4.93292212e-01,
                         -4.95152175e-01,  -4.97012109e-01,  -4.99104559e-01,
                         -5.00964522e-01,  -5.02766311e-01,  -5.04568160e-01,
                         -5.06311834e-01,  -5.08346140e-01,  -5.10206103e-01,
                         -5.11891663e-01,  -5.13635337e-01,  -5.15379071e-01,
                         -5.16948402e-01,  -5.18401504e-01,  -5.20145178e-01,
                         -5.22005141e-01,  -5.23690701e-01,  -5.25376260e-01,
                         -5.27061820e-01,  -5.28631151e-01,  -5.30142367e-01,
                         -5.31653583e-01,  -5.33397257e-01,  -5.34850359e-01,
                         -5.36129057e-01,  -5.37756503e-01,  -5.39151490e-01,
                         -5.40372074e-01,  -5.41650772e-01,  -5.42871356e-01,
                         -5.44382572e-01,  -5.45661271e-01,  -5.46823740e-01,
                         -5.48102438e-01,  -5.48974335e-01,  -5.49904287e-01,
                         -5.50950527e-01,  -5.51880479e-01,  -5.52984834e-01,
                         -5.53856671e-01,  -5.54612279e-01,  -5.55716634e-01,
                         -5.56472242e-01,  -5.56937218e-01,  -5.57634711e-01,
                         -5.58390260e-01,  -5.58971524e-01,  -5.59610903e-01,
                         -5.60192108e-01,  -5.60598969e-01,  -5.61063945e-01,
                         -5.61528921e-01,  -5.61703324e-01,  -5.61993957e-01,
                         -5.62400818e-01,  -5.62575161e-01,  -5.62749505e-01,
                         -5.62865794e-01,  -5.62982023e-01,  -5.63040137e-01,
                         -5.62923908e-01,  -5.62982023e-01,  -5.62807679e-01,
                         -5.62517047e-01,  -5.62400818e-01,  -5.62110186e-01,
                         -5.61761439e-01,  -5.61296463e-01,  -5.61005831e-01,
                         -5.60657084e-01,  -5.60017765e-01,  -5.59669018e-01,
                         -5.59087753e-01,  -5.58157802e-01,  -5.57518423e-01,
                         -5.56762815e-01,  -5.56123495e-01,  -5.55426002e-01,
                         -5.54496050e-01,  -5.53624153e-01,  -5.52810431e-01,
                         -5.51938593e-01,  -5.50834239e-01,  -5.49788058e-01,
                         -5.48625588e-01,  -5.47288716e-01,  -5.46300650e-01,
                         -5.45021951e-01,  -5.43394506e-01,  -5.42057633e-01,
                         -5.40662706e-01,  -5.39325833e-01,  -5.37872791e-01,
                         -5.36245346e-01,  -5.34734130e-01,  -5.32990396e-01,
                         -5.31304836e-01,  -5.29444873e-01,  -5.27294338e-01,
                         -5.25666893e-01,  -5.23865044e-01,  -5.21714509e-01,
                         -5.19738317e-01,  -5.17587721e-01,  -5.15553415e-01,
                         -5.13460994e-01,  -5.11019826e-01,  -5.08694887e-01,
                         -5.06428063e-01,  -5.04045010e-01,  -5.01603842e-01,
                         -4.99046415e-01,  -4.96605247e-01,  -4.94047821e-01,
                         -4.91374165e-01,  -4.88642365e-01,  -4.85794306e-01,
                         -4.83120650e-01,  -4.80388850e-01,  -4.77366447e-01,
                         -4.74344045e-01,  -4.71437871e-01,  -4.68647957e-01,
                         -4.65741783e-01,  -4.62486893e-01,  -4.59348232e-01,
                         -4.56093341e-01,  -4.53012794e-01,  -4.49990392e-01,
                         -4.46561098e-01,  -4.43248093e-01,  -4.39993173e-01,
                         -4.36447650e-01,  -4.32844013e-01,  -4.29472864e-01,
                         -4.26217973e-01,  -4.22439963e-01,  -4.18603808e-01,
                         -4.15174544e-01,  -4.11512762e-01,  -4.07676637e-01,
                         -4.03898627e-01,  -4.00178730e-01,  -3.96226346e-01,
                         -3.92215848e-01,  -3.88437837e-01,  -3.84485453e-01,
                         -3.80300581e-01,  -3.76464456e-01,  -3.72337699e-01,
                         -3.68152827e-01,  -3.64200443e-01,  -3.59841198e-01,
                         -3.55423808e-01,  -3.51238936e-01,  -3.46879691e-01,
                         -3.42346072e-01,  -3.37986827e-01,  -3.33511353e-01,
                         -3.28687102e-01,  -3.24269742e-01,  -3.19794238e-01,
                         -3.15028131e-01,  -3.10436398e-01,  -3.05612177e-01,
                         -3.01020443e-01,  -2.96486825e-01,  -2.91371971e-01,
                         -2.86547750e-01,  -2.81723499e-01,  -2.76724905e-01,
                         -2.72016913e-01,  -2.66960204e-01,  -2.61903465e-01,
                         -2.57021129e-01,  -2.51906276e-01,  -2.46791422e-01,
                         -2.41618454e-01,  -2.36561716e-01,  -2.31330633e-01,
                         -2.26273909e-01,  -2.21217185e-01,  -2.15753585e-01,
                         -2.10580617e-01,  -2.05291405e-01,  -1.99827820e-01,
                         -1.94771096e-01,  -1.89423755e-01,  -1.83960155e-01,
                         -1.78729072e-01,  -1.73323601e-01,  -1.67976260e-01,
                         -1.62628919e-01,  -1.57107204e-01,  -1.51701748e-01,
                         -1.46238163e-01,  -1.40774563e-01,  -1.35369107e-01,
                         -1.29847392e-01,  -1.24267556e-01,  -1.18687727e-01,
                         -1.13166012e-01,  -1.07644305e-01,  -1.02064468e-01,
                         -9.66008827e-02,  -9.09629241e-02,  -8.53249654e-02,
                         -7.98613802e-02,  -7.43396655e-02,  -6.87598288e-02,
                         -6.30056262e-02,  -5.73676713e-02,  -5.19040823e-02,
                         -4.62080017e-02,  -4.04537991e-02,  -3.48739624e-02,
                         -2.90616360e-02,  -2.35399250e-02,  -1.81344617e-02,
                         -1.24383802e-02,  -6.62605325e-03,  -8.71849130e-04,
                          4.64986172e-03,   1.03459423e-02,   1.61001459e-02,
                          2.16799807e-02,   2.72598155e-02,   3.28396484e-02,
                          3.84776071e-02,   4.42318097e-02,   4.96372767e-02,
                          5.51589876e-02,   6.09131902e-02,   6.66092709e-02,
                          7.20728561e-02,   7.73620754e-02,   8.28837901e-02,
                          8.84636194e-02,   9.41015780e-02,   9.97976586e-02,
                          1.05145000e-01,   1.10608593e-01,   1.15955934e-01,
                          1.21187024e-01,   1.26708731e-01,   1.32114202e-01,
                          1.37345299e-01,   1.42634511e-01,   1.47923738e-01,
                          1.53271079e-01,   1.58560291e-01,   1.63907632e-01,
                          1.69138730e-01,   1.74079210e-01,   1.79194048e-01,
                          1.84250772e-01,   1.89481869e-01,   1.94654837e-01,
                          1.99479073e-01,   2.04593927e-01,   2.09766895e-01,
                          2.14591131e-01,   2.19705969e-01,   2.24704579e-01,
                          2.29412556e-01,   2.34469280e-01,   2.39235386e-01,
                          2.43885249e-01,   2.48767614e-01,   2.53533721e-01,
                          2.58357942e-01,   2.63182193e-01,   2.67715812e-01,
                          2.72249401e-01,   2.76841164e-01,   2.81432897e-01,
                          2.85908371e-01,   2.90441990e-01,   2.95091867e-01,
                          2.99451113e-01,   3.03752214e-01,   3.08111459e-01,
                          3.12645078e-01,   3.16946208e-01,   3.20956707e-01,
                          3.25199723e-01,   3.29675198e-01,   3.33685726e-01,
                          3.37638110e-01,   3.41822982e-01,   3.45891595e-01,
                          3.49785864e-01,   3.53621989e-01,   3.57516259e-01,
                          3.61294270e-01,   3.65188539e-01,   3.68908405e-01,
                          3.72453928e-01,   3.76231939e-01,   3.79835606e-01,
                          3.83497357e-01,   3.87042880e-01,   3.90239656e-01,
                          3.93610805e-01,   3.96981955e-01,   4.00353104e-01,
                          4.03724253e-01,   4.06804800e-01,   4.09827203e-01,
                          4.13023978e-01,   4.16162640e-01,   4.19301301e-01,
                          4.22207445e-01,   4.25229877e-01,   4.27961648e-01,
                          4.30577219e-01,   4.33599621e-01,   4.36273277e-01,
                          4.38946962e-01,   4.41736877e-01,   4.44119930e-01,
                          4.46677357e-01,   4.49351013e-01,   4.51617837e-01,
                          4.54000890e-01,   4.56558317e-01,   4.58766997e-01,
                          4.60801303e-01,   4.63126242e-01,   4.65276808e-01,
                          4.67136741e-01,   4.69171077e-01,   4.71205384e-01,
                          4.73239690e-01,   4.75215882e-01,   4.77192074e-01,
                          4.78935778e-01,   4.80621338e-01,   4.82423156e-01,
                          4.83992487e-01,   4.85387444e-01,   4.87131149e-01,
                          4.88584250e-01,   4.89804834e-01,   4.91257906e-01,
                          4.92769122e-01,   4.94047821e-01,   4.95094031e-01,
                          4.96256500e-01,   4.97477084e-01,   4.98290837e-01,
                          4.99220788e-01,   5.00325143e-01,   5.01138866e-01,
                          5.01952589e-01,   5.02591968e-01,   5.03347576e-01,
                          5.04219413e-01,   5.04800618e-01,   5.05439997e-01,
                          5.05846858e-01,   5.05963087e-01,   5.06486177e-01,
                          5.06893039e-01,   5.07067442e-01,   5.07474303e-01,
                          5.07590532e-01,   5.07532418e-01,   5.07532418e-01,
                          5.07648647e-01,   5.07764935e-01,   5.07764935e-01,
                          5.07706821e-01,   5.07358074e-01,   5.06834924e-01,
                          5.06660581e-01,   5.06253719e-01,   5.05730629e-01,
                          5.05439997e-01,   5.04742503e-01,   5.04219413e-01,
                          5.03870666e-01,   5.03173172e-01,   5.02417564e-01,
                          5.01487613e-01,   5.00732005e-01,   5.00092626e-01,
                          4.99220788e-01,   4.98232692e-01,   4.97360855e-01,
                          4.96314645e-01,   4.95094031e-01,   4.93931592e-01,
                          4.92827237e-01,   4.91548508e-01,   4.90386069e-01,
                          4.89223599e-01,   4.87828642e-01,   4.86491799e-01,
                          4.84922469e-01,   4.83585626e-01,   4.82190669e-01,
                          4.80214477e-01,   4.78645146e-01,   4.77192074e-01,
                          4.75273997e-01,   4.73646551e-01,   4.71844733e-01,
                          4.69868541e-01,   4.67950463e-01,   4.66032416e-01,
                          4.64172453e-01,   4.62138146e-01,   4.59871352e-01,
                          4.57662642e-01,   4.55570221e-01,   4.53303397e-01,
                          4.51036602e-01,   4.48827922e-01,   4.46386755e-01,
                          4.43887442e-01,   4.41562504e-01,   4.39179450e-01,
                          4.36738282e-01,   4.34064597e-01,   4.31332827e-01,
                          4.28949744e-01,   4.26217973e-01,   4.23486173e-01,
                          4.20986861e-01,   4.18080717e-01,   4.15232658e-01,
                          4.12500858e-01,   4.09652829e-01,   4.06921029e-01,
                          4.03724253e-01,   4.00818080e-01,   3.98144424e-01,
                          3.95005763e-01,   3.91808987e-01,   3.88612211e-01,
                          3.85589808e-01,   3.82683635e-01,   3.79544973e-01,
                          3.76348197e-01,   3.73151422e-01,   3.69896501e-01,
                          3.66757870e-01,   3.63677323e-01,   3.60422432e-01,
                          3.56993139e-01,   3.53738248e-01,   3.50367099e-01,
                          3.46763462e-01,   3.43392313e-01,   3.40021163e-01,
                          3.36475641e-01,   3.33104491e-01,   3.29558969e-01,
                          3.26013446e-01,   3.22526038e-01,   3.18689913e-01,
                          3.15144390e-01,   3.11540753e-01,   3.07937115e-01,
                          3.04333448e-01,   3.00497323e-01,   2.96777427e-01,
                          2.93057531e-01,   2.89163291e-01,   2.85443395e-01,
                          2.81665385e-01,   2.77829260e-01,   2.73934990e-01,
                          2.70040721e-01,   2.66146481e-01,   2.62135953e-01,
                          2.58357942e-01,   2.54405558e-01,   2.50278801e-01,
                          2.46500805e-01,   2.42548421e-01,   2.38596037e-01,
                          2.34759897e-01,   2.30516896e-01,   2.26564527e-01,
                          2.22554013e-01,   2.18369141e-01,   2.14533001e-01,
                          2.10464373e-01,   2.06337616e-01,   2.02268988e-01,
                          1.98142245e-01,   1.94247976e-01,   1.90237477e-01,
                          1.85994476e-01,   1.81925848e-01,   1.77799091e-01,
                          1.73788592e-01,   1.69836208e-01,   1.65709451e-01,
                          1.61698952e-01,   1.57630324e-01,   1.53387323e-01,
                          1.49376810e-01,   1.45482555e-01,   1.41355798e-01,
                          1.37112796e-01,   1.33102298e-01,   1.28917426e-01,
                          1.24674425e-01,   1.20722041e-01,   1.16595283e-01,
                          1.12526655e-01,   1.08690523e-01,   1.04447521e-01,
                          1.00204520e-01,   9.61358920e-02,   9.21835080e-02,
                          8.83473754e-02,   8.42787474e-02,   8.00938681e-02,
                          7.61414915e-02,   7.21309856e-02,   6.78879842e-02,
                          6.37031049e-02,   5.97507246e-02,   5.58564663e-02,
                          5.17878383e-02,   4.78354543e-02,   4.37668264e-02,
                          3.96981947e-02,   3.59201841e-02,   3.19678001e-02,
                          2.80735418e-02,   2.41792817e-02,   2.02268995e-02,
                          1.63326394e-02,   1.24383802e-02,   8.66036769e-03,
                          4.64986172e-03,   6.97479292e-04,  -3.08053358e-03,
                         -6.91666966e-03,  -1.08109284e-02,  -1.44726951e-02,
                         -1.81344617e-02,  -2.18543503e-02,  -2.57486105e-02,
                         -2.95266230e-02,  -3.30140181e-02,  -3.66176628e-02,
                         -4.03375514e-02,  -4.41736877e-02,  -4.77192067e-02,
                         -5.12066036e-02,  -5.48683703e-02,  -5.82976416e-02,
                         -6.19012862e-02,  -6.54468089e-02,  -6.87017068e-02,
                         -7.23053515e-02,  -7.58508742e-02,  -7.91057721e-02,
                         -8.25350508e-02,  -8.59643221e-02,  -8.93935934e-02,
                         -9.25903767e-02,  -9.57871526e-02,  -9.91583019e-02,
                         -1.02413207e-01,  -1.05609991e-01,  -1.08806767e-01,
                         -1.11945428e-01,  -1.15200326e-01,  -1.18455231e-01,
                         -1.21419519e-01,  -1.24558173e-01,  -1.27754956e-01,
                         -1.30719244e-01,  -1.33741647e-01,  -1.36996552e-01,
                         -1.40018970e-01,  -1.42983258e-01,  -1.46005660e-01,
                         -1.48737460e-01,  -1.51643619e-01,  -1.54491663e-01,
                         -1.57339707e-01,  -1.60187736e-01,  -1.62803292e-01,
                         -1.65651336e-01,  -1.68615609e-01,  -1.71173036e-01,
                         -1.73846707e-01,  -1.76636621e-01,  -1.79135934e-01,
                         -1.81635231e-01,  -1.84250772e-01,  -1.86924443e-01,
                         -1.89307496e-01,  -1.91574305e-01,  -1.94131732e-01,
                         -1.96514785e-01,  -1.98897839e-01,  -2.01222777e-01,
                         -2.03663945e-01,  -2.06221372e-01,  -2.08197564e-01,
                         -2.10173756e-01,  -2.12673053e-01,  -2.14649245e-01,
                         -2.16625437e-01,  -2.18717873e-01,  -2.20810309e-01,
                         -2.23077118e-01,  -2.24820822e-01,  -2.26564527e-01,
                         -2.28773206e-01,  -2.30633155e-01,  -2.32434973e-01,
                         -2.34004304e-01,  -2.35747993e-01,  -2.37666070e-01,
                         -2.39351645e-01,  -2.41095334e-01,  -2.42548421e-01,
                         -2.43943378e-01,  -2.45628953e-01,  -2.47372657e-01,
                         -2.48825729e-01,  -2.50162572e-01,  -2.51673788e-01,
                         -2.53010601e-01,  -2.54289329e-01,  -2.55800515e-01,
                         -2.57079244e-01,  -2.58299828e-01,  -2.59636670e-01,
                         -2.60682881e-01,  -2.61903465e-01,  -2.63182193e-01,
                         -2.64112145e-01,  -2.65332729e-01,  -2.66553342e-01,
                         -2.67599553e-01,  -2.68529534e-01,  -2.69343257e-01,
                         -2.70273209e-01,  -2.71086961e-01,  -2.71958798e-01,
                         -2.72772521e-01,  -2.73353755e-01,  -2.74341851e-01,
                         -2.74981201e-01,  -2.75562435e-01,  -2.76376158e-01,
                         -2.76841164e-01,  -2.77422398e-01,  -2.78119862e-01,
                         -2.78584838e-01,  -2.79107958e-01,  -2.79340446e-01,
                         -2.79689193e-01,  -2.80154169e-01,  -2.80270427e-01,
                         -2.80502915e-01,  -2.80735403e-01,  -2.81026036e-01,
                         -2.81374753e-01,  -2.81258523e-01,  -2.81316638e-01,
                         -2.81491011e-01,  -2.81607270e-01,  -2.81723499e-01,
                         -2.81549126e-01,  -2.81491011e-01,  -2.81316638e-01,
                         -2.80967891e-01,  -2.80909777e-01,  -2.80561030e-01,
                         -2.80270427e-01,  -2.80154169e-01,  -2.79805452e-01,
                         -2.79282331e-01,  -2.78817356e-01,  -2.78468609e-01,
                         -2.78061748e-01,  -2.77654886e-01,  -2.77480513e-01,
                         -2.76899278e-01,  -2.76201785e-01,  -2.75620550e-01,
                         -2.74632454e-01,  -2.73993105e-01,  -2.73528129e-01,
                         -2.72714406e-01,  -2.72016913e-01,  -2.71261305e-01,
                         -2.70505726e-01,  -2.69633859e-01,  -2.68529534e-01,
                         -2.67715812e-01,  -2.66785830e-01,  -2.65797734e-01,
                         -2.65100241e-01,  -2.64054030e-01,  -2.62949675e-01,
                         -2.61787236e-01,  -2.60508507e-01,  -2.59636670e-01,
                         -2.58532315e-01,  -2.57253617e-01,  -2.56091148e-01,
                         -2.54521817e-01,  -2.53359348e-01,  -2.52254993e-01,
                         -2.50801921e-01,  -2.49581337e-01,  -2.48070136e-01,
                         -2.46500805e-01,  -2.45047718e-01,  -2.43478388e-01,
                         -2.42025316e-01,  -2.40339741e-01,  -2.38770410e-01,
                         -2.37317324e-01,  -2.35573635e-01,  -2.33888045e-01,
                         -2.32318729e-01,  -2.30691269e-01,  -2.29180068e-01,
                         -2.27378249e-01,  -2.25460172e-01,  -2.23774597e-01,
                         -2.21856534e-01,  -2.19822213e-01,  -2.17962280e-01,
                         -2.16102332e-01,  -2.14242384e-01,  -2.12266192e-01,
                         -2.10348129e-01,  -2.08430052e-01,  -2.06453860e-01,
                         -2.04245180e-01,  -2.02268988e-01,  -2.00409040e-01,
                         -1.98200360e-01,  -1.95933551e-01,  -1.93899244e-01,
                         -1.91923052e-01,  -1.89888731e-01,  -1.87854424e-01,
                         -1.85645729e-01,  -1.83262676e-01,  -1.81112126e-01,
                         -1.79019675e-01,  -1.76810995e-01,  -1.74486071e-01,
                         -1.72277376e-01,  -1.70068696e-01,  -1.67860016e-01,
                         -1.65535077e-01,  -1.63326398e-01,  -1.60885215e-01,
                         -1.58618420e-01,  -1.56700343e-01,  -1.54026672e-01,
                         -1.51527375e-01,  -1.49493054e-01,  -1.46935642e-01,
                         -1.44610703e-01,  -1.42402023e-01,  -1.39902726e-01,
                         -1.37868404e-01,  -1.35717839e-01,  -1.33102298e-01,
                         -1.30661115e-01,  -1.28336191e-01,  -1.25953138e-01,
                         -1.23511955e-01,  -1.21303275e-01,  -1.18920214e-01,
                         -1.16304673e-01,  -1.14095986e-01,  -1.11712933e-01,
                         -1.08981140e-01,  -1.06772453e-01,  -1.04331277e-01,
                         -1.01831973e-01,  -9.95070413e-02,  -9.69496220e-02,
                         -9.45084393e-02,  -9.22416374e-02,  -8.98585841e-02,
                         -8.74174014e-02,  -8.51505920e-02,  -8.28256682e-02,
                         -8.03844854e-02,  -7.81758055e-02,  -7.57927522e-02,
                         -7.33515695e-02,  -7.13172555e-02,  -6.87598288e-02,
                         -6.63186535e-02,  -6.43424615e-02,  -6.19594082e-02,
                         -5.95763549e-02,  -5.73095493e-02,  -5.49264923e-02,
                         -5.28921783e-02,  -5.07997423e-02,  -4.84748110e-02,
                         -4.62661274e-02,  -4.42318097e-02,  -4.20231260e-02,
                         -3.98144424e-02,  -3.77801284e-02,  -3.56295668e-02,
                         -3.35952528e-02,  -3.15609388e-02,  -2.94684991e-02,
                         -2.75504310e-02,  -2.56323628e-02,  -2.35399250e-02,
                         -2.16218568e-02,  -1.97037905e-02,  -1.77857224e-02,
                         -1.58676542e-02,  -1.40658319e-02,  -1.23221343e-02,
                         -1.02878194e-02,  -8.54412094e-03,  -6.97479304e-03,
                         -5.05672488e-03,  -3.25490325e-03,  -1.51120510e-03,
                          2.32493097e-04,   1.85994478e-03,   3.48739652e-03,
                          4.99860151e-03,   6.68417662e-03,   8.36975127e-03,
                          9.76470951e-03,   1.13340383e-02,   1.30196130e-02,
                          1.44145722e-02,   1.58676542e-02,   1.74951050e-02,
                          1.89481881e-02,   2.01106519e-02,   2.14474872e-02,
                          2.30749398e-02,   2.42955275e-02,   2.54579931e-02,
                          2.70854458e-02,   2.82479115e-02,   2.93522533e-02,
                          3.05147190e-02,   3.16190608e-02,   3.30721438e-02,
                          3.41183618e-02,   3.48739624e-02,   3.59783061e-02,
                          3.73151414e-02,   3.83613594e-02,   3.92332077e-02,
                          4.01631817e-02,   4.10350300e-02,   4.17325087e-02,
                          4.27206047e-02,   4.34762090e-02,   4.41736877e-02,
                          4.50455360e-02,   4.56848927e-02,   4.64404970e-02,
                          4.71960977e-02,   4.77773324e-02,   4.85329330e-02,
                          4.91141677e-02,   4.96953987e-02,   5.02185076e-02,
                          5.07997423e-02,   5.13228513e-02,   5.15553430e-02,
                          5.20784520e-02,   5.25434390e-02,   5.28921783e-02,
                          5.31827956e-02,   5.33571653e-02,   5.36477827e-02,
                          5.38802743e-02,   5.41127659e-02,   5.45196310e-02,
                          5.46358787e-02,   5.48683703e-02,   5.50427400e-02,
                          5.50427400e-02,   5.53914793e-02,   5.53333573e-02,
                          5.52752316e-02,   5.54496013e-02,   5.53333573e-02,
                          5.52752316e-02,   5.51589876e-02,   5.51008619e-02,
                          5.52752316e-02,   5.51008619e-02,   5.48102483e-02,
                          5.46358787e-02,   5.43452613e-02,   5.41127659e-02,
                          5.38802743e-02,   5.37059046e-02,   5.34152873e-02,
                          5.30665480e-02,   5.27178086e-02,   5.23109473e-02,
                          5.19622080e-02,   5.15553430e-02,   5.11484817e-02,
                          5.09159863e-02,   5.03928773e-02,   4.98697683e-02,
                          4.95791510e-02,   4.88816723e-02,   4.83004414e-02,
                          4.77773324e-02,   4.70217280e-02,   4.66148667e-02,
                          4.61498797e-02,   4.53942753e-02,   4.47549187e-02,
                          4.39993180e-02,   4.32437137e-02,   4.25462350e-02,
                          4.19068784e-02,   4.10931557e-02,   4.02213037e-02,
                          3.97563204e-02,   3.91750857e-02,   3.80707458e-02,
                          3.72570194e-02,   3.65014151e-02,   3.56876887e-02,
                          3.49902101e-02,   3.41183618e-02,   3.33046354e-02,
                          3.22584175e-02,   3.13284434e-02,   3.06309648e-02,
                          2.96428688e-02,   2.89453901e-02,   2.81316638e-02,
                          2.70273220e-02,   2.60392260e-02,   2.51673777e-02,
                          2.41792817e-02,   2.33655553e-02,   2.23774593e-02,
                          2.13893652e-02,   2.04012692e-02,   1.94131732e-02,
                          1.82507075e-02,   1.73207354e-02,   1.63907632e-02,
                          1.52864205e-02,   1.46470647e-02,   1.35427229e-02,
                          1.22058876e-02,   1.15084080e-02,   1.04621891e-02,
                          9.29972343e-03,   8.54412094e-03,   7.32353237e-03,
                          6.39356021e-03,   5.57983434e-03,   4.35924530e-03,
                          3.25490325e-03,   2.09243782e-03,   1.10434217e-03,
                          1.74369823e-04,  -1.04621891e-03,  -2.09243782e-03,
                         -3.19678010e-03,  -4.12675226e-03,  -4.99860151e-03,
                         -6.10294379e-03,  -7.14916270e-03,  -8.31162836e-03,
                         -9.53221694e-03,  -1.04621891e-02,  -1.15665318e-02,
                         -1.26127508e-02,  -1.37752155e-02,  -1.48214344e-02,
                         -1.56932846e-02,  -1.69138722e-02,  -1.77857224e-02,
                         -1.87738165e-02,  -2.00525299e-02,  -2.09243782e-02,
                         -2.20868438e-02,  -2.31911857e-02,  -2.40049120e-02,
                         -2.51673777e-02,  -2.62135956e-02,  -2.72598155e-02,
                         -2.83060335e-02,  -2.92941295e-02,  -3.04565951e-02,
                         -3.13865691e-02,  -3.23746651e-02,  -3.32465135e-02,
                         -3.42346095e-02,  -3.52227055e-02,  -3.61526757e-02,
                         -3.71988937e-02,  -3.81869897e-02,  -3.90588380e-02,
                         -4.01050597e-02,  -4.09187861e-02,  -4.18487564e-02,
                         -4.29531001e-02,  -4.37668264e-02,  -4.45805490e-02,
                         -4.53361534e-02,  -4.62080017e-02,  -4.70798500e-02,
                         -4.77773324e-02,  -4.88816723e-02,  -4.97535206e-02,
                         -5.04510030e-02,  -5.13809733e-02,  -5.21365777e-02,
                         -5.29503003e-02,  -5.38221523e-02,  -5.45196310e-02,
                         -5.53914793e-02,  -5.60308360e-02,  -5.67283146e-02,
                         -5.75420409e-02,  -5.81813976e-02,  -5.88788763e-02,
                         -5.94601072e-02,  -6.01575896e-02,  -6.09713122e-02,
                         -6.15525469e-02,  -6.21919036e-02,  -6.27731383e-02,
                         -6.35868609e-02,  -6.42843395e-02,  -6.48074523e-02,
                         -6.55049309e-02,  -6.60280362e-02,  -6.65511489e-02,
                         -6.73067495e-02,  -6.76554888e-02,  -6.82367235e-02,
                         -6.89342022e-02,  -6.92248195e-02,  -6.95154369e-02,
                         -6.99222982e-02,  -7.05035329e-02,  -7.11428896e-02,
                         -7.14916289e-02,  -7.19566122e-02,  -7.23634735e-02,
                         -7.27122128e-02,  -7.32353255e-02,  -7.37003088e-02,
                         -7.39909261e-02,  -7.42815435e-02,  -7.46302828e-02,
                         -7.48627782e-02,  -7.52115175e-02,  -7.55602568e-02,
                         -7.55021349e-02,  -7.55602568e-02,  -7.60833621e-02,
                         -7.63739794e-02,  -7.66064748e-02,  -7.68389702e-02,
                         -7.68389702e-02,  -7.71877095e-02,  -7.75364488e-02,
                         -7.74783269e-02,  -7.74783269e-02,  -7.75945708e-02,
                         -7.77108148e-02,  -7.77689368e-02,  -7.77689368e-02,
                         -7.77108148e-02,  -7.77689368e-02,  -7.78851882e-02,
                         -7.77108148e-02,  -7.77108148e-02,  -7.77108148e-02,
                         -7.74783269e-02,  -7.75945708e-02,  -7.75945708e-02,
                         -7.73039535e-02,  -7.71877095e-02,  -7.70714581e-02,
                         -7.69552141e-02,  -7.66064748e-02,  -7.63158575e-02,
                         -7.63739794e-02,  -7.60833621e-02,  -7.59089962e-02,
                         -7.58508742e-02,  -7.56183788e-02,  -7.53858835e-02,
                         -7.49209002e-02,  -7.46302828e-02,  -7.44559169e-02,
                         -7.40490481e-02,  -7.37584308e-02,  -7.33515695e-02,
                         -7.30028301e-02,  -7.28865862e-02,  -7.23634735e-02,
                         -7.21309856e-02,  -7.18403682e-02,  -7.11428896e-02,
                         -7.09103942e-02,  -7.06197768e-02,  -6.99222982e-02,
                         -6.95154369e-02,  -6.91666976e-02,  -6.87598288e-02,
                         -6.80042282e-02,  -6.71905056e-02,  -6.68998882e-02,
                         -6.62024096e-02,  -6.55049309e-02,  -6.51561916e-02,
                         -6.44587129e-02,  -6.38193563e-02,  -6.32381216e-02,
                         -6.25987649e-02,  -6.19594082e-02,  -6.12619296e-02,
                         -6.07969426e-02,  -6.01575896e-02,  -5.92857376e-02,
                         -5.85882589e-02,  -5.77745326e-02,  -5.70770539e-02,
                         -5.63214533e-02,  -5.55658489e-02,  -5.49264923e-02,
                         -5.38802743e-02,  -5.32990433e-02,  -5.27759306e-02,
                         -5.17878383e-02,  -5.09159863e-02,  -4.98116463e-02,
                         -4.88816723e-02,  -4.82423156e-02,  -4.74285893e-02,
                         -4.64404970e-02,  -4.55105230e-02,  -4.49292921e-02,
                         -4.42318097e-02,  -4.32437137e-02,  -4.24881130e-02,
                         -4.15000170e-02,  -4.05119210e-02,  -3.97563204e-02,
                         -3.84194851e-02,  -3.74313891e-02,  -3.65595408e-02,
                         -3.56295668e-02,  -3.49320881e-02,  -3.38277444e-02,
                         -3.28396484e-02,  -3.20259221e-02,  -3.09215821e-02,
                         -2.99334861e-02,  -2.88291443e-02,  -2.77829245e-02,
                         -2.69110762e-02,  -2.58067325e-02,  -2.48186383e-02,
                         -2.35980488e-02,  -2.23774593e-02,  -2.15637349e-02,
                         -2.04593930e-02,  -1.92969274e-02,  -1.81925837e-02,
                         -1.72044896e-02,  -1.62163936e-02,  -1.49958050e-02,
                         -1.39495861e-02,  -1.28452433e-02,  -1.16246548e-02,
                         -1.06946826e-02,  -9.47409403e-03,  -8.25350452e-03,
                         -7.26540899e-03,  -5.87045075e-03,  -4.70798509e-03,
                         -3.71988956e-03,  -2.32493086e-03,  -1.16246543e-03,
                          0.00000000e+00,   1.22058869e-03,   2.26680771e-03,
                          3.42927314e-03,   4.53361543e-03,   5.75420400e-03,
                          6.97479304e-03,   8.02101195e-03,   9.18347761e-03,
                          1.05203129e-02,   1.17990244e-02,   1.27871204e-02,
                          1.39495861e-02,   1.52864205e-02,   1.63907632e-02,
                          1.76694747e-02,   1.90063100e-02,   2.01687757e-02,
                          2.13893652e-02,   2.25518309e-02,   2.37724185e-02,
                          2.49348842e-02,   2.60973498e-02,   2.72598155e-02,
                          2.85385270e-02,   2.97591165e-02,   3.09215821e-02,
                          3.21421698e-02,   3.34208831e-02,   3.44671011e-02,
                          3.58039364e-02,   3.70245241e-02,   3.81869897e-02,
                          3.96400727e-02,   4.08025384e-02,   4.20231260e-02,
                          4.33018394e-02,   4.42318097e-02,   4.58011404e-02,
                          4.71379757e-02,   4.80679460e-02,   4.94047813e-02,
                          5.05091250e-02,   5.17878383e-02,   5.32990433e-02,
                          5.44033833e-02,   5.56239709e-02,   5.66701926e-02,
                          5.78907803e-02,   5.93438633e-02,   6.05644509e-02,
                          6.18431643e-02,   6.30056262e-02,   6.41099736e-02,
                          6.54468089e-02,   6.67836443e-02,   6.80042282e-02,
                          6.92248195e-02,   7.05035329e-02,   7.16659948e-02,
                          7.26540908e-02,   7.39328042e-02,   7.53277615e-02,
                          7.64902309e-02,   7.77108148e-02,   7.89314061e-02,
                          8.01519975e-02,   8.13725814e-02,   8.24769214e-02,
                          8.37556347e-02,   8.48599821e-02,   8.58480781e-02,
                          8.72430354e-02,   8.84636194e-02,   8.96260887e-02,
                          9.07885507e-02,   9.18347687e-02,   9.31716040e-02,
                          9.43340734e-02,   9.54384133e-02,   9.67752486e-02,
                          9.77633446e-02,   9.86933187e-02,   9.96814147e-02,
                          1.00495137e-01,   1.01599485e-01,   1.02936320e-01,
                          1.04040660e-01,   1.05086878e-01,   1.06133096e-01,
                          1.07237436e-01,   1.08283661e-01,   1.09213628e-01,
                          1.10201724e-01,   1.11364193e-01,   1.12526655e-01,
                          1.13456629e-01,   1.14560969e-01,   1.15723439e-01,
                          1.16711535e-01,   1.17815875e-01,   1.18803971e-01,
                          1.19850188e-01,   1.20838284e-01,   1.21652015e-01,
                          1.22756355e-01,   1.23628199e-01,   1.24616295e-01,
                          1.25720635e-01,   1.26592487e-01,   1.27580583e-01,
                          1.28510565e-01,   1.29440531e-01,   1.30486742e-01,
                          1.31126106e-01,   1.31997958e-01,   1.33044168e-01,
                          1.33741647e-01,   1.34845987e-01,   1.35834083e-01,
                          1.36473447e-01,   1.37403414e-01,   1.38333395e-01,
                          1.39147118e-01,   1.39844596e-01,   1.40425831e-01,
                          1.41239554e-01,   1.42169520e-01,   1.42925128e-01,
                          1.43622607e-01,   1.44552574e-01,   1.45366311e-01,
                          1.45947546e-01,   1.46645024e-01,   1.47226244e-01,
                          1.47807479e-01,   1.48563087e-01,   1.49086192e-01,
                          1.49783671e-01,   1.50597408e-01,   1.51178628e-01,
                          1.51817992e-01,   1.52224854e-01,   1.52864203e-01,
                          1.53561682e-01,   1.54026672e-01,   1.54782280e-01,
                          1.55305386e-01,   1.55537874e-01,   1.56235352e-01,
                          1.56700343e-01,   1.57165334e-01,   1.57746568e-01,
                          1.58211544e-01,   1.58676535e-01,   1.59257770e-01,
                          1.59722760e-01,   1.60013378e-01,   1.60303995e-01,
                          1.60943344e-01,   1.61233962e-01,   1.61582693e-01,
                          1.62105814e-01,   1.62338302e-01,   1.62745163e-01,
                          1.63035780e-01,   1.63326398e-01,   1.63965762e-01,
                          1.64372623e-01,   1.64663240e-01,   1.64895728e-01,
                          1.65244460e-01,   1.65535077e-01,   1.65651336e-01,
                          1.66116312e-01,   1.66465059e-01,   1.66523173e-01,
                          1.66871920e-01,   1.67104408e-01,   1.67220652e-01,
                          1.67511269e-01,   1.67743772e-01,   1.67976260e-01,
                          1.68092504e-01,   1.68266878e-01,   1.68383121e-01,
                          1.68383121e-01,   1.68615609e-01,   1.68789983e-01,
                          1.68789983e-01,   1.68906227e-01,   1.68906227e-01,
                          1.69080600e-01,   1.69138730e-01,   1.69196844e-01,
                          1.69254974e-01,   1.69080600e-01,   1.69138730e-01,
                          1.69196844e-01,   1.69138730e-01,   1.69254974e-01,
                          1.69080600e-01,   1.69080600e-01,   1.69254974e-01,
                          1.69080600e-01,   1.69080600e-01,   1.69080600e-01,
                          1.69022486e-01,   1.69080600e-01,   1.68848112e-01,
                          1.68906227e-01,   1.69080600e-01,   1.68906227e-01,
                          1.68789983e-01,   1.68557495e-01,   1.68499365e-01,
                          1.68557495e-01,   1.68673739e-01,   1.68499365e-01,
                          1.68092504e-01,   1.68208748e-01,   1.68325007e-01,
                          1.68150634e-01,   1.68150634e-01,   1.67918131e-01,
                          1.67801887e-01,   1.67743772e-01,   1.67627513e-01,
                          1.67801887e-01,   1.67743772e-01,   1.67511269e-01,
                          1.67511269e-01,   1.67395025e-01,   1.67453155e-01,
                          1.67220652e-01,   1.67046294e-01,   1.67220652e-01,
                          1.66813791e-01,   1.66581303e-01,   1.66639417e-01,
                          1.66348815e-01,   1.66348815e-01,   1.66348815e-01,
                          1.66290686e-01,   1.66232556e-01,   1.65941939e-01,
                          1.65883824e-01,   1.65825695e-01,   1.65651336e-01,
                          1.65651336e-01,   1.65476963e-01,   1.65244460e-01,
                          1.65128216e-01,   1.65070102e-01,   1.65128216e-01,
                          1.65128216e-01,   1.65011972e-01,   1.64779484e-01,
                          1.64488867e-01,   1.64605111e-01,   1.64372623e-01,
                          1.64198250e-01,   1.64256364e-01,   1.64198250e-01,
                          1.64314494e-01,   1.64198250e-01,   1.63849503e-01,
                          1.63675144e-01,   1.63617015e-01,   1.63675144e-01,
                          1.63849503e-01,   1.63791388e-01,   1.63675144e-01,
                          1.63500771e-01,   1.63558885e-01,   1.63558885e-01,
                          1.63500771e-01,   1.63558885e-01,   1.63500771e-01,
                          1.63617015e-01,   1.63733259e-01,   1.63791388e-01,
                          1.63907632e-01,   1.63791388e-01,   1.63791388e-01,
                          1.63965762e-01,   1.64023876e-01,   1.64256364e-01,
                          1.64314494e-01,   1.64430737e-01,   1.64721355e-01,
                          1.64721355e-01,   1.64895728e-01,   1.65070102e-01,
                          1.65186346e-01,   1.65360719e-01,   1.65244460e-01,
                          1.65476963e-01,   1.65767580e-01,   1.65767580e-01,
                          1.66058198e-01,   1.66290686e-01,   1.66465059e-01,
                          1.66639417e-01,   1.66697547e-01,   1.66988164e-01,
                          1.67220652e-01,   1.67453155e-01,   1.67801887e-01,
                          1.67860016e-01,   1.68208748e-01,   1.68266878e-01,
                          1.68150634e-01,   1.68789983e-01,   1.69080600e-01,
                          1.69022486e-01,   1.69313088e-01,   1.69719964e-01,
                          1.69952452e-01,   1.70184940e-01,   1.70591801e-01,
                          1.70940548e-01,   1.71056792e-01,   1.71521783e-01,
                          1.71928644e-01,   1.72103018e-01,   1.72626123e-01,
                          1.73032984e-01,   1.73439845e-01,   1.73846707e-01,
                          1.74195454e-01,   1.74427941e-01,   1.74834803e-01,
                          1.75474167e-01,   1.75822899e-01,   1.76171646e-01,
                          1.76636621e-01,   1.77101612e-01,   1.77624717e-01,
                          1.78089708e-01,   1.78438455e-01,   1.79077804e-01,
                          1.79426551e-01,   1.79717168e-01,   1.80298388e-01,
                          1.80705264e-01,   1.81228369e-01,   1.81751475e-01,
                          1.82158336e-01,   1.82739571e-01,   1.83262676e-01,
                          1.83902040e-01,   1.84308901e-01,   1.84657633e-01,
                          1.85355112e-01,   1.85761988e-01,   1.86226964e-01,
                          1.86808199e-01,   1.87389433e-01,   1.88145041e-01,
                          1.88726276e-01,   1.89191252e-01,   1.89772487e-01,
                          1.90004975e-01,   1.90469965e-01,   1.90934956e-01,
                          1.91341817e-01,   1.91981167e-01,   1.92446157e-01,
                          1.92969263e-01,   1.93492383e-01,   1.93899244e-01,
                          1.94480479e-01,   1.95061699e-01,   1.95526689e-01,
                          1.96107924e-01,   1.96805403e-01,   1.97444767e-01,
                          1.97793499e-01,   1.98258489e-01,   1.99072212e-01,
                          1.99595317e-01,   2.00118437e-01,   2.00583413e-01,
                          2.01048404e-01,   2.01745883e-01,   2.02327117e-01,
                          2.02966467e-01,   2.03605831e-01,   2.04012692e-01,
                          2.04593927e-01,   2.05233276e-01,   2.05814511e-01,
                          2.06221372e-01,   2.06628233e-01,   2.07209468e-01,
                          2.07616329e-01,   2.08371937e-01,   2.09243789e-01,
                          2.09650651e-01,   2.10057512e-01,   2.10754991e-01,
                          2.11336225e-01,   2.11917460e-01,   2.12382436e-01,
                          2.12905556e-01,   2.13486791e-01,   2.14126140e-01,
                          2.14707375e-01,   2.15056106e-01,   2.15637341e-01,
                          2.16276705e-01,   2.16683567e-01,   2.17148542e-01,
                          2.17671663e-01,   2.18427256e-01,   2.18892246e-01,
                          2.19299108e-01,   2.19938472e-01,   2.20403448e-01,
                          2.20635951e-01,   2.21042812e-01,   2.21682161e-01,
                          2.22263396e-01,   2.22612143e-01,   2.23019004e-01,
                          2.23367736e-01,   2.23542109e-01,   2.24123344e-01,
                          2.24762693e-01,   2.25111440e-01,   2.25343928e-01,
                          2.25576431e-01,   2.26041406e-01,   2.26506397e-01,
                          2.26971388e-01,   2.27320120e-01,   2.27610737e-01,
                          2.27959484e-01,   2.28133842e-01,   2.28250101e-01,
                          2.28656963e-01,   2.29005694e-01,   2.29354441e-01,
                          2.29819417e-01,   2.30110034e-01,   2.30284408e-01,
                          2.30516896e-01,   2.30807513e-01,   2.31156260e-01,
                          2.31563121e-01,   2.31737494e-01,   2.31795609e-01,
                          2.32028112e-01,   2.32260600e-01,   2.32318729e-01,
                          2.32609347e-01,   2.32841834e-01,   2.32958078e-01,
                          2.33248696e-01,   2.33364940e-01,   2.33597443e-01,
                          2.33888045e-01,   2.34062418e-01,   2.34353036e-01,
                          2.34411165e-01,   2.34353036e-01,   2.34469280e-01,
                          2.34527409e-01,   2.34818026e-01,   2.34759897e-01,
                          2.34585539e-01,   2.34818026e-01,   2.34759897e-01,
                          2.34643653e-01,   2.34818026e-01,   2.34992400e-01,
                          2.35050514e-01,   2.34934270e-01,   2.34876141e-01,
                          2.34759897e-01,   2.34469280e-01,   2.34701782e-01,
                          2.34643653e-01,   2.34469280e-01,   2.34411165e-01,
                          2.34062418e-01,   2.33946174e-01,   2.33946174e-01,
                          2.33655557e-01,   2.33539313e-01,   2.33306825e-01,
                          2.33190566e-01,   2.32899964e-01,   2.32551217e-01,
                          2.32609347e-01,   2.32318729e-01,   2.31911868e-01,
                          2.31795609e-01,   2.31446877e-01,   2.31214374e-01,
                          2.30923772e-01,   2.30633155e-01,   2.30400652e-01,
                          2.30226293e-01,   2.29877546e-01,   2.29238197e-01,
                          2.28889450e-01,   2.28656963e-01,   2.28250101e-01,
                          2.28017598e-01,   2.27668867e-01,   2.27087632e-01,
                          2.26622641e-01,   2.26157650e-01,   2.25750789e-01,
                          2.25460172e-01,   2.24995196e-01,   2.24472076e-01,
                          2.24007100e-01,   2.23542109e-01,   2.22902760e-01,
                          2.22437769e-01,   2.22030908e-01,   2.21507788e-01,
                          2.21100926e-01,   2.20345333e-01,   2.19531611e-01,
                          2.19182864e-01,   2.18427256e-01,   2.17613533e-01,
                          2.17032298e-01,   2.16276705e-01,   2.15695471e-01,
                          2.14997992e-01,   2.14184269e-01,   2.13486791e-01,
                          2.12440565e-01,   2.11684957e-01,   2.10813120e-01,
                          2.09999382e-01,   2.09360033e-01,   2.08488181e-01,
                          2.07616329e-01,   2.06802607e-01,   2.05698267e-01,
                          2.04826415e-01,   2.03722075e-01,   2.02733979e-01,
                          2.01804012e-01,   2.00525299e-01,   1.99711561e-01,
                          1.98781595e-01,   1.97561011e-01,   1.96514785e-01,
                          1.95352316e-01,   1.94480479e-01,   1.93376124e-01,
                          1.91923052e-01,   1.90876827e-01,   1.89656243e-01,
                          1.88377529e-01,   1.87389433e-01,   1.86052606e-01,
                          1.84773892e-01,   1.83495179e-01,   1.82332709e-01,
                          1.81112126e-01,   1.79600909e-01,   1.78205952e-01,
                          1.76869124e-01,   1.75648525e-01,   1.74369827e-01,
                          1.72742367e-01,   1.71405539e-01,   1.70068696e-01,
                          1.68499365e-01,   1.67046294e-01,   1.65302590e-01,
                          1.63675144e-01,   1.62222058e-01,   1.60710856e-01,
                          1.59257770e-01,   1.57746568e-01,   1.56119108e-01,
                          1.54433534e-01,   1.52573586e-01,   1.51062384e-01,
                          1.49376810e-01,   1.47574991e-01,   1.46005660e-01,
                          1.44203842e-01,   1.42460138e-01,   1.40716448e-01,
                          1.38798371e-01,   1.37054682e-01,   1.35136604e-01,
                          1.33218542e-01,   1.31300479e-01,   1.29208043e-01,
                          1.27348095e-01,   1.25546277e-01,   1.23453833e-01,
                          1.21245146e-01,   1.19210832e-01,   1.17409013e-01,
                          1.15374699e-01,   1.13107890e-01,   1.10957332e-01,
                          1.08806767e-01,   1.06714331e-01,   1.04505643e-01,
                          1.02355085e-01,   1.00320771e-01,   9.81702060e-02,
                          9.59615260e-02,   9.36947167e-02,   9.14860293e-02,
                          8.93935934e-02,   8.70105401e-02,   8.46856087e-02,
                          8.25931728e-02,   8.03844854e-02,   7.80595541e-02,
                          7.56765008e-02,   7.33515695e-02,   7.10847601e-02,
                          6.87017068e-02,   6.64930269e-02,   6.41099736e-02,
                          6.17269166e-02,   5.94019853e-02,   5.69026843e-02,
                          5.44615090e-02,   5.20784520e-02,   4.94629070e-02,
                          4.69054803e-02,   4.43480574e-02,   4.20231260e-02,
                          3.96981947e-02,   3.70245241e-02,   3.44089791e-02,
                          3.19096781e-02,   2.93522533e-02,   2.67367065e-02,
                          2.40049120e-02,   2.15056110e-02,   1.89481881e-02,
                          1.62745174e-02,   1.36589697e-02,   1.09852990e-02,
                          8.36975127e-03,   5.52171096e-03,   2.61554727e-03,
                          5.81232744e-05,  -2.67367065e-03,  -5.40546421e-03,
                         -8.07913486e-03,  -1.09271752e-02,  -1.35427229e-02,
                         -1.63907632e-02,  -1.91806797e-02,  -2.18543503e-02,
                         -2.48767603e-02,  -2.76085548e-02,  -3.03984713e-02,
                         -3.34208831e-02,  -3.60364281e-02,  -3.87682244e-02,
                         -4.16162647e-02,  -4.44643050e-02,  -4.73704673e-02,
                         -5.01603857e-02,  -5.29503003e-02,  -5.57402186e-02,
                         -5.85882589e-02,  -6.15525469e-02,  -6.43424615e-02,
                         -6.72486275e-02,  -7.01547936e-02,  -7.28865862e-02,
                         -7.57346228e-02,  -7.85245448e-02,  -8.13144594e-02,
                         -8.40462521e-02,  -8.67199227e-02,  -8.96842107e-02,
                         -9.26484987e-02,  -9.54965353e-02,  -9.82864574e-02,
                         -1.01192616e-01,  -1.04156904e-01,  -1.06888697e-01,
                         -1.09736741e-01,  -1.12526655e-01,  -1.15200326e-01,
                         -1.18280858e-01,  -1.21187024e-01,  -1.23918816e-01,
                         -1.27057478e-01,  -1.30021766e-01,  -1.32811680e-01,
                         -1.35659724e-01,  -1.38565883e-01,  -1.41355798e-01,
                         -1.44087598e-01,  -1.47110000e-01,  -1.50016174e-01,
                         -1.52806088e-01,  -1.56060994e-01,  -1.58909023e-01,
                         -1.61698952e-01,  -1.64663240e-01,  -1.67453155e-01,
                         -1.70475557e-01,  -1.73497975e-01,  -1.76346019e-01,
                         -1.79484665e-01,  -1.82274580e-01,  -1.85122624e-01,
                         -1.88028783e-01,  -1.90876827e-01,  -1.93783000e-01,
                         -1.96572915e-01,  -1.99479073e-01,  -2.02501491e-01,
                         -2.05407649e-01,  -2.08430052e-01,  -2.11336225e-01,
                         -2.14184269e-01,  -2.16974184e-01,  -2.19647855e-01,
                         -2.22612143e-01,  -2.25402057e-01,  -2.28075728e-01,
                         -2.31156260e-01,  -2.34004304e-01,  -2.36736089e-01,
                         -2.39642262e-01,  -2.42315933e-01,  -2.45105848e-01,
                         -2.47895762e-01,  -2.50801921e-01,  -2.53708094e-01,
                         -2.56439894e-01,  -2.59171665e-01,  -2.62019724e-01,
                         -2.64751524e-01,  -2.67308921e-01,  -2.70040721e-01,
                         -2.73063153e-01,  -2.75794923e-01,  -2.78468609e-01,
                         -2.81200409e-01,  -2.83699691e-01,  -2.86373377e-01,
                         -2.89105147e-01,  -2.91953206e-01,  -2.94743121e-01,
                         -2.97184289e-01,  -2.99916089e-01,  -3.02473515e-01,
                         -3.04972827e-01,  -3.07937115e-01,  -3.10552657e-01,
                         -3.13226312e-01,  -3.16016227e-01,  -3.18515539e-01,
                         -3.21189195e-01,  -3.23979139e-01,  -3.26594681e-01,
                         -3.29152107e-01,  -3.31535161e-01,  -3.34383190e-01,
                         -3.37114990e-01,  -3.39381784e-01,  -3.42113584e-01,
                         -3.44671011e-01,  -3.46995950e-01,  -3.49553376e-01,
                         -3.52227032e-01,  -3.54842573e-01,  -3.57283771e-01,
                         -3.59666824e-01,  -3.62224251e-01,  -3.64607304e-01,
                         -3.67048472e-01,  -3.69373411e-01,  -3.71814579e-01,
                         -3.74488264e-01,  -3.76696944e-01,  -3.79079998e-01,
                         -3.81463051e-01,  -3.83671731e-01,  -3.86054784e-01,
                         -3.88321579e-01,  -3.90472144e-01,  -3.92797083e-01,
                         -3.94947648e-01,  -3.97214442e-01,  -3.99306893e-01,
                         -4.01515573e-01,  -4.03956741e-01,  -4.06049192e-01,
                         -4.08025384e-01,  -4.10117805e-01,  -4.12210256e-01,
                         -4.14186448e-01,  -4.16162640e-01,  -4.18545693e-01,
                         -4.20696259e-01,  -4.22498077e-01,  -4.24590498e-01,
                         -4.26508576e-01,  -4.28426653e-01,  -4.30519074e-01,
                         -4.32495266e-01,  -4.34587717e-01,  -4.36563909e-01,
                         -4.38307613e-01,  -4.40109432e-01,  -4.42085624e-01,
                         -4.44119930e-01,  -4.45863634e-01,  -4.47607338e-01,
                         -4.49757904e-01,  -4.51559722e-01,  -4.53245282e-01,
                         -4.55047101e-01,  -4.56848919e-01,  -4.58592623e-01,
                         -4.60161954e-01,  -4.61963773e-01,  -4.63707477e-01,
                         -4.65393037e-01,  -4.67194885e-01,  -4.68647957e-01,
                         -4.70159173e-01,  -4.71844733e-01,  -4.73297805e-01,
                         -4.75157768e-01,  -4.76901472e-01,  -4.78238285e-01,
                         -4.79633242e-01,  -4.81086344e-01,  -4.82539415e-01,
                         -4.83876258e-01,  -4.85213101e-01,  -4.86608058e-01,
                         -4.88061130e-01,  -4.89397973e-01,  -4.90502298e-01,
                         -4.91781026e-01,  -4.93117839e-01,  -4.94280308e-01,
                         -4.95559037e-01,  -4.96663362e-01,  -4.97825831e-01,
                         -4.99162674e-01,  -5.00034511e-01,  -5.01138866e-01,
                         -5.02359450e-01,  -5.03231287e-01,  -5.04103124e-01,
                         -5.05091250e-01,  -5.06079316e-01,  -5.07009327e-01,
                         -5.07997394e-01,  -5.09101748e-01,  -5.09973586e-01,
                         -5.10787308e-01,  -5.11542916e-01,  -5.12124181e-01,
                         -5.12937903e-01,  -5.13751626e-01,  -5.14449120e-01,
                         -5.15262842e-01,  -5.16134679e-01,  -5.16948402e-01,
                         -5.17529607e-01,  -5.18227100e-01,  -5.18866479e-01,
                         -5.19331455e-01,  -5.19912660e-01,  -5.20435810e-01,
                         -5.20958900e-01,  -5.21540105e-01,  -5.21888852e-01,
                         -5.22412002e-01,  -5.23051322e-01,  -5.23458183e-01,
                         -5.24039447e-01,  -5.24446309e-01,  -5.24736941e-01,
                         -5.25085628e-01,  -5.25201917e-01,  -5.25550663e-01,
                         -5.25841236e-01,  -5.26015639e-01,  -5.26364386e-01,
                         -5.26538730e-01,  -5.26829362e-01,  -5.27061820e-01,
                         -5.27061820e-01,  -5.27410567e-01,  -5.27584970e-01,
                         -5.27410567e-01,  -5.27352452e-01,  -5.27468681e-01,
                         -5.27643085e-01,  -5.27468681e-01,  -5.27294338e-01,
                         -5.27294338e-01,  -5.27178109e-01,  -5.27119994e-01,
                         -5.26945591e-01,  -5.26713133e-01,  -5.26538730e-01,
                         -5.26248097e-01,  -5.26015639e-01,  -5.25783122e-01,
                         -5.25550663e-01,  -5.25260031e-01,  -5.24795055e-01,
                         -5.24446309e-01,  -5.23923159e-01,  -5.23400068e-01,
                         -5.23225725e-01,  -5.22818863e-01,  -5.22528231e-01,
                         -5.22121370e-01,  -5.21365762e-01,  -5.21133244e-01,
                         -5.20610154e-01,  -5.19680202e-01,  -5.19215226e-01,
                         -5.18633962e-01,  -5.17994642e-01,  -5.17529607e-01,
                         -5.16832173e-01,  -5.16134679e-01,  -5.15437186e-01,
                         -5.14739692e-01,  -5.14042258e-01,  -5.13286650e-01,
                         -5.12763500e-01,  -5.12066066e-01,  -5.11310458e-01,
                         -5.10496736e-01,  -5.09566724e-01,  -5.08578658e-01,
                         -5.07706821e-01,  -5.06834924e-01,  -5.05904973e-01,
                         -5.04975021e-01,  -5.04103124e-01,  -5.03056943e-01,
                         -5.02185106e-01,  -5.01138866e-01,  -4.99860138e-01,
                         -4.98755813e-01,  -4.97709602e-01,  -4.96488988e-01,
                         -4.95442778e-01,  -4.94338453e-01,  -4.93059725e-01,
                         -4.91664767e-01,  -4.90386069e-01,  -4.89281714e-01,
                         -4.88003016e-01,  -4.86724287e-01,  -4.85503703e-01,
                         -4.83876258e-01,  -4.82423156e-01,  -4.81144458e-01,
                         -4.79691386e-01,  -4.78180170e-01,  -4.76668954e-01,
                         -4.75332141e-01,  -4.73937184e-01,  -4.72367853e-01,
                         -4.70914751e-01,  -4.69403565e-01,  -4.67776090e-01,
                         -4.66148645e-01,  -4.64463085e-01,  -4.62893754e-01,
                         -4.61324424e-01,  -4.59696978e-01,  -4.57953274e-01,
                         -4.56267685e-01,  -4.54698354e-01,  -4.53012794e-01,
                         -4.51152861e-01,  -4.49409157e-01,  -4.47607338e-01,
                         -4.45921749e-01,  -4.43945557e-01,  -4.42027479e-01,
                         -4.40458179e-01,  -4.38481987e-01,  -4.36622024e-01,
                         -4.34762090e-01,  -4.32727784e-01,  -4.30925936e-01,
                         -4.28949744e-01,  -4.26973581e-01,  -4.25055504e-01,
                         -4.22904938e-01,  -4.20928746e-01,  -4.18836296e-01,
                         -4.16569501e-01,  -4.14767683e-01,  -4.12675232e-01,
                         -4.10582811e-01,  -4.08432245e-01,  -4.06107306e-01,
                         -4.04189229e-01,  -4.02038693e-01,  -3.99713755e-01,
                         -3.97388816e-01,  -3.94947648e-01,  -3.92855197e-01,
                         -3.90588403e-01,  -3.88205349e-01,  -3.85822296e-01,
                         -3.83322984e-01,  -3.80998045e-01,  -3.78673136e-01,
                         -3.76231939e-01,  -3.73848885e-01,  -3.71349603e-01,
                         -3.68850291e-01,  -3.66350979e-01,  -3.63909811e-01,
                         -3.61526757e-01,  -3.58853102e-01,  -3.56295675e-01,
                         -3.53796363e-01,  -3.51180822e-01,  -3.48681509e-01,
                         -3.46007854e-01,  -3.43276054e-01,  -3.40602368e-01,
                         -3.37928712e-01,  -3.35661918e-01,  -3.32930118e-01,
                         -3.30023944e-01,  -3.27408403e-01,  -3.24618489e-01,
                         -3.21886688e-01,  -3.19154888e-01,  -3.16364974e-01,
                         -3.13749433e-01,  -3.10901403e-01,  -3.08053344e-01,
                         -3.05379689e-01,  -3.02531630e-01,  -2.99799830e-01,
                         -2.96777427e-01,  -2.93929398e-01,  -2.91313857e-01,
                         -2.88291425e-01,  -2.85385281e-01,  -2.82827854e-01,
                         -2.79921681e-01,  -2.76899278e-01,  -2.74051219e-01,
                         -2.71086961e-01,  -2.68064529e-01,  -2.65216500e-01,
                         -2.62310326e-01,  -2.59113550e-01,  -2.56149262e-01,
                         -2.53126860e-01,  -2.50046313e-01,  -2.47256398e-01,
                         -2.44292125e-01,  -2.41095334e-01,  -2.37956688e-01,
                         -2.34876141e-01,  -2.31853738e-01,  -2.28715077e-01,
                         -2.25634545e-01,  -2.22670257e-01,  -2.19531611e-01,
                         -2.16509193e-01,  -2.13196173e-01,  -2.10057512e-01,
                         -2.07093224e-01,  -2.03780189e-01,  -2.00757787e-01,
                         -1.97444767e-01,  -1.94015488e-01,  -1.91109329e-01,
                         -1.87854424e-01,  -1.84715763e-01,  -1.81693345e-01,
                         -1.78438455e-01,  -1.75532281e-01,  -1.72219262e-01,
                         -1.69022486e-01,  -1.66058198e-01,  -1.62745163e-01,
                         -1.59722760e-01,  -1.56467855e-01,  -1.53096706e-01,
                         -1.50190532e-01,  -1.46935642e-01,  -1.43564492e-01,
                         -1.40425831e-01,  -1.37170926e-01,  -1.33857906e-01,
                         -1.30603001e-01,  -1.27580583e-01,  -1.24441929e-01,
                         -1.21187024e-01,  -1.17932118e-01,  -1.14444725e-01,
                         -1.11422315e-01,  -1.08458027e-01,  -1.05203122e-01,
                         -1.02180712e-01,  -9.90420580e-02,  -9.57290307e-02,
                         -9.24741253e-02,  -8.92773494e-02,  -8.61968175e-02,
                         -8.27675387e-02,  -7.94545114e-02,  -7.64321014e-02,
                         -7.32353255e-02,  -6.99804202e-02,  -6.66673928e-02,
                         -6.34706169e-02,  -6.05644509e-02,  -5.73095493e-02,
                         -5.44615090e-02,  -5.15553430e-02,  -4.81260717e-02,
                         -4.48130444e-02,  -4.16743867e-02,  -3.84776071e-02,
                         -3.52227055e-02,  -3.21421698e-02,  -2.92941295e-02,
                         -2.60392260e-02,  -2.27262005e-02,  -1.95294190e-02,
                         -1.62745174e-02,  -1.33683532e-02,  -1.04040662e-02,
                         -7.20728608e-03,  -4.30112239e-03,  -1.39495858e-03,
                          1.62745162e-03,   4.64986172e-03,   7.67227216e-03,
                          1.05784358e-02,   1.35427229e-02,   1.63326394e-02,
                          1.90644339e-02,   2.20868438e-02,   2.48767603e-02,
                          2.76085548e-02,   3.05728409e-02,   3.34790051e-02,
                          3.62107977e-02,   3.90007161e-02,   4.17325087e-02,
                          4.44643050e-02,   4.72542197e-02,   4.99278903e-02,
                          5.25434390e-02,   5.52171096e-02,   5.77745326e-02,
                          6.05063289e-02,   6.31799996e-02,   6.57374188e-02,
                          6.84692189e-02,   7.10266382e-02,   7.32934475e-02,
                          7.59671181e-02,   7.86407888e-02,   8.10238421e-02,
                          8.35812688e-02,   8.59643221e-02,   8.84054974e-02,
                          9.09048021e-02,   9.32297334e-02,   9.58452746e-02,
                          9.82283354e-02,   1.00437015e-01,   1.02994442e-01,
                          1.05145000e-01,   1.07411809e-01,   1.09852985e-01,
                          1.12003550e-01,   1.14270352e-01,   1.16537161e-01,
                          1.18803971e-01,   1.21070780e-01,   1.23105094e-01,
                          1.25313774e-01,   1.27522469e-01,   1.29731148e-01,
                          1.31765455e-01,   1.33857906e-01,   1.36066586e-01,
                          1.37984648e-01,   1.40135214e-01,   1.42343894e-01,
                          1.44145712e-01,   1.46121904e-01,   1.48039982e-01,
                          1.49899915e-01,   1.51934236e-01,   1.53852299e-01,
                          1.55654132e-01,   1.57397822e-01,   1.59432143e-01,
                          1.61292091e-01,   1.62977666e-01,   1.65011972e-01,
                          1.66639417e-01,   1.68208748e-01,   1.70010582e-01,
                          1.71579897e-01,   1.73381731e-01,   1.75067306e-01,
                          1.76636621e-01,   1.78554699e-01,   1.80007771e-01,
                          1.81635231e-01,   1.83495179e-01,   1.84948251e-01,
                          1.86633825e-01,   1.88261285e-01,   1.89772487e-01,
                          1.91458061e-01,   1.92911148e-01,   1.94480479e-01,
                          1.95875436e-01,   1.97386637e-01,   1.99188456e-01,
                          2.00699657e-01,   2.02094615e-01,   2.03373328e-01,
                          2.04768285e-01,   2.06511989e-01,   2.07906947e-01,
                          2.09243789e-01,   2.10871235e-01,   2.12208077e-01,
                          2.13661149e-01,   2.15114236e-01,   2.16509193e-01,
                          2.18078524e-01,   2.19473481e-01,   2.20868438e-01,
                          2.22263396e-01,   2.23542109e-01,   2.24878952e-01,
                          2.26215780e-01,   2.27494493e-01,   2.28889450e-01,
                          2.30342537e-01,   2.31621251e-01,   2.32667461e-01,
                          2.34062418e-01,   2.35399261e-01,   2.36387357e-01,
                          2.37549812e-01,   2.38828525e-01,   2.39932880e-01,
                          2.41153464e-01,   2.42374048e-01,   2.43594632e-01,
                          2.44815230e-01,   2.45977700e-01,   2.47082040e-01,
                          2.48128250e-01,   2.49348849e-01,   2.50395060e-01,
                          2.51499414e-01,   2.52836227e-01,   2.53940582e-01,
                          2.54986793e-01,   2.55916774e-01,   2.56962985e-01,
                          2.58067340e-01,   2.59113550e-01,   2.60276020e-01,
                          2.61322230e-01,   2.62310326e-01,   2.63472795e-01,
                          2.64402777e-01,   2.65332729e-01,   2.66437083e-01,
                          2.67483294e-01,   2.68471390e-01,   2.69226998e-01,
                          2.70331353e-01,   2.71668166e-01,   2.72423774e-01,
                          2.73295641e-01,   2.74225593e-01,   2.74923086e-01,
                          2.75969297e-01,   2.76957393e-01,   2.77945489e-01,
                          2.78817356e-01,   2.79631078e-01,   2.80677289e-01,
                          2.81607270e-01,   2.82420993e-01,   2.83467203e-01,
                          2.84280926e-01,   2.85094649e-01,   2.85908371e-01,
                          2.86838353e-01,   2.87768334e-01,   2.88582057e-01,
                          2.89628267e-01,   2.90441990e-01,   2.90965110e-01,
                          2.92069435e-01,   2.92766929e-01,   2.93290049e-01,
                          2.94278145e-01,   2.94975609e-01,   2.95847476e-01,
                          2.96777427e-01,   2.97416776e-01,   2.98172385e-01,
                          2.98811734e-01,   2.99392968e-01,   3.00322950e-01,
                          3.00962299e-01,   3.01543534e-01,   3.02299142e-01,
                          3.03054750e-01,   3.03635985e-01,   3.04275334e-01,
                          3.05089056e-01,   3.05728406e-01,   3.06309640e-01,
                          3.06949019e-01,   3.07413995e-01,   3.08053344e-01,
                          3.08808953e-01,   3.09506416e-01,   3.10087651e-01,
                          3.10668886e-01,   3.11482608e-01,   3.12063843e-01,
                          3.12761337e-01,   3.13516945e-01,   3.14040035e-01,
                          3.14563155e-01,   3.15202504e-01,   3.15725625e-01,
                          3.16306859e-01,   3.16888094e-01,   3.17527443e-01,
                          3.17992419e-01,   3.18515539e-01,   3.19271147e-01,
                          3.19619894e-01,   3.20259243e-01,   3.21014851e-01,
                          3.21247339e-01,   3.21828574e-01,   3.22584182e-01,
                          3.22991043e-01,   3.23456019e-01,   3.23920995e-01,
                          3.24444115e-01,   3.24967235e-01,   3.25432211e-01,
                          3.25839072e-01,   3.26129675e-01,   3.26652795e-01,
                          3.27175915e-01,   3.27640891e-01,   3.28222126e-01,
                          3.28745246e-01,   3.29093963e-01,   3.29500824e-01,
                          3.29849571e-01,   3.30198318e-01,   3.30547065e-01,
                          3.30953926e-01,   3.31244528e-01,   3.31418902e-01,
                          3.31825763e-01,   3.32232624e-01,   3.32523257e-01,
                          3.32930118e-01,   3.33220720e-01,   3.33511353e-01,
                          3.33743840e-01,   3.33918214e-01,   3.34325075e-01,
                          3.34731936e-01,   3.35080683e-01,   3.35429400e-01,
                          3.35429400e-01,   3.35487545e-01,   3.35836262e-01,
                          3.36185008e-01,   3.36359382e-01,   3.36591870e-01,
                          3.36824358e-01,   3.36998731e-01,   3.37173104e-01,
                          3.37405592e-01,   3.37463737e-01,   3.37579966e-01,
                          3.37870598e-01,   3.38103086e-01,   3.38335574e-01,
                          3.38509947e-01,   3.38684320e-01,   3.38800550e-01,
                          3.38742435e-01,   3.38684320e-01,   3.38800550e-01,
                          3.38974923e-01,   3.39033067e-01,   3.39091182e-01,
                          3.39149296e-01,   3.39149296e-01,   3.39265555e-01,
                          3.39323670e-01,   3.39323670e-01,   3.39323670e-01,
                          3.39149296e-01,   3.38916808e-01,   3.38858694e-01,
                          3.38800550e-01,   3.38742435e-01,   3.38684320e-01,
                          3.38568062e-01,   3.38626176e-01,   3.38509947e-01,
                          3.38393688e-01,   3.38393688e-01,   3.38161200e-01,
                          3.37986827e-01,   3.37812454e-01,   3.37521851e-01,
                          3.37347478e-01,   3.36998731e-01,   3.36824358e-01,
                          3.36650014e-01,   3.36185008e-01,   3.36010635e-01,
                          3.35894406e-01,   3.35778147e-01,   3.35545659e-01,
                          3.35138798e-01,   3.34615678e-01,   3.34266931e-01,
                          3.34034443e-01,   3.33685726e-01,   3.33336979e-01,
                          3.32988232e-01,   3.32523257e-01,   3.32116395e-01,
                          3.31825763e-01,   3.31360787e-01,   3.31244528e-01,
                          3.30895782e-01,   3.30198318e-01,   3.29791456e-01,
                          3.29442710e-01,   3.28861475e-01,   3.28280240e-01,
                          3.27931523e-01,   3.27524632e-01,   3.26943427e-01,
                          3.26362193e-01,   3.25897187e-01,   3.25548440e-01,
                          3.25025350e-01,   3.24386001e-01,   3.23746622e-01,
                          3.23049158e-01,   3.22642297e-01,   3.22235435e-01,
                          3.21363568e-01,   3.20666105e-01,   3.20201099e-01,
                          3.19387376e-01,   3.18748027e-01,   3.18108678e-01,
                          3.17469329e-01,   3.16829950e-01,   3.15958112e-01,
                          3.15376878e-01,   3.14679414e-01,   3.13807547e-01,
                          3.13226312e-01,   3.12354475e-01,   3.11482608e-01,
                          3.10668886e-01,   3.09797049e-01,   3.09099555e-01,
                          3.08169603e-01,   3.07239622e-01,   3.06658387e-01,
                          3.05902779e-01,   3.04914683e-01,   3.03984731e-01,
                          3.03171009e-01,   3.02357256e-01,   3.01427305e-01,
                          3.00439209e-01,   2.99392968e-01,   2.98404872e-01,
                          2.97533035e-01,   2.96486825e-01,   2.95440584e-01,
                          2.94452488e-01,   2.93522537e-01,   2.92708814e-01,
                          2.91604459e-01,   2.90674478e-01,   2.89860755e-01,
                          2.88640171e-01,   2.87593961e-01,   2.86722094e-01,
                          2.85443395e-01,   2.84280926e-01,   2.83409089e-01,
                          2.82420993e-01,   2.81258523e-01,   2.79979795e-01,
                          2.79049844e-01,   2.78003603e-01,   2.76666790e-01,
                          2.75446206e-01,   2.74458110e-01,   2.73353755e-01,
                          2.72249401e-01,   2.71145076e-01,   2.69982606e-01,
                          2.68645763e-01,   2.67425179e-01,   2.66262710e-01,
                          2.64984012e-01,   2.63705283e-01,   2.62426585e-01,
                          2.61322230e-01,   2.59927273e-01,   2.58474201e-01,
                          2.57253617e-01,   2.55916774e-01,   2.54521817e-01,
                          2.53184974e-01,   2.51731902e-01,   2.50395060e-01,
                          2.48883858e-01,   2.47488901e-01,   2.46152058e-01,
                          2.44640857e-01,   2.43245900e-01,   2.41909057e-01,
                          2.40514100e-01,   2.39119142e-01,   2.37549812e-01,
                          2.36038610e-01,   2.34527409e-01,   2.33016208e-01,
                          2.31621251e-01,   2.30226293e-01,   2.28947580e-01,
                          2.27552623e-01,   2.25867033e-01,   2.24297717e-01,
                          2.22786501e-01,   2.21333429e-01,   2.19647855e-01,
                          2.18020394e-01,   2.16625437e-01,   2.15114236e-01,
                          2.13719279e-01,   2.12033704e-01,   2.10406244e-01,
                          2.08895043e-01,   2.07209468e-01,   2.05698267e-01,
                          2.04187065e-01,   2.02327117e-01,   2.00815916e-01,
                          1.99362829e-01,   1.97677255e-01,   1.95991680e-01,
                          1.94247976e-01,   1.92678645e-01,   1.90993071e-01,
                          1.89191252e-01,   1.87621921e-01,   1.85936347e-01,
                          1.84367016e-01,   1.82739571e-01,   1.80937752e-01,
                          1.79310292e-01,   1.77566603e-01,   1.75764784e-01,
                          1.73962951e-01,   1.72103018e-01,   1.70533687e-01,
                          1.68789983e-01,   1.66871920e-01,   1.65186346e-01,
                          1.63268268e-01,   1.61466449e-01,   1.59839004e-01,
                          1.57920927e-01,   1.56002864e-01,   1.54084802e-01,
                          1.52224854e-01,   1.50423035e-01,   1.48621216e-01,
                          1.46761268e-01,   1.44843191e-01,   1.42925128e-01,
                          1.40948936e-01,   1.39088988e-01,   1.37287170e-01,
                          1.35369107e-01,   1.33509159e-01,   1.31649211e-01,
                          1.29556775e-01,   1.27754956e-01,   1.25953138e-01,
                          1.24035068e-01,   1.22000754e-01,   1.20024562e-01,
                          1.18164614e-01,   1.16304673e-01,   1.14444725e-01,
                          1.12526655e-01,   1.10492341e-01,   1.08632401e-01,
                          1.06656209e-01,   1.04621895e-01,   1.02936320e-01,
                          1.01018250e-01,   9.89258140e-02,   9.69496220e-02,
                          9.47409347e-02,   9.25903767e-02,   9.06141847e-02,
                          8.87542367e-02,   8.68942961e-02,   8.48018527e-02,
                          8.28256682e-02,   8.07913467e-02,   7.86989108e-02,
                          7.66645968e-02,   7.46302828e-02,   7.27703348e-02,
                          7.07360208e-02,   6.86435848e-02,   6.67255148e-02,
                          6.45749569e-02,   6.26568869e-02,   6.07388206e-02,
                          5.84138893e-02,   5.64376973e-02,   5.43452613e-02,
                          5.20784520e-02,   5.02185076e-02,   4.81260717e-02,
                          4.60336320e-02,   4.41155657e-02,   4.20812517e-02,
                          3.99306901e-02,   3.78382504e-02,   3.58620584e-02,
                          3.37696224e-02,   3.16771828e-02,   2.95847468e-02,
                          2.75504310e-02,   2.56323628e-02,   2.35980488e-02,
                          2.15056110e-02,   1.94131732e-02,   1.73207354e-02,
                          1.53445443e-02,   1.34264762e-02,   1.12177916e-02,
                          9.18347761e-03,   7.38165574e-03,   5.28921792e-03,
                          3.25490325e-03,   1.27871206e-03,  -6.97479292e-04,
                         -2.73179379e-03,  -4.70798509e-03,  -6.56792987e-03,
                         -8.54412094e-03,  -1.05203129e-02,  -1.24965040e-02,
                         -1.45889418e-02,  -1.66232567e-02,  -1.84250772e-02,
                         -2.03431454e-02,  -2.23193374e-02,  -2.41211578e-02,
                         -2.61554737e-02,  -2.82479115e-02,  -3.00497320e-02,
                         -3.20259221e-02,  -3.40021141e-02,  -3.57458144e-02,
                         -3.78963761e-02,  -4.00469340e-02,  -4.17906344e-02,
                         -4.38249484e-02,  -4.58011404e-02,  -4.76029627e-02,
                         -4.95210290e-02,  -5.12647256e-02,  -5.32409176e-02,
                         -5.51589876e-02,  -5.70189320e-02,  -5.91113679e-02,
                         -6.08550683e-02,  -6.26568869e-02,  -6.46912009e-02,
                         -6.65511489e-02,  -6.82948455e-02,  -7.00966641e-02,
                         -7.19566122e-02,  -7.38746822e-02,  -7.56765008e-02,
                         -7.74783269e-02,  -7.92220235e-02,  -8.10238421e-02,
                         -8.27675387e-02,  -8.45693648e-02,  -8.66036788e-02,
                         -8.84054974e-02,  -9.00329500e-02,  -9.18347687e-02,
                         -9.34622213e-02,  -9.52059254e-02,  -9.70077440e-02,
                         -9.86933187e-02,  -1.00437015e-01,  -1.02122590e-01,
                         -1.03750043e-01,  -1.05319373e-01,  -1.07004948e-01,
                         -1.08806767e-01,  -1.10550463e-01,  -1.12236038e-01,
                         -1.13747247e-01,  -1.15258448e-01,  -1.16827779e-01,
                         -1.18338987e-01,  -1.19966440e-01,  -1.21535763e-01,
                         -1.22988850e-01,  -1.24674425e-01,  -1.26185626e-01,
                         -1.27813071e-01,  -1.29324287e-01,  -1.30544871e-01,
                         -1.32056072e-01,  -1.33799776e-01,  -1.35252863e-01,
                         -1.36764064e-01,  -1.38333395e-01,  -1.39728352e-01,
                         -1.41239554e-01,  -1.42808884e-01,  -1.44203842e-01,
                         -1.45482555e-01,  -1.46993756e-01,  -1.48388714e-01,
                         -1.49783671e-01,  -1.51294887e-01,  -1.52515471e-01,
                         -1.53794184e-01,  -1.55421630e-01,  -1.56932831e-01,
                         -1.58211544e-01,  -1.59432143e-01,  -1.60710856e-01,
                         -1.62163928e-01,  -1.63326398e-01,  -1.64721355e-01,
                         -1.66290686e-01,  -1.67278782e-01,  -1.68557495e-01,
                         -1.69836208e-01,  -1.70998678e-01,  -1.72335505e-01,
                         -1.73381731e-01,  -1.74602315e-01,  -1.75881028e-01,
                         -1.76752880e-01,  -1.77857220e-01,  -1.79135934e-01,
                         -1.80240273e-01,  -1.81344613e-01,  -1.82448953e-01,
                         -1.83611423e-01,  -1.84541389e-01,  -1.85471371e-01,
                         -1.86691955e-01,  -1.87796295e-01,  -1.88726276e-01,
                         -1.89714357e-01,  -1.90760583e-01,  -1.91806808e-01,
                         -1.92620531e-01,  -1.93492383e-01,  -1.94422349e-01,
                         -1.95177957e-01,  -1.95933551e-01,  -1.96863532e-01,
                         -1.97851628e-01,  -1.98723465e-01,  -1.99537203e-01,
                         -2.00467169e-01,  -2.01397136e-01,  -2.02210873e-01,
                         -2.02850223e-01,  -2.03663945e-01,  -2.04477683e-01,
                         -2.05058903e-01,  -2.05814511e-01,  -2.06686363e-01,
                         -2.07325712e-01,  -2.07965076e-01,  -2.08546311e-01,
                         -2.09301904e-01,  -2.09999382e-01,  -2.10696861e-01,
                         -2.11510599e-01,  -2.12149948e-01,  -2.12614939e-01,
                         -2.13312417e-01,  -2.14009896e-01,  -2.14707375e-01,
                         -2.15172365e-01,  -2.15637341e-01,  -2.16276705e-01,
                         -2.16741681e-01,  -2.17206672e-01,  -2.17904150e-01,
                         -2.18369141e-01,  -2.18601629e-01,  -2.18950376e-01,
                         -2.19473481e-01,  -2.19880342e-01,  -2.20229089e-01,
                         -2.20810309e-01,  -2.21159056e-01,  -2.21333429e-01,
                         -2.21856534e-01,  -2.21972778e-01,  -2.22147152e-01,
                         -2.22495884e-01,  -2.22554013e-01,  -2.22786501e-01,
                         -2.23077118e-01,  -2.23135248e-01,  -2.23425865e-01,
                         -2.23542109e-01,  -2.23716483e-01,  -2.23890856e-01,
                         -2.23890856e-01,  -2.24123344e-01,  -2.24239588e-01,
                         -2.24239588e-01,  -2.24355832e-01,  -2.24297717e-01,
                         -2.24413961e-01,  -2.24588335e-01,  -2.24588335e-01,
                         -2.24413961e-01,  -2.24297717e-01,  -2.24413961e-01,
                         -2.24239588e-01,  -2.23948970e-01,  -2.23948970e-01,
                         -2.23948970e-01,  -2.23890856e-01,  -2.23774597e-01,
                         -2.23600239e-01,  -2.23425865e-01,  -2.23193377e-01,
                         -2.23193377e-01,  -2.23077118e-01,  -2.22786501e-01,
                         -2.22612143e-01,  -2.22379640e-01,  -2.22089022e-01,
                         -2.22147152e-01,  -2.21798405e-01,  -2.21507788e-01,
                         -2.21449673e-01,  -2.21042812e-01,  -2.20519707e-01,
                         -2.20403448e-01,  -2.20170960e-01,  -2.19705969e-01,
                         -2.19240993e-01,  -2.18892246e-01,  -2.18717873e-01,
                         -2.18485385e-01,  -2.18078524e-01,  -2.17729777e-01,
                         -2.17439160e-01,  -2.17032298e-01,  -2.16567323e-01,
                         -2.16044202e-01,  -2.15637341e-01,  -2.15114236e-01,
                         -2.14474872e-01,  -2.14068010e-01,  -2.13486791e-01,
                         -2.12905556e-01,  -2.12382436e-01,  -2.11626843e-01,
                         -2.11161852e-01,  -2.10696861e-01,  -2.09941268e-01,
                         -2.09243789e-01,  -2.08488181e-01,  -2.07965076e-01,
                         -2.07558215e-01,  -2.06686363e-01,  -2.06046999e-01,
                         -2.05465779e-01,  -2.04652041e-01,  -2.04070807e-01,
                         -2.03315213e-01,  -2.02617735e-01,  -2.01862127e-01,
                         -2.00990275e-01,  -2.00234681e-01,  -1.99362829e-01,
                         -1.98607221e-01,  -1.97909743e-01,  -1.96979776e-01,
                         -1.96224168e-01,  -1.95410445e-01,  -1.94654837e-01,
                         -1.93841115e-01,  -1.92794904e-01,  -1.92039296e-01,
                         -1.91225573e-01,  -1.90295592e-01,  -1.89481869e-01,
                         -1.88668147e-01,  -1.87621921e-01,  -1.86691955e-01,
                         -1.85994476e-01,  -1.85355112e-01,  -1.84250772e-01,
                         -1.83262676e-01,  -1.82332709e-01,  -1.81402743e-01,
                         -1.80472761e-01,  -1.79368421e-01,  -1.78438455e-01,
                         -1.77566603e-01,  -1.76462263e-01,  -1.75474167e-01,
                         -1.74369827e-01,  -1.73323601e-01,  -1.72451749e-01,
                         -1.71347409e-01,  -1.70359313e-01,  -1.69196844e-01,
                         -1.68034390e-01,  -1.66930035e-01,  -1.65767580e-01,
                         -1.64663240e-01,  -1.63558885e-01,  -1.62338302e-01,
                         -1.61059588e-01,  -1.59897119e-01,  -1.58909023e-01,
                         -1.57630324e-01,  -1.56409726e-01,  -1.55189142e-01,
                         -1.53852299e-01,  -1.52864203e-01,  -1.51585504e-01,
                         -1.50248662e-01,  -1.49202436e-01,  -1.47865608e-01,
                         -1.46703139e-01,  -1.45598799e-01,  -1.44145712e-01,
                         -1.42983258e-01,  -1.41646415e-01,  -1.40309587e-01,
                         -1.38972744e-01,  -1.37403414e-01,  -1.36124700e-01,
                         -1.34845987e-01,  -1.33451030e-01,  -1.32346690e-01,
                         -1.31067976e-01,  -1.29731148e-01,  -1.28394306e-01,
                         -1.27231851e-01,  -1.26069382e-01,  -1.24558173e-01,
                         -1.23105094e-01,  -1.21710137e-01,  -1.20257050e-01,
                         -1.19094588e-01,  -1.17641509e-01,  -1.16188422e-01,
                         -1.15025960e-01,  -1.13456629e-01,  -1.11887299e-01,
                         -1.10492341e-01,  -1.08981140e-01,  -1.07528053e-01,
                         -1.06074974e-01,  -1.04796261e-01,  -1.03401303e-01,
                         -1.01715729e-01,  -1.00437015e-01,  -9.88676846e-02,
                         -9.71821100e-02,  -9.59034041e-02,  -9.42759514e-02,
                         -9.27647427e-02,  -9.11954194e-02,  -8.94517154e-02,
                         -8.79986361e-02,  -8.63711834e-02,  -8.47437307e-02,
                         -8.32325295e-02,  -8.15469548e-02,  -7.99776241e-02,
                         -7.83501714e-02,  -7.67808408e-02,  -7.52115175e-02,
                         -7.34096915e-02,  -7.18403682e-02,  -7.02129155e-02,
                         -6.84692189e-02,  -6.68417662e-02,  -6.52143136e-02,
                         -6.36449829e-02,  -6.20756559e-02,  -6.03900813e-02,
                         -5.86463846e-02,  -5.68445623e-02,  -5.52752316e-02,
                         -5.37059046e-02,  -5.20784520e-02,  -5.03347553e-02,
                         -4.85329330e-02,  -4.69636060e-02,  -4.51617837e-02,
                         -4.34180871e-02,  -4.19650041e-02,  -4.02213037e-02,
                         -3.84776071e-02,  -3.68501544e-02,  -3.51645797e-02,
                         -3.37114967e-02,  -3.20259221e-02,  -3.02241016e-02,
                         -2.86547747e-02,  -2.69110762e-02,  -2.52255015e-02,
                         -2.35399250e-02,  -2.17962284e-02,  -2.02268995e-02,
                         -1.85413249e-02,  -1.67395025e-02,  -1.49958050e-02,
                         -1.33102294e-02,  -1.16246548e-02,  -9.82283335e-03,
                         -8.07913486e-03,  -6.45168312e-03,  -4.70798509e-03,
                         -2.96428683e-03,  -9.88095650e-04,   8.13725812e-04,
                          2.55742413e-03,   4.47549205e-03,   6.10294379e-03,
                          7.84664229e-03,   9.59033985e-03,   1.12177916e-02,
                          1.31939827e-02,   1.49376811e-02,   1.66232567e-02,
                          1.85994469e-02,   2.02850215e-02,   2.20868438e-02,
                          2.38886662e-02,   2.53998712e-02,   2.72598155e-02,
                          2.91197598e-02,   3.08053344e-02,   3.25490348e-02,
                          3.41764838e-02,   3.60364281e-02,   3.78382504e-02,
                          3.94657031e-02,   4.12675254e-02,   4.31274697e-02,
                          4.49292921e-02,   4.65567410e-02,   4.82423156e-02,
                          4.98697683e-02,   5.16134650e-02,   5.34152873e-02,
                          5.50427400e-02,   5.67283146e-02,   5.84138893e-02,
                          5.99832200e-02,   6.16687946e-02,   6.32381216e-02,
                          6.49236962e-02,   6.67255148e-02,   6.82367235e-02,
                          6.98641762e-02,   7.14916289e-02,   7.31190816e-02,
                          7.47465268e-02,   7.63158575e-02,   7.81758055e-02,
                          7.97451288e-02,   8.10819641e-02,   8.27094167e-02,
                          8.42206255e-02,   8.58480781e-02,   8.75336528e-02,
                          8.89286101e-02,   9.06141847e-02,   9.22416374e-02,
                          9.37528387e-02,   9.52059254e-02,   9.66008827e-02,
                          9.82283354e-02,   9.96232927e-02,   1.00960128e-01,
                          1.02761947e-01,   1.04156904e-01,   1.05551861e-01,
                          1.07179314e-01,   1.08632401e-01,   1.10143602e-01,
                          1.11538559e-01,   1.12991646e-01,   1.14502847e-01,
                          1.15839683e-01,   1.17234640e-01,   1.18629605e-01,
                          1.20024562e-01,   1.21303275e-01,   1.22581981e-01,
                          1.24151312e-01,   1.25430018e-01,   1.26650617e-01,
                          1.28219947e-01,   1.29440531e-01,   1.30603001e-01,
                          1.31939828e-01,   1.33044168e-01,   1.34381011e-01,
                          1.35601595e-01,   1.36647820e-01,   1.37926534e-01,
                          1.39088988e-01,   1.40251458e-01,   1.41297683e-01,
                          1.42343894e-01,   1.43506363e-01,   1.44494459e-01,
                          1.45656928e-01,   1.46819383e-01,   1.47923738e-01,
                          1.49028078e-01,   1.49958044e-01,   1.51004270e-01,
                          1.51992366e-01,   1.52922332e-01,   1.54084802e-01,
                          1.54956654e-01,   1.55944750e-01,   1.56932831e-01,
                          1.57630324e-01,   1.58734664e-01,   1.59664631e-01,
                          1.60303995e-01,   1.61175832e-01,   1.61989570e-01,
                          1.62919536e-01,   1.63849503e-01,   1.64488867e-01,
                          1.65244460e-01,   1.65883824e-01,   1.66697547e-01,
                          1.67685643e-01,   1.68208748e-01,   1.69022486e-01,
                          1.69952452e-01,   1.70533687e-01,   1.71289280e-01,
                          1.71812400e-01,   1.72335505e-01,   1.73032984e-01,
                          1.73788592e-01,   1.74486071e-01,   1.75067306e-01,
                          1.75764784e-01,   1.76462263e-01,   1.76927239e-01,
                          1.77334100e-01,   1.77740976e-01,   1.78264081e-01,
                          1.78845316e-01,   1.79310292e-01,   1.79833412e-01,
                          1.80182144e-01,   1.80647135e-01,   1.81112126e-01,
                          1.81518987e-01,   1.82042092e-01,   1.82390839e-01,
                          1.82739571e-01,   1.83030188e-01,   1.83088318e-01,
                          1.83262676e-01,   1.83495179e-01,   1.83785796e-01,
                          1.84134528e-01,   1.84250772e-01,   1.84483275e-01,
                          1.84599519e-01,   1.84425145e-01,   1.84715763e-01,
                          1.84890136e-01,   1.85006380e-01,   1.85180753e-01,
                          1.85296997e-01,   1.85296997e-01,   1.85238868e-01,
                          1.85180753e-01,   1.85122624e-01,   1.85238868e-01,
                          1.85471371e-01,   1.85471371e-01,   1.85355112e-01,
                          1.85471371e-01,   1.85355112e-01,   1.85296997e-01,
                          1.85180753e-01,   1.85006380e-01,   1.84890136e-01,
                          1.84832007e-01,   1.84832007e-01,   1.84599519e-01,
                          1.84308901e-01,   1.84192657e-01,   1.84134528e-01,
                          1.84076414e-01,   1.83960155e-01,   1.83727667e-01,
                          1.83669537e-01,   1.83262676e-01,   1.82797700e-01,
                          1.82797700e-01,   1.82623327e-01,   1.82216465e-01,
                          1.82042092e-01,   1.81635231e-01,   1.81112126e-01,
                          1.80879623e-01,   1.80530891e-01,   1.80182144e-01,
                          1.79891527e-01,   1.79600909e-01,   1.79252177e-01,
                          1.78670943e-01,   1.78147838e-01,   1.77799091e-01,
                          1.77334100e-01,   1.76869124e-01,   1.76287889e-01,
                          1.75590411e-01,   1.75009176e-01,   1.74602315e-01,
                          1.74195454e-01,   1.73788592e-01,   1.73207358e-01,
                          1.72393635e-01,   1.71754271e-01,   1.71231166e-01,
                          1.70708060e-01,   1.70301184e-01,   1.69429347e-01,
                          1.68557495e-01,   1.68208748e-01,   1.67627513e-01,
                          1.67046294e-01,   1.66581303e-01,   1.65709451e-01,
                          1.64837599e-01,   1.64198250e-01,   1.63558885e-01,
                          1.62919536e-01,   1.62222058e-01,   1.61408335e-01,
                          1.60652727e-01,   1.60013378e-01,   1.59199640e-01,
                          1.58444047e-01,   1.57920927e-01,   1.57339707e-01,
                          1.56467855e-01,   1.55654132e-01,   1.54898524e-01,
                          1.54142916e-01,   1.53329194e-01,   1.52631715e-01,
                          1.51817992e-01,   1.50946140e-01,   1.50306791e-01,
                          1.49725556e-01,   1.48911834e-01,   1.47865608e-01,
                          1.46935642e-01,   1.46296278e-01,   1.45366311e-01,
                          1.44610703e-01,   1.43913224e-01,   1.43041372e-01,
                          1.42227650e-01,   1.41297683e-01,   1.40309587e-01,
                          1.39670223e-01,   1.38740256e-01,   1.37926534e-01,
                          1.37287170e-01,   1.36124700e-01,   1.35020360e-01,
                          1.34148508e-01,   1.33218542e-01,   1.32346690e-01,
                          1.31416723e-01,   1.30486742e-01,   1.29440531e-01,
                          1.28452435e-01,   1.27580583e-01,   1.26650617e-01,
                          1.25778764e-01,   1.24906912e-01,   1.23860694e-01,
                          1.23046972e-01,   1.22233242e-01,   1.21303275e-01,
                          1.20373301e-01,   1.19559571e-01,   1.18629605e-01,
                          1.17641509e-01,   1.16769657e-01,   1.15897804e-01,
                          1.14909708e-01,   1.14154108e-01,   1.13224134e-01,
                          1.12352289e-01,   1.11538559e-01,   1.10492341e-01,
                          1.09620497e-01,   1.08806767e-01,   1.07818671e-01,
                          1.07063070e-01,   1.06249347e-01,   1.05435617e-01,
                          1.04563765e-01,   1.03575677e-01,   1.02703825e-01,
                          1.01831973e-01,   1.01018250e-01,   1.00320771e-01,
                          9.96232927e-02,   9.88095626e-02,   9.79377180e-02,
                          9.71239880e-02,   9.63683873e-02,   9.54384133e-02,
                          9.43921953e-02,   9.35203433e-02,   9.28809941e-02,
                          9.21835080e-02,   9.13697854e-02,   9.06141847e-02,
                          8.96842107e-02,   8.88704881e-02,   8.83473754e-02,
                          8.74755234e-02,   8.65455568e-02,   8.57318267e-02,
                          8.49762261e-02,   8.42787474e-02,   8.34650174e-02,
                          8.27094167e-02,   8.20119381e-02,   8.12563375e-02,
                          8.04426074e-02,   7.96870068e-02,   7.91057721e-02,
                          7.83501714e-02,   7.74783269e-02,   7.70714581e-02,
                          7.63158575e-02,   7.52696395e-02,   7.46884048e-02,
                          7.38165602e-02,   7.30609521e-02,   7.25959688e-02,
                          7.17822462e-02,   7.10266382e-02,   7.04454109e-02,
                          6.99222982e-02,   6.93410635e-02,   6.86435848e-02,
                          6.80042282e-02,   6.73067495e-02,   6.67255148e-02,
                          6.61442876e-02,   6.55630529e-02,   6.50980696e-02,
                          6.44005835e-02,   6.38774782e-02,   6.34124950e-02,
                          6.27731383e-02,   6.24825172e-02,   6.19594082e-02,
                          6.13200553e-02,   6.09131902e-02,   6.03900813e-02,
                          5.99832200e-02,   5.94601072e-02,   5.88788763e-02,
                          5.84720112e-02,   5.80651499e-02,   5.76582886e-02,
                          5.73676713e-02,   5.69608063e-02,   5.65539449e-02,
                          5.60889579e-02,   5.56820966e-02,   5.52171096e-02,
                          5.47521226e-02,   5.46358787e-02,   5.43452613e-02,
                          5.39965220e-02,   5.37640266e-02,   5.33571653e-02,
                          5.30084260e-02,   5.26015610e-02,   5.23109473e-02,
                          5.22528216e-02,   5.19040823e-02,   5.15553430e-02,
                          5.13809733e-02,   5.11484817e-02,   5.10322340e-02,
                          5.08578643e-02,   5.06253727e-02,   5.02766334e-02,
                          5.01022600e-02,   5.01022600e-02,   4.98697683e-02,
                          4.95791510e-02,   4.95210290e-02,   4.92885374e-02,
                          4.89979200e-02,   4.88816723e-02,   4.87654246e-02,
                          4.88816723e-02,   4.89397980e-02,   4.88816723e-02,
                          4.87073027e-02,   4.87073027e-02,   4.87654246e-02,
                          4.85910550e-02,   4.86491807e-02,   4.87654246e-02,
                          4.86491807e-02,   4.89979200e-02,   4.91141677e-02,
                          4.89979200e-02,   4.91722897e-02,   4.91141677e-02,
                          4.91722897e-02,   4.94629070e-02,   4.94629070e-02,
                          4.96372767e-02,   4.98697683e-02,   5.01603857e-02,
                          5.03347553e-02,   5.03928773e-02,   5.06253727e-02,
                          5.06834947e-02,   5.07416166e-02,   5.10322340e-02,
                          5.13228513e-02,   5.16715907e-02,   5.19622080e-02,
                          5.20203300e-02,   5.21365777e-02,   5.25434390e-02,
                          5.29503003e-02,   5.31246737e-02,   5.34152873e-02,
                          5.37059046e-02,   5.38802743e-02,   5.41127659e-02,
                          5.43452613e-02,   5.46358787e-02,   5.51589876e-02,
                          5.54496013e-02,   5.55658489e-02,   5.59145883e-02,
                          5.63214533e-02,   5.68445623e-02,   5.71933016e-02,
                          5.76001629e-02,   5.80070280e-02,   5.83557673e-02,
                          5.87626286e-02,   5.90532459e-02,   5.95182329e-02,
                          6.00994639e-02,   6.04482032e-02,   6.07969426e-02,
                          6.13200553e-02,   6.17269166e-02,   6.21919036e-02,
                          6.27731383e-02,   6.32962435e-02,   6.37031049e-02,
                          6.39937222e-02,   6.45749569e-02,   6.52143136e-02,
                          6.57374188e-02,   6.63186535e-02,   6.68417662e-02,
                          6.73648715e-02,   6.80042282e-02,   6.87598288e-02,
                          6.93410635e-02,   6.96316808e-02,   7.01547936e-02,
                          7.08522722e-02,   7.14916289e-02,   7.20147341e-02,
                          7.25378469e-02,   7.31772035e-02,   7.37584308e-02,
                          7.45140389e-02,   7.51533955e-02,   7.54440054e-02,
                          7.59671181e-02,   7.68389702e-02,   7.74201974e-02,
                          7.80595541e-02,   7.85826668e-02,   7.91057721e-02,
                          7.96870068e-02,   8.02682415e-02,   8.10819641e-02,
                          8.16050768e-02,   8.19538161e-02,   8.27094167e-02,
                          8.32325295e-02,   8.39300081e-02,   8.45112428e-02,
                          8.48018527e-02,   8.53830874e-02,   8.60224441e-02,
                          8.66036788e-02,   8.70686620e-02,   8.75336528e-02,
                          8.79986361e-02,   8.86379927e-02,   8.92773494e-02,
                          8.98004547e-02,   9.02073234e-02,   9.07885507e-02,
                          9.12535414e-02,   9.17766467e-02,   9.24741253e-02,
                          9.28228647e-02,   9.32297334e-02,   9.37528387e-02,
                          9.43340734e-02,   9.49734300e-02,   9.53221694e-02,
                          9.56127867e-02,   9.60196480e-02,   9.64846313e-02,
                          9.71239880e-02,   9.74727273e-02,   9.77052227e-02,
                          9.81702060e-02,   9.86933187e-02,   9.92164314e-02,
                          9.96232927e-02,   1.00088276e-01,   1.00320771e-01,
                          1.00611389e-01,   1.01192616e-01,   1.01366989e-01,
                          1.01657607e-01,   1.02180712e-01,   1.02296963e-01,
                          1.02645703e-01,   1.03285059e-01,   1.03459425e-01,
                          1.03633799e-01,   1.03982538e-01,   1.04215026e-01,
                          1.04389399e-01,   1.04505643e-01,   1.04738139e-01,
                          1.04854383e-01,   1.05028756e-01,   1.05203122e-01,
                          1.05377495e-01,   1.05493739e-01,   1.05551861e-01,
                          1.05726235e-01,   1.05726235e-01,   1.05726235e-01,
                          1.06016852e-01,   1.05900601e-01,   1.05726235e-01,
                          1.05958730e-01,   1.05784357e-01,   1.05726235e-01,
                          1.05958730e-01,   1.05842479e-01,   1.05668113e-01,
                          1.05435617e-01,   1.05319373e-01,   1.05319373e-01,
                          1.05261251e-01,   1.05086878e-01,   1.04621895e-01,
                          1.04389399e-01,   1.04331277e-01,   1.04098782e-01,
                          1.03924416e-01,   1.03691921e-01,   1.03459425e-01,
                          1.03401303e-01,   1.02878191e-01,   1.02471329e-01,
                          1.02238841e-01,   1.01599485e-01,   1.01425111e-01,
                          1.01134494e-01,   1.00669511e-01,   1.00262649e-01,
                          9.96232927e-02,   9.92164314e-02,   9.88676846e-02,
                          9.82283354e-02,   9.79377180e-02,   9.75308493e-02,
                          9.69496220e-02,   9.63102654e-02,   9.57290307e-02,
                          9.52059254e-02,   9.45084393e-02,   9.39272121e-02,
                          9.34040993e-02,   9.27647427e-02,   9.22416374e-02,
                          9.14860293e-02,   9.05560628e-02,   8.99748281e-02,
                          8.93354714e-02,   8.82892534e-02,   8.73592794e-02,
                          8.67199227e-02,   8.59062001e-02,   8.51505920e-02,
                          8.46856087e-02,   8.37556347e-02,   8.26512948e-02,
                          8.17794427e-02,   8.09075981e-02,   7.99195021e-02,
                          7.88732842e-02,   7.78851882e-02,   7.70133361e-02,
                          7.59089962e-02,   7.49209002e-02,   7.39909261e-02,
                          7.28865862e-02,   7.20147341e-02,   7.07941502e-02,
                          6.95154369e-02,   6.85273409e-02,   6.73648715e-02,
                          6.61442876e-02,   6.49818182e-02,   6.38193563e-02,
                          6.28312603e-02,   6.16106689e-02,   6.03900813e-02,
                          5.91694936e-02,   5.77164106e-02,   5.66701926e-02,
                          5.54496013e-02,   5.41708916e-02,   5.31246737e-02,
                          5.17878383e-02,   5.05091250e-02,   4.92304116e-02,
                          4.77773324e-02,   4.64404970e-02,   4.51617837e-02,
                          4.38249484e-02,   4.23718654e-02,   4.09769081e-02,
                          3.95819508e-02,   3.82451154e-02,   3.70245241e-02,
                          3.54551971e-02,   3.38277444e-02,   3.24909091e-02,
                          3.10378280e-02,   2.95847468e-02,   2.81897876e-02,
                          2.66785827e-02,   2.51092538e-02,   2.34818030e-02,
                          2.22612135e-02,   2.07500085e-02,   1.90063100e-02,
                          1.76113527e-02,   1.58676542e-02,   1.42402016e-02,
                          1.29033662e-02,   1.10434219e-02,   9.29972343e-03,
                          7.84664229e-03,   6.16106717e-03,   4.64986172e-03,
                          2.96428683e-03,   1.22058869e-03,  -4.06862906e-04,
                         -2.03431468e-03,  -3.66176618e-03,  -5.46358759e-03,
                         -6.97479304e-03,  -8.60224478e-03,  -1.05203129e-02,
                         -1.22058876e-02,  -1.38914622e-02,  -1.56351607e-02,
                         -1.72626115e-02,  -1.90063100e-02,  -2.06337627e-02,
                         -2.24355832e-02,  -2.42374055e-02,  -2.59229802e-02,
                         -2.77829245e-02,  -2.94103771e-02,  -3.11540738e-02,
                         -3.30721438e-02,  -3.46414708e-02,  -3.65014151e-02,
                         -3.82451154e-02,  -3.98725644e-02,  -4.17325087e-02,
                         -4.34762090e-02,  -4.52199057e-02,  -4.70798500e-02,
                         -4.88816723e-02,  -5.06253727e-02,  -5.23109473e-02,
                         -5.41708916e-02,  -5.60889579e-02,  -5.79489022e-02,
                         -5.97507246e-02,  -6.13200553e-02,  -6.31218776e-02,
                         -6.50980696e-02,  -6.67836443e-02,  -6.87017068e-02,
                         -7.03872815e-02,  -7.23053515e-02,  -7.44559169e-02,
                         -7.61414915e-02,  -7.79433101e-02,  -7.98613802e-02,
                         -8.17794427e-02,  -8.36975127e-02,  -8.53830874e-02,
                         -8.73011574e-02,  -8.92192274e-02,  -9.09629241e-02,
                         -9.28809941e-02,  -9.46246907e-02,  -9.64265093e-02,
                         -9.84027013e-02,  -1.00262649e-01,  -1.02122590e-01,
                         -1.03866287e-01,  -1.05668113e-01,  -1.07586183e-01,
                         -1.09504245e-01,  -1.11364193e-01,  -1.13166012e-01,
                         -1.15025960e-01,  -1.17002152e-01,  -1.18745849e-01,
                         -1.20547667e-01,  -1.22523859e-01,  -1.24151312e-01,
                         -1.25895008e-01,  -1.27754956e-01,  -1.29673019e-01,
                         -1.31649211e-01,  -1.33451030e-01,  -1.35194734e-01,
                         -1.36880308e-01,  -1.38682127e-01,  -1.40600204e-01,
                         -1.42343894e-01,  -1.44145712e-01,  -1.46121904e-01,
                         -1.47981852e-01,  -1.49841800e-01,  -1.51527375e-01,
                         -1.53387323e-01,  -1.55131012e-01,  -1.56816587e-01,
                         -1.58676535e-01,  -1.60303995e-01,  -1.62105814e-01,
                         -1.64023876e-01,  -1.65709451e-01,  -1.67627513e-01,
                         -1.69545591e-01,  -1.71347409e-01,  -1.73149228e-01,
                         -1.74718559e-01,  -1.76694751e-01,  -1.78496569e-01,
                         -1.80124030e-01,  -1.81983963e-01,  -1.83669537e-01,
                         -1.85355112e-01,  -1.87389433e-01,  -1.89249381e-01,
                         -1.90760583e-01,  -1.92504287e-01,  -1.94596723e-01,
                         -1.96166053e-01,  -1.97735369e-01,  -1.99653447e-01,
                         -2.01280892e-01,  -2.03024596e-01,  -2.05000788e-01,
                         -2.06628233e-01,  -2.08488181e-01,  -2.10173756e-01,
                         -2.11801201e-01,  -2.13661149e-01,  -2.15230480e-01,
                         -2.16916054e-01,  -2.18717873e-01,  -2.20461577e-01,
                         -2.22321525e-01,  -2.23890856e-01,  -2.25343928e-01,
                         -2.26971388e-01,  -2.28656963e-01,  -2.30284408e-01,
                         -2.31853738e-01,  -2.33771801e-01,  -2.35399261e-01,
                         -2.36910462e-01,  -2.38537908e-01,  -2.39932880e-01,
                         -2.41618454e-01,  -2.43478388e-01,  -2.44931474e-01,
                         -2.46733293e-01,  -2.48360753e-01,  -2.49581337e-01,
                         -2.51150668e-01,  -2.52545625e-01,  -2.54231185e-01,
                         -2.56033033e-01,  -2.57369846e-01,  -2.59055436e-01,
                         -2.60508507e-01,  -2.61787236e-01,  -2.63356566e-01,
                         -2.64809638e-01,  -2.66495198e-01,  -2.68064529e-01,
                         -2.69401371e-01,  -2.71086961e-01,  -2.72481918e-01,
                         -2.73934990e-01,  -2.75388062e-01,  -2.76550531e-01,
                         -2.78061748e-01,  -2.79514819e-01,  -2.80909777e-01,
                         -2.82246619e-01,  -2.83583462e-01,  -2.85036534e-01,
                         -2.86431491e-01,  -2.87826449e-01,  -2.89105147e-01,
                         -2.90267617e-01,  -2.91778833e-01,  -2.93173790e-01,
                         -2.94568747e-01,  -2.95963705e-01,  -2.97358662e-01,
                         -2.98753619e-01,  -2.99857974e-01,  -3.01136672e-01,
                         -3.02473515e-01,  -3.03519726e-01,  -3.04798454e-01,
                         -3.05960923e-01,  -3.06949019e-01,  -3.08343977e-01,
                         -3.09506416e-01,  -3.10494512e-01,  -3.11656982e-01,
                         -3.12819451e-01,  -3.13865662e-01,  -3.15028131e-01,
                         -3.16190600e-01,  -3.17236841e-01,  -3.18166792e-01,
                         -3.19213003e-01,  -3.20201099e-01,  -3.21131080e-01,
                         -3.22293550e-01,  -3.23397905e-01,  -3.24269742e-01,
                         -3.25141579e-01,  -3.26013446e-01,  -3.26827168e-01,
                         -3.27582777e-01,  -3.28570873e-01,  -3.29617083e-01,
                         -3.30488920e-01,  -3.31418902e-01,  -3.32116395e-01,
                         -3.32755744e-01,  -3.33801955e-01,  -3.34673822e-01,
                         -3.35487545e-01,  -3.36185008e-01,  -3.36882502e-01,
                         -3.37754339e-01,  -3.38393688e-01,  -3.39033067e-01,
                         -3.39672416e-01,  -3.40195507e-01,  -3.41009259e-01,
                         -3.41416121e-01,  -3.41881096e-01,  -3.42694819e-01,
                         -3.43217939e-01,  -3.43741030e-01,  -3.44322264e-01,
                         -3.44729125e-01,  -3.45194131e-01,  -3.45600992e-01,
                         -3.46182227e-01,  -3.46763462e-01,  -3.47054064e-01,
                         -3.47460926e-01,  -3.47984046e-01,  -3.48332763e-01,
                         -3.48565280e-01,  -3.48797768e-01,  -3.49320859e-01,
                         -3.49611491e-01,  -3.49727750e-01,  -3.49960238e-01,
                         -3.50192726e-01,  -3.50425214e-01,  -3.50425214e-01,
                         -3.50657701e-01,  -3.50890189e-01,  -3.50948334e-01,
                         -3.50890189e-01,  -3.50890189e-01,  -3.51006448e-01,
                         -3.51064563e-01,  -3.50948334e-01,  -3.51122707e-01,
                         -3.51122707e-01,  -3.51122707e-01,  -3.51122707e-01,
                         -3.50832075e-01,  -3.50715846e-01,  -3.50483328e-01,
                         -3.50250840e-01,  -3.50192726e-01,  -3.49843979e-01,
                         -3.49611491e-01,  -3.49553376e-01,  -3.49320859e-01,
                         -3.49088371e-01,  -3.48623395e-01,  -3.48274648e-01,
                         -3.48042160e-01,  -3.47577184e-01,  -3.47228438e-01,
                         -3.46879691e-01,  -3.46472830e-01,  -3.46065968e-01,
                         -3.45600992e-01,  -3.45194131e-01,  -3.44496638e-01,
                         -3.43799174e-01,  -3.43450427e-01,  -3.42694819e-01,
                         -3.42287958e-01,  -3.41822982e-01,  -3.40893000e-01,
                         -3.40428025e-01,  -3.39846790e-01,  -3.39033067e-01,
                         -3.38277459e-01,  -3.37347478e-01,  -3.36591870e-01,
                         -3.35778147e-01,  -3.34906310e-01,  -3.34150702e-01,
                         -3.33220720e-01,  -3.32348883e-01,  -3.31418902e-01,
                         -3.30547065e-01,  -3.29733342e-01,  -3.28570873e-01,
                         -3.27699006e-01,  -3.26710910e-01,  -3.25432211e-01,
                         -3.24444115e-01,  -3.23281646e-01,  -3.21944803e-01,
                         -3.20956707e-01,  -3.19794238e-01,  -3.18573654e-01,
                         -3.17353070e-01,  -3.16016227e-01,  -3.14853758e-01,
                         -3.13575059e-01,  -3.12470704e-01,  -3.11250120e-01,
                         -3.09738934e-01,  -3.08460206e-01,  -3.07123363e-01,
                         -3.05612177e-01,  -3.04159075e-01,  -3.02647889e-01,
                         -3.01311046e-01,  -2.99974203e-01,  -2.98404872e-01,
                         -2.96777427e-01,  -2.95266241e-01,  -2.93871284e-01,
                         -2.92301953e-01,  -2.90848851e-01,  -2.89395779e-01,
                         -2.87710190e-01,  -2.86082745e-01,  -2.84455299e-01,
                         -2.82769740e-01,  -2.80967891e-01,  -2.79224217e-01,
                         -2.77596742e-01,  -2.75794923e-01,  -2.74051219e-01,
                         -2.72481918e-01,  -2.70912588e-01,  -2.69226998e-01,
                         -2.67483294e-01,  -2.65565246e-01,  -2.63705283e-01,
                         -2.61670977e-01,  -2.59869158e-01,  -2.58009225e-01,
                         -2.56033033e-01,  -2.54173070e-01,  -2.52196878e-01,
                         -2.50278801e-01,  -2.48476997e-01,  -2.46442676e-01,
                         -2.44466484e-01,  -2.42606550e-01,  -2.40455985e-01,
                         -2.38537908e-01,  -2.36387357e-01,  -2.34353036e-01,
                         -2.32318729e-01,  -2.30110034e-01,  -2.28133842e-01,
                         -2.25983292e-01,  -2.23716483e-01,  -2.21682161e-01,
                         -2.19531611e-01,  -2.17264801e-01,  -2.15230480e-01,
                         -2.13079914e-01,  -2.10813120e-01,  -2.08604425e-01,
                         -2.06511989e-01,  -2.04245180e-01,  -2.01920256e-01,
                         -1.99711561e-01,  -1.97561011e-01,  -1.95468575e-01,
                         -1.93201765e-01,  -1.90702453e-01,  -1.88377529e-01,
                         -1.86168849e-01,  -1.83902040e-01,  -1.81693345e-01,
                         -1.79484665e-01,  -1.77043498e-01,  -1.74834803e-01,
                         -1.72684252e-01,  -1.70243070e-01,  -1.68034390e-01,
                         -1.65825695e-01,  -1.63268268e-01,  -1.61059588e-01,
                         -1.58850908e-01,  -1.56293482e-01,  -1.54084802e-01,
                         -1.51876107e-01,  -1.49551183e-01,  -1.47226244e-01,
                         -1.44785076e-01,  -1.42518267e-01,  -1.40309587e-01,
                         -1.37984648e-01,  -1.35543481e-01,  -1.33102298e-01,
                         -1.30893618e-01,  -1.28626809e-01,  -1.26185626e-01,
                         -1.23918816e-01,  -1.21535763e-01,  -1.19152710e-01,
                         -1.16827779e-01,  -1.14328481e-01,  -1.12177916e-01,
                         -1.09911107e-01,  -1.07353687e-01,  -1.04970634e-01,
                         -1.02587581e-01,  -1.00204520e-01,  -9.77633446e-02,
                         -9.54384133e-02,  -9.31716040e-02,  -9.07304287e-02,
                         -8.84636194e-02,  -8.59062001e-02,  -8.33487734e-02,
                         -8.10819641e-02,  -7.86407888e-02,  -7.63158575e-02,
                         -7.41071701e-02,  -7.17822462e-02,  -6.94573149e-02,
                         -6.70161322e-02,  -6.47493303e-02,  -6.23662733e-02,
                         -5.99832200e-02,  -5.76582886e-02,  -5.53333573e-02,
                         -5.30084260e-02,  -5.07416166e-02,  -4.83004414e-02,
                         -4.60917540e-02,  -4.38249484e-02,  -4.15581390e-02,
                         -3.92332077e-02,  -3.67920324e-02,  -3.46414708e-02,
                         -3.24909091e-02,  -3.01078558e-02,  -2.78410483e-02,
                         -2.55742408e-02,  -2.32493095e-02,  -2.10406259e-02,
                         -1.87738165e-02,  -1.65070090e-02,  -1.42983254e-02,
                         -1.22058876e-02,  -1.01134498e-02,  -7.78851844e-03,
                         -5.63795771e-03,  -3.37114977e-03,  -1.04621891e-03,
                          1.10434217e-03,   3.31302662e-03,   5.52171096e-03,
                          7.55602540e-03,   9.82283335e-03,   1.19733941e-02,
                          1.41820787e-02,   1.63907632e-02,   1.85413249e-02,
                          2.08081324e-02,   2.29586922e-02,   2.49930080e-02,
                          2.72016916e-02,   2.93522533e-02,   3.14446911e-02,
                          3.36533748e-02,   3.58620584e-02,   3.78382504e-02,
                          3.97563204e-02,   4.20812517e-02,   4.40574400e-02,
                          4.60336320e-02,   4.82423156e-02,   5.02185076e-02,
                          5.23690693e-02,   5.44615090e-02,   5.63795753e-02,
                          5.85882589e-02,   6.05644509e-02,   6.25406429e-02,
                          6.45749569e-02,   6.66092709e-02,   6.85854629e-02,
                          7.05616549e-02,   7.26540908e-02,   7.45140389e-02,
                          7.62577355e-02,   7.84082934e-02,   8.03263634e-02,
                          8.23025554e-02,   8.43949914e-02,   8.61968175e-02,
                          8.82311314e-02,   9.01491940e-02,   9.19510201e-02,
                          9.38690901e-02,   9.57290307e-02,   9.77633446e-02,
                          9.97395366e-02,   1.01425111e-01,   1.03285059e-01,
                          1.05145000e-01,   1.06946826e-01,   1.08923018e-01,
                          1.10782959e-01,   1.12526655e-01,   1.14212230e-01,
                          1.16072178e-01,   1.17757753e-01,   1.19385205e-01,
                          1.21245146e-01,   1.22930720e-01,   1.24674425e-01,
                          1.26592487e-01,   1.28394306e-01,   1.30021766e-01,
                          1.31707340e-01,   1.33451030e-01,   1.35252863e-01,
                          1.36880308e-01,   1.38682127e-01,   1.40425831e-01,
                          1.41937032e-01,   1.43564492e-01,   1.45308182e-01,
                          1.47110000e-01,   1.48911834e-01,   1.50539279e-01,
                          1.52341098e-01,   1.53910428e-01,   1.55479759e-01,
                          1.57281578e-01,   1.58909023e-01,   1.60303995e-01,
                          1.61931440e-01,   1.63675144e-01,   1.65244460e-01,
                          1.66581303e-01,   1.68441251e-01,   1.70184940e-01,
                          1.71463653e-01,   1.72916740e-01,   1.74544185e-01,
                          1.76113516e-01,   1.77566603e-01,   1.79019675e-01,
                          1.80589005e-01,   1.81983963e-01,   1.83495179e-01,
                          1.84948251e-01,   1.86401337e-01,   1.87970668e-01,
                          1.89365625e-01,   1.90934956e-01,   1.92446157e-01,
                          1.93666741e-01,   1.95061699e-01,   1.96340412e-01,
                          1.97677255e-01,   1.99304700e-01,   2.00525299e-01,
                          2.01862127e-01,   2.03257084e-01,   2.04535797e-01,
                          2.05930755e-01,   2.07209468e-01,   2.08488181e-01,
                          2.09650651e-01,   2.10871235e-01,   2.12266192e-01,
                          2.13603035e-01,   2.14881748e-01,   2.15986088e-01,
                          2.17090428e-01,   2.18601629e-01,   2.19938472e-01,
                          2.21275300e-01,   2.22495884e-01,   2.23367736e-01,
                          2.24588335e-01,   2.25925162e-01,   2.26971388e-01,
                          2.28133842e-01,   2.29296312e-01,   2.30458781e-01,
                          2.31504992e-01,   2.32667461e-01,   2.33888045e-01,
                          2.34992400e-01,   2.36096740e-01,   2.37142950e-01,
                          2.38131046e-01,   2.39177272e-01,   2.40165368e-01,
                          2.41269708e-01,   2.42432177e-01,   2.43362144e-01,
                          2.44524613e-01,   2.45512709e-01,   2.46326432e-01,
                          2.47256398e-01,   2.48186380e-01,   2.49058232e-01,
                          2.49988198e-01,   2.50860035e-01,   2.51673788e-01,
                          2.52487510e-01,   2.53417462e-01,   2.54289329e-01,
                          2.54986793e-01,   2.55800515e-01,   2.56556123e-01,
                          2.57369846e-01,   2.58125454e-01,   2.58764803e-01,
                          2.59636670e-01,   2.60566622e-01,   2.61206001e-01,
                          2.61845350e-01,   2.62600958e-01,   2.63182193e-01,
                          2.63763428e-01,   2.64577150e-01,   2.65158385e-01,
                          2.65739620e-01,   2.66437083e-01,   2.66960204e-01,
                          2.67425179e-01,   2.68006414e-01,   2.68471390e-01,
                          2.69168884e-01,   2.69808233e-01,   2.70273209e-01,
                          2.70970702e-01,   2.71435678e-01,   2.71842539e-01,
                          2.72481918e-01,   2.72888780e-01,   2.73353755e-01,
                          2.73760617e-01,   2.74109364e-01,   2.74690598e-01,
                          2.75039315e-01,   2.75446206e-01,   2.75969297e-01,
                          2.76201785e-01,   2.76550531e-01,   2.76783019e-01,
                          2.76899278e-01,   2.77306139e-01,   2.77654886e-01,
                          2.77887374e-01,   2.78177977e-01,   2.78526723e-01,
                          2.78933585e-01,   2.79049844e-01,   2.79224217e-01,
                          2.79572934e-01,   2.79747307e-01,   2.79863566e-01,
                          2.80037940e-01,   2.80037940e-01,   2.80096054e-01,
                          2.80154169e-01,   2.80328542e-01,   2.80328542e-01,
                          2.80154169e-01,   2.80096054e-01,   2.80270427e-01,
                          2.80386657e-01,   2.80212313e-01,   2.80037940e-01,
                          2.80096054e-01,   2.79863566e-01,   2.79631078e-01,
                          2.79689193e-01,   2.79631078e-01,   2.79514819e-01,
                          2.79398561e-01,   2.79166073e-01,   2.78933585e-01,
                          2.78817356e-01,   2.78642982e-01,   2.78410494e-01,
                          2.78236121e-01,   2.78061748e-01,   2.77829260e-01,
                          2.77422398e-01,   2.76899278e-01,   2.76724905e-01,
                          2.76318043e-01,   2.75794923e-01,   2.75794923e-01,
                          2.75446206e-01,   2.74748713e-01,   2.74341851e-01,
                          2.73993105e-01,   2.73644358e-01,   2.73353755e-01,
                          2.72946894e-01,   2.72481918e-01,   2.71900684e-01,
                          2.71493822e-01,   2.71319449e-01,   2.70738214e-01,
                          2.70040721e-01,   2.69575745e-01,   2.69052625e-01,
                          2.68529534e-01,   2.68006414e-01,   2.67483294e-01,
                          2.66785830e-01,   2.66088337e-01,   2.65565246e-01,
                          2.65042126e-01,   2.64402777e-01,   2.63763428e-01,
                          2.63007820e-01,   2.62368470e-01,   2.61612862e-01,
                          2.60740995e-01,   2.59985387e-01,   2.59404182e-01,
                          2.58590430e-01,   2.57892966e-01,   2.57137358e-01,
                          2.56091148e-01,   2.55393654e-01,   2.54696190e-01,
                          2.53591835e-01,   2.52778113e-01,   2.51964390e-01,
                          2.50918180e-01,   2.49988198e-01,   2.49000102e-01,
                          2.48244494e-01,   2.47372657e-01,   2.46210188e-01,
                          2.45338336e-01,   2.44524613e-01,   2.43536517e-01,
                          2.42664665e-01,   2.41618454e-01,   2.40630358e-01,
                          2.39874750e-01,   2.38886654e-01,   2.37666070e-01,
                          2.36677974e-01,   2.35806122e-01,   2.34643653e-01,
                          2.33597443e-01,   2.32493088e-01,   2.31388748e-01,
                          2.30575025e-01,   2.29354441e-01,   2.28075728e-01,
                          2.27087632e-01,   2.25925162e-01,   2.24878952e-01,
                          2.23774597e-01,   2.22554013e-01,   2.21565917e-01,
                          2.20345333e-01,   2.19124734e-01,   2.18020394e-01,
                          2.16741681e-01,   2.15695471e-01,   2.14765489e-01,
                          2.13486791e-01,   2.12266192e-01,   2.10987478e-01,
                          2.09825024e-01,   2.08662555e-01,   2.07441956e-01,
                          2.06163257e-01,   2.04710171e-01,   2.03315213e-01,
                          2.02210873e-01,   2.00932160e-01,   1.99653447e-01,
                          1.98374733e-01,   1.96863532e-01,   1.95642933e-01,
                          1.94364220e-01,   1.92911148e-01,   1.91632435e-01,
                          1.90237477e-01,   1.88900635e-01,   1.87563807e-01,
                          1.86168849e-01,   1.84832007e-01,   1.83320805e-01,
                          1.81983963e-01,   1.80647135e-01,   1.79194048e-01,
                          1.77740976e-01,   1.76404133e-01,   1.75125420e-01,
                          1.73497975e-01,   1.71986759e-01,   1.70824304e-01,
                          1.69138730e-01,   1.67685643e-01,   1.66232556e-01,
                          1.64663240e-01,   1.63617015e-01,   1.62338302e-01,
                          1.60768971e-01,   1.59199640e-01,   1.57514066e-01,
                          1.56177238e-01,   1.54607907e-01,   1.52980462e-01,
                          1.51585504e-01,   1.50074288e-01,   1.48737460e-01,
                          1.47168130e-01,   1.45540670e-01,   1.44145712e-01,
                          1.42576396e-01,   1.41065180e-01,   1.39612108e-01,
                          1.38042778e-01,   1.36589691e-01,   1.34904116e-01,
                          1.33509159e-01,   1.31997958e-01,   1.30254254e-01,
                          1.28801167e-01,   1.27173722e-01,   1.25778764e-01,
                          1.24441929e-01,   1.22523859e-01,   1.21070780e-01,
                          1.19559571e-01,   1.17699631e-01,   1.16246544e-01,
                          1.14619099e-01,   1.13049768e-01,   1.11538559e-01,
                          1.09736741e-01,   1.08283661e-01,   1.06598087e-01,
                          1.04796261e-01,   1.03343181e-01,   1.01657607e-01,
                          9.99720320e-02,   9.81702060e-02,   9.63683873e-02,
                          9.49734300e-02,   9.34040993e-02,   9.15441588e-02,
                          8.96260887e-02,   8.79405141e-02,   8.63130614e-02,
                          8.45693648e-02,   8.29419121e-02,   8.13144594e-02,
                          7.93963894e-02,   7.77689368e-02,   7.62577355e-02,
                          7.45721608e-02,   7.28865862e-02,   7.11428896e-02,
                          6.95735589e-02,   6.78298622e-02,   6.60861582e-02,
                          6.44005835e-02,   6.25406429e-02,   6.08550683e-02,
                          5.91113679e-02,   5.73095493e-02,   5.57402186e-02,
                          5.39965220e-02,   5.23109473e-02,   5.06253727e-02,
                          4.87654246e-02,   4.69636060e-02,   4.51617837e-02,
                          4.35924567e-02,   4.17906344e-02,   3.97563204e-02,
                          3.82451154e-02,   3.66176628e-02,   3.46995927e-02,
                          3.30721438e-02,   3.13865691e-02,   2.95847468e-02,
                          2.78991722e-02,   2.61554737e-02,   2.42955275e-02,
                          2.24355832e-02,   2.06918847e-02,   1.89481881e-02,
                          1.71463657e-02,   1.54607911e-02,   1.36589697e-02,
                          1.19152712e-02,   1.01134498e-02,   8.19538161e-03,
                          6.45168312e-03,   4.76610847e-03,   2.84804031e-03,
                          1.04621891e-03,  -7.55602552e-04,  -2.67367065e-03,
                         -4.59173881e-03,  -6.27731346e-03,  -8.07913486e-03,
                         -9.88095626e-03,  -1.16827777e-02,  -1.37170926e-02,
                         -1.55189140e-02,  -1.72626115e-02,  -1.91806797e-02,
                         -2.08662543e-02,  -2.27262005e-02,  -2.44698990e-02,
                         -2.61554737e-02,  -2.81897876e-02,  -2.98753623e-02,
                         -3.15028131e-02,  -3.35371271e-02,  -3.51645797e-02,
                         -3.69664021e-02,  -3.87100987e-02,  -4.03375514e-02,
                         -4.23137434e-02,  -4.38830703e-02,  -4.55686450e-02,
                         -4.76610847e-02,  -4.94047813e-02,  -5.13809733e-02,
                         -5.31827956e-02,  -5.46940006e-02,  -5.65539449e-02,
                         -5.81813976e-02,  -5.99250942e-02,  -6.17269166e-02,
                         -6.34124950e-02,  -6.52724355e-02,  -6.70161322e-02,
                         -6.86435848e-02,  -7.03291595e-02,  -7.20728561e-02,
                         -7.38746822e-02,  -7.54440054e-02,  -7.71295875e-02,
                         -7.89314061e-02,  -8.06751028e-02,  -8.24187994e-02,
                         -8.41043741e-02,  -8.58480781e-02,  -8.75917748e-02,
                         -8.93354714e-02,  -9.12535414e-02,  -9.27647427e-02,
                         -9.42759514e-02,  -9.61940140e-02,  -9.78214666e-02,
                         -9.95070413e-02,  -1.01192616e-01,  -1.02936320e-01,
                         -1.04680017e-01,  -1.06074974e-01,  -1.07818671e-01,
                         -1.09562367e-01,  -1.10957332e-01,  -1.12759151e-01,
                         -1.14502847e-01,  -1.16014056e-01,  -1.17699631e-01,
                         -1.19268954e-01,  -1.20838284e-01,  -1.22407615e-01,
                         -1.23860694e-01,  -1.25488147e-01,  -1.27115592e-01,
                         -1.28568679e-01,  -1.29963636e-01,  -1.31707340e-01,
                         -1.33276671e-01,  -1.34497255e-01,  -1.36124700e-01,
                         -1.37752160e-01,  -1.39147118e-01,  -1.40774563e-01,
                         -1.42111406e-01,  -1.43506363e-01,  -1.45017564e-01,
                         -1.46354407e-01,  -1.47807479e-01,  -1.49260566e-01,
                         -1.50655523e-01,  -1.51934236e-01,  -1.53271079e-01,
                         -1.55072898e-01,  -1.56642228e-01,  -1.57804683e-01,
                         -1.59199640e-01,  -1.60536483e-01,  -1.61873311e-01,
                         -1.63384527e-01,  -1.64721355e-01,  -1.66058198e-01,
                         -1.67278782e-01,  -1.68615609e-01,  -1.70010582e-01,
                         -1.71347409e-01,  -1.72742367e-01,  -1.74021080e-01,
                         -1.75183550e-01,  -1.76462263e-01,  -1.77740976e-01,
                         -1.78961560e-01,  -1.80124030e-01,  -1.81344613e-01,
                         -1.82739571e-01,  -1.83902040e-01,  -1.85006380e-01,
                         -1.86168849e-01,  -1.87447563e-01,  -1.88551903e-01,
                         -1.89598113e-01,  -1.90934956e-01,  -1.92271784e-01,
                         -1.93259880e-01,  -1.94306105e-01,  -1.95410445e-01,
                         -1.96631029e-01,  -1.97735369e-01,  -1.98723465e-01,
                         -1.99769691e-01,  -2.00815916e-01,  -2.01920256e-01,
                         -2.02850223e-01,  -2.03838319e-01,  -2.05058903e-01,
                         -2.05872640e-01,  -2.06802607e-01,  -2.07906947e-01,
                         -2.08778799e-01,  -2.09766895e-01,  -2.10696861e-01,
                         -2.11684957e-01,  -2.12614939e-01,  -2.13254288e-01,
                         -2.14242384e-01,  -2.15172365e-01,  -2.15811715e-01,
                         -2.16799811e-01,  -2.17555419e-01,  -2.18252897e-01,
                         -2.19066620e-01,  -2.19822213e-01,  -2.20635951e-01,
                         -2.21333429e-01,  -2.22147152e-01,  -2.22902760e-01,
                         -2.23425865e-01,  -2.24123344e-01,  -2.24762693e-01,
                         -2.25402057e-01,  -2.26215780e-01,  -2.26913258e-01,
                         -2.27552623e-01,  -2.28250101e-01,  -2.28947580e-01,
                         -2.29645059e-01,  -2.30110034e-01,  -2.30575025e-01,
                         -2.31156260e-01,  -2.31853738e-01,  -2.32493088e-01,
                         -2.32899964e-01,  -2.33481184e-01,  -2.34120548e-01,
                         -2.34585539e-01,  -2.35108644e-01,  -2.35631749e-01,
                         -2.36038610e-01,  -2.36561716e-01,  -2.36968592e-01,
                         -2.37433568e-01,  -2.37898558e-01,  -2.38131046e-01,
                         -2.38654166e-01,  -2.39235386e-01,  -2.39584133e-01,
                         -2.39932880e-01,  -2.40165368e-01,  -2.40455985e-01,
                         -2.40862846e-01,  -2.41095334e-01,  -2.41444081e-01,
                         -2.41676569e-01,  -2.41967186e-01,  -2.42315933e-01,
                         -2.42490292e-01,  -2.42664665e-01,  -2.42780909e-01,
                         -2.42955282e-01,  -2.42955282e-01,  -2.43071526e-01,
                         -2.43362144e-01,  -2.43420273e-01,  -2.43536517e-01,
                         -2.43827134e-01,  -2.43827134e-01,  -2.43710890e-01,
                         -2.43943378e-01,  -2.44001508e-01,  -2.43943378e-01,
                         -2.44059622e-01,  -2.44175866e-01,  -2.44001508e-01,
                         -2.44175866e-01,  -2.44175866e-01,  -2.44117752e-01,
                         -2.44175866e-01,  -2.44059622e-01,  -2.44117752e-01,
                         -2.44117752e-01,  -2.43827134e-01,  -2.43769005e-01,
                         -2.43536517e-01,  -2.43478388e-01,  -2.43478388e-01,
                         -2.43187770e-01,  -2.43013412e-01,  -2.42780909e-01,
                         -2.42374048e-01,  -2.42490292e-01,  -2.42315933e-01,
                         -2.41734698e-01,  -2.41444081e-01,  -2.41269708e-01,
                         -2.40979090e-01,  -2.40746602e-01,  -2.40514100e-01,
                         -2.40165368e-01,  -2.39816621e-01,  -2.39584133e-01,
                         -2.39293516e-01,  -2.38944784e-01,  -2.38479793e-01,
                         -2.38014802e-01,  -2.37666070e-01,  -2.37084836e-01,
                         -2.36794218e-01,  -2.36619845e-01,  -2.35922366e-01,
                         -2.35457376e-01,  -2.34934270e-01,  -2.34411165e-01,
                         -2.34120548e-01,  -2.33597443e-01,  -2.33074322e-01,
                         -2.32376844e-01,  -2.31737494e-01,  -2.31272504e-01,
                         -2.30516896e-01,  -2.29819417e-01,  -2.29354441e-01,
                         -2.28656963e-01,  -2.28133842e-01,  -2.27436364e-01,
                         -2.26564527e-01,  -2.25925162e-01,  -2.25111440e-01,
                         -2.24239588e-01,  -2.23658353e-01,  -2.23019004e-01,
                         -2.22321525e-01,  -2.21507788e-01,  -2.20752195e-01,
                         -2.20054716e-01,  -2.19240993e-01,  -2.18427256e-01,
                         -2.17671663e-01,  -2.16857940e-01,  -2.16102332e-01,
                         -2.15056106e-01,  -2.14068010e-01,  -2.13254288e-01,
                         -2.12498695e-01,  -2.11510599e-01,  -2.10522503e-01,
                         -2.09883139e-01,  -2.09069416e-01,  -2.08023190e-01,
                         -2.07209468e-01,  -2.06221372e-01,  -2.05349520e-01,
                         -2.04593927e-01,  -2.03431457e-01,  -2.02443361e-01,
                         -2.01571509e-01,  -2.00525299e-01,  -1.99653447e-01,
                         -1.98723465e-01,  -1.97677255e-01,  -1.96572915e-01,
                         -1.95468575e-01,  -1.94422349e-01,  -1.93376124e-01,
                         -1.92329913e-01,  -1.91225573e-01,  -1.90121233e-01,
                         -1.89133137e-01,  -1.88028783e-01,  -1.86924443e-01,
                         -1.86110720e-01,  -1.84948251e-01,  -1.83553293e-01,
                         -1.82448953e-01,  -1.81344613e-01,  -1.80065900e-01,
                         -1.79019675e-01,  -1.77915335e-01,  -1.76520377e-01,
                         -1.75125420e-01,  -1.73962951e-01,  -1.72858611e-01,
                         -1.71638027e-01,  -1.70301184e-01,  -1.69022486e-01,
                         -1.67801887e-01,  -1.66523173e-01,  -1.65418833e-01,
                         -1.64372623e-01,  -1.63093910e-01,  -1.61640823e-01,
                         -1.60245866e-01,  -1.59141526e-01,  -1.57920927e-01,
                         -1.56584099e-01,  -1.55421630e-01,  -1.53736055e-01,
                         -1.52282983e-01,  -1.51294887e-01,  -1.49899915e-01,
                         -1.48504958e-01,  -1.47168130e-01,  -1.45831287e-01,
                         -1.44552574e-01,  -1.43099502e-01,  -1.41820788e-01,
                         -1.40483946e-01,  -1.39030874e-01,  -1.37868404e-01,
                         -1.36299074e-01,  -1.34729743e-01,  -1.33625403e-01,
                         -1.32288575e-01,  -1.31009862e-01,  -1.29614905e-01,
                         -1.27929330e-01,  -1.26476243e-01,  -1.25139400e-01,
                         -1.23628199e-01,  -1.22058876e-01,  -1.20780163e-01,
                         -1.19501449e-01,  -1.17757753e-01,  -1.16362795e-01,
                         -1.15142204e-01,  -1.13631003e-01,  -1.12119794e-01,
                         -1.10608593e-01,  -1.09271757e-01,  -1.07586183e-01,
                         -1.05842479e-01,  -1.04505643e-01,  -1.02936320e-01,
                         -1.01425111e-01,  -9.99720320e-02,  -9.82283354e-02,
                         -9.67171267e-02,  -9.50896740e-02,  -9.35784727e-02,
                         -9.22997594e-02,  -9.04398113e-02,  -8.91029760e-02,
                         -8.76498967e-02,  -8.57899487e-02,  -8.43949914e-02,
                         -8.27675387e-02,  -8.11400861e-02,  -7.96870068e-02,
                         -7.79433101e-02,  -7.64902309e-02,  -7.48627782e-02,
                         -7.31772035e-02,  -7.17241168e-02,  -7.00966641e-02,
                         -6.86435848e-02,  -6.71323836e-02,  -6.55049309e-02,
                         -6.38774782e-02,  -6.21337779e-02,  -6.06806986e-02,
                         -5.91113679e-02,  -5.74257933e-02,  -5.58564663e-02,
                         -5.42290136e-02,  -5.27759306e-02,  -5.11484817e-02,
                         -4.94629070e-02,  -4.81841937e-02,  -4.63823713e-02,
                         -4.46967967e-02,  -4.33018394e-02,  -4.15581390e-02,
                         -3.99306901e-02,  -3.83032374e-02,  -3.67920324e-02,
                         -3.52808274e-02,  -3.35371271e-02,  -3.21421698e-02,
                         -3.05728409e-02,  -2.88291443e-02,  -2.73179393e-02,
                         -2.56323628e-02,  -2.40049120e-02,  -2.24355832e-02,
                         -2.06337627e-02,  -1.91806797e-02,  -1.77857224e-02,
                         -1.61582697e-02,  -1.42983254e-02,  -1.25546269e-02,
                         -1.10434219e-02,  -9.24160052e-03,  -7.38165574e-03,
                         -5.87045075e-03,  -4.12675226e-03,  -2.49930075e-03,
                         -8.71849130e-04,   7.55602552e-04,   2.20868434e-03,
                          3.95238260e-03,   5.57983434e-03,   7.20728608e-03,
                          8.95098411e-03,   1.04040662e-02,   1.20896408e-02,
                          1.37170926e-02,   1.53445443e-02,   1.70882419e-02,
                          1.85413249e-02,   2.02850215e-02,   2.18543503e-02,
                          2.33074334e-02,   2.51092538e-02,   2.67367065e-02,
                          2.82479115e-02,   2.97009926e-02,   3.10959518e-02,
                          3.28396484e-02,   3.45252231e-02,   3.62107977e-02,
                          3.77220027e-02,   3.92332077e-02,   4.09187861e-02,
                          4.23137434e-02,   4.38830703e-02,   4.55686450e-02,
                          4.70217280e-02,   4.86491807e-02,   5.01022600e-02,
                          5.14972210e-02,   5.31827956e-02,   5.46358787e-02,
                          5.63214533e-02,   5.79489022e-02,   5.95182329e-02,
                          6.11456819e-02,   6.24825172e-02,   6.39356002e-02,
                          6.56211749e-02,   6.70742542e-02,   6.85273409e-02,
                          6.99804202e-02,   7.14334995e-02,   7.29447082e-02,
                          7.43977875e-02,   7.60833621e-02,   7.75945708e-02,
                          7.88732842e-02,   8.05007368e-02,   8.20119381e-02,
                          8.34068954e-02,   8.50343481e-02,   8.64874274e-02,
                          8.77661407e-02,   8.92192274e-02,   9.09048021e-02,
                          9.22416374e-02,   9.34622213e-02,   9.50315520e-02,
                          9.64265093e-02,   9.78214666e-02,   9.93326753e-02,
                          1.00611389e-01,   1.02064468e-01,   1.03401303e-01,
                          1.04680017e-01,   1.06133096e-01,   1.07469931e-01,
                          1.08981140e-01,   1.10259853e-01,   1.11422315e-01,
                          1.13049768e-01,   1.14270352e-01,   1.15432821e-01,
                          1.16885900e-01,   1.18164614e-01,   1.19385205e-01,
                          1.20605789e-01,   1.22000754e-01,   1.23511955e-01,
                          1.24732547e-01,   1.25953138e-01,   1.27173722e-01,
                          1.28452435e-01,   1.29905522e-01,   1.31126106e-01,
                          1.32288575e-01,   1.33451030e-01,   1.34787872e-01,
                          1.36240959e-01,   1.37461543e-01,   1.38740256e-01,
                          1.39902726e-01,   1.41065180e-01,   1.42518267e-01,
                          1.43738851e-01,   1.44901320e-01,   1.46180034e-01,
                          1.47400618e-01,   1.48621216e-01,   1.49725556e-01,
                          1.51120514e-01,   1.52399227e-01,   1.53445438e-01,
                          1.54724151e-01,   1.55828491e-01,   1.56816587e-01,
                          1.58211544e-01,   1.59315899e-01,   1.60420239e-01,
                          1.61757067e-01,   1.62861407e-01,   1.63907632e-01,
                          1.64953843e-01,   1.66058198e-01,   1.67336911e-01,
                          1.68441251e-01,   1.69545591e-01,   1.70766175e-01,
                          1.71870515e-01,   1.72916740e-01,   1.74079210e-01,
                          1.75125420e-01,   1.75939143e-01,   1.77101612e-01,
                          1.78205952e-01,   1.79019675e-01,   1.80124030e-01,
                          1.81402743e-01,   1.82274580e-01,   1.83204561e-01,
                          1.84308901e-01,   1.85238868e-01,   1.86110720e-01,
                          1.87273189e-01,   1.88493773e-01,   1.89191252e-01,
                          1.90179348e-01,   1.91283688e-01,   1.92213669e-01,
                          1.93259880e-01,   1.94189861e-01,   1.95119828e-01,
                          1.95991680e-01,   1.96805403e-01,   1.97735369e-01,
                          1.98607221e-01,   1.99595317e-01,   2.00583413e-01,
                          2.01280892e-01,   2.02152744e-01,   2.03140840e-01,
                          2.04245180e-01,   2.04942659e-01,   2.05582023e-01,
                          2.06686363e-01,   2.07558215e-01,   2.08313808e-01,
                          2.09360033e-01,   2.09999382e-01,   2.10754991e-01,
                          2.11743087e-01,   2.12440565e-01,   2.13138044e-01,
                          2.14126140e-01,   2.15056106e-01,   2.15811715e-01,
                          2.16509193e-01,   2.17264801e-01,   2.17904150e-01,
                          2.18717873e-01,   2.19473481e-01,   2.19996586e-01,
                          2.20868438e-01,   2.21740291e-01,   2.22263396e-01,
                          2.23019004e-01,   2.23774597e-01,   2.24355832e-01,
                          2.24937066e-01,   2.25576431e-01,   2.26506397e-01,
                          2.27087632e-01,   2.27494493e-01,   2.28308216e-01,
                          2.28831321e-01,   2.29470685e-01,   2.30168164e-01,
                          2.30575025e-01,   2.31214374e-01,   2.31911868e-01,
                          2.32318729e-01,   2.32841834e-01,   2.33481184e-01,
                          2.34120548e-01,   2.34585539e-01,   2.35050514e-01,
                          2.35689878e-01,   2.36212984e-01,   2.36736089e-01,
                          2.37142950e-01,   2.37433568e-01,   2.38014802e-01,
                          2.38479793e-01,   2.39002898e-01,   2.39467889e-01,
                          2.40049124e-01,   2.40688473e-01,   2.40979090e-01,
                          2.41502196e-01,   2.42025316e-01,   2.42315933e-01,
                          2.42780909e-01,   2.43071526e-01,   2.43536517e-01,
                          2.44059622e-01,   2.44292125e-01,   2.44757101e-01,
                          2.45338336e-01,   2.45628953e-01,   2.46093944e-01,
                          2.46500805e-01,   2.46791422e-01,   2.47198284e-01,
                          2.47547016e-01,   2.47895762e-01,   2.48186380e-01,
                          2.48476997e-01,   2.48767614e-01,   2.49174476e-01,
                          2.49523208e-01,   2.49697581e-01,   2.49871954e-01,
                          2.50162572e-01,   2.50453174e-01,   2.50685692e-01,
                          2.50685692e-01,   2.50976294e-01,   2.51325041e-01,
                          2.51383156e-01,   2.51557529e-01,   2.51673788e-01,
                          2.51964390e-01,   2.52196878e-01,   2.52080649e-01,
                          2.52313137e-01,   2.52545625e-01,   2.52429366e-01,
                          2.52603740e-01,   2.52778113e-01,   2.52836227e-01,
                          2.52836227e-01,   2.52719998e-01,   2.52836227e-01,
                          2.53010601e-01,   2.53068745e-01,   2.53010601e-01,
                          2.53068745e-01,   2.53126860e-01,   2.53126860e-01,
                          2.53184974e-01,   2.53126860e-01,   2.52719998e-01,
                          2.52719998e-01,   2.52778113e-01,   2.52778113e-01,
                          2.52894372e-01,   2.52661884e-01,   2.52545625e-01,
                          2.52545625e-01,   2.52429366e-01,   2.52429366e-01,
                          2.52196878e-01,   2.52080649e-01,   2.52138764e-01,
                          2.51906276e-01,   2.51790017e-01,   2.51731902e-01,
                          2.51615644e-01,   2.51441270e-01,   2.51208782e-01,
                          2.51034409e-01,   2.50743806e-01,   2.50627548e-01,
                          2.50336945e-01,   2.50046313e-01,   2.49871954e-01,
                          2.49406964e-01,   2.49174476e-01,   2.48883858e-01,
                          2.48418868e-01,   2.48302624e-01,   2.48070136e-01,
                          2.47779518e-01,   2.47663274e-01,   2.47082040e-01,
                          2.46733293e-01,   2.46500805e-01,   2.46093944e-01,
                          2.45861441e-01,   2.45280221e-01,   2.44698986e-01,
                          2.44466484e-01,   2.43827134e-01,   2.43478388e-01,
                          2.43187770e-01,   2.42606550e-01,   2.42199674e-01,
                          2.41676569e-01,   2.41211578e-01,   2.40862846e-01,
                          2.40339741e-01,   2.39874750e-01,   2.39235386e-01,
                          2.38712281e-01,   2.38072932e-01,   2.37491697e-01,
                          2.37317324e-01,   2.36561716e-01,   2.35806122e-01,
                          2.35341132e-01,   2.34527409e-01,   2.34004304e-01,
                          2.33481184e-01,   2.32725590e-01,   2.32202470e-01,
                          2.31446877e-01,   2.30981886e-01,   2.30400652e-01,
                          2.29645059e-01,   2.29121938e-01,   2.28366345e-01,
                          2.27726981e-01,   2.26971388e-01,   2.26099536e-01,
                          2.25634545e-01,   2.24937066e-01,   2.24065214e-01,
                          2.23425865e-01,   2.22728387e-01,   2.22030908e-01,
                          2.21042812e-01,   2.20345333e-01,   2.19647855e-01,
                          2.18776003e-01,   2.18311012e-01,   2.17322916e-01,
                          2.16334820e-01,   2.15637341e-01,   2.14649245e-01,
                          2.13835523e-01,   2.12963670e-01,   2.12091818e-01,
                          2.11394340e-01,   2.10406244e-01,   2.09650651e-01,
                          2.08662555e-01,   2.07500085e-01,   2.06744477e-01,
                          2.05814511e-01,   2.05000788e-01,   2.04070807e-01,
                          2.02675849e-01,   2.01978371e-01,   2.01106533e-01,
                          1.99944064e-01,   1.99072212e-01,   1.98025987e-01,
                          1.96979776e-01,   1.96107924e-01,   1.95003584e-01,
                          1.93957359e-01,   1.92911148e-01,   1.92039296e-01,
                          1.91051200e-01,   1.89888731e-01,   1.89075008e-01,
                          1.88086912e-01,   1.86924443e-01,   1.85994476e-01,
                          1.84832007e-01,   1.83727667e-01,   1.82797700e-01,
                          1.81577101e-01,   1.80530891e-01,   1.79484665e-01,
                          1.78264081e-01,   1.77275985e-01,   1.76229760e-01,
                          1.75009176e-01,   1.73788592e-01,   1.72684252e-01,
                          1.71696156e-01,   1.70533687e-01,   1.69371217e-01,
                          1.68325007e-01,   1.67162538e-01,   1.66000068e-01,
                          1.64953843e-01,   1.63849503e-01,   1.62570789e-01,
                          1.61524579e-01,   1.60536483e-01,   1.59141526e-01,
                          1.57920927e-01,   1.56874716e-01,   1.55654132e-01,
                          1.54607907e-01,   1.53329194e-01,   1.51992366e-01,
                          1.51004270e-01,   1.49725556e-01,   1.48504958e-01,
                          1.47400618e-01,   1.46121904e-01,   1.44959450e-01,
                          1.43622607e-01,   1.42460138e-01,   1.41355798e-01,
                          1.40018970e-01,   1.38798371e-01,   1.37635916e-01,
                          1.36357203e-01,   1.35020360e-01,   1.33799776e-01,
                          1.32753551e-01,   1.31358594e-01,   1.30079880e-01,
                          1.29091784e-01,   1.27871200e-01,   1.26476243e-01,
                          1.25313774e-01,   1.24209434e-01,   1.22988850e-01,
                          1.21710137e-01,   1.20605789e-01,   1.19327083e-01,
                          1.18164614e-01,   1.17176518e-01,   1.15955934e-01,
                          1.14560969e-01,   1.13282263e-01,   1.12177916e-01,
                          1.11247942e-01,   1.09969236e-01,   1.08632401e-01,
                          1.07469931e-01,   1.06191218e-01,   1.05145000e-01,
                          1.03982538e-01,   1.02645703e-01,   1.01483233e-01,
                          1.00495137e-01,   9.92164314e-02,   9.79377180e-02,
                          9.68915001e-02,   9.58452746e-02,   9.45084393e-02,
                          9.34040993e-02,   9.24160033e-02,   9.12535414e-02,
                          9.00329500e-02,   8.87542367e-02,   8.75917748e-02,
                          8.66618007e-02,   8.55574608e-02,   8.43949914e-02,
                          8.32325295e-02,   8.19538161e-02,   8.09075981e-02,
                          7.98613802e-02,   7.85826668e-02,   7.73620754e-02,
                          7.61414915e-02,   7.50952661e-02,   7.39909261e-02,
                          7.26540908e-02,   7.15497509e-02,   7.05616549e-02,
                          6.93410635e-02,   6.81786016e-02,   6.71905056e-02,
                          6.60280362e-02,   6.48655742e-02,   6.38774782e-02,
                          6.28312603e-02,   6.16687946e-02,   6.05063289e-02,
                          5.95182329e-02,   5.84720112e-02,   5.73676713e-02,
                          5.63795753e-02,   5.52171096e-02,   5.38802743e-02,
                          5.30084260e-02,   5.19622080e-02,   5.06834947e-02,
                          4.96953987e-02,   4.87654246e-02,   4.77192067e-02,
                          4.64986190e-02,   4.55105230e-02,   4.46967967e-02,
                          4.34180871e-02,   4.24299911e-02,   4.15000170e-02,
                          4.03375514e-02,   3.93494554e-02,   3.82451154e-02,
                          3.71988937e-02,   3.62689234e-02,   3.52808274e-02,
                          3.44671011e-02,   3.33046354e-02,   3.20840478e-02,
                          3.12121976e-02,   3.01078558e-02,   2.88872663e-02,
                          2.78991722e-02,   2.69110762e-02,   2.57486105e-02,
                          2.45861448e-02,   2.37142947e-02,   2.26680767e-02,
                          2.16218568e-02,   2.05756389e-02,   1.94712970e-02,
                          1.85994469e-02,   1.76694747e-02,   1.63907632e-02,
                          1.52864205e-02,   1.42402016e-02,   1.31358597e-02,
                          1.20315179e-02,   1.09271752e-02,   9.99720301e-03,
                          8.77661444e-03,   7.55602540e-03,   6.68417662e-03,
                          5.46358759e-03,   4.24299901e-03,   3.37114977e-03,
                          2.20868434e-03,   9.88095650e-04,  -2.32493097e-04,
                         -1.33683532e-03,  -2.38305423e-03,  -3.42927314e-03,
                         -4.53361543e-03,  -5.75420400e-03,  -6.85854629e-03,
                         -7.90476520e-03,  -9.00910702e-03,  -1.01134498e-02,
                         -1.12177916e-02,  -1.23802572e-02,  -1.34264762e-02,
                         -1.46470647e-02,  -1.56932846e-02,  -1.66813787e-02,
                         -1.77857224e-02,  -1.88900642e-02,  -2.00525299e-02,
                         -2.10406259e-02,  -2.21449677e-02,  -2.34236792e-02,
                         -2.43536513e-02,  -2.54579931e-02,  -2.66785827e-02,
                         -2.77248006e-02,  -2.88872663e-02,  -3.00497320e-02,
                         -3.13865691e-02,  -3.24909091e-02,  -3.34790051e-02,
                         -3.48158404e-02,  -3.58039364e-02,  -3.68501544e-02,
                         -3.81288677e-02,  -3.90588380e-02,  -4.00469340e-02,
                         -4.13256474e-02,  -4.27206047e-02,  -4.38830703e-02,
                         -4.48130444e-02,  -4.61498797e-02,  -4.73704673e-02,
                         -4.84166853e-02,  -4.96953987e-02,  -5.09741120e-02,
                         -5.20784520e-02,  -5.31246737e-02,  -5.44033833e-02,
                         -5.56239709e-02,  -5.67864366e-02,  -5.81813976e-02,
                         -5.92857376e-02,  -6.03319593e-02,  -6.16687946e-02,
                         -6.28312603e-02,  -6.40518442e-02,  -6.52143136e-02,
                         -6.64349049e-02,  -6.78298622e-02,  -6.88760802e-02,
                         -7.01547936e-02,  -7.14916289e-02,  -7.25378469e-02,
                         -7.38165602e-02,  -7.50952661e-02,  -7.62577355e-02,
                         -7.75364488e-02,  -7.87570328e-02,  -8.00357461e-02,
                         -8.11400861e-02,  -8.21281821e-02,  -8.34650174e-02,
                         -8.46274868e-02,  -8.57899487e-02,  -8.70686620e-02,
                         -8.81730095e-02,  -8.93935934e-02,  -9.06723067e-02,
                         -9.18347687e-02,  -9.30553600e-02,  -9.42759514e-02,
                         -9.55546647e-02,  -9.68915001e-02,  -9.80539620e-02,
                         -9.91001800e-02,  -1.00378893e-01,  -1.01715729e-01,
                         -1.02761947e-01,  -1.04040660e-01,  -1.05377495e-01,
                         -1.06423713e-01,  -1.07818671e-01,  -1.09039262e-01,
                         -1.10085480e-01,  -1.11712933e-01,  -1.12817273e-01,
                         -1.13863491e-01,  -1.15258448e-01,  -1.16362795e-01,
                         -1.17641509e-01,  -1.18920214e-01,  -1.19966440e-01,
                         -1.21303275e-01,  -1.22698233e-01,  -1.24035068e-01,
                         -1.25139400e-01,  -1.26359999e-01,  -1.27813071e-01,
                         -1.28859296e-01,  -1.30079880e-01,  -1.31358594e-01,
                         -1.32462934e-01,  -1.33857906e-01,  -1.34962246e-01,
                         -1.36066586e-01,  -1.37403414e-01,  -1.38507754e-01,
                         -1.39612108e-01,  -1.40774563e-01,  -1.42053276e-01,
                         -1.43273875e-01,  -1.44378215e-01,  -1.45656928e-01,
                         -1.46935642e-01,  -1.48098096e-01,  -1.49318695e-01,
                         -1.50481150e-01,  -1.51643619e-01,  -1.52747959e-01,
                         -1.53736055e-01,  -1.55014768e-01,  -1.56060994e-01,
                         -1.57165334e-01,  -1.58385918e-01,  -1.59432143e-01,
                         -1.60478354e-01,  -1.61640823e-01,  -1.62861407e-01,
                         -1.64023876e-01,  -1.64895728e-01,  -1.66058198e-01,
                         -1.67162538e-01,  -1.68208748e-01,  -1.69371217e-01,
                         -1.70475557e-01,  -1.71521783e-01,  -1.72509879e-01,
                         -1.73497975e-01,  -1.74718559e-01,  -1.75764784e-01,
                         -1.76694751e-01,  -1.77857220e-01,  -1.79077804e-01,
                         -1.80007771e-01,  -1.81053996e-01,  -1.82274580e-01,
                         -1.83262676e-01,  -1.84192657e-01,  -1.85471371e-01,
                         -1.86401337e-01,  -1.87331304e-01,  -1.88435659e-01,
                         -1.89423755e-01,  -1.90469965e-01,  -1.91458061e-01,
                         -1.92446157e-01,  -1.93492383e-01,  -1.94364220e-01,
                         -1.95410445e-01,  -1.96166053e-01,  -1.97096020e-01,
                         -1.98316604e-01,  -1.99188456e-01,  -2.00118437e-01,
                         -2.01164648e-01,  -2.01978371e-01,  -2.03024596e-01,
                         -2.03722075e-01,  -2.04477683e-01,  -2.05698267e-01,
                         -2.06570119e-01,  -2.07441956e-01,  -2.08255693e-01,
                         -2.09011286e-01,  -2.09999382e-01,  -2.10696861e-01,
                         -2.11510599e-01,  -2.12382436e-01,  -2.13254288e-01,
                         -2.14300513e-01,  -2.14997992e-01,  -2.15637341e-01,
                         -2.16451064e-01,  -2.17206672e-01,  -2.18078524e-01,
                         -2.18834117e-01,  -2.19705969e-01,  -2.20519707e-01,
                         -2.20984682e-01,  -2.21914664e-01,  -2.22786501e-01,
                         -2.23309621e-01,  -2.24007100e-01,  -2.24704579e-01,
                         -2.25460172e-01,  -2.26332024e-01,  -2.26971388e-01,
                         -2.27726981e-01,  -2.28424460e-01,  -2.29180068e-01,
                         -2.29761302e-01,  -2.30342537e-01,  -2.31156260e-01,
                         -2.31737494e-01,  -2.32434973e-01,  -2.33248696e-01,
                         -2.33771801e-01,  -2.34469280e-01,  -2.35050514e-01,
                         -2.35689878e-01,  -2.36387357e-01,  -2.37026706e-01,
                         -2.37724185e-01,  -2.38189176e-01,  -2.38712281e-01,
                         -2.39351645e-01,  -2.39700377e-01,  -2.40281612e-01,
                         -2.40862846e-01,  -2.41327837e-01,  -2.41967186e-01,
                         -2.42374048e-01,  -2.42780909e-01,  -2.43245900e-01,
                         -2.43594632e-01,  -2.44175866e-01,  -2.44524613e-01,
                         -2.44873345e-01,  -2.45396465e-01,  -2.45745197e-01,
                         -2.46152058e-01,  -2.46384561e-01,  -2.46733293e-01,
                         -2.47198284e-01,  -2.47430772e-01,  -2.47837633e-01,
                         -2.48186380e-01,  -2.48476997e-01,  -2.48883858e-01,
                         -2.49174476e-01,  -2.49406964e-01,  -2.49639466e-01,
                         -2.49813825e-01,  -2.50104457e-01,  -2.50336945e-01,
                         -2.50685692e-01,  -2.50918180e-01,  -2.51034409e-01,
                         -2.51383156e-01,  -2.51557529e-01,  -2.51790017e-01,
                         -2.52138764e-01,  -2.52022505e-01,  -2.52196878e-01,
                         -2.52429366e-01,  -2.52545625e-01,  -2.52719998e-01,
                         -2.52778113e-01,  -2.52952486e-01,  -2.53010601e-01,
                         -2.53184974e-01,  -2.53301233e-01,  -2.53184974e-01,
                         -2.53417462e-01,  -2.53649980e-01,  -2.53533721e-01,
                         -2.53708094e-01,  -2.53649980e-01,  -2.53591835e-01,
                         -2.53766209e-01,  -2.53649980e-01,  -2.53591835e-01,
                         -2.53359348e-01,  -2.53184974e-01,  -2.53533721e-01,
                         -2.53475606e-01,  -2.53243089e-01,  -2.53243089e-01,
                         -2.52952486e-01,  -2.52894372e-01,  -2.52719998e-01,
                         -2.52603740e-01,  -2.52487510e-01,  -2.52138764e-01,
                         -2.52138764e-01,  -2.51906276e-01,  -2.51441270e-01,
                         -2.51441270e-01,  -2.51266897e-01,  -2.50918180e-01,
                         -2.50511318e-01,  -2.50220686e-01,  -2.50162572e-01,
                         -2.49813825e-01,  -2.49465093e-01,  -2.49232590e-01,
                         -2.48941973e-01,  -2.48767614e-01,  -2.48535112e-01,
                         -2.48128250e-01,  -2.47721389e-01,  -2.47314528e-01,
                         -2.46965796e-01,  -2.46733293e-01,  -2.46384561e-01,
                         -2.45919570e-01,  -2.45396465e-01,  -2.45105848e-01,
                         -2.44698986e-01,  -2.44175866e-01,  -2.43769005e-01,
                         -2.43420273e-01,  -2.43013412e-01,  -2.42548421e-01,
                         -2.42083430e-01,  -2.41502196e-01,  -2.41037220e-01,
                         -2.40688473e-01,  -2.40049124e-01,  -2.39409760e-01,
                         -2.39061028e-01,  -2.38596037e-01,  -2.38072932e-01,
                         -2.37607941e-01,  -2.36968592e-01,  -2.36503601e-01,
                         -2.35922366e-01,  -2.35399261e-01,  -2.34876141e-01,
                         -2.34353036e-01,  -2.33713686e-01,  -2.33074322e-01,
                         -2.32609347e-01,  -2.31969982e-01,  -2.31272504e-01,
                         -2.30865642e-01,  -2.30051920e-01,  -2.29296312e-01,
                         -2.28889450e-01,  -2.28017598e-01,  -2.27320120e-01,
                         -2.26797014e-01,  -2.26099536e-01,  -2.25460172e-01,
                         -2.24704579e-01,  -2.24065214e-01,  -2.23251492e-01,
                         -2.22495884e-01,  -2.21914664e-01,  -2.21042812e-01,
                         -2.20287204e-01,  -2.19705969e-01,  -2.18950376e-01,
                         -2.18252897e-01,  -2.17555419e-01,  -2.16857940e-01,
                         -2.16218576e-01,  -2.15404853e-01,  -2.14649245e-01,
                         -2.13661149e-01,  -2.12789297e-01,  -2.12033704e-01,
                         -2.10987478e-01,  -2.10115626e-01,  -2.09301904e-01,
                         -2.08604425e-01,  -2.07848832e-01,  -2.06918851e-01,
                         -2.06221372e-01,  -2.05175161e-01,  -2.04128936e-01,
                         -2.03547701e-01,  -2.02443361e-01,  -2.01455265e-01,
                         -2.00699657e-01,  -1.99711561e-01,  -1.98839724e-01,
                         -1.97793499e-01,  -1.96921647e-01,  -1.96107924e-01,
                         -1.95119828e-01,  -1.94306105e-01,  -1.93143636e-01,
                         -1.92155540e-01,  -1.91458061e-01,  -1.90353721e-01,
                         -1.89307496e-01,  -1.88377529e-01,  -1.87447563e-01,
                         -1.86517581e-01,  -1.85355112e-01,  -1.84425145e-01,
                         -1.83437049e-01,  -1.82158336e-01,  -1.81228369e-01,
                         -1.80065900e-01,  -1.78845316e-01,  -1.77915335e-01,
                         -1.76752880e-01,  -1.75648525e-01,  -1.74602315e-01,
                         -1.73439845e-01,  -1.72335505e-01,  -1.71173036e-01,
                         -1.70184940e-01,  -1.68964356e-01,  -1.67743772e-01,
                         -1.66697547e-01,  -1.65302590e-01,  -1.64140120e-01,
                         -1.62977666e-01,  -1.61698952e-01,  -1.60768971e-01,
                         -1.59548387e-01,  -1.58153430e-01,  -1.57107204e-01,
                         -1.55886620e-01,  -1.54549778e-01,  -1.53271079e-01,
                         -1.52108610e-01,  -1.51004270e-01,  -1.49551183e-01,
                         -1.48388714e-01,  -1.47168130e-01,  -1.45831287e-01,
                         -1.44785076e-01,  -1.43390119e-01,  -1.42227650e-01,
                         -1.41181424e-01,  -1.39612108e-01,  -1.38391510e-01,
                         -1.37054682e-01,  -1.35601595e-01,  -1.34497255e-01,
                         -1.33044168e-01,  -1.31765455e-01,  -1.30486742e-01,
                         -1.28975540e-01,  -1.27987444e-01,  -1.26476243e-01,
                         -1.24965034e-01,  -1.23744451e-01,  -1.22291364e-01,
                         -1.20896406e-01,  -1.19443327e-01,  -1.18106492e-01,
                         -1.16769657e-01,  -1.15142204e-01,  -1.13805369e-01,
                         -1.12410411e-01,  -1.10957332e-01,  -1.09678619e-01,
                         -1.08051166e-01,  -1.06714331e-01,  -1.05261251e-01,
                         -1.03633799e-01,  -1.02355085e-01,  -1.00843877e-01,
                         -9.93907973e-02,  -9.80539620e-02,  -9.64265093e-02,
                         -9.49153081e-02,  -9.33459774e-02,  -9.19510201e-02,
                         -9.04979333e-02,  -8.87542367e-02,  -8.74755234e-02,
                         -8.59643221e-02,  -8.43368694e-02,  -8.29419121e-02,
                         -8.12563375e-02,  -7.96288848e-02,  -7.81758055e-02,
                         -7.66064748e-02,  -7.50952661e-02,  -7.34678209e-02,
                         -7.18403682e-02,  -7.03291595e-02,  -6.88760802e-02,
                         -6.75392449e-02,  -6.58536702e-02,  -6.41680956e-02,
                         -6.27150089e-02,  -6.12619296e-02,  -5.97507246e-02,
                         -5.81232719e-02,  -5.66120669e-02,  -5.51008619e-02,
                         -5.34734130e-02,  -5.20784520e-02,  -5.05672470e-02,
                         -4.88816723e-02,  -4.72542197e-02,  -4.56267707e-02,
                         -4.41155657e-02,  -4.25462350e-02,  -4.09769081e-02,
                         -3.93494554e-02,  -3.76057588e-02,  -3.62689234e-02,
                         -3.47577184e-02,  -3.30721438e-02,  -3.16771828e-02,
                         -2.99334861e-02,  -2.82479115e-02,  -2.67948285e-02,
                         -2.51092538e-02,  -2.34818030e-02,  -2.19124742e-02,
                         -2.02268995e-02,  -1.87738165e-02,  -1.72044896e-02,
                         -1.55189140e-02,  -1.39495861e-02,  -1.23221343e-02,
                         -1.07528055e-02,  -9.18347761e-03,  -7.55602540e-03,
                         -5.87045075e-03,  -4.18487564e-03,  -2.49930075e-03,
                         -8.71849130e-04,   6.39356032e-04,   2.32493086e-03,
                          4.06862935e-03,   5.69608063e-03,   7.32353237e-03,
                          8.95098411e-03,   1.05784358e-02,   1.22058876e-02,
                          1.37752155e-02,   1.54026672e-02,   1.69719961e-02,
                          1.85413249e-02,   2.04012692e-02,   2.19705980e-02,
                          2.34236792e-02,   2.49930080e-02,   2.65623368e-02,
                          2.83060335e-02,   2.98172385e-02,   3.13865691e-02,
                          3.31302658e-02,   3.46414708e-02,   3.62689234e-02,
                          3.78963761e-02,   3.93494554e-02,   4.11512777e-02,
                          4.26624827e-02,   4.41155657e-02,   4.58011404e-02,
                          4.71960977e-02,   4.88235503e-02,   5.04510030e-02,
                          5.20203300e-02,   5.35315350e-02,   5.49846180e-02,
                          5.68445623e-02,   5.85301369e-02,   5.97507246e-02,
                          6.14362992e-02,   6.31799996e-02,   6.46912009e-02,
                          6.60280362e-02,   6.74811229e-02,   6.92829415e-02,
                          7.08522722e-02,   7.24215955e-02,   7.39909261e-02,
                          7.53858835e-02,   7.68970922e-02,   7.83501714e-02,
                          7.98032507e-02,   8.14888328e-02,   8.29419121e-02,
                          8.44531134e-02,   8.59062001e-02,   8.73592794e-02,
                          8.89286101e-02,   9.03816894e-02,   9.18928981e-02,
                          9.32297334e-02,   9.47409347e-02,   9.64846313e-02,
                          9.78795961e-02,   9.92164314e-02,   1.00611389e-01,
                          1.02006346e-01,   1.03459425e-01,   1.04854383e-01,
                          1.06365591e-01,   1.07818671e-01,   1.09213628e-01,
                          1.10666715e-01,   1.11945428e-01,   1.13282263e-01,
                          1.14677221e-01,   1.16072178e-01,   1.17467135e-01,
                          1.18745849e-01,   1.20198928e-01,   1.21535763e-01,
                          1.22640111e-01,   1.24093190e-01,   1.25488147e-01,
                          1.26766860e-01,   1.28103688e-01,   1.29266158e-01,
                          1.30544871e-01,   1.31823584e-01,   1.33044168e-01,
                          1.34497255e-01,   1.35717839e-01,   1.36764064e-01,
                          1.37926534e-01,   1.39263362e-01,   1.40542075e-01,
                          1.41704544e-01,   1.43099502e-01,   1.44436330e-01,
                          1.45540670e-01,   1.46819383e-01,   1.47923738e-01,
                          1.49086192e-01,   1.50364906e-01,   1.51353002e-01,
                          1.52573586e-01,   1.53794184e-01,   1.54782280e-01,
                          1.56119108e-01,   1.57223448e-01,   1.58269674e-01,
                          1.59432143e-01,   1.60536483e-01,   1.61698952e-01,
                          1.62687048e-01,   1.63675144e-01,   1.65011972e-01,
                          1.66000068e-01,   1.66988164e-01,   1.68092504e-01,
                          1.68964356e-01,   1.70068696e-01,   1.71056792e-01,
                          1.72044888e-01,   1.73207358e-01,   1.74137324e-01,
                          1.75183550e-01,   1.76171646e-01,   1.77101612e-01,
                          1.78205952e-01,   1.79252177e-01,   1.80065900e-01,
                          1.80995867e-01,   1.82158336e-01,   1.83030188e-01,
                          1.83727667e-01,   1.84715763e-01,   1.85645729e-01,
                          1.86401337e-01,   1.87331304e-01,   1.88203156e-01,
                          1.89016879e-01,   1.89830616e-01,   1.90760583e-01,
                          1.91632435e-01,   1.92271784e-01,   1.93143636e-01,
                          1.93899244e-01,   1.94596723e-01,   1.95526689e-01,
                          1.96107924e-01,   1.96863532e-01,   1.97793499e-01,
                          1.98374733e-01,   1.98955968e-01,   1.99595317e-01,
                          2.00176552e-01,   2.00932160e-01,   2.01571509e-01,
                          2.02268988e-01,   2.02966467e-01,   2.03722075e-01,
                          2.04535797e-01,   2.05058903e-01,   2.05698267e-01,
                          2.06279501e-01,   2.06976980e-01,   2.07674459e-01,
                          2.08139449e-01,   2.08720669e-01,   2.09418148e-01,
                          2.10057512e-01,   2.10696861e-01,   2.11045608e-01,
                          2.11568713e-01,   2.12149948e-01,   2.12614939e-01,
                          2.13254288e-01,   2.13719279e-01,   2.14184269e-01,
                          2.14939862e-01,   2.15404853e-01,   2.15753585e-01,
                          2.16160446e-01,   2.16683567e-01,   2.17206672e-01,
                          2.17439160e-01,   2.17904150e-01,   2.18311012e-01,
                          2.18601629e-01,   2.19357237e-01,   2.19647855e-01,
                          2.19822213e-01,   2.20345333e-01,   2.20577821e-01,
                          2.20694065e-01,   2.20926568e-01,   2.21333429e-01,
                          2.21798405e-01,   2.21856534e-01,   2.22147152e-01,
                          2.22437769e-01,   2.22670257e-01,   2.23019004e-01,
                          2.23193377e-01,   2.23309621e-01,   2.23425865e-01,
                          2.23483980e-01,   2.23774597e-01,   2.23948970e-01,
                          2.24065214e-01,   2.24355832e-01,   2.24530205e-01,
                          2.24704579e-01,   2.24762693e-01,   2.24820822e-01,
                          2.24937066e-01,   2.24937066e-01,   2.25053310e-01,
                          2.25169554e-01,   2.25227684e-01,   2.25402057e-01,
                          2.25402057e-01,   2.25460172e-01,   2.25402057e-01,
                          2.25518301e-01,   2.25634545e-01,   2.25460172e-01,
                          2.25576431e-01,   2.25576431e-01,   2.25460172e-01,
                          2.25634545e-01,   2.25460172e-01,   2.25460172e-01,
                          2.25518301e-01,   2.25343928e-01,   2.25518301e-01,
                          2.25343928e-01,   2.25111440e-01,   2.25111440e-01,
                          2.24878952e-01,   2.24704579e-01,   2.24704579e-01,
                          2.24472076e-01,   2.24413961e-01,   2.24123344e-01,
                          2.23832726e-01,   2.23600239e-01,   2.23483980e-01,
                          2.23367736e-01,   2.23077118e-01,   2.22960874e-01,
                          2.22902760e-01,   2.22379640e-01,   2.22089022e-01,
                          2.21798405e-01,   2.21391544e-01,   2.21159056e-01,
                          2.20810309e-01,   2.20635951e-01,   2.20229089e-01,
                          2.19880342e-01,   2.19705969e-01,   2.19124734e-01,
                          2.18892246e-01,   2.18717873e-01,   2.18136638e-01,
                          2.17904150e-01,   2.17613533e-01,   2.17264801e-01,
                          2.16857940e-01,   2.16102332e-01,   2.15869844e-01,
                          2.15521097e-01,   2.14881748e-01,   2.14591131e-01,
                          2.14009896e-01,   2.13603035e-01,   2.13138044e-01,
                          2.12556809e-01,   2.12149948e-01,   2.11626843e-01,
                          2.11161852e-01,   2.10754991e-01,   2.10173756e-01,
                          2.09708765e-01,   2.09185660e-01,   2.08720669e-01,
                          2.08313808e-01,   2.07674459e-01,   2.07151353e-01,
                          2.06511989e-01,   2.05930755e-01,   2.05407649e-01,
                          2.04535797e-01,   2.04128936e-01,   2.03838319e-01,
                          2.03082711e-01,   2.02385232e-01,   2.01687753e-01,
                          2.01222777e-01,   2.00583413e-01,   1.99711561e-01,
                          1.99188456e-01,   1.98549107e-01,   1.97909743e-01,
                          1.97270393e-01,   1.96398541e-01,   1.95875436e-01,
                          1.95119828e-01,   1.94306105e-01,   1.93724871e-01,
                          1.92794904e-01,   1.92155540e-01,   1.91516191e-01,
                          1.90528095e-01,   1.89714357e-01,   1.88900635e-01,
                          1.88028783e-01,   1.87273189e-01,   1.86401337e-01,
                          1.85703859e-01,   1.84890136e-01,   1.84018284e-01,
                          1.83320805e-01,   1.82274580e-01,   1.81460857e-01,
                          1.80647135e-01,   1.79600909e-01,   1.78845316e-01,
                          1.78031594e-01,   1.77159742e-01,   1.76229760e-01,
                          1.75357923e-01,   1.74486071e-01,   1.73556089e-01,
                          1.72742367e-01,   1.71754271e-01,   1.70824304e-01,
                          1.70010582e-01,   1.69022486e-01,   1.68092504e-01,
                          1.67162538e-01,   1.66116312e-01,   1.65244460e-01,
                          1.64140120e-01,   1.63210154e-01,   1.62396431e-01,
                          1.61292091e-01,   1.60187736e-01,   1.59257770e-01,
                          1.58269674e-01,   1.57339707e-01,   1.56409726e-01,
                          1.55421630e-01,   1.54375419e-01,   1.53329194e-01,
                          1.52457342e-01,   1.51294887e-01,   1.50248662e-01,
                          1.49318695e-01,   1.48214340e-01,   1.47284374e-01,
                          1.46296278e-01,   1.45133808e-01,   1.43971354e-01,
                          1.42750755e-01,   1.41878918e-01,   1.40774563e-01,
                          1.39495850e-01,   1.38391510e-01,   1.37112796e-01,
                          1.35892212e-01,   1.34787872e-01,   1.33625403e-01,
                          1.32695436e-01,   1.31532967e-01,   1.30254254e-01,
                          1.29091784e-01,   1.28103688e-01,   1.26999348e-01,
                          1.25546277e-01,   1.24325685e-01,   1.23395711e-01,
                          1.22116998e-01,   1.20954528e-01,   1.19908310e-01,
                          1.18687727e-01,   1.17525257e-01,   1.16246544e-01,
                          1.15025960e-01,   1.13805369e-01,   1.12701029e-01,
                          1.11596689e-01,   1.10201724e-01,   1.09039262e-01,
                          1.07934922e-01,   1.06656209e-01,   1.05493739e-01,
                          1.04273155e-01,   1.03168808e-01,   1.02180712e-01,
                          1.00960128e-01,   9.96814147e-02,   9.84608233e-02,
                          9.73564833e-02,   9.61940140e-02,   9.49153081e-02,
                          9.37528387e-02,   9.24741253e-02,   9.11954194e-02,
                          9.02654454e-02,   8.89867321e-02,   8.77080187e-02,
                          8.66036788e-02,   8.54412094e-02,   8.41625035e-02,
                          8.30000341e-02,   8.19538161e-02,   8.05588588e-02,
                          7.91639015e-02,   7.80014321e-02,   7.67227188e-02,
                          7.55602568e-02,   7.43977875e-02,   7.30609521e-02,
                          7.18403682e-02,   7.05616549e-02,   6.93410635e-02,
                          6.81786016e-02,   6.68998882e-02,   6.57955483e-02,
                          6.44005835e-02,   6.31218776e-02,   6.21337779e-02,
                          6.07388206e-02,   5.94019853e-02,   5.82395196e-02,
                          5.68445623e-02,   5.56239709e-02,   5.43452613e-02,
                          5.29503003e-02,   5.16715907e-02,   5.05091250e-02,
                          4.93466593e-02,   4.77773324e-02,   4.63823713e-02,
                          4.53361534e-02,   4.40574400e-02,   4.28368524e-02,
                          4.16743867e-02,   4.04537991e-02,   3.92913334e-02,
                          3.78963761e-02,   3.67339104e-02,   3.56295668e-02,
                          3.41183618e-02,   3.28396484e-02,   3.16190608e-02,
                          3.03984713e-02,   2.92941295e-02,   2.79572941e-02,
                          2.67367065e-02,   2.55161170e-02,   2.44117752e-02,
                          2.31330637e-02,   2.17381045e-02,   2.05175150e-02,
                          1.93550494e-02,   1.80763379e-02,   1.67976264e-02,
                          1.55189140e-02,   1.44726951e-02,   1.31358597e-02,
                          1.17409015e-02,   1.06946826e-02,   9.59033985e-03,
                          8.31162836e-03,   7.03291595e-03,   5.69608063e-03,
                          4.59173881e-03,   3.19678010e-03,   1.91806804e-03,
                          9.29972390e-04,  -2.90616357e-04,  -1.68557488e-03,
                         -3.13865673e-03,  -4.35924530e-03,  -5.57983434e-03,
                         -6.91666966e-03,  -8.02101195e-03,  -9.24160052e-03,
                         -1.06365588e-02,  -1.17409015e-02,  -1.29614901e-02,
                         -1.42402016e-02,  -1.55770369e-02,  -1.67395025e-02,
                         -1.78438444e-02,  -1.92969274e-02,  -2.04593930e-02,
                         -2.15637349e-02,  -2.29586922e-02,  -2.41211578e-02,
                         -2.54579931e-02,  -2.66204588e-02,  -2.74923090e-02,
                         -2.88291443e-02,  -3.00497320e-02,  -3.12703215e-02,
                         -3.25490348e-02,  -3.35952528e-02,  -3.47577184e-02,
                         -3.59201841e-02,  -3.70245241e-02,  -3.83032374e-02,
                         -3.94657031e-02,  -4.05700430e-02,  -4.18487564e-02,
                         -4.30112220e-02,  -4.39993180e-02,  -4.50455360e-02,
                         -4.62661274e-02,  -4.73704673e-02,  -4.83585633e-02,
                         -4.94629070e-02,  -5.06253727e-02,  -5.18459603e-02,
                         -5.29503003e-02,  -5.39965220e-02,  -5.51589876e-02,
                         -5.63795753e-02,  -5.75420409e-02,  -5.87045066e-02,
                         -5.98088466e-02,  -6.08550683e-02,  -6.19594082e-02,
                         -6.31799996e-02,  -6.42262176e-02,  -6.53305575e-02,
                         -6.66673928e-02,  -6.75973669e-02,  -6.85854629e-02,
                         -6.98060542e-02,  -7.07941502e-02,  -7.20728561e-02,
                         -7.30609521e-02,  -7.39328042e-02,  -7.52696395e-02,
                         -7.63739794e-02,  -7.74201974e-02,  -7.85245448e-02,
                         -7.93382674e-02,  -8.05588588e-02,  -8.16631988e-02,
                         -8.24769214e-02,  -8.36393908e-02,  -8.46274868e-02,
                         -8.58480781e-02,  -8.68942961e-02,  -8.76498967e-02,
                         -8.86961147e-02,  -8.96260887e-02,  -9.04979333e-02,
                         -9.14860293e-02,  -9.24160033e-02,  -9.34040993e-02,
                         -9.41597000e-02,  -9.50315520e-02,  -9.61358920e-02,
                         -9.69496220e-02,  -9.77633446e-02,  -9.85770747e-02,
                         -9.94489193e-02,  -1.00320771e-01,  -1.01192616e-01,
                         -1.02180712e-01,  -1.02820069e-01,  -1.03575677e-01,
                         -1.04505643e-01,  -1.05028756e-01,  -1.06016852e-01,
                         -1.06946826e-01,  -1.07469931e-01,  -1.08341783e-01,
                         -1.09155506e-01,  -1.09911107e-01,  -1.10724837e-01,
                         -1.11247942e-01,  -1.12177916e-01,  -1.12991646e-01,
                         -1.13689125e-01,  -1.14502847e-01,  -1.14851587e-01,
                         -1.15723439e-01,  -1.16595283e-01,  -1.17060274e-01,
                         -1.17873996e-01,  -1.18629605e-01,  -1.19268954e-01,
                         -1.20082684e-01,  -1.20722041e-01,  -1.21593885e-01,
                         -1.22349493e-01,  -1.23105094e-01,  -1.23860694e-01,
                         -1.24500051e-01,  -1.25197530e-01,  -1.25895008e-01,
                         -1.26592487e-01,  -1.27406210e-01,  -1.28278062e-01,
                         -1.29033670e-01,  -1.29614905e-01,  -1.30254254e-01,
                         -1.30951732e-01,  -1.31649211e-01,  -1.32346690e-01,
                         -1.33102298e-01,  -1.33916020e-01,  -1.34439126e-01,
                         -1.34845987e-01,  -1.35659724e-01,  -1.36415318e-01,
                         -1.37170926e-01,  -1.37926534e-01,  -1.38159022e-01,
                         -1.38798371e-01,  -1.39553979e-01,  -1.40077084e-01,
                         -1.40948936e-01,  -1.41588300e-01,  -1.42053276e-01,
                         -1.42750755e-01,  -1.43273875e-01,  -1.43855095e-01,
                         -1.44552574e-01,  -1.45308182e-01,  -1.45715043e-01,
                         -1.46063790e-01,  -1.46761268e-01,  -1.47342503e-01,
                         -1.47923738e-01,  -1.48679331e-01,  -1.49086192e-01,
                         -1.49667427e-01,  -1.50132418e-01,  -1.50597408e-01,
                         -1.51469246e-01,  -1.51876107e-01,  -1.52457342e-01,
                         -1.53329194e-01,  -1.53736055e-01,  -1.54142916e-01,
                         -1.54724151e-01,  -1.55247256e-01,  -1.55944750e-01,
                         -1.56351611e-01,  -1.56816587e-01,  -1.57572195e-01,
                         -1.58211544e-01,  -1.58734664e-01,  -1.59315899e-01,
                         -1.59839004e-01,  -1.60420239e-01,  -1.60943344e-01,
                         -1.61524579e-01,  -1.61815196e-01,  -1.62280172e-01,
                         -1.62977666e-01,  -1.63326398e-01,  -1.63675144e-01,
                         -1.64198250e-01,  -1.64721355e-01,  -1.65302590e-01,
                         -1.65709451e-01,  -1.66232556e-01,  -1.66755676e-01,
                         -1.67046294e-01,  -1.67511269e-01,  -1.67976260e-01,
                         -1.68383121e-01,  -1.68789983e-01,  -1.69138730e-01,
                         -1.69661835e-01,  -1.70184940e-01,  -1.70591801e-01,
                         -1.70998678e-01,  -1.71347409e-01,  -1.71812400e-01,
                         -1.72219262e-01,  -1.72335505e-01,  -1.72684252e-01,
                         -1.73207358e-01,  -1.73614219e-01,  -1.73904836e-01,
                         -1.74253568e-01,  -1.74602315e-01,  -1.74951047e-01,
                         -1.75357923e-01,  -1.75764784e-01,  -1.76055402e-01,
                         -1.76287889e-01,  -1.76694751e-01,  -1.76985368e-01,
                         -1.77217856e-01,  -1.77624717e-01,  -1.77973464e-01,
                         -1.78205952e-01,  -1.78554699e-01,  -1.78845316e-01,
                         -1.79077804e-01,  -1.79426551e-01,  -1.79833412e-01,
                         -1.80298388e-01,  -1.80647135e-01,  -1.80705264e-01,
                         -1.81053996e-01,  -1.81402743e-01,  -1.81693345e-01,
                         -1.81983963e-01,  -1.82216465e-01,  -1.82623327e-01,
                         -1.82797700e-01,  -1.83030188e-01,  -1.83437049e-01,
                         -1.83495179e-01,  -1.83727667e-01,  -1.83960155e-01,
                         -1.84250772e-01,  -1.84657633e-01,  -1.84657633e-01,
                         -1.84890136e-01,  -1.85180753e-01,  -1.85180753e-01,
                         -1.85471371e-01,  -1.85703859e-01,  -1.85878232e-01,
                         -1.86052606e-01,  -1.85994476e-01,  -1.86226964e-01,
                         -1.86285093e-01,  -1.86401337e-01,  -1.86633825e-01,
                         -1.86459467e-01,  -1.86633825e-01,  -1.86866328e-01,
                         -1.86866328e-01,  -1.87040687e-01,  -1.86982572e-01,
                         -1.87098816e-01,  -1.87215060e-01,  -1.87040687e-01,
                         -1.87215060e-01,  -1.87156945e-01,  -1.87040687e-01,
                         -1.87215060e-01,  -1.87098816e-01,  -1.87273189e-01,
                         -1.87273189e-01,  -1.87098816e-01,  -1.87156945e-01,
                         -1.86982572e-01,  -1.86924443e-01,  -1.87156945e-01,
                         -1.87156945e-01,  -1.87156945e-01,  -1.86982572e-01,
                         -1.86924443e-01,  -1.87040687e-01,  -1.86982572e-01,
                         -1.86982572e-01,  -1.86982572e-01,  -1.86866328e-01,
                         -1.86750084e-01,  -1.86575711e-01,  -1.86459467e-01,
                         -1.86285093e-01,  -1.86285093e-01,  -1.86285093e-01,
                         -1.86110720e-01,  -1.86226964e-01,  -1.85994476e-01,
                         -1.85703859e-01,  -1.85761988e-01,  -1.85529485e-01,
                         -1.85471371e-01,  -1.85296997e-01,  -1.84832007e-01,
                         -1.84832007e-01,  -1.84715763e-01,  -1.84425145e-01,
                         -1.84308901e-01,  -1.84018284e-01,  -1.83843911e-01,
                         -1.83495179e-01,  -1.83262676e-01,  -1.83088318e-01,
                         -1.82507083e-01,  -1.82158336e-01,  -1.81983963e-01,
                         -1.81635231e-01,  -1.81402743e-01,  -1.80879623e-01,
                         -1.80589005e-01,  -1.80356517e-01,  -1.79949656e-01,
                         -1.79717168e-01,  -1.79310292e-01,  -1.78961560e-01,
                         -1.78670943e-01,  -1.78089708e-01,  -1.77682847e-01,
                         -1.77275985e-01,  -1.76927239e-01,  -1.76520377e-01,
                         -1.76055402e-01,  -1.75590411e-01,  -1.75067306e-01,
                         -1.74834803e-01,  -1.74486071e-01,  -1.73962951e-01,
                         -1.73672348e-01,  -1.73149228e-01,  -1.72567993e-01,
                         -1.72277376e-01,  -1.71812400e-01,  -1.71405539e-01,
                         -1.70882419e-01,  -1.70301184e-01,  -1.69894323e-01,
                         -1.69429347e-01,  -1.69022486e-01,  -1.68499365e-01,
                         -1.67860016e-01,  -1.67511269e-01,  -1.66988164e-01,
                         -1.66406929e-01,  -1.66000068e-01,  -1.65418833e-01,
                         -1.64953843e-01,  -1.64430737e-01,  -1.63849503e-01,
                         -1.63210154e-01,  -1.62396431e-01,  -1.61931440e-01,
                         -1.61466449e-01,  -1.60652727e-01,  -1.60071492e-01,
                         -1.59664631e-01,  -1.59025282e-01,  -1.58269674e-01,
                         -1.57572195e-01,  -1.57049090e-01,  -1.56351611e-01,
                         -1.55654132e-01,  -1.54840395e-01,  -1.54142916e-01,
                         -1.53561682e-01,  -1.52689844e-01,  -1.51934236e-01,
                         -1.51294887e-01,  -1.50423035e-01,  -1.49725556e-01,
                         -1.48969948e-01,  -1.48156226e-01,  -1.47400618e-01,
                         -1.46586895e-01,  -1.45889416e-01,  -1.45075694e-01,
                         -1.44203842e-01,  -1.43564492e-01,  -1.42634511e-01,
                         -1.41588300e-01,  -1.40774563e-01,  -1.40018970e-01,
                         -1.39030874e-01,  -1.38217151e-01,  -1.37635916e-01,
                         -1.36589691e-01,  -1.35543481e-01,  -1.34904116e-01,
                         -1.33916020e-01,  -1.32986054e-01,  -1.32056072e-01,
                         -1.31184235e-01,  -1.30603001e-01,  -1.29673019e-01,
                         -1.28626809e-01,  -1.27813071e-01,  -1.26824990e-01,
                         -1.25953138e-01,  -1.25139400e-01,  -1.24035068e-01,
                         -1.23105094e-01,  -1.22175120e-01,  -1.21187024e-01,
                         -1.20257050e-01,  -1.19327083e-01,  -1.18455231e-01,
                         -1.17467135e-01,  -1.16479039e-01,  -1.15549065e-01,
                         -1.14444725e-01,  -1.13514751e-01,  -1.12584777e-01,
                         -1.11480437e-01,  -1.10376097e-01,  -1.09213628e-01,
                         -1.08225532e-01,  -1.07353687e-01,  -1.06249347e-01,
                         -1.05086878e-01,  -1.04040660e-01,  -1.02994442e-01,
                         -1.01773851e-01,  -1.00553267e-01,  -9.93907973e-02,
                         -9.82283354e-02,  -9.71821100e-02,  -9.60196480e-02,
                         -9.46828127e-02,  -9.37528387e-02,  -9.28228647e-02,
                         -9.14279073e-02,  -9.02654454e-02,  -8.90448540e-02,
                         -8.79405141e-02,  -8.68361741e-02,  -8.54993388e-02,
                         -8.43368694e-02,  -8.32325295e-02,  -8.20700601e-02,
                         -8.09657201e-02,  -7.96288848e-02,  -7.83501714e-02,
                         -7.73039535e-02,  -7.61414915e-02,  -7.48627782e-02,
                         -7.35259429e-02,  -7.23053515e-02,  -7.11428896e-02,
                         -6.98641762e-02,  -6.86435848e-02,  -6.74811229e-02,
                         -6.63186535e-02,  -6.50980696e-02,  -6.38193563e-02,
                         -6.25987649e-02,  -6.13200553e-02,  -5.99832200e-02,
                         -5.87045066e-02,  -5.75420409e-02,  -5.64376973e-02,
                         -5.50427400e-02,  -5.39383963e-02,  -5.27178086e-02,
                         -5.12066036e-02,  -5.00441380e-02,  -4.87654246e-02,
                         -4.73704673e-02,  -4.61498797e-02,  -4.48711663e-02,
                         -4.35343310e-02,  -4.20812517e-02,  -4.06862907e-02,
                         -3.95819508e-02,  -3.81869897e-02,  -3.68501544e-02,
                         -3.55714448e-02,  -3.42346095e-02,  -3.29558961e-02,
                         -3.16190608e-02,  -3.03403493e-02,  -2.88872663e-02,
                         -2.73179393e-02,  -2.62135956e-02,  -2.46442687e-02,
                         -2.30168160e-02,  -2.17962284e-02,  -2.02850215e-02,
                         -1.89481881e-02,  -1.76113527e-02,  -1.61001459e-02,
                         -1.48795582e-02,  -1.32521065e-02,  -1.18571473e-02,
                         -1.07528055e-02,  -9.06723086e-03,  -7.78851844e-03,
                         -6.45168312e-03,  -4.88235475e-03,  -3.54551966e-03,
                         -2.03431468e-03,  -7.55602552e-04,   6.39356032e-04,
                          2.15056119e-03,   3.42927314e-03,   4.64986172e-03,
                          5.92857366e-03,   7.32353237e-03,   8.83473735e-03,
                          1.01134498e-02,   1.14502851e-02,   1.28452433e-02,
                          1.41820787e-02,   1.56351607e-02,   1.72044896e-02,
                          1.84832010e-02,   1.98200364e-02,   2.12731175e-02,
                          2.26099528e-02,   2.37724185e-02,   2.52255015e-02,
                          2.67367065e-02,   2.81316638e-02,   2.94103771e-02,
                          3.06890886e-02,   3.21421698e-02,   3.34790051e-02,
                          3.48158404e-02,   3.62689234e-02,   3.76057588e-02,
                          3.90007161e-02,   4.04537991e-02,   4.17325087e-02,
                          4.31855917e-02,   4.45805490e-02,   4.59173843e-02,
                          4.73704673e-02,   4.88235503e-02,   5.01603857e-02,
                          5.13809733e-02,   5.27178086e-02,   5.40546440e-02,
                          5.53914793e-02,   5.69608063e-02,   5.84720112e-02,
                          5.96344769e-02,   6.10875599e-02,   6.24243952e-02,
                          6.37031049e-02,   6.51561916e-02,   6.64349049e-02,
                          6.78298622e-02,   6.92248195e-02,   7.04454109e-02,
                          7.16659948e-02,   7.29447082e-02,   7.43396655e-02,
                          7.56765008e-02,   7.71877095e-02,   7.85245448e-02,
                          7.95707628e-02,   8.08494762e-02,   8.20700601e-02,
                          8.32325295e-02,   8.46274868e-02,   8.58480781e-02,
                          8.71267840e-02,   8.82892534e-02,   8.93935934e-02,
                          9.06723067e-02,   9.18928981e-02,   9.32297334e-02,
                          9.43921953e-02,   9.54384133e-02,   9.70077440e-02,
                          9.81120840e-02,   9.91583019e-02,   1.00437015e-01,
                          1.01425111e-01,   1.02645703e-01,   1.03750043e-01,
                          1.04912512e-01,   1.06249347e-01,   1.07179314e-01,
                          1.08341783e-01,   1.09620497e-01,   1.10666715e-01,
                          1.11945428e-01,   1.12991646e-01,   1.14095986e-01,
                          1.15374699e-01,   1.16420917e-01,   1.17641509e-01,
                          1.18629605e-01,   1.19675823e-01,   1.20896406e-01,
                          1.21826380e-01,   1.22988850e-01,   1.24151312e-01,
                          1.25197530e-01,   1.26418114e-01,   1.27115592e-01,
                          1.28103688e-01,   1.29382402e-01,   1.30196139e-01,
                          1.31300479e-01,   1.32404819e-01,   1.33392915e-01,
                          1.34439126e-01,   1.35369107e-01,   1.36473447e-01,
                          1.37403414e-01,   1.38275266e-01,   1.39263362e-01,
                          1.39960840e-01,   1.40890822e-01,   1.42053276e-01,
                          1.42808884e-01,   1.43738851e-01,   1.44610703e-01,
                          1.45540670e-01,   1.46412522e-01,   1.47226244e-01,
                          1.48098096e-01,   1.48737460e-01,   1.49434939e-01,
                          1.50248662e-01,   1.51004270e-01,   1.51934236e-01,
                          1.52631715e-01,   1.53329194e-01,   1.54201046e-01,
                          1.54956654e-01,   1.55770376e-01,   1.56467855e-01,
                          1.57107204e-01,   1.57920927e-01,   1.58734664e-01,
                          1.59490258e-01,   1.60071492e-01,   1.60768971e-01,
                          1.61582693e-01,   1.62280172e-01,   1.62977666e-01,
                          1.63617015e-01,   1.64314494e-01,   1.65011972e-01,
                          1.65535077e-01,   1.66116312e-01,   1.66813791e-01,
                          1.67627513e-01,   1.68441251e-01,   1.68964356e-01,
                          1.69661835e-01,   1.70417443e-01,   1.70940548e-01,
                          1.71521783e-01,   1.72044888e-01,   1.72684252e-01,
                          1.73381731e-01,   1.73962951e-01,   1.74660429e-01,
                          1.75067306e-01,   1.75532281e-01,   1.76229760e-01,
                          1.76636621e-01,   1.77159742e-01,   1.77799091e-01,
                          1.78264081e-01,   1.78845316e-01,   1.79135934e-01,
                          1.79484665e-01,   1.80007771e-01,   1.80356517e-01,
                          1.80995867e-01,   1.81286484e-01,   1.81577101e-01,
                          1.82332709e-01,   1.82565197e-01,   1.82855815e-01,
                          1.83088318e-01,   1.83204561e-01,   1.83785796e-01,
                          1.84076414e-01,   1.84308901e-01,   1.84890136e-01,
                          1.85064510e-01,   1.85355112e-01,   1.85645729e-01,
                          1.85761988e-01,   1.85994476e-01,   1.86110720e-01,
                          1.86343208e-01,   1.86575711e-01,   1.86691955e-01,
                          1.86924443e-01,   1.87156945e-01,   1.87505677e-01,
                          1.87680051e-01,   1.87796295e-01,   1.88028783e-01,
                          1.88086912e-01,   1.88203156e-01,   1.88551903e-01,
                          1.88610017e-01,   1.88668147e-01,   1.89016879e-01,
                          1.89191252e-01,   1.89191252e-01,   1.89307496e-01,
                          1.89598113e-01,   1.89656243e-01,   1.89714357e-01,
                          1.89946860e-01,   1.90004975e-01,   1.90121233e-01,
                          1.90121233e-01,   1.90004975e-01,   1.90237477e-01,
                          1.90295592e-01,   1.90353721e-01,   1.90528095e-01,
                          1.90528095e-01,   1.90528095e-01,   1.90295592e-01,
                          1.90295592e-01,   1.90411851e-01,   1.90353721e-01,
                          1.90353721e-01,   1.90063104e-01,   1.89772487e-01,
                          1.90063104e-01,   1.90063104e-01,   1.89772487e-01,
                          1.89714357e-01,   1.89714357e-01,   1.89714357e-01,
                          1.89539999e-01,   1.89365625e-01,   1.89191252e-01,
                          1.89075008e-01,   1.88958764e-01,   1.88726276e-01,
                          1.88493773e-01,   1.88435659e-01,   1.88261285e-01,
                          1.88203156e-01,   1.87970668e-01,   1.87680051e-01,
                          1.87563807e-01,   1.87389433e-01,   1.87273189e-01,
                          1.87156945e-01,   1.87040687e-01,   1.87040687e-01,
                          1.86866328e-01,   1.86633825e-01,   1.86517581e-01,
                          1.86168849e-01,   1.86052606e-01,   1.85878232e-01,
                          1.85529485e-01,   1.85413241e-01,   1.85238868e-01,
                          1.85006380e-01,   1.84890136e-01,   1.84657633e-01,
                          1.84425145e-01,   1.84308901e-01,   1.84134528e-01,
                          1.83902040e-01,   1.83611423e-01,   1.83495179e-01,
                          1.83378935e-01,   1.83262676e-01,   1.83030188e-01,
                          1.82739571e-01,   1.82681441e-01,   1.82390839e-01,
                          1.81983963e-01,   1.81983963e-01,   1.81693345e-01,
                          1.81402743e-01,   1.81170240e-01,   1.80879623e-01,
                          1.80705264e-01,   1.80356517e-01,   1.80124030e-01,
                          1.79891527e-01,   1.79542795e-01,   1.79368421e-01,
                          1.78961560e-01,   1.78670943e-01,   1.78554699e-01,
                          1.78205952e-01,   1.77915335e-01,   1.77624717e-01,
                          1.77334100e-01,   1.77043498e-01,   1.76694751e-01,
                          1.76578507e-01,   1.76113516e-01,   1.75648525e-01,
                          1.75474167e-01,   1.75009176e-01,   1.74718559e-01,
                          1.74486071e-01,   1.74195454e-01,   1.74021080e-01,
                          1.73614219e-01,   1.73265472e-01,   1.73032984e-01,
                          1.72800496e-01,   1.72567993e-01,   1.72161132e-01,
                          1.71986759e-01,   1.71638027e-01,   1.71114922e-01,
                          1.70940548e-01,   1.70591801e-01,   1.70243070e-01,
                          1.70126826e-01,   1.69778079e-01,   1.69545591e-01,
                          1.69371217e-01,   1.68848112e-01,   1.68557495e-01,
                          1.68441251e-01,   1.68266878e-01,   1.67976260e-01,
                          1.67511269e-01,   1.67162538e-01,   1.66930035e-01,
                          1.66581303e-01,   1.66232556e-01,   1.65941939e-01,
                          1.65767580e-01,   1.65476963e-01,   1.65186346e-01,
                          1.64895728e-01,   1.64663240e-01,   1.64372623e-01,
                          1.63907632e-01,   1.63558885e-01,   1.63152024e-01,
                          1.62745163e-01,   1.62454545e-01,   1.62222058e-01,
                          1.61931440e-01,   1.61524579e-01,   1.61059588e-01,
                          1.60710856e-01,   1.60478354e-01,   1.60187736e-01,
                          1.59780875e-01,   1.59315899e-01,   1.58967152e-01,
                          1.58618420e-01,   1.58385918e-01,   1.58095300e-01,
                          1.57746568e-01,   1.57397822e-01,   1.56990960e-01,
                          1.56584099e-01,   1.56235352e-01,   1.55828491e-01,
                          1.55654132e-01,   1.55305386e-01,   1.54782280e-01,
                          1.54666036e-01,   1.54317290e-01,   1.53794184e-01,
                          1.53561682e-01,   1.53329194e-01,   1.53154820e-01,
                          1.52806088e-01,   1.52282983e-01,   1.51876107e-01,
                          1.51411131e-01,   1.51294887e-01,   1.51062384e-01,
                          1.50423035e-01,   1.50248662e-01,   1.49899915e-01,
                          1.49434939e-01,   1.49260566e-01,   1.48737460e-01,
                          1.48388714e-01,   1.48156226e-01,   1.47807479e-01,
                          1.47574991e-01,   1.47400618e-01,   1.46993756e-01,
                          1.46586895e-01,   1.46238163e-01,   1.45889416e-01,
                          1.45308182e-01,   1.45017564e-01,   1.44610703e-01,
                          1.44087598e-01,   1.43971354e-01,   1.43448234e-01,
                          1.42750755e-01,   1.42518267e-01,   1.41995162e-01,
                          1.41704544e-01,   1.41355798e-01,   1.40774563e-01,
                          1.40425831e-01,   1.39902726e-01,   1.39437735e-01,
                          1.38972744e-01,   1.38391510e-01,   1.38100892e-01,
                          1.37519658e-01,   1.37112796e-01,   1.36764064e-01,
                          1.36066586e-01,   1.35775968e-01,   1.35310978e-01,
                          1.34613499e-01,   1.34148508e-01,   1.33567289e-01,
                          1.33044168e-01,   1.32521063e-01,   1.32056072e-01,
                          1.31765455e-01,   1.31126106e-01,   1.30719244e-01,
                          1.30312383e-01,   1.29614905e-01,   1.29324287e-01,
                          1.29033670e-01,   1.28452435e-01,   1.28045574e-01,
                          1.27522469e-01,   1.27115592e-01,   1.26708731e-01,
                          1.26301870e-01,   1.25720635e-01,   1.25255659e-01,
                          1.24790668e-01,   1.24093190e-01,   1.23686329e-01,
                          1.23221338e-01,   1.22640111e-01,   1.22291364e-01,
                          1.21768259e-01,   1.21303275e-01,   1.20954528e-01,
                          1.20315179e-01,   1.19850188e-01,   1.19210832e-01,
                          1.18629605e-01,   1.18280858e-01,   1.17641509e-01,
                          1.17234640e-01,   1.16711535e-01,   1.16072178e-01,
                          1.15607187e-01,   1.15084082e-01,   1.14502847e-01,
                          1.14037864e-01,   1.13456629e-01,   1.12933517e-01,
                          1.12294167e-01,   1.11712933e-01,   1.11131698e-01,
                          1.10492341e-01,   1.09911107e-01,   1.09329879e-01,
                          1.08806767e-01,   1.08225532e-01,   1.07586183e-01,
                          1.07121192e-01,   1.06481835e-01,   1.05958730e-01,
                          1.05493739e-01,   1.04680017e-01,   1.04331277e-01,
                          1.03982538e-01,   1.03285059e-01,   1.02820069e-01,
                          1.02180712e-01,   1.01657607e-01,   1.01250745e-01,
                          1.00495137e-01,   1.00030154e-01,   9.94489193e-02,
                          9.87514406e-02,   9.83445793e-02,   9.78795961e-02,
                          9.74727273e-02,   9.69496220e-02,   9.61358920e-02,
                          9.57871526e-02,   9.51477960e-02,   9.45665687e-02,
                          9.42759514e-02,   9.35203433e-02,   9.29391161e-02,
                          9.24741253e-02,   9.20091420e-02,   9.16022807e-02,
                          9.09629241e-02,   9.04979333e-02,   8.99167061e-02,
                          8.91610980e-02,   8.88123587e-02,   8.82311314e-02,
                          8.75336528e-02,   8.70686620e-02,   8.64293054e-02,
                          8.57899487e-02,   8.50924700e-02,   8.44531134e-02,
                          8.40462521e-02,   8.34068954e-02,   8.27675387e-02,
                          8.22444335e-02,   8.15469548e-02,   8.09657201e-02,
                          8.02682415e-02,   7.95126408e-02,   7.89895281e-02,
                          7.83501714e-02,   7.75945708e-02,   7.69552141e-02,
                          7.63158575e-02,   7.56183788e-02,   7.50371441e-02,
                          7.44559169e-02,   7.38165602e-02,   7.31190816e-02,
                          7.24797249e-02,   7.20147341e-02,   7.13172555e-02,
                          7.03872815e-02,   6.97479248e-02,   6.92829415e-02,
                          6.86435848e-02,   6.79461062e-02,   6.73067495e-02,
                          6.67255148e-02,   6.62024096e-02,   6.55049309e-02,
                          6.49236962e-02,   6.41680956e-02,   6.35287389e-02,
                          6.31218776e-02,   6.24243952e-02,   6.15525469e-02,
                          6.09713122e-02,   6.05644509e-02,   5.99832200e-02,
                          5.92276156e-02,   5.88788763e-02,   5.82395196e-02,
                          5.73676713e-02,   5.69608063e-02,   5.63795753e-02,
                          5.57402186e-02,   5.51589876e-02,   5.42871356e-02,
                          5.37640266e-02,   5.31246737e-02,   5.25434390e-02,
                          5.21946996e-02,   5.13809733e-02,   5.06253727e-02,
                          5.01022600e-02,   4.92885374e-02,   4.85910550e-02,
                          4.80679460e-02,   4.74867150e-02,   4.67892364e-02,
                          4.59755100e-02,   4.54524010e-02,   4.49292921e-02,
                          4.43480574e-02,   4.36505787e-02,   4.27787304e-02,
                          4.23137434e-02,   4.17906344e-02,   4.10931557e-02,
                          4.03956734e-02,   3.96981947e-02,   3.92332077e-02,
                          3.85938548e-02,   3.78382504e-02,   3.71988937e-02,
                          3.64432931e-02,   3.59201841e-02,   3.54551971e-02,
                          3.47577184e-02,   3.42927314e-02,   3.35371271e-02,
                          3.28396484e-02,   3.23746651e-02,   3.17353085e-02,
                          3.12121976e-02,   3.06309648e-02,   3.01078558e-02,
                          2.96428688e-02,   2.88872663e-02,   2.82479115e-02,
                          2.77829245e-02,   2.72016916e-02,   2.65623368e-02,
                          2.58648563e-02,   2.54579931e-02,   2.48767603e-02,
                          2.41792817e-02,   2.37142947e-02,   2.30749398e-02,
                          2.24937070e-02,   2.17962284e-02,   2.11568717e-02,
                          2.06918847e-02,   2.00525299e-02,   1.94712970e-02,
                          1.89481881e-02,   1.83088314e-02,   1.79019682e-02,
                          1.71463657e-02,   1.63907632e-02,   1.59839001e-02,
                          1.51120508e-02,   1.45308180e-02,   1.40658319e-02,
                          1.33683532e-02,   1.28452433e-02,   1.21477637e-02,
                          1.15084080e-02,   1.09852990e-02,   1.03459423e-02,
                          9.76470951e-03,   9.12535377e-03,   8.48599803e-03,
                          7.84664229e-03,   7.09103933e-03,   6.56792987e-03,
                          5.98669704e-03,   5.23109455e-03,   4.64986172e-03,
                          4.01050597e-03,   3.48739652e-03,   2.90616369e-03,
                          2.20868434e-03,   1.62745162e-03,   1.10434217e-03,
                          4.64986195e-04,  -1.74369823e-04,  -6.97479292e-04,
                         -1.27871206e-03,  -1.91806804e-03,  -2.44117738e-03,
                         -3.08053358e-03,  -3.89425922e-03,  -4.47549205e-03,
                         -5.05672488e-03,  -5.46358759e-03,  -5.92857366e-03,
                         -6.80042291e-03,  -7.26540899e-03,  -7.73039553e-03,
                         -8.42787419e-03,  -9.00910702e-03,  -9.64846369e-03,
                         -1.01134498e-02,  -1.07528055e-02,  -1.13921613e-02,
                         -1.17990244e-02,  -1.23802572e-02,  -1.30777368e-02,
                         -1.36008458e-02,  -1.42402016e-02,  -1.47633115e-02,
                         -1.53445443e-02,  -1.59839001e-02,  -1.66232567e-02,
                         -1.72626115e-02,  -1.77857224e-02,  -1.85413249e-02,
                         -1.93550494e-02,  -1.98200364e-02,  -2.04012692e-02,
                         -2.10406259e-02,  -2.15637349e-02,  -2.22030897e-02,
                         -2.29005702e-02,  -2.35399250e-02,  -2.41211578e-02,
                         -2.48186383e-02,  -2.54579931e-02,  -2.59229802e-02,
                         -2.67367065e-02,  -2.74923090e-02,  -2.77829245e-02,
                         -2.83060335e-02,  -2.91197598e-02,  -2.96428688e-02,
                         -3.03403493e-02,  -3.10959518e-02,  -3.16190608e-02,
                         -3.21421698e-02,  -3.28396484e-02,  -3.34208831e-02,
                         -3.40602398e-02,  -3.50483321e-02,  -3.55714448e-02,
                         -3.59783061e-02,  -3.66757847e-02,  -3.72570194e-02,
                         -3.78382504e-02,  -3.84776071e-02,  -3.91169637e-02,
                         -3.98725644e-02,  -4.03375514e-02,  -4.08606604e-02,
                         -4.14418951e-02,  -4.19650041e-02,  -4.27206047e-02,
                         -4.32437137e-02,  -4.37668264e-02,  -4.44643050e-02,
                         -4.49874140e-02,  -4.55686450e-02,  -4.61498797e-02,
                         -4.66729887e-02,  -4.73704673e-02,  -4.79517020e-02,
                         -4.85910550e-02,  -4.90560420e-02,  -4.98116463e-02,
                         -5.06253727e-02,  -5.09159863e-02,  -5.14972210e-02,
                         -5.21946996e-02,  -5.28340563e-02,  -5.35896569e-02,
                         -5.41708916e-02,  -5.48683703e-02,  -5.55658489e-02,
                         -5.62633276e-02,  -5.71933016e-02,  -5.76582886e-02,
                         -5.82976416e-02,  -5.92276156e-02,  -5.95763549e-02,
                         -6.02157116e-02,  -6.09713122e-02,  -6.16106689e-02,
                         -6.23081475e-02,  -6.28893822e-02,  -6.35287389e-02,
                         -6.40518442e-02,  -6.46912009e-02,  -6.55049309e-02,
                         -6.60861582e-02,  -6.66673928e-02,  -6.72486275e-02,
                         -6.78879842e-02,  -6.85854629e-02,  -6.89923242e-02,
                         -6.98060542e-02,  -7.06197768e-02,  -7.10266382e-02,
                         -7.17822462e-02,  -7.22472295e-02,  -7.28284642e-02,
                         -7.35840648e-02,  -7.41652995e-02,  -7.49209002e-02,
                         -7.53858835e-02,  -7.59089962e-02,  -7.68389702e-02,
                         -7.74783269e-02,  -7.80595541e-02,  -7.85826668e-02,
                         -7.91057721e-02,  -7.99195021e-02,  -8.04426074e-02,
                         -8.11400861e-02,  -8.18375722e-02,  -8.22444335e-02,
                         -8.28837901e-02,  -8.34650174e-02,  -8.40462521e-02,
                         -8.46856087e-02,  -8.52668434e-02,  -8.59062001e-02,
                         -8.64293054e-02,  -8.70105401e-02,  -8.75917748e-02,
                         -8.80567580e-02,  -8.87542367e-02,  -8.93935934e-02,
                         -8.98585841e-02,  -9.05560628e-02,  -9.12535414e-02,
                         -9.19510201e-02,  -9.25903767e-02,  -9.31134820e-02,
                         -9.38109607e-02,  -9.42759514e-02,  -9.48571786e-02,
                         -9.55546647e-02,  -9.61358920e-02,  -9.67171267e-02,
                         -9.72402394e-02,  -9.78214666e-02,  -9.84608233e-02,
                         -9.88095626e-02,  -9.95651707e-02,  -1.00320771e-01,
                         -1.00727633e-01,  -1.01366989e-01,  -1.01831973e-01,
                         -1.02355085e-01,  -1.02994442e-01,  -1.03459425e-01,
                         -1.04040660e-01,  -1.04621895e-01,  -1.05086878e-01,
                         -1.05551861e-01,  -1.06191218e-01,  -1.06830575e-01,
                         -1.07237436e-01,  -1.07818671e-01,  -1.08516149e-01,
                         -1.08864889e-01,  -1.09446123e-01,  -1.10027358e-01,
                         -1.10550463e-01,  -1.11131698e-01,  -1.11538559e-01,
                         -1.12177916e-01,  -1.12642907e-01,  -1.12875395e-01,
                         -1.13340385e-01,  -1.13747247e-01,  -1.14328481e-01,
                         -1.14793465e-01,  -1.15084082e-01,  -1.15723439e-01,
                         -1.16188422e-01,  -1.16479039e-01,  -1.17002152e-01,
                         -1.17467135e-01,  -1.17932118e-01,  -1.18397109e-01,
                         -1.18745849e-01,  -1.19152710e-01,  -1.19733945e-01,
                         -1.20373301e-01,  -1.20605789e-01,  -1.20896406e-01,
                         -1.21477641e-01,  -1.21768259e-01,  -1.22233242e-01,
                         -1.22640111e-01,  -1.22872598e-01,  -1.23279460e-01,
                         -1.23802572e-01,  -1.24209434e-01,  -1.24441929e-01,
                         -1.24674425e-01,  -1.25313774e-01,  -1.25662521e-01,
                         -1.25836894e-01,  -1.26127496e-01,  -1.26592487e-01,
                         -1.27057478e-01,  -1.27289966e-01,  -1.27406210e-01,
                         -1.27754956e-01,  -1.27987444e-01,  -1.28278062e-01,
                         -1.28510565e-01,  -1.28801167e-01,  -1.29091784e-01,
                         -1.29266158e-01,  -1.29440531e-01,  -1.29731148e-01,
                         -1.29963636e-01,  -1.30254254e-01,  -1.30312383e-01,
                         -1.30544871e-01,  -1.30835488e-01,  -1.30893618e-01,
                         -1.31242350e-01,  -1.31358594e-01,  -1.31474838e-01,
                         -1.31823584e-01,  -1.31997958e-01,  -1.32172316e-01,
                         -1.32230446e-01,  -1.32288575e-01,  -1.32579193e-01,
                         -1.32579193e-01,  -1.32695436e-01,  -1.32811680e-01,
                         -1.32869810e-01,  -1.33218542e-01,  -1.33218542e-01,
                         -1.33276671e-01,  -1.33625403e-01,  -1.33509159e-01,
                         -1.33683532e-01,  -1.33741647e-01,  -1.33741647e-01,
                         -1.33974150e-01,  -1.33857906e-01,  -1.33857906e-01,
                         -1.34090394e-01,  -1.34206638e-01,  -1.34148508e-01,
                         -1.34032264e-01,  -1.34322882e-01,  -1.34439126e-01,
                         -1.34322882e-01,  -1.34439126e-01,  -1.34322882e-01,
                         -1.34381011e-01,  -1.34497255e-01,  -1.34264767e-01,
                         -1.34322882e-01,  -1.34264767e-01,  -1.34322882e-01,
                         -1.34439126e-01,  -1.34090394e-01,  -1.34032264e-01,
                         -1.34090394e-01,  -1.33974150e-01,  -1.33974150e-01,
                         -1.33683532e-01,  -1.33683532e-01,  -1.33683532e-01,
                         -1.33509159e-01,  -1.33451030e-01,  -1.33334786e-01,
                         -1.33218542e-01,  -1.33160412e-01,  -1.32986054e-01,
                         -1.32869810e-01,  -1.32637307e-01,  -1.32521063e-01,
                         -1.32462934e-01,  -1.32114202e-01,  -1.32056072e-01,
                         -1.31939828e-01,  -1.31649211e-01,  -1.31591097e-01,
                         -1.31242350e-01,  -1.31067976e-01,  -1.31067976e-01,
                         -1.30777359e-01,  -1.30603001e-01,  -1.30312383e-01,
                         -1.30079880e-01,  -1.29905522e-01,  -1.29614905e-01,
                         -1.29382402e-01,  -1.28975540e-01,  -1.28743052e-01,
                         -1.28684923e-01,  -1.28394306e-01,  -1.28219947e-01,
                         -1.27929330e-01,  -1.27638713e-01,  -1.27522469e-01,
                         -1.27173722e-01,  -1.27115592e-01,  -1.26941234e-01,
                         -1.26650617e-01,  -1.26476243e-01,  -1.26011252e-01,
                         -1.25720635e-01,  -1.25604391e-01,  -1.25255659e-01,
                         -1.25139400e-01,  -1.24906912e-01,  -1.24616295e-01,
                         -1.24383807e-01,  -1.24035068e-01,  -1.23860694e-01,
                         -1.23628199e-01,  -1.23279460e-01,  -1.23046972e-01,
                         -1.22814476e-01,  -1.22640111e-01,  -1.22291364e-01,
                         -1.22000754e-01,  -1.21884502e-01,  -1.21535763e-01,
                         -1.21245146e-01,  -1.21012658e-01,  -1.20663919e-01,
                         -1.20489545e-01,  -1.20024562e-01,  -1.19675823e-01,
                         -1.19733945e-01,  -1.19385205e-01,  -1.19036466e-01,
                         -1.18862092e-01,  -1.18455231e-01,  -1.18338987e-01,
                         -1.17990248e-01,  -1.17525257e-01,  -1.17583379e-01,
                         -1.17350891e-01,  -1.16944022e-01,  -1.16653413e-01,
                         -1.16479039e-01,  -1.16362795e-01,  -1.15839683e-01,
                         -1.15549065e-01,  -1.15432821e-01,  -1.15025960e-01,
                         -1.14909708e-01,  -1.14793465e-01,  -1.14444725e-01,
                         -1.14212230e-01,  -1.14095986e-01,  -1.13921613e-01,
                         -1.13631003e-01,  -1.13340385e-01,  -1.13107890e-01,
                         -1.12933517e-01,  -1.12759151e-01,  -1.12584777e-01,
                         -1.12352289e-01,  -1.12061672e-01,  -1.11945428e-01,
                         -1.11829177e-01,  -1.11654811e-01,  -1.11422315e-01,
                         -1.11189820e-01,  -1.11015454e-01,  -1.10782959e-01,
                         -1.10608593e-01,  -1.10608593e-01,  -1.10317975e-01,
                         -1.10085480e-01,  -1.10027358e-01,  -1.09620497e-01,
                         -1.09504245e-01,  -1.09562367e-01,  -1.09271757e-01,
                         -1.09097384e-01,  -1.08864889e-01,  -1.08690523e-01,
                         -1.08574271e-01,  -1.08167410e-01,  -1.08051166e-01,
                         -1.08051166e-01,  -1.07818671e-01,  -1.07644305e-01,
                         -1.07528053e-01,  -1.07469931e-01,  -1.07121192e-01,
                         -1.07004948e-01,  -1.07063070e-01,  -1.06714331e-01,
                         -1.06772453e-01,  -1.06772453e-01,  -1.06307469e-01,
                         -1.06307469e-01,  -1.06249347e-01,  -1.06016852e-01,
                         -1.05958730e-01,  -1.05784357e-01,  -1.05784357e-01,
                         -1.05668113e-01,  -1.05435617e-01,  -1.05609991e-01,
                         -1.05551861e-01,  -1.05319373e-01,  -1.05145000e-01,
                         -1.04970634e-01,  -1.04912512e-01,  -1.04796261e-01,
                         -1.04796261e-01,  -1.04796261e-01,  -1.04563765e-01,
                         -1.04621895e-01,  -1.04563765e-01,  -1.04331277e-01,
                         -1.04447521e-01,  -1.04331277e-01,  -1.04215026e-01,
                         -1.04156904e-01,  -1.04156904e-01,  -1.04273155e-01,
                         -1.04098782e-01,  -1.03982538e-01,  -1.04098782e-01,
                         -1.03982538e-01,  -1.03866287e-01,  -1.03750043e-01,
                         -1.03808165e-01,  -1.03750043e-01,  -1.03575677e-01,
                         -1.03575677e-01,  -1.03459425e-01,  -1.03459425e-01,
                         -1.03633799e-01,  -1.03459425e-01,  -1.03343181e-01,
                         -1.03459425e-01,  -1.03459425e-01,  -1.03226930e-01,
                         -1.03052564e-01,  -1.03226930e-01,  -1.03226930e-01,
                         -1.02994442e-01,  -1.03110686e-01,  -1.02994442e-01,
                         -1.02936320e-01,  -1.02994442e-01,  -1.02994442e-01,
                         -1.03110686e-01,  -1.03110686e-01,  -1.03052564e-01,
                         -1.03052564e-01,  -1.02936320e-01,  -1.03110686e-01,
                         -1.03226930e-01,  -1.03110686e-01,  -1.03052564e-01,
                         -1.02878191e-01,  -1.02761947e-01,  -1.02761947e-01,
                         -1.02820069e-01,  -1.02820069e-01,  -1.02645703e-01,
                         -1.02761947e-01,  -1.02878191e-01,  -1.02703825e-01,
                         -1.02645703e-01,  -1.02529451e-01,  -1.02529451e-01,
                         -1.02645703e-01,  -1.02471329e-01,  -1.02296963e-01,
                         -1.02296963e-01,  -1.02238841e-01,  -1.02296963e-01,
                         -1.02296963e-01,  -1.02355085e-01,  -1.02238841e-01,
                         -1.02006346e-01,  -1.02180712e-01,  -1.02064468e-01,
                         -1.01715729e-01,  -1.01773851e-01,  -1.01773851e-01,
                         -1.01599485e-01,  -1.01599485e-01,  -1.01483233e-01,
                         -1.01366989e-01,  -1.01366989e-01,  -1.01192616e-01,
                         -1.01076372e-01,  -1.01192616e-01,  -1.01076372e-01,
                         -1.00843877e-01,  -1.00843877e-01,  -1.00727633e-01,
                         -1.00553267e-01,  -1.00553267e-01,  -1.00437015e-01,
                         -1.00262649e-01,  -1.00088276e-01,  -9.99139100e-02,
                         -9.98557806e-02,  -9.97976586e-02,  -9.96814147e-02,
                         -9.95070413e-02,  -9.93326753e-02,  -9.91583019e-02,
                         -9.91001800e-02,  -9.89839360e-02,  -9.87514406e-02,
                         -9.85770747e-02,  -9.84608233e-02,  -9.82283354e-02,
                         -9.80539620e-02,  -9.79377180e-02,  -9.76471007e-02,
                         -9.75889787e-02,  -9.75308493e-02,  -9.74146053e-02,
                         -9.71821100e-02,  -9.68915001e-02,  -9.68915001e-02,
                         -9.68333706e-02,  -9.65427607e-02,  -9.64265093e-02,
                         -9.61358920e-02,  -9.60777700e-02,  -9.60777700e-02,
                         -9.57290307e-02,  -9.55546647e-02,  -9.54965353e-02,
                         -9.53221694e-02,  -9.52059254e-02,  -9.50315520e-02,
                         -9.49153081e-02,  -9.45665687e-02,  -9.43921953e-02,
                         -9.42178294e-02,  -9.36947167e-02,  -9.36365947e-02,
                         -9.35784727e-02,  -9.31716040e-02,  -9.31716040e-02,
                         -9.29972380e-02,  -9.26484987e-02,  -9.24160033e-02,
                         -9.21835080e-02,  -9.20091420e-02,  -9.17766467e-02,
                         -9.16022807e-02,  -9.14860293e-02,  -9.11954194e-02,
                         -9.09629241e-02,  -9.08466727e-02,  -9.06723067e-02,
                         -9.02654454e-02,  -8.98585841e-02,  -8.98004547e-02,
                         -8.95098373e-02,  -8.92192274e-02,  -8.90448540e-02,
                         -8.87542367e-02,  -8.85798708e-02,  -8.82892534e-02,
                         -8.79986361e-02,  -8.78823921e-02,  -8.75336528e-02,
                         -8.72430354e-02,  -8.70105401e-02,  -8.66036788e-02,
                         -8.63711834e-02,  -8.61968175e-02,  -8.60224441e-02,
                         -8.58480781e-02,  -8.55574608e-02,  -8.51505920e-02,
                         -8.48018527e-02,  -8.46274868e-02,  -8.44531134e-02,
                         -8.39300081e-02,  -8.36393908e-02,  -8.35812688e-02,
                         -8.32906514e-02,  -8.28837901e-02,  -8.24769214e-02,
                         -8.23606774e-02,  -8.21281821e-02,  -8.18375722e-02,
                         -8.16050768e-02,  -8.12563375e-02,  -8.09075981e-02,
                         -8.06751028e-02,  -8.04426074e-02,  -8.02682415e-02,
                         -7.98032507e-02,  -7.95126408e-02,  -7.94545114e-02,
                         -7.90476501e-02,  -7.88151622e-02,  -7.86407888e-02,
                         -7.82339275e-02,  -7.80595541e-02,  -7.77108148e-02,
                         -7.73620754e-02,  -7.73039535e-02,  -7.68970922e-02,
                         -7.64321014e-02,  -7.62577355e-02,  -7.60833621e-02,
                         -7.57346228e-02,  -7.52696395e-02,  -7.51533955e-02,
                         -7.49790221e-02,  -7.45721608e-02,  -7.42234215e-02,
                         -7.39909261e-02,  -7.35840648e-02,  -7.29447082e-02,
                         -7.27122128e-02,  -7.25378469e-02,  -7.20147341e-02,
                         -7.17822462e-02,  -7.15497509e-02,  -7.09685162e-02,
                         -7.07360208e-02,  -7.05035329e-02,  -7.00385422e-02,
                         -6.96898028e-02,  -6.94573149e-02,  -6.90504462e-02,
                         -6.87017068e-02,  -6.84692189e-02,  -6.81204796e-02,
                         -6.77717403e-02,  -6.75973669e-02,  -6.72486275e-02,
                         -6.68417662e-02,  -6.66673928e-02,  -6.62605315e-02,
                         -6.59117922e-02,  -6.57374188e-02,  -6.55049309e-02,
                         -6.51561916e-02,  -6.47493303e-02,  -6.45749569e-02,
                         -6.44005835e-02,  -6.40518442e-02,  -6.38774782e-02,
                         -6.35287389e-02,  -6.31218776e-02,  -6.28893822e-02,
                         -6.24825172e-02,  -6.22500256e-02,  -6.20175339e-02,
                         -6.14944249e-02,  -6.12619296e-02,  -6.10294379e-02,
                         -6.06225729e-02,  -6.03900813e-02,  -6.01575896e-02,
                         -5.98669723e-02,  -5.95182329e-02,  -5.91694936e-02,
                         -5.89369982e-02,  -5.87045066e-02,  -5.85301369e-02,
                         -5.80651499e-02,  -5.77745326e-02,  -5.74839190e-02,
                         -5.70770539e-02,  -5.70189320e-02,  -5.66701926e-02,
                         -5.62052056e-02,  -5.62633276e-02,  -5.60889579e-02,
                         -5.57402186e-02,  -5.53914793e-02,  -5.50427400e-02,
                         -5.49264923e-02,  -5.44033833e-02,  -5.40546440e-02,
                         -5.38802743e-02,  -5.35315350e-02,  -5.33571653e-02,
                         -5.30084260e-02,  -5.28340563e-02,  -5.27178086e-02,
                         -5.21946996e-02,  -5.19040823e-02,  -5.18459603e-02,
                         -5.17297126e-02,  -5.13809733e-02,  -5.09159863e-02,
                         -5.09741120e-02,  -5.06253727e-02,  -5.01603857e-02,
                         -5.01603857e-02,  -4.96372767e-02,  -4.92885374e-02,
                         -4.94047813e-02,  -4.90560420e-02,  -4.87073027e-02,
                         -4.85329330e-02,  -4.82423156e-02,  -4.79517020e-02,
                         -4.76610847e-02,  -4.76610847e-02,  -4.73704673e-02,
                         -4.70798500e-02,  -4.69636060e-02,  -4.67311107e-02,
                         -4.66729887e-02,  -4.63823713e-02,  -4.59173843e-02,
                         -4.59173843e-02,  -4.59173843e-02,  -4.55686450e-02,
                         -4.53942753e-02,  -4.52199057e-02,  -4.50455360e-02,
                         -4.47549187e-02,  -4.45224270e-02,  -4.43480574e-02,
                         -4.41736877e-02,  -4.40574400e-02,  -4.38830703e-02,
                         -4.37668264e-02,  -4.37087007e-02,  -4.34762090e-02,
                         -4.33018394e-02,  -4.30693440e-02,  -4.29531001e-02,
                         -4.28368524e-02,  -4.24881130e-02,  -4.23137434e-02,
                         -4.20231260e-02,  -4.17906344e-02,  -4.19068784e-02,
                         -4.17325087e-02,  -4.15581390e-02,  -4.13256474e-02,
                         -4.12093997e-02,  -4.12093997e-02,  -4.09187861e-02,
                         -4.08025384e-02,  -4.07444164e-02,  -4.05700430e-02,
                         -4.05700430e-02,  -4.03956734e-02,  -4.01631817e-02,
                         -4.02213037e-02,  -4.00469340e-02,  -3.99306901e-02,
                         -3.97563204e-02,  -3.95819508e-02,  -3.96400727e-02,
                         -3.92913334e-02,  -3.91750857e-02,  -3.92332077e-02,
                         -3.88844684e-02,  -3.89425941e-02,  -3.90007161e-02,
                         -3.86519767e-02,  -3.85938548e-02,  -3.85938548e-02,
                         -3.85357291e-02,  -3.85357291e-02,  -3.83613594e-02,
                         -3.81869897e-02,  -3.82451154e-02,  -3.81869897e-02,
                         -3.79544981e-02,  -3.78963761e-02,  -3.80707458e-02,
                         -3.80126201e-02,  -3.79544981e-02,  -3.79544981e-02,
                         -3.79544981e-02,  -3.79544981e-02,  -3.76638807e-02,
                         -3.75476331e-02,  -3.76057588e-02,  -3.76638807e-02,
                         -3.78963761e-02,  -3.76638807e-02,  -3.76057588e-02,
                         -3.78382504e-02,  -3.76057588e-02,  -3.76638807e-02,
                         -3.77801284e-02,  -3.74895111e-02,  -3.74895111e-02,
                         -3.74313891e-02,  -3.73732634e-02,  -3.74895111e-02,
                         -3.74313891e-02,  -3.76057588e-02,  -3.75476331e-02,
                         -3.73151414e-02,  -3.74895111e-02,  -3.76057588e-02,
                         -3.76057588e-02,  -3.75476331e-02,  -3.75476331e-02,
                         -3.76057588e-02,  -3.74895111e-02,  -3.75476331e-02,
                         -3.77801284e-02,  -3.78382504e-02,  -3.79544981e-02,
                         -3.80126201e-02,  -3.80126201e-02,  -3.78963761e-02,
                         -3.79544981e-02,  -3.81869897e-02,  -3.80707458e-02,
                         -3.81288677e-02,  -3.83032374e-02,  -3.83613594e-02,
                         -3.83613594e-02,  -3.84194851e-02,  -3.85357291e-02,
                         -3.87100987e-02,  -3.85938548e-02,  -3.87682244e-02,
                         -3.89425941e-02,  -3.90007161e-02,  -3.92332077e-02,
                         -3.92913334e-02,  -3.94075811e-02,  -3.93494554e-02,
                         -3.91750857e-02,  -3.94075811e-02,  -3.94075811e-02,
                         -3.94075811e-02,  -3.96981947e-02,  -3.98144424e-02,
                         -3.98725644e-02,  -4.01631817e-02,  -4.03375514e-02,
                         -4.02213037e-02,  -4.02794294e-02,  -4.05119210e-02,
                         -4.05119210e-02,  -4.06862907e-02,  -4.08025384e-02,
                         -4.08025384e-02,  -4.09769081e-02,  -4.09187861e-02,
                         -4.10350300e-02,  -4.12675254e-02,  -4.12675254e-02,
                         -4.14418951e-02,  -4.15000170e-02,  -4.15581390e-02,
                         -4.17906344e-02,  -4.17906344e-02,  -4.20231260e-02,
                         -4.20812517e-02,  -4.20812517e-02,  -4.24881130e-02,
                         -4.26043607e-02,  -4.27206047e-02,  -4.29531001e-02,
                         -4.28949744e-02,  -4.30693440e-02,  -4.30693440e-02,
                         -4.31274697e-02,  -4.33018394e-02,  -4.34180871e-02,
                         -4.35924567e-02,  -4.36505787e-02,  -4.37668264e-02,
                         -4.39411961e-02,  -4.39993180e-02,  -4.41736877e-02,
                         -4.42899354e-02,  -4.44061793e-02,  -4.46967967e-02,
                         -4.46967967e-02,  -4.48711663e-02,  -4.50455360e-02,
                         -4.49874140e-02,  -4.53361534e-02,  -4.53942753e-02,
                         -4.54524010e-02,  -4.58011404e-02,  -4.55686450e-02,
                         -4.56848927e-02,  -4.60336320e-02,  -4.61498797e-02,
                         -4.63242494e-02,  -4.62661274e-02,  -4.65567410e-02,
                         -4.67892364e-02,  -4.66729887e-02,  -4.69636060e-02,
                         -4.71379757e-02,  -4.71379757e-02,  -4.74285893e-02,
                         -4.75448370e-02,  -4.76610847e-02,  -4.77773324e-02,
                         -4.77192067e-02,  -4.79517020e-02,  -4.81260717e-02,
                         -4.82423156e-02,  -4.83004414e-02,  -4.84166853e-02,
                         -4.85329330e-02,  -4.85910550e-02,  -4.89397980e-02,
                         -4.91141677e-02,  -4.90560420e-02,  -4.91141677e-02,
                         -4.92304116e-02,  -4.94629070e-02,  -4.95791510e-02,
                         -4.94047813e-02,  -4.96372767e-02,  -4.98116463e-02,
                         -4.97535206e-02,  -4.98697683e-02,  -4.98697683e-02,
                         -4.99860160e-02,  -5.01022600e-02,  -5.01022600e-02,
                         -5.02185076e-02,  -5.02766334e-02,  -5.05091250e-02,
                         -5.07416166e-02,  -5.08578643e-02,  -5.10322340e-02,
                         -5.10322340e-02,  -5.11484817e-02,  -5.12647256e-02,
                         -5.12066036e-02,  -5.13809733e-02,  -5.15553430e-02,
                         -5.16715907e-02,  -5.17878383e-02,  -5.17878383e-02,
                         -5.19622080e-02,  -5.20784520e-02,  -5.20784520e-02,
                         -5.23109473e-02,  -5.24853170e-02,  -5.24853170e-02,
                         -5.25434390e-02,  -5.26015610e-02,  -5.27178086e-02,
                         -5.27178086e-02,  -5.27759306e-02,  -5.28921783e-02,
                         -5.30084260e-02,  -5.30084260e-02,  -5.31246737e-02,
                         -5.32990433e-02,  -5.31827956e-02,  -5.31246737e-02,
                         -5.34152873e-02,  -5.34152873e-02,  -5.34152873e-02,
                         -5.34734130e-02,  -5.35315350e-02,  -5.38802743e-02,
                         -5.39965220e-02,  -5.39383963e-02,  -5.41708916e-02,
                         -5.41127659e-02,  -5.41127659e-02,  -5.42871356e-02,
                         -5.41708916e-02,  -5.41708916e-02,  -5.42290136e-02,
                         -5.42871356e-02,  -5.43452613e-02,  -5.42290136e-02,
                         -5.41708916e-02,  -5.40546440e-02,  -5.41127659e-02,
                         -5.41127659e-02,  -5.39965220e-02,  -5.41127659e-02,
                         -5.41127659e-02,  -5.41127659e-02,  -5.40546440e-02,
                         -5.38802743e-02,  -5.39383963e-02,  -5.39965220e-02,
                         -5.39965220e-02,  -5.39383963e-02,  -5.38802743e-02,
                         -5.39383963e-02,  -5.38802743e-02,  -5.38802743e-02,
                         -5.38221523e-02,  -5.37059046e-02,  -5.37640266e-02,
                         -5.36477827e-02,  -5.35315350e-02,  -5.35896569e-02,
                         -5.35315350e-02,  -5.36477827e-02,  -5.35315350e-02,
                         -5.33571653e-02,  -5.32990433e-02,  -5.31827956e-02,
                         -5.33571653e-02,  -5.35315350e-02,  -5.31827956e-02,
                         -5.30665480e-02,  -5.30665480e-02,  -5.29503003e-02,
                         -5.28340563e-02,  -5.26015610e-02,  -5.26596867e-02,
                         -5.27178086e-02,  -5.24853170e-02,  -5.24853170e-02,
                         -5.23109473e-02,  -5.21365777e-02,  -5.21946996e-02,
                         -5.20784520e-02,  -5.19040823e-02,  -5.17878383e-02,
                         -5.15553430e-02,  -5.13809733e-02,  -5.12647256e-02,
                         -5.12066036e-02,  -5.11484817e-02,  -5.09741120e-02,
                         -5.07997423e-02,  -5.06834947e-02,  -5.07416166e-02,
                         -5.05091250e-02,  -5.02766334e-02,  -5.03347553e-02,
                         -4.99860160e-02,  -4.98116463e-02,  -4.99860160e-02,
                         -4.97535206e-02,  -4.96953987e-02,  -4.95210290e-02,
                         -4.92304116e-02,  -4.92304116e-02,  -4.89979200e-02,
                         -4.89397980e-02,  -4.88235503e-02,  -4.85329330e-02,
                         -4.85329330e-02,  -4.83004414e-02,  -4.80679460e-02,
                         -4.80679460e-02,  -4.78354543e-02,  -4.77192067e-02,
                         -4.76029627e-02,  -4.74285893e-02,  -4.73704673e-02,
                         -4.73123454e-02,  -4.71960977e-02,  -4.69054803e-02,
                         -4.67311107e-02,  -4.67311107e-02,  -4.66148667e-02,
                         -4.66148667e-02,  -4.64404970e-02,  -4.62080017e-02,
                         -4.62080017e-02,  -4.58592623e-02,  -4.55105230e-02,
                         -4.55686450e-02,  -4.54524010e-02,  -4.54524010e-02,
                         -4.53942753e-02,  -4.49874140e-02,  -4.48711663e-02,
                         -4.46967967e-02,  -4.44061793e-02,  -4.42899354e-02,
                         -4.41736877e-02,  -4.39993180e-02,  -4.38830703e-02,
                         -4.39993180e-02,  -4.37087007e-02,  -4.31855917e-02,
                         -4.31855917e-02,  -4.32437137e-02,  -4.30693440e-02,
                         -4.28368524e-02,  -4.24881130e-02,  -4.22556214e-02,
                         -4.21393737e-02,  -4.21393737e-02,  -4.19650041e-02,
                         -4.17906344e-02,  -4.17325087e-02,  -4.15000170e-02,
                         -4.13837694e-02,  -4.12093997e-02,  -4.08606604e-02,
                         -4.08606604e-02,  -4.08025384e-02,  -4.06281687e-02,
                         -4.05119210e-02,  -4.02794294e-02,  -4.02213037e-02,
                         -3.99888121e-02,  -3.98144424e-02,  -3.96981947e-02,
                         -3.93494554e-02,  -3.93494554e-02,  -3.92913334e-02,
                         -3.88844684e-02,  -3.88844684e-02,  -3.87100987e-02,
                         -3.85938548e-02,  -3.84776071e-02,  -3.81288677e-02,
                         -3.80707458e-02,  -3.78963761e-02,  -3.77801284e-02,
                         -3.76638807e-02,  -3.73732634e-02,  -3.74313891e-02,
                         -3.73732634e-02,  -3.70826498e-02,  -3.69664021e-02,
                         -3.67339104e-02,  -3.65014151e-02,  -3.62107977e-02,
                         -3.60364281e-02,  -3.60945538e-02,  -3.58620584e-02,
                         -3.56876887e-02,  -3.56876887e-02,  -3.53389494e-02,
                         -3.51064578e-02,  -3.50483321e-02,  -3.48158404e-02,
                         -3.46995927e-02,  -3.45833488e-02,  -3.42927314e-02,
                         -3.41764838e-02,  -3.40021141e-02,  -3.37696224e-02,
                         -3.35952528e-02,  -3.33627574e-02,  -3.32465135e-02,
                         -3.31302658e-02,  -3.29558961e-02,  -3.27815264e-02,
                         -3.24909091e-02,  -3.22584175e-02,  -3.22002918e-02,
                         -3.20259221e-02,  -3.17934304e-02,  -3.16190608e-02,
                         -3.14446911e-02,  -3.12703215e-02,  -3.11540738e-02,
                         -3.09215821e-02,  -3.08053344e-02,  -3.04565951e-02,
                         -3.02241016e-02,  -3.03403493e-02,  -3.01659796e-02,
                         -2.99916100e-02,  -2.98172385e-02,  -2.95847468e-02,
                         -2.94684991e-02,  -2.90616360e-02,  -2.89453901e-02,
                         -2.91197598e-02,  -2.86547747e-02,  -2.84804031e-02,
                         -2.84804031e-02,  -2.82479115e-02,  -2.82479115e-02,
                         -2.79572941e-02,  -2.77248006e-02,  -2.77829245e-02,
                         -2.73179393e-02,  -2.72016916e-02,  -2.72016916e-02,
                         -2.69110762e-02,  -2.68529523e-02,  -2.65623368e-02,
                         -2.63298433e-02,  -2.60973498e-02,  -2.58648563e-02,
                         -2.58648563e-02,  -2.55742408e-02,  -2.54579931e-02,
                         -2.53998712e-02,  -2.51092538e-02,  -2.49930080e-02,
                         -2.47605145e-02,  -2.45280210e-02,  -2.44117752e-02,
                         -2.42374055e-02,  -2.41792817e-02,  -2.38886662e-02,
                         -2.36561727e-02,  -2.35399250e-02,  -2.32493095e-02,
                         -2.31330637e-02,  -2.28424463e-02,  -2.26680767e-02,
                         -2.27843225e-02,  -2.24937070e-02,  -2.23774593e-02,
                         -2.23193374e-02,  -2.21449677e-02,  -2.20868438e-02,
                         -2.19705980e-02,  -2.19124742e-02,  -2.17381045e-02,
                         -2.13893652e-02,  -2.13312414e-02,  -2.11568717e-02,
                         -2.10987478e-02,  -2.12149955e-02,  -2.10406259e-02,
                         -2.09825020e-02,  -2.08081324e-02,  -2.07500085e-02,
                         -2.08662543e-02,  -2.06337627e-02,  -2.05756389e-02,
                         -2.06337627e-02,  -2.05175150e-02,  -2.05175150e-02,
                         -2.04012692e-02,  -2.04012692e-02,  -2.04012692e-02,
                         -2.02850215e-02,  -2.03431454e-02,  -2.02268995e-02,
                         -2.02268995e-02,  -2.02850215e-02,  -1.99944060e-02,
                         -1.99944060e-02,  -1.99944060e-02,  -1.98781602e-02,
                         -1.99362822e-02,  -1.97619125e-02,  -1.98781602e-02,
                         -1.99362822e-02,  -1.97037905e-02,  -1.98781602e-02,
                         -1.99944060e-02,  -1.98200364e-02,  -1.97619125e-02,
                         -1.97619125e-02,  -1.98200364e-02,  -1.97037905e-02,
                         -1.97037905e-02,  -1.98781602e-02,  -1.97037905e-02,
                         -1.96456667e-02,  -1.97619125e-02,  -1.97619125e-02,
                         -1.98200364e-02,  -1.98200364e-02,  -1.99362822e-02,
                         -1.99362822e-02,  -2.00525299e-02,  -2.01106519e-02,
                         -1.99944060e-02,  -2.00525299e-02,  -2.01687757e-02,
                         -2.00525299e-02,  -2.02268995e-02,  -2.02850215e-02,
                         -2.03431454e-02,  -2.04012692e-02,  -2.03431454e-02,
                         -2.04593930e-02,  -2.05175150e-02,  -2.04593930e-02,
                         -2.05175150e-02,  -2.05756389e-02,  -2.07500085e-02,
                         -2.08081324e-02,  -2.06918847e-02,  -2.08662543e-02,
                         -2.09825020e-02,  -2.10987478e-02,  -2.11568717e-02,
                         -2.12731175e-02,  -2.12731175e-02,  -2.13312414e-02,
                         -2.15637349e-02,  -2.15637349e-02,  -2.15056110e-02,
                         -2.17962284e-02,  -2.16799807e-02,  -2.17381045e-02,
                         -2.19705980e-02,  -2.20287200e-02,  -2.22612135e-02,
                         -2.24355832e-02,  -2.24355832e-02,  -2.24937070e-02,
                         -2.24355832e-02,  -2.24937070e-02,  -2.25518309e-02,
                         -2.24937070e-02,  -2.26680767e-02,  -2.26099528e-02,
                         -2.26680767e-02,  -2.29586922e-02,  -2.27843225e-02,
                         -2.28424463e-02,  -2.30168160e-02,  -2.30168160e-02,
                         -2.29586922e-02,  -2.28424463e-02,  -2.31330637e-02,
                         -2.30749398e-02,  -2.28424463e-02,  -2.30749398e-02,
                         -2.31330637e-02,  -2.30168160e-02,  -2.30168160e-02,
                         -2.30168160e-02,  -2.30749398e-02,  -2.30749398e-02,
                         -2.32493095e-02,  -2.33074334e-02,  -2.31911857e-02,
                         -2.31911857e-02,  -2.31330637e-02,  -2.33074334e-02,
                         -2.31911857e-02,  -2.29586922e-02,  -2.31911857e-02,
                         -2.30749398e-02,  -2.30749398e-02,  -2.32493095e-02,
                         -2.30168160e-02,  -2.31911857e-02,  -2.32493095e-02,
                         -2.30168160e-02,  -2.31911857e-02,  -2.31911857e-02,
                         -2.31911857e-02,  -2.31911857e-02,  -2.30749398e-02,
                         -2.30168160e-02,  -2.29586922e-02,  -2.30749398e-02,
                         -2.29586922e-02,  -2.27843225e-02,  -2.29586922e-02,
                         -2.27262005e-02,  -2.26099528e-02,  -2.27262005e-02,
                         -2.24355832e-02,  -2.24355832e-02,  -2.23193374e-02,
                         -2.21449677e-02,  -2.19705980e-02,  -2.18543503e-02,
                         -2.19705980e-02,  -2.17381045e-02,  -2.15637349e-02,
                         -2.15637349e-02,  -2.12149955e-02,  -2.10406259e-02,
                         -2.09243782e-02,  -2.06918847e-02,  -2.05175150e-02,
                         -2.03431454e-02,  -2.03431454e-02,  -2.02268995e-02,
                         -1.98781602e-02,  -1.97619125e-02,  -1.94131732e-02,
                         -1.91806797e-02,  -1.91225577e-02,  -1.88319404e-02,
                         -1.87156945e-02,  -1.84832010e-02,  -1.80763379e-02,
                         -1.79600921e-02,  -1.76694747e-02,  -1.74369812e-02,
                         -1.73788592e-02,  -1.71463657e-02,  -1.67976264e-02,
                         -1.65651329e-02,  -1.62163936e-02,  -1.59839001e-02,
                         -1.57514066e-02,  -1.53445443e-02,  -1.51120508e-02,
                         -1.49376811e-02,  -1.45889418e-02,  -1.43564483e-02,
                         -1.40658319e-02,  -1.36589697e-02,  -1.35427229e-02],
                         dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri12",
    rate = 41000,
    data = numpy.array([  1.08563311e-01,   9.46022749e-01,  -5.03652573e-01,
                         -7.36201286e-01,   8.10470760e-01,   3.97727281e-01,
                         -9.76663947e-01,   9.53733735e-03,   9.72605526e-01,
                         -4.15381491e-01,  -7.99512982e-01,   7.48782456e-01,
                          4.86810058e-01,  -9.52110410e-01,  -8.98944810e-02,
                          9.89448071e-01,  -3.23254883e-01,  -8.54707778e-01,
                          6.79586053e-01,   5.71022749e-01,  -9.18019474e-01,
                         -1.88108772e-01,   9.96347427e-01,  -2.27678567e-01,
                         -9.01379883e-01,   6.03693187e-01,   6.49350643e-01,
                         -8.74797106e-01,  -2.84496754e-01,   9.93303597e-01,
                         -1.30073056e-01,  -9.39326286e-01,   5.21712661e-01,
                          7.21387982e-01,  -8.23051929e-01,  -3.78246754e-01,
                          9.80519474e-01,  -3.12500000e-02,  -9.67735410e-01,
                          4.34862018e-01,   7.86120117e-01,  -7.62987018e-01,
                         -4.67938304e-01,   9.58198071e-01,   6.79788962e-02,
                         -9.86607134e-01,   3.43547076e-01,   8.43141258e-01,
                         -6.95413947e-01,  -5.53165555e-01,   9.26136374e-01,
                          1.66599020e-01,  -9.95738626e-01,   2.48782471e-01,
                          8.91842544e-01,  -6.21144474e-01,  -6.32913947e-01,
                          8.84943187e-01,   2.63392866e-01,  -9.95129883e-01,
                          1.51582792e-01,   9.31615233e-01,  -5.40584445e-01,
                         -7.06168830e-01,   8.35024357e-01,   3.57548714e-01,
                         -9.84577894e-01,   5.29626608e-02,   9.62256491e-01,
                         -4.54748362e-01,  -7.72524357e-01,   7.76988626e-01,
                          4.48254883e-01,  -9.64285731e-01,  -4.60633114e-02,
                          9.83157456e-01,  -3.64448041e-01,  -8.31371725e-01,
                          7.11241901e-01,   5.34496725e-01,  -9.34456170e-01,
                         -1.44683436e-01,   9.94521081e-01,  -2.70495117e-01,
                         -8.81899357e-01,   6.38392866e-01,   6.15259767e-01,
                         -8.95292222e-01,  -2.41883114e-01,   9.96144474e-01,
                         -1.73904225e-01,  -9.23701286e-01,   5.59253275e-01,
                          6.90137982e-01,  -8.47402573e-01,  -3.36647719e-01,
                          9.87824678e-01,  -7.56899342e-02,  -9.56371725e-01,
                          4.74634737e-01,   7.58116901e-01,  -7.91193187e-01,
                         -4.28165585e-01,   9.69561696e-01,   2.33360399e-02,
                         -9.79504883e-01,   3.85349035e-01,   8.18587661e-01,
                         -7.27069795e-01,  -5.15422106e-01,   9.41964269e-01,
                          1.22159094e-01,  -9.93100643e-01,   2.92207778e-01,
                          8.71144474e-01,  -6.55844152e-01,  -5.97605526e-01,
                          9.05032456e-01,   2.19764605e-01,  -9.96956170e-01,
                          1.96225643e-01,   9.14772749e-01,  -5.78125000e-01,
                         -6.73904240e-01,   8.59172106e-01,   3.15137982e-01,
                         -9.90868509e-01,   9.82142836e-02,   9.49675322e-01,
                         -4.94724035e-01,  -7.43506491e-01,   8.04788947e-01,
                          4.07467544e-01,  -9.75040555e-01,  -6.08766219e-04,
                          9.75040555e-01,  -4.06452924e-01,  -8.05600643e-01,
                          7.42491901e-01,   4.95535702e-01,  -9.49472427e-01,
                         -9.96347368e-02,   9.90868509e-01,  -3.14123362e-01,
                         -8.59983742e-01,   6.72889590e-01,   5.78936696e-01,
                         -9.14569795e-01,  -1.97443187e-01,   9.96956170e-01,
                         -2.18750000e-01,  -9.05844152e-01,   5.96590936e-01,
                          6.56655848e-01,  -8.70738626e-01,  -2.93425322e-01,
                          9.93100643e-01,  -1.21144481e-01,  -9.42775965e-01,
                          5.14407456e-01,   7.27881491e-01,  -8.18384767e-01,
                         -3.86566550e-01,   9.79504883e-01,  -2.23214291e-02,
                         -9.70373392e-01,   4.26948041e-01,   7.91801929e-01,
                         -7.57711053e-01,  -4.75852281e-01,   9.56168830e-01,
                          7.67045468e-02,  -9.88433421e-01,   3.35633129e-01,
                          8.48011374e-01,  -6.89732134e-01,  -5.60470760e-01,
                          9.23295438e-01,   1.74918830e-01,  -9.96550322e-01,
                          2.40665585e-01,   8.95900965e-01,  -6.14853919e-01,
                         -6.39610410e-01,   8.81493509e-01,   2.71509737e-01,
                         -9.95129883e-01,   1.43465906e-01,   9.34862018e-01,
                         -5.33887982e-01,  -7.12459445e-01,   8.30965936e-01,
                          3.65462661e-01,  -9.83563304e-01,   4.48457785e-02,
                          9.64691579e-01,  -4.47646111e-01,  -7.78003275e-01,
                          7.72118509e-01,   4.55762982e-01,  -9.62459445e-01,
                         -5.41801937e-02,   9.84983742e-01,  -3.56939942e-01,
                         -8.36241901e-01,   7.05762982e-01,   5.41396081e-01,
                         -9.31818187e-01,  -1.52800322e-01,   9.95332778e-01,
                         -2.62784094e-01,  -8.85957778e-01,   6.32305205e-01,
                          6.21956170e-01,  -8.92045438e-01,  -2.50000000e-01,
                          9.96144474e-01,  -1.65990263e-01,  -9.26948071e-01,
                          5.52556813e-01,   6.96225643e-01,  -8.43344152e-01,
                         -3.44561696e-01,   9.86810088e-01,  -6.75730556e-02,
                         -9.58806813e-01,   4.67329532e-01,   7.63595760e-01,
                         -7.86323071e-01,  -4.35673714e-01,   9.67938304e-01,
                          3.16558443e-02,  -9.81331170e-01,   3.77637982e-01,
                          8.23457778e-01,  -7.21590936e-01,  -5.22727251e-01,
                          9.39326286e-01,   1.30478889e-01,  -9.94115233e-01,
                          2.84090906e-01,   8.75202894e-01,  -6.49553597e-01,
                         -6.04504883e-01,   9.01582778e-01,   2.27881491e-01,
                         -9.96956170e-01,   1.87702924e-01,   9.18222427e-01,
                         -5.71225643e-01,  -6.80194795e-01,   8.54707778e-01,
                          3.23254883e-01,  -9.89853919e-01,   8.94886330e-02,
                          9.52313304e-01,  -4.87215906e-01,  -7.49188304e-01,
                          7.99512982e-01,   4.15381491e-01,  -9.73214269e-01,
                         -9.53733735e-03,   9.76866901e-01,  -3.98336053e-01,
                         -8.10876608e-01,   7.36607134e-01,   5.03246725e-01,
                         -9.46834445e-01,  -1.08360387e-01,   9.91883099e-01,
                         -3.05600643e-01,  -8.64448071e-01,   6.66193187e-01,
                          5.86241901e-01,  -9.11120117e-01,  -2.06371754e-01,
                          9.96956170e-01,  -2.09821433e-01,  -9.09496725e-01,
                          5.89285731e-01,   6.63352251e-01,  -8.66274357e-01,
                         -3.02150965e-01,   9.92086053e-01,  -1.12215906e-01,
                         -9.45616901e-01,   5.06493509e-01,   7.33969152e-01,
                         -8.13108742e-01,  -3.95089298e-01,   9.77678597e-01,
                         -1.31899351e-02,  -9.72402573e-01,   4.18831170e-01,
                          7.97280848e-01,  -7.51826286e-01,  -4.83969152e-01,
                          9.53530848e-01,   8.56331140e-02,  -9.89650965e-01,
                          3.26907456e-01,   8.52881491e-01,  -6.83238626e-01,
                         -5.67978919e-01,   9.20048714e-01,   1.83847398e-01,
                         -9.96956170e-01,   2.31939942e-01,   8.99959445e-01,
                         -6.07954562e-01,  -6.46509767e-01,   8.77435088e-01,
                          2.80032456e-01,  -9.94521081e-01,   1.34943187e-01,
                          9.38108742e-01,  -5.26785731e-01,  -7.18547106e-01,
                          8.26298714e-01,   3.73579532e-01,  -9.82345760e-01,
                          3.59172076e-02,   9.67126608e-01,  -4.39529210e-01,
                         -7.84090936e-01,   7.66233742e-01,   4.64285702e-01,
                         -9.60024357e-01,  -6.41233772e-02,   9.86404240e-01,
                         -3.47605526e-01,  -8.41720760e-01,   6.98457778e-01,
                          5.50121725e-01,  -9.28165555e-01,  -1.63149357e-01,
                          9.95941579e-01,  -2.52435058e-01,  -8.90827894e-01,
                          6.23782456e-01,   6.30478919e-01,  -8.86972427e-01,
                         -2.60754883e-01,   9.95535731e-01,  -1.54829547e-01,
                         -9.31209445e-01,   5.43019474e-01,   7.04342544e-01,
                         -8.37053597e-01,  -3.55519474e-01,   9.85186696e-01,
                         -5.58035709e-02,  -9.62053597e-01,   4.56777602e-01,
                          7.71306813e-01,  -7.78814912e-01,  -4.46631491e-01,
                          9.64894474e-01,   4.38311696e-02,  -9.83563304e-01,
                          3.66071433e-01,   8.30560088e-01,  -7.12865233e-01,
                         -5.33482134e-01,   9.35064912e-01,   1.43060058e-01,
                         -9.94926929e-01,   2.71712661e-01,   8.81493509e-01,
                         -6.39610410e-01,  -6.14853919e-01,   8.95900965e-01,
                          2.40868509e-01,  -9.96550322e-01,   1.74715906e-01,
                          9.23498392e-01,  -5.60267866e-01,  -6.90137982e-01,
                          8.47808421e-01,   3.36241871e-01,  -9.88230526e-01,
                          7.58928582e-02,   9.56371725e-01,  -4.75040585e-01,
                         -7.58522749e-01,   7.91193187e-01,   4.28165585e-01,
                         -9.70170438e-01,  -2.37418823e-02,   9.79707778e-01,
                         -3.85349035e-01,  -8.19399357e-01,   7.26866901e-01,
                          5.15827894e-01,  -9.42370117e-01,  -1.22970782e-01,
                          9.93303597e-01,  -2.91599035e-01,  -8.71956170e-01,
                          6.55032456e-01,   5.98417222e-01,  -9.05032456e-01,
                         -2.21185058e-01,   9.96956170e-01,  -1.95008114e-01,
                         -9.15990233e-01,   5.76907456e-01,   6.75121725e-01,
                         -8.58766258e-01,  -3.17167222e-01,   9.90665555e-01,
                         -9.63879898e-02,  -9.50892866e-01,   4.92897719e-01,
                          7.44926929e-01,  -8.03774357e-01,  -4.09902602e-01,
                          9.74634767e-01,   3.04383109e-03,  -9.76258099e-01,
                          4.03814942e-01,   8.07426929e-01,  -7.40868509e-01,
                         -4.98579532e-01,   9.48660731e-01,   1.02678575e-01,
                         -9.91680205e-01,   3.10876638e-01,   8.61810088e-01,
                         -6.70657456e-01,  -5.82386374e-01,   9.13352251e-01,
                          2.01095775e-01,  -9.97564912e-01,   2.14691564e-01,
                          9.07670438e-01,  -5.93547106e-01,  -6.60308421e-01,
                          8.68709445e-01,   2.97686696e-01,  -9.93303597e-01,
                          1.16477273e-01,   9.44399357e-01,  -5.10551929e-01,
                         -7.31737018e-01,   8.15543830e-01,   3.91233772e-01,
                         -9.79099035e-01,   1.68425329e-02,   9.71793830e-01,
                         -4.22483772e-01,  -7.95860410e-01,   7.54261374e-01,
                          4.80925322e-01,  -9.55154240e-01,  -8.27922076e-02,
                          9.89245117e-01,  -3.30154210e-01,  -8.51866901e-01,
                          6.85267866e-01,   5.65746725e-01,  -9.21469152e-01,
                         -1.81615263e-01,   9.96956170e-01,  -2.34577924e-01,
                         -8.99553597e-01,   6.09375000e-01,   6.45089269e-01,
                         -8.78855526e-01,  -2.78814942e-01,   9.94724035e-01,
                         -1.36566564e-01,  -9.38108742e-01,   5.27597427e-01,
                          7.17735410e-01,  -8.27313304e-01,  -3.72970790e-01,
                          9.82548714e-01,  -3.71347405e-02,  -9.67329562e-01,
                          4.40340906e-01,   7.83482134e-01,  -7.67451286e-01,
                         -4.63676959e-01,   9.60430205e-01,   6.27029240e-02,
                         -9.87012982e-01,   3.48620117e-01,   8.41112018e-01,
                         -6.99878275e-01,  -5.49512982e-01,   9.28774357e-01,
                          1.61931813e-01,  -9.96550322e-01,   2.53652602e-01,
                          8.90625000e-01,  -6.25405848e-01,  -6.30073071e-01,
                          8.87784064e-01,   2.59334415e-01,  -9.96347427e-01,
                          1.55844152e-01,   9.31006491e-01,  -5.44642866e-01,
                         -7.04139590e-01,   8.38068187e-01,   3.54301959e-01,
                         -9.85998392e-01,   5.66152595e-02,   9.62053597e-01,
                         -4.58198041e-01,  -7.71306813e-01,   7.79626608e-01,
                          4.45819795e-01,  -9.65909064e-01,  -4.32224013e-02,
                          9.83563304e-01,  -3.67491871e-01,  -8.30762982e-01,
                          7.13676929e-01,   5.32670438e-01,  -9.36079562e-01,
                         -1.42451301e-01,   9.95332778e-01,  -2.72930205e-01,
                         -8.81696403e-01,   6.40422106e-01,   6.14245117e-01,
                         -8.96915555e-01,  -2.40462661e-01,   9.96956170e-01,
                         -1.75730526e-01,  -9.23904240e-01,   5.60876608e-01,
                          6.89732134e-01,  -8.48823071e-01,  -3.36038947e-01,
                          9.88636374e-01,  -7.67045468e-02,  -9.56980526e-01,
                          4.75649357e-01,   7.58319795e-01,  -7.92207778e-01,
                         -4.28165585e-01,   9.70576286e-01,   2.29301956e-02,
                         -9.80316579e-01,   3.85551959e-01,   8.19196403e-01,
                         -7.27678597e-01,  -5.16030848e-01,   9.42573071e-01,
                          1.22362010e-01,  -9.93912339e-01,   2.91801959e-01,
                          8.71956170e-01,  -6.55844152e-01,  -5.98620117e-01,
                          9.05235410e-01,   2.20779225e-01,  -9.97767866e-01,
                          1.95211038e-01,   9.15990233e-01,  -5.77516258e-01,
                         -6.75324678e-01,   8.58969152e-01,   3.16761374e-01,
                         -9.91477251e-01,   9.65909064e-02,   9.50892866e-01,
                         -4.93506491e-01,  -7.45332778e-01,   8.03977251e-01,
                          4.09496754e-01,  -9.75243509e-01,  -3.04383109e-03,
                          9.76258099e-01,  -4.04423714e-01,  -8.07832778e-01,
                          7.41071403e-01,   4.98173714e-01,  -9.49269474e-01,
                         -1.02475651e-01,   9.91883099e-01,  -3.11485380e-01,
                         -8.62215936e-01,   6.70860410e-01,   5.81980526e-01,
                         -9.13961053e-01,  -2.01095775e-01,   9.97564912e-01,
                         -2.15503246e-01,  -9.07873392e-01,   5.93952894e-01,
                          6.59902573e-01,  -8.69521081e-01,  -2.97483772e-01,
                          9.93303597e-01,  -1.17288962e-01,  -9.44805205e-01,
                          5.10957778e-01,   7.31128275e-01,  -8.16355526e-01,
                         -3.90827924e-01,   9.79301929e-01,  -1.78571437e-02,
                         -9.71996725e-01,   4.23092544e-01,   7.95251608e-01,
                         -7.55275965e-01,  -4.80519474e-01,   9.55357134e-01,
                          8.15746784e-02,  -9.89650965e-01,   3.30965906e-01,
                          8.51258099e-01,  -6.86485410e-01,  -5.65137982e-01,
                          9.22077894e-01,   1.80194810e-01,  -9.97564912e-01,
                          2.35592529e-01,   8.98944795e-01,  -6.10998392e-01,
                         -6.44277573e-01,   8.79464269e-01,   2.76988626e-01,
                         -9.95535731e-01,   1.37987018e-01,   9.37702894e-01,
                         -5.29423714e-01,  -7.17126608e-01,   8.28327894e-01,
                          3.71144474e-01,  -9.83563304e-01,   3.87581177e-02,
                          9.66923714e-01,  -4.42573041e-01,  -7.82670438e-01,
                          7.68871725e-01,   4.61444795e-01,  -9.61850643e-01,
                         -6.06737025e-02,   9.86810088e-01,  -3.51461053e-01,
                         -8.40503275e-01,   7.01704562e-01,   5.47280848e-01,
                         -9.30600643e-01,  -1.59496754e-01,   9.96753275e-01,
                         -2.56696433e-01,  -8.90016258e-01,   6.27840936e-01,
                          6.27637982e-01,  -8.90016258e-01,  -2.56696433e-01,
                          9.96753275e-01,  -1.59496754e-01,  -9.30600643e-01,
                          5.47483742e-01,   7.01704562e-01,  -8.40706170e-01,
                         -3.51258129e-01,   9.87012982e-01,  -6.06737025e-02,
                         -9.62053597e-01,   4.61850643e-01,   7.69074678e-01,
                         -7.83076286e-01,  -4.42573041e-01,   9.67532456e-01,
                          3.85551937e-02,  -9.83969152e-01,   3.71550322e-01,
                          8.28530848e-01,  -7.17735410e-01,  -5.29423714e-01,
                          9.38311696e-01,   1.37581170e-01,  -9.96144474e-01,
                          2.77597398e-01,   8.79870117e-01,  -6.45089269e-01,
                         -6.10998392e-01,   8.99959445e-01,   2.35186681e-01,
                         -9.98376608e-01,   1.81006491e-01,   9.22483742e-01,
                         -5.66355526e-01,  -6.86485410e-01,   8.52475643e-01,
                          3.30560058e-01,  -9.90868509e-01,   8.25892836e-02,
                          9.55965936e-01,  -4.81737018e-01,  -7.55275965e-01,
                          7.96672106e-01,   4.22686696e-01,  -9.73417222e-01,
                         -1.68425329e-02,   9.80113626e-01,  -3.92451286e-01,
                         -8.16558421e-01,   7.32954562e-01,   5.10551929e-01,
                         -9.46428597e-01,  -1.15868509e-01,   9.94521081e-01,
                         -2.99310058e-01,  -8.69926929e-01,   6.61931813e-01,
                          5.93344152e-01,  -9.09902573e-01,  -2.13879868e-01,
                          9.98985410e-01,  -2.03125000e-01,  -9.14569795e-01,
                          5.84415555e-01,   6.70251608e-01,  -8.64448071e-01,
                         -3.09862018e-01,   9.93506491e-01,  -1.04910716e-01,
                         -9.50081170e-01,   5.01014590e-01,   7.40665555e-01,
                         -8.10470760e-01,  -4.02800322e-01,   9.78287339e-01,
                         -5.68181835e-03,  -9.76258099e-01,   4.12743509e-01,
                          8.03774357e-01,  -7.48579562e-01,  -4.91680205e-01,
                          9.53530848e-01,   9.35470760e-02,  -9.92897749e-01,
                          3.20413947e-01,   8.58766258e-01,  -6.78977251e-01,
                         -5.75689912e-01,   9.19034064e-01,   1.91964284e-01,
                         -9.99594152e-01,   2.24634737e-01,   9.05438304e-01,
                         -6.02881491e-01,  -6.54220760e-01,   8.75608742e-01,
                          2.88555205e-01,  -9.96347427e-01,   1.26826301e-01,
                          9.43181813e-01,  -5.20698071e-01,  -7.26055205e-01,
                          8.23457778e-01,   3.82305205e-01,  -9.83157456e-01,
                          2.75974032e-02,   9.71387982e-01,  -4.33238626e-01,
                         -7.90787339e-01,   7.62987018e-01,   4.72199678e-01,
                         -9.60430205e-01,  -7.18344152e-02,   9.90056813e-01,
                         -3.41517866e-01,  -8.47808421e-01,   6.95008099e-01,
                          5.57426929e-01,  -9.27962661e-01,  -1.70657471e-01,
                          9.98985410e-01,  -2.46550322e-01,  -8.96306813e-01,
                          6.20129883e-01,   6.37175322e-01,  -8.86363626e-01,
                         -2.67654210e-01,   9.97767866e-01,  -1.48944810e-01,
                         -9.35876608e-01,   5.39163947e-01,   7.10633099e-01,
                         -8.36038947e-01,  -3.62012982e-01,   9.86810088e-01,
                         -4.99188304e-02,  -9.66314912e-01,   4.52719152e-01,
                          7.76988626e-01,  -7.77394474e-01,  -4.52922076e-01,
                          9.66112018e-01,   4.97159101e-02,  -9.87012982e-01,
                          3.61810058e-01,   8.35633099e-01,  -7.10836053e-01,
                         -5.39366901e-01,   9.35673714e-01,   1.48741886e-01,
                         -9.97970760e-01,   2.67451286e-01,   8.86160731e-01,
                         -6.37378275e-01,  -6.20332778e-01,   8.96103919e-01,
                          2.46347398e-01,  -9.98985410e-01,   1.70251623e-01,
                          9.27759767e-01,  -5.57629883e-01,  -6.95211053e-01,
                          8.47402573e-01,   3.41517866e-01,  -9.90259767e-01,
                          7.14285746e-02,   9.60024357e-01,  -4.72199678e-01,
                         -7.63189912e-01,   7.90381491e-01,   4.33238626e-01,
                         -9.71387982e-01,  -2.82061696e-02,   9.82954562e-01,
                         -3.82102281e-01,  -8.23660731e-01,   7.25446403e-01,
                          5.20495117e-01,  -9.42978919e-01,  -1.27435058e-01,
                          9.95941579e-01,  -2.88352281e-01,  -8.75811696e-01,
                          6.53409064e-01,   6.02881491e-01,  -9.05235410e-01,
                         -2.25446433e-01,   9.98985410e-01,  -1.91558436e-01,
                         -9.19237018e-01,   5.74878275e-01,   6.79180205e-01,
                         -8.58563304e-01,  -3.21225643e-01,   9.92288947e-01,
                         -9.29383114e-02,  -9.53530848e-01,   4.90665585e-01,
                          7.48579562e-01,  -8.03165555e-01,  -4.13758129e-01,
                          9.75649357e-01,   6.49350649e-03,  -9.78490233e-01,
                          4.01379883e-01,   8.10673714e-01,  -7.39853919e-01,
                         -5.02029240e-01,   9.49269474e-01,   1.05925322e-01,
                         -9.93506491e-01,   3.08441550e-01,   8.64650965e-01,
                         -6.69237018e-01,  -5.85430205e-01,   9.13352251e-01,
                          2.04139605e-01,  -9.98782456e-01,   2.12256491e-01,
                          9.09902573e-01,  -5.92126608e-01,  -6.63149357e-01,
                          8.68506491e-01,   3.00527602e-01,  -9.94115233e-01,
                          1.14042208e-01,   9.46225643e-01,  -5.08928597e-01,
                         -7.33969152e-01,   8.14935088e-01,   3.93668830e-01,
                         -9.79504883e-01,   1.46103892e-02,   9.73214269e-01,
                         -4.20860380e-01,  -7.97686696e-01,   7.53449678e-01,
                          4.83157456e-01,  -9.55154240e-01,  -8.48214254e-02,
                          9.90259767e-01,  -3.28530848e-01,  -8.53287339e-01,
                          6.84456170e-01,   5.67573071e-01,  -9.21469152e-01,
                         -1.83441564e-01,   9.97767866e-01,  -2.32954547e-01,
                         -9.00568187e-01,   6.08563304e-01,   6.46306813e-01,
                         -8.78449678e-01,  -2.80235380e-01,   9.95129883e-01,
                         -1.35146111e-01,  -9.38920438e-01,   5.26582778e-01,
                          7.18750000e-01,  -8.26907456e-01,  -3.74188304e-01,
                          9.82751608e-01,  -3.61201316e-02,  -9.67735410e-01,
                          4.39529210e-01,   7.84090936e-01,  -7.67045438e-01,
                         -4.64285702e-01,   9.60430205e-01,   6.35146126e-02,
                         -9.87215936e-01,   3.48011374e-01,   8.41517866e-01,
                         -6.99472427e-01,  -5.49918830e-01,   9.28774357e-01,
                          1.62337661e-01,  -9.96550322e-01,   2.53246754e-01,
                          8.90625000e-01,  -6.25000000e-01,  -6.30073071e-01,
                          8.87784064e-01,   2.59334415e-01,  -9.96144474e-01,
                          1.55844152e-01,   9.30803597e-01,  -5.44439912e-01,
                         -7.03733742e-01,   8.38068187e-01,   3.54099035e-01,
                         -9.85998392e-01,   5.70211038e-02,   9.61850643e-01,
                         -4.58400965e-01,  -7.70698071e-01,   7.79829562e-01,
                          4.45008129e-01,  -9.65909064e-01,  -4.24107127e-02,
                          9.83360410e-01,  -3.67897719e-01,  -8.29951286e-01,
                          7.14082778e-01,   5.31655848e-01,  -9.36282456e-01,
                         -1.41436681e-01,   9.94926929e-01,  -2.73741871e-01,
                         -8.80884767e-01,   6.41030848e-01,   6.13027573e-01,
                         -8.97118509e-01,  -2.39042208e-01,   9.96753275e-01,
                         -1.76948056e-01,  -9.23092544e-01,   5.61891258e-01,
                          6.88311696e-01,  -8.49431813e-01,  -3.34212661e-01,
                          9.88636374e-01,  -7.83279240e-02,  -9.56168830e-01,
                          4.76866871e-01,   7.56899357e-01,  -7.93019474e-01,
                         -4.26136374e-01,   9.70779240e-01,   2.11038962e-02,
                         -9.79707778e-01,   3.87378246e-01,   8.17775965e-01,
                         -7.28896081e-01,  -5.14001608e-01,   9.43181813e-01,
                          1.20332792e-01,  -9.93506491e-01,   2.93831170e-01,
                          8.70535731e-01,  -6.57467544e-01,  -5.96590936e-01,
                          9.06250000e-01,   2.18344152e-01,  -9.97564912e-01,
                          1.97443187e-01,   9.14772749e-01,  -5.79342544e-01,
                         -6.73295438e-01,   8.60186696e-01,   3.14123362e-01,
                         -9.91477251e-01,   9.92288962e-02,   9.49878275e-01,
                         -4.95738626e-01,  -7.43303597e-01,   8.05600643e-01,
                          4.06858772e-01,  -9.75649357e-01,  -2.02922078e-04,
                          9.75649357e-01,  -4.07061696e-01,  -8.06006491e-01,
                          7.43100643e-01,   4.95738626e-01,  -9.50284064e-01,
                         -9.96347368e-02,   9.91477251e-01,  -3.14326286e-01,
                         -8.60592544e-01,   6.73092544e-01,   5.79545438e-01,
                         -9.15178597e-01,  -1.98051944e-01,   9.97767866e-01,
                         -2.18344152e-01,  -9.06655848e-01,   5.96387982e-01,
                          6.57670438e-01,  -8.71144474e-01,  -2.94439942e-01,
                          9.93912339e-01,  -1.20332792e-01,  -9.43790555e-01,
                          5.13798714e-01,   7.29099035e-01,  -8.18384767e-01,
                         -3.87987018e-01,   9.80113626e-01,  -2.09009741e-02,
                         -9.71590936e-01,   4.26136374e-01,   7.93628275e-01,
                         -7.57508099e-01,  -4.77678567e-01,   9.56777573e-01,
                          7.85308406e-02,  -9.89650965e-01,   3.34009737e-01,
                          8.50040555e-01,  -6.88920438e-01,  -5.62702894e-01,
                          9.23701286e-01,   1.77353889e-01,  -9.97970760e-01,
                          2.38636360e-01,   8.98133099e-01,  -6.13636374e-01,
                         -6.42248392e-01,   8.81493509e-01,   2.74350643e-01,
                         -9.96144474e-01,   1.41030848e-01,   9.37094152e-01,
                         -5.32061696e-01,  -7.15300322e-01,   8.30560088e-01,
                          3.68709415e-01,  -9.84577894e-01,   4.18019481e-02,
                          9.66923714e-01,  -4.45413947e-01,  -7.81250000e-01,
                          7.71103919e-01,   4.59415585e-01,  -9.63068187e-01,
                         -5.78327924e-02,   9.87012982e-01,  -3.54099035e-01,
                         -8.39488626e-01,   7.04139590e-01,   5.45454562e-01,
                         -9.32021081e-01,  -1.56858772e-01,   9.97362018e-01,
                         -2.59334415e-01,  -8.89407456e-01,   6.30073071e-01,
                          6.26217544e-01,  -8.91639590e-01,  -2.54464298e-01,
                          9.97767866e-01,  -1.61931813e-01,  -9.30397749e-01,
                          5.49715936e-01,   7.00689912e-01,  -8.42532456e-01,
                         -3.49431813e-01,   9.88027573e-01,  -6.27029240e-02,
                         -9.62053597e-01,   4.63879883e-01,   7.68262982e-01,
                         -7.84699678e-01,  -4.41152602e-01,   9.68750000e-01,
                          3.69318165e-02,  -9.84172106e-01,   3.73376638e-01,
                          8.28125000e-01,  -7.19155848e-01,  -5.28206170e-01,
                          9.39529240e-01,   1.36160716e-01,  -9.96550322e-01,
                          2.79220790e-01,   8.79667222e-01,  -6.46509767e-01,
                         -6.10186696e-01,   9.00974035e-01,   2.34172076e-01,
                         -9.98985410e-01,   1.82224020e-01,   9.22686696e-01,
                         -5.67370117e-01,  -6.86079562e-01,   8.53490233e-01,
                          3.29748362e-01,  -9.91477251e-01,   8.34009722e-02,
                          9.56371725e-01,  -4.82548714e-01,  -7.55073071e-01,
                          7.97483742e-01,   4.22077924e-01,  -9.74025965e-01,
                         -1.62337665e-02,   9.80519474e-01,  -3.93060058e-01,
                         -8.16558421e-01,   7.33563304e-01,   5.10349035e-01,
                         -9.46834445e-01,  -1.15665585e-01,   9.94724035e-01,
                         -2.99512982e-01,  -8.69926929e-01,   6.62337661e-01,
                          5.93344152e-01,  -9.10105526e-01,  -2.13879868e-01,
                          9.99188304e-01,  -2.02922076e-01,  -9.14569795e-01,
                          5.84415555e-01,   6.70454562e-01,  -8.64448071e-01,
                         -3.10064942e-01,   9.93709445e-01,  -1.04504868e-01,
                         -9.50081170e-01,   5.00811696e-01,   7.40868509e-01,
                         -8.10064912e-01,  -4.03206170e-01,   9.78287339e-01,
                         -5.07305190e-03,  -9.76258099e-01,   4.12134737e-01,
                          8.03977251e-01,  -7.47767866e-01,  -4.92288947e-01,
                          9.53125000e-01,   9.45616886e-02,  -9.92694795e-01,
                          3.19399357e-01,   8.59172106e-01,  -6.77962661e-01,
                         -5.76298714e-01,   9.18425322e-01,   1.93181813e-01,
                         -9.99188304e-01,   2.23417208e-01,   9.05641258e-01,
                         -6.01461053e-01,  -6.54829562e-01,   8.74594152e-01,
                          2.89772719e-01,  -9.95738626e-01,   1.25405848e-01,
                          9.42978919e-01,  -5.19074678e-01,  -7.26663947e-01,
                          8.22037339e-01,   3.83522719e-01,  -9.82345760e-01,
                          2.59740259e-02,   9.71185088e-01,  -4.31412339e-01,
                         -7.91193187e-01,   7.61363626e-01,   4.73417222e-01,
                         -9.59009767e-01,  -7.34577924e-02,   9.89448071e-01,
                         -3.39488626e-01,  -8.48011374e-01,   6.93181813e-01,
                          5.58441579e-01,  -9.26339269e-01,  -1.72280848e-01,
                          9.97970760e-01,  -2.44318187e-01,  -8.96306813e-01,
                          6.17897749e-01,   6.38189912e-01,  -8.84537339e-01,
                         -2.69277602e-01,   9.96753275e-01,  -1.46712661e-01,
                         -9.35673714e-01,   5.36728919e-01,   7.11241901e-01,
                         -8.33806813e-01,  -3.63636374e-01,   9.85389590e-01,
                         -4.74837646e-02,  -9.65706170e-01,   4.50284094e-01,
                          7.77394474e-01,  -7.74959445e-01,  -4.54342544e-01,
                          9.64285731e-01,   5.19480519e-02,  -9.86201286e-01,
                          3.59172076e-01,   8.35836053e-01,  -7.08198071e-01,
                         -5.40584445e-01,   9.33644474e-01,   1.50974020e-01,
                         -9.96753275e-01,   2.64610380e-01,   8.85957778e-01,
                         -6.34537339e-01,  -6.21347427e-01,   8.93668830e-01,
                          2.48376623e-01,  -9.97564912e-01,   1.67613640e-01,
                          9.27353919e-01,  -5.54788947e-01,  -6.96022749e-01,
                          8.44967544e-01,   3.43344152e-01,  -9.88433421e-01,
                          6.87905848e-02,   9.59415555e-01,  -4.69358772e-01,
                         -7.63798714e-01,   7.87743509e-01,   4.34862018e-01,
                         -9.69561696e-01,  -3.06412335e-02,   9.81939912e-01,
                         -3.79261374e-01,  -8.23863626e-01,   7.22808421e-01,
                          5.22118509e-01,  -9.40949678e-01,  -1.29870132e-01,
                          9.94724035e-01,  -2.85308450e-01,  -8.75811696e-01,
                          6.50568187e-01,   6.04099035e-01,  -9.03003275e-01,
                         -2.27678567e-01,   9.97564912e-01,  -1.88717529e-01,
                         -9.19034064e-01,   5.71834445e-01,   6.80194795e-01,
                         -8.55925322e-01,  -3.23254883e-01,   9.90665555e-01,
                         -9.00974050e-02,  -9.53125000e-01,   4.87621754e-01,
                          7.49391258e-01,  -8.00527573e-01,  -4.15787339e-01,
                          9.73823071e-01,   9.33441520e-03,  -9.77881491e-01,
                          3.98336053e-01,   8.11282456e-01,  -7.37012982e-01,
                         -5.04058421e-01,   9.47240233e-01,   1.08766235e-01,
                         -9.92694795e-01,   3.04991871e-01,   8.65056813e-01,
                         -6.66193187e-01,  -5.87256491e-01,   9.11120117e-01,
                          2.06980526e-01,  -9.97767866e-01,   2.08806813e-01,
                          9.10308421e-01,  -5.88879883e-01,  -6.64772749e-01,
                          8.65868509e-01,   3.03368509e-01,  -9.92694795e-01,
                          1.10389613e-01,   9.46225643e-01,  -5.05478919e-01,
                         -7.35592544e-01,   8.12094152e-01,   3.96712661e-01,
                         -9.77881491e-01,   1.07548703e-02,   9.73011374e-01,
                         -4.16801959e-01,  -7.99310088e-01,   7.50000000e-01,
                          4.86201286e-01,  -9.53125000e-01,  -8.88798684e-02,
                          9.89853919e-01,  -3.24066550e-01,  -8.54910731e-01,
                          6.80397749e-01,   5.70819795e-01,  -9.18831170e-01,
                         -1.87500000e-01,   9.96956170e-01,  -2.28693187e-01,
                         -9.01582778e-01,   6.04910731e-01,   6.48944795e-01,
                         -8.76014590e-01,  -2.83685058e-01,   9.94318187e-01,
                         -1.31493509e-01,  -9.39529240e-01,   5.23336053e-01,
                          7.20779240e-01,  -8.24472427e-01,  -3.77029210e-01,
                          9.81737018e-01,  -3.28733772e-02,  -9.68344152e-01,
                          4.36485380e-01,   7.85714269e-01,  -7.64813304e-01,
                         -4.66720790e-01,   9.59415555e-01,   6.63555190e-02,
                         -9.87418830e-01,   3.45373362e-01,   8.42938304e-01,
                         -6.97443187e-01,  -5.52150965e-01,   9.27759767e-01,
                          1.64772734e-01,  -9.96753275e-01,   2.50811696e-01,
                          8.91842544e-01,  -6.23173714e-01,  -6.31899357e-01,
                          8.86769474e-01,   2.61769474e-01,  -9.96347427e-01,
                          1.53612018e-01,   9.31818187e-01,  -5.42613626e-01,
                         -7.05560088e-01,   8.36850643e-01,   3.56128246e-01,
                         -9.85998392e-01,   5.47889620e-02,   9.62662339e-01,
                         -4.56777602e-01,  -7.72321403e-01,   7.78814912e-01,
                          4.47037339e-01,  -9.65706170e-01,  -4.44399342e-02,
                          9.83969152e-01,  -3.66274357e-01,  -8.31371725e-01,
                          7.13068187e-01,   5.33685088e-01,  -9.36079562e-01,
                         -1.43465906e-01,   9.95535731e-01,  -2.72118509e-01,
                         -8.82305205e-01,   6.40016258e-01,   6.14853919e-01,
                         -8.96915555e-01,  -2.41071433e-01,   9.97362018e-01,
                         -1.75324678e-01,  -9.24310088e-01,   5.60673714e-01,
                          6.90137982e-01,  -8.49025965e-01,  -3.36241871e-01,
                          9.89042222e-01,  -7.67045468e-02,  -9.57386374e-01,
                          4.75649357e-01,   7.58522749e-01,  -7.92613626e-01,
                         -4.28165585e-01,   9.70982134e-01,   2.27272734e-02,
                         -9.80722427e-01,   3.86160702e-01,   8.19399357e-01,
                         -7.28287339e-01,  -5.15827894e-01,   9.43384767e-01,
                          1.21956170e-01,  -9.94521081e-01,   2.92613626e-01,
                          8.71956170e-01,  -6.56858742e-01,  -5.98214269e-01,
                          9.06250000e-01,   2.19967529e-01,  -9.98376608e-01,
                          1.96225643e-01,   9.16193187e-01,  -5.78733742e-01,
                         -6.74918830e-01,   8.60186696e-01,   3.15746754e-01,
                         -9.92288947e-01,   9.78084430e-02,   9.51095760e-01,
                         -4.94926959e-01,  -7.44926929e-01,   8.05397749e-01,
                          4.08482134e-01,  -9.76258099e-01,  -1.62337662e-03,
                          9.76663947e-01,  -4.06047076e-01,  -8.07426929e-01,
                          7.42694795e-01,   4.97159094e-01,  -9.50689912e-01,
                         -1.01055197e-01,   9.92491901e-01,  -3.13311696e-01,
                         -8.61810088e-01,   6.72686696e-01,   5.80965936e-01,
                         -9.15584445e-01,  -1.99269474e-01,   9.98376608e-01,
                         -2.17532471e-01,  -9.07873392e-01,   5.95982134e-01,
                          6.58887982e-01,  -8.71347427e-01,  -2.95657456e-01,
                          9.94318187e-01,  -1.19318180e-01,  -9.44805205e-01,
                          5.13392866e-01,   7.30316579e-01,  -8.18384767e-01,
                         -3.89204532e-01,   9.80519474e-01,  -2.00892854e-02,
                         -9.72402573e-01,   4.25527602e-01,   7.94439912e-01,
                         -7.57508099e-01,  -4.78693187e-01,   9.56980526e-01,
                          7.91396126e-02,  -9.90259767e-01,   3.33603889e-01,
                          8.50649357e-01,  -6.88920438e-01,  -5.63514590e-01,
                          9.23904240e-01,   1.77759737e-01,  -9.98376608e-01,
                          2.38230526e-01,   8.98538947e-01,  -6.13636374e-01,
                         -6.42857134e-01,   8.81493509e-01,   2.74756491e-01,
                         -9.96550322e-01,   1.40625000e-01,   9.37500000e-01,
                         -5.32061696e-01,  -7.15706170e-01,   8.30560088e-01,
                          3.68912339e-01,  -9.84780848e-01,   4.15990278e-02,
                          9.67126608e-01,  -4.45413947e-01,  -7.81452894e-01,
                          7.71306813e-01,   4.59212661e-01,  -9.63271081e-01,
                         -5.78327924e-02,   9.87012982e-01,  -3.54301959e-01,
                         -8.39488626e-01,   7.04342544e-01,   5.45251608e-01,
                         -9.32224035e-01,  -1.56655848e-01,   9.97159064e-01,
                         -2.59740263e-01,  -8.89001608e-01,   6.30478919e-01,
                          6.25608742e-01,  -8.91842544e-01,  -2.53855526e-01,
                          9.97564912e-01,  -1.62540585e-01,  -9.29991901e-01,
                          5.50324678e-01,   6.99878275e-01,  -8.42735410e-01,
                         -3.48620117e-01,   9.88027573e-01,  -6.37175292e-02,
                         -9.61647749e-01,   4.64691550e-01,   7.67248392e-01,
                         -7.85105526e-01,  -4.39935058e-01,   9.68547106e-01,
                          3.57142873e-02,  -9.83563304e-01,   3.74391228e-01,
                          8.26907456e-01,  -7.19967544e-01,  -5.26988626e-01,
                          9.39529240e-01,   1.34740263e-01,  -9.95941579e-01,
                          2.80438304e-01,   8.78449678e-01,  -6.47321403e-01,
                         -6.08563304e-01,   9.01176929e-01,   2.32345775e-01,
                         -9.98376608e-01,   1.83847398e-01,   9.21266258e-01,
                         -5.68587661e-01,  -6.84253275e-01,   8.53896081e-01,
                          3.27719152e-01,  -9.90868509e-01,   8.54301974e-02,
                          9.54951286e-01,  -4.84172076e-01,  -7.53043830e-01,
                          7.98092544e-01,   4.19845790e-01,  -9.73620117e-01,
                         -1.40016237e-02,   9.79099035e-01,  -3.94886374e-01,
                         -8.14529240e-01,   7.34375000e-01,   5.07711053e-01,
                         -9.46631491e-01,  -1.13230519e-01,   9.93506491e-01,
                         -3.01745117e-01,  -8.67897749e-01,   6.63555205e-01,
                          5.90706170e-01,  -9.10308421e-01,  -2.11241886e-01,
                          9.98173714e-01,  -2.05560058e-01,  -9.12540555e-01,
                          5.86038947e-01,   6.67613626e-01,  -8.65056813e-01,
                         -3.07021111e-01,   9.92694795e-01,  -1.07345782e-01,
                         -9.48254883e-01,   5.02637982e-01,   7.38027573e-01,
                         -8.11079562e-01,  -3.99959415e-01,   9.77678597e-01,
                         -8.11688323e-03,  -9.74431813e-01,   4.14366871e-01,
                          8.01136374e-01,  -7.48985410e-01,  -4.88839298e-01,
                          9.52719152e-01,   9.11120102e-02,  -9.91071403e-01,
                          3.22037339e-01,   8.56128275e-01,  -6.79586053e-01,
                         -5.72849035e-01,   9.18425322e-01,   1.89326301e-01,
                         -9.97767866e-01,   2.26461038e-01,   9.02800322e-01,
                         -6.03490233e-01,  -6.51176929e-01,   8.75000000e-01,
                          2.85917222e-01,  -9.94521081e-01,   1.28652602e-01,
                          9.40340936e-01,  -5.21306813e-01,  -7.23011374e-01,
                          8.22849035e-01,   3.79464298e-01,  -9.81534064e-01,
                          2.96266228e-02,   9.68750000e-01,  -4.34050322e-01,
                         -7.87743509e-01,   7.62581170e-01,   4.69358772e-01,
                         -9.58806813e-01,  -6.96022734e-02,   9.87418830e-01,
                         -3.42532456e-01,  -8.44561696e-01,   6.94602251e-01,
                          5.54383099e-01,  -9.26339269e-01,  -1.68222398e-01,
                          9.96347427e-01,  -2.47564942e-01,  -8.93060088e-01,
                          6.19926929e-01,   6.34131491e-01,  -8.84943187e-01,
                         -2.65219152e-01,   9.95332778e-01,  -1.50162339e-01,
                         -9.32832778e-01,   5.39163947e-01,   7.07386374e-01,
                         -8.34618509e-01,  -3.59577924e-01,   9.84375000e-01,
                         -5.13392873e-02,  -9.63068187e-01,   4.52922076e-01,
                          7.73741901e-01,  -7.76176929e-01,  -4.50284094e-01,
                          9.63676929e-01,   4.78896089e-02,  -9.83969152e-01,
                          3.62215906e-01,   8.32386374e-01,  -7.09821403e-01,
                         -5.36525965e-01,   9.33441579e-01,   1.46712661e-01,
                         -9.94926929e-01,   2.67857134e-01,   8.82711053e-01,
                         -6.36566579e-01,  -6.17288947e-01,   8.93871725e-01,
                          2.44115263e-01,  -9.96144474e-01,   1.71063319e-01,
                          9.24310088e-01,  -5.57021081e-01,  -6.92167222e-01,
                          8.45576286e-01,   3.39082778e-01,  -9.87418830e-01,
                          7.24431798e-02,   9.56777573e-01,  -4.71793830e-01,
                         -7.60146081e-01,   7.88758099e-01,   4.30600643e-01,
                         -9.68750000e-01,  -2.67857146e-02,   9.79707778e-01,
                         -3.82102281e-01,  -8.20413947e-01,   7.24228919e-01,
                          5.17857134e-01,  -9.40543830e-01,  -1.25811681e-01,
                          9.92694795e-01,  -2.88555205e-01,  -8.72564912e-01,
                          6.52394474e-01,   6.00040555e-01,  -9.03003275e-01,
                         -2.23620132e-01,   9.96144474e-01,  -1.92167208e-01,
                         -9.16193187e-01,   5.74066579e-01,   6.76136374e-01,
                         -8.56534064e-01,  -3.19196433e-01,   9.89448071e-01,
                         -9.37500000e-02,  -9.50487018e-01,   4.90056813e-01,
                          7.45738626e-01,  -8.01542222e-01,  -4.11525965e-01,
                          9.73011374e-01,   5.47889620e-03,  -9.75446403e-01,
                          4.01176959e-01,   8.07629883e-01,  -7.38636374e-01,
                         -4.99797076e-01,   9.46834445e-01,   1.04504868e-01,
                         -9.90868509e-01,   3.08441550e-01,   8.61607134e-01,
                         -6.68222427e-01,  -5.83198071e-01,   9.11323071e-01,
                          2.02719152e-01,  -9.96144474e-01,   2.12662339e-01,
                          9.07061696e-01,  -5.91314912e-01,  -6.60714269e-01,
                          8.66680205e-01,   2.98701286e-01,  -9.91680205e-01,
                          1.14650972e-01,   9.43587661e-01,  -5.08522749e-01,
                         -7.31534064e-01,   8.13514590e-01,   3.91842544e-01,
                         -9.77475643e-01,   1.54220778e-02,   9.70576286e-01,
                         -4.20657456e-01,  -7.95251608e-01,   7.52232134e-01,
                          4.81128246e-01,  -9.53327894e-01,  -8.38068202e-02,
                          9.88027573e-01,  -3.28733772e-01,  -8.51055205e-01,
                          6.83441579e-01,   5.65543830e-01,  -9.19845760e-01,
                         -1.82224020e-01,   9.95535731e-01,  -2.33360395e-01,
                         -8.98336053e-01,   6.07954562e-01,   6.44480526e-01,
                         -8.77029240e-01,  -2.78814942e-01,   9.93100643e-01,
                         -1.35754868e-01,  -9.36688304e-01,   5.26176929e-01,
                          7.16720760e-01,  -8.25689912e-01,  -3.72564942e-01,
                          9.80925322e-01,  -3.67288962e-02,  -9.65706170e-01,
                          4.39326286e-01,   7.82061696e-01,  -7.66030848e-01,
                         -4.62865263e-01,   9.59009767e-01,   6.25000000e-02,
                         -9.85186696e-01,   3.48214298e-01,   8.39691579e-01,
                         -6.98863626e-01,  -5.48295438e-01,   9.27353919e-01,
                          1.61120132e-01,  -9.94926929e-01,   2.53449678e-01,
                          8.88798714e-01,  -6.24594152e-01,  -6.28449678e-01,
                          8.86566579e-01,   2.58319795e-01,  -9.94724035e-01,
                          1.56250000e-01,   9.29180205e-01,  -5.44237018e-01,
                         -7.02313304e-01,   8.37053597e-01,   3.52881491e-01,
                         -9.84577894e-01,   5.76298684e-02,   9.60227251e-01,
                         -4.58400965e-01,  -7.69074678e-01,   7.79220760e-01,
                          4.43790585e-01,  -9.64691579e-01,  -4.15990278e-02,
                          9.81737018e-01,  -3.68100643e-01,  -8.28327894e-01,
                          7.13474035e-01,   5.30438304e-01,  -9.35267866e-01,
                         -1.40625000e-01,   9.93506491e-01,  -2.74147719e-01,
                         -8.79261374e-01,   6.40827894e-01,   6.11607134e-01,
                         -8.96306813e-01,  -2.38027602e-01,   9.95332778e-01,
                         -1.77353889e-01,  -9.21672106e-01,   5.61688304e-01,
                          6.86891258e-01,  -8.48620117e-01,  -3.33198041e-01,
                          9.87418830e-01,  -7.89366886e-02,  -9.54545438e-01,
                          4.76866871e-01,   7.55275965e-01,  -7.92410731e-01,
                         -4.24918830e-01,   9.69561696e-01,   2.02922076e-02,
                         -9.78287339e-01,   3.87581170e-01,   8.16152573e-01,
                         -7.28287339e-01,  -5.12581170e-01,   9.41964269e-01,
                          1.19318180e-01,  -9.92086053e-01,   2.94237018e-01,
                          8.68912339e-01,  -6.57061696e-01,  -5.95170438e-01,
                          9.05032456e-01,   2.17329547e-01,  -9.95941579e-01,
                          1.97849020e-01,   9.13149357e-01,  -5.79139590e-01,
                         -6.71672106e-01,   8.59172106e-01,   3.13108772e-01,
                         -9.90056813e-01,   9.96347368e-02,   9.48254883e-01,
                         -4.95535702e-01,  -7.41680205e-01,   8.04788947e-01,
                          4.05641228e-01,  -9.74228919e-01,   6.08766219e-04,
                          9.73823071e-01,  -4.07061696e-01,  -8.04180205e-01,
                          7.42288947e-01,   4.94115263e-01,  -9.48863626e-01,
                         -9.86201316e-02,   9.89650965e-01,  -3.14529210e-01,
                         -8.58766258e-01,   6.72483742e-01,   5.77922106e-01,
                         -9.13961053e-01,  -1.96834415e-01,   9.95738626e-01,
                         -2.18750000e-01,  -9.04626608e-01,   5.95982134e-01,
                          6.55844152e-01,  -8.69926929e-01,  -2.93222398e-01,
                          9.91883099e-01,  -1.20941557e-01,  -9.41761374e-01,
                          5.13595760e-01,   7.27272749e-01,  -8.17167222e-01,
                         -3.86566550e-01,   9.78287339e-01,  -2.19155848e-02,
                         -9.69358742e-01,   4.25933450e-01,   7.91396081e-01,
                         -7.56493509e-01,  -4.76055205e-01,   9.54748392e-01,
                          7.75162354e-02,  -9.87418830e-01,   3.34212661e-01,
                          8.47605526e-01,  -6.88108742e-01,  -5.60673714e-01,
                          9.21875000e-01,   1.75933436e-01,  -9.95535731e-01,
                          2.39042208e-01,   8.95495117e-01,  -6.13027573e-01,
                         -6.39813304e-01,   8.79667222e-01,   2.72727281e-01,
                         -9.93709445e-01,   1.41639605e-01,   9.34456170e-01,
                         -5.31655848e-01,  -7.12662339e-01,   8.28936696e-01,
                          3.66680205e-01,  -9.82142866e-01,   4.28165570e-02,
                          9.64082778e-01,  -4.45211053e-01,  -7.78409064e-01,
                          7.69683421e-01,   4.57183450e-01,  -9.60836053e-01,
                         -5.66152595e-02,   9.84172106e-01,  -3.54301959e-01,
                         -8.36444795e-01,   7.02922106e-01,   5.43019474e-01,
                         -9.29788947e-01,  -1.55235395e-01,   9.94318187e-01,
                         -2.59740263e-01,  -8.86160731e-01,   6.29261374e-01,
                          6.23376608e-01,  -8.89610410e-01,  -2.52435058e-01,
                          9.94724035e-01,  -1.62743509e-01,  -9.26948071e-01,
                          5.49310088e-01,   6.97646081e-01,  -8.40503275e-01,
                         -3.47199678e-01,   9.85186696e-01,  -6.41233772e-02,
                         -9.58603919e-01,   4.63879883e-01,   7.64813304e-01,
                         -7.83076286e-01,  -4.38311696e-01,   9.65909064e-01,
                          3.53084430e-02,  -9.80722427e-01,   3.73782456e-01,
                          8.24675322e-01,  -7.17938304e-01,  -5.25162339e-01,
                          9.36891258e-01,   1.34131491e-01,  -9.93100643e-01,
                          2.79829532e-01,   8.76014590e-01,  -6.45698071e-01,
                         -6.06939912e-01,   8.98741901e-01,   2.31737018e-01,
                         -9.95535731e-01,   1.83441564e-01,   9.18831170e-01,
                         -5.66964269e-01,  -6.82426929e-01,   8.51461053e-01,
                          3.27110380e-01,  -9.88230526e-01,   8.50243494e-02,
                          9.52516258e-01,  -4.82548714e-01,  -7.51420438e-01,
                          7.95860410e-01,   4.19034094e-01,  -9.70982134e-01,
                         -1.42045459e-02,   9.76663947e-01,  -3.93465906e-01,
                         -8.12702894e-01,   7.32345760e-01,   5.07102251e-01,
                         -9.43993509e-01,  -1.13433443e-01,   9.91071403e-01,
                         -3.00324678e-01,  -8.66071403e-01,   6.61525965e-01,
                          5.89894474e-01,  -9.07873392e-01,  -2.11444810e-01,
                          9.95738626e-01,  -2.04342529e-01,  -9.10714269e-01,
                          5.84009767e-01,   6.66801929e-01,  -8.62621725e-01,
                         -3.07224035e-01,   9.90462661e-01,  -1.06128246e-01,
                         -9.46428597e-01,   5.00811696e-01,   7.37215936e-01,
                         -8.08644474e-01,  -4.00162339e-01,   9.75446403e-01,
                         -7.10227294e-03,  -9.72808421e-01,   4.12743509e-01,
                          8.00324678e-01,  -7.46753275e-01,  -4.89042222e-01,
                          9.50689912e-01,   9.21266228e-02,  -9.89245117e-01,
                          3.20413947e-01,   8.55316579e-01,  -6.77556813e-01,
                         -5.72849035e-01,   9.16396081e-01,   1.90340906e-01,
                         -9.96144474e-01,   2.25040585e-01,   9.01988626e-01,
                         -6.01461053e-01,  -6.51176929e-01,   8.72970760e-01,
                          2.86728889e-01,  -9.92897749e-01,   1.27232149e-01,
                          9.39529240e-01,  -5.19480526e-01,  -7.23011374e-01,
                          8.21022749e-01,   3.80275965e-01,  -9.79910731e-01,
                          2.82061696e-02,   9.67938304e-01,  -4.32224035e-01,
                         -7.87743509e-01,   7.60754883e-01,   4.70170468e-01,
                         -9.57183421e-01,  -7.10227266e-02,   9.86607134e-01,
                         -3.40706170e-01,  -8.44561696e-01,   6.92978919e-01,
                          5.55194795e-01,  -9.24918830e-01,  -1.69642851e-01,
                          9.95332778e-01,  -2.45941564e-01,  -8.93060088e-01,
                          6.18303597e-01,   6.34740233e-01,  -8.83319795e-01,
                         -2.66436696e-01,   9.94318187e-01,  -1.48538962e-01,
                         -9.32629883e-01,   5.37540555e-01,   7.08198071e-01,
                         -8.33198071e-01,  -3.60795468e-01,   9.83563304e-01,
                         -4.97159101e-02,  -9.62865233e-01,   4.51298714e-01,
                          7.74553597e-01,  -7.74553597e-01,  -4.51501638e-01,
                          9.62865233e-01,   4.97159101e-02,  -9.83766258e-01,
                          3.60592544e-01,   8.32995117e-01,  -7.08400965e-01,
                         -5.37743509e-01,   9.32629883e-01,   1.48538962e-01,
                         -9.94724035e-01,   2.66436696e-01,   8.83319795e-01,
                         -6.35146081e-01,  -6.18709445e-01,   8.93060088e-01,
                          2.45738640e-01,  -9.95941579e-01,   1.69439942e-01,
                          9.24918830e-01,  -5.55600643e-01,  -6.93384767e-01,
                          8.44764590e-01,   3.40706170e-01,  -9.87012982e-01,
                          7.08198026e-02,   9.57386374e-01,  -4.70373362e-01,
                         -7.61160731e-01,   7.87946403e-01,   4.32224035e-01,
                         -9.68547106e-01,  -2.84090918e-02,   9.80113626e-01,
                         -3.80681813e-01,  -8.21428597e-01,   7.23214269e-01,
                          5.19480526e-01,  -9.40340936e-01,  -1.27435058e-01,
                          9.93303597e-01,  -2.87134737e-01,  -8.73579562e-01,
                          6.51379883e-01,   6.01663947e-01,  -9.02597427e-01,
                         -2.25243509e-01,   9.96550322e-01,  -1.90543830e-01,
                         -9.17207778e-01,   5.73051929e-01,   6.77759767e-01,
                         -8.56128275e-01,  -3.20819795e-01,   9.89853919e-01,
                         -9.23295468e-02,  -9.51501608e-01,   4.89042222e-01,
                          7.47159064e-01,  -8.00933421e-01,  -4.13352281e-01,
                          9.73214269e-01,   7.10227294e-03,  -9.76461053e-01,
                          4.00162339e-01,   8.09253275e-01,  -7.38027573e-01,
                         -5.01623392e-01,   9.47037339e-01,   1.06331170e-01,
                         -9.91680205e-01,   3.07224035e-01,   8.63230526e-01,
                         -6.67613626e-01,  -5.84821403e-01,   9.11525965e-01,
                          2.04342529e-01,  -9.96956170e-01,   2.11241886e-01,
                          9.08482134e-01,  -5.90503275e-01,  -6.62337661e-01,
                          8.66680205e-01,   3.00527602e-01,  -9.92288947e-01,
                          1.13230519e-01,   9.44805205e-01,  -5.07711053e-01,
                         -7.33360410e-01,   8.13514590e-01,   3.93668830e-01,
                         -9.77881491e-01,   1.40016237e-02,   9.71793830e-01,
                         -4.19845790e-01,  -7.96875000e-01,   7.52029240e-01,
                          4.82954532e-01,  -9.53733742e-01,  -8.52272734e-02,
                          9.89042222e-01,  -3.27719152e-01,  -8.52475643e-01,
                          6.83035731e-01,   5.67370117e-01,  -9.20048714e-01,
                         -1.83644474e-01,   9.96550322e-01,  -2.32345775e-01,
                         -8.99756491e-01,   6.07345760e-01,   6.46103919e-01,
                         -8.77232134e-01,  -2.80438304e-01,   9.93912339e-01,
                         -1.34537339e-01,  -9.37905848e-01,   5.25568187e-01,
                          7.18547106e-01,  -8.25689912e-01,  -3.74188304e-01,
                          9.81534064e-01,  -3.55113633e-02,  -9.66923714e-01,
                          4.38717544e-01,   7.83685088e-01,  -7.65827894e-01,
                         -4.64285702e-01,   9.59415555e-01,   6.39204532e-02,
                         -9.86201286e-01,   3.47402602e-01,   8.41112018e-01,
                         -6.98457778e-01,  -5.49918830e-01,   9.27556813e-01,
                          1.62743509e-01,  -9.95738626e-01,   2.52435058e-01,
                          8.90016258e-01,  -6.23985410e-01,  -6.29870117e-01,
                          8.86566579e-01,   2.59740263e-01,  -9.95332778e-01,
                          1.55235395e-01,   9.30194795e-01,  -5.43425322e-01,
                         -7.03733742e-01,   8.36850643e-01,   3.54301959e-01,
                         -9.84983742e-01,   5.64123392e-02,   9.61241901e-01,
                         -4.57589298e-01,  -7.70495117e-01,   7.78814912e-01,
                          4.45413947e-01,  -9.64894474e-01,  -4.30194810e-02,
                          9.82548714e-01,  -3.67086053e-01,  -8.29545438e-01,
                          7.13068187e-01,   5.31858742e-01,  -9.35267866e-01,
                         -1.41842529e-01,   9.94115233e-01,  -2.73133129e-01,
                         -8.80478919e-01,   6.40219152e-01,   6.13027573e-01,
                         -8.96306813e-01,  -2.39448056e-01,   9.95941579e-01,
                         -1.76339284e-01,  -9.22483742e-01,   5.61079562e-01,
                          6.88108742e-01,  -8.48417222e-01,  -3.34415585e-01,
                          9.87621725e-01,  -7.79220760e-02,  -9.55357134e-01,
                          4.76258129e-01,   7.56290555e-01,  -7.92004883e-01,
                         -4.26136374e-01,   9.69561696e-01,   2.13068184e-02,
                         -9.78693187e-01,   3.86769474e-01,   8.16964269e-01,
                         -7.27881491e-01,  -5.13595760e-01,   9.41964269e-01,
                          1.20332792e-01,  -9.92288947e-01,   2.93425322e-01,
                          8.69521081e-01,  -6.56452894e-01,  -5.95982134e-01,
                          9.04829562e-01,   2.18141228e-01,  -9.96144474e-01,
                          1.97240263e-01,   9.13555205e-01,  -5.78530848e-01,
                         -6.72280848e-01,   8.58969152e-01,   3.13717544e-01,
                         -9.90056813e-01,   9.90259722e-02,   9.48457778e-01,
                         -4.95129883e-01,  -7.42086053e-01,   8.04383099e-01,
                          4.06250000e-01,  -9.74228919e-01,   0.00000000e+00,
                          9.73823071e-01,  -4.06655848e-01,  -8.04586053e-01,
                          7.42086053e-01,   4.94521111e-01,  -9.48660731e-01,
                         -9.90259722e-02,   9.89853919e-01,  -3.14326286e-01,
                         -8.58969152e-01,   6.72483742e-01,   5.78125000e-01,
                         -9.13961053e-01,  -1.97037339e-01,   9.95941579e-01,
                         -2.18952924e-01,  -9.05032456e-01,   5.96387982e-01,
                          6.55844152e-01,  -8.70332778e-01,  -2.92816550e-01,
                          9.92491901e-01,  -1.21550322e-01,  -9.41964269e-01,
                          5.14610410e-01,   7.27069795e-01,  -8.18181813e-01,
                         -3.85957778e-01,   9.78896081e-01,  -2.25243513e-02,
                         -9.69764590e-01,   4.26745117e-01,   7.91599035e-01,
                         -7.57305205e-01,  -4.76055205e-01,   9.55560088e-01,
                          7.73133114e-02,  -9.88027573e-01,   3.34618509e-01,
                          8.48214269e-01,  -6.88717544e-01,  -5.61079562e-01,
                          9.22686696e-01,   1.75933436e-01,  -9.96347427e-01,
                          2.39245132e-01,   8.96306813e-01,  -6.13433421e-01,
                         -6.40625000e-01,   8.80478919e-01,   2.72930205e-01,
                         -9.94724035e-01,   1.41639605e-01,   9.35267866e-01,
                         -5.32264590e-01,  -7.13474035e-01,   8.29545438e-01,
                          3.67086053e-01,  -9.82954562e-01,   4.28165570e-02,
                          9.64894474e-01,  -4.45616871e-01,  -7.79220760e-01,
                          7.70495117e-01,   4.57589298e-01,  -9.61647749e-01,
                         -5.66152595e-02,   9.84983742e-01,  -3.54707778e-01,
                         -8.37256491e-01,   7.03733742e-01,   5.43425322e-01,
                         -9.30600643e-01,  -1.55438319e-01,   9.95129883e-01,
                         -2.60146111e-01,  -8.86972427e-01,   6.29870117e-01,
                          6.23782456e-01,  -8.90422106e-01,  -2.52637982e-01,
                          9.95535731e-01,  -1.62946433e-01,  -9.27759767e-01,
                          5.49918830e-01,   6.98051929e-01,  -8.41314912e-01,
                         -3.47402602e-01,   9.85998392e-01,  -6.43263012e-02,
                         -9.59415555e-01,   4.64285702e-01,   7.65422106e-01,
                         -7.83887982e-01,  -4.38514620e-01,   9.66720760e-01,
                          3.49025987e-02,  -9.81534064e-01,   3.74188304e-01,
                          8.25081170e-01,  -7.18750000e-01,  -5.25568187e-01,
                          9.37702894e-01,   1.33928567e-01,  -9.93912339e-01,
                          2.80438304e-01,   8.76623392e-01,  -6.46509767e-01,
                         -6.07142866e-01,   8.99553597e-01,   2.31534094e-01,
                         -9.96550322e-01,   1.83847398e-01,   9.19439912e-01,
                         -5.67775965e-01,  -6.82832778e-01,   8.52475643e-01,
                          3.26907456e-01,  -9.89042222e-01,   8.54301974e-02,
                          9.53125000e-01,  -4.83360380e-01,  -7.51826286e-01,
                          7.96875000e-01,   4.19034094e-01,  -9.71996725e-01,
                         -1.37987016e-02,   9.77475643e-01,  -3.94277602e-01,
                         -8.13311696e-01,   7.33360410e-01,   5.06899357e-01,
                         -9.45211053e-01,  -1.12824678e-01,   9.91883099e-01,
                         -3.01339298e-01,  -8.66680205e-01,   6.62540555e-01,
                          5.89894474e-01,  -9.08887982e-01,  -2.10836038e-01,
                          9.96753275e-01,  -2.05154225e-01,  -9.11323071e-01,
                          5.85227251e-01,   6.67004883e-01,  -8.63636374e-01,
                         -3.06818187e-01,   9.91477251e-01,  -1.07142858e-01,
                         -9.47037339e-01,   5.02029240e-01,   7.37418830e-01,
                         -8.09862018e-01,  -3.99756491e-01,   9.76461053e-01,
                         -7.91396108e-03,  -9.73417222e-01,   4.13758129e-01,
                          8.00527573e-01,  -7.47970760e-01,  -4.88839298e-01,
                          9.51704562e-01,   9.15178582e-02,  -9.90056813e-01,
                          3.21428567e-01,   8.55722427e-01,  -6.78571403e-01,
                         -5.72849035e-01,   9.17410731e-01,   1.89732149e-01,
                         -9.96956170e-01,   2.25852266e-01,   9.02394474e-01,
                         -6.02678597e-01,  -6.51379883e-01,   8.73985410e-01,
                          2.86323041e-01,  -9.93912339e-01,   1.28043830e-01,
                          9.40137982e-01,  -5.20495117e-01,  -7.23214269e-01,
                          8.22037339e-01,   3.80073041e-01,  -9.80925322e-01,
                          2.88149342e-02,   9.68547106e-01,  -4.33238626e-01,
                         -7.88149357e-01,   7.61769474e-01,   4.69967544e-01,
                         -9.58198071e-01,  -7.06168860e-02,   9.87215936e-01,
                         -3.41720790e-01,  -8.45170438e-01,   6.93993509e-01,
                          5.55194795e-01,  -9.25933421e-01,  -1.69237018e-01,
                          9.96144474e-01,  -2.46753246e-01,  -8.93668830e-01,
                          6.19115233e-01,   6.34943187e-01,  -8.84537339e-01,
                         -2.66233772e-01,   9.95332778e-01,  -1.49147734e-01,
                         -9.33238626e-01,   5.38352251e-01,   7.08400965e-01,
                         -8.34212661e-01,  -3.60592544e-01,   9.84375000e-01,
                         -5.03246747e-02,  -9.63676929e-01,   4.52110380e-01,
                          7.74756491e-01,  -7.75568187e-01,  -4.51501638e-01,
                          9.63676929e-01,   4.91071418e-02,  -9.84375000e-01,
                          3.61201286e-01,   8.33400965e-01,  -7.09212661e-01,
                         -5.37743509e-01,   9.33238626e-01,   1.48133114e-01,
                         -9.95332778e-01,   2.66842544e-01,   8.83725643e-01,
                         -6.35957778e-01,  -6.18709445e-01,   8.93668830e-01,
                          2.45535716e-01,  -9.96550322e-01,   1.69845775e-01,
                          9.25324678e-01,  -5.56209445e-01,  -6.93587661e-01,
                          8.45170438e-01,   3.40706170e-01,  -9.87621725e-01,
                          7.10227266e-02,   9.57589269e-01,  -4.70982134e-01,
                         -7.61566579e-01,   7.88352251e-01,   4.32224035e-01,
                         -9.68952894e-01,  -2.84090918e-02,   9.80519474e-01,
                         -3.81087661e-01,  -8.21834445e-01,   7.23620117e-01,
                          5.19683421e-01,  -9.40746725e-01,  -1.27435058e-01,
                          9.93506491e-01,  -2.87337661e-01,  -8.73985410e-01,
                          6.51582778e-01,   6.01663947e-01,  -9.03003275e-01,
                         -2.25446433e-01,   9.96753275e-01,  -1.90746754e-01,
                         -9.17410731e-01,   5.73254883e-01,   6.77962661e-01,
                         -8.56331170e-01,  -3.21022719e-01,   9.89853919e-01,
                         -9.23295468e-02,  -9.51704562e-01,   4.89042222e-01,
                          7.47362018e-01,  -8.01136374e-01,  -4.13352281e-01,
                          9.73214269e-01,   6.89935079e-03,  -9.76461053e-01,
                          4.00162339e-01,   8.09253275e-01,  -7.38027573e-01,
                         -5.01623392e-01,   9.47037339e-01,   1.06128246e-01,
                         -9.91680205e-01,   3.07224035e-01,   8.63027573e-01,
                         -6.67613626e-01,  -5.84821403e-01,   9.11323071e-01,
                          2.04342529e-01,  -9.96753275e-01,   2.11241886e-01,
                          9.08279240e-01,  -5.90503275e-01,  -6.62337661e-01,
                          8.66477251e-01,   3.00527602e-01,  -9.92086053e-01,
                          1.13230519e-01,   9.44602251e-01,  -5.07508099e-01,
                         -7.33157456e-01,   8.13108742e-01,   3.93465906e-01,
                         -9.77678597e-01,   1.40016237e-02,   9.71387982e-01,
                         -4.19642866e-01,  -7.96672106e-01,   7.51623392e-01,
                          4.82751638e-01,  -9.53327894e-01,  -8.52272734e-02,
                          9.88636374e-01,  -3.27516228e-01,  -8.52272749e-01,
                          6.82629883e-01,   5.67167222e-01,  -9.19642866e-01,
                         -1.83847398e-01,   9.95941579e-01,  -2.32142851e-01,
                         -8.99350643e-01,   6.06939912e-01,   6.45900965e-01,
                         -8.76826286e-01,  -2.80438304e-01,   9.93506491e-01,
                         -1.34334415e-01,  -9.37702894e-01,   5.25365233e-01,
                          7.18141258e-01,  -8.25284064e-01,  -3.74188304e-01,
                          9.81128275e-01,  -3.55113633e-02,  -9.66517866e-01,
                          4.38311696e-01,   7.83279240e-01,  -7.65625000e-01,
                         -4.64285702e-01,   9.59009767e-01,   6.39204532e-02,
                         -9.85795438e-01,   3.47199678e-01,   8.40706170e-01,
                         -6.98254883e-01,  -5.49715936e-01,   9.27353919e-01,
                          1.62540585e-01,  -9.95332778e-01,   2.52435058e-01,
                          8.89813304e-01,  -6.23985410e-01,  -6.29667222e-01,
                          8.86363626e-01,   2.59537339e-01,  -9.95129883e-01,
                          1.55235395e-01,   9.29991901e-01,  -5.43628275e-01,
                         -7.03530848e-01,   8.36850643e-01,   3.54099035e-01,
                         -9.84780848e-01,   5.64123392e-02,   9.60836053e-01,
                         -4.57792222e-01,  -7.70292222e-01,   7.78814912e-01,
                          4.45008129e-01,  -9.64894474e-01,  -4.28165570e-02,
                          9.82345760e-01,  -3.67288947e-01,  -8.29342544e-01,
                          7.13068187e-01,   5.31452894e-01,  -9.35267866e-01,
                         -1.41639605e-01,   9.94115233e-01,  -2.73336053e-01,
                         -8.80275965e-01,   6.40219152e-01,   6.12824678e-01,
                         -8.96306813e-01,  -2.39245132e-01,   9.95738626e-01,
                         -1.76542208e-01,  -9.22483742e-01,   5.61079562e-01,
                          6.87905848e-01,  -8.48620117e-01,  -3.34212661e-01,
                          9.87824678e-01,  -7.81250000e-02,  -9.55560088e-01,
                          4.76461053e-01,   7.56290555e-01,  -7.92410731e-01,
                         -4.26136374e-01,   9.69967544e-01,   2.11038962e-02,
                         -9.79099035e-01,   3.86972398e-01,   8.17167222e-01,
                         -7.28287339e-01,  -5.13798714e-01,   9.42370117e-01,
                          1.20332792e-01,  -9.92897749e-01,   2.93628246e-01,
                          8.70129883e-01,  -6.56858742e-01,  -5.96185088e-01,
                          9.05438304e-01,   2.18141228e-01,  -9.96753275e-01,
                          1.97240263e-01,   9.14163947e-01,  -5.78936696e-01,
                         -6.72889590e-01,   8.59577894e-01,   3.13920468e-01,
                         -9.90868509e-01,   9.90259722e-02,   9.49269474e-01,
                         -4.95332778e-01,  -7.42897749e-01,   8.04991901e-01,
                          4.06655848e-01,  -9.75040555e-01,  -2.02922078e-04,
                          9.74837661e-01,  -4.06858772e-01,  -8.05397749e-01,
                          7.42491901e-01,   4.95332778e-01,  -9.49675322e-01,
                         -9.96347368e-02,   9.90868509e-01,  -3.14123362e-01,
                         -8.60186696e-01,   6.72686696e-01,   5.79139590e-01,
                         -9.14772749e-01,  -1.97849020e-01,   9.96956170e-01,
                         -2.18344152e-01,  -9.06250000e-01,   5.95982134e-01,
                          6.57264590e-01,  -8.70535731e-01,  -2.94439942e-01,
                          9.93100643e-01,  -1.20332792e-01,  -9.43384767e-01,
                          5.13392866e-01,   7.28693187e-01,  -8.17978919e-01,
                         -3.87784094e-01,   9.79504883e-01,  -2.09009741e-02,
                         -9.70982134e-01,   4.25730526e-01,   7.93019474e-01,
                         -7.57102251e-01,  -4.77475643e-01,   9.55965936e-01,
                          7.85308406e-02,  -9.89042222e-01,   3.33806813e-01,
                          8.49431813e-01,  -6.88514590e-01,  -5.62500000e-01,
                          9.23092544e-01,   1.77150980e-01,  -9.97362018e-01,
                          2.38433436e-01,   8.97524357e-01,  -6.13230526e-01,
                         -6.41842544e-01,   8.80884767e-01,   2.74147719e-01,
                         -9.95535731e-01,   1.40827924e-01,   9.36485410e-01,
                         -5.31858742e-01,  -7.14894474e-01,   8.29951286e-01,
                          3.68506491e-01,  -9.83969152e-01,   4.15990278e-02,
                          9.66314912e-01,  -4.45008129e-01,  -7.80844152e-01,
                          7.70698071e-01,   4.59009737e-01,  -9.62459445e-01,
                         -5.78327924e-02,   9.86404240e-01,  -3.53896111e-01,
                         -8.39082778e-01,   7.03733742e-01,   5.45251608e-01,
                         -9.31412339e-01,  -1.56858772e-01,   9.96753275e-01,
                         -2.59131491e-01,  -8.88798714e-01,   6.29667222e-01,
                          6.25811696e-01,  -8.91233742e-01,  -2.54261374e-01,
                          9.96956170e-01,  -1.61728889e-01,  -9.29788947e-01,
                          5.49512982e-01,   7.00284064e-01,  -8.41923714e-01,
                         -3.49228889e-01,   9.87418830e-01,  -6.29058406e-02,
                         -9.61444795e-01,   4.63676959e-01,   7.67654240e-01,
                         -7.84293830e-01,  -4.40746754e-01,   9.67938304e-01,
                          3.67288962e-02,  -9.83563304e-01,   3.73376638e-01,
                          8.27516258e-01,  -7.18750000e-01,  -5.27800322e-01,
                          9.38920438e-01,   1.35957792e-01,  -9.95738626e-01,
                          2.79220790e-01,   8.79058421e-01,  -6.46306813e-01,
                         -6.09577894e-01,   9.00365233e-01,   2.33766228e-01,
                         -9.98173714e-01,   1.82224020e-01,   9.21875000e-01,
                         -5.67167222e-01,  -6.85267866e-01,   8.52881491e-01,
                          3.29342544e-01,  -9.90665555e-01,   8.36038962e-02,
                          9.55357134e-01,  -4.82548714e-01,  -7.54261374e-01,
                          7.96875000e-01,   4.21469152e-01,  -9.73214269e-01,
                         -1.58279222e-02,   9.79504883e-01,  -3.92857134e-01,
                         -8.15746725e-01,   7.33157456e-01,   5.09537339e-01,
                         -9.46022749e-01,  -1.15259737e-01,   9.93709445e-01,
                         -2.99512982e-01,  -8.68912339e-01,   6.61931813e-01,
                          5.92532456e-01,  -9.09496725e-01,  -2.13474020e-01,
                          9.98173714e-01,  -2.03125000e-01,  -9.13555205e-01,
                          5.84212661e-01,   6.69642866e-01,  -8.63839269e-01,
                         -3.09456170e-01,   9.92694795e-01,  -1.04910716e-01,
                         -9.49066579e-01,   5.00608742e-01,   7.40056813e-01,
                         -8.09659064e-01,  -4.02394474e-01,   9.77272749e-01,
                         -5.47889620e-03,  -9.75243509e-01,   4.12134737e-01,
                          8.02962661e-01,  -7.47362018e-01,  -4.91274357e-01,
                          9.52313304e-01,   9.39529240e-02,  -9.91680205e-01,
                          3.19399357e-01,   8.57954562e-01,  -6.77759767e-01,
                         -5.75487018e-01,   9.17613626e-01,   1.92370132e-01,
                         -9.98173714e-01,   2.23823056e-01,   9.04423714e-01,
                         -6.01461053e-01,  -6.53612018e-01,   8.73985410e-01,
                          2.88758129e-01,  -9.94724035e-01,   1.25811681e-01,
                          9.41964269e-01,  -5.19074678e-01,  -7.25446403e-01,
                          8.21631491e-01,   3.82508129e-01,  -9.81534064e-01,
                          2.67857146e-02,   9.69967544e-01,  -4.31615263e-01,
                         -7.89975643e-01,   7.61160731e-01,   4.72199678e-01,
                         -9.58400965e-01,  -7.26461038e-02,   9.88433421e-01,
                         -3.39894474e-01,  -8.46793830e-01,   6.92978919e-01,
                          5.57224035e-01,  -9.25933421e-01,  -1.71266228e-01,
                          9.97159064e-01,  -2.44926944e-01,  -8.95089269e-01,
                          6.18100643e-01,   6.36769474e-01,  -8.84131491e-01,
                         -2.68262982e-01,   9.95738626e-01,  -1.47524357e-01,
                         -9.34456170e-01,   5.37134767e-01,   7.10024357e-01,
                         -8.33603919e-01,  -3.62418830e-01,   9.84577894e-01,
                         -4.84983772e-02,  -9.64488626e-01,   4.50689942e-01,
                          7.76176929e-01,  -7.74959445e-01,  -4.53125000e-01,
                          9.63676929e-01,   5.07305190e-02,  -9.85186696e-01,
                          3.59983772e-01,   8.34618509e-01,  -7.08400965e-01,
                         -5.39163947e-01,   9.33238626e-01,   1.49553567e-01,
                         -9.95941579e-01,   2.65625000e-01,   8.84740233e-01,
                         -6.35146081e-01,  -6.19926929e-01,   8.93465936e-01,
                          2.46956170e-01,  -9.96753275e-01,   1.68628246e-01,
                          9.26136374e-01,  -5.55397749e-01,  -6.94399357e-01,
                          8.44967544e-01,   3.41720790e-01,  -9.87824678e-01,
                          7.00081140e-02,   9.58198071e-01,  -4.70170468e-01,
                         -7.62175322e-01,   7.87946403e-01,   4.33238626e-01,
                         -9.69155848e-01,  -2.92207785e-02,   9.80925322e-01,
                         -3.80275965e-01,  -8.22443187e-01,   7.23214269e-01,
                          5.20292222e-01,  -9.40746725e-01,  -1.28246754e-01,
                          9.93912339e-01,  -2.86728889e-01,  -8.74391258e-01,
                          6.51379883e-01,   6.02272749e-01,  -9.03003275e-01,
                         -2.25852266e-01,   9.96956170e-01,  -1.90340906e-01,
                         -9.17816579e-01,   5.73051929e-01,   6.78368509e-01,
                         -8.56331170e-01,  -3.21428567e-01,   9.90259767e-01,
                         -9.19236988e-02,  -9.52110410e-01,   4.89042222e-01,
                          7.47767866e-01,  -8.01339269e-01,  -4.13555205e-01,
                          9.73620117e-01,   7.30519462e-03,  -9.76866901e-01,
                          4.00162339e-01,   8.09659064e-01,  -7.38230526e-01,
                         -5.01826286e-01,   9.47443187e-01,   1.06331170e-01,
                         -9.92086053e-01,   3.07224035e-01,   8.63433421e-01,
                         -6.67816579e-01,  -5.85024357e-01,   9.11728919e-01,
                          2.04545453e-01,  -9.97362018e-01,   2.11241886e-01,
                          9.08887982e-01,  -5.90706170e-01,  -6.62540555e-01,
                          8.67086053e-01,   3.00527602e-01,  -9.92694795e-01,
                          1.13433443e-01,   9.45211053e-01,  -5.07913947e-01,
                         -7.33360410e-01,   8.13717544e-01,   3.93668830e-01,
                         -9.78287339e-01,   1.42045459e-02,   9.71996725e-01,
                         -4.20048714e-01,  -7.96875000e-01,   7.52435088e-01,
                          4.82751638e-01,  -9.54139590e-01,  -8.50243494e-02,
                          9.89448071e-01,  -3.27922076e-01,  -8.52678597e-01,
                          6.83441579e-01,   5.67167222e-01,  -9.20454562e-01,
                         -1.83441564e-01,   9.96753275e-01,  -2.32548699e-01,
                         -8.99959445e-01,   6.07751608e-01,   6.46103919e-01,
                         -8.77637982e-01,  -2.80032456e-01,   9.94318187e-01,
                         -1.34943187e-01,  -9.38311696e-01,   5.26176929e-01,
                          7.18344152e-01,  -8.26095760e-01,  -3.73985380e-01,
                          9.82142866e-01,  -3.59172076e-02,  -9.67329562e-01,
                          4.39123362e-01,   7.83685088e-01,  -7.66436696e-01,
                         -4.64082778e-01,   9.60024357e-01,   6.35146126e-02,
                         -9.86607134e-01,   3.47808450e-01,   8.41112018e-01,
                         -6.99066579e-01,  -5.49715936e-01,   9.28368509e-01,
                          1.62134737e-01,  -9.96144474e-01,   2.53043830e-01,
                          8.90219152e-01,  -6.24797106e-01,  -6.29667222e-01,
                          8.87581170e-01,   2.59334415e-01,  -9.95941579e-01,
                          1.55844152e-01,   9.30600643e-01,  -5.44237018e-01,
                         -7.03530848e-01,   8.37865233e-01,   3.53896111e-01,
                         -9.85795438e-01,   5.70211038e-02,   9.61647749e-01,
                         -4.58400965e-01,  -7.70495117e-01,   7.79829562e-01,
                          4.45008129e-01,  -9.65706170e-01,  -4.24107127e-02,
                          9.83157456e-01,  -3.67897719e-01,  -8.29748392e-01,
                          7.13879883e-01,   5.31655848e-01,  -9.36079562e-01,
                         -1.41436681e-01,   9.94724035e-01,  -2.73741871e-01,
                         -8.80681813e-01,   6.41030848e-01,   6.12824678e-01,
                         -8.97118509e-01,  -2.38839284e-01,   9.96550322e-01,
                         -1.76948056e-01,  -9.22889590e-01,   5.61891258e-01,
                          6.88108742e-01,  -8.49228919e-01,  -3.34009737e-01,
                          9.88433421e-01,  -7.83279240e-02,  -9.55762982e-01,
                          4.77069795e-01,   7.56493509e-01,  -7.93019474e-01,
                         -4.25933450e-01,   9.70576286e-01,   2.09009741e-02,
                         -9.79301929e-01,   3.87378246e-01,   8.17370117e-01,
                         -7.28693187e-01,  -5.13595760e-01,   9.42775965e-01,
                          1.20129868e-01,  -9.93100643e-01,   2.94034094e-01,
                          8.70129883e-01,  -6.57264590e-01,  -5.95982134e-01,
                          9.05844152e-01,   2.17938319e-01,  -9.96956170e-01,
                          1.97646111e-01,   9.14163947e-01,  -5.79342544e-01,
                         -6.72686696e-01,   8.59780848e-01,   3.13717544e-01,
                         -9.91071403e-01,   9.94318202e-02,   9.49269474e-01,
                         -4.95535702e-01,  -7.42491901e-01,   8.05397749e-01,
                          4.06250000e-01,  -9.75040555e-01,   2.02922078e-04,
                          9.74634767e-01,  -4.07061696e-01,  -8.04991901e-01,
                          7.42694795e-01,   4.94926959e-01,  -9.49472427e-01,
                         -9.90259722e-02,   9.90462661e-01,  -3.14326286e-01,
                         -8.59375000e-01,   6.72889590e-01,   5.78530848e-01,
                         -9.14569795e-01,  -1.97240263e-01,   9.96550322e-01,
                         -2.18750000e-01,  -9.05438304e-01,   5.96185088e-01,
                          6.56250000e-01,  -8.70332778e-01,  -2.93425322e-01,
                          9.92694795e-01,  -1.20738633e-01,  -9.42370117e-01,
                          5.13798714e-01,   7.27678597e-01,  -8.17573071e-01,
                         -3.86769474e-01,   9.78896081e-01,  -2.17126627e-02,
                         -9.69967544e-01,   4.26136374e-01,   7.91599035e-01,
                         -7.56899357e-01,  -4.76055205e-01,   9.55357134e-01,
                          7.75162354e-02,  -9.87824678e-01,   3.34415585e-01,
                          8.47808421e-01,  -6.88514590e-01,  -5.60876608e-01,
                          9.22280848e-01,   1.75933436e-01,  -9.95941579e-01,
                          2.39448056e-01,   8.95698071e-01,  -6.13230526e-01,
                         -6.39813304e-01,   8.80073071e-01,   2.72524357e-01,
                         -9.94115233e-01,   1.41842529e-01,   9.34456170e-01,
                         -5.32061696e-01,  -7.12662339e-01,   8.29342544e-01,
                          3.66477281e-01,  -9.82345760e-01,   4.32224013e-02,
                          9.64082778e-01,  -4.45616871e-01,  -7.78206170e-01,
                          7.70089269e-01,   4.56777602e-01,  -9.61038947e-01,
                         -5.60064949e-02,   9.84172106e-01,  -3.54707778e-01,
                         -8.36241901e-01,   7.03530848e-01,   5.42410731e-01,
                         -9.30194795e-01,  -1.54626623e-01,   9.94318187e-01,
                         -2.60349035e-01,  -8.85754883e-01,   6.29667222e-01,
                          6.22767866e-01,  -8.90016258e-01,  -2.51826286e-01,
                          9.94724035e-01,  -1.63352266e-01,  -9.26745117e-01,
                          5.49715936e-01,   6.97037339e-01,  -8.40909064e-01,
                         -3.46387982e-01,   9.85186696e-01,  -6.49350658e-02,
                         -9.58400965e-01,   4.64488626e-01,   7.64204562e-01,
                         -7.83482134e-01,  -4.37500000e-01,   9.65909064e-01,
                          3.42938304e-02,  -9.80519474e-01,   3.74391228e-01,
                          8.23863626e-01,  -7.18547106e-01,  -5.24350643e-01,
                          9.37094152e-01,   1.33116886e-01,  -9.92897749e-01,
                          2.80641228e-01,   8.75405848e-01,  -6.46103919e-01,
                         -6.05925322e-01,   8.98741901e-01,   2.30722398e-01,
                         -9.95332778e-01,   1.84253246e-01,   9.18019474e-01,
                         -5.67573071e-01,  -6.81412339e-01,   8.51663947e-01,
                          3.25892866e-01,  -9.88027573e-01,   8.58360380e-02,
                          9.51704562e-01,  -4.83157456e-01,  -7.50405848e-01,
                          7.96063304e-01,   4.18019474e-01,  -9.70779240e-01,
                         -1.33928573e-02,   9.76055205e-01,  -3.94074678e-01,
                         -8.11688304e-01,   7.32548714e-01,   5.05884767e-01,
                         -9.43790555e-01,  -1.12418830e-01,   9.90462661e-01,
                         -3.00933450e-01,  -8.65056813e-01,   6.61525965e-01,
                          5.88676929e-01,  -9.07467544e-01,  -2.10430190e-01,
                          9.95129883e-01,  -2.04748377e-01,  -9.09699678e-01,
                          5.84009767e-01,   6.65787339e-01,  -8.62215936e-01,
                         -3.06412339e-01,   9.89853919e-01,  -1.06534094e-01,
                         -9.45413947e-01,   5.00608742e-01,   7.36201286e-01,
                         -8.08238626e-01,  -3.99350643e-01,   9.74634767e-01,
                         -7.30519462e-03,  -9.71793830e-01,   4.12134737e-01,
                          7.99310088e-01,  -7.45941579e-01,  -4.88433450e-01,
                          9.49472427e-01,   9.23295468e-02,  -9.88230526e-01,
                          3.19399357e-01,   8.54504883e-01,  -6.76136374e-01,
                         -5.72849035e-01,   9.14975643e-01,   1.90543830e-01,
                         -9.94926929e-01,   2.24228889e-01,   9.00974035e-01,
                         -6.00649357e-01,  -6.50365233e-01,   8.71956170e-01,
                          2.86323041e-01,  -9.91883099e-01,   1.27232149e-01,
                          9.38311696e-01,  -5.19074678e-01,  -7.21996725e-01,
                          8.20211053e-01,   3.79464298e-01,  -9.78896081e-01,
                          2.88149342e-02,   9.66720760e-01,  -4.32426959e-01,
                         -7.86323071e-01,   7.60349035e-01,   4.68750000e-01,
                         -9.56371725e-01,  -7.02110380e-02,   9.85389590e-01,
                         -3.41314942e-01,  -8.43141258e-01,   6.92775965e-01,
                          5.53774357e-01,  -9.24310088e-01,  -1.68425322e-01,
                          9.94318187e-01,  -2.46753246e-01,  -8.91639590e-01,
                          6.18506491e-01,   6.33116901e-01,  -8.83116901e-01,
                         -2.65016228e-01,   9.93506491e-01,  -1.49553567e-01,
                         -9.31209445e-01,   5.37946403e-01,   7.06371725e-01,
                         -8.32995117e-01,  -3.59172076e-01,   9.82751608e-01,
                         -5.11363633e-02,  -9.61647749e-01,   4.51907456e-01,
                          7.72727251e-01,  -7.74756491e-01,  -4.49675322e-01,
                          9.62256491e-01,   4.80925329e-02,  -9.82548714e-01,
                          3.61607134e-01,   8.31371725e-01,  -7.08806813e-01,
                         -5.35917222e-01,   9.32224035e-01,   1.46712661e-01,
                         -9.93709445e-01,   2.67451286e-01,   8.81696403e-01,
                         -6.35754883e-01,  -6.16680205e-01,   8.92857134e-01,
                          2.43912339e-01,  -9.94926929e-01,   1.70657471e-01,
                          9.23295438e-01,  -5.56209445e-01,  -6.91558421e-01,
                          8.44561696e-01,   3.38879883e-01,  -9.86404240e-01,
                          7.22402632e-02,   9.55965936e-01,  -4.71387982e-01,
                         -7.59537339e-01,   7.87946403e-01,   4.30397719e-01,
                         -9.67938304e-01,  -2.69886367e-02,   9.78896081e-01,
                         -3.81696433e-01,  -8.19805205e-01,   7.23620117e-01,
                          5.17654240e-01,  -9.39935088e-01,  -1.26014605e-01,
                          9.92288947e-01,  -2.88149357e-01,  -8.72159064e-01,
                          6.51785731e-01,   5.99837661e-01,  -9.02597427e-01,
                         -2.23620132e-01,   9.95535731e-01,  -1.91964284e-01,
                         -9.15787339e-01,   5.73660731e-01,   6.76136374e-01,
                         -8.56128275e-01,  -3.19196433e-01,   9.89042222e-01,
                         -9.37500000e-02,  -9.50284064e-01,   4.89853889e-01,
                          7.45535731e-01,  -8.01339269e-01,  -4.11525965e-01,
                          9.72808421e-01,   5.47889620e-03,  -9.75446403e-01,
                          4.00974035e-01,   8.07629883e-01,  -7.38433421e-01,
                         -4.99797076e-01,   9.46834445e-01,   1.04707792e-01,
                         -9.90665555e-01,   3.08238626e-01,   8.61810088e-01,
                         -6.68222427e-01,  -5.83198071e-01,   9.11323071e-01,
                          2.02719152e-01,  -9.96347427e-01,   2.12459415e-01,
                          9.07264590e-01,  -5.91314912e-01,  -6.60714269e-01,
                          8.66883099e-01,   2.98904210e-01,  -9.91883099e-01,
                          1.14650972e-01,   9.43790555e-01,  -5.08522749e-01,
                         -7.31737018e-01,   8.13717544e-01,   3.92045468e-01,
                         -9.77678597e-01,   1.54220778e-02,   9.70779240e-01,
                         -4.20860380e-01,  -7.95454562e-01,   7.52435088e-01,
                          4.81128246e-01,  -9.53733742e-01,  -8.38068202e-02,
                          9.88230526e-01,  -3.28733772e-01,  -8.51258099e-01,
                          6.83847427e-01,   5.65746725e-01,  -9.20251608e-01,
                         -1.82224020e-01,   9.95941579e-01,  -2.33563319e-01,
                         -8.98741901e-01,   6.08360410e-01,   6.44480526e-01,
                         -8.77637982e-01,  -2.78814942e-01,   9.93709445e-01,
                         -1.35957792e-01,  -9.37094152e-01,   5.26785731e-01,
                          7.16923714e-01,  -8.26298714e-01,  -3.72564942e-01,
                          9.81534064e-01,  -3.71347405e-02,  -9.66314912e-01,
                          4.39935058e-01,   7.82264590e-01,  -7.66842544e-01,
                         -4.62662339e-01,   9.59618509e-01,   6.20941557e-02,
                         -9.85795438e-01,   3.48823041e-01,   8.39894474e-01,
                         -6.99675322e-01,  -5.48295438e-01,   9.28165555e-01,
                          1.60714284e-01,  -9.95535731e-01,   2.54261374e-01,
                          8.89001608e-01,  -6.25405848e-01,  -6.28246725e-01,
                          8.87378275e-01,   2.57913947e-01,  -9.95332778e-01,
                          1.57061681e-01,   9.29383099e-01,  -5.45251608e-01,
                         -7.02110410e-01,   8.37865233e-01,   3.52272719e-01,
                         -9.85389590e-01,   5.84415570e-02,   9.60633099e-01,
                         -4.59415585e-01,  -7.69074678e-01,   7.80032456e-01,
                          4.43384737e-01,  -9.65503275e-01,  -4.09902595e-02,
                          9.82142866e-01,  -3.69115263e-01,  -8.28327894e-01,
                          7.14488626e-01,   5.29829562e-01,  -9.36079562e-01,
                         -1.39813319e-01,   9.93912339e-01,  -2.75162339e-01,
                         -8.79261374e-01,   6.41842544e-01,   6.11201286e-01,
                         -8.97321403e-01,  -2.37215906e-01,   9.95941579e-01,
                         -1.78571433e-01,  -9.21672106e-01,   5.62702894e-01,
                          6.86485410e-01,  -8.49634767e-01,  -3.32386374e-01,
                          9.88027573e-01,  -8.01542178e-02,  -9.54748392e-01,
                          4.78084415e-01,   7.54870117e-01,  -7.93628275e-01,
                         -4.24107134e-01,   9.70170438e-01,   1.90746747e-02,
                         -9.78490233e-01,   3.88798714e-01,   8.15746725e-01,
                         -7.29504883e-01,  -5.11769474e-01,   9.42775965e-01,
                          1.18100651e-01,  -9.92491901e-01,   2.95454532e-01,
                          8.68709445e-01,  -6.58279240e-01,  -5.94358742e-01,
                          9.06047106e-01,   2.15909094e-01,  -9.96550322e-01,
                          1.99269474e-01,   9.12946403e-01,  -5.80560088e-01,
                         -6.70860410e-01,   8.60389590e-01,   3.11688304e-01,
                         -9.90665555e-01,   1.01258114e-01,   9.48051929e-01,
                         -4.97159094e-01,  -7.40868509e-01,   8.06006491e-01,
                          4.04220790e-01,  -9.75040555e-01,   2.02922081e-03,
                          9.73823071e-01,  -4.08685058e-01,  -8.03571403e-01,
                          7.43709445e-01,   4.92897719e-01,  -9.49675322e-01,
                         -9.69967544e-02,   9.89853919e-01,  -3.16152602e-01,
                         -8.58157456e-01,   6.73904240e-01,   5.76501608e-01,
                         -9.14772749e-01,  -1.95211038e-01,   9.95941579e-01,
                         -2.20576301e-01,  -9.04220760e-01,   5.97402573e-01,
                          6.54626608e-01,  -8.70941579e-01,  -2.91599035e-01,
                          9.92288947e-01,  -1.22767858e-01,  -9.41355526e-01,
                          5.15016258e-01,   7.26055205e-01,  -8.18384767e-01,
                         -3.84943187e-01,   9.78693187e-01,  -2.37418823e-02,
                         -9.69155848e-01,   4.27556813e-01,   7.90381491e-01,
                         -7.57711053e-01,  -4.74431813e-01,   9.55357134e-01,
                          7.56899342e-02,  -9.87215936e-01,   3.35836053e-01,
                          8.46590936e-01,  -6.89529240e-01,  -5.59253275e-01,
                          9.22686696e-01,   1.74107149e-01,  -9.95535731e-01,
                          2.40868509e-01,   8.94683421e-01,  -6.14448071e-01,
                         -6.38595760e-01,   8.80681813e-01,   2.70900965e-01,
                         -9.94115233e-01,   1.43465906e-01,   9.33847427e-01,
                         -5.33279240e-01,  -7.11444795e-01,   8.29951286e-01,
                          3.65056813e-01,  -9.82548714e-01,   4.44399342e-02,
                          9.63676929e-01,  -4.46834415e-01,  -7.77394474e-01,
                          7.70900965e-01,   4.55560058e-01,  -9.61241901e-01,
                         -5.47889620e-02,   9.83766258e-01,  -3.55925322e-01,
                         -8.35633099e-01,   7.04342544e-01,   5.41396081e-01,
                         -9.30600643e-01,  -1.53612018e-01,   9.94318187e-01,
                         -2.61363626e-01,  -8.85349035e-01,   6.30681813e-01,
                          6.21956170e-01,  -8.90422106e-01,  -2.50811696e-01,
                          9.94926929e-01,  -1.64366886e-01,  -9.26542222e-01,
                          5.50730526e-01,   6.96428597e-01,  -8.41517866e-01,
                         -3.45576286e-01,   9.85389590e-01,  -6.57467544e-02,
                         -9.58198071e-01,   4.65300322e-01,   7.63798714e-01,
                         -7.84293830e-01,  -4.36891228e-01,   9.66314912e-01,
                          3.34821418e-02,  -9.80519474e-01,   3.75202924e-01,
                          8.23660731e-01,  -7.19155848e-01,  -5.23944795e-01,
                          9.37500000e-01,   1.32508114e-01,  -9.93100643e-01,
                          2.81452924e-01,   8.75405848e-01,  -6.46915555e-01,
                         -6.05722427e-01,   8.99350643e-01,   2.30316564e-01,
                         -9.95738626e-01,   1.84862018e-01,   9.18222427e-01,
                         -5.68181813e-01,  -6.81412339e-01,   8.52272749e-01,
                          3.25689942e-01,  -9.88636374e-01,   8.64448026e-02,
                          9.52110410e-01,  -4.83969152e-01,  -7.50405848e-01,
                          7.96875000e-01,   4.17816550e-01,  -9.71387982e-01,
                         -1.29870130e-02,   9.76461053e-01,  -3.94683450e-01,
                         -8.12094152e-01,   7.33360410e-01,   5.05884767e-01,
                         -9.44805205e-01,  -1.12012990e-01,   9.91071403e-01,
                         -3.01745117e-01,  -8.65462661e-01,   6.62540555e-01,
                          5.88879883e-01,  -9.08482134e-01,  -2.10024357e-01,
                          9.95941579e-01,  -2.05560058e-01,  -9.10308421e-01,
                          5.85227251e-01,   6.65990233e-01,  -8.63433421e-01,
                         -3.06006491e-01,   9.90868509e-01,  -1.07548699e-01,
                         -9.46225643e-01,   5.02029240e-01,   7.36404240e-01,
                         -8.09659064e-01,  -3.98944795e-01,   9.75852251e-01,
                         -8.31980538e-03,  -9.72605526e-01,   4.13758129e-01,
                          7.99512982e-01,  -7.47767866e-01,  -4.88027602e-01,
                          9.51095760e-01,   9.09090936e-02,  -9.89245117e-01,
                          3.21428567e-01,   8.54910731e-01,  -6.78368509e-01,
                         -5.72037339e-01,   9.17004883e-01,   1.89326301e-01,
                         -9.96144474e-01,   2.26055190e-01,   9.01582778e-01,
                         -6.02475643e-01,  -6.50365233e-01,   8.73579562e-01,
                          2.85714298e-01,  -9.93100643e-01,   1.28246754e-01,
                          9.39326286e-01,  -5.20292222e-01,  -7.22402573e-01,
                          8.21631491e-01,   3.79464298e-01,  -9.80113626e-01,
                          2.92207785e-02,   9.67735410e-01,  -4.33238626e-01,
                         -7.87134767e-01,   7.61363626e-01,   4.69358772e-01,
                         -9.57589269e-01,  -7.02110380e-02,   9.86404240e-01,
                         -3.41720790e-01,  -8.44155848e-01,   6.93587661e-01,
                          5.54586053e-01,  -9.25324678e-01,  -1.68831170e-01,
                          9.95535731e-01,  -2.46753246e-01,  -8.92654240e-01,
                          6.18912339e-01,   6.34131491e-01,  -8.83928597e-01,
                         -2.65827924e-01,   9.94521081e-01,  -1.49350643e-01,
                         -9.32426929e-01,   5.38149357e-01,   7.07589269e-01,
                         -8.33603919e-01,  -3.60186696e-01,   9.83766258e-01,
                         -5.05275987e-02,  -9.62865233e-01,   4.51907456e-01,
                          7.73944795e-01,  -7.75162339e-01,  -4.50892866e-01,
                          9.63068187e-01,   4.89042215e-02,  -9.83766258e-01,
                          3.61201286e-01,   8.32589269e-01,  -7.09009767e-01,
                         -5.37134767e-01,   9.32832778e-01,   1.47727266e-01,
                         -9.94724035e-01,   2.67045468e-01,   8.83116901e-01,
                         -6.35754883e-01,  -6.18100643e-01,   8.93465936e-01,
                          2.45129868e-01,  -9.95941579e-01,   1.70048699e-01,
                          9.24715936e-01,  -5.56209445e-01,  -6.92775965e-01,
                          8.44967544e-01,   3.40097398e-01,  -9.87215936e-01,
                          7.14285746e-02,   9.56980526e-01,  -4.70982134e-01,
                         -7.60754883e-01,   7.88149357e-01,   4.31615263e-01,
                         -9.68547106e-01,  -2.78003253e-02,   9.79910731e-01,
                         -3.81290585e-01,  -8.21022749e-01,   7.23620117e-01,
                          5.18871725e-01,  -9.40340936e-01,  -1.26826301e-01,
                          9.93100643e-01,  -2.87743509e-01,  -8.73173714e-01,
                          6.51785731e-01,   6.01055205e-01,  -9.02800322e-01,
                         -2.24634737e-01,   9.96347427e-01,  -1.91355526e-01,
                         -9.16801929e-01,   5.73457778e-01,   6.77150965e-01,
                         -8.56331170e-01,  -3.20211053e-01,   9.89650965e-01,
                         -9.29383114e-02,  -9.51095760e-01,   4.89448041e-01,
                          7.46550322e-01,  -8.01339269e-01,  -4.12540585e-01,
                          9.73214269e-01,   6.29058434e-03,  -9.76055205e-01,
                          4.00568187e-01,   8.08644474e-01,  -7.38230526e-01,
                         -5.00811696e-01,   9.47037339e-01,   1.05519481e-01,
                         -9.91274357e-01,   3.07832778e-01,   8.62621725e-01,
                         -6.68019474e-01,  -5.84009767e-01,   9.11525965e-01,
                          2.03530848e-01,  -9.96753275e-01,   2.12053567e-01,
                          9.07873392e-01,  -5.91112018e-01,  -6.61525965e-01,
                          8.66883099e-01,   2.99715906e-01,  -9.92086053e-01,
                          1.14042208e-01,   9.44196403e-01,  -5.08116901e-01,
                         -7.32345760e-01,   8.13514590e-01,   3.92654210e-01,
                         -9.77678597e-01,   1.48133114e-02,   9.71185088e-01,
                         -4.20251638e-01,  -7.96063304e-01,   7.52232134e-01,
                          4.81939942e-01,  -9.53530848e-01,  -8.44155848e-02,
                          9.88433421e-01,  -3.28327924e-01,  -8.51663947e-01,
                          6.83441579e-01,   5.66355526e-01,  -9.20048714e-01,
                         -1.82832792e-01,   9.95941579e-01,  -2.32954547e-01,
                         -8.98944795e-01,   6.07751608e-01,   6.45089269e-01,
                         -8.77232134e-01,  -2.79423714e-01,   9.93506491e-01,
                         -1.35349020e-01,  -9.37297106e-01,   5.26176929e-01,
                          7.17329562e-01,  -8.25689912e-01,  -3.73173714e-01,
                          9.81331170e-01,  -3.63230519e-02,  -9.66314912e-01,
                          4.39326286e-01,   7.82670438e-01,  -7.66030848e-01,
                         -4.63271111e-01,   9.59212661e-01,   6.29058406e-02,
                         -9.85592544e-01,   3.48011374e-01,   8.40097427e-01,
                         -6.98863626e-01,  -5.48701286e-01,   9.27556813e-01,
                          1.61525980e-01,  -9.95129883e-01,   2.53449678e-01,
                          8.89204562e-01,  -6.24594152e-01,  -6.28855526e-01,
                          8.86769474e-01,   2.58725643e-01,  -9.94926929e-01,
                          1.56250000e-01,   9.29586053e-01,  -5.44237018e-01,
                         -7.02719152e-01,   8.37256491e-01,   3.53084415e-01,
                         -9.84780848e-01,   5.74269481e-02,   9.60633099e-01,
                         -4.58400965e-01,  -7.69480526e-01,   7.79220760e-01,
                          4.44196433e-01,  -9.64894474e-01,  -4.18019481e-02,
                          9.81939912e-01,  -3.68100643e-01,  -8.28733742e-01,
                          7.13676929e-01,   5.30641258e-01,  -9.35267866e-01,
                         -1.40625000e-01,   9.93709445e-01,  -2.74147719e-01,
                         -8.79667222e-01,   6.40827894e-01,   6.12012982e-01,
                         -8.96509767e-01,  -2.38230526e-01,   9.95535731e-01,
                         -1.77353889e-01,  -9.21672106e-01,   5.61688304e-01,
                          6.87094152e-01,  -8.48620117e-01,  -3.33400965e-01,
                          9.87621725e-01,  -7.89366886e-02,  -9.54748392e-01,
                          4.77069795e-01,   7.55478919e-01,  -7.92410731e-01,
                         -4.25121754e-01,   9.69764590e-01,   2.02922076e-02,
                         -9.78287339e-01,   3.87581170e-01,   8.16355526e-01,
                         -7.28490233e-01,  -5.12784064e-01,   9.42167222e-01,
                          1.19521104e-01,  -9.92288947e-01,   2.94237018e-01,
                          8.69115233e-01,  -6.57264590e-01,  -5.95170438e-01,
                          9.05235410e-01,   2.17329547e-01,  -9.96144474e-01,
                          1.98051944e-01,   9.13352251e-01,  -5.79342544e-01,
                         -6.71875000e-01,   8.59375000e-01,   3.13108772e-01,
                         -9.90259767e-01,   9.98376608e-02,   9.48457778e-01,
                         -4.95738626e-01,  -7.41680205e-01,   8.04991901e-01,
                          4.05641228e-01,  -9.74634767e-01,   8.11688311e-04,
                          9.74025965e-01,  -4.07264620e-01,  -8.04383099e-01,
                          7.42694795e-01,   4.94318187e-01,  -9.49066579e-01,
                         -9.84172076e-02,   9.90056813e-01,  -3.14732134e-01,
                         -8.58766258e-01,   6.72889590e-01,   5.77922106e-01,
                         -9.14366901e-01,  -1.96631491e-01,   9.96144474e-01,
                         -2.19155848e-01,  -9.04829562e-01,   5.96387982e-01,
                          6.55844152e-01,  -8.70332778e-01,  -2.93019474e-01,
                          9.92288947e-01,  -1.21347405e-01,  -9.41964269e-01,
                          5.14001608e-01,   7.27272749e-01,  -8.17775965e-01,
                         -3.86363626e-01,   9.78693187e-01,  -2.21185070e-02,
                         -9.69561696e-01,   4.26542222e-01,   7.91396081e-01,
                         -7.56899357e-01,  -4.75852281e-01,   9.55357134e-01,
                          7.71103874e-02,  -9.87621725e-01,   3.34821433e-01,
                          8.47808421e-01,  -6.88717544e-01,  -5.60673714e-01,
                          9.22483742e-01,   1.75730526e-01,  -9.95941579e-01,
                          2.39650980e-01,   8.95698071e-01,  -6.13636374e-01,
                         -6.40016258e-01,   8.80478919e-01,   2.72524357e-01,
                         -9.94318187e-01,   1.42248377e-01,   9.34862018e-01,
                         -5.32467544e-01,  -7.12865233e-01,   8.29545438e-01,
                          3.66477281e-01,  -9.82751608e-01,   4.32224013e-02,
                          9.64488626e-01,  -4.45819795e-01,  -7.78814912e-01,
                          7.70698071e-01,   4.56980526e-01,  -9.61444795e-01,
                         -5.60064949e-02,   9.84780848e-01,  -3.54910702e-01,
                         -8.36850643e-01,   7.03936696e-01,   5.43019474e-01,
                         -9.30600643e-01,  -1.54829547e-01,   9.95129883e-01,
                         -2.60551959e-01,  -8.86566579e-01,   6.30275965e-01,
                          6.23579562e-01,  -8.90625000e-01,  -2.52232134e-01,
                          9.95535731e-01,  -1.63352266e-01,  -9.27556813e-01,
                          5.50324678e-01,   6.97849035e-01,  -8.41720760e-01,
                         -3.46996754e-01,   9.86201286e-01,  -6.47321418e-02,
                         -9.59415555e-01,   4.64894474e-01,   7.65219152e-01,
                         -7.84293830e-01,  -4.38311696e-01,   9.66923714e-01,
                          3.46996747e-02,  -9.81737018e-01,   3.74797076e-01,
                          8.25081170e-01,  -7.19155848e-01,  -5.25162339e-01,
                          9.38108742e-01,   1.33725643e-01,  -9.94115233e-01,
                          2.80844152e-01,   8.76623392e-01,  -6.46915555e-01,
                         -6.06939912e-01,   8.99959445e-01,   2.31331170e-01,
                         -9.96753275e-01,   1.84253246e-01,   9.19642866e-01,
                         -5.68181813e-01,  -6.82832778e-01,   8.52881491e-01,
                          3.26704532e-01,  -9.89448071e-01,   8.58360380e-02,
                          9.53327894e-01,  -4.83766228e-01,  -7.51826286e-01,
                          7.97077894e-01,   4.19034094e-01,  -9.72199678e-01,
                         -1.35957794e-02,   9.77678597e-01,  -3.94480526e-01,
                         -8.13311696e-01,   7.33563304e-01,   5.07102251e-01,
                         -9.45413947e-01,  -1.12824678e-01,   9.92288947e-01,
                         -3.01339298e-01,  -8.66680205e-01,   6.62743509e-01,
                          5.90097427e-01,  -9.09090936e-01,  -2.11038962e-01,
                          9.96956170e-01,  -2.05154225e-01,  -9.11525965e-01,
                          5.85227251e-01,   6.67207778e-01,  -8.63839269e-01,
                         -3.07021111e-01,   9.91680205e-01,  -1.06939934e-01,
                         -9.47240233e-01,   5.02029240e-01,   7.37621725e-01,
                         -8.09862018e-01,  -3.99959415e-01,   9.76663947e-01,
                         -7.71103892e-03,  -9.73620117e-01,   4.13758129e-01,
                          8.00730526e-01,  -7.47970760e-01,  -4.88839298e-01,
                          9.51704562e-01,   9.15178582e-02,  -9.90259767e-01,
                          3.21225643e-01,   8.55925322e-01,  -6.78571403e-01,
                         -5.73051929e-01,   9.17410731e-01,   1.89935058e-01,
                         -9.96956170e-01,   2.25649357e-01,   9.02597427e-01,
                         -6.02475643e-01,  -6.51379883e-01,   8.73985410e-01,
                          2.86525965e-01,  -9.93709445e-01,   1.27840906e-01,
                          9.40137982e-01,  -5.20292222e-01,  -7.23417222e-01,
                          8.21834445e-01,   3.80275965e-01,  -9.80722427e-01,
                          2.88149342e-02,   9.68547106e-01,  -4.33035702e-01,
                         -7.87946403e-01,   7.61566579e-01,   4.70170468e-01,
                         -9.57792222e-01,  -7.06168860e-02,   9.87012982e-01,
                         -3.41314942e-01,  -8.44967544e-01,   6.93587661e-01,
                          5.55397749e-01,  -9.25527573e-01,  -1.69439942e-01,
                          9.95941579e-01,  -2.46347398e-01,  -8.93465936e-01,
                          6.18709445e-01,   6.34943187e-01,  -8.83928597e-01,
                         -2.66436696e-01,   9.94926929e-01,  -1.48741886e-01,
                         -9.33035731e-01,   5.37743509e-01,   7.08400965e-01,
                         -8.33603919e-01,  -3.60795468e-01,   9.83766258e-01,
                         -4.99188304e-02,  -9.63271081e-01,   4.51501638e-01,
                          7.74553597e-01,  -7.74959445e-01,  -4.51501638e-01,
                          9.63068187e-01,   4.95129861e-02,  -9.83969152e-01,
                          3.60795468e-01,   8.33198071e-01,  -7.08603919e-01,
                         -5.37743509e-01,   9.32832778e-01,   1.48336038e-01,
                         -9.94926929e-01,   2.66436696e-01,   8.83319795e-01,
                         -6.35349035e-01,  -6.18506491e-01,   8.93262982e-01,
                          2.45738640e-01,  -9.95941579e-01,   1.69642851e-01,
                          9.24918830e-01,  -5.55803597e-01,  -6.93181813e-01,
                          8.44764590e-01,   3.40503246e-01,  -9.87012982e-01,
                          7.10227266e-02,   9.56980526e-01,  -4.70576286e-01,
                         -7.60957778e-01,   7.87743509e-01,   4.32021111e-01,
                         -9.68141258e-01,  -2.82061696e-02,   9.79707778e-01,
                         -3.80884737e-01,  -8.21022749e-01,   7.23011374e-01,
                          5.19074678e-01,  -9.39935088e-01,  -1.27232149e-01,
                          9.92694795e-01,  -2.87134737e-01,  -8.72970760e-01,
                          6.51176929e-01,   6.01055205e-01,  -9.02191579e-01,
                         -2.24837661e-01,   9.95738626e-01,  -1.90949678e-01,
                         -9.16396081e-01,   5.72849035e-01,   6.76948071e-01,
                         -8.55722427e-01,  -3.20211053e-01,   9.89042222e-01,
                         -9.25324708e-02,  -9.50487018e-01,   4.89042222e-01,
                          7.46347427e-01,  -8.00527573e-01,  -4.12540585e-01,
                          9.72402573e-01,   6.49350649e-03,  -9.75446403e-01,
                          4.00162339e-01,   8.08238626e-01,  -7.37824678e-01,
                         -5.00608742e-01,   9.46428597e-01,   1.05519481e-01,
                         -9.90665555e-01,   3.07629883e-01,   8.62012982e-01,
                         -6.67613626e-01,  -5.83806813e-01,   9.10917222e-01,
                          2.03327924e-01,  -9.96144474e-01,   2.12053567e-01,
                          9.07467544e-01,  -5.91112018e-01,  -6.61120117e-01,
                          8.66680205e-01,   2.99107134e-01,  -9.91883099e-01,
                          1.14650972e-01,   9.43790555e-01,  -5.08928597e-01,
                         -7.31737018e-01,   8.14123392e-01,   3.91842544e-01,
                         -9.77678597e-01,   1.56250000e-02,   9.70982134e-01,
                         -4.20860380e-01,  -7.95860410e-01,   7.52435088e-01,
                          4.81737018e-01,  -9.53733742e-01,  -8.42126608e-02,
                          9.88433421e-01,  -3.28530848e-01,  -8.51866901e-01,
                          6.83441579e-01,   5.66355526e-01,  -9.20048714e-01,
                         -1.82832792e-01,   9.96144474e-01,  -2.32954547e-01,
                         -8.99147749e-01,   6.07751608e-01,   6.45292222e-01,
                         -8.77435088e-01,  -2.79626638e-01,   9.93709445e-01,
                         -1.35146111e-01,  -9.37702894e-01,   5.26176929e-01,
                          7.17735410e-01,  -8.25892866e-01,  -3.73579532e-01,
                          9.81534064e-01,  -3.61201316e-02,  -9.66517866e-01,
                          4.39123362e-01,   7.83076286e-01,  -7.66233742e-01,
                         -4.63676959e-01,   9.59415555e-01,   6.31087646e-02,
                         -9.85998392e-01,   3.48011374e-01,   8.40503275e-01,
                         -6.98863626e-01,  -5.49107134e-01,   9.27759767e-01,
                          1.61728889e-01,  -9.95535731e-01,   2.53246754e-01,
                          8.89610410e-01,  -6.24594152e-01,  -6.29261374e-01,
                          8.86972427e-01,   2.58928567e-01,  -9.95129883e-01,
                          1.56047076e-01,   9.29788947e-01,  -5.44237018e-01,
                         -7.02922106e-01,   8.37256491e-01,   3.53287339e-01,
                         -9.84983742e-01,   5.72240278e-02,   9.60836053e-01,
                         -4.58400965e-01,  -7.69683421e-01,   7.79220760e-01,
                          4.44399357e-01,  -9.64894474e-01,  -4.20048684e-02,
                          9.82142866e-01,  -3.68100643e-01,  -8.28936696e-01,
                          7.13676929e-01,   5.30844152e-01,  -9.35470760e-01,
                         -1.40827924e-01,   9.93912339e-01,  -2.74147719e-01,
                         -8.79870117e-01,   6.40827894e-01,   6.12215936e-01,
                         -8.96509767e-01,  -2.38433436e-01,   9.95738626e-01,
                         -1.77353889e-01,  -9.22077894e-01,   5.61688304e-01,
                          6.87297106e-01,  -8.48823071e-01,  -3.33400965e-01,
                          9.87621725e-01,  -7.89366886e-02,  -9.55154240e-01,
                          4.77069795e-01,   7.55681813e-01,  -7.92816579e-01,
                         -4.25324678e-01,   9.69967544e-01,   2.02922076e-02,
                         -9.78693187e-01,   3.87784094e-01,   8.16558421e-01,
                         -7.28693187e-01,  -5.12784064e-01,   9.42370117e-01,
                          1.19318180e-01,  -9.92491901e-01,   2.94439942e-01,
                          8.69318187e-01,  -6.57467544e-01,  -5.95373392e-01,
                          9.05641258e-01,   2.17329547e-01,  -9.96550322e-01,
                          1.98254868e-01,   9.13555205e-01,  -5.79748392e-01,
                         -6.71875000e-01,   8.59780848e-01,   3.12905848e-01,
                         -9.90665555e-01,   1.00040585e-01,   9.48660731e-01,
                         -4.96144474e-01,  -7.41883099e-01,   8.05397749e-01,
                          4.05641228e-01,  -9.74837661e-01,   8.11688311e-04,
                          9.74228919e-01,  -4.07670468e-01,  -8.04586053e-01,
                          7.42897749e-01,   4.94318187e-01,  -9.49472427e-01,
                         -9.84172076e-02,   9.90259767e-01,  -3.14935058e-01,
                         -8.59172106e-01,   6.73092544e-01,   5.77922106e-01,
                         -9.14569795e-01,  -1.96631491e-01,   9.96347427e-01,
                         -2.19358772e-01,  -9.05235410e-01,   5.96590936e-01,
                          6.56047106e-01,  -8.70738626e-01,  -2.93019474e-01,
                          9.92694795e-01,  -1.21347405e-01,  -9.42370117e-01,
                          5.14204562e-01,   7.27475643e-01,  -8.17978919e-01,
                         -3.86566550e-01,   9.79099035e-01,  -2.23214291e-02,
                         -9.70170438e-01,   4.26745117e-01,   7.91801929e-01,
                         -7.57305205e-01,  -4.76055205e-01,   9.55762982e-01,
                          7.71103874e-02,  -9.88230526e-01,   3.34821433e-01,
                          8.48214269e-01,  -6.89123392e-01,  -5.61079562e-01,
                          9.22889590e-01,   1.75730526e-01,  -9.96347427e-01,
                          2.39650980e-01,   8.96103919e-01,  -6.13839269e-01,
                         -6.40219152e-01,   8.80681813e-01,   2.72524357e-01,
                         -9.94724035e-01,   1.42248377e-01,   9.35064912e-01,
                         -5.32670438e-01,  -7.13271081e-01,   8.29951286e-01,
                          3.66680205e-01,  -9.83157456e-01,   4.32224013e-02,
                          9.64894474e-01,  -4.46022719e-01,  -7.79017866e-01,
                          7.70900965e-01,   4.57183450e-01,  -9.61850643e-01,
                         -5.62094152e-02,   9.84983742e-01,  -3.55113626e-01,
                         -8.37053597e-01,   7.03936696e-01,   5.43019474e-01,
                         -9.31006491e-01,  -1.55032471e-01,   9.95332778e-01,
                         -2.60551959e-01,  -8.86972427e-01,   6.30275965e-01,
                          6.23579562e-01,  -8.90625000e-01,  -2.52435058e-01,
                          9.95738626e-01,  -1.63352266e-01,  -9.27759767e-01,
                          5.50121725e-01,   6.98051929e-01,  -8.41720760e-01,
                         -3.47199678e-01,   9.86201286e-01,  -6.45292178e-02,
                         -9.59415555e-01,   4.64488626e-01,   7.65422106e-01,
                         -7.84090936e-01,  -4.38514620e-01,   9.66720760e-01,
                          3.49025987e-02,  -9.81534064e-01,   3.74391228e-01,
                          8.25081170e-01,  -7.18952894e-01,  -5.25365233e-01,
                          9.37905848e-01,   1.33928567e-01,  -9.93912339e-01,
                          2.80438304e-01,   8.76623392e-01,  -6.46509767e-01,
                         -6.07142866e-01,   8.99553597e-01,   2.31534094e-01,
                         -9.96550322e-01,   1.83847398e-01,   9.19439912e-01,
                         -5.67775965e-01,  -6.82832778e-01,   8.52272749e-01,
                          3.26907456e-01,  -9.89042222e-01,   8.54301974e-02,
                          9.53125000e-01,  -4.83360380e-01,  -7.51826286e-01,
                          7.96672106e-01,   4.19034094e-01,  -9.71793830e-01,
                         -1.40016237e-02,   9.77272749e-01,  -3.94074678e-01,
                         -8.13108742e-01,   7.32954562e-01,   5.06899357e-01,
                         -9.44805205e-01,  -1.13027595e-01,   9.91680205e-01,
                         -3.00933450e-01,  -8.66477251e-01,   6.62134767e-01,
                          5.89894474e-01,  -9.08482134e-01,  -2.11241886e-01,
                          9.96347427e-01,  -2.04748377e-01,  -9.11120117e-01,
                          5.84618509e-01,   6.66801929e-01,  -8.63230526e-01,
                         -3.07021111e-01,   9.90868509e-01,  -1.06737010e-01,
                         -9.46631491e-01,   5.01420438e-01,   7.37215936e-01,
                         -8.09253275e-01,  -3.99959415e-01,   9.75852251e-01,
                         -7.50811677e-03,  -9.73011374e-01,   4.13149357e-01,
                          8.00121725e-01,  -7.47362018e-01,  -4.88636374e-01,
                          9.50892866e-01,   9.17207822e-02,  -9.89448071e-01,
                          3.20819795e-01,   8.55316579e-01,  -6.77962661e-01,
                         -5.72646081e-01,   9.16599035e-01,   1.89935058e-01,
                         -9.96144474e-01,   2.25243509e-01,   9.01785731e-01,
                         -6.01866901e-01,  -6.50974035e-01,   8.73173714e-01,
                          2.86323041e-01,  -9.93100643e-01,   1.27637982e-01,
                          9.39326286e-01,  -5.19886374e-01,  -7.22808421e-01,
                          8.21225643e-01,   3.79870117e-01,  -9.79910731e-01,
                          2.86120139e-02,   9.67735410e-01,  -4.32629883e-01,
                         -7.87337661e-01,   7.60957778e-01,   4.69561696e-01,
                         -9.57183421e-01,  -7.06168860e-02,   9.86404240e-01,
                         -3.41314942e-01,  -8.44155848e-01,   6.93181813e-01,
                          5.54788947e-01,  -9.24918830e-01,  -1.69034094e-01,
                          9.95129883e-01,  -2.46347398e-01,  -8.92654240e-01,
                          6.18506491e-01,   6.34334445e-01,  -8.83522749e-01,
                         -2.66030848e-01,   9.94115233e-01,  -1.49147734e-01,
                         -9.32224035e-01,   5.37743509e-01,   7.07589269e-01,
                         -8.33400965e-01,  -3.60186696e-01,   9.83360410e-01,
                         -5.03246747e-02,  -9.62662339e-01,   4.51704532e-01,
                          7.73741901e-01,  -7.74959445e-01,  -4.50689942e-01,
                          9.62662339e-01,   4.89042215e-02,  -9.83360410e-01,
                          3.61201286e-01,   8.32386374e-01,  -7.08806813e-01,
                         -5.36931813e-01,   9.32426929e-01,   1.47524357e-01,
                         -9.94318187e-01,   2.67045468e-01,   8.82711053e-01,
                         -6.35551929e-01,  -6.17694795e-01,   8.93060088e-01,
                          2.44926944e-01,  -9.95535731e-01,   1.70048699e-01,
                          9.24107134e-01,  -5.56006491e-01,  -6.92573071e-01,
                          8.44764590e-01,   3.39691550e-01,  -9.86810088e-01,
                          7.16314912e-02,   9.56574678e-01,  -4.70982134e-01,
                         -7.60349035e-01,   7.87946403e-01,   4.31209415e-01,
                         -9.68344152e-01,  -2.75974032e-02,   9.79504883e-01,
                         -3.81290585e-01,  -8.20616901e-01,   7.23417222e-01,
                          5.18465936e-01,  -9.40137982e-01,  -1.26623377e-01,
                          9.92694795e-01,  -2.87946433e-01,  -8.72970760e-01,
                          6.51785731e-01,   6.00649357e-01,  -9.02800322e-01,
                         -2.24228889e-01,   9.96144474e-01,  -1.91558436e-01,
                         -9.16396081e-01,   5.73660731e-01,   6.76745117e-01,
                         -8.56331170e-01,  -3.19805205e-01,   9.89448071e-01,
                         -9.31412354e-02,  -9.50892866e-01,   4.89650965e-01,
                          7.46347427e-01,  -8.01339269e-01,  -4.12134737e-01,
                          9.73214269e-01,   5.88474004e-03,  -9.75852251e-01,
                          4.00974035e-01,   8.08238626e-01,  -7.38433421e-01,
                         -5.00608742e-01,   9.47037339e-01,   1.05113633e-01,
                         -9.91274357e-01,   3.08035702e-01,   8.62418830e-01,
                         -6.68222427e-01,  -5.83806813e-01,   9.11525965e-01,
                          2.03327924e-01,  -9.96753275e-01,   2.12256491e-01,
                          9.07873392e-01,  -5.91314912e-01,  -6.61525965e-01,
                          8.67086053e-01,   2.99512982e-01,  -9.92288947e-01,
                          1.14245132e-01,   9.44399357e-01,  -5.08522749e-01,
                         -7.32345760e-01,   8.13920438e-01,   3.92654210e-01,
                         -9.78084445e-01,   1.50162335e-02,   9.71387982e-01,
                         -4.20657456e-01,  -7.96266258e-01,   7.52637982e-01,
                          4.81939942e-01,  -9.53936696e-01,  -8.42126608e-02,
                          9.88839269e-01,  -3.28530848e-01,  -8.52069795e-01,
                          6.83847427e-01,   5.66355526e-01,  -9.20454562e-01,
                         -1.82832792e-01,   9.96347427e-01,  -2.33157471e-01,
                         -8.99350643e-01,   6.08157456e-01,   6.45292222e-01,
                         -8.77840936e-01,  -2.79423714e-01,   9.94115233e-01,
                         -1.35551944e-01,  -9.37905848e-01,   5.26379883e-01,
                          7.17938304e-01,  -8.26298714e-01,  -3.73376638e-01,
                          9.81939912e-01,  -3.63230519e-02,  -9.66923714e-01,
                          4.39529210e-01,   7.83279240e-01,  -7.66639590e-01,
                         -4.63676959e-01,   9.59821403e-01,   6.31087646e-02,
                         -9.86404240e-01,   3.48214298e-01,   8.40706170e-01,
                         -6.99269474e-01,  -5.49310088e-01,   9.28165555e-01,
                          1.61931813e-01,  -9.95941579e-01,   2.53449678e-01,
                          8.90016258e-01,  -6.25000000e-01,  -6.29464269e-01,
                          8.87378275e-01,   2.59131491e-01,  -9.95738626e-01,
                          1.56047076e-01,   9.30397749e-01,  -5.44439912e-01,
                         -7.03327894e-01,   8.37662339e-01,   3.53693187e-01,
                         -9.85592544e-01,   5.72240278e-02,   9.61444795e-01,
                         -4.58400965e-01,  -7.70292222e-01,   7.79626608e-01,
                          4.44805205e-01,  -9.65503275e-01,  -4.22077924e-02,
                          9.82954562e-01,  -3.67897719e-01,  -8.29545438e-01,
                          7.13879883e-01,   5.31452894e-01,  -9.35876608e-01,
                         -1.41233772e-01,   9.94521081e-01,  -2.73741871e-01,
                         -8.80478919e-01,   6.40827894e-01,   6.12824678e-01,
                         -8.96915555e-01,  -2.38839284e-01,   9.96347427e-01,
                         -1.76948056e-01,  -9.22686696e-01,   5.61688304e-01,
                          6.88108742e-01,  -8.49025965e-01,  -3.34212661e-01,
                          9.88230526e-01,  -7.83279240e-02,  -9.55762982e-01,
                          4.76663947e-01,   7.56493509e-01,  -7.92613626e-01,
                         -4.25933450e-01,   9.70170438e-01,   2.11038962e-02,
                         -9.79099035e-01,   3.87175322e-01,   8.17370117e-01,
                         -7.28490233e-01,  -5.13595760e-01,   9.42573071e-01,
                          1.20332792e-01,  -9.92897749e-01,   2.93628246e-01,
                          8.69926929e-01,  -6.56858742e-01,  -5.96185088e-01,
                          9.05438304e-01,   2.18141228e-01,  -9.96753275e-01,
                          1.97240263e-01,   9.13961053e-01,  -5.78936696e-01,
                         -6.72686696e-01,   8.59375000e-01,   3.13920468e-01,
                         -9.90665555e-01,   9.90259722e-02,   9.48863626e-01,
                         -4.95129883e-01,  -7.42491901e-01,   8.04788947e-01,
                          4.06452924e-01,  -9.74634767e-01,  -2.02922078e-04,
                          9.74431813e-01,  -4.06452924e-01,  -8.04991901e-01,
                          7.42288947e-01,   4.95129883e-01,  -9.49066579e-01,
                         -9.94318202e-02,   9.90259767e-01,  -3.13920468e-01,
                         -8.59375000e-01,   6.72280848e-01,   5.78530848e-01,
                         -9.13961053e-01,  -1.97646111e-01,   9.96144474e-01,
                         -2.18141228e-01,  -9.05235410e-01,   5.95576286e-01,
                          6.56452894e-01,  -8.69724035e-01,  -2.93831170e-01,
                          9.92086053e-01,  -1.20332792e-01,  -9.42167222e-01,
                          5.13189912e-01,   7.27678597e-01,  -8.16964269e-01,
                         -3.86972398e-01,   9.78287339e-01,  -2.13068184e-02,
                         -9.69561696e-01,   4.25527602e-01,   7.91801929e-01,
                         -7.56087661e-01,  -4.76461053e-01,   9.54748392e-01,
                          7.79220760e-02,  -9.87418830e-01,   3.33806813e-01,
                          8.47808421e-01,  -6.87702894e-01,  -5.61079562e-01,
                          9.21672106e-01,   1.76339284e-01,  -9.95535731e-01,
                          2.38636360e-01,   8.95495117e-01,  -6.12621725e-01,
                         -6.40219152e-01,   8.79464269e-01,   2.72930205e-01,
                         -9.93709445e-01,   1.41233772e-01,   9.34456170e-01,
                         -5.31452894e-01,  -7.12865233e-01,   8.28733742e-01,
                          3.66883129e-01,  -9.81939912e-01,   4.26136367e-02,
                          9.63879883e-01,  -4.45008129e-01,  -7.78409064e-01,
                          7.69480526e-01,   4.57183450e-01,  -9.60633099e-01,
                         -5.66152595e-02,   9.83969152e-01,  -3.54099035e-01,
                         -8.36241901e-01,   7.02922106e-01,   5.42816579e-01,
                         -9.29586053e-01,  -1.55235395e-01,   9.94115233e-01,
                         -2.59740263e-01,  -8.85957778e-01,   6.29058421e-01,
                          6.23173714e-01,  -8.89407456e-01,  -2.52232134e-01,
                          9.94521081e-01,  -1.62743509e-01,  -9.26745117e-01,
                          5.49310088e-01,   6.97240233e-01,  -8.40503275e-01,
                         -3.46793830e-01,   9.84983742e-01,  -6.43263012e-02,
                         -9.58198071e-01,   4.63879883e-01,   7.64407456e-01,
                         -7.83076286e-01,  -4.37905848e-01,   9.65706170e-01,
                          3.49025987e-02,  -9.80316579e-01,   3.73985380e-01,
                          8.24066579e-01,  -7.18141258e-01,  -5.24553597e-01,
                          9.36891258e-01,   1.33522734e-01,  -9.92694795e-01,
                          2.80438304e-01,   8.75405848e-01,  -6.45900965e-01,
                         -6.06128275e-01,   8.98741901e-01,   2.30925322e-01,
                         -9.95332778e-01,   1.84050322e-01,   9.18222427e-01,
                         -5.67370117e-01,  -6.81615233e-01,   8.51663947e-01,
                          3.26095790e-01,  -9.87824678e-01,   8.58360380e-02,
                          9.51907456e-01,  -4.83157456e-01,  -7.50405848e-01,
                          7.96063304e-01,   4.18019474e-01,  -9.70779240e-01,
                         -1.33928573e-02,   9.76055205e-01,  -3.94074678e-01,
                         -8.11688304e-01,   7.32751608e-01,   5.05884767e-01,
                         -9.43993509e-01,  -1.12215906e-01,   9.90665555e-01,
                         -3.01136374e-01,  -8.65056813e-01,   6.61931813e-01,
                          5.88676929e-01,  -9.07873392e-01,  -2.10024357e-01,
                          9.95332778e-01,  -2.05357149e-01,  -9.09699678e-01,
                          5.84821403e-01,   6.65584445e-01,  -8.62824678e-01,
                         -3.05803567e-01,   9.90259767e-01,  -1.07345782e-01,
                         -9.45413947e-01,   5.01623392e-01,   7.35795438e-01,
                         -8.09050322e-01,  -3.98538947e-01,   9.75243509e-01,
                         -8.31980538e-03,  -9.71793830e-01,   4.13555205e-01,
                          7.98904240e-01,  -7.47362018e-01,  -4.87418830e-01,
                          9.50487018e-01,   9.07061696e-02,  -9.88433421e-01,
                          3.21428567e-01,   8.54099035e-01,  -6.78165555e-01,
                         -5.71225643e-01,   9.16396081e-01,   1.88920453e-01,
                         -9.95332778e-01,   2.26055190e-01,   9.00771081e-01,
                         -6.02272749e-01,  -6.49553597e-01,   8.73173714e-01,
                          2.85105526e-01,  -9.92288947e-01,   1.28449678e-01,
                          9.38514590e-01,  -5.20292222e-01,  -7.21387982e-01,
                          8.21225643e-01,   3.78652602e-01,  -9.79504883e-01,
                          2.96266228e-02,   9.66923714e-01,  -4.33238626e-01,
                         -7.86120117e-01,   7.61160731e-01,   4.68547076e-01,
                         -9.56777573e-01,  -6.96022734e-02,   9.85592544e-01,
                         -3.41720790e-01,  -8.43141258e-01,   6.93384767e-01,
                          5.53571403e-01,  -9.24715936e-01,  -1.68019474e-01,
                          9.94521081e-01,  -2.46956170e-01,  -8.91639590e-01,
                          6.18912339e-01,   6.33116901e-01,  -8.83319795e-01,
                         -2.65016228e-01,   9.93709445e-01,  -1.49756491e-01,
                         -9.31412339e-01,   5.38149357e-01,   7.06574678e-01,
                         -8.33198071e-01,  -3.59172076e-01,   9.82954562e-01,
                         -5.09334430e-02,  -9.61850643e-01,   4.52110380e-01,
                          7.72930205e-01,  -7.74756491e-01,  -4.49878246e-01,
                          9.62256491e-01,   4.82954532e-02,  -9.82548714e-01,
                          3.61404210e-01,   8.31574678e-01,  -7.08603919e-01,
                         -5.36120117e-01,   9.32224035e-01,   1.46915585e-01,
                         -9.93709445e-01,   2.67248362e-01,   8.81899357e-01,
                         -6.35551929e-01,  -6.16883099e-01,   8.92654240e-01,
                          2.44318187e-01,  -9.94926929e-01,   1.70454547e-01,
                          9.23498392e-01,  -5.56006491e-01,  -6.91558421e-01,
                          8.44358742e-01,   3.39285702e-01,  -9.86201286e-01,
                          7.18344152e-02,   9.55965936e-01,  -4.70982134e-01,
                         -7.59537339e-01,   7.87743509e-01,   4.30803567e-01,
                         -9.67735410e-01,  -2.73944810e-02,   9.78896081e-01,
                         -3.81290585e-01,  -8.19805205e-01,   7.23214269e-01,
                          5.17857134e-01,  -9.39529240e-01,  -1.26217529e-01,
                          9.91883099e-01,  -2.87743509e-01,  -8.71956170e-01,
                          6.51379883e-01,   6.00040555e-01,  -9.01988626e-01,
                         -2.24025980e-01,   9.95332778e-01,  -1.91355526e-01,
                         -9.15584445e-01,   5.73051929e-01,   6.76136374e-01,
                         -8.55519474e-01,  -3.19399357e-01,   9.88636374e-01,
                         -9.31412354e-02,  -9.49878275e-01,   4.89245117e-01,
                          7.45535731e-01,  -8.00527573e-01,  -4.11728889e-01,
                          9.72199678e-01,   6.08766219e-03,  -9.74837661e-01,
                          4.00365263e-01,   8.07426929e-01,  -7.37621725e-01,
                         -5.00000000e-01,   9.46022749e-01,   1.05113633e-01,
                         -9.90056813e-01,   3.07629883e-01,   8.61404240e-01,
                         -6.67410731e-01,  -5.83198071e-01,   9.10511374e-01,
                          2.03125000e-01,  -9.95535731e-01,   2.11850643e-01,
                          9.06858742e-01,  -5.90503275e-01,  -6.60511374e-01,
                          8.65868509e-01,   2.99107134e-01,  -9.91071403e-01,
                          1.14042208e-01,   9.43181813e-01,  -5.07711053e-01,
                         -7.31331170e-01,   8.12702894e-01,   3.92045468e-01,
                         -9.76663947e-01,   1.50162335e-02,   9.70170438e-01,
                         -4.20048714e-01,  -7.95048714e-01,   7.51623392e-01,
                          4.81331170e-01,  -9.52719152e-01,  -8.42126608e-02,
                          9.87418830e-01,  -3.28125000e-01,  -8.50649357e-01,
                          6.82832778e-01,   5.65543830e-01,  -9.19034064e-01,
                         -1.82426944e-01,   9.94926929e-01,  -2.32954547e-01,
                         -8.97930205e-01,   6.07345760e-01,   6.44277573e-01,
                         -8.76420438e-01,  -2.78814942e-01,   9.92694795e-01,
                         -1.35349020e-01,  -9.36282456e-01,   5.25771081e-01,
                          7.16517866e-01,  -8.25081170e-01,  -3.72564942e-01,
                          9.80316579e-01,  -3.65259722e-02,  -9.65300322e-01,
                          4.39123362e-01,   7.81858742e-01,  -7.65625000e-01,
                         -4.62662339e-01,   9.58400965e-01,   6.25000000e-02,
                         -9.84780848e-01,   3.48011374e-01,   8.39285731e-01,
                         -6.98457778e-01,  -5.47889590e-01,   9.26948071e-01,
                          1.61120132e-01,  -9.94318187e-01,   2.53449678e-01,
                          8.88392866e-01,  -6.24391258e-01,  -6.28043830e-01,
                          8.86363626e-01,   2.57913947e-01,  -9.94115233e-01,
                          1.56452924e-01,   9.28571403e-01,  -5.44237018e-01,
                         -7.01704562e-01,   8.36850643e-01,   3.52475643e-01,
                         -9.84172106e-01,   5.78327924e-02,   9.59618509e-01,
                         -4.58603889e-01,  -7.68465936e-01,   7.79017866e-01,
                          4.43181813e-01,  -9.64285731e-01,  -4.11931835e-02,
                          9.81331170e-01,  -3.68303567e-01,  -8.27719152e-01,
                          7.13474035e-01,   5.29829562e-01,  -9.34862018e-01,
                         -1.40016228e-01,   9.93100643e-01,  -2.74350643e-01,
                         -8.78652573e-01,   6.40827894e-01,   6.10998392e-01,
                         -8.96103919e-01,  -2.37418830e-01,   9.94926929e-01,
                         -1.77759737e-01,  -9.21063304e-01,   5.61891258e-01,
                          6.86282456e-01,  -8.48417222e-01,  -3.32589298e-01,
                          9.87012982e-01,  -7.93425292e-02,  -9.54139590e-01,
                          4.77272719e-01,   7.54667222e-01,  -7.92410731e-01,
                         -4.24310058e-01,   9.69358742e-01,   1.98863633e-02,
                         -9.77678597e-01,   3.87784094e-01,   8.15543830e-01,
                         -7.28287339e-01,  -5.11972427e-01,   9.41761374e-01,
                          1.18912339e-01,  -9.91680205e-01,   2.94439942e-01,
                          8.68506491e-01,  -6.57061696e-01,  -5.94561696e-01,
                          9.05032456e-01,   2.16923699e-01,  -9.95738626e-01,
                          1.98051944e-01,   9.12743509e-01,  -5.79139590e-01,
                         -6.71266258e-01,   8.58969152e-01,   3.12702924e-01,
                         -9.89853919e-01,   9.98376608e-02,   9.47849035e-01,
                         -4.95332778e-01,  -7.41274357e-01,   8.04586053e-01,
                          4.05641228e-01,  -9.74025965e-01,   4.05844155e-04,
                          9.73620117e-01,  -4.06655848e-01,  -8.04180205e-01,
                          7.41883099e-01,   4.94318187e-01,  -9.48457778e-01,
                         -9.92288962e-02,   9.89448071e-01,  -3.13717544e-01,
                         -8.58766258e-01,   6.71672106e-01,   5.78327894e-01,
                         -9.13352251e-01,  -1.97443187e-01,   9.95535731e-01,
                         -2.18344152e-01,  -9.04626608e-01,   5.95576286e-01,
                          6.55844152e-01,  -8.69724035e-01,  -2.93019474e-01,
                          9.91883099e-01,  -1.20941557e-01,  -9.41558421e-01,
                          5.13595760e-01,   7.26866901e-01,  -8.17370117e-01,
                         -3.85957778e-01,   9.78287339e-01,  -2.23214291e-02,
                         -9.69155848e-01,   4.26542222e-01,   7.90787339e-01,
                         -7.56899357e-01,  -4.75243509e-01,   9.55154240e-01,
                          7.65016228e-02,  -9.87418830e-01,   3.35024357e-01,
                          8.47199678e-01,  -6.88920438e-01,  -5.59862018e-01,
                          9.22483742e-01,   1.74715906e-01,  -9.95738626e-01,
                          2.40259737e-01,   8.95089269e-01,  -6.14042222e-01,
                         -6.39001608e-01,   8.80681813e-01,   2.71306813e-01,
                         -9.94115233e-01,   1.43060058e-01,   9.34050322e-01,
                         -5.33076286e-01,  -7.11850643e-01,   8.29951286e-01,
                          3.65259737e-01,  -9.82751608e-01,   4.42370139e-02,
                          9.63879883e-01,  -4.46834415e-01,  -7.77800322e-01,
                          7.71103919e-01,   4.55762982e-01,  -9.61647749e-01,
                         -5.49918823e-02,   9.84172106e-01,  -3.55925322e-01,
                         -8.35836053e-01,   7.04545438e-01,   5.41599035e-01,
                         -9.30803597e-01,  -1.53612018e-01,   9.94724035e-01,
                         -2.61566550e-01,  -8.85754883e-01,   6.30884767e-01,
                          6.22159064e-01,  -8.90827894e-01,  -2.51014620e-01,
                          9.95332778e-01,  -1.64569810e-01,  -9.26948071e-01,
                          5.50933421e-01,   6.96631491e-01,  -8.41923714e-01,
                         -3.45779210e-01,   9.85998392e-01,  -6.57467544e-02,
                         -9.58806813e-01,   4.65503246e-01,   7.64204562e-01,
                         -7.84699678e-01,  -4.37094152e-01,   9.66923714e-01,
                          3.34821418e-02,  -9.81128275e-01,   3.75405848e-01,
                          8.24066579e-01,  -7.19561696e-01,  -5.24147749e-01,
                          9.38108742e-01,   1.32711038e-01,  -9.93709445e-01,
                          2.81655848e-01,   8.75811696e-01,  -6.47321403e-01,
                         -6.06128275e-01,   8.99959445e-01,   2.30316564e-01,
                         -9.96347427e-01,   1.84862018e-01,   9.18831170e-01,
                         -5.68587661e-01,  -6.81818187e-01,   8.52881491e-01,
                          3.25892866e-01,  -9.89245117e-01,   8.64448026e-02,
                          9.52719152e-01,  -4.84172076e-01,  -7.51014590e-01,
                          7.97280848e-01,   4.18019474e-01,  -9.71996725e-01,
                         -1.29870130e-02,   9.77069795e-01,  -3.94886374e-01,
                         -8.12500000e-01,   7.33766258e-01,   5.06087661e-01,
                         -9.45211053e-01,  -1.12215906e-01,   9.91680205e-01,
                         -3.01745117e-01,  -8.66071403e-01,   6.62743509e-01,
                          5.89285731e-01,  -9.09090936e-01,  -2.10430190e-01,
                          9.96550322e-01,  -2.05560058e-01,  -9.10917222e-01,
                          5.85227251e-01,   6.66396081e-01,  -8.63636374e-01,
                         -3.06412339e-01,   9.91274357e-01,  -1.07345782e-01,
                         -9.46834445e-01,   5.02029240e-01,   7.37012982e-01,
                         -8.09862018e-01,  -3.99553567e-01,   9.76258099e-01,
                         -7.91396108e-03,  -9.73214269e-01,   4.13555205e-01,
                          8.00324678e-01,  -7.47767866e-01,  -4.88636374e-01,
                          9.51501608e-01,   9.15178582e-02,  -9.89853919e-01,
                          3.21225643e-01,   8.55519474e-01,  -6.78368509e-01,
                         -5.72646081e-01,   9.17207778e-01,   1.89935058e-01,
                         -9.96753275e-01,   2.25446433e-01,   9.02191579e-01,
                         -6.02272749e-01,  -6.51176929e-01,   8.73782456e-01,
                          2.86525965e-01,  -9.93506491e-01,   1.27637982e-01,
                          9.39935088e-01,  -5.20089269e-01,  -7.23214269e-01,
                          8.21631491e-01,   3.80275965e-01,  -9.80519474e-01,
                          2.84090918e-02,   9.68344152e-01,  -4.32629883e-01,
                         -7.88149357e-01,   7.61160731e-01,   4.70170468e-01,
                         -9.57792222e-01,  -7.10227266e-02,   9.87012982e-01,
                         -3.40909094e-01,  -8.44967544e-01,   6.93384767e-01,
                          5.55397749e-01,  -9.25527573e-01,  -1.69845775e-01,
                          9.95941579e-01,  -2.45941564e-01,  -8.93668830e-01,
                          6.18506491e-01,   6.35146081e-01,  -8.83928597e-01,
                         -2.66842544e-01,   9.94926929e-01,  -1.48336038e-01,
                         -9.33238626e-01,   5.37540555e-01,   7.08603919e-01,
                         -8.33603919e-01,  -3.61201286e-01,   9.83969152e-01,
                         -4.95129861e-02,  -9.63676929e-01,   4.51095790e-01,
                          7.74959445e-01,  -7.74756491e-01,  -4.52110380e-01,
                          9.63271081e-01,   5.01217544e-02,  -9.84375000e-01,
                          3.60186696e-01,   8.33603919e-01,  -7.08400965e-01,
                         -5.38352251e-01,   9.32832778e-01,   1.48944810e-01,
                         -9.95332778e-01,   2.65827924e-01,   8.84131491e-01,
                         -6.34943187e-01,  -6.19318187e-01,   8.93262982e-01,
                          2.46550322e-01,  -9.96347427e-01,   1.68831170e-01,
                          9.25527573e-01,  -5.55194795e-01,  -6.94196403e-01,
                          8.44764590e-01,   3.41517866e-01,  -9.87621725e-01,
                          7.00081140e-02,   9.57995117e-01,  -4.69967544e-01,
                         -7.62175322e-01,   7.87743509e-01,   4.33238626e-01,
                         -9.68952894e-01,  -2.94237006e-02,   9.80722427e-01,
                         -3.80073041e-01,  -8.22443187e-01,   7.23011374e-01,
                          5.20495117e-01,  -9.40543830e-01,  -1.28652602e-01,
                          9.93912339e-01,  -2.86323041e-01,  -8.74594152e-01,
                          6.50974035e-01,   6.02678597e-01,  -9.02800322e-01,
                         -2.26461038e-01,   9.96956170e-01,  -1.89732149e-01,
                         -9.18019474e-01,   5.72443187e-01,   6.78774357e-01,
                         -8.56128275e-01,  -3.22037339e-01,   9.90259767e-01,
                         -9.13149342e-02,  -9.52313304e-01,   4.88230526e-01,
                          7.48376608e-01,  -8.00933421e-01,  -4.14569795e-01,
                          9.73620117e-01,   8.11688323e-03,  -9.77272749e-01,
                          3.99350643e-01,   8.10267866e-01,  -7.37824678e-01,
                         -5.02840936e-01,   9.47240233e-01,   1.07345782e-01,
                         -9.92491901e-01,   3.06209415e-01,   8.64245117e-01,
                         -6.67207778e-01,  -5.86241901e-01,   9.11525965e-01,
                          2.05560058e-01,  -9.97767866e-01,   2.10227266e-01,
                          9.09496725e-01,  -5.90097427e-01,  -6.63555205e-01,
                          8.66680205e-01,   3.01745117e-01,  -9.93100643e-01,
                          1.12012990e-01,   9.45819795e-01,  -5.07102251e-01,
                         -7.34577894e-01,   8.13311696e-01,   3.94886374e-01,
                         -9.78490233e-01,   1.27840908e-02,   9.72808421e-01,
                         -4.19034094e-01,  -7.98092544e-01,   7.51826286e-01,
                          4.84172076e-01,  -9.54139590e-01,  -8.66477266e-02,
                          9.90056813e-01,  -3.26704532e-01,  -8.53896081e-01,
                          6.82832778e-01,   5.68790555e-01,  -9.20454562e-01,
                         -1.85064942e-01,   9.97362018e-01,  -2.31331170e-01,
                         -9.01176929e-01,   6.06939912e-01,   6.47524357e-01,
                         -8.77637982e-01,  -2.81858772e-01,   9.94926929e-01,
                         -1.33522734e-01,  -9.39326286e-01,   5.25162339e-01,
                          7.19967544e-01,  -8.25892866e-01,  -3.75608772e-01,
                          9.82345760e-01,  -3.44967544e-02,  -9.68344152e-01,
                          4.38108772e-01,   7.85105526e-01,  -7.66030848e-01,
                         -4.65909094e-01,   9.60227251e-01,   6.49350658e-02,
                         -9.87621725e-01,   3.46590906e-01,   8.42532456e-01,
                         -6.98660731e-01,  -5.51339269e-01,   9.28368509e-01,
                          1.63758114e-01,  -9.97159064e-01,   2.51826286e-01,
                          8.91639590e-01,  -6.24188304e-01,  -6.31493509e-01,
                          8.87378275e-01,   2.60957778e-01,  -9.96753275e-01,
                          1.54423699e-01,   9.31818187e-01,  -5.43628275e-01,
                         -7.05357134e-01,   8.37662339e-01,   3.55519474e-01,
                         -9.86404240e-01,   5.56006506e-02,   9.62865233e-01,
                         -4.57589298e-01,  -7.72118509e-01,   7.79423714e-01,
                          4.46631491e-01,  -9.66112018e-01,  -4.38311696e-02,
                          9.84172106e-01,  -3.67086053e-01,  -8.31168830e-01,
                          7.13676929e-01,   5.33076286e-01,  -9.36485410e-01,
                         -1.42857149e-01,   9.95738626e-01,  -2.72930205e-01,
                         -8.82102251e-01,   6.40625000e-01,   6.14448071e-01,
                         -8.97524357e-01,  -2.40462661e-01,   9.97564912e-01,
                         -1.75933436e-01,  -9.24310088e-01,   5.61282456e-01,
                          6.89732134e-01,  -8.49431813e-01,  -3.35633129e-01,
                          9.89245117e-01,  -7.73133114e-02,  -9.57183421e-01,
                          4.76461053e-01,   7.58116901e-01,  -7.93019474e-01,
                         -4.27556813e-01,   9.71185088e-01,   2.21185070e-02,
                         -9.80722427e-01,   3.86769474e-01,   8.18993509e-01,
                         -7.28896081e-01,  -5.15219152e-01,   9.43587661e-01,
                          1.21347405e-01,  -9.94318187e-01,   2.93222398e-01,
                          8.71550322e-01,  -6.57264590e-01,  -5.97605526e-01,
                          9.06452894e-01,   2.19155848e-01,  -9.98173714e-01,
                          1.96834415e-01,   9.15787339e-01,  -5.79342544e-01,
                         -6.74310088e-01,   8.60389590e-01,   3.15137982e-01,
                         -9.92086053e-01,   9.86201316e-02,   9.50689912e-01,
                         -4.95535702e-01,  -7.44115233e-01,   8.05803597e-01,
                          4.07670468e-01,  -9.76258099e-01,  -8.11688311e-04,
                          9.76258099e-01,  -4.06655848e-01,  -8.06615233e-01,
                          7.43100643e-01,   4.96347398e-01,  -9.50487018e-01,
                         -1.00040585e-01,   9.92086053e-01,  -3.13920468e-01,
                         -8.61201286e-01,   6.73092544e-01,   5.79951286e-01,
                         -9.15381491e-01,  -1.98457792e-01,   9.97970760e-01,
                         -2.18141228e-01,  -9.07061696e-01,   5.96387982e-01,
                          6.57873392e-01,  -8.71347427e-01,  -2.94845790e-01,
                          9.93912339e-01,  -1.20129868e-01,  -9.43993509e-01,
                          5.13798714e-01,   7.29301929e-01,  -8.18384767e-01,
                         -3.88189942e-01,   9.80113626e-01,  -2.09009741e-02,
                         -9.71590936e-01,   4.25933450e-01,   7.93425322e-01,
                         -7.57508099e-01,  -4.77678567e-01,   9.56574678e-01,
                          7.85308406e-02,  -9.89448071e-01,   3.34009737e-01,
                          8.49837661e-01,  -6.88920438e-01,  -5.62500000e-01,
                          9.23498392e-01,   1.77150980e-01,  -9.97564912e-01,
                          2.38839284e-01,   8.97524357e-01,  -6.13636374e-01,
                         -6.41842544e-01,   8.81290555e-01,   2.73944795e-01,
                         -9.95738626e-01,   1.41233772e-01,   9.36485410e-01,
                         -5.32264590e-01,  -7.14691579e-01,   8.30154240e-01,
                          3.68100643e-01,  -9.83969152e-01,   4.22077924e-02,
                          9.66112018e-01,  -4.45616871e-01,  -7.80438304e-01,
                          7.70900965e-01,   4.58603889e-01,  -9.62662339e-01,
                         -5.72240278e-02,   9.86201286e-01,  -3.54504883e-01,
                         -8.38474035e-01,   7.03936696e-01,   5.44439912e-01,
                         -9.31412339e-01,  -1.56047076e-01,   9.96347427e-01,
                         -2.59740263e-01,  -8.88189912e-01,   6.30073071e-01,
                          6.25000000e-01,  -8.91233742e-01,  -2.53449678e-01,
                          9.96550322e-01,  -1.62540585e-01,  -9.28977251e-01,
                          5.49918830e-01,   6.99269474e-01,  -8.41923714e-01,
                         -3.48214298e-01,   9.87012982e-01,  -6.37175292e-02,
                         -9.60633099e-01,   4.64285702e-01,   7.66639590e-01,
                         -7.84496725e-01,  -4.39529210e-01,   9.67532456e-01,
                          3.57142873e-02,  -9.82751608e-01,   3.73985380e-01,
                          8.26298714e-01,  -7.19155848e-01,  -5.26582778e-01,
                          9.38514590e-01,   1.34740263e-01,  -9.94926929e-01,
                          2.80032456e-01,   8.77840936e-01,  -6.46712661e-01,
                         -6.08157456e-01,   9.00162339e-01,   2.32345775e-01,
                         -9.97362018e-01,   1.83441564e-01,   9.20657456e-01,
                         -5.67775965e-01,  -6.83847427e-01,   8.52881491e-01,
                          3.27719152e-01,  -9.89853919e-01,   8.48214254e-02,
                          9.54139590e-01,  -4.83157456e-01,  -7.52840936e-01,
                          7.97077894e-01,   4.19845790e-01,  -9.72605526e-01,
                         -1.44074671e-02,   9.78287339e-01,  -3.93871754e-01,
                         -8.14123392e-01,   7.33360410e-01,   5.07913947e-01,
                         -9.45616901e-01,  -1.13636367e-01,   9.92694795e-01,
                         -3.00730526e-01,  -8.67491901e-01,   6.62540555e-01,
                          5.90706170e-01,  -9.09293830e-01,  -2.11647734e-01,
                          9.97362018e-01,  -2.04545453e-01,  -9.12134767e-01,
                          5.84821403e-01,   6.67816579e-01,  -8.63839269e-01,
                         -3.07629883e-01,   9.92086053e-01,  -1.06331170e-01,
                         -9.47849035e-01,   5.01623392e-01,   7.38230526e-01,
                         -8.09862018e-01,  -4.00568187e-01,   9.76866901e-01,
                         -7.10227294e-03,  -9.74025965e-01,   4.13352281e-01,
                          8.01339269e-01,  -7.47767866e-01,  -4.89448041e-01,
                          9.51907456e-01,   9.21266228e-02,  -9.90462661e-01,
                          3.20819795e-01,   8.56331170e-01,  -6.78368509e-01,
                         -5.73457778e-01,   9.17410731e-01,   1.90543830e-01,
                         -9.97159064e-01,   2.25243509e-01,   9.02800322e-01,
                         -6.02272749e-01,  -6.51785731e-01,   8.73985410e-01,
                          2.86931813e-01,  -9.93912339e-01,   1.27435058e-01,
                          9.40543830e-01,  -5.20089269e-01,  -7.23620117e-01,
                          8.21834445e-01,   3.80478889e-01,  -9.80925322e-01,
                          2.84090918e-02,   9.68750000e-01,  -4.32832778e-01,
                         -7.88352251e-01,   7.61566579e-01,   4.70373362e-01,
                         -9.57995117e-01,  -7.10227266e-02,   9.87418830e-01,
                         -3.41112018e-01,  -8.45170438e-01,   6.93587661e-01,
                          5.55600643e-01,  -9.25730526e-01,  -1.69642851e-01,
                          9.96144474e-01,  -2.46144474e-01,  -8.93668830e-01,
                          6.18912339e-01,   6.35146081e-01,  -8.84131491e-01,
                         -2.66436696e-01,   9.95129883e-01,  -1.48944810e-01,
                         -9.33035731e-01,   5.37946403e-01,   7.08400965e-01,
                         -8.33806813e-01,  -3.60795468e-01,   9.84172106e-01,
                         -4.99188304e-02,  -9.63474035e-01,   4.51704532e-01,
                          7.74553597e-01,  -7.75162339e-01,  -4.51501638e-01,
                          9.63271081e-01,   4.93100658e-02,  -9.84172106e-01,
                          3.60998362e-01,   8.33198071e-01,  -7.08806813e-01,
                         -5.37540555e-01,   9.33035731e-01,   1.48133114e-01,
                         -9.95129883e-01,   2.66639620e-01,   8.83522749e-01,
                         -6.35551929e-01,  -6.18506491e-01,   8.93465936e-01,
                          2.45535716e-01,  -9.96144474e-01,   1.69845775e-01,
                          9.24918830e-01,  -5.56006491e-01,  -6.93181813e-01,
                          8.44967544e-01,   3.40503246e-01,  -9.87215936e-01,
                          7.12256506e-02,   9.57183421e-01,  -4.70779210e-01,
                         -7.60957778e-01,   7.88149357e-01,   4.32021111e-01,
                         -9.68547106e-01,  -2.80032475e-02,   9.80113626e-01,
                         -3.81087661e-01,  -8.21225643e-01,   7.23417222e-01,
                          5.19074678e-01,  -9.40340936e-01,  -1.27029225e-01,
                          9.93100643e-01,  -2.87540585e-01,  -8.73376608e-01,
                          6.51582778e-01,   6.01258099e-01,  -9.02800322e-01,
                         -2.24837661e-01,   9.96347427e-01,  -1.91152602e-01,
                         -9.16801929e-01,   5.73457778e-01,   6.77353919e-01,
                         -8.56128275e-01,  -3.20211053e-01,   9.89650965e-01,
                         -9.27353874e-02,  -9.51095760e-01,   4.89448041e-01,
                          7.46753275e-01,  -8.01136374e-01,  -4.12540585e-01,
                          9.73214269e-01,   6.49350649e-03,  -9.76055205e-01,
                          4.00568187e-01,   8.08644474e-01,  -7.38230526e-01,
                         -5.00811696e-01,   9.47037339e-01,   1.05519481e-01,
                         -9.91071403e-01,   3.07832778e-01,   8.62621725e-01,
                         -6.67816579e-01,  -5.84009767e-01,   9.11323071e-01,
                          2.03733772e-01,  -9.96550322e-01,   2.11850643e-01,
                          9.07873392e-01,  -5.90909064e-01,  -6.61525965e-01,
                          8.66680205e-01,   2.99715906e-01,  -9.91883099e-01,
                          1.14042208e-01,   9.44196403e-01,  -5.08116901e-01,
                         -7.32345760e-01,   8.13514590e-01,   3.92857134e-01,
                         -9.77678597e-01,   1.48133114e-02,   9.71185088e-01,
                         -4.20251638e-01,  -7.96063304e-01,   7.52232134e-01,
                          4.81939942e-01,  -9.53530848e-01,  -8.44155848e-02,
                          9.88433421e-01,  -3.28327924e-01,  -8.51663947e-01,
                          6.83441579e-01,   5.66355526e-01,  -9.19845760e-01,
                         -1.82832792e-01,   9.95941579e-01,  -2.32954547e-01,
                         -8.98944795e-01,   6.07751608e-01,   6.45089269e-01,
                         -8.77232134e-01,  -2.79423714e-01,   9.93709445e-01,
                         -1.35349020e-01,  -9.37297106e-01,   5.26176929e-01,
                          7.17532456e-01,  -8.25892866e-01,  -3.73173714e-01,
                          9.81331170e-01,  -3.63230519e-02,  -9.66314912e-01,
                          4.39326286e-01,   7.82873392e-01,  -7.66233742e-01,
                         -4.63271111e-01,   9.59415555e-01,   6.29058406e-02,
                         -9.85795438e-01,   3.48214298e-01,   8.40300322e-01,
                         -6.99066579e-01,  -5.48904240e-01,   9.27759767e-01,
                          1.61525980e-01,  -9.95535731e-01,   2.53449678e-01,
                          8.89407456e-01,  -6.24797106e-01,  -6.29058421e-01,
                          8.86972427e-01,   2.58725643e-01,  -9.95129883e-01,
                          1.56250000e-01,   9.29788947e-01,  -5.44439912e-01,
                         -7.02719152e-01,   8.37459445e-01,   3.53287339e-01,
                         -9.84983742e-01,   5.76298684e-02,   9.60836053e-01,
                         -4.58603889e-01,  -7.69683421e-01,   7.79626608e-01,
                          4.44196433e-01,  -9.65097427e-01,  -4.18019481e-02,
                          9.82345760e-01,  -3.68303567e-01,  -8.28936696e-01,
                          7.13879883e-01,   5.30844152e-01,  -9.35673714e-01,
                         -1.40827924e-01,   9.94115233e-01,  -2.74147719e-01,
                         -8.79870117e-01,   6.41233742e-01,   6.12215936e-01,
                         -8.96712661e-01,  -2.38230526e-01,   9.95941579e-01,
                         -1.77556813e-01,  -9.22280848e-01,   5.62094152e-01,
                          6.87500000e-01,  -8.49025965e-01,  -3.33400965e-01,
                          9.88027573e-01,  -7.89366886e-02,  -9.55357134e-01,
                          4.77272719e-01,   7.55884767e-01,  -7.92816579e-01,
                         -4.25324678e-01,   9.70170438e-01,   2.04951297e-02,
                         -9.78896081e-01,   3.87784094e-01,   8.16964269e-01,
                         -7.28896081e-01,  -5.12987018e-01,   9.42573071e-01,
                          1.19521104e-01,  -9.92694795e-01,   2.94439942e-01,
                          8.69724035e-01,  -6.57467544e-01,  -5.95576286e-01,
                          9.05844152e-01,   2.17532471e-01,  -9.96753275e-01,
                          1.98051944e-01,   9.13961053e-01,  -5.79545438e-01,
                         -6.72280848e-01,   8.59983742e-01,   3.13311696e-01,
                         -9.90868509e-01,   9.98376608e-02,   9.48863626e-01,
                         -4.95941550e-01,  -7.42288947e-01,   8.05397749e-01,
                          4.06047076e-01,  -9.75040555e-01,   6.08766219e-04,
                          9.74634767e-01,  -4.07467544e-01,  -8.04788947e-01,
                          7.42897749e-01,   4.94724035e-01,  -9.49472427e-01,
                         -9.88230556e-02,   9.90462661e-01,  -3.14732134e-01,
                         -8.59375000e-01,   6.73092544e-01,   5.78327894e-01,
                         -9.14569795e-01,  -1.97037339e-01,   9.96550322e-01,
                         -2.18952924e-01,  -9.05438304e-01,   5.96590936e-01,
                          6.56452894e-01,  -8.70535731e-01,  -2.93425322e-01,
                          9.92694795e-01,  -1.20941557e-01,  -9.42573071e-01,
                          5.14001608e-01,   7.27881491e-01,  -8.17775965e-01,
                         -3.86769474e-01,   9.79099035e-01,  -2.19155848e-02,
                         -9.70170438e-01,   4.26339298e-01,   7.92004883e-01,
                         -7.57102251e-01,  -4.76461053e-01,   9.55560088e-01,
                          7.75162354e-02,  -9.88230526e-01,   3.34415585e-01,
                          8.48417222e-01,  -6.88717544e-01,  -5.61282456e-01,
                          9.22686696e-01,   1.76136360e-01,  -9.96347427e-01,
                          2.39245132e-01,   8.96306813e-01,  -6.13433421e-01,
                         -6.40625000e-01,   8.80478919e-01,   2.72930205e-01,
                         -9.94521081e-01,   1.41639605e-01,   9.35267866e-01,
                         -5.32061696e-01,  -7.13474035e-01,   8.29545438e-01,
                          3.67086053e-01,  -9.82954562e-01,   4.28165570e-02,
                          9.64894474e-01,  -4.45413947e-01,  -7.79220760e-01,
                          7.70292222e-01,   4.57589298e-01,  -9.61444795e-01,
                         -5.66152595e-02,   9.84780848e-01,  -3.54504883e-01,
                         -8.37256491e-01,   7.03530848e-01,   5.43425322e-01,
                         -9.30397749e-01,  -1.55438319e-01,   9.95129883e-01,
                         -2.59943187e-01,  -8.86769474e-01,   6.29667222e-01,
                          6.23782456e-01,  -8.90219152e-01,  -2.52637982e-01,
                          9.95332778e-01,  -1.62743509e-01,  -9.27759767e-01,
                          5.49715936e-01,   6.98051929e-01,  -8.41112018e-01,
                         -3.47402602e-01,   9.85795438e-01,  -6.41233772e-02,
                         -9.59212661e-01,   4.64082778e-01,   7.65422106e-01,
                         -7.83685088e-01,  -4.38514620e-01,   9.66517866e-01,
                          3.51055190e-02,  -9.81331170e-01,   3.74188304e-01,
                          8.25081170e-01,  -7.18547106e-01,  -5.25365233e-01,
                          9.37500000e-01,   1.33928567e-01,  -9.93709445e-01,
                          2.80438304e-01,   8.76420438e-01,  -6.46306813e-01,
                         -6.06939912e-01,   8.99350643e-01,   2.31534094e-01,
                         -9.96144474e-01,   1.83847398e-01,   9.19237018e-01,
                         -5.67573071e-01,  -6.82426929e-01,   8.52272749e-01,
                          3.26704532e-01,  -9.88636374e-01,   8.56331140e-02,
                          9.52719152e-01,  -4.83360380e-01,  -7.51217544e-01,
                          7.96672106e-01,   4.18628246e-01,  -9.71590936e-01,
                         -1.33928573e-02,   9.76866901e-01,  -3.94480526e-01,
                         -8.12500000e-01,   7.33360410e-01,   5.06290555e-01,
                         -9.44805205e-01,  -1.12215906e-01,   9.91274357e-01,
                         -3.01745117e-01,  -8.65665555e-01,   6.62743509e-01,
                          5.88879883e-01,  -9.08685088e-01,  -2.09821433e-01,
                          9.95941579e-01,  -2.06168830e-01,  -9.10308421e-01,
                          5.85836053e-01,   6.65584445e-01,  -8.63839269e-01,
                         -3.05194795e-01,   9.90868509e-01,  -1.08563311e-01,
                         -9.45819795e-01,   5.03246725e-01,   7.35592544e-01,
                         -8.10470760e-01,  -3.97727281e-01,   9.76055205e-01,
                         -9.53733735e-03,  -9.72199678e-01,   4.14772719e-01,
                          7.98904240e-01,  -7.48173714e-01,  -4.87215906e-01,
                          9.51095760e-01,   9.03003216e-02,  -9.88839269e-01,
                          3.22037339e-01,   8.54301929e-01,  -6.78571403e-01,
                         -5.71428597e-01,   9.16599035e-01,   1.88920453e-01,
                         -9.95738626e-01,   2.26258114e-01,   9.00974035e-01,
                         -6.02272749e-01,  -6.49959445e-01,   8.73173714e-01,
                          2.85511374e-01,  -9.92491901e-01,   1.28246754e-01,
                          9.38717544e-01,  -5.20089269e-01,  -7.21996725e-01,
                          8.21022749e-01,   3.79261374e-01,  -9.79504883e-01,
                          2.92207785e-02,   9.66923714e-01,  -4.32832778e-01,
                         -7.86728919e-01,   7.60754883e-01,   4.69155848e-01,
                         -9.56574678e-01,  -7.02110380e-02,   9.85592544e-01,
                         -3.41314942e-01,  -8.43547106e-01,   6.92775965e-01,
                          5.54180205e-01,  -9.24310088e-01,  -1.68831170e-01,
                          9.94521081e-01,  -2.46347398e-01,  -8.92045438e-01,
                          6.18100643e-01,   6.33725643e-01,  -8.82913947e-01,
                         -2.65827924e-01,   9.93303597e-01,  -1.48944810e-01,
                         -9.31615233e-01,   5.37337661e-01,   7.06980526e-01,
                         -8.32589269e-01,  -3.59983772e-01,   9.82548714e-01,
                         -5.01217544e-02,  -9.61850643e-01,   4.51095790e-01,
                          7.73336053e-01,  -7.74147749e-01,  -4.50689942e-01,
                          9.61647749e-01,   4.91071418e-02,  -9.82548714e-01,
                          3.60592544e-01,   8.31777573e-01,  -7.07792222e-01,
                         -5.36728919e-01,   9.31412339e-01,   1.47727266e-01,
                         -9.93506491e-01,   2.66436696e-01,   8.81899357e-01,
                         -6.34740233e-01,  -6.17491901e-01,   8.92045438e-01,
                          2.45129868e-01,  -9.94521081e-01,   1.69642851e-01,
                          9.23498392e-01,  -5.55194795e-01,  -6.92167222e-01,
                          8.43547106e-01,   3.39894474e-01,  -9.85592544e-01,
                          7.10227266e-02,   9.55762982e-01,  -4.70170468e-01,
                         -7.59943187e-01,   7.86931813e-01,   4.31209415e-01,
                         -9.67126608e-01,  -2.82061696e-02,   9.78490233e-01,
                         -3.80478889e-01,  -8.20008099e-01,   7.22199678e-01,
                          5.18465936e-01,  -9.38920438e-01,  -1.27029225e-01,
                          9.91477251e-01,  -2.86931813e-01,  -8.72159064e-01,
                          6.50568187e-01,   6.00446403e-01,  -9.01379883e-01,
                         -2.24634737e-01,   9.94724035e-01,  -1.90746754e-01,
                         -9.15584445e-01,   5.72240233e-01,   6.76339269e-01,
                         -8.54910731e-01,  -3.20008129e-01,   9.88027573e-01,
                         -9.25324708e-02,  -9.49878275e-01,   4.88433450e-01,
                          7.45738626e-01,  -7.99918830e-01,  -4.12337661e-01,
                          9.71590936e-01,   6.69642864e-03,  -9.74634767e-01,
                          3.99553567e-01,   8.07629883e-01,  -7.36810088e-01,
                         -5.00405848e-01,   9.45413947e-01,   1.05722405e-01,
                         -9.89853919e-01,   3.06818187e-01,   8.61404240e-01,
                         -6.66599035e-01,  -5.83603919e-01,   9.09902573e-01,
                          2.03733772e-01,  -9.95129883e-01,   2.11038962e-01,
                          9.06858742e-01,  -5.89691579e-01,  -6.61120117e-01,
                          8.65259767e-01,   2.99715906e-01,  -9.90665555e-01,
                          1.13230519e-01,   9.42978919e-01,  -5.06899357e-01,
                         -7.31939912e-01,   8.11891258e-01,   3.92857134e-01,
                         -9.76055205e-01,   1.42045459e-02,   9.69967544e-01,
                         -4.19034094e-01,  -7.95454562e-01,   7.50608742e-01,
                          4.81939942e-01,  -9.51907456e-01,  -8.50243494e-02,
                          9.87215936e-01,  -3.27110380e-01,  -8.51055205e-01,
                          6.81818187e-01,   5.66152573e-01,  -9.18425322e-01,
                         -1.83441564e-01,   9.94521081e-01,  -2.31737018e-01,
                         -8.98133099e-01,   6.06128275e-01,   6.44886374e-01,
                         -8.75608742e-01,  -2.80032456e-01,   9.92086053e-01,
                         -1.34334415e-01,  -9.36282456e-01,   5.24553597e-01,
                          7.17126608e-01,  -8.24066579e-01,  -3.73579532e-01,
                          9.79707778e-01,  -3.53084430e-02,  -9.65300322e-01,
                          4.37702924e-01,   7.82264590e-01,  -7.64407456e-01,
                         -4.63676959e-01,   9.57589269e-01,   6.39204532e-02,
                         -9.84577894e-01,   3.46590906e-01,   8.39691579e-01,
                         -6.97240233e-01,  -5.49107134e-01,   9.25933421e-01,
                          1.62540585e-01,  -9.94115233e-01,   2.51826286e-01,
                          8.88595760e-01,  -6.22970760e-01,  -6.29058421e-01,
                          8.84943187e-01,   2.59537339e-01,  -9.93506491e-01,
                          1.54829547e-01,   9.28774357e-01,  -5.42613626e-01,
                         -7.02719152e-01,   8.35430205e-01,   3.53896111e-01,
                         -9.83360410e-01,   5.60064949e-02,   9.59618509e-01,
                         -4.56777602e-01,  -7.69277573e-01,   7.77394474e-01,
                          4.44602281e-01,  -9.63271081e-01,  -4.32224013e-02,
                          9.80925322e-01,  -3.66477281e-01,  -8.28327894e-01,
                          7.11647749e-01,   5.31047106e-01,  -9.33441579e-01,
                         -1.41842529e-01,   9.92491901e-01,  -2.72321433e-01,
                         -8.79058421e-01,   6.38798714e-01,   6.12215936e-01,
                         -8.94480526e-01,  -2.39245132e-01,   9.94115233e-01,
                         -1.75730526e-01,  -9.21063304e-01,   5.59659064e-01,
                          6.87094152e-01,  -8.46793830e-01,  -3.34212661e-01,
                          9.85795438e-01,  -7.73133114e-02,  -9.53936696e-01,
                          4.75040585e-01,   7.55275965e-01,  -7.90381491e-01,
                         -4.25933450e-01,   9.67735410e-01,   2.17126627e-02,
                         -9.77272749e-01,   3.85551959e-01,   8.15949678e-01,
                         -7.26461053e-01,  -5.13189912e-01,   9.40137982e-01,
                          1.20535716e-01,  -9.90868509e-01,   2.92410702e-01,
                          8.68506491e-01,  -6.55032456e-01,  -5.95373392e-01,
                          9.03206170e-01,   2.18344152e-01,  -9.94521081e-01,
                          1.96428567e-01,   9.12337661e-01,  -5.77313304e-01,
                         -6.71672106e-01,   8.57142866e-01,   3.13717544e-01,
                         -9.88433421e-01,   9.82142836e-02,   9.47037339e-01,
                         -4.93709415e-01,  -7.41274357e-01,   8.02759767e-01,
                          4.06047076e-01,  -9.72605526e-01,  -6.08766219e-04,
                          9.72402573e-01,  -4.05438304e-01,  -8.03571403e-01,
                          7.40462661e-01,   4.94318187e-01,  -9.47037339e-01,
                         -9.96347368e-02,   9.88230526e-01,  -3.12905848e-01,
                         -8.57954562e-01,   6.70657456e-01,   5.77719152e-01,
                         -9.11931813e-01,  -1.97646111e-01,   9.94115233e-01,
                         -2.17532471e-01,  -9.03612018e-01,   5.94155848e-01,
                          6.55438304e-01,  -8.67897749e-01,  -2.93628246e-01,
                          9.90056813e-01,  -1.19926944e-01,  -9.40340936e-01,
                          5.11972427e-01,   7.26461053e-01,  -8.15340936e-01,
                         -3.86566550e-01,   9.76258099e-01,  -2.11038962e-02,
                         -9.67735410e-01,   4.24512982e-01,   7.90381491e-01,
                         -7.54667222e-01,  -4.75852281e-01,   9.52922106e-01,
                          7.79220760e-02,  -9.85592544e-01,   3.32995117e-01,
                          8.46387982e-01,  -6.86485410e-01,  -5.60267866e-01,
                          9.20048714e-01,   1.76136360e-01,  -9.93709445e-01,
                          2.38230526e-01,   8.94074678e-01,  -6.11607134e-01,
                         -6.39204562e-01,   8.77840936e-01,   2.72524357e-01,
                         -9.91883099e-01,   1.41030848e-01,   9.32832778e-01,
                         -5.30438304e-01,  -7.11647749e-01,   8.27110410e-01,
                          3.66274357e-01,  -9.80316579e-01,   4.24107127e-02,
                          9.62256491e-01,  -4.44196433e-01,  -7.77191579e-01,
                          7.68262982e-01,   4.56371754e-01,  -9.59009767e-01,
                         -5.66152595e-02,   9.82345760e-01,  -3.53490263e-01,
                         -8.35024357e-01,   7.01704562e-01,   5.42004883e-01,
                         -9.28165555e-01,  -1.55032471e-01,   9.92491901e-01,
                         -2.59334415e-01,  -8.84537339e-01,   6.28043830e-01,
                          6.22159064e-01,  -8.88189912e-01,  -2.52029210e-01,
                          9.92897749e-01,  -1.62540585e-01,  -9.25324678e-01,
                          5.48295438e-01,   6.96225643e-01,  -8.39285731e-01,
                         -3.46387982e-01,   9.83563304e-01,  -6.41233772e-02,
                         -9.56980526e-01,   4.63068187e-01,   7.63392866e-01,
                         -7.82061696e-01,  -4.37500000e-01,   9.64285731e-01,
                          3.49025987e-02,  -9.79099035e-01,   3.73376638e-01,
                          8.23051929e-01,  -7.17126608e-01,  -5.24147749e-01,
                          9.35470760e-01,   1.33522734e-01,  -9.91680205e-01,
                          2.79829532e-01,   8.74594152e-01,  -6.44886374e-01,
                         -6.05722427e-01,   8.97524357e-01,   2.30925322e-01,
                         -9.94115233e-01,   1.83441564e-01,   9.17410731e-01,
                         -5.66558421e-01,  -6.81209445e-01,   8.50446403e-01,
                          3.26095790e-01,  -9.86810088e-01,   8.52272734e-02,
                          9.51095760e-01,  -4.82345790e-01,  -7.50000000e-01,
                          7.95048714e-01,   4.18019474e-01,  -9.69764590e-01,
                         -1.37987016e-02,   9.75243509e-01,  -3.93465906e-01,
                         -8.11485410e-01,   7.31737018e-01,   5.05884767e-01,
                         -9.43181813e-01,  -1.12824678e-01,   9.89853919e-01,
                         -3.00527602e-01,  -8.64650965e-01,   6.60917222e-01,
                          5.88676929e-01,  -9.07061696e-01,  -2.10633114e-01,
                          9.94521081e-01,  -2.04545453e-01,  -9.09496725e-01,
                          5.83806813e-01,   6.65584445e-01,  -8.61810088e-01,
                         -3.06412339e-01,   9.89448071e-01,  -1.06534094e-01,
                         -9.45211053e-01,   5.00608742e-01,   7.35998392e-01,
                         -8.08035731e-01,  -3.99147719e-01,   9.74431813e-01,
                         -7.50811677e-03,  -9.71590936e-01,   4.12540585e-01,
                          7.99107134e-01,  -7.46347427e-01,  -4.88027602e-01,
                          9.49675322e-01,   9.15178582e-02,  -9.88230526e-01,
                          3.20413947e-01,   8.54301929e-01,  -6.77150965e-01,
                         -5.72037339e-01,   9.15584445e-01,   1.89935058e-01,
                         -9.95129883e-01,   2.25040585e-01,   9.00974035e-01,
                         -6.01055205e-01,  -6.50365233e-01,   8.72159064e-01,
                          2.86323041e-01,  -9.92086053e-01,   1.27232149e-01,
                          9.38514590e-01,  -5.19074678e-01,  -7.22199678e-01,
                          8.20211053e-01,   3.79870117e-01,  -9.79099035e-01,
                          2.82061696e-02,   9.66923714e-01,  -4.32021111e-01,
                         -7.86931813e-01,   7.60146081e-01,   4.69561696e-01,
                         -9.56371725e-01,  -7.10227266e-02,   9.85592544e-01,
                         -3.40503246e-01,  -8.43952894e-01,   6.92370117e-01,
                          5.54788947e-01,  -9.24107134e-01,  -1.69642851e-01,
                          9.94521081e-01,  -2.45535716e-01,  -8.92451286e-01,
                          6.17491901e-01,   6.34334445e-01,  -8.82711053e-01,
                         -2.66436696e-01,   9.93506491e-01,  -1.48133114e-01,
                         -9.32021081e-01,   5.36728919e-01,   7.07792222e-01,
                         -8.32386374e-01,  -3.60795468e-01,   9.82751608e-01,
                         -4.93100658e-02,  -9.62256491e-01,   4.50487018e-01,
                          7.73944795e-01,  -7.73741901e-01,  -4.51501638e-01,
                          9.61850643e-01,   4.99188304e-02,  -9.82954562e-01,
                          3.59780848e-01,   8.32589269e-01,  -7.07386374e-01,
                         -5.37743509e-01,   9.31615233e-01,   1.48944810e-01,
                         -9.93912339e-01,   2.65422076e-01,   8.82913947e-01,
                         -6.34131491e-01,  -6.18506491e-01,   8.92045438e-01,
                          2.46144474e-01,  -9.94926929e-01,   1.68628246e-01,
                          9.24310088e-01,  -5.54383099e-01,  -6.93181813e-01,
                          8.43547106e-01,   3.41112018e-01,  -9.86201286e-01,
                          7.00081140e-02,   9.56574678e-01,  -4.69358772e-01,
                         -7.60957778e-01,   7.86525965e-01,   4.32629883e-01,
                         -9.67329562e-01,  -2.94237006e-02,   9.79301929e-01,
                         -3.79464298e-01,  -8.21225643e-01,   7.21793830e-01,
                          5.19886374e-01,  -9.39123392e-01,  -1.28449678e-01,
                          9.92288947e-01,  -2.85917222e-01,  -8.73376608e-01,
                          6.49959445e-01,   6.01866901e-01,  -9.01379883e-01,
                         -2.26055190e-01,   9.95535731e-01,  -1.89326301e-01,
                         -9.16599035e-01,   5.71631491e-01,   6.77759767e-01,
                         -8.54707778e-01,  -3.21631491e-01,   9.88636374e-01,
                         -9.11120102e-02,  -9.50892866e-01,   4.87418830e-01,
                          7.47159064e-01,  -7.99512982e-01,  -4.13758129e-01,
                          9.71996725e-01,   8.11688323e-03,  -9.75446403e-01,
                          3.98538947e-01,   8.08847427e-01,  -7.36404240e-01,
                         -5.01826286e-01,   9.45616901e-01,   1.07142858e-01,
                         -9.90665555e-01,   3.05803567e-01,   8.62621725e-01,
                         -6.65990233e-01,  -5.85024357e-01,   9.09902573e-01,
                          2.05154225e-01,  -9.95738626e-01,   2.09821433e-01,
                          9.07873392e-01,  -5.88879883e-01,  -6.62337661e-01,
                          8.65056813e-01,   3.01136374e-01,  -9.91071403e-01,
                          1.12012990e-01,   9.43993509e-01,  -5.06087661e-01,
                         -7.32954562e-01,   8.11688304e-01,   3.94074678e-01,
                         -9.76461053e-01,   1.29870130e-02,   9.70779240e-01,
                         -4.18222398e-01,  -7.96469152e-01,   7.50202894e-01,
                          4.83157456e-01,  -9.52110410e-01,  -8.62418860e-02,
                          9.87824678e-01,  -3.26095790e-01,  -8.51866901e-01,
                          6.81412339e-01,   5.67370117e-01,  -9.18425322e-01,
                         -1.84456170e-01,   9.95129883e-01,  -2.30925322e-01,
                         -8.98944795e-01,   6.05722427e-01,   6.45900965e-01,
                         -8.75608742e-01,  -2.80844152e-01,   9.92491901e-01,
                         -1.33319810e-01,  -9.37094152e-01,   5.24147749e-01,
                          7.17938304e-01,  -8.24066579e-01,  -3.74391228e-01,
                          9.80113626e-01,  -3.44967544e-02,  -9.65706170e-01,
                          4.37297076e-01,   7.83076286e-01,  -7.64204562e-01,
                         -4.64285702e-01,   9.57792222e-01,   6.45292178e-02,
                         -9.84983742e-01,   3.46185058e-01,   8.40300322e-01,
                         -6.97037339e-01,  -5.49715936e-01,   9.26136374e-01,
                          1.63149357e-01,  -9.94318187e-01,   2.51623362e-01,
                          8.89204562e-01,  -6.22767866e-01,  -6.29464269e-01,
                          8.85349035e-01,   2.59943187e-01,  -9.93912339e-01,
                          1.54423699e-01,   9.29180205e-01,  -5.42410731e-01,
                         -7.02922106e-01,   8.35633099e-01,   3.54099035e-01,
                         -9.83766258e-01,   5.60064949e-02,   9.60024357e-01,
                         -4.56777602e-01,  -7.69683421e-01,   7.77800322e-01,
                          4.45008129e-01,  -9.63676929e-01,  -4.32224013e-02,
                          9.81331170e-01,  -3.66477281e-01,  -8.28530848e-01,
                          7.12053597e-01,   5.31250000e-01,  -9.34050322e-01,
                         -1.41842529e-01,   9.92897749e-01,  -2.72524357e-01,
                         -8.79261374e-01,   6.39407456e-01,   6.12418830e-01,
                         -8.95089269e-01,  -2.39042208e-01,   9.94724035e-01,
                         -1.75933436e-01,  -9.21469152e-01,   5.60267866e-01,
                          6.87297106e-01,  -8.47402573e-01,  -3.34009737e-01,
                          9.86607134e-01,  -7.77191594e-02,  -9.54342544e-01,
                          4.75649357e-01,   7.55478919e-01,  -7.91193187e-01,
                         -4.25730526e-01,   9.68750000e-01,   2.13068184e-02,
                         -9.77678597e-01,   3.86363626e-01,   8.16355526e-01,
                         -7.27069795e-01,  -5.12987018e-01,   9.41152573e-01,
                          1.20332792e-01,  -9.91477251e-01,   2.93019474e-01,
                          8.68912339e-01,  -6.55844152e-01,  -5.95373392e-01,
                          9.04220760e-01,   2.17938319e-01,  -9.95332778e-01,
                          1.97037339e-01,   9.12946403e-01,  -5.78125000e-01,
                         -6.71875000e-01,   8.58360410e-01,   3.13514620e-01,
                         -9.89448071e-01,   9.90259722e-02,   9.47849035e-01,
                         -4.94724035e-01,  -7.41680205e-01,   8.03977251e-01,
                          4.06047076e-01,  -9.73620117e-01,  -2.02922078e-04,
                          9.73417222e-01,  -4.06250000e-01,  -8.03977251e-01,
                          7.41477251e-01,   4.94521111e-01,  -9.48254883e-01,
                         -9.92288962e-02,   9.89245117e-01,  -3.13717544e-01,
                         -8.58563304e-01,   6.71875000e-01,   5.77922106e-01,
                         -9.13352251e-01,  -1.97240263e-01,   9.95332778e-01,
                         -2.18141228e-01,  -9.04423714e-01,   5.95373392e-01,
                          6.55844152e-01,  -8.69318187e-01,  -2.93425322e-01,
                          9.91477251e-01,  -1.20332792e-01,  -9.41355526e-01,
                          5.12987018e-01,   7.27069795e-01,  -8.16558421e-01,
                         -3.86769474e-01,   9.77881491e-01,  -2.13068184e-02,
                         -9.69155848e-01,   4.25324678e-01,   7.91193187e-01,
                         -7.55884767e-01,  -4.76055205e-01,   9.54342544e-01,
                          7.79220760e-02,  -9.87012982e-01,   3.33603889e-01,
                          8.47605526e-01,  -6.87500000e-01,  -5.60876608e-01,
                          9.21469152e-01,   1.76339284e-01,  -9.95129883e-01,
                          2.38636360e-01,   8.95292222e-01,  -6.12418830e-01,
                         -6.40016258e-01,   8.79261374e-01,   2.73133129e-01,
                         -9.93506491e-01,   1.41030848e-01,   9.34253275e-01,
                         -5.31047106e-01,  -7.12865233e-01,   8.28530848e-01,
                          3.67086053e-01,  -9.81939912e-01,   4.22077924e-02,
                          9.63879883e-01,  -4.44602281e-01,  -7.78612018e-01,
                          7.69277573e-01,   4.57386374e-01,  -9.60430205e-01,
                         -5.70211038e-02,   9.83969152e-01,  -3.53693187e-01,
                         -8.36647749e-01,   7.02516258e-01,   5.43222427e-01,
                         -9.29383099e-01,  -1.55844152e-01,   9.94318187e-01,
                         -2.59131491e-01,  -8.86160731e-01,   6.28652573e-01,
                          6.23579562e-01,  -8.89204562e-01,  -2.53043830e-01,
                          9.94521081e-01,  -1.62134737e-01,  -9.27150965e-01,
                          5.48701286e-01,   6.97849035e-01,  -8.40097427e-01,
                         -3.47605526e-01,   9.84983742e-01,  -6.33116886e-02,
                         -9.58603919e-01,   4.63068187e-01,   7.65219152e-01,
                         -7.82670438e-01,  -4.38920468e-01,   9.65706170e-01,
                          3.59172076e-02,  -9.80722427e-01,   3.72970790e-01,
                          8.24878275e-01,  -7.17329562e-01,  -5.25771081e-01,
                          9.36688304e-01,   1.34943187e-01,  -9.93100643e-01,
                          2.79220790e-01,   8.76420438e-01,  -6.45089269e-01,
                         -6.07345760e-01,   8.98336053e-01,   2.32548699e-01,
                         -9.95535731e-01,   1.82426944e-01,   9.19034064e-01,
                         -5.66152573e-01,  -6.83035731e-01,   8.51055205e-01,
                          3.27719152e-01,  -9.88027573e-01,   8.40097368e-02,
                          9.52719152e-01,  -4.81737018e-01,  -7.51826286e-01,
                          7.95251608e-01,   4.19845790e-01,  -9.70779240e-01,
                         -1.52191557e-02,   9.76663947e-01,  -3.92451286e-01,
                         -8.13108742e-01,   7.31534064e-01,   5.07711053e-01,
                         -9.43790555e-01,  -1.14245132e-01,   9.91071403e-01,
                         -2.99310058e-01,  -8.66274357e-01,   6.60714269e-01,
                          5.90503275e-01,  -9.07264590e-01,  -2.12256491e-01,
                          9.95535731e-01,  -2.03327924e-01,  -9.10917222e-01,
                          5.83198071e-01,   6.67410731e-01,  -8.62012982e-01,
                         -3.08035702e-01,   9.90259767e-01,  -1.05316557e-01,
                         -9.46428597e-01,   4.99797076e-01,   7.37621725e-01,
                         -8.08035731e-01,  -4.00771111e-01,   9.75040555e-01,
                         -6.08766219e-03,  -9.72605526e-01,   4.11728889e-01,
                          8.00527573e-01,  -7.45941579e-01,  -4.89448041e-01,
                          9.50081170e-01,   9.29383114e-02,  -9.89042222e-01,
                          3.19399357e-01,   8.55519474e-01,  -6.76542222e-01,
                         -5.73457778e-01,   9.15584445e-01,   1.91152602e-01,
                         -9.95738626e-01,   2.23823056e-01,   9.01988626e-01,
                         -6.00446403e-01,  -6.51582778e-01,   8.72159064e-01,
                          2.87540585e-01,  -9.92288947e-01,   1.26217529e-01,
                          9.39326286e-01,  -5.18262982e-01,  -7.23214269e-01,
                          8.20008099e-01,   3.81087661e-01,  -9.79301929e-01,
                          2.71915589e-02,   9.67532456e-01,  -4.31209415e-01,
                         -7.87743509e-01,   7.59740233e-01,   4.70576286e-01,
                         -9.56371725e-01,  -7.20373392e-02,   9.86201286e-01,
                         -3.39691550e-01,  -8.44561696e-01,   6.91964269e-01,
                          5.55600643e-01,  -9.24107134e-01,  -1.70454547e-01,
                          9.94926929e-01,  -2.44724020e-01,  -8.92857134e-01,
                          6.17086053e-01,   6.35146081e-01,  -8.82508099e-01,
                         -2.67248362e-01,   9.93709445e-01,  -1.47524357e-01,
                         -9.32426929e-01,   5.36323071e-01,   7.08198071e-01,
                         -8.32183421e-01,  -3.61404210e-01,   9.82751608e-01,
                         -4.89042215e-02,  -9.62662339e-01,   4.50081170e-01,
                          7.74350643e-01,  -7.73538947e-01,  -4.51907456e-01,
                          9.62053597e-01,   5.03246747e-02,  -9.83157456e-01,
                          3.59577924e-01,   8.32792222e-01,  -7.07386374e-01,
                         -5.37946403e-01,   9.31615233e-01,   1.49147734e-01,
                         -9.94115233e-01,   2.65219152e-01,   8.83116901e-01,
                         -6.34131491e-01,  -6.18709445e-01,   8.92045438e-01,
                          2.46347398e-01,  -9.95129883e-01,   1.68425322e-01,
                          9.24512982e-01,  -5.54383099e-01,  -6.93384767e-01,
                          8.43547106e-01,   3.41314942e-01,  -9.86201286e-01,
                          6.98051974e-02,   9.56777573e-01,  -4.69358772e-01,
                         -7.61160731e-01,   7.86728919e-01,   4.32629883e-01,
                         -9.67532456e-01,  -2.94237006e-02,   9.79504883e-01,
                         -3.79464298e-01,  -8.21428597e-01,   7.21996725e-01,
                          5.19886374e-01,  -9.39123392e-01,  -1.28449678e-01,
                          9.92491901e-01,  -2.85714298e-01,  -8.73376608e-01,
                          6.49959445e-01,   6.02069795e-01,  -9.01379883e-01,
                         -2.26258114e-01,   9.95738626e-01,  -1.89123377e-01,
                         -9.16801929e-01,   5.71428597e-01,   6.78165555e-01,
                         -8.54707778e-01,  -3.22037339e-01,   9.88839269e-01,
                         -9.07061696e-02,  -9.51095760e-01,   4.87215906e-01,
                          7.47564912e-01,  -7.99310088e-01,  -4.14366871e-01,
                          9.71996725e-01,   8.72564968e-03,  -9.75852251e-01,
                          3.97930205e-01,   8.09659064e-01,  -7.35998392e-01,
                         -5.02840936e-01,   9.45616901e-01,   1.08360387e-01,
                         -9.90868509e-01,   3.04586053e-01,   8.63636374e-01,
                         -6.64975643e-01,  -5.86444795e-01,   9.09699678e-01,
                          2.06574678e-01,  -9.96144474e-01,   2.09009737e-01,
                          9.08482134e-01,  -5.88474035e-01,  -6.63149357e-01,
                          8.65056813e-01,   3.01948041e-01,  -9.91477251e-01,
                          1.11404218e-01,   9.44602251e-01,  -5.05884767e-01,
                         -7.33563304e-01,   8.12094152e-01,   3.94480526e-01,
                         -9.77069795e-01,   1.27840908e-02,   9.71387982e-01,
                         -4.18425322e-01,  -7.96875000e-01,   7.50811696e-01,
                          4.83360380e-01,  -9.52922106e-01,  -8.60389620e-02,
                          9.88636374e-01,  -3.26501638e-01,  -8.52475643e-01,
                          6.82021081e-01,   5.67573071e-01,  -9.19237018e-01,
                         -1.84253246e-01,   9.95941579e-01,  -2.31534094e-01,
                         -8.99553597e-01,   6.06534064e-01,   6.46103919e-01,
                         -8.76623392e-01,  -2.80641228e-01,   9.93506491e-01,
                         -1.34131491e-01,  -9.37702894e-01,   5.25162339e-01,
                          7.18344152e-01,  -8.25284064e-01,  -3.74391228e-01,
                          9.81128275e-01,  -3.51055190e-02,  -9.66720760e-01,
                          4.38311696e-01,   7.83482134e-01,  -7.65625000e-01,
                         -4.64488626e-01,   9.59212661e-01,   6.41233772e-02,
                         -9.86201286e-01,   3.46996754e-01,   8.40909064e-01,
                         -6.98254883e-01,  -5.49918830e-01,   9.27556813e-01,
                          1.62743509e-01,  -9.95738626e-01,   2.52435058e-01,
                          8.90016258e-01,  -6.23985410e-01,  -6.29870117e-01,
                          8.86769474e-01,   2.59740263e-01,  -9.95332778e-01,
                          1.55032471e-01,   9.30194795e-01,  -5.43628275e-01,
                         -7.03733742e-01,   8.37053597e-01,   3.54301959e-01,
                         -9.85186696e-01,   5.64123392e-02,   9.61241901e-01,
                         -4.57589298e-01,  -7.70495117e-01,   7.79017866e-01,
                          4.45413947e-01,  -9.65097427e-01,  -4.30194810e-02,
                          9.82751608e-01,  -3.67086053e-01,  -8.29748392e-01,
                          7.13068187e-01,   5.31858742e-01,  -9.35470760e-01,
                         -1.42045453e-01,   9.94521081e-01,  -2.72930205e-01,
                         -8.80681813e-01,   6.40219152e-01,   6.13230526e-01,
                         -8.96509767e-01,  -2.39650980e-01,   9.96144474e-01,
                         -1.76136360e-01,  -9.22889590e-01,   5.60876608e-01,
                          6.88514590e-01,  -8.48620117e-01,  -3.34821433e-01,
                          9.88027573e-01,  -7.75162354e-02,  -9.55965936e-01,
                          4.76055205e-01,   7.56899357e-01,  -7.92207778e-01,
                         -4.26745117e-01,   9.70170438e-01,   2.19155848e-02,
                         -9.79504883e-01,   3.86363626e-01,   8.17978919e-01,
                         -7.27881491e-01,  -5.14407456e-01,   9.42370117e-01,
                          1.21144481e-01,  -9.93303597e-01,   2.92816550e-01,
                          8.70738626e-01,  -6.56452894e-01,  -5.96996725e-01,
                          9.05438304e-01,   2.19155848e-01,  -9.97159064e-01,
                          1.96428567e-01,   9.14772749e-01,  -5.78327894e-01,
                         -6.73701286e-01,   8.59172106e-01,   3.14935058e-01,
                         -9.91071403e-01,   9.80113670e-02,   9.49675322e-01,
                         -4.94521111e-01,  -7.43709445e-01,   8.04586053e-01,
                          4.07670468e-01,  -9.75040555e-01,  -1.42045459e-03,
                          9.75243509e-01,  -4.05844152e-01,  -8.06209445e-01,
                          7.41883099e-01,   4.96347398e-01,  -9.49472427e-01,
                         -1.00649349e-01,   9.91071403e-01,  -3.12905848e-01,
                         -8.60592544e-01,   6.71875000e-01,   5.80154240e-01,
                         -9.14163947e-01,  -1.99066564e-01,   9.96956170e-01,
                         -2.17126623e-01,  -9.06655848e-01,   5.95170438e-01,
                          6.58076286e-01,  -8.69926929e-01,  -2.95454532e-01,
                          9.93100643e-01,  -1.19115263e-01,  -9.43587661e-01,
                          5.12378275e-01,   7.29504883e-01,  -8.17167222e-01,
                         -3.88798714e-01,   9.79099035e-01,  -1.98863633e-02,
                         -9.71185088e-01,   4.24512982e-01,   7.93628275e-01,
                         -7.56087661e-01,  -4.78490263e-01,   9.55357134e-01,
                          7.95454532e-02,  -9.89042222e-01,   3.32589298e-01,
                          8.49837661e-01,  -6.87500000e-01,  -5.63311696e-01,
                          9.22280848e-01,   1.78368509e-01,  -9.96956170e-01,
                          2.37215906e-01,   8.97524357e-01,  -6.12012982e-01,
                         -6.42451286e-01,   8.79870117e-01,   2.75162339e-01,
                         -9.95129883e-01,   1.39610395e-01,   9.36485410e-01,
                         -5.30641258e-01,  -7.15300322e-01,   8.28733742e-01,
                          3.69318187e-01,  -9.83157456e-01,   4.05844152e-02,
                          9.65909064e-01,  -4.43790585e-01,  -7.81047106e-01,
                          7.69480526e-01,   4.59618509e-01,  -9.61647749e-01,
                         -5.88474013e-02,   9.85795438e-01,  -3.52678567e-01,
                         -8.38879883e-01,   7.02313304e-01,   5.45657456e-01,
                         -9.30397749e-01,  -1.57873377e-01,   9.95941579e-01,
                         -2.57913947e-01,  -8.88595760e-01,   6.28449678e-01,
                          6.26014590e-01,  -8.90016258e-01,  -2.55073041e-01,
                          9.96144474e-01,  -1.60714284e-01,  -9.29383099e-01,
                          5.48092544e-01,   7.00284064e-01,  -8.40706170e-01,
                         -3.49837661e-01,   9.86404240e-01,  -6.18912354e-02,
                         -9.60836053e-01,   4.62459415e-01,   7.67451286e-01,
                         -7.83076286e-01,  -4.41152602e-01,   9.66923714e-01,
                          3.75405848e-02,  -9.82751608e-01,   3.72159094e-01,
                          8.27110410e-01,  -7.17532456e-01,  -5.28003275e-01,
                          9.37702894e-01,   1.36566564e-01,  -9.94926929e-01,
                          2.78206170e-01,   8.78449678e-01,  -6.45089269e-01,
                         -6.09577894e-01,   8.99147749e-01,   2.34172076e-01,
                         -9.97159064e-01,   1.81412339e-01,   9.21063304e-01,
                         -5.66152573e-01,  -6.85267866e-01,   8.51663947e-01,
                          3.29545468e-01,  -9.89650965e-01,   8.27922076e-02,
                          9.54545438e-01,  -4.81534094e-01,  -7.54058421e-01,
                          7.95860410e-01,   4.21672076e-01,  -9.72199678e-01,
                         -1.64366886e-02,   9.78693187e-01,  -3.92045468e-01,
                         -8.15137982e-01,   7.31939912e-01,   5.09537339e-01,
                         -9.45008099e-01,  -1.15665585e-01,   9.92897749e-01,
                         -2.98904210e-01,  -8.68303597e-01,   6.60917222e-01,
                          5.92329562e-01,  -9.08482134e-01,  -2.13676944e-01,
                          9.97362018e-01,  -2.02719152e-01,  -9.12946403e-01,
                          5.83198071e-01,   6.69237018e-01,  -8.62824678e-01,
                         -3.09659094e-01,   9.91680205e-01,  -1.04504868e-01,
                         -9.48457778e-01,   4.99797076e-01,   7.39448071e-01,
                         -8.08847427e-01,  -4.02394474e-01,   9.76461053e-01,
                         -5.27597405e-03,  -9.74431813e-01,   4.11323041e-01,
                          8.02353919e-01,  -7.46550322e-01,  -4.91274357e-01,
                          9.51298714e-01,   9.41558406e-02,  -9.90868509e-01,
                          3.18993509e-01,   8.57345760e-01,  -6.76948071e-01,
                         -5.75081170e-01,   9.16801929e-01,   1.92370132e-01,
                         -9.97362018e-01,   2.23417208e-01,   9.03612018e-01,
                         -6.00649357e-01,  -6.53409064e-01,   8.73173714e-01,
                          2.88758129e-01,  -9.93912339e-01,   1.25405848e-01,
                          9.41152573e-01,  -5.18465936e-01,  -7.25040555e-01,
                          8.20819795e-01,   3.82305205e-01,  -9.80722427e-01,
                          2.63798703e-02,   9.69155848e-01,  -4.31006491e-01,
                         -7.89569795e-01,   7.60349035e-01,   4.71996754e-01,
                         -9.57589269e-01,  -7.28490278e-02,   9.87621725e-01,
                         -3.39488626e-01,  -8.46185088e-01,   6.92370117e-01,
                          5.57021081e-01,  -9.25121725e-01,  -1.71469152e-01,
                          9.96347427e-01,  -2.44521111e-01,  -8.94480526e-01,
                          6.17491901e-01,   6.36566579e-01,  -8.83319795e-01,
                         -2.68262982e-01,   9.95129883e-01,  -1.47118509e-01,
                         -9.33847427e-01,   5.36323071e-01,   7.09618509e-01,
                         -8.32995117e-01,  -3.62621754e-01,   9.83969152e-01,
                         -4.80925329e-02,  -9.64082778e-01,   4.50081170e-01,
                          7.75771081e-01,  -7.74147749e-01,  -4.53125000e-01,
                          9.62865233e-01,   5.11363633e-02,  -9.84577894e-01,
                          3.59375000e-01,   8.34212661e-01,  -7.07792222e-01,
                         -5.39163947e-01,   9.32426929e-01,   1.49959415e-01,
                         -9.95332778e-01,   2.65016228e-01,   8.84334445e-01,
                         -6.34334445e-01,  -6.19926929e-01,   8.92654240e-01,
                          2.47159094e-01,  -9.96144474e-01,   1.68019474e-01,
                          9.25730526e-01,  -5.54586053e-01,  -6.94602251e-01,
                          8.44155848e-01,   3.42126638e-01,  -9.87215936e-01,
                          6.93993494e-02,   9.57792222e-01,  -4.69358772e-01,
                         -7.62175322e-01,   7.87134767e-01,   4.33441550e-01,
                         -9.68344152e-01,  -2.98295449e-02,   9.80519474e-01,
                         -3.79464298e-01,  -8.22240233e-01,   7.22199678e-01,
                          5.20698071e-01,  -9.39935088e-01,  -1.28855526e-01,
                          9.93303597e-01,  -2.85714298e-01,  -8.74188304e-01,
                          6.50365233e-01,   6.02678597e-01,  -9.02191579e-01,
                         -2.26663962e-01,   9.96347427e-01,  -1.89326301e-01,
                         -9.17613626e-01,   5.71834445e-01,   6.78571403e-01,
                         -8.55316579e-01,  -3.22037339e-01,   9.89448071e-01,
                         -9.09090936e-02,  -9.51704562e-01,   4.87824678e-01,
                          7.47767866e-01,  -8.00121725e-01,  -4.14366871e-01,
                          9.72808421e-01,   8.31980538e-03,  -9.76461053e-01,
                          3.98741871e-01,   8.09659064e-01,  -7.37012982e-01,
                         -5.02435088e-01,   9.46428597e-01,   1.07345782e-01,
                         -9.91477251e-01,   3.05803567e-01,   8.63433421e-01,
                         -6.66396081e-01,  -5.85633099e-01,   9.10511374e-01,
                          2.05560058e-01,  -9.96550322e-01,   2.10024357e-01,
                          9.08482134e-01,  -5.89285731e-01,  -6.62946403e-01,
                          8.65665555e-01,   3.01542222e-01,  -9.91680205e-01,
                          1.12012990e-01,   9.44602251e-01,  -5.06290555e-01,
                         -7.33563304e-01,   8.12297106e-01,   3.94480526e-01,
                         -9.77069795e-01,   1.27840908e-02,   9.71387982e-01,
                         -4.18425322e-01,  -7.97077894e-01,   7.50608742e-01,
                          4.83563304e-01,  -9.52719152e-01,  -8.64448026e-02,
                          9.88636374e-01,  -3.26298714e-01,  -8.52678597e-01,
                          6.81818187e-01,   5.67978919e-01,  -9.19034064e-01,
                         -1.84862018e-01,   9.95738626e-01,  -2.30925322e-01,
                         -8.99756491e-01,   6.05925322e-01,   6.46509767e-01,
                         -8.76014590e-01,  -2.81452924e-01,   9.93100643e-01,
                         -1.33116886e-01,  -9.37905848e-01,   5.24147749e-01,
                          7.18750000e-01,  -8.24472427e-01,  -3.75202924e-01,
                          9.80722427e-01,  -3.40909101e-02,  -9.66720760e-01,
                          4.37094152e-01,   7.83887982e-01,  -7.64610410e-01,
                         -4.65097398e-01,   9.58400965e-01,   6.51379898e-02,
                         -9.85795438e-01,   3.45779210e-01,   8.41112018e-01,
                         -6.97037339e-01,  -5.50527573e-01,   9.26542222e-01,
                          1.63758114e-01,  -9.95129883e-01,   2.51014620e-01,
                          8.90016258e-01,  -6.22767866e-01,  -6.30478919e-01,
                          8.85551929e-01,   2.60754883e-01,  -9.94724035e-01,
                          1.53814942e-01,   9.30194795e-01,  -5.42207778e-01,
                         -7.04139590e-01,   8.35633099e-01,   3.55316550e-01,
                         -9.84172106e-01,   5.49918823e-02,   9.61038947e-01,
                         -4.56168830e-01,  -7.70900965e-01,   7.77597427e-01,
                          4.46225643e-01,  -9.64082778e-01,  -4.44399342e-02,
                          9.82142866e-01,  -3.65665585e-01,  -8.29951286e-01,
                          7.11647749e-01,   5.32670438e-01,  -9.34253275e-01,
                         -1.43262982e-01,   9.93709445e-01,  -2.71509737e-01,
                         -8.80681813e-01,   6.38595760e-01,   6.13839269e-01,
                         -8.95089269e-01,  -2.40665585e-01,   9.95332778e-01,
                         -1.74715906e-01,  -9.22686696e-01,   5.59456170e-01,
                          6.88920438e-01,  -8.47199678e-01,  -3.35836053e-01,
                          9.87012982e-01,  -7.60957822e-02,  -9.55357134e-01,
                          4.74431813e-01,   7.57102251e-01,  -7.90584445e-01,
                         -4.27556813e-01,   9.68750000e-01,   2.31331177e-02,
                         -9.78693187e-01,   3.84943187e-01,   8.17775965e-01,
                         -7.26258099e-01,  -5.15016258e-01,   9.40949678e-01,
                          1.22159094e-01,  -9.92288947e-01,   2.91396111e-01,
                          8.70332778e-01,  -6.54829562e-01,  -5.97402573e-01,
                          9.03814912e-01,   2.20170453e-01,  -9.95941579e-01,
                          1.95008114e-01,   9.14163947e-01,  -5.76704562e-01,
                         -6.73904240e-01,   8.57751608e-01,   3.15746754e-01,
                         -9.89650965e-01,   9.67938304e-02,   9.49066579e-01,
                         -4.93100643e-01,  -7.43506491e-01,   8.02962661e-01,
                          4.08279210e-01,  -9.73620117e-01,  -2.43506487e-03,
                          9.74431813e-01,  -4.04423714e-01,  -8.05803597e-01,
                          7.40259767e-01,   4.96753246e-01,  -9.47849035e-01,
                         -1.01663962e-01,   9.90056813e-01,  -3.11688304e-01,
                         -8.60186696e-01,   6.70251608e-01,   5.80154240e-01,
                         -9.12743509e-01,  -1.99675322e-01,   9.95738626e-01,
                         -2.15909094e-01,  -9.05844152e-01,   5.93547106e-01,
                          6.57873392e-01,  -8.68506491e-01,  -2.95860380e-01,
                          9.91680205e-01,  -1.17897727e-01,  -9.42573071e-01,
                          5.10957778e-01,   7.29099035e-01,  -8.15543830e-01,
                         -3.89204532e-01,   9.77678597e-01,  -1.88717525e-02,
                         -9.69967544e-01,   4.23295468e-01,   7.93019474e-01,
                         -7.54464269e-01,  -4.78490263e-01,   9.53936696e-01,
                          8.03571418e-02,  -9.87621725e-01,   3.31574678e-01,
                          8.49025965e-01,  -6.86079562e-01,  -5.63108742e-01,
                          9.20860410e-01,   1.78774357e-01,  -9.95535731e-01,
                          2.36404225e-01,   8.96712661e-01,  -6.10795438e-01,
                         -6.42045438e-01,   8.78449678e-01,   2.75365263e-01,
                         -9.93506491e-01,   1.38798699e-01,   9.35470760e-01,
                         -5.29423714e-01,  -7.14691579e-01,   8.27313304e-01,
                          3.69318187e-01,  -9.81737018e-01,   3.99756506e-02,
                          9.64691579e-01,  -4.42775965e-01,  -7.80235410e-01,
                          7.68060088e-01,   4.59618509e-01,  -9.60024357e-01,
                         -5.92532456e-02,   9.84577894e-01,  -3.51663947e-01,
                         -8.38068187e-01,   7.01095760e-01,   5.45251608e-01,
                         -9.28977251e-01,  -1.57873377e-01,   9.94521081e-01,
                         -2.57305205e-01,  -8.87378275e-01,   6.27232134e-01,
                          6.25405848e-01,  -8.88595760e-01,  -2.54870117e-01,
                          9.94724035e-01,  -1.60308436e-01,  -9.27962661e-01,
                          5.47280848e-01,   6.99472427e-01,  -8.39285731e-01,
                         -3.49431813e-01,   9.84983742e-01,  -6.16883114e-02,
                         -9.59415555e-01,   4.61850643e-01,   7.66436696e-01,
                         -7.81858742e-01,  -4.40543830e-01,   9.65503275e-01,
                          3.75405848e-02,  -9.81331170e-01,   3.71753246e-01,
                          8.25892866e-01,  -7.16517866e-01,  -5.27191579e-01,
                          9.36282456e-01,   1.36363640e-01,  -9.93506491e-01,
                          2.78003246e-01,   8.77232134e-01,  -6.44277573e-01,
                         -6.08563304e-01,   8.97930205e-01,   2.33766228e-01,
                         -9.95738626e-01,   1.81412339e-01,   9.19845760e-01,
                         -5.65543830e-01,  -6.84050322e-01,   8.50649357e-01,
                          3.28936696e-01,  -9.88230526e-01,   8.31980556e-02,
                          9.53125000e-01,  -4.81128246e-01,  -7.52637982e-01,
                          7.95048714e-01,   4.20657456e-01,  -9.70779240e-01,
                         -1.58279222e-02,   9.77272749e-01,  -3.92045468e-01,
                         -8.13717544e-01,   7.31331170e-01,   5.08319795e-01,
                         -9.43790555e-01,  -1.14853896e-01,   9.91477251e-01,
                         -2.99107134e-01,  -8.66883099e-01,   6.60714269e-01,
                          5.90909064e-01,  -9.07467544e-01,  -2.12662339e-01,
                          9.95941579e-01,  -2.03125000e-01,  -9.11323071e-01,
                          5.83198071e-01,   6.67816579e-01,  -8.62215936e-01,
                         -3.08238626e-01,   9.90462661e-01,  -1.05316557e-01,
                         -9.46834445e-01,   5.00202894e-01,   7.37824678e-01,
                         -8.08238626e-01,  -4.00771111e-01,   9.75243509e-01,
                         -6.29058434e-03,  -9.72808421e-01,   4.12134737e-01,
                          8.00730526e-01,  -7.46347427e-01,  -4.89448041e-01,
                          9.50487018e-01,   9.27353874e-02,  -9.89245117e-01,
                          3.20008129e-01,   8.55519474e-01,  -6.77150965e-01,
                         -5.73254883e-01,   9.16193187e-01,   1.90746754e-01,
                         -9.95941579e-01,   2.24634737e-01,   9.01988626e-01,
                         -6.01258099e-01,  -6.51379883e-01,   8.72767866e-01,
                          2.86931813e-01,  -9.92694795e-01,   1.27029225e-01,
                          9.39529240e-01,  -5.19277573e-01,  -7.23011374e-01,
                          8.20819795e-01,   3.80275965e-01,  -9.79707778e-01,
                          2.84090918e-02,   9.67532456e-01,  -4.32224035e-01,
                         -7.87337661e-01,   7.60754883e-01,   4.69764620e-01,
                         -9.56980526e-01,  -7.08198026e-02,   9.86201286e-01,
                         -3.40909094e-01,  -8.44155848e-01,   6.92978919e-01,
                          5.54788947e-01,  -9.24715936e-01,  -1.69034094e-01,
                          9.95129883e-01,  -2.46347398e-01,  -8.92451286e-01,
                          6.18506491e-01,   6.34131491e-01,  -8.83319795e-01,
                         -2.65827924e-01,   9.93912339e-01,  -1.49147734e-01,
                         -9.32021081e-01,   5.37946403e-01,   7.07183421e-01,
                         -8.33198071e-01,  -3.59780848e-01,   9.83157456e-01,
                         -5.05275987e-02,  -9.62256491e-01,   4.51907456e-01,
                          7.73336053e-01,  -7.74756491e-01,  -4.50284094e-01,
                          9.62459445e-01,   4.84983772e-02,  -9.82954562e-01,
                          3.61404210e-01,   8.31777573e-01,  -7.08806813e-01,
                         -5.36323071e-01,   9.32426929e-01,   1.47118509e-01,
                         -9.93912339e-01,   2.67451286e-01,   8.82102251e-01,
                         -6.35754883e-01,  -6.17086053e-01,   8.92857134e-01,
                          2.44318187e-01,  -9.95129883e-01,   1.70657471e-01,
                          9.23498392e-01,  -5.56412339e-01,  -6.91558421e-01,
                          8.44764590e-01,   3.38879883e-01,  -9.86404240e-01,
                          7.24431798e-02,   9.55965936e-01,  -4.71387982e-01,
                         -7.59334445e-01,   7.88149357e-01,   4.30397719e-01,
                         -9.67735410e-01,  -2.67857146e-02,   9.78693187e-01,
                         -3.81899357e-01,  -8.19602251e-01,   7.23620117e-01,
                          5.17451286e-01,  -9.39732134e-01,  -1.25608772e-01,
                          9.91883099e-01,  -2.88555205e-01,  -8.71753275e-01,
                          6.51988626e-01,   5.99431813e-01,  -9.02394474e-01,
                         -2.23214284e-01,   9.95129883e-01,  -1.92370132e-01,
                         -9.15178597e-01,   5.73863626e-01,   6.75527573e-01,
                         -8.55925322e-01,  -3.18587661e-01,   9.88636374e-01,
                         -9.41558406e-02,  -9.49472427e-01,   4.90056813e-01,
                          7.44724035e-01,  -8.01136374e-01,  -4.10714298e-01,
                          9.72199678e-01,   4.87012975e-03,  -9.74431813e-01,
                          4.01379883e-01,   8.06818187e-01,  -7.38230526e-01,
                         -4.98985380e-01,   9.46225643e-01,   1.03896104e-01,
                         -9.89650965e-01,   3.08847398e-01,   8.60592544e-01,
                         -6.68019474e-01,  -5.82183421e-01,   9.10714269e-01,
                          2.01907471e-01,  -9.95129883e-01,   2.13068187e-01,
                          9.06047106e-01,  -5.91314912e-01,  -6.59496725e-01,
                          8.66274357e-01,   2.97889620e-01,  -9.90665555e-01,
                          1.15259737e-01,   9.42370117e-01,  -5.08522749e-01,
                         -7.30519474e-01,   8.13108742e-01,   3.91030848e-01,
                         -9.76461053e-01,   1.62337665e-02,   9.69561696e-01,
                         -4.20860380e-01,  -7.94034064e-01,   7.52029240e-01,
                          4.80113626e-01,  -9.52516258e-01,  -8.29951316e-02,
                          9.86810088e-01,  -3.28936696e-01,  -8.49837661e-01,
                          6.83238626e-01,   5.64529240e-01,  -9.19034064e-01,
                         -1.81412339e-01,   9.94521081e-01,  -2.33766228e-01,
                         -8.97118509e-01,   6.07751608e-01,   6.43262982e-01,
                         -8.76420438e-01,  -2.78003246e-01,   9.92086053e-01,
                         -1.36160716e-01,  -9.35470760e-01,   5.26176929e-01,
                          7.15706170e-01,  -8.25081170e-01,  -3.71753246e-01,
                          9.79910731e-01,  -3.73376608e-02,  -9.64488626e-01,
                          4.39529210e-01,   7.81047106e-01,  -7.65625000e-01,
                         -4.61850643e-01,   9.57995117e-01,   6.18912354e-02,
                         -9.83969152e-01,   3.48417222e-01,   8.38474035e-01,
                         -6.98457778e-01,  -5.47280848e-01,   9.26542222e-01,
                          1.60511360e-01,  -9.93709445e-01,   2.53652602e-01,
                          8.87581170e-01,  -6.24391258e-01,  -6.27435088e-01,
                          8.85754883e-01,   2.57711053e-01,  -9.93506491e-01,
                          1.56655848e-01,   9.27962661e-01,  -5.44034064e-01,
                         -7.01298714e-01,   8.36241901e-01,   3.52069795e-01,
                         -9.83563304e-01,   5.80357127e-02,   9.59009767e-01,
                         -4.58400965e-01,  -7.68060088e-01,   7.78612018e-01,
                          4.43181813e-01,  -9.63676929e-01,  -4.13961038e-02,
                          9.80722427e-01,  -3.68100643e-01,  -8.27313304e-01,
                          7.13068187e-01,   5.29626608e-01,  -9.34253275e-01,
                         -1.40219152e-01,   9.92491901e-01,  -2.74147719e-01,
                         -8.78246725e-01,   6.40422106e-01,   6.10998392e-01,
                         -8.95495117e-01,  -2.37621754e-01,   9.94318187e-01,
                         -1.77556813e-01,  -9.20657456e-01,   5.61485410e-01,
                          6.86079562e-01,  -8.48011374e-01,  -3.32589298e-01,
                          9.86404240e-01,  -7.93425292e-02,  -9.53733742e-01,
                          4.76866871e-01,   7.54464269e-01,  -7.92004883e-01,
                         -4.24310058e-01,   9.68750000e-01,   1.98863633e-02,
                         -9.77475643e-01,   3.87784094e-01,   8.15340936e-01,
                         -7.28287339e-01,  -5.11769474e-01,   9.41558421e-01,
                          1.18709415e-01,  -9.91274357e-01,   2.94845790e-01,
                          8.68100643e-01,  -6.57264590e-01,  -5.94155848e-01,
                          9.05032456e-01,   2.16314942e-01,  -9.95535731e-01,
                          1.98863640e-01,   9.12337661e-01,  -5.79951286e-01,
                         -6.70657456e-01,   8.59577894e-01,   3.11688304e-01,
                         -9.89853919e-01,   1.01258114e-01,   9.47443187e-01,
                         -4.96956170e-01,  -7.40462661e-01,   8.05600643e-01,
                          4.04220790e-01,  -9.74431813e-01,   2.02922081e-03,
                          9.73417222e-01,  -4.08076286e-01,  -8.03571403e-01,
                          7.42897749e-01,   4.93506491e-01,  -9.49066579e-01,
                         -9.78084430e-02,   9.89650965e-01,  -3.15137982e-01,
                         -8.58563304e-01,   6.72889590e-01,   5.77516258e-01,
                         -9.14163947e-01,  -1.96631491e-01,   9.95941579e-01,
                         -2.18952924e-01,  -9.04829562e-01,   5.96185088e-01,
                          6.56047106e-01,  -8.70129883e-01,  -2.93222398e-01,
                          9.92288947e-01,  -1.20738633e-01,  -9.42167222e-01,
                          5.13595760e-01,   7.27678597e-01,  -8.17370117e-01,
                         -3.86972398e-01,   9.78693187e-01,  -2.15097405e-02,
                         -9.69967544e-01,   4.25730526e-01,   7.92207778e-01,
                         -7.56493509e-01,  -4.76866871e-01,   9.55154240e-01,
                          7.81250000e-02,  -9.88230526e-01,   3.33806813e-01,
                          8.48620117e-01,  -6.88108742e-01,  -5.61891258e-01,
                          9.22280848e-01,   1.76948056e-01,  -9.96550322e-01,
                          2.38433436e-01,   8.96712661e-01,  -6.12824678e-01,
                         -6.41436696e-01,   8.80275965e-01,   2.73944795e-01,
                         -9.94926929e-01,   1.40827924e-01,   9.35876608e-01,
                         -5.31452894e-01,  -7.14488626e-01,   8.29342544e-01,
                          3.68303567e-01,  -9.83360410e-01,   4.15990278e-02,
                          9.65706170e-01,  -4.44805205e-01,  -7.80438304e-01,
                          7.70089269e-01,   4.59009737e-01,  -9.62053597e-01,
                         -5.78327924e-02,   9.85998392e-01,  -3.53693187e-01,
                         -8.38676929e-01,   7.03327894e-01,   5.45048714e-01,
                         -9.31006491e-01,  -1.56858772e-01,   9.96347427e-01,
                         -2.59131491e-01,  -8.88595760e-01,   6.29464269e-01,
                          6.25811696e-01,  -8.90827894e-01,  -2.54464298e-01,
                          9.96753275e-01,  -1.61728889e-01,  -9.29586053e-01,
                          5.49310088e-01,   7.00284064e-01,  -8.41720760e-01,
                         -3.49228889e-01,   9.87215936e-01,  -6.29058406e-02,
                         -9.61444795e-01,   4.63676959e-01,   7.67654240e-01,
                         -7.84293830e-01,  -4.40746754e-01,   9.67938304e-01,
                          3.67288962e-02,  -9.83766258e-01,   3.73376638e-01,
                          8.27719152e-01,  -7.18952894e-01,  -5.28003275e-01,
                          9.39123392e-01,   1.35957792e-01,  -9.96144474e-01,
                          2.79423714e-01,   8.79261374e-01,  -6.46509767e-01,
                         -6.09983742e-01,   9.00771081e-01,   2.33766228e-01,
                         -9.98782456e-01,   1.82426944e-01,   9.22280848e-01,
                         -5.67573071e-01,  -6.85876608e-01,   8.53490233e-01,
                          3.29545468e-01,  -9.91274357e-01,   8.38068202e-02,
                          9.56168830e-01,  -4.82954532e-01,  -7.54870117e-01,
                          7.97686696e-01,   4.21875000e-01,  -9.74025965e-01,
                         -1.58279222e-02,   9.80316579e-01,  -3.93668830e-01,
                         -8.16558421e-01,   7.33969152e-01,   5.09943187e-01,
                         -9.47037339e-01,  -1.15259737e-01,   9.94926929e-01,
                         -3.00121754e-01,  -8.69926929e-01,   6.62946403e-01,
                          5.93141258e-01,  -9.10714269e-01,  -2.13474020e-01,
                          9.99594152e-01,  -2.03733772e-01,  -9.14772749e-01,
                          5.85227251e-01,   6.70454562e-01,  -8.65259767e-01,
                         -3.09862018e-01,   9.94115233e-01,  -1.05316557e-01,
                         -9.50487018e-01,   5.01623392e-01,   7.41071403e-01,
                         -8.11079562e-01,  -4.03003246e-01,   9.78896081e-01,
                         -5.68181835e-03,  -9.76866901e-01,   4.12946433e-01,
                          8.04180205e-01,  -7.48782456e-01,  -4.92086053e-01,
                          9.53936696e-01,   9.39529240e-02,  -9.93506491e-01,
                          3.20211053e-01,   8.59577894e-01,  -6.79180205e-01,
                         -5.76501608e-01,   9.19439912e-01,   1.92573056e-01,
                         -1.00000000e+00,   2.24431813e-01,   9.06250000e-01,
                         -6.02678597e-01,  -6.55032456e-01,   8.75811696e-01,
                          2.89366871e-01,  -9.96753275e-01,   1.26217529e-01,
                          9.43790555e-01,  -5.20292222e-01,  -7.27069795e-01,
                          8.23254883e-01,   3.83319795e-01,  -9.83563304e-01,
                          2.67857146e-02,   9.71996725e-01,  -4.32629883e-01,
                         -7.91801929e-01,   7.62784064e-01,   4.73417222e-01,
                         -9.60633099e-01,  -7.28490278e-02,   9.90665555e-01,
                         -3.40706170e-01,  -8.48823071e-01,   6.94602251e-01,
                          5.58847427e-01,  -9.27962661e-01,  -1.71875000e-01,
                          9.99391258e-01,  -2.45332792e-01,  -8.97321403e-01,
                          6.19318187e-01,   6.38595760e-01,  -8.86160731e-01,
                         -2.69277602e-01,   9.98173714e-01,  -1.47524357e-01,
                         -9.36891258e-01,   5.38149357e-01,   7.12053597e-01,
                         -8.35430205e-01,  -3.63839298e-01,   9.87012982e-01,
                         -4.82954532e-02,  -9.67126608e-01,   4.51501638e-01,
                          7.78409064e-01,  -7.76582778e-01,  -4.54748362e-01,
                          9.65909064e-01,   5.13392873e-02,  -9.87621725e-01,
                          3.60389620e-01,   8.36850643e-01,  -7.09821403e-01,
                         -5.40990233e-01,   9.35267866e-01,   1.50568187e-01,
                         -9.98376608e-01,   2.65625000e-01,   8.87175322e-01,
                         -6.36160731e-01,  -6.21956170e-01,   8.95292222e-01,
                          2.48173699e-01,  -9.99188304e-01,   1.68425322e-01,
                          9.28571403e-01,  -5.56209445e-01,  -6.96834445e-01,
                          8.46590936e-01,   3.43344152e-01,  -9.90056813e-01,
                          6.93993494e-02,   9.60633099e-01,  -4.70576286e-01,
                         -7.64610410e-01,   7.89366901e-01,   4.35064942e-01,
                         -9.71185088e-01,  -3.02353892e-02,   9.83360410e-01,
                         -3.80478889e-01,  -8.24878275e-01,   7.24228919e-01,
                          5.22321403e-01,  -9.42573071e-01,  -1.29464284e-01,
                          9.96144474e-01,  -2.86525965e-01,  -8.76826286e-01,
                          6.51988626e-01,   6.04504883e-01,  -9.04626608e-01,
                         -2.27272734e-01,   9.98985410e-01,  -1.89732149e-01,
                         -9.20048714e-01,   5.73457778e-01,   6.80600643e-01,
                         -8.57548714e-01,  -3.23051959e-01,   9.92086053e-01,
                         -9.13149342e-02,  -9.54139590e-01,   4.89042222e-01,
                          7.49797106e-01,  -8.02150965e-01,  -4.15381491e-01,
                          9.75243509e-01,   8.11688323e-03,  -9.78896081e-01,
                          3.99959415e-01,   8.11688304e-01,  -7.38839269e-01,
                         -5.03652573e-01,   9.48660731e-01,   1.07548699e-01,
                         -9.93709445e-01,   3.06818187e-01,   8.65462661e-01,
                         -6.68222427e-01,  -5.86850643e-01,   9.12743509e-01,
                          2.05762982e-01,  -9.98782456e-01,   2.10836038e-01,
                          9.10511374e-01,  -5.90909064e-01,  -6.64163947e-01,
                          8.67694795e-01,   3.01745117e-01,  -9.93912339e-01,
                          1.12621754e-01,   9.46631491e-01,  -5.07913947e-01,
                         -7.34983742e-01,   8.14326286e-01,   3.94886374e-01,
                         -9.79301929e-01,   1.33928573e-02,   9.73417222e-01,
                         -4.19845790e-01,  -7.98295438e-01,   7.52637982e-01,
                          4.83969152e-01,  -9.54951286e-01,  -8.58360380e-02,
                          9.90462661e-01,  -3.27719152e-01,  -8.53896081e-01,
                          6.83644474e-01,   5.68384767e-01,  -9.21063304e-01,
                         -1.84253246e-01,   9.97564912e-01,  -2.32142851e-01,
                         -9.00974035e-01,   6.07954562e-01,   6.46915555e-01,
                         -8.78043830e-01,  -2.80844152e-01,   9.94926929e-01,
                         -1.34537339e-01,  -9.39123392e-01,   5.26176929e-01,
                          7.19155848e-01,  -8.26501608e-01,  -3.74594152e-01,
                          9.82548714e-01,  -3.57142873e-02,  -9.67938304e-01,
                          4.39123362e-01,   7.84293830e-01,  -7.66639590e-01,
                         -4.64691550e-01,   9.60227251e-01,   6.37175292e-02,
                         -9.87215936e-01,   3.47808450e-01,   8.41517866e-01,
                         -6.99269474e-01,  -5.50121725e-01,   9.28571403e-01,
                          1.62337661e-01,  -9.96550322e-01,   2.53246754e-01,
                          8.90625000e-01,  -6.25202894e-01,  -6.30073071e-01,
                          8.87784064e-01,   2.59334415e-01,  -9.96144474e-01,
                          1.56047076e-01,   9.30600643e-01,  -5.44642866e-01,
                         -7.03733742e-01,   8.38068187e-01,   3.53693187e-01,
                         -9.85998392e-01,   5.72240278e-02,   9.61647749e-01,
                         -4.58806813e-01,  -7.70495117e-01,   7.80032456e-01,
                          4.44602281e-01,  -9.65909064e-01,  -4.20048684e-02,
                          9.82954562e-01,  -3.68506491e-01,  -8.29545438e-01,
                          7.14285731e-01,   5.31047106e-01,  -9.36282456e-01,
                         -1.40827924e-01,   9.94724035e-01,  -2.74553567e-01,
                         -8.80275965e-01,   6.41639590e-01,   6.12418830e-01,
                         -8.97321403e-01,  -2.38230526e-01,   9.96550322e-01,
                         -1.77759737e-01,  -9.22483742e-01,   5.62500000e-01,
                          6.87500000e-01,  -8.49634767e-01,  -3.33198041e-01,
                          9.88433421e-01,  -7.93425292e-02,  -9.55560088e-01,
                          4.77881491e-01,   7.55884767e-01,  -7.93425322e-01,
                         -4.25121754e-01,   9.70576286e-01,   1.98863633e-02,
                         -9.79099035e-01,   3.88392866e-01,   8.16761374e-01,
                         -7.29504883e-01,  -5.12581170e-01,   9.43181813e-01,
                          1.18912339e-01,  -9.92897749e-01,   2.95048714e-01,
                          8.69521081e-01,  -6.58279240e-01,  -5.95170438e-01,
                          9.06250000e-01,   2.16720775e-01,  -9.96956170e-01,
                          1.98863640e-01,   9.13555205e-01,  -5.80357134e-01,
                         -6.71672106e-01,   8.60389590e-01,   3.12500000e-01,
                         -9.91071403e-01,   1.00852273e-01,   9.48660731e-01,
                         -4.96956170e-01,  -7.41680205e-01,   8.06006491e-01,
                          4.05032456e-01,  -9.75446403e-01,   1.62337662e-03,
                          9.74431813e-01,  -4.08482134e-01,  -8.04180205e-01,
                          7.43709445e-01,   4.93506491e-01,  -9.49878275e-01,
                         -9.76055190e-02,   9.90462661e-01,  -3.15949678e-01,
                         -8.58766258e-01,   6.73904240e-01,   5.77313304e-01,
                         -9.15178597e-01,  -1.95819810e-01,   9.96550322e-01,
                         -2.20170453e-01,  -9.04829562e-01,   5.97402573e-01,
                          6.55235410e-01,  -8.71144474e-01,  -2.92004883e-01,
                          9.92694795e-01,  -1.22362010e-01,  -9.41964269e-01,
                          5.15016258e-01,   7.26663947e-01,  -8.18587661e-01,
                         -3.85551959e-01,   9.79099035e-01,  -2.33360399e-02,
                         -9.69764590e-01,   4.27556813e-01,   7.90990233e-01,
                         -7.57913947e-01,  -4.75040585e-01,   9.55762982e-01,
                          7.60957822e-02,  -9.87824678e-01,   3.35836053e-01,
                          8.47402573e-01,  -6.89529240e-01,  -5.59862018e-01,
                          9.22889590e-01,   1.74512982e-01,  -9.95941579e-01,
                          2.40665585e-01,   8.95292222e-01,  -6.14448071e-01,
                         -6.39204562e-01,   8.80884767e-01,   2.71306813e-01,
                         -9.94318187e-01,   1.43262982e-01,   9.34253275e-01,
                         -5.33279240e-01,  -7.12053597e-01,   8.30154240e-01,
                          3.65462661e-01,  -9.82751608e-01,   4.42370139e-02,
                          9.64082778e-01,  -4.46631491e-01,  -7.77800322e-01,
                          7.71103919e-01,   4.55965906e-01,  -9.61444795e-01,
                         -5.49918823e-02,   9.84172106e-01,  -3.55722398e-01,
                         -8.35836053e-01,   7.04342544e-01,   5.41801929e-01,
                         -9.30600643e-01,  -1.53814942e-01,   9.94521081e-01,
                         -2.61363626e-01,  -8.85754883e-01,   6.30478919e-01,
                          6.22362018e-01,  -8.90422106e-01,  -2.51014620e-01,
                          9.94926929e-01,  -1.64163962e-01,  -9.26542222e-01,
                          5.50527573e-01,   6.96631491e-01,  -8.41517866e-01,
                         -3.45779210e-01,   9.85592544e-01,  -6.55438304e-02,
                         -9.58400965e-01,   4.65097398e-01,   7.63798714e-01,
                         -7.84090936e-01,  -4.37094152e-01,   9.66314912e-01,
                          3.36850658e-02,  -9.80519474e-01,   3.75000000e-01,
                          8.23660731e-01,  -7.18952894e-01,  -5.23944795e-01,
                          9.37297106e-01,   1.32711038e-01,  -9.92897749e-01,
                          2.81250000e-01,   8.75202894e-01,  -6.46712661e-01,
                         -6.05519474e-01,   8.99147749e-01,   2.30316564e-01,
                         -9.95332778e-01,   1.84659094e-01,   9.18019474e-01,
                         -5.67978919e-01,  -6.81209445e-01,   8.52069795e-01,
                          3.25487018e-01,  -9.88027573e-01,   8.64448026e-02,
                          9.51704562e-01,  -4.83563304e-01,  -7.50000000e-01,
                          7.96266258e-01,   4.17410702e-01,  -9.70779240e-01,
                         -1.27840908e-02,   9.75852251e-01,  -3.94480526e-01,
                         -8.11282456e-01,   7.32751608e-01,   5.05275965e-01,
                         -9.43993509e-01,  -1.11810066e-01,   9.90259767e-01,
                         -3.01542222e-01,  -8.64650965e-01,   6.62134767e-01,
                          5.88068187e-01,  -9.07670438e-01,  -2.09618509e-01,
                          9.94926929e-01,  -2.05560058e-01,  -9.09293830e-01,
                          5.84618509e-01,   6.64975643e-01,  -8.62418830e-01,
                         -3.05397719e-01,   9.89650965e-01,  -1.07548699e-01,
                         -9.45008099e-01,   5.01623392e-01,   7.35389590e-01,
                         -8.08644474e-01,  -3.98133129e-01,   9.74634767e-01,
                         -8.52272753e-03,  -9.71185088e-01,   4.13555205e-01,
                          7.98295438e-01,  -7.46753275e-01,  -4.87012982e-01,
                          9.49878275e-01,   9.05032456e-02,  -9.87824678e-01,
                          3.21225643e-01,   8.53287339e-01,  -6.77556813e-01,
                         -5.70819795e-01,   9.15584445e-01,   1.88717529e-01,
                         -9.94521081e-01,   2.26055190e-01,   8.99959445e-01,
                         -6.01663947e-01,  -6.48944795e-01,   8.72362018e-01,
                          2.84902602e-01,  -9.91477251e-01,   1.28449678e-01,
                          9.37500000e-01,  -5.19683421e-01,  -7.20779240e-01,
                          8.20413947e-01,   3.78246754e-01,  -9.78490233e-01,
                          2.96266228e-02,   9.65706170e-01,  -4.32832778e-01,
                         -7.85308421e-01,   7.60349035e-01,   4.67938304e-01,
                         -9.55762982e-01,  -6.96022734e-02,   9.84577894e-01,
                         -3.41314942e-01,  -8.42126608e-01,   6.92573071e-01,
                          5.52962661e-01,  -9.23701286e-01,  -1.67816564e-01,
                          9.93506491e-01,  -2.46753246e-01,  -8.90625000e-01,
                          6.18100643e-01,   6.32508099e-01,  -8.82305205e-01,
                         -2.64610380e-01,   9.92491901e-01,  -1.49553567e-01,
                         -9.30194795e-01,   5.37540555e-01,   7.05762982e-01,
                         -8.32183421e-01,  -3.58766228e-01,   9.81737018e-01,
                         -5.09334430e-02,  -9.60633099e-01,   4.51501638e-01,
                          7.71915555e-01,  -7.73944795e-01,  -4.49269474e-01,
                          9.61241901e-01,   4.80925329e-02,  -9.81331170e-01,
                          3.60998362e-01,   8.30560088e-01,  -7.07792222e-01,
                         -5.35308421e-01,   9.31006491e-01,   1.46712661e-01,
                         -9.92491901e-01,   2.67045468e-01,   8.80884767e-01,
                         -6.34740233e-01,  -6.16071403e-01,   8.91639590e-01,
                          2.43912339e-01,  -9.93709445e-01,   1.70251623e-01,
                          9.22483742e-01,  -5.55397749e-01,  -6.90949678e-01,
                          8.43547106e-01,   3.38879883e-01,  -9.85186696e-01,
                          7.18344152e-02,   9.54951286e-01,  -4.70373362e-01,
                         -7.58725643e-01,   7.86931813e-01,   4.30194795e-01,
                         -9.66720760e-01,  -2.71915589e-02,   9.77881491e-01,
                         -3.80884737e-01,  -8.18993509e-01,   7.22402573e-01,
                          5.17451286e-01,  -9.38717544e-01,  -1.26217529e-01,
                          9.91071403e-01,  -2.87540585e-01,  -8.71347427e-01,
                          6.50771081e-01,   5.99431813e-01,  -9.01176929e-01,
                         -2.23823056e-01,   9.94521081e-01,  -1.91152602e-01,
                         -9.14772749e-01,   5.72646081e-01,   6.75730526e-01,
                         -8.54910731e-01,  -3.19196433e-01,   9.88027573e-01,
                         -9.29383114e-02,  -9.49269474e-01,   4.88839298e-01,
                          7.45129883e-01,  -8.00121725e-01,  -4.11525965e-01,
                          9.71590936e-01,   6.08766219e-03,  -9.74431813e-01,
                          4.00162339e-01,   8.07224035e-01,  -7.37215936e-01,
                         -4.99797076e-01,   9.45616901e-01,   1.05316557e-01,
                         -9.89853919e-01,   3.07426959e-01,   8.61201286e-01,
                         -6.67004883e-01,  -5.83198071e-01,   9.10105526e-01,
                          2.03327924e-01,  -9.95332778e-01,   2.11444810e-01,
                          9.06858742e-01,  -5.90097427e-01,  -6.60714269e-01,
                          8.65665555e-01,   2.99512982e-01,  -9.90868509e-01,
                          1.13636367e-01,   9.43181813e-01,  -5.07305205e-01,
                         -7.31737018e-01,   8.12500000e-01,   3.92654210e-01,
                         -9.76663947e-01,   1.44074671e-02,   9.70373392e-01,
                         -4.19439942e-01,  -7.95454562e-01,   7.51217544e-01,
                          4.81939942e-01,  -9.52719152e-01,  -8.48214254e-02,
                          9.87824678e-01,  -3.27313304e-01,  -8.51461053e-01,
                          6.82426929e-01,   5.66558421e-01,  -9.19034064e-01,
                         -1.83441564e-01,   9.95332778e-01,  -2.31939942e-01,
                         -8.98741901e-01,   6.06737018e-01,   6.45292222e-01,
                         -8.76420438e-01,  -2.80032456e-01,   9.93100643e-01,
                         -1.34334415e-01,  -9.37297106e-01,   5.25162339e-01,
                          7.17938304e-01,  -8.24878275e-01,  -3.73985380e-01,
                          9.80925322e-01,  -3.53084430e-02,  -9.66314912e-01,
                          4.38108772e-01,   7.83279240e-01,  -7.65219152e-01,
                         -4.64285702e-01,   9.58806813e-01,   6.41233772e-02,
                         -9.85795438e-01,   3.46793830e-01,   8.40909064e-01,
                         -6.97849035e-01,  -5.49918830e-01,   9.27353919e-01,
                          1.62946433e-01,  -9.95535731e-01,   2.52029210e-01,
                          8.90016258e-01,  -6.23579562e-01,  -6.30073071e-01,
                          8.86363626e-01,   2.60146111e-01,  -9.95129883e-01,
                          1.54626623e-01,   9.30397749e-01,  -5.43019474e-01,
                         -7.03936696e-01,   8.36647749e-01,   3.54910702e-01,
                         -9.84983742e-01,   5.58035709e-02,   9.61444795e-01,
                         -4.56980526e-01,  -7.70900965e-01,   7.78612018e-01,
                          4.46022719e-01,  -9.64894474e-01,  -4.38311696e-02,
                          9.82954562e-01,  -3.66477281e-01,  -8.30154240e-01,
                          7.12662339e-01,   5.32670438e-01,  -9.35267866e-01,
                         -1.42857149e-01,   9.94724035e-01,  -2.72321433e-01,
                         -8.81290555e-01,   6.39813304e-01,   6.14042222e-01,
                         -8.96306813e-01,  -2.40462661e-01,   9.96347427e-01,
                         -1.75324678e-01,  -9.23498392e-01,   5.60267866e-01,
                          6.89326286e-01,  -8.48214269e-01,  -3.35836053e-01,
                          9.88230526e-01,  -7.65016228e-02,  -9.56371725e-01,
                          4.75446433e-01,   7.57711053e-01,  -7.91801929e-01,
                         -4.27759737e-01,   9.70170438e-01,   2.29301956e-02,
                         -9.79910731e-01,   3.85754883e-01,   8.18587661e-01,
                         -7.27475643e-01,  -5.15422106e-01,   9.42370117e-01,
                          1.22159094e-01,  -9.93506491e-01,   2.92207778e-01,
                          8.71347427e-01,  -6.56047106e-01,  -5.98011374e-01,
                          9.05235410e-01,   2.20170453e-01,  -9.97362018e-01,
                          1.95616886e-01,   9.15381491e-01,  -5.77922106e-01,
                         -6.74512982e-01,   8.59172106e-01,   3.15949678e-01,
                         -9.91274357e-01,   9.71996784e-02,   9.50284064e-01,
                         -4.93912339e-01,  -7.44521081e-01,   8.04383099e-01,
                          4.08685058e-01,  -9.75243509e-01,  -2.02922081e-03,
                          9.75852251e-01,  -4.05235380e-01,  -8.06818187e-01,
                          7.41680205e-01,   4.97159094e-01,  -9.49472427e-01,
                         -1.01461038e-01,   9.91680205e-01,  -3.12500000e-01,
                         -8.61404240e-01,   6.71672106e-01,   5.80965936e-01,
                         -9.14366901e-01,  -1.99675322e-01,   9.97362018e-01,
                         -2.16517851e-01,  -9.07264590e-01,   5.94764590e-01,
                          6.58887982e-01,  -8.70129883e-01,  -2.96063304e-01,
                          9.93303597e-01,  -1.18506491e-01,  -9.44196403e-01,
                          5.12175322e-01,   7.30113626e-01,  -8.17167222e-01,
                         -3.89407456e-01,   9.79504883e-01,  -1.92775968e-02,
                         -9.71590936e-01,   4.24310058e-01,   7.94237018e-01,
                         -7.56087661e-01,  -4.79099035e-01,   9.55762982e-01,
                          8.01542178e-02,  -9.89448071e-01,   3.32386374e-01,
                          8.50446403e-01,  -6.87500000e-01,  -5.63717544e-01,
                          9.22483742e-01,   1.78774357e-01,  -9.97362018e-01,
                          2.37012982e-01,   8.98133099e-01,  -6.12012982e-01,
                         -6.42857134e-01,   8.80073071e-01,   2.75568187e-01,
                         -9.95332778e-01,   1.39407471e-01,   9.36891258e-01,
                         -5.30438304e-01,  -7.15706170e-01,   8.28936696e-01,
                          3.69724035e-01,  -9.83563304e-01,   4.03814949e-02,
                          9.66314912e-01,  -4.43790585e-01,  -7.81452894e-01,
                          7.69683421e-01,   4.60024357e-01,  -9.61850643e-01,
                         -5.90503253e-02,   9.86201286e-01,  -3.52475643e-01,
                         -8.39285731e-01,   7.02516258e-01,   5.46063304e-01,
                         -9.30600643e-01,  -1.58076301e-01,   9.96347427e-01,
                         -2.57711053e-01,  -8.89001608e-01,   6.28449678e-01,
                          6.26420438e-01,  -8.90219152e-01,  -2.55478889e-01,
                          9.96550322e-01,  -1.60511360e-01,  -9.29788947e-01,
                          5.48092544e-01,   7.00689912e-01,  -8.40909064e-01,
                         -3.50243509e-01,   9.86810088e-01,  -6.14853911e-02,
                         -9.61241901e-01,   4.62256491e-01,   7.68060088e-01,
                         -7.83076286e-01,  -4.41558450e-01,   9.67126608e-01,
                          3.79464291e-02,  -9.83157456e-01,   3.71753246e-01,
                          8.27719152e-01,  -7.17532456e-01,  -5.28612018e-01,
                          9.37905848e-01,   1.37175322e-01,  -9.95332778e-01,
                          2.77597398e-01,   8.79058421e-01,  -6.44683421e-01,
                         -6.10389590e-01,   8.99147749e-01,   2.35186681e-01,
                         -9.97564912e-01,   1.80600643e-01,   9.21875000e-01,
                         -5.65340936e-01,  -6.86282456e-01,   8.51461053e-01,
                          3.30762982e-01,  -9.89853919e-01,   8.17775950e-02,
                          9.55357134e-01,  -4.80519474e-01,  -7.55073071e-01,
                          7.95251608e-01,   4.23295468e-01,  -9.72199678e-01,
                         -1.80600658e-02,   9.79301929e-01,  -3.90625000e-01,
                         -8.16558421e-01,   7.30925322e-01,   5.11363626e-01,
                         -9.44602251e-01,  -1.17897727e-01,   9.93506491e-01,
                         -2.96672076e-01,  -8.69926929e-01,   6.59293830e-01,
                          5.94764590e-01,  -9.07873392e-01,  -2.16112018e-01,
                          9.97767866e-01,  -2.00487018e-01,  -9.14163947e-01,
                          5.81777573e-01,   6.71063304e-01,  -8.62418830e-01,
                         -3.11485380e-01,   9.92086053e-01,  -1.02678575e-01,
                         -9.49472427e-01,   4.98579532e-01,   7.41071403e-01,
                         -8.08238626e-01,  -4.04017866e-01,   9.76663947e-01,
                         -3.65259731e-03,  -9.75446403e-01,   4.10511374e-01,
                          8.03774357e-01,  -7.46144474e-01,  -4.92694795e-01,
                          9.51704562e-01,   9.53733772e-02,  -9.91680205e-01,
                          3.17978889e-01,   8.58766258e-01,  -6.76745117e-01,
                         -5.76501608e-01,   9.17207778e-01,   1.93790585e-01,
                         -9.98173714e-01,   2.22402602e-01,   9.05032456e-01,
                         -6.00446403e-01,  -6.54829562e-01,   8.73579562e-01,
                          2.90178567e-01,  -9.94926929e-01,   1.24594159e-01,
                          9.42573071e-01,  -5.18060088e-01,  -7.26461053e-01,
                          8.21225643e-01,   3.83725643e-01,  -9.81534064e-01,
                          2.53652595e-02,   9.70576286e-01,  -4.30600643e-01,
                         -7.91193187e-01,   7.60551929e-01,   4.73620117e-01,
                         -9.58603919e-01,  -7.40665570e-02,   9.89245117e-01,
                         -3.38879883e-01,  -8.48011374e-01,   6.92573071e-01,
                          5.58644474e-01,  -9.25933421e-01,  -1.72686681e-01,
                          9.97767866e-01,  -2.43709415e-01,  -8.96306813e-01,
                          6.17491901e-01,   6.38392866e-01,  -8.84131491e-01,
                         -2.69886374e-01,   9.96550322e-01,  -1.46103889e-01,
                         -9.35876608e-01,   5.36323071e-01,   7.11647749e-01,
                         -8.33603919e-01,  -3.64245117e-01,   9.85389590e-01,
                         -4.70779203e-02,  -9.65909064e-01,   4.49675322e-01,
                          7.78003275e-01,  -7.74756491e-01,  -4.55154210e-01,
                          9.64285731e-01,   5.25568165e-02,  -9.86607134e-01,
                          3.58766228e-01,   8.36647749e-01,  -7.07995117e-01,
                         -5.41396081e-01,   9.33847427e-01,   1.51582792e-01,
                         -9.97362018e-01,   2.64001638e-01,   8.86769474e-01,
                         -6.34334445e-01,  -6.22362018e-01,   8.93871725e-01,
                          2.49188319e-01,  -9.98173714e-01,   1.66801944e-01,
                          9.28165555e-01,  -5.54383099e-01,  -6.97240233e-01,
                          8.44967544e-01,   3.44358772e-01,  -9.89042222e-01,
                          6.77759722e-02,   9.60430205e-01,  -4.68750000e-01,
                         -7.65016258e-01,   7.87743509e-01,   4.36079532e-01,
                         -9.70170438e-01,  -3.16558443e-02,   9.82954562e-01,
                         -3.78652602e-01,  -8.25284064e-01,   7.22808421e-01,
                          5.23336053e-01,  -9.41558421e-01,  -1.31087661e-01,
                          9.95941579e-01,  -2.84699678e-01,  -8.77232134e-01,
                          6.50568187e-01,   6.05519474e-01,  -9.03612018e-01,
                         -2.29099020e-01,   9.98782456e-01,  -1.87905848e-01,
                         -9.20657456e-01,   5.71834445e-01,   6.81615233e-01,
                         -8.56534064e-01,  -3.24675322e-01,   9.91883099e-01,
                         -8.92857164e-02,  -9.54748392e-01,   4.87215906e-01,
                          7.51014590e-01,  -8.01136374e-01,  -4.17207778e-01,
                          9.74837661e-01,   1.01461038e-02,  -9.79504883e-01,
                          3.98133129e-01,   8.12905848e-01,  -7.37621725e-01,
                         -5.05478919e-01,   9.48254883e-01,   1.09577924e-01,
                         -9.94318187e-01,   3.04788947e-01,   8.66680205e-01,
                         -6.66801929e-01,  -5.88676929e-01,   9.12337661e-01,
                          2.07995132e-01,  -9.99391258e-01,   2.08603889e-01,
                          9.11931813e-01,  -5.89488626e-01,  -6.66193187e-01,
                          8.67086053e-01,   3.04180205e-01,  -9.94318187e-01,
                          1.10389613e-01,   9.48051929e-01,  -5.06087661e-01,
                         -7.37012982e-01,   8.13514590e-01,   3.97321433e-01,
                         -9.79504883e-01,   1.09577924e-02,   9.74634767e-01,
                         -4.17816550e-01,  -8.00527573e-01,   7.51623392e-01,
                          4.86607134e-01,  -9.54951286e-01,  -8.84740278e-02,
                          9.91680205e-01,  -3.25487018e-01,  -8.55925322e-01,
                          6.82426929e-01,   5.71022749e-01,  -9.21063304e-01,
                         -1.87094152e-01,   9.98782456e-01,  -2.29910716e-01,
                         -9.03003275e-01,   6.06331170e-01,   6.49553597e-01,
                         -8.77840936e-01,  -2.83685058e-01,   9.95941579e-01,
                         -1.31899357e-01,  -9.40949678e-01,   5.24350643e-01,
                          7.21793830e-01,  -8.25892866e-01,  -3.77637982e-01,
                          9.83157456e-01,  -3.28733772e-02,  -9.69764590e-01,
                          4.37094152e-01,   7.86931813e-01,  -7.65827894e-01,
                         -4.67735380e-01,   9.60633099e-01,   6.65584430e-02,
                         -9.88839269e-01,   3.45576286e-01,   8.44155848e-01,
                         -6.98051929e-01,  -5.53165555e-01,   9.28774357e-01,
                          1.65381491e-01,  -9.97970760e-01,   2.50608772e-01,
                          8.93060088e-01,  -6.23579562e-01,  -6.33116901e-01,
                          8.87378275e-01,   2.62581170e-01,  -9.97362018e-01,
                          1.53206170e-01,   9.33035731e-01,  -5.42816579e-01,
                         -7.06777573e-01,   8.37459445e-01,   3.56939942e-01,
                         -9.86607134e-01,   5.41801937e-02,   9.63676929e-01,
                         -4.56574678e-01,  -7.73336053e-01,   7.79017866e-01,
                          4.48051959e-01,  -9.66314912e-01,  -4.52516228e-02,
                          9.84780848e-01,  -3.65868509e-01,  -8.32183421e-01,
                          7.13068187e-01,   5.34496725e-01,  -9.36282456e-01,
                         -1.44074678e-01,   9.96144474e-01,  -2.71712661e-01,
                         -8.82913947e-01,   6.39813304e-01,   6.15665555e-01,
                         -8.97118509e-01,  -2.41680190e-01,   9.97564912e-01,
                         -1.74715906e-01,  -9.24715936e-01,   5.60267866e-01,
                          6.90543830e-01,  -8.48823071e-01,  -3.36850643e-01,
                          9.89042222e-01,  -7.60957822e-02,  -9.57589269e-01,
                          4.75446433e-01,   7.58725643e-01,  -7.92410731e-01,
                         -4.28571433e-01,   9.70779240e-01,   2.31331177e-02,
                         -9.80722427e-01,   3.85551959e-01,   8.19399357e-01,
                         -7.27881491e-01,  -5.16030848e-01,   9.42978919e-01,
                          1.22362010e-01,  -9.94318187e-01,   2.92207778e-01,
                          8.71956170e-01,  -6.56250000e-01,  -5.98214269e-01,
                          9.05641258e-01,   2.20170453e-01,  -9.97767866e-01,
                          1.95819810e-01,   9.15787339e-01,  -5.78125000e-01,
                         -6.74715936e-01,   8.59375000e-01,   3.15746754e-01,
                         -9.91477251e-01,   9.74025950e-02,   9.50487018e-01,
                         -4.94318187e-01,  -7.44318187e-01,   8.04586053e-01,
                          4.08279210e-01,  -9.75446403e-01,  -1.82629866e-03,
                          9.75649357e-01,  -4.05641228e-01,  -8.06615233e-01,
                          7.41883099e-01,   4.96753246e-01,  -9.49472427e-01,
                         -1.01055197e-01,   9.91274357e-01,  -3.12905848e-01,
                         -8.60998392e-01,   6.71875000e-01,   5.80357134e-01,
                         -9.14366901e-01,  -1.99269474e-01,   9.97159064e-01,
                         -2.17126623e-01,  -9.06655848e-01,   5.95170438e-01,
                          6.58076286e-01,  -8.70129883e-01,  -2.95454532e-01,
                          9.92897749e-01,  -1.19115263e-01,  -9.43384767e-01,
                          5.12378275e-01,   7.29301929e-01,  -8.17167222e-01,
                         -3.88595790e-01,   9.79099035e-01,  -2.00892854e-02,
                         -9.70779240e-01,   4.24715906e-01,   7.93222427e-01,
                         -7.56087661e-01,  -4.78084415e-01,   9.55357134e-01,
                          7.93425292e-02,  -9.88636374e-01,   3.32792222e-01,
                          8.49228919e-01,  -6.87500000e-01,  -5.62702894e-01,
                          9.22077894e-01,   1.77759737e-01,  -9.96550322e-01,
                          2.37621754e-01,   8.96915555e-01,  -6.12215936e-01,
                         -6.41842544e-01,   8.79870117e-01,   2.74553567e-01,
                         -9.94521081e-01,   1.40016228e-01,   9.35673714e-01,
                         -5.30844152e-01,  -7.14488626e-01,   8.28733742e-01,
                          3.68506491e-01,  -9.82751608e-01,   4.11931835e-02,
                          9.65097427e-01,  -4.44196433e-01,  -7.80032456e-01,
                          7.69480526e-01,   4.58806813e-01,  -9.61241901e-01,
                         -5.80357127e-02,   9.85186696e-01,  -3.53084415e-01,
                         -8.37865233e-01,   7.02516258e-01,   5.44439912e-01,
                         -9.29991901e-01,  -1.56858772e-01,   9.95129883e-01,
                         -2.58522719e-01,  -8.87378275e-01,   6.28652573e-01,
                          6.24797106e-01,  -8.89813304e-01,  -2.54058450e-01,
                          9.95332778e-01,  -1.61525980e-01,  -9.28165555e-01,
                          5.48498392e-01,   6.99066579e-01,  -8.40503275e-01,
                         -3.48620117e-01,   9.85795438e-01,  -6.29058406e-02,
                         -9.59821403e-01,   4.62865263e-01,   7.66233742e-01,
                         -7.83076286e-01,  -4.39935058e-01,   9.66314912e-01,
                          3.65259722e-02,  -9.81737018e-01,   3.72767866e-01,
                          8.25892866e-01,  -7.17735410e-01,  -5.26582778e-01,
                          9.37297106e-01,   1.35349020e-01,  -9.94115233e-01,
                          2.79017866e-01,   8.77232134e-01,  -6.45292222e-01,
                         -6.08360410e-01,   8.98944795e-01,   2.32954547e-01,
                         -9.96347427e-01,   1.82426944e-01,   9.20048714e-01,
                         -5.66558421e-01,  -6.83847427e-01,   8.51663947e-01,
                          3.28327924e-01,  -9.89042222e-01,   8.40097368e-02,
                          9.53530848e-01,  -4.82142866e-01,  -7.52637982e-01,
                          7.95860410e-01,   4.20251638e-01,  -9.71590936e-01,
                         -1.52191557e-02,   9.77678597e-01,  -3.92857134e-01,
                         -8.13920438e-01,   7.32345760e-01,   5.08116901e-01,
                         -9.44602251e-01,  -1.14448056e-01,   9.92086053e-01,
                         -2.99715906e-01,  -8.67288947e-01,   6.61323071e-01,
                          5.90909064e-01,  -9.08279240e-01,  -2.12256491e-01,
                          9.96550322e-01,  -2.03733772e-01,  -9.11931813e-01,
                          5.83806813e-01,   6.67816579e-01,  -8.63027573e-01,
                         -3.08238626e-01,   9.91274357e-01,  -1.05519481e-01,
                         -9.47443187e-01,   5.00608742e-01,   7.38230526e-01,
                         -8.09050322e-01,  -4.00974035e-01,   9.76055205e-01,
                         -6.49350649e-03,  -9.73620117e-01,   4.12337661e-01,
                          8.01339269e-01,  -7.46956170e-01,  -4.89853889e-01,
                          9.51095760e-01,   9.27353874e-02,  -9.90259767e-01,
                          3.20008129e-01,   8.56331170e-01,  -6.77556813e-01,
                         -5.73863626e-01,   9.16801929e-01,   1.91152602e-01,
                         -9.96753275e-01,   2.24431813e-01,   9.02800322e-01,
                         -6.01461053e-01,  -6.52191579e-01,   8.73376608e-01,
                          2.87540585e-01,  -9.93709445e-01,   1.26623377e-01,
                          9.40543830e-01,  -5.19277573e-01,  -7.24025965e-01,
                          8.21225643e-01,   3.81087661e-01,  -9.80519474e-01,
                          2.75974032e-02,   9.68750000e-01,  -4.32021111e-01,
                         -7.88555205e-01,   7.60957778e-01,   4.70982134e-01,
                         -9.57792222e-01,  -7.16314912e-02,   9.87418830e-01,
                         -3.40503246e-01,  -8.45576286e-01,   6.93181813e-01,
                          5.56006491e-01,  -9.25527573e-01,  -1.70251623e-01,
                          9.96144474e-01,  -2.45535716e-01,  -8.93871725e-01,
                          6.18303597e-01,   6.35551929e-01,  -8.83928597e-01,
                         -2.67248362e-01,   9.95129883e-01,  -1.48336038e-01,
                         -9.33441579e-01,   5.37540555e-01,   7.09009767e-01,
                         -8.33603919e-01,  -3.61404210e-01,   9.84172106e-01,
                         -4.95129861e-02,  -9.63879883e-01,   4.51298714e-01,
                          7.75162339e-01,  -7.74959445e-01,  -4.52110380e-01,
                          9.63474035e-01,   4.99188304e-02,  -9.84577894e-01,
                          3.60592544e-01,   8.33806813e-01,  -7.08806813e-01,
                         -5.38352251e-01,   9.33035731e-01,   1.48741886e-01,
                         -9.95332778e-01,   2.66233772e-01,   8.84131491e-01,
                         -6.35349035e-01,  -6.19115233e-01,   8.93465936e-01,
                          2.46144474e-01,  -9.96550322e-01,   1.69237018e-01,
                          9.25527573e-01,  -5.55600643e-01,  -6.93993509e-01,
                          8.45170438e-01,   3.41112018e-01,  -9.87621725e-01,
                          7.06168860e-02,   9.57792222e-01,  -4.70576286e-01,
                         -7.61769474e-01,   7.88149357e-01,   4.32629883e-01,
                         -9.68952894e-01,  -2.86120139e-02,   9.80722427e-01,
                         -3.80681813e-01,  -8.22037339e-01,   7.23417222e-01,
                          5.19886374e-01,  -9.40746725e-01,  -1.27637982e-01,
                          9.93709445e-01,  -2.87134737e-01,  -8.74188304e-01,
                          6.51582778e-01,   6.02069795e-01,  -9.03003275e-01,
                         -2.25446433e-01,   9.96956170e-01,  -1.90746754e-01,
                         -9.17613626e-01,   5.73254883e-01,   6.78165555e-01,
                         -8.56534064e-01,  -3.21022719e-01,   9.90259767e-01,
                         -9.23295468e-02,  -9.51907456e-01,   4.89245117e-01,
                          7.47362018e-01,  -8.01339269e-01,  -4.13352281e-01,
                          9.73620117e-01,   7.10227294e-03,  -9.76663947e-01,
                          4.00365263e-01,   8.09456170e-01,  -7.38230526e-01,
                         -5.01623392e-01,   9.47240233e-01,   1.06128246e-01,
                         -9.91883099e-01,   3.07426959e-01,   8.63230526e-01,
                         -6.67816579e-01,  -5.84821403e-01,   9.11728919e-01,
                          2.04342529e-01,  -9.97159064e-01,   2.11444810e-01,
                          9.08685088e-01,  -5.90706170e-01,  -6.62337661e-01,
                          8.66883099e-01,   3.00527602e-01,  -9.92491901e-01,
                          1.13433443e-01,   9.44805205e-01,  -5.07913947e-01,
                         -7.33157456e-01,   8.13514590e-01,   3.93465906e-01,
                         -9.77881491e-01,   1.42045459e-02,   9.71793830e-01,
                         -4.19845790e-01,  -7.96875000e-01,   7.52029240e-01,
                          4.82751638e-01,  -9.53733742e-01,  -8.52272734e-02,
                          9.89042222e-01,  -3.27719152e-01,  -8.52475643e-01,
                          6.83238626e-01,   5.67167222e-01,  -9.20048714e-01,
                         -1.83644474e-01,   9.96347427e-01,  -2.32345775e-01,
                         -8.99756491e-01,   6.07345760e-01,   6.45900965e-01,
                         -8.77232134e-01,  -2.80235380e-01,   9.93912339e-01,
                         -1.34537339e-01,  -9.37905848e-01,   5.25771081e-01,
                          7.18344152e-01,  -8.25689912e-01,  -3.73985380e-01,
                          9.81534064e-01,  -3.57142873e-02,  -9.66923714e-01,
                          4.38920468e-01,   7.83482134e-01,  -7.66030848e-01,
                         -4.64285702e-01,   9.59415555e-01,   6.37175292e-02,
                         -9.86201286e-01,   3.47402602e-01,   8.40909064e-01,
                         -6.98660731e-01,  -5.49715936e-01,   9.27759767e-01,
                          1.62337661e-01,  -9.95738626e-01,   2.52637982e-01,
                          8.90016258e-01,  -6.24391258e-01,  -6.29667222e-01,
                          8.86769474e-01,   2.59537339e-01,  -9.95332778e-01,
                          1.55438319e-01,   9.30194795e-01,  -5.43831170e-01,
                         -7.03530848e-01,   8.37053597e-01,   3.53896111e-01,
                         -9.84983742e-01,   5.68181835e-02,   9.61241901e-01,
                         -4.57995117e-01,  -7.70292222e-01,   7.79017866e-01,
                          4.45008129e-01,  -9.65097427e-01,  -4.26136367e-02,
                          9.82548714e-01,  -3.67491871e-01,  -8.29342544e-01,
                          7.13271081e-01,   5.31655848e-01,  -9.35267866e-01,
                         -1.41639605e-01,   9.94115233e-01,  -2.73336053e-01,
                         -8.80275965e-01,   6.40422106e-01,   6.12824678e-01,
                         -8.96306813e-01,  -2.39042208e-01,   9.95941579e-01,
                         -1.76542208e-01,  -9.22483742e-01,   5.61282456e-01,
                          6.88108742e-01,  -8.48620117e-01,  -3.34212661e-01,
                          9.87824678e-01,  -7.81250000e-02,  -9.55357134e-01,
                          4.76461053e-01,   7.56493509e-01,  -7.92207778e-01,
                         -4.25933450e-01,   9.69764590e-01,   2.11038962e-02,
                         -9.78896081e-01,   3.86972398e-01,   8.17167222e-01,
                         -7.28084445e-01,  -5.13595760e-01,   9.42370117e-01,
                          1.20332792e-01,  -9.92694795e-01,   2.93628246e-01,
                          8.69926929e-01,  -6.56858742e-01,  -5.96185088e-01,
                          9.05235410e-01,   2.18141228e-01,  -9.96550322e-01,
                          1.97443187e-01,   9.13961053e-01,  -5.78936696e-01,
                         -6.72686696e-01,   8.59375000e-01,   3.13920468e-01,
                         -9.90462661e-01,   9.90259722e-02,   9.48863626e-01,
                         -4.95129883e-01,  -7.42491901e-01,   8.04788947e-01,
                          4.06452924e-01,  -9.74634767e-01,   0.00000000e+00,
                          9.74431813e-01,  -4.06655848e-01,  -8.04991901e-01,
                          7.42288947e-01,   4.95129883e-01,  -9.49066579e-01,
                         -9.92288962e-02,   9.90259767e-01,  -3.14123362e-01,
                         -8.59375000e-01,   6.72483742e-01,   5.78733742e-01,
                         -9.14163947e-01,  -1.97646111e-01,   9.96347427e-01,
                         -2.18344152e-01,  -9.05438304e-01,   5.95982134e-01,
                          6.56655848e-01,  -8.69926929e-01,  -2.93831170e-01,
                          9.92491901e-01,  -1.20332792e-01,  -9.42370117e-01,
                          5.13392866e-01,   7.28084445e-01,  -8.17370117e-01,
                         -3.87175322e-01,   9.78693187e-01,  -2.13068184e-02,
                         -9.69967544e-01,   4.25730526e-01,   7.92207778e-01,
                         -7.56493509e-01,  -4.76663947e-01,   9.55154240e-01,
                          7.81250000e-02,  -9.88027573e-01,   3.34009737e-01,
                          8.48417222e-01,  -6.88108742e-01,  -5.61485410e-01,
                          9.22280848e-01,   1.76542208e-01,  -9.96144474e-01,
                          2.38839284e-01,   8.96306813e-01,  -6.13027573e-01,
                         -6.40625000e-01,   8.80073071e-01,   2.73336053e-01,
                         -9.94318187e-01,   1.41233772e-01,   9.35267866e-01,
                         -5.31655848e-01,  -7.13474035e-01,   8.29342544e-01,
                          3.67491871e-01,  -9.82751608e-01,   4.24107127e-02,
                          9.64894474e-01,  -4.45211053e-01,  -7.79423714e-01,
                          7.70089269e-01,   4.57792222e-01,  -9.61444795e-01,
                         -5.68181835e-02,   9.84983742e-01,  -3.54099035e-01,
                         -8.37256491e-01,   7.03327894e-01,   5.43628275e-01,
                         -9.30397749e-01,  -1.55641228e-01,   9.95129883e-01,
                         -2.59740263e-01,  -8.86972427e-01,   6.29667222e-01,
                          6.24188304e-01,  -8.90219152e-01,  -2.52840906e-01,
                          9.95535731e-01,  -1.62540585e-01,  -9.27759767e-01,
                          5.49512982e-01,   6.98254883e-01,  -8.41112018e-01,
                         -3.47605526e-01,   9.85998392e-01,  -6.39204532e-02,
                         -9.59415555e-01,   4.63879883e-01,   7.65625000e-01,
                         -7.83685088e-01,  -4.38920468e-01,   9.66517866e-01,
                          3.55113633e-02,  -9.81534064e-01,   3.73782456e-01,
                          8.25487018e-01,  -7.18344152e-01,  -5.25974035e-01,
                          9.37500000e-01,   1.34537339e-01,  -9.93912339e-01,
                          2.79829532e-01,   8.77029240e-01,  -6.45900965e-01,
                         -6.07548714e-01,   8.99350643e-01,   2.32345775e-01,
                         -9.96347427e-01,   1.83238640e-01,   9.19642866e-01,
                         -5.67167222e-01,  -6.83238626e-01,   8.52069795e-01,
                          3.27719152e-01,  -9.88839269e-01,   8.48214254e-02,
                          9.53327894e-01,  -4.82751638e-01,  -7.52232134e-01,
                          7.96266258e-01,   4.19642866e-01,  -9.71793830e-01,
                         -1.46103892e-02,   9.77475643e-01,  -3.93465906e-01,
                         -8.13514590e-01,   7.32751608e-01,   5.07711053e-01,
                         -9.44805205e-01,  -1.13839284e-01,   9.91883099e-01,
                         -3.00324678e-01,  -8.66883099e-01,   6.61728919e-01,
                          5.90503275e-01,  -9.08279240e-01,  -2.11647734e-01,
                          9.96550322e-01,  -2.04139605e-01,  -9.11525965e-01,
                          5.84212661e-01,   6.67410731e-01,  -8.63027573e-01,
                         -3.07629883e-01,   9.91071403e-01,  -1.05925322e-01,
                         -9.47037339e-01,   5.01014590e-01,   7.37824678e-01,
                         -8.09050322e-01,  -4.00568187e-01,   9.75852251e-01,
                         -6.89935079e-03,  -9.73214269e-01,   4.12540585e-01,
                          8.00933421e-01,  -7.46956170e-01,  -4.89448041e-01,
                          9.50892866e-01,   9.25324708e-02,  -9.89650965e-01,
                          3.20211053e-01,   8.55925322e-01,  -6.77353919e-01,
                         -5.73457778e-01,   9.16396081e-01,   1.90949678e-01,
                         -9.96347427e-01,   2.24634737e-01,   9.02394474e-01,
                         -6.01258099e-01,  -6.51785731e-01,   8.72767866e-01,
                          2.87337661e-01,  -9.92897749e-01,   1.26623377e-01,
                          9.39935088e-01,  -5.19074678e-01,  -7.23620117e-01,
                          8.20616901e-01,   3.80884737e-01,  -9.79910731e-01,
                          2.75974032e-02,   9.67938304e-01,  -4.31818187e-01,
                         -7.88149357e-01,   7.60349035e-01,   4.70779210e-01,
                         -9.56980526e-01,  -7.16314912e-02,   9.86607134e-01,
                         -3.40097398e-01,  -8.44967544e-01,   6.92370117e-01,
                          5.55803597e-01,  -9.24512982e-01,  -1.70251623e-01,
                          9.95332778e-01,  -2.45129868e-01,  -8.93262982e-01,
                          6.17694795e-01,   6.35146081e-01,  -8.82913947e-01,
                         -2.67045468e-01,   9.94115233e-01,  -1.47930190e-01,
                         -9.32629883e-01,   5.36728919e-01,   7.08400965e-01,
                         -8.32589269e-01,  -3.61201286e-01,   9.82954562e-01,
                         -4.91071418e-02,  -9.62662339e-01,   4.50487018e-01,
                          7.74350643e-01,  -7.73944795e-01,  -4.51704532e-01,
                          9.62053597e-01,   5.01217544e-02,  -9.83157456e-01,
                          3.59780848e-01,   8.32792222e-01,  -7.07589269e-01,
                         -5.37743509e-01,   9.31615233e-01,   1.48741886e-01,
                         -9.93912339e-01,   2.65625000e-01,   8.82913947e-01,
                         -6.34131491e-01,  -6.18506491e-01,   8.92045438e-01,
                          2.45941564e-01,  -9.94926929e-01,   1.68831170e-01,
                          9.24107134e-01,  -5.54586053e-01,  -6.92978919e-01,
                          8.43547106e-01,   3.40706170e-01,  -9.85795438e-01,
                          7.02110380e-02,   9.56168830e-01,  -4.69561696e-01,
                         -7.60551929e-01,   7.86728919e-01,   4.32224035e-01,
                         -9.67126608e-01,  -2.88149342e-02,   9.78896081e-01,
                         -3.79870117e-01,  -8.20819795e-01,   7.21996725e-01,
                          5.19074678e-01,  -9.38920438e-01,  -1.27637982e-01,
                          9.92086053e-01,  -2.86525965e-01,  -8.72767866e-01,
                          6.50568187e-01,   6.01055205e-01,  -9.01582778e-01,
                         -2.25040585e-01,   9.95332778e-01,  -1.90543830e-01,
                         -9.15990233e-01,   5.72646081e-01,   6.76948071e-01,
                         -8.55316579e-01,  -3.20211053e-01,   9.88839269e-01,
                         -9.27353874e-02,  -9.50487018e-01,   4.89245117e-01,
                          7.45941579e-01,  -8.00933421e-01,  -4.12134737e-01,
                          9.72402573e-01,   6.49350649e-03,  -9.75446403e-01,
                          4.00162339e-01,   8.08238626e-01,  -7.37621725e-01,
                         -5.01014590e-01,   9.46225643e-01,   1.05925322e-01,
                         -9.90868509e-01,   3.07021111e-01,   8.62418830e-01,
                         -6.67004883e-01,  -5.84415555e-01,   9.10714269e-01,
                          2.04342529e-01,  -9.96144474e-01,   2.11038962e-01,
                          9.07873392e-01,  -5.90097427e-01,  -6.61931813e-01,
                          8.65868509e-01,   3.00527602e-01,  -9.91477251e-01,
                          1.12824678e-01,   9.44196403e-01,  -5.07102251e-01,
                         -7.32954562e-01,   8.12500000e-01,   3.93668830e-01,
                         -9.77069795e-01,   1.37987016e-02,   9.71185088e-01,
                         -4.19034094e-01,  -7.96469152e-01,   7.51217544e-01,
                          4.82751638e-01,  -9.52922106e-01,  -8.56331140e-02,
                          9.88230526e-01,  -3.27110380e-01,  -8.52069795e-01,
                          6.82224035e-01,   5.67167222e-01,  -9.19237018e-01,
                         -1.83847398e-01,   9.95535731e-01,  -2.31737018e-01,
                         -8.99147749e-01,   6.06534064e-01,   6.45698071e-01,
                         -8.76217544e-01,  -2.80438304e-01,   9.93100643e-01,
                         -1.34131491e-01,  -9.37297106e-01,   5.24959445e-01,
                          7.17938304e-01,  -8.24878275e-01,  -3.74188304e-01,
                          9.80519474e-01,  -3.53084430e-02,  -9.66112018e-01,
                          4.38108772e-01,   7.83076286e-01,  -7.65016258e-01,
                         -4.64082778e-01,   9.58400965e-01,   6.39204532e-02,
                         -9.85389590e-01,   3.46793830e-01,   8.40300322e-01,
                         -6.97646081e-01,  -5.49512982e-01,   9.26745117e-01,
                          1.62540585e-01,  -9.94926929e-01,   2.52232134e-01,
                          8.89407456e-01,  -6.23579562e-01,  -6.29464269e-01,
                          8.85957778e-01,   2.59537339e-01,  -9.94521081e-01,
                          1.55032471e-01,   9.29586053e-01,  -5.43222427e-01,
                         -7.03125000e-01,   8.36241901e-01,   3.53896111e-01,
                         -9.84375000e-01,   5.64123392e-02,   9.60430205e-01,
                         -4.57386374e-01,  -7.69886374e-01,   7.78409064e-01,
                          4.44805205e-01,  -9.64285731e-01,  -4.28165570e-02,
                          9.81737018e-01,  -3.67086053e-01,  -8.28936696e-01,
                          7.12662339e-01,   5.31452894e-01,  -9.34659064e-01,
                         -1.41639605e-01,   9.93506491e-01,  -2.73133129e-01,
                         -8.79870117e-01,   6.39813304e-01,   6.12621725e-01,
                         -8.95698071e-01,  -2.39042208e-01,   9.95332778e-01,
                         -1.76339284e-01,  -9.21875000e-01,   5.60673714e-01,
                          6.87702894e-01,  -8.48011374e-01,  -3.34212661e-01,
                          9.87012982e-01,  -7.79220760e-02,  -9.54951286e-01,
                          4.76055205e-01,   7.56087661e-01,  -7.91801929e-01,
                         -4.25933450e-01,   9.69155848e-01,   2.13068184e-02,
                         -9.78490233e-01,   3.86566550e-01,   8.16761374e-01,
                         -7.27678597e-01,  -5.13595760e-01,   9.41558421e-01,
                          1.20332792e-01,  -9.92086053e-01,   2.93222398e-01,
                          8.69521081e-01,  -6.56250000e-01,  -5.95982134e-01,
                          9.04626608e-01,   2.18344152e-01,  -9.95941579e-01,
                          1.97037339e-01,   9.13555205e-01,  -5.78327894e-01,
                         -6.72483742e-01,   8.58766258e-01,   3.13920468e-01,
                         -9.90056813e-01,   9.86201316e-02,   9.48457778e-01,
                         -4.94724035e-01,  -7.42491901e-01,   8.04180205e-01,
                          4.06655848e-01,  -9.74228919e-01,  -4.05844155e-04,
                          9.74025965e-01,  -4.06250000e-01,  -8.04991901e-01,
                          7.41680205e-01,   4.95129883e-01,  -9.48660731e-01,
                         -9.96347368e-02,   9.90056813e-01,  -3.13514620e-01,
                         -8.59375000e-01,   6.71875000e-01,   5.78733742e-01,
                         -9.13758099e-01,  -1.98051944e-01,   9.95941579e-01,
                         -2.17938319e-01,  -9.05438304e-01,   5.95373392e-01,
                          6.56858742e-01,  -8.69724035e-01,  -2.94237018e-01,
                          9.92086053e-01,  -1.20129868e-01,  -9.42370117e-01,
                          5.12784064e-01,   7.28084445e-01,  -8.16964269e-01,
                         -3.87581170e-01,   9.78287339e-01,  -2.09009741e-02,
                         -9.69967544e-01,   4.25324678e-01,   7.92207778e-01,
                         -7.56087661e-01,  -4.77069795e-01,   9.54748392e-01,
                          7.83279240e-02,  -9.87824678e-01,   3.33400965e-01,
                          8.48417222e-01,  -6.87702894e-01,  -5.61891258e-01,
                          9.21672106e-01,   1.76948056e-01,  -9.95941579e-01,
                          2.38230526e-01,   8.96103919e-01,  -6.12418830e-01,
                         -6.40827894e-01,   8.79464269e-01,   2.73741871e-01,
                         -9.94115233e-01,   1.40625000e-01,   9.35064912e-01,
                         -5.31047106e-01,  -7.13676929e-01,   8.28530848e-01,
                          3.67694795e-01,  -9.82142866e-01,   4.18019481e-02,
                          9.64488626e-01,  -4.44399357e-01,  -7.79423714e-01,
                          7.69277573e-01,   4.58198041e-01,  -9.60836053e-01,
                         -5.76298684e-02,   9.84577894e-01,  -3.53287339e-01,
                         -8.37256491e-01,   7.02313304e-01,   5.44034064e-01,
                         -9.29586053e-01,  -1.56452924e-01,   9.94521081e-01,
                         -2.58928567e-01,  -8.86972427e-01,   6.28449678e-01,
                          6.24391258e-01,  -8.89204562e-01,  -2.53652602e-01,
                          9.94724035e-01,  -1.61728889e-01,  -9.27759767e-01,
                          5.48295438e-01,   6.98457778e-01,  -8.40097427e-01,
                         -3.48214298e-01,   9.85186696e-01,  -6.29058406e-02,
                         -9.59212661e-01,   4.62865263e-01,   7.65625000e-01,
                         -7.82670438e-01,  -4.39529210e-01,   9.65706170e-01,
                          3.63230519e-02,  -9.81128275e-01,   3.72767866e-01,
                          8.25284064e-01,  -7.17329562e-01,  -5.26379883e-01,
                          9.36688304e-01,   1.35349020e-01,  -9.93303597e-01,
                          2.78814942e-01,   8.76623392e-01,  -6.44886374e-01,
                         -6.07954562e-01,   8.98133099e-01,   2.32954547e-01,
                         -9.95738626e-01,   1.82224020e-01,   9.19237018e-01,
                         -5.66152573e-01,  -6.83441579e-01,   8.50852251e-01,
                          3.28125000e-01,  -9.88027573e-01,   8.38068202e-02,
                          9.52922106e-01,  -4.81534094e-01,  -7.52232134e-01,
                          7.95048714e-01,   4.20048714e-01,  -9.70779240e-01,
                         -1.54220778e-02,   9.76866901e-01,  -3.92451286e-01,
                         -8.13311696e-01,   7.31534064e-01,   5.07913947e-01,
                         -9.43587661e-01,  -1.14448056e-01,   9.91071403e-01,
                         -2.99310058e-01,  -8.66477251e-01,   6.60511374e-01,
                          5.90706170e-01,  -9.07264590e-01,  -2.12459415e-01,
                          9.95535731e-01,  -2.03327924e-01,  -9.11120117e-01,
                          5.82995117e-01,   6.67410731e-01,  -8.62012982e-01,
                         -3.08238626e-01,   9.90259767e-01,  -1.05113633e-01,
                         -9.46631491e-01,   4.99797076e-01,   7.37621725e-01,
                         -8.08035731e-01,  -4.00974035e-01,   9.74837661e-01,
                         -6.08766219e-03,  -9.72605526e-01,   4.11728889e-01,
                          8.00527573e-01,  -7.45941579e-01,  -4.89650965e-01,
                          9.50081170e-01,   9.29383114e-02,  -9.89042222e-01,
                          3.19399357e-01,   8.55519474e-01,  -6.76745117e-01,
                         -5.73457778e-01,   9.15584445e-01,   1.91152602e-01,
                         -9.95738626e-01,   2.24025980e-01,   9.01988626e-01,
                         -6.00649357e-01,  -6.51582778e-01,   8.72159064e-01,
                          2.87540585e-01,  -9.92491901e-01,   1.26217529e-01,
                          9.39529240e-01,  -5.18465936e-01,  -7.23417222e-01,
                          8.20008099e-01,   3.80884737e-01,  -9.79301929e-01,
                          2.73944810e-02,   9.67532456e-01,  -4.31412339e-01,
                         -7.87946403e-01,   7.59740233e-01,   4.70576286e-01,
                         -9.56371725e-01,  -7.18344152e-02,   9.86201286e-01,
                         -3.39894474e-01,  -8.44561696e-01,   6.91964269e-01,
                          5.55600643e-01,  -9.24107134e-01,  -1.70251623e-01,
                          9.94926929e-01,  -2.44926944e-01,  -8.92857134e-01,
                          6.17288947e-01,   6.35146081e-01,  -8.82711053e-01,
                         -2.67248362e-01,   9.93709445e-01,  -1.47727266e-01,
                         -9.32426929e-01,   5.36525965e-01,   7.08400965e-01,
                         -8.32386374e-01,  -3.61404210e-01,   9.82954562e-01,
                         -4.91071418e-02,  -9.62662339e-01,   4.50284094e-01,
                          7.74553597e-01,  -7.73944795e-01,  -4.51907456e-01,
                          9.62256491e-01,   5.03246747e-02,  -9.83360410e-01,
                          3.59780848e-01,   8.32995117e-01,  -7.07589269e-01,
                         -5.38149357e-01,   9.31818187e-01,   1.48944810e-01,
                         -9.94318187e-01,   2.65625000e-01,   8.83319795e-01,
                         -6.34334445e-01,  -6.18912339e-01,   8.92248392e-01,
                          2.46347398e-01,  -9.95535731e-01,   1.68628246e-01,
                          9.24715936e-01,  -5.54788947e-01,  -6.93587661e-01,
                          8.43952894e-01,   3.41314942e-01,  -9.86607134e-01,
                          7.00081140e-02,   9.57183421e-01,  -4.69764620e-01,
                         -7.61363626e-01,   7.87134767e-01,   4.32832778e-01,
                         -9.68141258e-01,  -2.92207785e-02,   9.79910731e-01,
                         -3.79870117e-01,  -8.21631491e-01,   7.22402573e-01,
                          5.19886374e-01,  -9.39935088e-01,  -1.28246754e-01,
                          9.93100643e-01,  -2.86323041e-01,  -8.73782456e-01,
                          6.50771081e-01,   6.02069795e-01,  -9.02191579e-01,
                         -2.26055190e-01,   9.96347427e-01,  -1.89935058e-01,
                         -9.17410731e-01,   5.72443187e-01,   6.78165555e-01,
                         -8.55722427e-01,  -3.21631491e-01,   9.89650965e-01,
                         -9.15178582e-02,  -9.51704562e-01,   4.88230526e-01,
                          7.47564912e-01,  -8.00527573e-01,  -4.13961053e-01,
                          9.73011374e-01,   7.71103892e-03,  -9.76663947e-01,
                          3.99350643e-01,   8.09659064e-01,  -7.37621725e-01,
                         -5.02232134e-01,   9.46834445e-01,   1.06939934e-01,
                         -9.91883099e-01,   3.06412339e-01,   8.63636374e-01,
                         -6.67004883e-01,  -5.85633099e-01,   9.11323071e-01,
                          2.05154225e-01,  -9.97159064e-01,   2.10430190e-01,
                          9.09090936e-01,  -5.90097427e-01,  -6.63149357e-01,
                          8.66477251e-01,   3.01542222e-01,  -9.92491901e-01,
                          1.12418830e-01,   9.45413947e-01,  -5.07102251e-01,
                         -7.34172106e-01,   8.13108742e-01,   3.94683450e-01,
                         -9.78084445e-01,   1.31899351e-02,   9.72402573e-01,
                         -4.19034094e-01,  -7.97686696e-01,   7.51623392e-01,
                          4.83969152e-01,  -9.53936696e-01,  -8.64448026e-02,
                          9.89650965e-01,  -3.26704532e-01,  -8.53490233e-01,
                          6.82629883e-01,   5.68384767e-01,  -9.20048714e-01,
                         -1.84862018e-01,   9.96956170e-01,  -2.31331170e-01,
                         -9.00771081e-01,   6.06737018e-01,   6.47321403e-01,
                         -8.77232134e-01,  -2.81655848e-01,   9.94521081e-01,
                         -1.33522734e-01,  -9.38920438e-01,   5.24959445e-01,
                          7.19764590e-01,  -8.25689912e-01,  -3.75608772e-01,
                          9.82142866e-01,  -3.42938304e-02,  -9.67938304e-01,
                          4.37905848e-01,   7.84902573e-01,  -7.65625000e-01,
                         -4.65706170e-01,   9.59821403e-01,   6.51379898e-02,
                         -9.87215936e-01,   3.46387982e-01,   8.42329562e-01,
                         -6.98254883e-01,  -5.51339269e-01,   9.27962661e-01,
                          1.63961038e-01,  -9.96753275e-01,   2.51420468e-01,
                          8.91436696e-01,  -6.23782456e-01,  -6.31493509e-01,
                          8.86972427e-01,   2.61160702e-01,  -9.96144474e-01,
                          1.54017851e-01,   9.31615233e-01,  -5.43019474e-01,
                         -7.05357134e-01,   8.37053597e-01,   3.55722398e-01,
                         -9.85795438e-01,   5.51948063e-02,   9.62459445e-01,
                         -4.56980526e-01,  -7.72118509e-01,   7.78814912e-01,
                          4.46834415e-01,  -9.65706170e-01,  -4.44399342e-02,
                          9.83766258e-01,  -3.66274357e-01,  -8.31168830e-01,
                          7.12865233e-01,   5.33482134e-01,  -9.35673714e-01,
                         -1.43465906e-01,   9.95332778e-01,  -2.72118509e-01,
                         -8.81899357e-01,   6.39813304e-01,   6.14650965e-01,
                         -8.96712661e-01,  -2.41071433e-01,   9.96956170e-01,
                         -1.75121754e-01,  -9.23904240e-01,   5.60470760e-01,
                          6.89935088e-01,  -8.48620117e-01,  -3.36241871e-01,
                          9.88636374e-01,  -7.65016228e-02,  -9.56777573e-01,
                          4.75446433e-01,   7.58116901e-01,  -7.92004883e-01,
                         -4.27962661e-01,   9.70373392e-01,   2.29301956e-02,
                         -9.80113626e-01,   3.85754883e-01,   8.18790555e-01,
                         -7.27678597e-01,  -5.15625000e-01,   9.42573071e-01,
                          1.22159094e-01,  -9.93709445e-01,   2.92207778e-01,
                          8.71550322e-01,  -6.56047106e-01,  -5.98011374e-01,
                          9.05438304e-01,   2.19967529e-01,  -9.97362018e-01,
                          1.95819810e-01,   9.15381491e-01,  -5.77922106e-01,
                         -6.74310088e-01,   8.59172106e-01,   3.15746754e-01,
                         -9.91274357e-01,   9.74025950e-02,   9.50081170e-01,
                         -4.94115263e-01,  -7.44115233e-01,   8.04586053e-01,
                          4.08279210e-01,  -9.75040555e-01,  -1.82629866e-03,
                          9.75446403e-01,  -4.05438304e-01,  -8.06412339e-01,
                          7.41680205e-01,   4.96753246e-01,  -9.49269474e-01,
                         -1.01055197e-01,   9.91274357e-01,  -3.12702924e-01,
                         -8.60795438e-01,   6.71672106e-01,   5.80357134e-01,
                         -9.14163947e-01,  -1.99269474e-01,   9.96956170e-01,
                         -2.16923699e-01,  -9.06655848e-01,   5.94967544e-01,
                          6.58076286e-01,  -8.69926929e-01,  -2.95454532e-01,
                          9.92897749e-01,  -1.19115263e-01,  -9.43384767e-01,
                          5.12378275e-01,   7.29301929e-01,  -8.16964269e-01,
                         -3.88595790e-01,   9.78896081e-01,  -1.98863633e-02,
                         -9.70779240e-01,   4.24715906e-01,   7.93222427e-01,
                         -7.56087661e-01,  -4.78084415e-01,   9.55357134e-01,
                          7.93425292e-02,  -9.88636374e-01,   3.32995117e-01,
                          8.49228919e-01,  -6.87500000e-01,  -5.62702894e-01,
                          9.22280848e-01,   1.77759737e-01,  -9.96550322e-01,
                          2.37824678e-01,   8.96915555e-01,  -6.12418830e-01,
                         -6.41639590e-01,   8.79870117e-01,   2.74350643e-01,
                         -9.94724035e-01,   1.40422076e-01,   9.35673714e-01,
                         -5.31047106e-01,  -7.14285731e-01,   8.28936696e-01,
                          3.68303567e-01,  -9.82954562e-01,   4.15990278e-02,
                          9.65300322e-01,  -4.44399357e-01,  -7.80032456e-01,
                          7.69683421e-01,   4.58603889e-01,  -9.61444795e-01,
                         -5.78327924e-02,   9.85186696e-01,  -3.53490263e-01,
                         -8.37865233e-01,   7.02922106e-01,   5.44237018e-01,
                         -9.30397749e-01,  -1.56452924e-01,   9.95332778e-01,
                         -2.58928567e-01,  -8.87378275e-01,   6.29058421e-01,
                          6.24594152e-01,  -8.90016258e-01,  -2.53449678e-01,
                          9.95738626e-01,  -1.61931813e-01,  -9.28165555e-01,
                          5.49107134e-01,   6.98863626e-01,  -8.40909064e-01,
                         -3.48214298e-01,   9.85998392e-01,  -6.33116886e-02,
                         -9.59821403e-01,   4.63676959e-01,   7.66030848e-01,
                         -7.83482134e-01,  -4.39326286e-01,   9.66720760e-01,
                          3.59172076e-02,  -9.81737018e-01,   3.73579532e-01,
                          8.25689912e-01,  -7.18344152e-01,  -5.26176929e-01,
                          9.37702894e-01,   1.34740263e-01,  -9.94115233e-01,
                          2.79829532e-01,   8.77029240e-01,  -6.45900965e-01,
                         -6.07751608e-01,   8.99553597e-01,   2.32345775e-01,
                         -9.96550322e-01,   1.83238640e-01,   9.19845760e-01,
                         -5.67167222e-01,  -6.83441579e-01,   8.52272749e-01,
                          3.27719152e-01,  -9.89245117e-01,   8.48214254e-02,
                          9.53530848e-01,  -4.82954532e-01,  -7.52232134e-01,
                          7.96672106e-01,   4.19642866e-01,  -9.71996725e-01,
                         -1.44074671e-02,   9.77678597e-01,  -3.93668830e-01,
                         -8.13514590e-01,   7.33157456e-01,   5.07508099e-01,
                         -9.45211053e-01,  -1.13636367e-01,   9.92288947e-01,
                         -3.00527602e-01,  -8.66883099e-01,   6.62134767e-01,
                          5.90503275e-01,  -9.08887982e-01,  -2.11444810e-01,
                          9.96956170e-01,  -2.04545453e-01,  -9.11728919e-01,
                          5.84821403e-01,   6.67410731e-01,  -8.63636374e-01,
                         -3.07426959e-01,   9.91680205e-01,  -1.06331170e-01,
                         -9.47443187e-01,   5.01623392e-01,   7.37824678e-01,
                         -8.09659064e-01,  -4.00365263e-01,   9.76461053e-01,
                         -7.30519462e-03,  -9.73620117e-01,   4.13352281e-01,
                          8.00933421e-01,  -7.47767866e-01,  -4.89245117e-01,
                          9.51704562e-01,   9.19236988e-02,  -9.90259767e-01,
                          3.21022719e-01,   8.56128275e-01,  -6.78368509e-01,
                         -5.73254883e-01,   9.17410731e-01,   1.90340906e-01,
                         -9.97159064e-01,   2.25446433e-01,   9.02800322e-01,
                         -6.02272749e-01,  -6.51582778e-01,   8.73985410e-01,
                          2.86728889e-01,  -9.93912339e-01,   1.27637982e-01,
                          9.40340936e-01,  -5.20089269e-01,  -7.23417222e-01,
                          8.22037339e-01,   3.80478889e-01,  -9.80925322e-01,
                          2.86120139e-02,   9.68750000e-01,  -4.32832778e-01,
                         -7.88149357e-01,   7.61769474e-01,   4.70170468e-01,
                         -9.58198071e-01,  -7.08198026e-02,   9.87418830e-01,
                         -3.41314942e-01,  -8.45170438e-01,   6.93790555e-01,
                          5.55397749e-01,  -9.25933421e-01,  -1.69439942e-01,
                          9.96347427e-01,  -2.46347398e-01,  -8.93668830e-01,
                          6.19115233e-01,   6.35146081e-01,  -8.84334445e-01,
                         -2.66436696e-01,   9.95332778e-01,  -1.48944810e-01,
                         -9.33238626e-01,   5.38149357e-01,   7.08400965e-01,
                         -8.34009767e-01,  -3.60592544e-01,   9.84375000e-01,
                         -5.01217544e-02,  -9.63676929e-01,   4.51907456e-01,
                          7.74756491e-01,  -7.75568187e-01,  -4.51298714e-01,
                          9.63676929e-01,   4.93100658e-02,  -9.84375000e-01,
                          3.61201286e-01,   8.33400965e-01,  -7.09212661e-01,
                         -5.37540555e-01,   9.33441579e-01,   1.48133114e-01,
                         -9.95332778e-01,   2.66842544e-01,   8.83725643e-01,
                         -6.35957778e-01,  -6.18506491e-01,   8.93871725e-01,
                          2.45332792e-01,  -9.96347427e-01,   1.70048699e-01,
                          9.25121725e-01,  -5.56209445e-01,  -6.93181813e-01,
                          8.45373392e-01,   3.40300322e-01,  -9.87621725e-01,
                          7.14285746e-02,   9.57589269e-01,  -4.71185058e-01,
                         -7.60957778e-01,   7.88555205e-01,   4.31818187e-01,
                         -9.68952894e-01,  -2.78003253e-02,   9.80316579e-01,
                         -3.81290585e-01,  -8.21225643e-01,   7.23823071e-01,
                          5.19074678e-01,  -9.40746725e-01,  -1.26826301e-01,
                          9.93303597e-01,  -2.87743509e-01,  -8.73376608e-01,
                          6.51988626e-01,   6.01055205e-01,  -9.03206170e-01,
                         -2.24634737e-01,   9.96550322e-01,  -1.91355526e-01,
                         -9.16801929e-01,   5.73660731e-01,   6.77150965e-01,
                         -8.56534064e-01,  -3.20008129e-01,   9.89853919e-01,
                         -9.31412354e-02,  -9.51095760e-01,   4.89650965e-01,
                          7.46550322e-01,  -8.01542222e-01,  -4.12337661e-01,
                          9.73417222e-01,   6.08766219e-03,  -9.76055205e-01,
                          4.00974035e-01,   8.08441579e-01,  -7.38433421e-01,
                         -5.00405848e-01,   9.47240233e-01,   1.05113633e-01,
                         -9.91274357e-01,   3.08238626e-01,   8.62215936e-01,
                         -6.68222427e-01,  -5.83603919e-01,   9.11525965e-01,
                          2.03125000e-01,  -9.96550322e-01,   2.12459415e-01,
                          9.07467544e-01,  -5.91314912e-01,  -6.60917222e-01,
                          8.66883099e-01,   2.99107134e-01,  -9.92086053e-01,
                          1.14448056e-01,   9.43790555e-01,  -5.08522749e-01,
                         -7.31737018e-01,   8.13717544e-01,   3.92045468e-01,
                         -9.77678597e-01,   1.54220778e-02,   9.70779240e-01,
                         -4.20860380e-01,  -7.95251608e-01,   7.52435088e-01,
                          4.81128246e-01,  -9.53530848e-01,  -8.36038962e-02,
                          9.88027573e-01,  -3.28936696e-01,  -8.51055205e-01,
                          6.83847427e-01,   5.65340936e-01,  -9.20048714e-01,
                         -1.81818187e-01,   9.95535731e-01,  -2.33766228e-01,
                         -8.98133099e-01,   6.08360410e-01,   6.44074678e-01,
                         -8.77232134e-01,  -2.78206170e-01,   9.93303597e-01,
                         -1.36160716e-01,  -9.36485410e-01,   5.26785731e-01,
                          7.16314912e-01,  -8.25892866e-01,  -3.71956170e-01,
                          9.80925322e-01,  -3.75405848e-02,  -9.65503275e-01,
                          4.39935058e-01,   7.81452894e-01,  -7.66436696e-01,
                         -4.62053567e-01,   9.59009767e-01,   6.16883114e-02,
                         -9.84983742e-01,   3.49025965e-01,   8.38879883e-01,
                         -6.99269474e-01,  -5.47483742e-01,   9.27556813e-01,
                          1.60308436e-01,  -9.94521081e-01,   2.54464298e-01,
                          8.87987018e-01,  -6.25202894e-01,  -6.27435088e-01,
                          8.86769474e-01,   2.57305205e-01,  -9.94318187e-01,
                          1.57264605e-01,   9.28368509e-01,  -5.44845760e-01,
                         -7.01095760e-01,   8.37256491e-01,   3.51663947e-01,
                         -9.84375000e-01,   5.86444810e-02,   9.59415555e-01,
                         -4.59212661e-01,  -7.68060088e-01,   7.79423714e-01,
                          4.42573041e-01,  -9.64488626e-01,  -4.05844152e-02,
                          9.80925322e-01,  -3.68912339e-01,  -8.27313304e-01,
                          7.13879883e-01,   5.29220760e-01,  -9.34862018e-01,
                         -1.39407471e-01,   9.92897749e-01,  -2.74959415e-01,
                         -8.78246725e-01,   6.41030848e-01,   6.10592544e-01,
                         -8.96103919e-01,  -2.37012982e-01,   9.94724035e-01,
                         -1.78165585e-01,  -9.20657456e-01,   5.61891258e-01,
                          6.85876608e-01,  -8.48417222e-01,  -3.32183450e-01,
                          9.86607134e-01,  -7.95454532e-02,  -9.53733742e-01,
                          4.77069795e-01,   7.54261374e-01,  -7.92004883e-01,
                         -4.24310058e-01,   9.68750000e-01,   2.00892854e-02,
                         -9.77272749e-01,   3.87378246e-01,   8.15340936e-01,
                         -7.27881491e-01,  -5.12175322e-01,   9.41152573e-01,
                          1.19318180e-01,  -9.91274357e-01,   2.93628246e-01,
                          8.68303597e-01,  -6.56047106e-01,  -5.94967544e-01,
                          9.04220760e-01,   2.17329547e-01,  -9.95129883e-01,
                          1.97646111e-01,   9.12337661e-01,  -5.78733742e-01,
                         -6.70860410e-01,   8.58766258e-01,   3.12297076e-01,
                         -9.89245117e-01,   1.00243509e-01,   9.47240233e-01,
                         -4.95738626e-01,  -7.40462661e-01,   8.04586053e-01,
                          4.04423714e-01,  -9.73823071e-01,   1.42045459e-03,
                          9.72808421e-01,  -4.07670468e-01,  -8.02759767e-01,
                          7.42491901e-01,   4.92694795e-01,  -9.48457778e-01,
                         -9.71996784e-02,   9.88839269e-01,  -3.15543830e-01,
                         -8.57345760e-01,   6.73092544e-01,   5.76095760e-01,
                         -9.13961053e-01,  -1.95211038e-01,   9.95129883e-01,
                         -2.20170453e-01,  -9.03409064e-01,   5.96996725e-01,
                          6.54017866e-01,  -8.70129883e-01,  -2.91193187e-01,
                          9.91477251e-01,  -1.22564934e-01,  -9.40543830e-01,
                          5.14813304e-01,   7.25446403e-01,  -8.17775965e-01,
                         -3.84537339e-01,   9.78084445e-01,  -2.37418823e-02,
                         -9.68344152e-01,   4.27556813e-01,   7.89569795e-01,
                         -7.57305205e-01,  -4.74025965e-01,   9.54951286e-01,
                          7.52840936e-02,  -9.86607134e-01,   3.36038947e-01,
                          8.45982134e-01,  -6.89326286e-01,  -5.58847427e-01,
                          9.22280848e-01,   1.73701301e-01,  -9.95129883e-01,
                          2.41071433e-01,   8.94074678e-01,  -6.14448071e-01,
                         -6.37987018e-01,   8.80478919e-01,   2.70495117e-01,
                         -9.93709445e-01,   1.43668830e-01,   9.33441579e-01,
                         -5.33279240e-01,  -7.11038947e-01,   8.29951286e-01,
                          3.64650965e-01,  -9.82345760e-01,   4.48457785e-02,
                          9.63271081e-01,  -4.47037339e-01,  -7.76988626e-01,
                          7.70900965e-01,   4.55154210e-01,  -9.61241901e-01,
                         -5.43831177e-02,   9.83563304e-01,  -3.56128246e-01,
                         -8.35227251e-01,   7.04342544e-01,   5.40990233e-01,
                         -9.30600643e-01,  -1.53206170e-01,   9.94115233e-01,
                         -2.61769474e-01,  -8.85146081e-01,   6.30884767e-01,
                          6.21753275e-01,  -8.90625000e-01,  -2.50405848e-01,
                          9.94926929e-01,  -1.64772734e-01,  -9.26339269e-01,
                          5.50933421e-01,   6.96225643e-01,  -8.41720760e-01,
                         -3.45373362e-01,   9.85592544e-01,  -6.61525950e-02,
                         -9.58400965e-01,   4.65503246e-01,   7.63595760e-01,
                         -7.84699678e-01,  -4.36688304e-01,   9.66517866e-01,
                          3.32792215e-02,  -9.80722427e-01,   3.75608772e-01,
                          8.23660731e-01,  -7.19561696e-01,  -5.23741901e-01,
                          9.37905848e-01,   1.32305190e-01,  -9.93303597e-01,
                          2.81858772e-01,   8.75405848e-01,  -6.47321403e-01,
                         -6.05519474e-01,   8.99959445e-01,   2.29910716e-01,
                         -9.96144474e-01,   1.85267851e-01,   9.18425322e-01,
                         -5.68790555e-01,  -6.81412339e-01,   8.52881491e-01,
                          3.25284094e-01,  -9.89042222e-01,   8.68506506e-02,
                          9.52313304e-01,  -4.84375000e-01,  -7.50405848e-01,
                          7.97483742e-01,   4.17613626e-01,  -9.71996725e-01,
                         -1.23782465e-02,   9.76866901e-01,  -3.95292222e-01,
                         -8.12094152e-01,   7.33969152e-01,   5.05681813e-01,
                         -9.45211053e-01,  -1.11607142e-01,   9.91477251e-01,
                         -3.02353889e-01,  -8.65665555e-01,   6.63149357e-01,
                          5.88676929e-01,  -9.09293830e-01,  -2.09618509e-01,
                          9.96347427e-01,  -2.06168830e-01,  -9.10511374e-01,
                          5.85836053e-01,   6.65787339e-01,  -8.64042222e-01,
                         -3.05600643e-01,   9.91274357e-01,  -1.08157471e-01,
                         -9.46428597e-01,   5.02637982e-01,   7.36201286e-01,
                         -8.10267866e-01,  -3.98538947e-01,   9.76461053e-01,
                         -8.92857183e-03,  -9.72808421e-01,   4.14569795e-01,
                          7.99512982e-01,  -7.48579562e-01,  -4.87621754e-01,
                          9.51704562e-01,   9.03003216e-02,  -9.89650965e-01,
                          3.22240263e-01,   8.54707778e-01,  -6.79383099e-01,
                         -5.71631491e-01,   9.17613626e-01,   1.88514605e-01,
                         -9.96550322e-01,   2.26866886e-01,   9.01582778e-01,
                         -6.03287339e-01,  -6.50162339e-01,   8.74391258e-01,
                          2.85105526e-01,  -9.93506491e-01,   1.29058436e-01,
                          9.39326286e-01,  -5.21306813e-01,  -7.21996725e-01,
                          8.22443187e-01,   3.78652602e-01,  -9.80722427e-01,
                          3.00324671e-02,   9.67735410e-01,  -4.34253246e-01,
                         -7.86931813e-01,   7.62175322e-01,   4.68547076e-01,
                         -9.58198071e-01,  -6.91964254e-02,   9.86607134e-01,
                         -3.42735380e-01,  -8.43952894e-01,   6.94602251e-01,
                          5.53774357e-01,  -9.25933421e-01,  -1.67816564e-01,
                          9.95738626e-01,  -2.47767851e-01,  -8.92451286e-01,
                          6.19926929e-01,   6.33522749e-01,  -8.84537339e-01,
                         -2.64813304e-01,   9.94724035e-01,  -1.50568187e-01,
                         -9.32224035e-01,   5.39163947e-01,   7.06777573e-01,
                         -8.34415555e-01,  -3.58969152e-01,   9.83969152e-01,
                         -5.17451316e-02,  -9.62662339e-01,   4.53125000e-01,
                          7.73133099e-01,  -7.75974035e-01,  -4.49675322e-01,
                          9.63474035e-01,   4.74837646e-02,  -9.83563304e-01,
                          3.62418830e-01,   8.31980526e-01,  -7.09821403e-01,
                         -5.35917222e-01,   9.33238626e-01,   1.46306813e-01,
                         -9.94724035e-01,   2.68262982e-01,   8.82305205e-01,
                         -6.36769474e-01,  -6.16883099e-01,   8.93871725e-01,
                          2.43709415e-01,  -9.95941579e-01,   1.71266228e-01,
                          9.23904240e-01,  -5.57224035e-01,  -6.91761374e-01,
                          8.45576286e-01,   3.38676959e-01,  -9.87215936e-01,
                          7.28490278e-02,   9.56371725e-01,  -4.72199678e-01,
                         -7.59740233e-01,   7.88961053e-01,   4.30194795e-01,
                         -9.68750000e-01,  -2.63798703e-02,   9.79301929e-01,
                         -3.82508129e-01,  -8.20008099e-01,   7.24228919e-01,
                          5.17451286e-01,  -9.40543830e-01,  -1.25405848e-01,
                          9.92694795e-01,  -2.88961053e-01,  -8.72159064e-01,
                          6.52597427e-01,   5.99634767e-01,  -9.03206170e-01,
                         -2.23214284e-01,   9.95941579e-01,  -1.92573056e-01,
                         -9.15787339e-01,   5.74269474e-01,   6.75730526e-01,
                         -8.56737018e-01,  -3.18790585e-01,   9.89448071e-01,
                         -9.43587646e-02,  -9.50284064e-01,   4.90462661e-01,
                          7.45332778e-01,  -8.01745117e-01,  -4.11120117e-01,
                          9.73011374e-01,   4.87012975e-03,  -9.75243509e-01,
                          4.01582778e-01,   8.07224035e-01,  -7.38839269e-01,
                         -4.99391228e-01,   9.47037339e-01,   1.04099028e-01,
                         -9.90665555e-01,   3.08847398e-01,   8.61404240e-01,
                         -6.68628275e-01,  -5.82792222e-01,   9.11525965e-01,
                          2.02110395e-01,  -9.96144474e-01,   2.13068187e-01,
                          9.06858742e-01,  -5.91720760e-01,  -6.60308421e-01,
                          8.66883099e-01,   2.98295468e-01,  -9.91680205e-01,
                          1.15056820e-01,   9.43384767e-01,  -5.08928597e-01,
                         -7.31128275e-01,   8.13717544e-01,   3.91436696e-01,
                         -9.77475643e-01,   1.60308443e-02,   9.70373392e-01,
                         -4.21063304e-01,  -7.94845760e-01,   7.52435088e-01,
                          4.80722398e-01,  -9.53327894e-01,  -8.34009722e-02,
                          9.87824678e-01,  -3.29139620e-01,  -8.50649357e-01,
                          6.83644474e-01,   5.65137982e-01,  -9.19845760e-01,
                         -1.81818187e-01,   9.95332778e-01,  -2.33766228e-01,
                         -8.98133099e-01,   6.08157456e-01,   6.44074678e-01,
                         -8.77232134e-01,  -2.78409094e-01,   9.93100643e-01,
                         -1.36160716e-01,  -9.36485410e-01,   5.26582778e-01,
                          7.16517866e-01,  -8.25892866e-01,  -3.72159094e-01,
                          9.80925322e-01,  -3.71347405e-02,  -9.65706170e-01,
                          4.39732134e-01,   7.81858742e-01,  -7.66436696e-01,
                         -4.62459415e-01,   9.59009767e-01,   6.20941557e-02,
                         -9.85186696e-01,   3.48620117e-01,   8.39285731e-01,
                         -6.99066579e-01,  -5.47889590e-01,   9.27556813e-01,
                          1.60714284e-01,  -9.94926929e-01,   2.53855526e-01,
                          8.88595760e-01,  -6.25000000e-01,  -6.28043830e-01,
                          8.86769474e-01,   2.57913947e-01,  -9.94724035e-01,
                          1.56655848e-01,   9.28977251e-01,  -5.44642866e-01,
                         -7.02110410e-01,   8.37256491e-01,   3.52475643e-01,
                         -9.84780848e-01,   5.80357127e-02,   9.60227251e-01,
                         -4.58806813e-01,  -7.68871725e-01,   7.79423714e-01,
                          4.43384737e-01,  -9.64894474e-01,  -4.13961038e-02,
                          9.81737018e-01,  -3.68506491e-01,  -8.28327894e-01,
                          7.13879883e-01,   5.30032456e-01,  -9.35470760e-01,
                         -1.40219152e-01,   9.93709445e-01,  -2.74553567e-01,
                         -8.79261374e-01,   6.41233742e-01,   6.11404240e-01,
                         -8.96712661e-01,  -2.37824678e-01,   9.95535731e-01,
                         -1.77759737e-01,  -9.21672106e-01,   5.62094152e-01,
                          6.86891258e-01,  -8.49025965e-01,  -3.32995117e-01,
                          9.87621725e-01,  -7.93425292e-02,  -9.54748392e-01,
                          4.77272719e-01,   7.55275965e-01,  -7.92816579e-01,
                         -4.24918830e-01,   9.69967544e-01,   1.98863633e-02,
                         -9.78490233e-01,   3.87987018e-01,   8.16355526e-01,
                         -7.28896081e-01,  -5.12378275e-01,   9.42573071e-01,
                          1.19115263e-01,  -9.92491901e-01,   2.94642866e-01,
                          8.69115233e-01,  -6.57670438e-01,  -5.94967544e-01,
                          9.05641258e-01,   2.16923699e-01,  -9.96550322e-01,
                          1.98457792e-01,   9.13352251e-01,  -5.79748392e-01,
                         -6.71672106e-01,   8.59983742e-01,   3.12702924e-01,
                         -9.90665555e-01,   1.00243509e-01,   9.48457778e-01,
                         -4.96347398e-01,  -7.41680205e-01,   8.05600643e-01,
                          4.05438304e-01,  -9.75040555e-01,   1.01461040e-03,
                          9.74228919e-01,  -4.07873362e-01,  -8.04383099e-01,
                          7.43100643e-01,   4.93912339e-01,  -9.49675322e-01,
                         -9.82142836e-02,   9.90259767e-01,  -3.15340906e-01,
                         -8.58969152e-01,   6.73498392e-01,   5.77719152e-01,
                         -9.14772749e-01,  -1.96428567e-01,   9.96550322e-01,
                         -2.19561681e-01,  -9.05032456e-01,   5.96996725e-01,
                          6.55641258e-01,  -8.70941579e-01,  -2.92613626e-01,
                          9.92694795e-01,  -1.21753246e-01,  -9.42167222e-01,
                          5.14610410e-01,   7.27069795e-01,  -8.18384767e-01,
                         -3.85957778e-01,   9.79099035e-01,  -2.27272734e-02,
                         -9.69967544e-01,   4.27150965e-01,   7.91396081e-01,
                         -7.57711053e-01,  -4.75649357e-01,   9.55762982e-01,
                          7.65016228e-02,  -9.88027573e-01,   3.35430205e-01,
                          8.47808421e-01,  -6.89326286e-01,  -5.60470760e-01,
                          9.23092544e-01,   1.75121754e-01,  -9.96347427e-01,
                          2.40259737e-01,   8.95698071e-01,  -6.14245117e-01,
                         -6.39610410e-01,   8.81087661e-01,   2.71915585e-01,
                         -9.94724035e-01,   1.42857149e-01,   9.34862018e-01,
                         -5.33076286e-01,  -7.12662339e-01,   8.30154240e-01,
                          3.65868509e-01,  -9.83157456e-01,   4.40340899e-02,
                          9.64488626e-01,  -4.46631491e-01,  -7.78409064e-01,
                          7.71103919e-01,   4.56371754e-01,  -9.61850643e-01,
                         -5.53977266e-02,   9.84780848e-01,  -3.55722398e-01,
                         -8.36444795e-01,   7.04545438e-01,   5.42207778e-01,
                         -9.31006491e-01,  -1.54017851e-01,   9.95129883e-01,
                         -2.61363626e-01,  -8.86363626e-01,   6.30884767e-01,
                          6.22767866e-01,  -8.91030848e-01,  -2.51420468e-01,
                          9.95535731e-01,  -1.64163962e-01,  -9.27150965e-01,
                          5.50933421e-01,   6.97037339e-01,  -8.42126608e-01,
                         -3.45982134e-01,   9.86201286e-01,  -6.55438304e-02,
                         -9.59009767e-01,   4.65503246e-01,   7.64407456e-01,
                         -7.84699678e-01,  -4.37297076e-01,   9.66923714e-01,
                          3.36850658e-02,  -9.81331170e-01,   3.75405848e-01,
                          8.24269474e-01,  -7.19561696e-01,  -5.24350643e-01,
                          9.38108742e-01,   1.32711038e-01,  -9.93709445e-01,
                          2.81655848e-01,   8.75811696e-01,  -6.47321403e-01,
                         -6.05925322e-01,   8.99959445e-01,   2.30316564e-01,
                         -9.96347427e-01,   1.85064942e-01,   9.18831170e-01,
                         -5.68790555e-01,  -6.81615233e-01,   8.52881491e-01,
                          3.25689942e-01,  -9.89042222e-01,   8.66477266e-02,
                          9.52516258e-01,  -4.84375000e-01,  -7.50608742e-01,
                          7.97280848e-01,   4.17816550e-01,  -9.71996725e-01,
                         -1.25811687e-02,   9.76866901e-01,  -3.95292222e-01,
                         -8.12094152e-01,   7.33969152e-01,   5.05681813e-01,
                         -9.45211053e-01,  -1.11607142e-01,   9.91477251e-01,
                         -3.02150965e-01,  -8.65462661e-01,   6.63149357e-01,
                          5.88676929e-01,  -9.08887982e-01,  -2.09618509e-01,
                          9.96144474e-01,  -2.06168830e-01,  -9.10308421e-01,
                          5.85633099e-01,   6.65584445e-01,  -8.63636374e-01,
                         -3.05600643e-01,   9.91071403e-01,  -1.08157471e-01,
                         -9.46022749e-01,   5.02637982e-01,   7.36201286e-01,
                         -8.09862018e-01,  -3.98538947e-01,   9.75852251e-01,
                         -8.92857183e-03,  -9.72402573e-01,   4.14366871e-01,
                          7.99310088e-01,  -7.48173714e-01,  -4.87418830e-01,
                          9.51298714e-01,   9.03003216e-02,  -9.89042222e-01,
                          3.22037339e-01,   8.54504883e-01,  -6.78774357e-01,
                         -5.71428597e-01,   9.17004883e-01,   1.88717529e-01,
                         -9.95941579e-01,   2.26663962e-01,   9.01176929e-01,
                         -6.02881491e-01,  -6.49756491e-01,   8.73782456e-01,
                          2.85105526e-01,  -9.92897749e-01,   1.28855526e-01,
                          9.38920438e-01,  -5.20698071e-01,  -7.21793830e-01,
                          8.21631491e-01,   3.78652602e-01,  -9.79910731e-01,
                          2.98295449e-02,   9.67329562e-01,  -4.33644474e-01,
                         -7.86525965e-01,   7.61566579e-01,   4.68547076e-01,
                         -9.57386374e-01,  -6.93993494e-02,   9.85998392e-01,
                         -3.42126638e-01,  -8.43547106e-01,   6.93790555e-01,
                          5.53774357e-01,  -9.25121725e-01,  -1.68019474e-01,
                          9.94926929e-01,  -2.47159094e-01,  -8.92045438e-01,
                          6.19115233e-01,   6.33522749e-01,  -8.83725643e-01,
                         -2.65016228e-01,   9.94115233e-01,  -1.49756491e-01,
                         -9.31818187e-01,   5.38352251e-01,   7.06980526e-01,
                         -8.33603919e-01,  -3.59375000e-01,   9.83360410e-01,
                         -5.09334430e-02,  -9.62256491e-01,   4.52313304e-01,
                          7.73336053e-01,  -7.75162339e-01,  -4.50081170e-01,
                          9.62662339e-01,   4.82954532e-02,  -9.83157456e-01,
                          3.61607134e-01,   8.31980526e-01,  -7.08806813e-01,
                         -5.36525965e-01,   9.32426929e-01,   1.47118509e-01,
                         -9.94115233e-01,   2.67248362e-01,   8.82305205e-01,
                         -6.35754883e-01,  -6.17491901e-01,   8.93060088e-01,
                          2.44521111e-01,  -9.95332778e-01,   1.70454547e-01,
                          9.24107134e-01,  -5.56209445e-01,  -6.92167222e-01,
                          8.44764590e-01,   3.39691550e-01,  -9.86607134e-01,
                          7.18344152e-02,   9.56371725e-01,  -4.70982134e-01,
                         -7.60146081e-01,   7.87946403e-01,   4.31209415e-01,
                         -9.68141258e-01,  -2.75974032e-02,   9.79301929e-01,
                         -3.81290585e-01,  -8.20616901e-01,   7.23417222e-01,
                          5.18465936e-01,  -9.39935088e-01,  -1.26623377e-01,
                          9.92491901e-01,  -2.87743509e-01,  -8.72767866e-01,
                          6.51582778e-01,   6.00649357e-01,  -9.02394474e-01,
                         -2.24431813e-01,   9.95941579e-01,  -1.91355526e-01,
                         -9.16193187e-01,   5.73254883e-01,   6.76948071e-01,
                         -8.55925322e-01,  -3.20008129e-01,   9.89245117e-01,
                         -9.29383114e-02,  -9.50689912e-01,   4.89448041e-01,
                          7.46347427e-01,  -8.00933421e-01,  -4.12337661e-01,
                          9.72808421e-01,   6.29058434e-03,  -9.75649357e-01,
                          4.00568187e-01,   8.08441579e-01,  -7.38027573e-01,
                         -5.00608742e-01,   9.46631491e-01,   1.05519481e-01,
                         -9.90868509e-01,   3.07629883e-01,   8.62418830e-01,
                         -6.67613626e-01,  -5.84009767e-01,   9.11120117e-01,
                          2.03733772e-01,  -9.96347427e-01,   2.11647734e-01,
                          9.07873392e-01,  -5.90706170e-01,  -6.61525965e-01,
                          8.66477251e-01,   2.99918830e-01,  -9.91883099e-01,
                          1.13636367e-01,   9.44196403e-01,  -5.07913947e-01,
                         -7.32548714e-01,   8.13311696e-01,   3.93060058e-01,
                         -9.77475643e-01,   1.46103892e-02,   9.71185088e-01,
                         -4.19845790e-01,  -7.96063304e-01,   7.51826286e-01,
                          4.82142866e-01,  -9.53327894e-01,  -8.48214254e-02,
                          9.88433421e-01,  -3.27922076e-01,  -8.51866901e-01,
                          6.83035731e-01,   5.66761374e-01,  -9.19642866e-01,
                         -1.83238640e-01,   9.95941579e-01,  -2.32548699e-01,
                         -8.99147749e-01,   6.07345760e-01,   6.45495117e-01,
                         -8.77029240e-01,  -2.79829532e-01,   9.93506491e-01,
                         -1.34740263e-01,  -9.37500000e-01,   5.25771081e-01,
                          7.17938304e-01,  -8.25487018e-01,  -3.73782456e-01,
                          9.81128275e-01,  -3.59172076e-02,  -9.66314912e-01,
                          4.38717544e-01,   7.83076286e-01,  -7.65625000e-01,
                         -4.63879883e-01,   9.59009767e-01,   6.35146126e-02,
                         -9.85795438e-01,   3.47605526e-01,   8.40503275e-01,
                         -6.98457778e-01,  -5.49310088e-01,   9.27353919e-01,
                          1.62337661e-01,  -9.95332778e-01,   2.52840906e-01,
                          8.89610410e-01,  -6.24188304e-01,  -6.29464269e-01,
                          8.86566579e-01,   2.59334415e-01,  -9.94926929e-01,
                          1.55438319e-01,   9.29788947e-01,  -5.43628275e-01,
                         -7.03125000e-01,   8.36647749e-01,   3.53896111e-01,
                         -9.84577894e-01,   5.66152595e-02,   9.60633099e-01,
                         -4.57589298e-01,  -7.69886374e-01,   7.78612018e-01,
                          4.44805205e-01,  -9.64488626e-01,  -4.26136367e-02,
                          9.82142866e-01,  -3.67288947e-01,  -8.28936696e-01,
                          7.12865233e-01,   5.31452894e-01,  -9.34862018e-01,
                         -1.41639605e-01,   9.93709445e-01,  -2.73133129e-01,
                         -8.79870117e-01,   6.40016258e-01,   6.12621725e-01,
                         -8.95698071e-01,  -2.39042208e-01,   9.95332778e-01,
                         -1.76339284e-01,  -9.21875000e-01,   5.60673714e-01,
                          6.87702894e-01,  -8.47808421e-01,  -3.34212661e-01,
                          9.87012982e-01,  -7.77191594e-02,  -9.54748392e-01,
                          4.75852281e-01,   7.56087661e-01,  -7.91396081e-01,
                         -4.25933450e-01,   9.68952894e-01,   2.15097405e-02,
                         -9.78084445e-01,   3.86363626e-01,   8.16761374e-01,
                         -7.27272749e-01,  -5.13595760e-01,   9.41152573e-01,
                          1.20738633e-01,  -9.91680205e-01,   2.92816550e-01,
                          8.69318187e-01,  -6.55641258e-01,  -5.95982134e-01,
                          9.04220760e-01,   2.18547076e-01,  -9.95535731e-01,
                          1.96631491e-01,   9.13149357e-01,  -5.77719152e-01,
                         -6.72483742e-01,   8.57954562e-01,   3.14123362e-01,
                         -9.89245117e-01,   9.82142836e-02,   9.48051929e-01,
                         -4.94115263e-01,  -7.42086053e-01,   8.03368509e-01,
                          4.06655848e-01,  -9.73214269e-01,  -1.01461040e-03,
                          9.73417222e-01,  -4.05438304e-01,  -8.04383099e-01,
                          7.40665555e-01,   4.95129883e-01,  -9.47646081e-01,
                         -1.00040585e-01,   9.89042222e-01,  -3.12702924e-01,
                         -8.58766258e-01,   6.70860410e-01,   5.78733742e-01,
                         -9.12337661e-01,  -1.98254868e-01,   9.94926929e-01,
                         -2.16923699e-01,  -9.04423714e-01,   5.94155848e-01,
                          6.56452894e-01,  -8.68100643e-01,  -2.94439942e-01,
                          9.90665555e-01,  -1.19115263e-01,  -9.41355526e-01,
                          5.11566579e-01,   7.27475643e-01,  -8.15340936e-01,
                         -3.87581170e-01,   9.76866901e-01,  -2.00892854e-02,
                         -9.68547106e-01,   4.23904210e-01,   7.91396081e-01,
                         -7.54464269e-01,  -4.77069795e-01,   9.53125000e-01,
                          7.91396126e-02,  -9.86404240e-01,   3.32183450e-01,
                          8.47402573e-01,  -6.85876608e-01,  -5.61485410e-01,
                          9.20048714e-01,   1.77556813e-01,  -9.94318187e-01,
                          2.37012982e-01,   8.95089269e-01,  -6.10795438e-01,
                         -6.40422106e-01,   8.77637982e-01,   2.73944795e-01,
                         -9.92288947e-01,   1.39610395e-01,   9.33644474e-01,
                         -5.29423714e-01,  -7.13068187e-01,   8.26704562e-01,
                          3.67897719e-01,  -9.80519474e-01,   4.09902595e-02,
                          9.63068187e-01,  -4.42978889e-01,  -7.78409064e-01,
                          7.67654240e-01,   4.57995117e-01,  -9.59009767e-01,
                         -5.80357127e-02,   9.82954562e-01,  -3.52272719e-01,
                         -8.36241901e-01,   7.00892866e-01,   5.43425322e-01,
                         -9.27962661e-01,  -1.56655848e-01,   9.92897749e-01,
                         -2.57913947e-01,  -8.85551929e-01,   6.27232134e-01,
                          6.23579562e-01,  -8.87581170e-01,  -2.53449678e-01,
                          9.93100643e-01,  -1.61120132e-01,  -9.26136374e-01,
                          5.47483742e-01,   6.97443187e-01,  -8.38676929e-01,
                         -3.47808450e-01,   9.83563304e-01,  -6.29058406e-02,
                         -9.57589269e-01,   4.62256491e-01,   7.64610410e-01,
                         -7.81452894e-01,  -4.38717544e-01,   9.64285731e-01,
                          3.59172076e-02,  -9.79504883e-01,   3.72564942e-01,
                          8.23863626e-01,  -7.16720760e-01,  -5.25162339e-01,
                          9.35470760e-01,   1.34537339e-01,  -9.91883099e-01,
                          2.79220790e-01,   8.75202894e-01,  -6.44683421e-01,
                         -6.06331170e-01,   8.97524357e-01,   2.31534094e-01,
                         -9.94521081e-01,   1.83238640e-01,   9.17613626e-01,
                         -5.66558421e-01,  -6.81615233e-01,   8.50852251e-01,
                          3.26095790e-01,  -9.87215936e-01,   8.56331140e-02,
                          9.51298714e-01,  -4.82954532e-01,  -7.49797106e-01,
                          7.95860410e-01,   4.17816550e-01,  -9.70170438e-01,
                         -1.33928573e-02,   9.75649357e-01,  -3.93871754e-01,
                         -8.11688304e-01,   7.32142866e-01,   5.05884767e-01,
                         -9.43384767e-01,  -1.12824678e-01,   9.90259767e-01,
                         -3.00527602e-01,  -8.65056813e-01,   6.61120117e-01,
                          5.89082778e-01,  -9.07264590e-01,  -2.10836038e-01,
                          9.94926929e-01,  -2.04545453e-01,  -9.09902573e-01,
                          5.83806813e-01,   6.66193187e-01,  -8.62012982e-01,
                         -3.06818187e-01,   9.89853919e-01,  -1.06331170e-01,
                         -9.45616901e-01,   5.00608742e-01,   7.36607134e-01,
                         -8.08238626e-01,  -3.99756491e-01,   9.74837661e-01,
                         -7.30519462e-03,  -9.71996725e-01,   4.12540585e-01,
                          7.99715936e-01,  -7.46550322e-01,  -4.88636374e-01,
                          9.50081170e-01,   9.19236988e-02,  -9.88839269e-01,
                          3.20413947e-01,   8.54910731e-01,  -6.77353919e-01,
                         -5.72443187e-01,   9.15990233e-01,   1.90137982e-01,
                         -9.95738626e-01,   2.25040585e-01,   9.01582778e-01,
                         -6.01663947e-01,  -6.50771081e-01,   8.72970760e-01,
                          2.86323041e-01,  -9.92694795e-01,   1.27637982e-01,
                          9.39326286e-01,  -5.19683421e-01,  -7.22808421e-01,
                          8.21022749e-01,   3.79870117e-01,  -9.79910731e-01,
                          2.88149342e-02,   9.67735410e-01,  -4.32832778e-01,
                         -7.87540555e-01,   7.61160731e-01,   4.69561696e-01,
                         -9.57386374e-01,  -7.04139620e-02,   9.86607134e-01,
                         -3.41517866e-01,  -8.44358742e-01,   6.93790555e-01,
                          5.54788947e-01,  -9.25527573e-01,  -1.68831170e-01,
                          9.95738626e-01,  -2.46956170e-01,  -8.93060088e-01,
                          6.19318187e-01,   6.34334445e-01,  -8.84334445e-01,
                         -2.65625000e-01,   9.94926929e-01,  -1.49756491e-01,
                         -9.32832778e-01,   5.38758099e-01,   7.07792222e-01,
                         -8.34415555e-01,  -3.59780848e-01,   9.84375000e-01,
                         -5.11363633e-02,  -9.63474035e-01,   4.52922076e-01,
                          7.74147749e-01,  -7.76379883e-01,  -4.50487018e-01,
                          9.64082778e-01,   4.78896089e-02,  -9.84577894e-01,
                          3.62621754e-01,   8.32995117e-01,  -7.10430205e-01,
                         -5.36931813e-01,   9.34253275e-01,   1.46712661e-01,
                         -9.95941579e-01,   2.68465906e-01,   8.83522749e-01,
                         -6.37581170e-01,  -6.17897749e-01,   8.95089269e-01,
                          2.44115263e-01,  -9.97362018e-01,   1.71875000e-01,
                          9.25527573e-01,  -5.58238626e-01,  -6.92775965e-01,
                          8.47199678e-01,   3.39082778e-01,  -9.89042222e-01,
                          7.32548684e-02,   9.58198071e-01,  -4.73417222e-01,
                         -7.60957778e-01,   7.90787339e-01,   4.30803567e-01,
                         -9.70779240e-01,  -2.59740259e-02,   9.81331170e-01,
                         -3.83928567e-01,  -8.21631491e-01,   7.26461053e-01,
                          5.18262982e-01,  -9.42978919e-01,  -1.25000000e-01,
                          9.94926929e-01,  -2.90381491e-01,  -8.74188304e-01,
                          6.54829562e-01,   6.00649357e-01,  -9.05844152e-01,
                         -2.23011360e-01,   9.98579562e-01,  -1.93993509e-01,
                         -9.18019474e-01,   5.76907456e-01,   6.77150965e-01,
                         -8.59577894e-01,  -3.18790585e-01,   9.92491901e-01,
                         -9.57792178e-02,  -9.52922106e-01,   4.92897719e-01,
                          7.46956170e-01,  -8.04991901e-01,  -4.11323041e-01,
                          9.76258099e-01,   3.65259731e-03,  -9.78287339e-01,
                          4.04220790e-01,   8.09253275e-01,  -7.42288947e-01,
                         -5.00000000e-01,   9.50487018e-01,   1.03084415e-01,
                         -9.93912339e-01,   3.11282456e-01,   8.63636374e-01,
                         -6.72077894e-01,  -5.83603919e-01,   9.15381491e-01,
                          2.01501623e-01,  -9.99594152e-01,   2.15300322e-01,
                          9.09496725e-01,  -5.95170438e-01,  -6.61525965e-01,
                          8.70941579e-01,   2.97889620e-01,  -9.95535731e-01,
                          1.17288962e-01,   9.46428597e-01,  -5.12378275e-01,
                         -7.32954562e-01,   8.17978919e-01,   3.91436696e-01,
                         -9.81534064e-01,   1.78571437e-02,   9.73823071e-01,
                         -4.24512982e-01,  -7.97077894e-01,   7.56696403e-01,
                          4.80925322e-01,  -9.57792222e-01,  -8.17775950e-02,
                          9.91477251e-01,  -3.32386374e-01,  -8.53287339e-01,
                          6.87905848e-01,   5.65949678e-01,  -9.24512982e-01,
                         -1.80600643e-01,   9.99391258e-01,  -2.36810058e-01,
                         -9.00974035e-01,   6.12418830e-01,   6.45089269e-01,
                         -8.81899357e-01,  -2.77597398e-01,   9.97362018e-01,
                         -1.39001623e-01,  -9.39732134e-01,   5.30641258e-01,
                          7.17938304e-01,  -8.30560088e-01,  -3.71753246e-01,
                          9.85389590e-01,  -3.95698063e-02,  -9.69155848e-01,
                          4.43587661e-01,   7.83685088e-01,  -7.70900965e-01,
                         -4.62459415e-01,   9.63676929e-01,   6.00649342e-02,
                         -9.89042222e-01,   3.52272719e-01,   8.41720760e-01,
                         -7.03733742e-01,  -5.48498392e-01,   9.32224035e-01,
                          1.59293830e-01,  -9.98985410e-01,   2.57305205e-01,
                          8.91233742e-01,  -6.29464269e-01,  -6.29058421e-01,
                          8.91436696e-01,   2.56696433e-01,  -9.98985410e-01,
                          1.59699678e-01,   9.32021081e-01,  -5.48701286e-01,
                         -7.03327894e-01,   8.41923714e-01,   3.51663947e-01,
                         -9.89042222e-01,   6.04707785e-02,   9.63271081e-01,
                         -4.62662339e-01,  -7.70698071e-01,   7.83887982e-01,
                          4.43181813e-01,  -9.69155848e-01,  -3.91639620e-02,
                          9.85186696e-01,  -3.72159094e-01,  -8.30154240e-01,
                          7.18141258e-01,   5.30235410e-01,  -9.39732134e-01,
                         -1.38595775e-01,   9.97159064e-01,  -2.77800322e-01,
                         -8.81493509e-01,   6.45292222e-01,   6.12012982e-01,
                         -9.00771081e-01,  -2.36607149e-01,   9.99188304e-01,
                         -1.80600643e-01,  -9.24107134e-01,   5.65746725e-01,
                          6.87702894e-01,  -8.53084445e-01,  -3.32183450e-01,
                          9.91274357e-01,  -8.17775950e-02,  -9.57386374e-01,
                          4.80925322e-01,   7.56493509e-01,  -7.96672106e-01,
                         -4.24512982e-01,   9.73417222e-01,   1.80600658e-02,
                         -9.81331170e-01,   3.91030848e-01,   8.17775965e-01,
                         -7.32548714e-01,  -5.12378275e-01,   9.46022749e-01,
                          1.17491886e-01,  -9.95332778e-01,   2.97483772e-01,
                          8.70941579e-01,  -6.60917222e-01,  -5.95373392e-01,
                          9.09090936e-01,   2.15706170e-01,  -9.99391258e-01,
                          2.00892851e-01,   9.15178597e-01,  -5.82995117e-01,
                         -6.72280848e-01,   8.63027573e-01,   3.11891228e-01,
                         -9.93506491e-01,   1.02272727e-01,   9.50487018e-01,
                         -4.98985380e-01,  -7.42491901e-01,   8.08441579e-01,
                          4.05032456e-01,  -9.77678597e-01,   2.63798703e-03,
                          9.76258099e-01,  -4.10308450e-01,  -8.05397749e-01,
                          7.45941579e-01,   4.93912339e-01,  -9.52313304e-01,
                         -9.69967544e-02,   9.92288947e-01,  -3.17370117e-01,
                         -8.60186696e-01,   6.75933421e-01,   5.77922106e-01,
                         -9.17410731e-01,  -1.95616886e-01,   9.98579562e-01,
                         -2.21387982e-01,  -9.06452894e-01,   5.99228919e-01,
                          6.56250000e-01,  -8.73173714e-01,  -2.92207778e-01,
                          9.94724035e-01,  -1.23173699e-01,  -9.43790555e-01,
                          5.16436696e-01,   7.27881491e-01,  -8.20413947e-01,
                         -3.85957778e-01,   9.81128275e-01,  -2.37418823e-02,
                         -9.71590936e-01,   4.28774357e-01,   7.92410731e-01,
                         -7.59537339e-01,  -4.75852281e-01,   9.57792222e-01,
                          7.58928582e-02,  -9.89650965e-01,   3.36647719e-01,
                          8.48823071e-01,  -6.91152573e-01,  -5.60876608e-01,
                          9.24715936e-01,   1.74715906e-01,  -9.97970760e-01,
                          2.41274357e-01,   8.96915555e-01,  -6.15665555e-01,
                         -6.40422106e-01,   8.82508099e-01,   2.71915585e-01,
                         -9.96347427e-01,   1.43465906e-01,   9.36079562e-01,
                         -5.34293830e-01,  -7.13474035e-01,   8.31574678e-01,
                          3.66274357e-01,  -9.84780848e-01,   4.42370139e-02,
                          9.65909064e-01,  -4.47443187e-01,  -7.79626608e-01,
                          7.72321403e-01,   4.56980526e-01,  -9.63271081e-01,
                         -5.53977266e-02,   9.86201286e-01,  -3.56331170e-01,
                         -8.37865233e-01,   7.05560088e-01,   5.43222427e-01,
                         -9.32426929e-01,  -1.54626623e-01,   9.96550322e-01,
                         -2.61566550e-01,  -8.87784064e-01,   6.31493509e-01,
                          6.23985410e-01,  -8.92045438e-01,  -2.52029210e-01,
                          9.96956170e-01,  -1.64163962e-01,  -9.28774357e-01,
                          5.51339269e-01,   6.98457778e-01,  -8.42938304e-01,
                         -3.47199678e-01,   9.87621725e-01,  -6.51379898e-02,
                         -9.60633099e-01,   4.65503246e-01,   7.66233742e-01,
                         -7.85511374e-01,  -4.38717544e-01,   9.68344152e-01,
                          3.44967544e-02,  -9.82954562e-01,   3.75202924e-01,
                          8.26095760e-01,  -7.20170438e-01,  -5.25974035e-01,
                          9.39326286e-01,   1.33725643e-01,  -9.95332778e-01,
                          2.81250000e-01,   8.77840936e-01,  -6.47727251e-01,
                         -6.07954562e-01,   9.00974035e-01,   2.31737018e-01,
                         -9.97970760e-01,   1.84253246e-01,   9.20860410e-01,
                         -5.68790555e-01,  -6.83847427e-01,   8.53693187e-01,
                          3.27516228e-01,  -9.90665555e-01,   8.54301974e-02,
                          9.54748392e-01,  -4.83969152e-01,  -7.53043830e-01,
                          7.97889590e-01,   4.19845790e-01,  -9.73417222e-01,
                         -1.40016237e-02,   9.78896081e-01,  -3.94683450e-01,
                         -8.14732134e-01,   7.34172106e-01,   5.08116901e-01,
                         -9.46428597e-01,  -1.13636367e-01,   9.93506491e-01,
                         -3.01136374e-01,  -8.68100643e-01,   6.63149357e-01,
                          5.91314912e-01,  -9.10105526e-01,  -2.11850643e-01,
                          9.98173714e-01,  -2.04748377e-01,  -9.13149357e-01,
                          5.85430205e-01,   6.68628275e-01,  -8.64650965e-01,
                         -3.08238626e-01,   9.92897749e-01,  -1.06331170e-01,
                         -9.48863626e-01,   5.01826286e-01,   7.39245117e-01,
                         -8.10470760e-01,  -4.01379883e-01,   9.77678597e-01,
                         -6.89935079e-03,  -9.75243509e-01,   4.13352281e-01,
                          8.02556813e-01,  -7.48376608e-01,  -4.90462661e-01,
                          9.52719152e-01,   9.27353874e-02,  -9.91680205e-01,
                          3.20616871e-01,   8.57751608e-01,  -6.78774357e-01,
                         -5.74878275e-01,   9.18425322e-01,   1.91558436e-01,
                         -9.98579562e-01,   2.24837661e-01,   9.04423714e-01,
                         -6.02475643e-01,  -6.53409064e-01,   8.74797106e-01,
                          2.88149357e-01,  -9.95332778e-01,   1.26623377e-01,
                          9.42167222e-01,  -5.20089269e-01,  -7.25446403e-01,
                          8.22443187e-01,   3.82102281e-01,  -9.82142866e-01,
                          2.73944810e-02,   9.70373392e-01,  -4.32426959e-01,
                         -7.90381491e-01,   7.61972427e-01,   4.72199678e-01,
                         -9.59212661e-01,  -7.22402632e-02,   9.89042222e-01,
                         -3.40503246e-01,  -8.47199678e-01,   6.93790555e-01,
                          5.57629883e-01,  -9.26745117e-01,  -1.71266228e-01,
                          9.97970760e-01,  -2.45332792e-01,  -8.95900965e-01,
                          6.18709445e-01,   6.37378275e-01,  -8.84943187e-01,
                         -2.68465906e-01,   9.96753275e-01,  -1.47524357e-01,
                         -9.35470760e-01,   5.37540555e-01,   7.10836053e-01,
                         -8.34415555e-01,  -3.63027602e-01,   9.85592544e-01,
                         -4.84983772e-02,  -9.65706170e-01,   4.51095790e-01,
                          7.77191579e-01,  -7.75568187e-01,  -4.53936696e-01,
                          9.64691579e-01,   5.11363633e-02,  -9.86404240e-01,
                          3.59983772e-01,   8.35836053e-01,  -7.09009767e-01,
                         -5.40381491e-01,   9.34253275e-01,   1.50365263e-01,
                         -9.97159064e-01,   2.65422076e-01,   8.86160731e-01,
                         -6.35349035e-01,  -6.21347427e-01,   8.94480526e-01,
                          2.47970775e-01,  -9.98173714e-01,   1.68222398e-01,
                          9.27759767e-01,  -5.55397749e-01,  -6.96225643e-01,
                          8.45779240e-01,   3.43141228e-01,  -9.89042222e-01,
                          6.91964254e-02,   9.60024357e-01,  -4.69967544e-01,
                         -7.64001608e-01,   7.88555205e-01,   4.34862018e-01,
                         -9.70170438e-01,  -3.02353892e-02,   9.82548714e-01,
                         -3.79870117e-01,  -8.24472427e-01,   7.23620117e-01,
                          5.22321403e-01,  -9.41761374e-01,  -1.29667208e-01,
                          9.95535731e-01,  -2.85917222e-01,  -8.76420438e-01,
                          6.51379883e-01,   6.04504883e-01,  -9.03814912e-01,
                         -2.27475643e-01,   9.98579562e-01,  -1.89326301e-01,
                         -9.19845760e-01,   5.72849035e-01,   6.80600643e-01,
                         -8.56939912e-01,  -3.23254883e-01,   9.91680205e-01,
                         -9.07061696e-02,  -9.54139590e-01,   4.88433450e-01,
                          7.50000000e-01,  -8.01745117e-01,  -4.15787339e-01,
                          9.74837661e-01,   8.72564968e-03,  -9.78693187e-01,
                          3.99350643e-01,   8.11891258e-01,  -7.38433421e-01,
                         -5.04058421e-01,   9.48457778e-01,   1.08157471e-01,
                         -9.93709445e-01,   3.06209415e-01,   8.65868509e-01,
                         -6.67613626e-01,  -5.87459445e-01,   9.12540555e-01,
                          2.06371754e-01,  -9.98985410e-01,   2.10024357e-01,
                          9.11120117e-01,  -5.90503275e-01,  -6.64975643e-01,
                          8.67694795e-01,   3.02759737e-01,  -9.94115233e-01,
                          1.11810066e-01,   9.47240233e-01,  -5.07305205e-01,
                         -7.35795438e-01,   8.14123392e-01,   3.95900965e-01,
                         -9.79504883e-01,   1.25811687e-02,   9.74025965e-01,
                         -4.19237018e-01,  -7.99310088e-01,   7.52435088e-01,
                          4.85186696e-01,  -9.55154240e-01,  -8.68506506e-02,
                          9.91071403e-01,  -3.26907456e-01,  -8.54910731e-01,
                          6.83441579e-01,   5.69602251e-01,  -9.21266258e-01,
                         -1.85470775e-01,   9.98376608e-01,  -2.31331170e-01,
                         -9.02191579e-01,   6.07548714e-01,   6.48538947e-01,
                         -8.78246725e-01,  -2.82264620e-01,   9.95738626e-01,
                         -1.33522734e-01,  -9.40340936e-01,   5.25568187e-01,
                          7.20779240e-01,  -8.26501608e-01,  -3.76217544e-01,
                          9.83360410e-01,  -3.42938304e-02,  -9.69155848e-01,
                          4.38514620e-01,   7.86120117e-01,  -7.66639590e-01,
                         -4.66517866e-01,   9.61038947e-01,   6.53409064e-02,
                         -9.88433421e-01,   3.46996754e-01,   8.43547106e-01,
                         -6.99066579e-01,  -5.51948071e-01,   9.29180205e-01,
                          1.64163962e-01,  -9.97767866e-01,   2.52029210e-01,
                          8.92451286e-01,  -6.24594152e-01,  -6.32102251e-01,
                          8.88189912e-01,   2.61363626e-01,  -9.97362018e-01,
                          1.54626623e-01,   9.32629883e-01,  -5.43831170e-01,
                         -7.05965936e-01,   8.38271081e-01,   3.55925322e-01,
                         -9.87012982e-01,   5.56006506e-02,   9.63676929e-01,
                         -4.57792222e-01,  -7.72727251e-01,   7.80032456e-01,
                          4.47240263e-01,  -9.66720760e-01,  -4.40340899e-02,
                          9.84983742e-01,  -3.67086053e-01,  -8.31980526e-01,
                          7.14082778e-01,   5.33887982e-01,  -9.37094152e-01,
                         -1.43060058e-01,   9.96550322e-01,  -2.72930205e-01,
                         -8.82913947e-01,   6.41030848e-01,   6.15259767e-01,
                         -8.97930205e-01,  -2.40868509e-01,   9.98173714e-01,
                         -1.75933436e-01,  -9.24918830e-01,   5.61485410e-01,
                          6.90543830e-01,  -8.49837661e-01,  -3.36038947e-01,
                          9.89853919e-01,  -7.71103874e-02,  -9.57995117e-01,
                          4.76461053e-01,   7.58928597e-01,  -7.93425322e-01,
                         -4.28165585e-01,   9.71793830e-01,   2.25243513e-02,
                         -9.81331170e-01,   3.86769474e-01,   8.19805205e-01,
                         -7.29099035e-01,  -5.15827894e-01,   9.43993509e-01,
                          1.21753246e-01,  -9.95129883e-01,   2.93222398e-01,
                          8.72564912e-01,  -6.57467544e-01,  -5.98417222e-01,
                          9.06858742e-01,   2.19967529e-01,  -9.98782456e-01,
                          1.96631491e-01,   9.16599035e-01,  -5.79139590e-01,
                         -6.75121725e-01,   8.60592544e-01,   3.15949678e-01,
                         -9.92694795e-01,   9.80113670e-02,   9.51501608e-01,
                         -4.95332778e-01,  -7.45129883e-01,   8.06006491e-01,
                          4.08685058e-01,  -9.76663947e-01,  -1.42045459e-03,
                          9.77069795e-01,  -4.06452924e-01,  -8.07629883e-01,
                          7.43100643e-01,   4.97362018e-01,  -9.50892866e-01,
                         -1.00852273e-01,   9.92694795e-01,  -3.13514620e-01,
                         -8.62215936e-01,   6.72889590e-01,   5.81168830e-01,
                         -9.15584445e-01,  -1.99472398e-01,   9.98579562e-01,
                         -2.17329547e-01,  -9.08076286e-01,   5.95982134e-01,
                          6.59293830e-01,  -8.71347427e-01,  -2.95860380e-01,
                          9.94521081e-01,  -1.19115263e-01,  -9.45008099e-01,
                          5.13189912e-01,   7.30722427e-01,  -8.18181813e-01,
                         -3.89407456e-01,   9.80519474e-01,  -1.98863633e-02,
                         -9.72402573e-01,   4.25324678e-01,   7.94845760e-01,
                         -7.57102251e-01,  -4.79099035e-01,   9.56777573e-01,
                          7.97483772e-02,  -9.90259767e-01,   3.33198041e-01,
                          8.51055205e-01,  -6.88311696e-01,  -5.64123392e-01,
                          9.23498392e-01,   1.78571433e-01,  -9.98173714e-01,
                          2.37621754e-01,   8.98741901e-01,  -6.12824678e-01,
                         -6.43262982e-01,   8.81087661e-01,   2.75568187e-01,
                         -9.96144474e-01,   1.39813319e-01,   9.37702894e-01,
                         -5.31250000e-01,  -7.16112018e-01,   8.29748392e-01,
                          3.69724035e-01,  -9.84172106e-01,   4.05844152e-02,
                          9.67126608e-01,  -4.44399357e-01,  -7.81858742e-01,
                          7.70292222e-01,   4.60227281e-01,  -9.62459445e-01,
                         -5.88474013e-02,   9.86810088e-01,  -3.53084415e-01,
                         -8.39691579e-01,   7.03125000e-01,   5.46266258e-01,
                         -9.31209445e-01,  -1.57873377e-01,   9.96956170e-01,
                         -2.58116871e-01,  -8.89407456e-01,   6.29058421e-01,
                          6.26623392e-01,  -8.90625000e-01,  -2.55275965e-01,
                          9.96956170e-01,  -1.60917208e-01,  -9.29991901e-01,
                          5.48701286e-01,   7.00892866e-01,  -8.41314912e-01,
                         -3.50040585e-01,   9.87012982e-01,  -6.18912354e-02,
                         -9.61444795e-01,   4.62865263e-01,   7.68060088e-01,
                         -7.83482134e-01,  -4.41355526e-01,   9.67329562e-01,
                          3.75405848e-02,  -9.83157456e-01,   3.72362018e-01,
                          8.27516258e-01,  -7.17938304e-01,  -5.28206170e-01,
                          9.38108742e-01,   1.36566564e-01,  -9.95332778e-01,
                          2.78409094e-01,   8.78855526e-01,  -6.45292222e-01,
                         -6.09780848e-01,   8.99553597e-01,   2.34375000e-01,
                         -9.97362018e-01,   1.81615263e-01,   9.21469152e-01,
                         -5.66152573e-01,  -6.85470760e-01,   8.51866901e-01,
                          3.29748362e-01,  -9.89650965e-01,   8.29951316e-02,
                          9.54748392e-01,  -4.81534094e-01,  -7.54058421e-01,
                          7.95860410e-01,   4.21672076e-01,  -9.71996725e-01,
                         -1.64366886e-02,   9.78693187e-01,  -3.92248362e-01,
                         -8.15137982e-01,   7.32142866e-01,   5.09537339e-01,
                         -9.44805205e-01,  -1.15462661e-01,   9.92897749e-01,
                         -2.98904210e-01,  -8.68303597e-01,   6.60917222e-01,
                          5.92329562e-01,  -9.08279240e-01,  -2.13474020e-01,
                          9.97159064e-01,  -2.02719152e-01,  -9.12743509e-01,
                          5.83198071e-01,   6.69034064e-01,  -8.62621725e-01,
                         -3.09253246e-01,   9.91477251e-01,  -1.04504868e-01,
                         -9.48051929e-01,   4.99797076e-01,   7.39245117e-01,
                         -8.08441579e-01,  -4.01988626e-01,   9.76055205e-01,
                         -5.47889620e-03,  -9.74025965e-01,   4.11525965e-01,
                          8.01948071e-01,  -7.46347427e-01,  -4.90868509e-01,
                          9.50892866e-01,   9.37500000e-02,  -9.90259767e-01,
                          3.18993509e-01,   8.56737018e-01,  -6.76745117e-01,
                         -5.74675322e-01,   9.16193187e-01,   1.91964284e-01,
                         -9.96550322e-01,   2.23620132e-01,   9.03003275e-01,
                         -6.00649357e-01,  -6.52800322e-01,   8.72564912e-01,
                          2.88352281e-01,  -9.93100643e-01,   1.25811681e-01,
                          9.40340936e-01,  -5.18465936e-01,  -7.24431813e-01,
                          8.20413947e-01,   3.81899357e-01,  -9.79910731e-01,
                          2.67857146e-02,   9.68344152e-01,  -4.31006491e-01,
                         -7.88758099e-01,   7.59943187e-01,   4.71387982e-01,
                         -9.56777573e-01,  -7.24431798e-02,   9.86810088e-01,
                         -3.39488626e-01,  -8.45373392e-01,   6.91964269e-01,
                          5.56412339e-01,  -9.24310088e-01,  -1.71063319e-01,
                          9.95332778e-01,  -2.44521111e-01,  -8.93668830e-01,
                          6.17086053e-01,   6.35754883e-01,  -8.82711053e-01,
                         -2.67857134e-01,   9.94115233e-01,  -1.47118509e-01,
                         -9.32832778e-01,   5.36120117e-01,   7.09009767e-01,
                         -8.32183421e-01,  -3.62012982e-01,   9.82954562e-01,
                         -4.82954532e-02,  -9.63068187e-01,   4.49878246e-01,
                          7.74959445e-01,  -7.73336053e-01,  -4.52719152e-01,
                          9.62053597e-01,   5.09334430e-02,  -9.83563304e-01,
                          3.58969152e-01,   8.33400965e-01,  -7.06980526e-01,
                         -5.38758099e-01,   9.31412339e-01,   1.49959415e-01,
                         -9.94318187e-01,   2.64610380e-01,   8.83522749e-01,
                         -6.33522749e-01,  -6.19521081e-01,   8.91639590e-01,
                          2.47362018e-01,  -9.95129883e-01,   1.67613640e-01,
                          9.24918830e-01,  -5.53571403e-01,  -6.94196403e-01,
                          8.42938304e-01,   3.42329532e-01,  -9.85998392e-01,
                          6.87905848e-02,   9.56980526e-01,  -4.68141228e-01,
                         -7.61972427e-01,   7.85714269e-01,   4.34050322e-01,
                         -9.66923714e-01,  -3.08441557e-02,   9.79707778e-01,
                         -3.78043830e-01,  -8.22240233e-01,   7.20576286e-01,
                          5.21306813e-01,  -9.38311696e-01,  -1.30275980e-01,
                          9.92491901e-01,  -2.83887982e-01,  -8.74188304e-01,
                          6.48133099e-01,   6.03693187e-01,  -9.00365233e-01,
                         -2.28084415e-01,   9.95332778e-01,  -1.87702924e-01,
                         -9.17207778e-01,   5.70211053e-01,   6.78977251e-01,
                         -8.53896081e-01,  -3.22849035e-01,   9.88433421e-01,
                         -8.98944810e-02,  -9.51095760e-01,   4.86607134e-01,
                          7.47767866e-01,  -7.98904240e-01,  -4.14772719e-01,
                          9.71793830e-01,   8.92857183e-03,  -9.75852251e-01,
                          3.97930205e-01,   8.09456170e-01,  -7.35998392e-01,
                         -5.02637982e-01,   9.45413947e-01,   1.07751623e-01,
                         -9.90665555e-01,   3.05397719e-01,   8.63027573e-01,
                         -6.65787339e-01,  -5.85430205e-01,   9.09902573e-01,
                          2.05560058e-01,  -9.95941579e-01,   2.09821433e-01,
                          9.08076286e-01,  -5.89082778e-01,  -6.62743509e-01,
                          8.65259767e-01,   3.01339298e-01,  -9.91274357e-01,
                          1.12012990e-01,   9.44399357e-01,  -5.06290555e-01,
                         -7.33360410e-01,   8.11891258e-01,   3.94277602e-01,
                         -9.76866901e-01,   1.29870130e-02,   9.71185088e-01,
                         -4.18425322e-01,  -7.96875000e-01,   7.50608742e-01,
                          4.83360380e-01,  -9.52719152e-01,  -8.62418860e-02,
                          9.88230526e-01,  -3.26501638e-01,  -8.52475643e-01,
                          6.81818187e-01,   5.67573071e-01,  -9.19034064e-01,
                         -1.84456170e-01,   9.95738626e-01,  -2.31128246e-01,
                         -8.99553597e-01,   6.06331170e-01,   6.46306813e-01,
                         -8.76217544e-01,  -2.81047076e-01,   9.93303597e-01,
                         -1.33522734e-01,  -9.37702894e-01,   5.24553597e-01,
                          7.18547106e-01,  -8.24675322e-01,  -3.74797076e-01,
                          9.80925322e-01,  -3.46996747e-02,  -9.66720760e-01,
                          4.37702924e-01,   7.83887982e-01,  -7.65016258e-01,
                         -4.64894474e-01,   9.58806813e-01,   6.47321418e-02,
                         -9.85998392e-01,   3.46387982e-01,   8.41314912e-01,
                         -6.97646081e-01,  -5.50527573e-01,   9.27150965e-01,
                          1.63352266e-01,  -9.95535731e-01,   2.51623362e-01,
                          8.90219152e-01,  -6.23376608e-01,  -6.30478919e-01,
                          8.86160731e-01,   2.60551959e-01,  -9.95129883e-01,
                          1.54423699e-01,   9.30600643e-01,  -5.43019474e-01,
                         -7.04342544e-01,   8.36444795e-01,   3.55113626e-01,
                         -9.84983742e-01,   5.56006506e-02,   9.61444795e-01,
                         -4.56980526e-01,  -7.71103919e-01,   7.78409064e-01,
                          4.46022719e-01,  -9.64894474e-01,  -4.38311696e-02,
                          9.82954562e-01,  -3.66477281e-01,  -8.30357134e-01,
                          7.12662339e-01,   5.32670438e-01,  -9.35267866e-01,
                         -1.42857149e-01,   9.94521081e-01,  -2.72524357e-01,
                         -8.81087661e-01,   6.39813304e-01,   6.14042222e-01,
                         -8.96306813e-01,  -2.40259737e-01,   9.96144474e-01,
                         -1.75527602e-01,  -9.23295438e-01,   5.60470760e-01,
                          6.89123392e-01,  -8.48417222e-01,  -3.35430205e-01,
                          9.88027573e-01,  -7.71103874e-02,  -9.56168830e-01,
                          4.75649357e-01,   7.57508099e-01,  -7.92004883e-01,
                         -4.27353889e-01,   9.69967544e-01,   2.23214291e-02,
                         -9.79707778e-01,   3.86160702e-01,   8.18384767e-01,
                         -7.27881491e-01,  -5.15016258e-01,   9.42370117e-01,
                          1.21550322e-01,  -9.93303597e-01,   2.92613626e-01,
                          8.70941579e-01,  -6.56452894e-01,  -5.97402573e-01,
                          9.05438304e-01,   2.19358772e-01,  -9.97159064e-01,
                          1.96428567e-01,   9.14975643e-01,  -5.78530848e-01,
                         -6.73904240e-01,   8.59375000e-01,   3.15137982e-01,
                         -9.91071403e-01,   9.80113670e-02,   9.49878275e-01,
                         -4.94724035e-01,  -7.43912339e-01,   8.04788947e-01,
                          4.07670468e-01,  -9.75243509e-01,  -1.21753244e-03,
                          9.75446403e-01,  -4.06047076e-01,  -8.06209445e-01,
                          7.42288947e-01,   4.96347398e-01,  -9.49675322e-01,
                         -1.00446425e-01,   9.91274357e-01,  -3.13514620e-01,
                         -8.60795438e-01,   6.72280848e-01,   5.79951286e-01,
                         -9.14569795e-01,  -1.98660716e-01,   9.97159064e-01,
                         -2.17735395e-01,  -9.06655848e-01,   5.95576286e-01,
                          6.57873392e-01,  -8.70332778e-01,  -2.94845790e-01,
                          9.93100643e-01,  -1.19724028e-01,  -9.43587661e-01,
                          5.13189912e-01,   7.29099035e-01,  -8.17573071e-01,
                         -3.88189942e-01,   9.79301929e-01,  -2.06980519e-02,
                         -9.70982134e-01,   4.25527602e-01,   7.93222427e-01,
                         -7.56696403e-01,  -4.77678567e-01,   9.55762982e-01,
                          7.87337646e-02,  -9.88839269e-01,   3.33603889e-01,
                          8.49431813e-01,  -6.88311696e-01,  -5.62500000e-01,
                          9.22686696e-01,   1.77150980e-01,  -9.96956170e-01,
                          2.38433436e-01,   8.97118509e-01,  -6.13027573e-01,
                         -6.41639590e-01,   8.80478919e-01,   2.73944795e-01,
                         -9.95129883e-01,   1.40827924e-01,   9.35876608e-01,
                         -5.31655848e-01,  -7.14285731e-01,   8.29545438e-01,
                          3.67897719e-01,  -9.83360410e-01,   4.20048684e-02,
                          9.65503275e-01,  -4.45211053e-01,  -7.80032456e-01,
                          7.70292222e-01,   4.58400965e-01,  -9.61850643e-01,
                         -5.72240278e-02,   9.85389590e-01,  -3.54099035e-01,
                         -8.37865233e-01,   7.03530848e-01,   5.44034064e-01,
                         -9.30803597e-01,  -1.56047076e-01,   9.95535731e-01,
                         -2.59740263e-01,  -8.87581170e-01,   6.29667222e-01,
                          6.24391258e-01,  -8.90422106e-01,  -2.53246754e-01,
                          9.95738626e-01,  -1.62540585e-01,  -9.28368509e-01,
                          5.49512982e-01,   6.98660731e-01,  -8.41314912e-01,
                         -3.47808450e-01,   9.86201286e-01,  -6.39204532e-02,
                         -9.59821403e-01,   4.64082778e-01,   7.65827894e-01,
                         -7.83887982e-01,  -4.39123362e-01,   9.66720760e-01,
                          3.53084430e-02,  -9.81939912e-01,   3.73985380e-01,
                          8.25487018e-01,  -7.18750000e-01,  -5.25974035e-01,
                          9.37905848e-01,   1.34334415e-01,  -9.94115233e-01,
                          2.80235380e-01,   8.77029240e-01,  -6.46306813e-01,
                         -6.07548714e-01,   8.99553597e-01,   2.31939942e-01,
                         -9.96550322e-01,   1.83644474e-01,   9.19642866e-01,
                         -5.67573071e-01,  -6.83238626e-01,   8.52272749e-01,
                          3.27313304e-01,  -9.89245117e-01,   8.52272734e-02,
                          9.53327894e-01,  -4.83157456e-01,  -7.52029240e-01,
                          7.96672106e-01,   4.19237018e-01,  -9.71793830e-01,
                         -1.40016237e-02,   9.77475643e-01,  -3.94074678e-01,
                         -8.13311696e-01,   7.33157456e-01,   5.07102251e-01,
                         -9.45008099e-01,  -1.13230519e-01,   9.91883099e-01,
                         -3.00933450e-01,  -8.66477251e-01,   6.62337661e-01,
                          5.89894474e-01,  -9.08685088e-01,  -2.11038962e-01,
                          9.96347427e-01,  -2.04951301e-01,  -9.11323071e-01,
                          5.84821403e-01,   6.66801929e-01,  -8.63433421e-01,
                         -3.07021111e-01,   9.91071403e-01,  -1.06939934e-01,
                         -9.46834445e-01,   5.01623392e-01,   7.37215936e-01,
                         -8.09456170e-01,  -3.99756491e-01,   9.76055205e-01,
                         -7.71103892e-03,  -9.73011374e-01,   4.13352281e-01,
                          8.00324678e-01,  -7.47564912e-01,  -4.88636374e-01,
                          9.51298714e-01,   9.15178582e-02,  -9.89650965e-01,
                          3.21225643e-01,   8.55316579e-01,  -6.78368509e-01,
                         -5.72646081e-01,   9.17004883e-01,   1.89732149e-01,
                         -9.96550322e-01,   2.25649357e-01,   9.01988626e-01,
                         -6.02272749e-01,  -6.50974035e-01,   8.73579562e-01,
                          2.86120117e-01,  -9.93303597e-01,   1.28043830e-01,
                          9.39732134e-01,  -5.20292222e-01,  -7.22808421e-01,
                          8.21631491e-01,   3.79667222e-01,  -9.80316579e-01,
                          2.90178563e-02,   9.67938304e-01,  -4.33238626e-01,
                         -7.87540555e-01,   7.61566579e-01,   4.69561696e-01,
                         -9.57792222e-01,  -7.02110380e-02,   9.86810088e-01,
                         -3.41720790e-01,  -8.44358742e-01,   6.93790555e-01,
                          5.54788947e-01,  -9.25527573e-01,  -1.68831170e-01,
                          9.95738626e-01,  -2.46956170e-01,  -8.93060088e-01,
                          6.19115233e-01,   6.34334445e-01,  -8.84131491e-01,
                         -2.65827924e-01,   9.94724035e-01,  -1.49553567e-01,
                         -9.32629883e-01,   5.38352251e-01,   7.07792222e-01,
                         -8.34009767e-01,  -3.59983772e-01,   9.83969152e-01,
                         -5.07305190e-02,  -9.63068187e-01,   4.52313304e-01,
                          7.74147749e-01,  -7.75568187e-01,  -4.50892866e-01,
                          9.63474035e-01,   4.84983772e-02,  -9.83969152e-01,
                          3.61607134e-01,   8.32792222e-01,  -7.09415555e-01,
                         -5.37134767e-01,   9.33238626e-01,   1.47321433e-01,
                         -9.95129883e-01,   2.67451286e-01,   8.83319795e-01,
                         -6.36363626e-01,  -6.18100643e-01,   8.93871725e-01,
                          2.44724020e-01,  -9.96347427e-01,   1.70657471e-01,
                          9.24918830e-01,  -5.56818187e-01,  -6.92978919e-01,
                          8.45576286e-01,   3.39691550e-01,  -9.87824678e-01,
                          7.20373392e-02,   9.57386374e-01,  -4.71793830e-01,
                         -7.60957778e-01,   7.88961053e-01,   4.31412339e-01,
                         -9.69358742e-01,  -2.71915589e-02,   9.80316579e-01,
                         -3.82102281e-01,  -8.21225643e-01,   7.24431813e-01,
                          5.18668830e-01,  -9.41152573e-01,  -1.26420453e-01,
                          9.93709445e-01,  -2.88555205e-01,  -8.73579562e-01,
                          6.52800322e-01,   6.01055205e-01,  -9.03814912e-01,
                         -2.24228889e-01,   9.97159064e-01,  -1.92167208e-01,
                         -9.17207778e-01,   5.74675322e-01,   6.77353919e-01,
                         -8.57548714e-01,  -3.19805205e-01,   9.90665555e-01,
                         -9.37500000e-02,  -9.51907456e-01,   4.90665585e-01,
                          7.46753275e-01,  -8.02556813e-01,  -4.12337661e-01,
                          9.74431813e-01,   5.47889620e-03,  -9.76866901e-01,
                          4.01785702e-01,   8.09050322e-01,  -7.39650965e-01,
                         -5.00608742e-01,   9.48254883e-01,   1.04707792e-01,
                         -9.92288947e-01,   3.09050322e-01,   8.63230526e-01,
                         -6.69439912e-01,  -5.84009767e-01,   9.12946403e-01,
                          2.02922076e-01,  -9.97970760e-01,   2.13068187e-01,
                          9.08685088e-01,  -5.92532456e-01,  -6.61728919e-01,
                          8.68506491e-01,   2.99107134e-01,  -9.93506491e-01,
                          1.15056820e-01,   9.45211053e-01,  -5.09740233e-01,
                         -7.32954562e-01,   8.15340936e-01,   3.92451286e-01,
                         -9.79301929e-01,   1.58279222e-02,   9.72402573e-01,
                         -4.21875000e-01,  -7.96672106e-01,   7.54058421e-01,
                          4.81737018e-01,  -9.55357134e-01,  -8.34009722e-02,
                          9.90056813e-01,  -3.29951286e-01,  -8.52678597e-01,
                          6.85267866e-01,   5.66355526e-01,  -9.21875000e-01,
                         -1.82021111e-01,   9.97767866e-01,  -2.34577924e-01,
                         -9.00162339e-01,   6.09780848e-01,   6.45495117e-01,
                         -8.79464269e-01,  -2.78814942e-01,   9.95535731e-01,
                         -1.36769474e-01,  -9.38717544e-01,   5.28206170e-01,
                          7.18141258e-01,  -8.27922106e-01,  -3.72767866e-01,
                          9.83360410e-01,  -3.77435051e-02,  -9.67938304e-01,
                          4.41152602e-01,   7.83482134e-01,  -7.68465936e-01,
                         -4.63271111e-01,   9.61444795e-01,   6.18912354e-02,
                         -9.87418830e-01,   3.50040585e-01,   8.41314912e-01,
                         -7.01095760e-01,  -5.48904240e-01,   9.29991901e-01,
                          1.60714284e-01,  -9.97159064e-01,   2.55073041e-01,
                          8.90625000e-01,  -6.27029240e-01,  -6.29261374e-01,
                          8.89204562e-01,   2.57913947e-01,  -9.97159064e-01,
                          1.57873377e-01,   9.31006491e-01,  -5.46469152e-01,
                         -7.03327894e-01,   8.39691579e-01,   3.52678567e-01,
                         -9.87012982e-01,   5.88474013e-02,   9.62256491e-01,
                         -4.60633129e-01,  -7.70292222e-01,   7.81655848e-01,
                          4.43993509e-01,  -9.67126608e-01,  -4.05844152e-02,
                          9.83969152e-01,  -3.70129883e-01,  -8.29748392e-01,
                          7.16112018e-01,   5.30641258e-01,  -9.37702894e-01,
                         -1.39813319e-01,   9.95738626e-01,  -2.75974035e-01,
                         -8.80884767e-01,   6.43262982e-01,   6.12215936e-01,
                         -8.98944795e-01,  -2.37418830e-01,   9.97767866e-01,
                         -1.78977266e-01,  -9.23295438e-01,   5.63920438e-01,
                          6.87702894e-01,  -8.51055205e-01,  -3.32792222e-01,
                          9.89650965e-01,  -8.03571418e-02,  -9.56371725e-01,
                          4.79099035e-01,   7.56290555e-01,  -7.94845760e-01,
                         -4.24918830e-01,   9.71793830e-01,   1.92775968e-02,
                         -9.80113626e-01,   3.89407456e-01,   8.17370117e-01,
                         -7.30722427e-01,  -5.12784064e-01,   9.44399357e-01,
                          1.18506491e-01,  -9.94115233e-01,   2.96063304e-01,
                          8.70332778e-01,  -6.59293830e-01,  -5.95373392e-01,
                          9.07467544e-01,   2.16517851e-01,  -9.97970760e-01,
                          1.99472398e-01,   9.14569795e-01,  -5.81371725e-01,
                         -6.72280848e-01,   8.61404240e-01,   3.12500000e-01,
                         -9.92086053e-01,   1.01055197e-01,   9.49675322e-01,
                         -4.97564942e-01,  -7.42288947e-01,   8.07021081e-01,
                          4.05438304e-01,  -9.76258099e-01,   1.62337662e-03,
                          9.75446403e-01,  -4.08887982e-01,  -8.04991901e-01,
                          7.44521081e-01,   4.94115263e-01,  -9.50892866e-01,
                         -9.78084430e-02,   9.91274357e-01,  -3.16152602e-01,
                         -8.59577894e-01,   6.74512982e-01,   5.78125000e-01,
                         -9.15787339e-01,  -1.96225643e-01,   9.97362018e-01,
                         -2.20170453e-01,  -9.05844152e-01,   5.97808421e-01,
                          6.56047106e-01,  -8.71753275e-01,  -2.92613626e-01,
                          9.93506491e-01,  -1.22159094e-01,  -9.42775965e-01,
                          5.15219152e-01,   7.27678597e-01,  -8.18993509e-01,
                         -3.86160702e-01,   9.79910731e-01,  -2.27272734e-02,
                         -9.70576286e-01,   4.27353889e-01,   7.92004883e-01,
                         -7.58116901e-01,  -4.75852281e-01,   9.56371725e-01,
                          7.67045468e-02,  -9.88433421e-01,   3.35430205e-01,
                          8.48214269e-01,  -6.89529240e-01,  -5.60876608e-01,
                          9.23295438e-01,   1.75324678e-01,  -9.96753275e-01,
                          2.40259737e-01,   8.96306813e-01,  -6.14245117e-01,
                         -6.40219152e-01,   8.81087661e-01,   2.72321433e-01,
                         -9.94926929e-01,   1.42451301e-01,   9.35267866e-01,
                         -5.32873392e-01,  -7.13068187e-01,   8.30154240e-01,
                          3.66477281e-01,  -9.83157456e-01,   4.34253253e-02,
                          9.64894474e-01,  -4.46225643e-01,  -7.79017866e-01,
                          7.70900965e-01,   4.57183450e-01,  -9.61850643e-01,
                         -5.60064949e-02,   9.84983742e-01,  -3.55113626e-01,
                         -8.37053597e-01,   7.03936696e-01,   5.43019474e-01,
                         -9.30803597e-01,  -1.55032471e-01,   9.95129883e-01,
                         -2.60349035e-01,  -8.86769474e-01,   6.30073071e-01,
                          6.23579562e-01,  -8.90422106e-01,  -2.52435058e-01,
                          9.95535731e-01,  -1.63149357e-01,  -9.27556813e-01,
                          5.49918830e-01,   6.98051929e-01,  -8.41314912e-01,
                         -3.47199678e-01,   9.85998392e-01,  -6.43263012e-02,
                         -9.59212661e-01,   4.64285702e-01,   7.65422106e-01,
                         -7.83887982e-01,  -4.38514620e-01,   9.66517866e-01,
                          3.51055190e-02,  -9.81331170e-01,   3.74188304e-01,
                          8.25081170e-01,  -7.18547106e-01,  -5.25568187e-01,
                          9.37500000e-01,   1.34131491e-01,  -9.93709445e-01,
                          2.80235380e-01,   8.76623392e-01,  -6.46103919e-01,
                         -6.07345760e-01,   8.99147749e-01,   2.31939942e-01,
                         -9.96144474e-01,   1.83441564e-01,   9.19439912e-01,
                         -5.67167222e-01,  -6.83035731e-01,   8.51866901e-01,
                          3.27313304e-01,  -9.88636374e-01,   8.50243494e-02,
                          9.52922106e-01,  -4.82751638e-01,  -7.51826286e-01,
                          7.96266258e-01,   4.19439942e-01,  -9.71387982e-01,
                         -1.44074671e-02,   9.77272749e-01,  -3.93465906e-01,
                         -8.13311696e-01,   7.32548714e-01,   5.07305205e-01,
                         -9.44399357e-01,  -1.13636367e-01,   9.91680205e-01,
                         -3.00324678e-01,  -8.66477251e-01,   6.61525965e-01,
                          5.90300322e-01,  -9.08076286e-01,  -2.11647734e-01,
                          9.96144474e-01,  -2.04139605e-01,  -9.11120117e-01,
                          5.84009767e-01,   6.67410731e-01,  -8.62621725e-01,
                         -3.07629883e-01,   9.90868509e-01,  -1.05925322e-01,
                         -9.46834445e-01,   5.00811696e-01,   7.37621725e-01,
                         -8.08847427e-01,  -4.00568187e-01,   9.75649357e-01,
                         -6.69642864e-03,  -9.73011374e-01,   4.12540585e-01,
                          8.00730526e-01,  -7.46753275e-01,  -4.89448041e-01,
                          9.50689912e-01,   9.25324708e-02,  -9.89448071e-01,
                          3.20008129e-01,   8.55722427e-01,  -6.77353919e-01,
                         -5.73457778e-01,   9.16396081e-01,   1.90949678e-01,
                         -9.96144474e-01,   2.24431813e-01,   9.02394474e-01,
                         -6.01258099e-01,  -6.51785731e-01,   8.72970760e-01,
                          2.87337661e-01,  -9.93100643e-01,   1.26826301e-01,
                          9.39935088e-01,  -5.19074678e-01,  -7.23620117e-01,
                          8.20819795e-01,   3.80884737e-01,  -9.79910731e-01,
                          2.75974032e-02,   9.68141258e-01,  -4.31818187e-01,
                         -7.88352251e-01,   7.60551929e-01,   4.70779210e-01,
                         -9.57183421e-01,  -7.16314912e-02,   9.86810088e-01,
                         -3.40300322e-01,  -8.45170438e-01,   6.92573071e-01,
                          5.56006491e-01,  -9.24715936e-01,  -1.70251623e-01,
                          9.95738626e-01,  -2.45332792e-01,  -8.93465936e-01,
                          6.17897749e-01,   6.35551929e-01,  -8.83319795e-01,
                         -2.67248362e-01,   9.94521081e-01,  -1.47930190e-01,
                         -9.33035731e-01,   5.36931813e-01,   7.08806813e-01,
                         -8.32995117e-01,  -3.61607134e-01,   9.83563304e-01,
                         -4.89042215e-02,  -9.63271081e-01,   4.50689942e-01,
                          7.75162339e-01,  -7.74350643e-01,  -4.52313304e-01,
                          9.62865233e-01,   5.03246747e-02,  -9.84172106e-01,
                          3.59983772e-01,   8.33603919e-01,  -7.07995117e-01,
                         -5.38555205e-01,   9.32426929e-01,   1.49350643e-01,
                         -9.94926929e-01,   2.65625000e-01,   8.83928597e-01,
                         -6.34740233e-01,  -6.19318187e-01,   8.92857134e-01,
                          2.46753246e-01,  -9.96144474e-01,   1.68628246e-01,
                          9.25527573e-01,  -5.54991901e-01,  -6.94196403e-01,
                          8.44358742e-01,   3.41720790e-01,  -9.87215936e-01,
                          7.00081140e-02,   9.57792222e-01,  -4.69764620e-01,
                         -7.61972427e-01,   7.87540555e-01,   4.33238626e-01,
                         -9.68547106e-01,  -2.94237006e-02,   9.80519474e-01,
                         -3.80073041e-01,  -8.22240233e-01,   7.22808421e-01,
                          5.20495117e-01,  -9.40137982e-01,  -1.28449678e-01,
                          9.93506491e-01,  -2.86323041e-01,  -8.74391258e-01,
                          6.50974035e-01,   6.02678597e-01,  -9.02597427e-01,
                         -2.26258114e-01,   9.96753275e-01,  -1.89935058e-01,
                         -9.17816579e-01,   5.72443187e-01,   6.78774357e-01,
                         -8.55925322e-01,  -3.21834415e-01,   9.90056813e-01,
                         -9.15178582e-02,  -9.52110410e-01,   4.88433450e-01,
                          7.48173714e-01,  -8.00730526e-01,  -4.14163947e-01,
                          9.73417222e-01,   7.91396108e-03,  -9.76866901e-01,
                          3.99553567e-01,   8.10064912e-01,  -7.37621725e-01,
                         -5.02435088e-01,   9.47240233e-01,   1.07142858e-01,
                         -9.92086053e-01,   3.06615263e-01,   8.64042222e-01,
                         -6.67207778e-01,  -5.85836053e-01,   9.11525965e-01,
                          2.05357149e-01,  -9.97362018e-01,   2.10633114e-01,
                          9.09293830e-01,  -5.90097427e-01,  -6.63352251e-01,
                          8.66680205e-01,   3.01542222e-01,  -9.92694795e-01,
                          1.12418830e-01,   9.45616901e-01,  -5.07305205e-01,
                         -7.34172106e-01,   8.13311696e-01,   3.94683450e-01,
                         -9.78287339e-01,   1.33928573e-02,   9.72402573e-01,
                         -4.19237018e-01,  -7.97686696e-01,   7.51826286e-01,
                          4.83766228e-01,  -9.53936696e-01,  -8.60389620e-02,
                          9.89650965e-01,  -3.27110380e-01,  -8.53490233e-01,
                          6.83035731e-01,   5.68181813e-01,  -9.20251608e-01,
                         -1.84456170e-01,   9.96956170e-01,  -2.31737018e-01,
                         -9.00568187e-01,   6.07345760e-01,   6.46915555e-01,
                         -8.77435088e-01,  -2.81047076e-01,   9.94521081e-01,
                         -1.34131491e-01,  -9.38920438e-01,   5.25568187e-01,
                          7.19358742e-01,  -8.25892866e-01,  -3.75000000e-01,
                          9.82142866e-01,  -3.51055190e-02,  -9.67735410e-01,
                          4.38717544e-01,   7.84496725e-01,  -7.66233742e-01,
                         -4.65097398e-01,   9.60024357e-01,   6.43263012e-02,
                         -9.87012982e-01,   3.47402602e-01,   8.41923714e-01,
                         -6.98863626e-01,  -5.50527573e-01,   9.28368509e-01,
                          1.62946433e-01,  -9.96550322e-01,   2.52637982e-01,
                          8.90827894e-01,  -6.24797106e-01,  -6.30478919e-01,
                          8.87581170e-01,   2.59943187e-01,  -9.96347427e-01,
                          1.55641228e-01,   9.31006491e-01,  -5.44439912e-01,
                         -7.04139590e-01,   8.37865233e-01,   3.54301959e-01,
                         -9.85998392e-01,   5.70211038e-02,   9.62053597e-01,
                         -4.58603889e-01,  -7.70900965e-01,   7.80032456e-01,
                          4.45008129e-01,  -9.66112018e-01,  -4.22077924e-02,
                          9.83360410e-01,  -3.68506491e-01,  -8.29951286e-01,
                          7.14488626e-01,   5.31452894e-01,  -9.36688304e-01,
                         -1.40827924e-01,   9.95129883e-01,  -2.74756491e-01,
                         -8.80681813e-01,   6.42045438e-01,   6.12621725e-01,
                         -8.97930205e-01,  -2.38027602e-01,   9.97159064e-01,
                         -1.78368509e-01,  -9.22889590e-01,   5.63311696e-01,
                          6.87500000e-01,  -8.50446403e-01,  -3.32792222e-01,
                          9.89245117e-01,  -8.03571418e-02,  -9.55965936e-01,
                          4.79099035e-01,   7.55681813e-01,  -7.94845760e-01,
                         -4.24512982e-01,   9.71387982e-01,   1.90746747e-02,
                         -9.79707778e-01,   3.89204532e-01,   8.16964269e-01,
                         -7.30316579e-01,  -5.12581170e-01,   9.43790555e-01,
                          1.18709415e-01,  -9.93709445e-01,   2.95454532e-01,
                          8.70129883e-01,  -6.58685088e-01,  -5.95576286e-01,
                          9.06858742e-01,   2.16923699e-01,  -9.97564912e-01,
                          1.98863640e-01,   9.14366901e-01,  -5.80560088e-01,
                         -6.72483742e-01,   8.60795438e-01,   3.13108772e-01,
                         -9.91680205e-01,   1.00446425e-01,   9.49472427e-01,
                         -4.96753246e-01,  -7.42491901e-01,   8.06209445e-01,
                          4.05844152e-01,  -9.75852251e-01,   8.11688311e-04,
                          9.75243509e-01,  -4.08076286e-01,  -8.05194795e-01,
                          7.43709445e-01,   4.94724035e-01,  -9.50284064e-01,
                         -9.84172076e-02,   9.91274357e-01,  -3.15340906e-01,
                         -8.59983742e-01,   6.73701286e-01,   5.78530848e-01,
                         -9.15381491e-01,  -1.96834415e-01,   9.97362018e-01,
                         -2.19358772e-01,  -9.06047106e-01,   5.97199678e-01,
                          6.56655848e-01,  -8.71347427e-01,  -2.93425322e-01,
                          9.93506491e-01,  -1.21347405e-01,  -9.42978919e-01,
                          5.14610410e-01,   7.28084445e-01,  -8.18587661e-01,
                         -3.86769474e-01,   9.79707778e-01,  -2.23214291e-02,
                         -9.70779240e-01,   4.26948041e-01,   7.92410731e-01,
                         -7.57711053e-01,  -4.76461053e-01,   9.56371725e-01,
                          7.71103874e-02,  -9.88839269e-01,   3.35024357e-01,
                          8.48620117e-01,  -6.89529240e-01,  -5.61282456e-01,
                          9.23295438e-01,   1.75730526e-01,  -9.96956170e-01,
                          2.39853889e-01,   8.96509767e-01,  -6.14245117e-01,
                         -6.40625000e-01,   8.81290555e-01,   2.72727281e-01,
                         -9.95332778e-01,   1.42248377e-01,   9.35673714e-01,
                         -5.32873392e-01,  -7.13474035e-01,   8.30357134e-01,
                          3.66883129e-01,  -9.83766258e-01,   4.34253253e-02,
                          9.65300322e-01,  -4.46428567e-01,  -7.79423714e-01,
                          7.71306813e-01,   4.57386374e-01,  -9.62256491e-01,
                         -5.60064949e-02,   9.85389590e-01,  -3.55316550e-01,
                         -8.37459445e-01,   7.04545438e-01,   5.43222427e-01,
                         -9.31412339e-01,  -1.55032471e-01,   9.95738626e-01,
                         -2.60754883e-01,  -8.87175322e-01,   6.30681813e-01,
                          6.23782456e-01,  -8.91233742e-01,  -2.52232134e-01,
                          9.96144474e-01,  -1.63555190e-01,  -9.28165555e-01,
                          5.50527573e-01,   6.98254883e-01,  -8.42126608e-01,
                         -3.47199678e-01,   9.86607134e-01,  -6.49350658e-02,
                         -9.60024357e-01,   4.65097398e-01,   7.65625000e-01,
                         -7.84699678e-01,  -4.38514620e-01,   9.67329562e-01,
                          3.44967544e-02,  -9.82142866e-01,   3.74797076e-01,
                          8.25487018e-01,  -7.19561696e-01,  -5.25568187e-01,
                          9.38514590e-01,   1.33725643e-01,  -9.94521081e-01,
                          2.80844152e-01,   8.77029240e-01,  -6.47118509e-01,
                         -6.07345760e-01,   9.00162339e-01,   2.31534094e-01,
                         -9.97159064e-01,   1.84253246e-01,   9.19845760e-01,
                         -5.68384767e-01,  -6.83035731e-01,   8.53084445e-01,
                          3.26907456e-01,  -9.89650965e-01,   8.56331140e-02,
                          9.53733742e-01,  -4.83766228e-01,  -7.52029240e-01,
                          7.97280848e-01,   4.19237018e-01,  -9.72402573e-01,
                         -1.37987016e-02,   9.77881491e-01,  -3.94480526e-01,
                         -8.13514590e-01,   7.33563304e-01,   5.07305205e-01,
                         -9.45616901e-01,  -1.13027595e-01,   9.92288947e-01,
                         -3.01339298e-01,  -8.67086053e-01,   6.62743509e-01,
                          5.90300322e-01,  -9.09293830e-01,  -2.11241886e-01,
                          9.96956170e-01,  -2.04951301e-01,  -9.11728919e-01,
                          5.85024357e-01,   6.67410731e-01,  -8.63839269e-01,
                         -3.07224035e-01,   9.91680205e-01,  -1.06737010e-01,
                         -9.47443187e-01,   5.01623392e-01,   7.37824678e-01,
                         -8.09862018e-01,  -4.00162339e-01,   9.76461053e-01,
                         -7.50811677e-03,  -9.73620117e-01,   4.13352281e-01,
                          8.00933421e-01,  -7.47767866e-01,  -4.89245117e-01,
                          9.51501608e-01,   9.19236988e-02,  -9.90259767e-01,
                          3.20819795e-01,   8.55925322e-01,  -6.78165555e-01,
                         -5.73457778e-01,   9.17207778e-01,   1.90340906e-01,
                         -9.96956170e-01,   2.25040585e-01,   9.02597427e-01,
                         -6.02069795e-01,  -6.51785731e-01,   8.73579562e-01,
                          2.86931813e-01,  -9.93506491e-01,   1.27232149e-01,
                          9.40137982e-01,  -5.19683421e-01,  -7.23620117e-01,
                          8.21428597e-01,   3.80681813e-01,  -9.80519474e-01,
                          2.80032475e-02,   9.68344152e-01,  -4.32426959e-01,
                         -7.88352251e-01,   7.60957778e-01,   4.70576286e-01,
                         -9.57589269e-01,  -7.14285746e-02,   9.87012982e-01,
                         -3.40706170e-01,  -8.45170438e-01,   6.92978919e-01,
                          5.55600643e-01,  -9.25121725e-01,  -1.70048699e-01,
                          9.95738626e-01,  -2.45738640e-01,  -8.93465936e-01,
                          6.18100643e-01,   6.35146081e-01,  -8.83319795e-01,
                         -2.67045468e-01,   9.94521081e-01,  -1.48133114e-01,
                         -9.32832778e-01,   5.37134767e-01,   7.08400965e-01,
                         -8.32995117e-01,  -3.61201286e-01,   9.83360410e-01,
                         -4.93100658e-02,  -9.63068187e-01,   4.50689942e-01,
                          7.74756491e-01,  -7.74147749e-01,  -4.51907456e-01,
                          9.62459445e-01,   5.01217544e-02,  -9.83563304e-01,
                          3.59983772e-01,   8.32995117e-01,  -7.07792222e-01,
                         -5.38149357e-01,   9.32021081e-01,   1.48944810e-01,
                         -9.94318187e-01,   2.65625000e-01,   8.83319795e-01,
                         -6.34537339e-01,  -6.18912339e-01,   8.92248392e-01,
                          2.46144474e-01,  -9.95332778e-01,   1.68628246e-01,
                          9.24512982e-01,  -5.54788947e-01,  -6.93384767e-01,
                          8.43750000e-01,   3.41112018e-01,  -9.86201286e-01,
                          7.02110380e-02,   9.56574678e-01,  -4.69561696e-01,
                         -7.60957778e-01,   7.86728919e-01,   4.32426959e-01,
                         -9.67532456e-01,  -2.92207785e-02,   9.79301929e-01,
                         -3.79667222e-01,  -8.21022749e-01,   7.21996725e-01,
                          5.19480526e-01,  -9.39123392e-01,  -1.28043830e-01,
                          9.92086053e-01,  -2.86120117e-01,  -8.72970760e-01,
                          6.50162339e-01,   6.01461053e-01,  -9.01379883e-01,
                         -2.25649357e-01,   9.95129883e-01,  -1.89935058e-01,
                         -9.16193187e-01,   5.71834445e-01,   6.77353919e-01,
                         -8.54707778e-01,  -3.21022719e-01,   9.88230526e-01,
                         -9.15178582e-02,  -9.50284064e-01,   4.87824678e-01,
                          7.46550322e-01,  -7.99512982e-01,  -4.13149357e-01,
                          9.71590936e-01,   7.50811677e-03,  -9.75040555e-01,
                          3.98944795e-01,   8.08238626e-01,  -7.36404240e-01,
                         -5.01217544e-01,   9.45211053e-01,   1.06534094e-01,
                         -9.90056813e-01,   3.06209415e-01,   8.61810088e-01,
                         -6.66193187e-01,  -5.84212661e-01,   9.09496725e-01,
                          2.04342529e-01,  -9.95129883e-01,   2.10430190e-01,
                          9.07061696e-01,  -5.89285731e-01,  -6.61525965e-01,
                          8.64853919e-01,   3.00324678e-01,  -9.90462661e-01,
                          1.12621754e-01,   9.43181813e-01,  -5.06493509e-01,
                         -7.32142866e-01,   8.11485410e-01,   3.93060058e-01,
                         -9.75852251e-01,   1.37987016e-02,   9.69764590e-01,
                         -4.18628246e-01,  -7.95454562e-01,   7.50202894e-01,
                          4.82142866e-01,  -9.51704562e-01,  -8.52272734e-02,
                          9.87012982e-01,  -3.26704532e-01,  -8.50852251e-01,
                          6.81412339e-01,   5.66152573e-01,  -9.18019474e-01,
                         -1.83441564e-01,   9.94318187e-01,  -2.31737018e-01,
                         -8.97930205e-01,   6.05925322e-01,   6.44886374e-01,
                         -8.75405848e-01,  -2.79829532e-01,   9.91883099e-01,
                         -1.34131491e-01,  -9.36079562e-01,   5.24553597e-01,
                          7.16923714e-01,  -8.23863626e-01,  -3.73579532e-01,
                          9.79504883e-01,  -3.55113633e-02,  -9.64894474e-01,
                          4.37702924e-01,   7.82061696e-01,  -7.64407456e-01,
                         -4.63474035e-01,   9.57386374e-01,   6.37175292e-02,
                         -9.84172106e-01,   3.46590906e-01,   8.39285731e-01,
                         -6.97240233e-01,  -5.48701286e-01,   9.25730526e-01,
                          1.62134737e-01,  -9.93709445e-01,   2.52232134e-01,
                          8.88189912e-01,  -6.22970760e-01,  -6.28652573e-01,
                          8.84943187e-01,   2.58928567e-01,  -9.93303597e-01,
                          1.55235395e-01,   9.28368509e-01,  -5.42816579e-01,
                         -7.02110410e-01,   8.35430205e-01,   3.53287339e-01,
                         -9.83157456e-01,   5.66152595e-02,   9.59212661e-01,
                         -4.56980526e-01,  -7.68871725e-01,   7.77597427e-01,
                          4.44196433e-01,  -9.63271081e-01,  -4.26136367e-02,
                          9.80722427e-01,  -3.66883129e-01,  -8.27922106e-01,
                          7.12053597e-01,   5.30641258e-01,  -9.33644474e-01,
                         -1.41436681e-01,   9.92288947e-01,  -2.72930205e-01,
                         -8.78855526e-01,   6.39407456e-01,   6.11810088e-01,
                         -8.94886374e-01,  -2.38839284e-01,   9.94115233e-01,
                         -1.76339284e-01,  -9.20860410e-01,   5.60267866e-01,
                          6.86891258e-01,  -8.47199678e-01,  -3.33806813e-01,
                          9.86201286e-01,  -7.79220760e-02,  -9.53936696e-01,
                          4.75649357e-01,   7.55275965e-01,  -7.90990233e-01,
                         -4.25527602e-01,   9.68344152e-01,   2.13068184e-02,
                         -9.77475643e-01,   3.86160702e-01,   8.15949678e-01,
                         -7.27069795e-01,  -5.12987018e-01,   9.40746725e-01,
                          1.20332792e-01,  -9.91274357e-01,   2.93019474e-01,
                          8.68709445e-01,  -6.55641258e-01,  -5.95373392e-01,
                          9.03814912e-01,   2.18141228e-01,  -9.95129883e-01,
                          1.96834415e-01,   9.12743509e-01,  -5.77922106e-01,
                         -6.72077894e-01,   8.57954562e-01,   3.13717544e-01,
                         -9.89245117e-01,   9.86201316e-02,   9.47849035e-01,
                         -4.94318187e-01,  -7.41883099e-01,   8.03571403e-01,
                          4.06250000e-01,  -9.73417222e-01,  -6.08766219e-04,
                          9.73417222e-01,  -4.05844152e-01,  -8.04383099e-01,
                          7.41071403e-01,   4.94926959e-01,  -9.47849035e-01,
                         -9.96347368e-02,   9.89245117e-01,  -3.13311696e-01,
                         -8.58766258e-01,   6.71266258e-01,   5.78530848e-01,
                         -9.12946403e-01,  -1.97849020e-01,   9.95332778e-01,
                         -2.17532471e-01,  -9.04829562e-01,   5.94764590e-01,
                          6.56452894e-01,  -8.68912339e-01,  -2.94237018e-01,
                          9.91274357e-01,  -1.19724028e-01,  -9.41761374e-01,
                          5.12175322e-01,   7.27678597e-01,  -8.16152573e-01,
                         -3.87581170e-01,   9.77475643e-01,  -2.04951297e-02,
                         -9.69358742e-01,   4.24715906e-01,   7.91801929e-01,
                         -7.55275965e-01,  -4.77069795e-01,   9.54139590e-01,
                          7.87337646e-02,  -9.87215936e-01,   3.32792222e-01,
                          8.48011374e-01,  -6.86891258e-01,  -5.61688304e-01,
                          9.21063304e-01,   1.77150980e-01,  -9.95332778e-01,
                          2.37824678e-01,   8.95900965e-01,  -6.11810088e-01,
                         -6.40827894e-01,   8.78855526e-01,   2.73944795e-01,
                         -9.93303597e-01,   1.40219152e-01,   9.34659064e-01,
                         -5.30438304e-01,  -7.13676929e-01,   8.27922106e-01,
                          3.67897719e-01,  -9.81737018e-01,   4.13961038e-02,
                          9.64082778e-01,  -4.43790585e-01,  -7.79220760e-01,
                          7.68668830e-01,   4.58400965e-01,  -9.60227251e-01,
                         -5.80357127e-02,   9.84172106e-01,  -3.52881491e-01,
                         -8.37256491e-01,   7.01907456e-01,   5.44034064e-01,
                         -9.29180205e-01,  -1.56655848e-01,   9.94318187e-01,
                         -2.58319795e-01,  -8.86769474e-01,   6.28043830e-01,
                          6.24391258e-01,  -8.88798714e-01,  -2.53855526e-01,
                          9.94521081e-01,  -1.61323056e-01,  -9.27353919e-01,
                          5.47889590e-01,   6.98660731e-01,  -8.39691579e-01,
                         -3.48620117e-01,   9.84780848e-01,  -6.25000000e-02,
                         -9.59009767e-01,   4.62459415e-01,   7.65827894e-01,
                         -7.82061696e-01,  -4.39732134e-01,   9.65300322e-01,
                          3.67288962e-02,  -9.80925322e-01,   3.72362018e-01,
                          8.25284064e-01,  -7.16923714e-01,  -5.26379883e-01,
                          9.36282456e-01,   1.35551944e-01,  -9.93100643e-01,
                          2.78409094e-01,   8.76623392e-01,  -6.44480526e-01,
                         -6.07954562e-01,   8.97930205e-01,   2.33157471e-01,
                         -9.95332778e-01,   1.82021111e-01,   9.19237018e-01,
                         -5.65746725e-01,  -6.83441579e-01,   8.50649357e-01,
                          3.28327924e-01,  -9.87824678e-01,   8.36038962e-02,
                          9.52719152e-01,  -4.81331170e-01,  -7.52029240e-01,
                          7.94845760e-01,   4.20251638e-01,  -9.70373392e-01,
                         -1.56250000e-02,   9.76663947e-01,  -3.92248362e-01,
                         -8.13311696e-01,   7.31331170e-01,   5.07913947e-01,
                         -9.43384767e-01,  -1.14650972e-01,   9.91071403e-01,
                         -2.99107134e-01,  -8.66477251e-01,   6.60308421e-01,
                          5.90706170e-01,  -9.07061696e-01,  -2.12459415e-01,
                          9.95535731e-01,  -2.03125000e-01,  -9.10917222e-01,
                          5.82995117e-01,   6.67410731e-01,  -8.61607134e-01,
                         -3.08035702e-01,   9.90056813e-01,  -1.05113633e-01,
                         -9.46428597e-01,   4.99797076e-01,   7.37621725e-01,
                         -8.07832778e-01,  -4.00771111e-01,   9.74837661e-01,
                         -6.08766219e-03,  -9.72402573e-01,   4.11728889e-01,
                          8.00324678e-01,  -7.45941579e-01,  -4.89448041e-01,
                          9.49878275e-01,   9.29383114e-02,  -9.88839269e-01,
                          3.19399357e-01,   8.55316579e-01,  -6.76542222e-01,
                         -5.73254883e-01,   9.15584445e-01,   1.91152602e-01,
                         -9.95332778e-01,   2.24025980e-01,   9.01785731e-01,
                         -6.00446403e-01,  -6.51379883e-01,   8.72159064e-01,
                          2.87337661e-01,  -9.92086053e-01,   1.26420453e-01,
                          9.39123392e-01,  -5.18465936e-01,  -7.23011374e-01,
                          8.20008099e-01,   3.80681813e-01,  -9.79099035e-01,
                          2.75974032e-02,   9.67329562e-01,  -4.31412339e-01,
                         -7.87540555e-01,   7.59740233e-01,   4.70373362e-01,
                         -9.56168830e-01,  -7.14285746e-02,   9.85998392e-01,
                         -3.40097398e-01,  -8.44155848e-01,   6.92167222e-01,
                          5.55194795e-01,  -9.23904240e-01,  -1.70048699e-01,
                          9.94724035e-01,  -2.45332792e-01,  -8.92654240e-01,
                          6.17491901e-01,   6.34740233e-01,  -8.82508099e-01,
                         -2.66639620e-01,   9.93709445e-01,  -1.48133114e-01,
                         -9.32021081e-01,   5.36728919e-01,   7.07792222e-01,
                         -8.32386374e-01,  -3.60795468e-01,   9.82751608e-01,
                         -4.95129861e-02,  -9.62256491e-01,   4.50689942e-01,
                          7.73944795e-01,  -7.73944795e-01,  -4.51298714e-01,
                          9.62053597e-01,   4.97159101e-02,  -9.82954562e-01,
                          3.60186696e-01,   8.32589269e-01,  -7.07792222e-01,
                         -5.37337661e-01,   9.31818187e-01,   1.48538962e-01,
                         -9.93912339e-01,   2.66030848e-01,   8.82711053e-01,
                         -6.34537339e-01,  -6.18100643e-01,   8.92248392e-01,
                          2.45738640e-01,  -9.95129883e-01,   1.69237018e-01,
                          9.24310088e-01,  -5.55194795e-01,  -6.92775965e-01,
                          8.43952894e-01,   3.40503246e-01,  -9.86201286e-01,
                          7.08198026e-02,   9.56574678e-01,  -4.70170468e-01,
                         -7.60551929e-01,   7.87337661e-01,   4.32021111e-01,
                         -9.67735410e-01,  -2.84090918e-02,   9.79301929e-01,
                         -3.80478889e-01,  -8.20819795e-01,   7.22605526e-01,
                          5.19074678e-01,  -9.39529240e-01,  -1.27435058e-01,
                          9.92491901e-01,  -2.86931813e-01,  -8.72970760e-01,
                          6.50974035e-01,   6.01258099e-01,  -9.01988626e-01,
                         -2.25040585e-01,   9.95738626e-01,  -1.90543830e-01,
                         -9.16396081e-01,   5.72646081e-01,   6.77353919e-01,
                         -8.55519474e-01,  -3.20616871e-01,   9.89042222e-01,
                         -9.23295468e-02,  -9.50689912e-01,   4.88839298e-01,
                          7.46753275e-01,  -8.00527573e-01,  -4.12946433e-01,
                          9.72605526e-01,   6.89935079e-03,  -9.75649357e-01,
                          3.99959415e-01,   8.08644474e-01,  -7.37621725e-01,
                         -5.01217544e-01,   9.46428597e-01,   1.06128246e-01,
                         -9.90868509e-01,   3.07224035e-01,   8.62621725e-01,
                         -6.67207778e-01,  -5.84415555e-01,   9.10917222e-01,
                          2.04139605e-01,  -9.96347427e-01,   2.11241886e-01,
                          9.07873392e-01,  -5.90300322e-01,  -6.61931813e-01,
                          8.66274357e-01,   3.00324678e-01,  -9.91680205e-01,
                          1.13230519e-01,   9.44196403e-01,  -5.07508099e-01,
                         -7.32751608e-01,   8.12905848e-01,   3.93465906e-01,
                         -9.77272749e-01,   1.42045459e-02,   9.71185088e-01,
                         -4.19439942e-01,  -7.96469152e-01,   7.51623392e-01,
                          4.82548714e-01,  -9.53125000e-01,  -8.52272734e-02,
                          9.88433421e-01,  -3.27516228e-01,  -8.52069795e-01,
                          6.82629883e-01,   5.66964269e-01,  -9.19439912e-01,
                         -1.83644474e-01,   9.95941579e-01,  -2.32142851e-01,
                         -8.99350643e-01,   6.07142866e-01,   6.45900965e-01,
                         -8.76623392e-01,  -2.80235380e-01,   9.93506491e-01,
                         -1.34334415e-01,  -9.37500000e-01,   5.25365233e-01,
                          7.18141258e-01,  -8.25284064e-01,  -3.74188304e-01,
                          9.81128275e-01,  -3.53084430e-02,  -9.66517866e-01,
                          4.38514620e-01,   7.83482134e-01,  -7.65422106e-01,
                         -4.64285702e-01,   9.59009767e-01,   6.39204532e-02,
                         -9.85795438e-01,   3.47199678e-01,   8.40909064e-01,
                         -6.98051929e-01,  -5.49715936e-01,   9.27353919e-01,
                          1.62743509e-01,  -9.95332778e-01,   2.52435058e-01,
                          8.89813304e-01,  -6.23782456e-01,  -6.29667222e-01,
                          8.86363626e-01,   2.59740263e-01,  -9.94926929e-01,
                          1.55235395e-01,   9.29991901e-01,  -5.43425322e-01,
                         -7.03530848e-01,   8.36647749e-01,   3.54301959e-01,
                         -9.84577894e-01,   5.64123392e-02,   9.60836053e-01,
                         -4.57589298e-01,  -7.70292222e-01,   7.78612018e-01,
                          4.45211053e-01,  -9.64488626e-01,  -4.30194810e-02,
                          9.82142866e-01,  -3.67086053e-01,  -8.29342544e-01,
                          7.12865233e-01,   5.31655848e-01,  -9.34862018e-01,
                         -1.41842529e-01,   9.93709445e-01,  -2.72930205e-01,
                         -8.80073071e-01,   6.40016258e-01,   6.12824678e-01,
                         -8.95900965e-01,  -2.39245132e-01,   9.95535731e-01,
                         -1.76136360e-01,  -9.22077894e-01,   5.60673714e-01,
                          6.87905848e-01,  -8.48011374e-01,  -3.34415585e-01,
                          9.87215936e-01,  -7.77191594e-02,  -9.54951286e-01,
                          4.75852281e-01,   7.56290555e-01,  -7.91599035e-01,
                         -4.26136374e-01,   9.69155848e-01,   2.15097405e-02,
                         -9.78287339e-01,   3.86363626e-01,   8.16964269e-01,
                         -7.27475643e-01,  -5.13595760e-01,   9.41558421e-01,
                          1.20535716e-01,  -9.92086053e-01,   2.93019474e-01,
                          8.69521081e-01,  -6.56047106e-01,  -5.95982134e-01,
                          9.04626608e-01,   2.18344152e-01,  -9.95941579e-01,
                          1.96834415e-01,   9.13555205e-01,  -5.78327894e-01,
                         -6.72483742e-01,   8.58563304e-01,   3.13920468e-01,
                         -9.89853919e-01,   9.88230556e-02,   9.48254883e-01,
                         -4.94724035e-01,  -7.42086053e-01,   8.04180205e-01,
                          4.06452924e-01,  -9.73823071e-01,  -4.05844155e-04,
                          9.73823071e-01,  -4.06250000e-01,  -8.04586053e-01,
                          7.41680205e-01,   4.94926959e-01,  -9.48254883e-01,
                         -9.94318202e-02,   9.89650965e-01,  -3.13717544e-01,
                         -8.58969152e-01,   6.71875000e-01,   5.78327894e-01,
                         -9.13352251e-01,  -1.97443187e-01,   9.95535731e-01,
                         -2.18141228e-01,  -9.04829562e-01,   5.95373392e-01,
                          6.56047106e-01,  -8.69318187e-01,  -2.93628246e-01,
                          9.91477251e-01,  -1.20332792e-01,  -9.41558421e-01,
                          5.12987018e-01,   7.27272749e-01,  -8.16558421e-01,
                         -3.86769474e-01,   9.77678597e-01,  -2.13068184e-02,
                         -9.69155848e-01,   4.25324678e-01,   7.91396081e-01,
                         -7.55884767e-01,  -4.76258129e-01,   9.54342544e-01,
                          7.79220760e-02,  -9.87012982e-01,   3.33603889e-01,
                          8.47605526e-01,  -6.87500000e-01,  -5.60876608e-01,
                          9.21266258e-01,   1.76339284e-01,  -9.95129883e-01,
                          2.38636360e-01,   8.95292222e-01,  -6.12418830e-01,
                         -6.40016258e-01,   8.79261374e-01,   2.72930205e-01,
                         -9.93506491e-01,   1.41233772e-01,   9.34253275e-01,
                         -5.31250000e-01,  -7.12865233e-01,   8.28530848e-01,
                          3.66883129e-01,  -9.81737018e-01,   4.24107127e-02,
                          9.63879883e-01,  -4.44805205e-01,  -7.78612018e-01,
                          7.69480526e-01,   4.57183450e-01,  -9.60430205e-01,
                         -5.68181835e-02,   9.83969152e-01,  -3.53896111e-01,
                         -8.36444795e-01,   7.02719152e-01,   5.43019474e-01,
                         -9.29586053e-01,  -1.55438319e-01,   9.94115233e-01,
                         -2.59537339e-01,  -8.86160731e-01,   6.29058421e-01,
                          6.23376608e-01,  -8.89407456e-01,  -2.52637982e-01,
                          9.94521081e-01,  -1.62540585e-01,  -9.26948071e-01,
                          5.48904240e-01,   6.97646081e-01,  -8.40300322e-01,
                         -3.47402602e-01,   9.84983742e-01,  -6.37175292e-02,
                         -9.58603919e-01,   4.63474035e-01,   7.65016258e-01,
                         -7.82670438e-01,  -4.38717544e-01,   9.65503275e-01,
                          3.57142873e-02,  -9.80519474e-01,   3.73173714e-01,
                          8.24675322e-01,  -7.17329562e-01,  -5.25568187e-01,
                          9.36282456e-01,   1.34943187e-01,  -9.92694795e-01,
                          2.78814942e-01,   8.76014590e-01,  -6.44480526e-01,
                         -6.07548714e-01,   8.97727251e-01,   2.32345775e-01,
                         -9.94926929e-01,   1.82629868e-01,   9.18425322e-01,
                         -5.66152573e-01,  -6.82426929e-01,   8.50649357e-01,
                          3.27110380e-01,  -9.87418830e-01,   8.48214254e-02,
                          9.51704562e-01,  -4.82142866e-01,  -7.50811696e-01,
                          7.95251608e-01,   4.18628246e-01,  -9.70170438e-01,
                         -1.40016237e-02,   9.75649357e-01,  -3.93262982e-01,
                         -8.11891258e-01,   7.31737018e-01,   5.06290555e-01,
                         -9.43384767e-01,  -1.12824678e-01,   9.90056813e-01,
                         -3.00527602e-01,  -8.65056813e-01,   6.61120117e-01,
                          5.88879883e-01,  -9.07061696e-01,  -2.10633114e-01,
                          9.94724035e-01,  -2.04748377e-01,  -9.09699678e-01,
                          5.84009767e-01,   6.65787339e-01,  -8.62012982e-01,
                         -3.06412339e-01,   9.89650965e-01,  -1.06737010e-01,
                         -9.45413947e-01,   5.01014590e-01,   7.36201286e-01,
                         -8.08441579e-01,  -3.99147719e-01,   9.74634767e-01,
                         -7.71103892e-03,  -9.71793830e-01,   4.12946433e-01,
                          7.99107134e-01,  -7.46753275e-01,  -4.88027602e-01,
                          9.50081170e-01,   9.13149342e-02,  -9.88433421e-01,
                          3.20819795e-01,   8.54301929e-01,  -6.77556813e-01,
                         -5.71834445e-01,   9.15990233e-01,   1.89529225e-01,
                         -9.95332778e-01,   2.25446433e-01,   9.00974035e-01,
                         -6.01663947e-01,  -6.50162339e-01,   8.72767866e-01,
                          2.85917222e-01,  -9.92288947e-01,   1.27840906e-01,
                          9.38717544e-01,  -5.19886374e-01,  -7.22199678e-01,
                          8.20819795e-01,   3.79261374e-01,  -9.79504883e-01,
                          2.90178563e-02,   9.67126608e-01,  -4.32832778e-01,
                         -7.86728919e-01,   7.60754883e-01,   4.69155848e-01,
                         -9.56777573e-01,  -7.02110380e-02,   9.85795438e-01,
                         -3.41314942e-01,  -8.43750000e-01,   6.92978919e-01,
                          5.54180205e-01,  -9.24512982e-01,  -1.68831170e-01,
                          9.94724035e-01,  -2.46550322e-01,  -8.92248392e-01,
                          6.18506491e-01,   6.33928597e-01,  -8.83116901e-01,
                         -2.65827924e-01,   9.93709445e-01,  -1.49147734e-01,
                         -9.31818187e-01,   5.37743509e-01,   7.07183421e-01,
                         -8.32995117e-01,  -3.59983772e-01,   9.82954562e-01,
                         -5.03246747e-02,  -9.62256491e-01,   4.51501638e-01,
                          7.73538947e-01,  -7.74553597e-01,  -4.50689942e-01,
                          9.62256491e-01,   4.89042215e-02,  -9.83157456e-01,
                          3.60795468e-01,   8.32183421e-01,  -7.08400965e-01,
                         -5.36931813e-01,   9.32224035e-01,   1.47727266e-01,
                         -9.94115233e-01,   2.66639620e-01,   8.82711053e-01,
                         -6.35146081e-01,  -6.17897749e-01,   8.92654240e-01,
                          2.45129868e-01,  -9.95332778e-01,   1.69845775e-01,
                          9.24107134e-01,  -5.55600643e-01,  -6.92775965e-01,
                          8.44358742e-01,   3.40097398e-01,  -9.86607134e-01,
                          7.12256506e-02,   9.56574678e-01,  -4.70576286e-01,
                         -7.60551929e-01,   7.87540555e-01,   4.31615263e-01,
                         -9.67938304e-01,  -2.80032475e-02,   9.79301929e-01,
                         -3.80884737e-01,  -8.20819795e-01,   7.23011374e-01,
                          5.18871725e-01,  -9.39732134e-01,  -1.27029225e-01,
                          9.92491901e-01,  -2.87337661e-01,  -8.72970760e-01,
                          6.51176929e-01,   6.00852251e-01,  -9.02191579e-01,
                         -2.24837661e-01,   9.95738626e-01,  -1.90949678e-01,
                         -9.16396081e-01,   5.72849035e-01,   6.76948071e-01,
                         -8.55722427e-01,  -3.20211053e-01,   9.89042222e-01,
                         -9.25324708e-02,  -9.50689912e-01,   4.88839298e-01,
                          7.46347427e-01,  -8.00527573e-01,  -4.12540585e-01,
                          9.72402573e-01,   6.69642864e-03,  -9.75446403e-01,
                          3.99959415e-01,   8.08238626e-01,  -7.37621725e-01,
                         -5.00811696e-01,   9.46225643e-01,   1.05722405e-01,
                         -9.90665555e-01,   3.07224035e-01,   8.62215936e-01,
                         -6.67207778e-01,  -5.84212661e-01,   9.10511374e-01,
                          2.03936681e-01,  -9.95941579e-01,   2.11241886e-01,
                          9.07467544e-01,  -5.90097427e-01,  -6.61525965e-01,
                          8.65868509e-01,   2.99918830e-01,  -9.91274357e-01,
                          1.13230519e-01,   9.43790555e-01,  -5.07305205e-01,
                         -7.32345760e-01,   8.12702894e-01,   3.93060058e-01,
                         -9.76866901e-01,   1.42045459e-02,   9.70779240e-01,
                         -4.19439942e-01,  -7.96063304e-01,   7.51217544e-01,
                          4.82345790e-01,  -9.52719152e-01,  -8.50243494e-02,
                          9.88027573e-01,  -3.27516228e-01,  -8.51663947e-01,
                          6.82426929e-01,   5.66558421e-01,  -9.19237018e-01,
                         -1.83441564e-01,   9.95332778e-01,  -2.32142851e-01,
                         -8.98944795e-01,   6.06939912e-01,   6.45292222e-01,
                         -8.76420438e-01,  -2.80032456e-01,   9.92897749e-01,
                         -1.34537339e-01,  -9.37094152e-01,   5.25162339e-01,
                          7.17532456e-01,  -8.24878275e-01,  -3.73782456e-01,
                          9.80519474e-01,  -3.57142873e-02,  -9.65909064e-01,
                          4.38311696e-01,   7.82873392e-01,  -7.65219152e-01,
                         -4.63879883e-01,   9.58400965e-01,   6.35146126e-02,
                         -9.85389590e-01,   3.47199678e-01,   8.40097427e-01,
                         -6.98051929e-01,  -5.49310088e-01,   9.26948071e-01,
                          1.62134737e-01,  -9.94926929e-01,   2.52637982e-01,
                          8.89204562e-01,  -6.23782456e-01,  -6.29261374e-01,
                          8.85957778e-01,   2.59131491e-01,  -9.94521081e-01,
                          1.55438319e-01,   9.29383099e-01,  -5.43425322e-01,
                         -7.02922106e-01,   8.36444795e-01,   3.53693187e-01,
                         -9.84172106e-01,   5.66152595e-02,   9.60227251e-01,
                         -4.57589298e-01,  -7.69683421e-01,   7.78409064e-01,
                          4.44602281e-01,  -9.64285731e-01,  -4.26136367e-02,
                          9.81737018e-01,  -3.67288947e-01,  -8.28733742e-01,
                          7.12865233e-01,   5.31047106e-01,  -9.34659064e-01,
                         -1.41436681e-01,   9.93303597e-01,  -2.73336053e-01,
                         -8.79667222e-01,   6.40016258e-01,   6.12215936e-01,
                         -8.95698071e-01,  -2.38839284e-01,   9.95129883e-01,
                         -1.76745132e-01,  -9.21672106e-01,   5.60876608e-01,
                          6.87297106e-01,  -8.48011374e-01,  -3.33806813e-01,
                          9.87012982e-01,  -7.83279240e-02,  -9.54748392e-01,
                          4.76258129e-01,   7.55681813e-01,  -7.91801929e-01,
                         -4.25527602e-01,   9.69155848e-01,   2.09009741e-02,
                         -9.78084445e-01,   3.86769474e-01,   8.16355526e-01,
                         -7.27678597e-01,  -5.12987018e-01,   9.41558421e-01,
                          1.19926944e-01,  -9.91883099e-01,   2.93628246e-01,
                          8.69115233e-01,  -6.56452894e-01,  -5.95576286e-01,
                          9.04626608e-01,   2.17735395e-01,  -9.95738626e-01,
                          1.97443187e-01,   9.13149357e-01,  -5.78733742e-01,
                         -6.72077894e-01,   8.58766258e-01,   3.13311696e-01,
                         -9.89853919e-01,   9.92288962e-02,   9.48051929e-01,
                         -4.95129883e-01,  -7.41883099e-01,   8.04180205e-01,
                          4.06047076e-01,  -9.74025965e-01,   0.00000000e+00,
                          9.73620117e-01,  -4.06655848e-01,  -8.04383099e-01,
                          7.41883099e-01,   4.94521111e-01,  -9.48457778e-01,
                         -9.90259722e-02,   9.89448071e-01,  -3.14123362e-01,
                         -8.58766258e-01,   6.72077894e-01,   5.78125000e-01,
                         -9.13555205e-01,  -1.97240263e-01,   9.95535731e-01,
                         -2.18547076e-01,  -9.04829562e-01,   5.95576286e-01,
                          6.55844152e-01,  -8.69521081e-01,  -2.93425322e-01,
                          9.91680205e-01,  -1.20738633e-01,  -9.41761374e-01,
                          5.13189912e-01,   7.27272749e-01,  -8.16964269e-01,
                         -3.86769474e-01,   9.78084445e-01,  -2.17126627e-02,
                         -9.69358742e-01,   4.25730526e-01,   7.91396081e-01,
                         -7.56290555e-01,  -4.76055205e-01,   9.54748392e-01,
                          7.75162354e-02,  -9.87418830e-01,   3.34009737e-01,
                          8.47605526e-01,  -6.88108742e-01,  -5.60876608e-01,
                          9.21672106e-01,   1.75933436e-01,  -9.95535731e-01,
                          2.39042208e-01,   8.95495117e-01,  -6.13027573e-01,
                         -6.40016258e-01,   8.79667222e-01,   2.72727281e-01,
                         -9.93709445e-01,   1.41639605e-01,   9.34456170e-01,
                         -5.31858742e-01,  -7.12865233e-01,   8.28936696e-01,
                          3.66680205e-01,  -9.82142866e-01,   4.28165570e-02,
                          9.64082778e-01,  -4.45413947e-01,  -7.78612018e-01,
                          7.69886374e-01,   4.56980526e-01,  -9.60836053e-01,
                         -5.64123392e-02,   9.84172106e-01,  -3.54504883e-01,
                         -8.36444795e-01,   7.03125000e-01,   5.42816579e-01,
                         -9.29991901e-01,  -1.55032471e-01,   9.94318187e-01,
                         -2.60146111e-01,  -8.86160731e-01,   6.29464269e-01,
                          6.23173714e-01,  -8.89813304e-01,  -2.52232134e-01,
                          9.94724035e-01,  -1.62946433e-01,  -9.27150965e-01,
                          5.49512982e-01,   6.97443187e-01,  -8.40909064e-01,
                         -3.46996754e-01,   9.85389590e-01,  -6.43263012e-02,
                         -9.58806813e-01,   4.64082778e-01,   7.64813304e-01,
                         -7.83482134e-01,  -4.38311696e-01,   9.66112018e-01,
                          3.49025987e-02,  -9.80925322e-01,   3.74188304e-01,
                          8.24472427e-01,  -7.18547106e-01,  -5.25162339e-01,
                          9.37297106e-01,   1.33725643e-01,  -9.93303597e-01,
                          2.80438304e-01,   8.76014590e-01,  -6.46306813e-01,
                         -6.06737018e-01,   8.99147749e-01,   2.31331170e-01,
                         -9.95941579e-01,   1.83847398e-01,   9.18831170e-01,
                         -5.67573071e-01,  -6.82426929e-01,   8.52069795e-01,
                          3.26704532e-01,  -9.88636374e-01,   8.54301974e-02,
                          9.52516258e-01,  -4.83157456e-01,  -7.51217544e-01,
                          7.96469152e-01,   4.18628246e-01,  -9.71387982e-01,
                         -1.37987016e-02,   9.76866901e-01,  -3.94074678e-01,
                         -8.12702894e-01,   7.32954562e-01,   5.06696403e-01,
                         -9.44602251e-01,  -1.12824678e-01,   9.91274357e-01,
                         -3.00933450e-01,  -8.66071403e-01,   6.62134767e-01,
                          5.89488626e-01,  -9.08279240e-01,  -2.10836038e-01,
                          9.95941579e-01,  -2.04951301e-01,  -9.10714269e-01,
                          5.84618509e-01,   6.66599035e-01,  -8.63027573e-01,
                         -3.06818187e-01,   9.90868509e-01,  -1.06939934e-01,
                         -9.46428597e-01,   5.01420438e-01,   7.37012982e-01,
                         -8.09253275e-01,  -3.99553567e-01,   9.75649357e-01,
                         -7.71103892e-03,  -9.72808421e-01,   4.13352281e-01,
                          8.00121725e-01,  -7.47362018e-01,  -4.88636374e-01,
                          9.50892866e-01,   9.15178582e-02,  -9.89448071e-01,
                          3.21022719e-01,   8.55316579e-01,  -6.78165555e-01,
                         -5.72646081e-01,   9.16801929e-01,   1.89935058e-01,
                         -9.96144474e-01,   2.25446433e-01,   9.01785731e-01,
                         -6.02069795e-01,  -6.50974035e-01,   8.73376608e-01,
                          2.86323041e-01,  -9.93100643e-01,   1.27840906e-01,
                          9.39529240e-01,  -5.20089269e-01,  -7.22808421e-01,
                          8.21428597e-01,   3.79870117e-01,  -9.80113626e-01,
                          2.88149342e-02,   9.67938304e-01,  -4.32832778e-01,
                         -7.87540555e-01,   7.61160731e-01,   4.69764620e-01,
                         -9.57386374e-01,  -7.04139620e-02,   9.86607134e-01,
                         -3.41314942e-01,  -8.44358742e-01,   6.93384767e-01,
                          5.54788947e-01,  -9.25121725e-01,  -1.69034094e-01,
                          9.95535731e-01,  -2.46550322e-01,  -8.92857134e-01,
                          6.18709445e-01,   6.34537339e-01,  -8.83725643e-01,
                         -2.66030848e-01,   9.94521081e-01,  -1.49147734e-01,
                         -9.32426929e-01,   5.37946403e-01,   7.07792222e-01,
                         -8.33400965e-01,  -3.60389620e-01,   9.83563304e-01,
                         -5.03246747e-02,  -9.62865233e-01,   4.51704532e-01,
                          7.74147749e-01,  -7.74959445e-01,  -4.51095790e-01,
                          9.62865233e-01,   4.91071418e-02,  -9.83563304e-01,
                          3.60998362e-01,   8.32792222e-01,  -7.08806813e-01,
                         -5.37337661e-01,   9.32629883e-01,   1.47930190e-01,
                         -9.94724035e-01,   2.66842544e-01,   8.83116901e-01,
                         -6.35551929e-01,  -6.18303597e-01,   8.93060088e-01,
                          2.45332792e-01,  -9.95738626e-01,   1.69845775e-01,
                          9.24715936e-01,  -5.55803597e-01,  -6.92978919e-01,
                          8.44764590e-01,   3.40300322e-01,  -9.87012982e-01,
                          7.12256506e-02,   9.56980526e-01,  -4.70779210e-01,
                         -7.60754883e-01,   7.87946403e-01,   4.31818187e-01,
                         -9.68344152e-01,  -2.80032475e-02,   9.79910731e-01,
                         -3.81087661e-01,  -8.21225643e-01,   7.23417222e-01,
                          5.19074678e-01,  -9.40137982e-01,  -1.27029225e-01,
                          9.92897749e-01,  -2.87337661e-01,  -8.73376608e-01,
                          6.51582778e-01,   6.01258099e-01,  -9.02597427e-01,
                         -2.24837661e-01,   9.96144474e-01,  -1.90949678e-01,
                         -9.16801929e-01,   5.73254883e-01,   6.77353919e-01,
                         -8.56128275e-01,  -3.20413947e-01,   9.89448071e-01,
                         -9.27353874e-02,  -9.51095760e-01,   4.89245117e-01,
                          7.46753275e-01,  -8.00933421e-01,  -4.12743509e-01,
                          9.73011374e-01,   6.69642864e-03,  -9.76055205e-01,
                          4.00365263e-01,   8.08644474e-01,  -7.38027573e-01,
                         -5.01014590e-01,   9.46834445e-01,   1.05722405e-01,
                         -9.91071403e-01,   3.07426959e-01,   8.62621725e-01,
                         -6.67613626e-01,  -5.84415555e-01,   9.11120117e-01,
                          2.03936681e-01,  -9.96550322e-01,   2.11647734e-01,
                          9.08076286e-01,  -5.90706170e-01,  -6.61728919e-01,
                          8.66477251e-01,   3.00121754e-01,  -9.91883099e-01,
                          1.13636367e-01,   9.44399357e-01,  -5.07711053e-01,
                         -7.32751608e-01,   8.13311696e-01,   3.93060058e-01,
                         -9.77475643e-01,   1.44074671e-02,   9.71185088e-01,
                         -4.19845790e-01,  -7.96266258e-01,   7.52029240e-01,
                          4.82345790e-01,  -9.53327894e-01,  -8.48214254e-02,
                          9.88636374e-01,  -3.27922076e-01,  -8.52069795e-01,
                          6.83035731e-01,   5.66761374e-01,  -9.19845760e-01,
                         -1.83238640e-01,   9.95941579e-01,  -2.32548699e-01,
                         -8.99147749e-01,   6.07548714e-01,   6.45495117e-01,
                         -8.77029240e-01,  -2.79829532e-01,   9.93506491e-01,
                         -1.34943187e-01,  -9.37500000e-01,   5.25771081e-01,
                          7.17938304e-01,  -8.25487018e-01,  -3.73579532e-01,
                          9.81128275e-01,  -3.59172076e-02,  -9.66314912e-01,
                          4.38920468e-01,   7.83076286e-01,  -7.65827894e-01,
                         -4.63676959e-01,   9.59212661e-01,   6.33116886e-02,
                         -9.85795438e-01,   3.47808450e-01,   8.40503275e-01,
                         -6.98660731e-01,  -5.49310088e-01,   9.27556813e-01,
                          1.62134737e-01,  -9.95332778e-01,   2.53043830e-01,
                          8.89610410e-01,  -6.24391258e-01,  -6.29261374e-01,
                          8.86769474e-01,   2.59131491e-01,  -9.94926929e-01,
                          1.55844152e-01,   9.29788947e-01,  -5.43831170e-01,
                         -7.03125000e-01,   8.37053597e-01,   3.53693187e-01,
                         -9.84780848e-01,   5.70211038e-02,   9.60836053e-01,
                         -4.58198041e-01,  -7.69886374e-01,   7.79017866e-01,
                          4.44602281e-01,  -9.64894474e-01,  -4.22077924e-02,
                          9.82345760e-01,  -3.67694795e-01,  -8.29139590e-01,
                          7.13474035e-01,   5.31250000e-01,  -9.35267866e-01,
                         -1.41233772e-01,   9.93912339e-01,  -2.73741871e-01,
                         -8.80073071e-01,   6.40625000e-01,   6.12418830e-01,
                         -8.96306813e-01,  -2.38636360e-01,   9.95738626e-01,
                         -1.76948056e-01,  -9.22077894e-01,   5.61485410e-01,
                          6.87702894e-01,  -8.48620117e-01,  -3.33806813e-01,
                          9.87621725e-01,  -7.85308406e-02,  -9.55154240e-01,
                          4.76866871e-01,   7.56087661e-01,  -7.92410731e-01,
                         -4.25730526e-01,   9.69764590e-01,   2.09009741e-02,
                         -9.78693187e-01,   3.87378246e-01,   8.16964269e-01,
                         -7.28287339e-01,  -5.13189912e-01,   9.42167222e-01,
                          1.19926944e-01,  -9.92491901e-01,   2.94034094e-01,
                          8.69724035e-01,  -6.57061696e-01,  -5.95779240e-01,
                          9.05438304e-01,   2.17735395e-01,  -9.96347427e-01,
                          1.97646111e-01,   9.13758099e-01,  -5.79139590e-01,
                         -6.72280848e-01,   8.59375000e-01,   3.13514620e-01,
                         -9.90462661e-01,   9.94318202e-02,   9.48660731e-01,
                         -4.95535702e-01,  -7.42288947e-01,   8.04991901e-01,
                          4.06250000e-01,  -9.74634767e-01,   2.02922078e-04,
                          9.74431813e-01,  -4.07061696e-01,  -8.04788947e-01,
                          7.42491901e-01,   4.94724035e-01,  -9.49269474e-01,
                         -9.90259722e-02,   9.90259767e-01,  -3.14326286e-01,
                         -8.59375000e-01,   6.72686696e-01,   5.78530848e-01,
                         -9.14366901e-01,  -1.97240263e-01,   9.96347427e-01,
                         -2.18750000e-01,  -9.05235410e-01,   5.96185088e-01,
                          6.56452894e-01,  -8.70332778e-01,  -2.93425322e-01,
                          9.92491901e-01,  -1.20738633e-01,  -9.42370117e-01,
                          5.13798714e-01,   7.27881491e-01,  -8.17573071e-01,
                         -3.86769474e-01,   9.78896081e-01,  -2.17126627e-02,
                         -9.69967544e-01,   4.26136374e-01,   7.92004883e-01,
                         -7.56899357e-01,  -4.76461053e-01,   9.55357134e-01,
                          7.75162354e-02,  -9.88027573e-01,   3.34415585e-01,
                          8.48214269e-01,  -6.88514590e-01,  -5.61282456e-01,
                          9.22483742e-01,   1.76136360e-01,  -9.96144474e-01,
                          2.39245132e-01,   8.96103919e-01,  -6.13433421e-01,
                         -6.40422106e-01,   8.80275965e-01,   2.72930205e-01,
                         -9.94318187e-01,   1.41639605e-01,   9.35064912e-01,
                         -5.32061696e-01,  -7.13271081e-01,   8.29545438e-01,
                          3.67086053e-01,  -9.82751608e-01,   4.28165570e-02,
                          9.64691579e-01,  -4.45413947e-01,  -7.79220760e-01,
                          7.70292222e-01,   4.57589298e-01,  -9.61444795e-01,
                         -5.66152595e-02,   9.84780848e-01,  -3.54504883e-01,
                         -8.37256491e-01,   7.03530848e-01,   5.43425322e-01,
                         -9.30397749e-01,  -1.55438319e-01,   9.95129883e-01,
                         -2.59943187e-01,  -8.86972427e-01,   6.29667222e-01,
                          6.23985410e-01,  -8.90219152e-01,  -2.52840906e-01,
                          9.95535731e-01,  -1.62743509e-01,  -9.27962661e-01,
                          5.49715936e-01,   6.98457778e-01,  -8.41314912e-01,
                         -3.47605526e-01,   9.85998392e-01,  -6.39204532e-02,
                         -9.59618509e-01,   4.64082778e-01,   7.65827894e-01,
                         -7.83887982e-01,  -4.38920468e-01,   9.66720760e-01,
                          3.53084430e-02,  -9.81737018e-01,   3.73985380e-01,
                          8.25487018e-01,  -7.18547106e-01,  -5.25974035e-01,
                          9.37905848e-01,   1.34334415e-01,  -9.94115233e-01,
                          2.80235380e-01,   8.77029240e-01,  -6.46306813e-01,
                         -6.07548714e-01,   8.99553597e-01,   2.32142851e-01,
                         -9.96550322e-01,   1.83441564e-01,   9.19845760e-01,
                         -5.67370117e-01,  -6.83238626e-01,   8.52272749e-01,
                          3.27516228e-01,  -9.89042222e-01,   8.50243494e-02,
                          9.53530848e-01,  -4.82954532e-01,  -7.52232134e-01,
                          7.96469152e-01,   4.19642866e-01,  -9.71793830e-01,
                         -1.44074671e-02,   9.77678597e-01,  -3.93668830e-01,
                         -8.13514590e-01,   7.32954562e-01,   5.07508099e-01,
                         -9.44805205e-01,  -1.13636367e-01,   9.92086053e-01,
                         -3.00527602e-01,  -8.66883099e-01,   6.61931813e-01,
                          5.90503275e-01,  -9.08482134e-01,  -2.11647734e-01,
                          9.96550322e-01,  -2.04342529e-01,  -9.11525965e-01,
                          5.84415555e-01,   6.67410731e-01,  -8.63027573e-01,
                         -3.07629883e-01,   9.91071403e-01,  -1.06128246e-01,
                         -9.47037339e-01,   5.01014590e-01,   7.37824678e-01,
                         -8.09050322e-01,  -4.00568187e-01,   9.75852251e-01,
                         -6.89935079e-03,  -9.73417222e-01,   4.12743509e-01,
                          8.00933421e-01,  -7.46956170e-01,  -4.89448041e-01,
                          9.51095760e-01,   9.25324708e-02,  -9.89853919e-01,
                          3.20211053e-01,   8.55925322e-01,  -6.77556813e-01,
                         -5.73457778e-01,   9.16599035e-01,   1.90746754e-01,
                         -9.96550322e-01,   2.24634737e-01,   9.02394474e-01,
                         -6.01461053e-01,  -6.51785731e-01,   8.73173714e-01,
                          2.87134737e-01,  -9.93303597e-01,   1.27029225e-01,
                          9.39935088e-01,  -5.19277573e-01,  -7.23620117e-01,
                          8.21022749e-01,   3.80681813e-01,  -9.80113626e-01,
                          2.80032475e-02,   9.68141258e-01,  -4.32021111e-01,
                         -7.88149357e-01,   7.60551929e-01,   4.70373362e-01,
                         -9.57183421e-01,  -7.14285746e-02,   9.86607134e-01,
                         -3.40503246e-01,  -8.44764590e-01,   6.92775965e-01,
                          5.55397749e-01,  -9.24715936e-01,  -1.69845775e-01,
                          9.95332778e-01,  -2.45738640e-01,  -8.93060088e-01,
                          6.18100643e-01,   6.34943187e-01,  -8.83116901e-01,
                         -2.66639620e-01,   9.94115233e-01,  -1.48336038e-01,
                         -9.32426929e-01,   5.37134767e-01,   7.08198071e-01,
                         -8.32792222e-01,  -3.60795468e-01,   9.83157456e-01,
                         -4.95129861e-02,  -9.62662339e-01,   4.51095790e-01,
                          7.74350643e-01,  -7.74350643e-01,  -4.51501638e-01,
                          9.62459445e-01,   4.97159101e-02,  -9.83360410e-01,
                          3.60389620e-01,   8.32792222e-01,  -7.08198071e-01,
                         -5.37540555e-01,   9.32224035e-01,   1.48336038e-01,
                         -9.94318187e-01,   2.66436696e-01,   8.82913947e-01,
                         -6.35146081e-01,  -6.18303597e-01,   8.92857134e-01,
                          2.45332792e-01,  -9.95535731e-01,   1.69845775e-01,
                          9.24512982e-01,  -5.56006491e-01,  -6.92775965e-01,
                          8.44764590e-01,   3.39894474e-01,  -9.87012982e-01,
                          7.16314912e-02,   9.56777573e-01,  -4.71387982e-01,
                         -7.60349035e-01,   7.88555205e-01,   4.31209415e-01,
                         -9.68750000e-01,  -2.75974032e-02,   9.79910731e-01,
                         -3.81493509e-01,  -8.21225643e-01,   7.23620117e-01,
                          5.19074678e-01,  -9.40543830e-01,  -1.27029225e-01,
                          9.93303597e-01,  -2.87540585e-01,  -8.73579562e-01,
                          6.51785731e-01,   6.01461053e-01,  -9.03003275e-01,
                         -2.25040585e-01,   9.96550322e-01,  -1.90949678e-01,
                         -9.17207778e-01,   5.73254883e-01,   6.77759767e-01,
                         -8.56331170e-01,  -3.20819795e-01,   9.89853919e-01,
                         -9.23295468e-02,  -9.51704562e-01,   4.89245117e-01,
                          7.47362018e-01,  -8.01136374e-01,  -4.13352281e-01,
                          9.73417222e-01,   6.89935079e-03,  -9.76663947e-01,
                          4.00162339e-01,   8.09253275e-01,  -7.38230526e-01,
                         -5.01623392e-01,   9.47240233e-01,   1.06128246e-01,
                         -9.91680205e-01,   3.07224035e-01,   8.63230526e-01,
                         -6.67816579e-01,  -5.84821403e-01,   9.11525965e-01,
                          2.04342529e-01,  -9.96956170e-01,   2.11444810e-01,
                          9.08482134e-01,  -5.90706170e-01,  -6.62337661e-01,
                          8.66680205e-01,   3.00527602e-01,  -9.92288947e-01,
                          1.13230519e-01,   9.44805205e-01,  -5.07711053e-01,
                         -7.33157456e-01,   8.13311696e-01,   3.93668830e-01,
                         -9.77881491e-01,   1.42045459e-02,   9.71793830e-01,
                         -4.19845790e-01,  -7.96875000e-01,   7.52029240e-01,
                          4.82751638e-01,  -9.53733742e-01,  -8.52272734e-02,
                          9.89042222e-01,  -3.27719152e-01,  -8.52475643e-01,
                          6.83238626e-01,   5.67167222e-01,  -9.20048714e-01,
                         -1.83644474e-01,   9.96347427e-01,  -2.32345775e-01,
                         -8.99756491e-01,   6.07548714e-01,   6.46103919e-01,
                         -8.77435088e-01,  -2.80235380e-01,   9.93912339e-01,
                         -1.34740263e-01,  -9.38108742e-01,   5.25771081e-01,
                          7.18344152e-01,  -8.25892866e-01,  -3.74188304e-01,
                          9.81737018e-01,  -3.57142873e-02,  -9.67126608e-01,
                          4.38920468e-01,   7.83685088e-01,  -7.66233742e-01,
                         -4.64285702e-01,   9.59618509e-01,   6.35146126e-02,
                         -9.86404240e-01,   3.47808450e-01,   8.41112018e-01,
                         -6.99066579e-01,  -5.49715936e-01,   9.28165555e-01,
                          1.62337661e-01,  -9.96144474e-01,   2.53043830e-01,
                          8.90219152e-01,  -6.24797106e-01,  -6.29870117e-01,
                          8.87175322e-01,   2.59334415e-01,  -9.95738626e-01,
                          1.55844152e-01,   9.30397749e-01,  -5.44439912e-01,
                         -7.03733742e-01,   8.37662339e-01,   3.53896111e-01,
                         -9.85592544e-01,   5.70211038e-02,   9.61444795e-01,
                         -4.58400965e-01,  -7.70495117e-01,   7.79626608e-01,
                          4.45008129e-01,  -9.65706170e-01,  -4.24107127e-02,
                          9.82954562e-01,  -3.68100643e-01,  -8.29748392e-01,
                          7.13879883e-01,   5.31655848e-01,  -9.36079562e-01,
                         -1.41436681e-01,   9.94724035e-01,  -2.73944795e-01,
                         -8.80681813e-01,   6.41030848e-01,   6.13027573e-01,
                         -8.97118509e-01,  -2.39042208e-01,   9.96550322e-01,
                         -1.77150980e-01,  -9.23092544e-01,   5.61891258e-01,
                          6.88311696e-01,  -8.49431813e-01,  -3.34212661e-01,
                          9.88433421e-01,  -7.85308406e-02,  -9.56168830e-01,
                          4.77069795e-01,   7.56696403e-01,  -7.93019474e-01,
                         -4.26136374e-01,   9.70576286e-01,   2.09009741e-02,
                         -9.79707778e-01,   3.87378246e-01,   8.17775965e-01,
                         -7.28896081e-01,  -5.14001608e-01,   9.43181813e-01,
                          1.20129868e-01,  -9.93506491e-01,   2.94034094e-01,
                          8.70535731e-01,  -6.57467544e-01,  -5.96590936e-01,
                          9.06250000e-01,   2.18141228e-01,  -9.97564912e-01,
                          1.97646111e-01,   9.14772749e-01,  -5.79545438e-01,
                         -6.73295438e-01,   8.60186696e-01,   3.14123362e-01,
                         -9.91477251e-01,   9.92288962e-02,   9.49878275e-01,
                         -4.95941550e-01,  -7.43303597e-01,   8.05600643e-01,
                          4.06858772e-01,  -9.75649357e-01,   0.00000000e+00,
                          9.75446403e-01,  -4.07264620e-01,  -8.05803597e-01,
                          7.43100643e-01,   4.95535702e-01,  -9.50081170e-01,
                         -9.94318202e-02,   9.91274357e-01,  -3.14529210e-01,
                         -8.60389590e-01,   6.73092544e-01,   5.79139590e-01,
                         -9.15178597e-01,  -1.97646111e-01,   9.97362018e-01,
                         -2.18750000e-01,  -9.06452894e-01,   5.96590936e-01,
                          6.57264590e-01,  -8.70941579e-01,  -2.94034094e-01,
                          9.93506491e-01,  -1.20738633e-01,  -9.43384767e-01,
                          5.14001608e-01,   7.28693187e-01,  -8.18181813e-01,
                         -3.87581170e-01,   9.79707778e-01,  -2.15097405e-02,
                         -9.70982134e-01,   4.26136374e-01,   7.92816579e-01,
                         -7.57305205e-01,  -4.77272719e-01,   9.55965936e-01,
                          7.79220760e-02,  -9.88839269e-01,   3.34212661e-01,
                          8.49228919e-01,  -6.88920438e-01,  -5.62094152e-01,
                          9.22889590e-01,   1.76745132e-01,  -9.96956170e-01,
                          2.39042208e-01,   8.96915555e-01,  -6.13433421e-01,
                         -6.41233742e-01,   8.80681813e-01,   2.73538947e-01,
                         -9.95129883e-01,   1.41436681e-01,   9.35876608e-01,
                         -5.32061696e-01,  -7.14082778e-01,   8.29748392e-01,
                          3.67694795e-01,  -9.83360410e-01,   4.24107127e-02,
                          9.65503275e-01,  -4.45413947e-01,  -7.79829562e-01,
                          7.70495117e-01,   4.58198041e-01,  -9.61850643e-01,
                         -5.70211038e-02,   9.85389590e-01,  -3.54301959e-01,
                         -8.37865233e-01,   7.03530848e-01,   5.44034064e-01,
                         -9.30803597e-01,  -1.56047076e-01,   9.95535731e-01,
                         -2.59740263e-01,  -8.87581170e-01,   6.29667222e-01,
                          6.24391258e-01,  -8.90422106e-01,  -2.53246754e-01,
                          9.95738626e-01,  -1.62540585e-01,  -9.28368509e-01,
                          5.49512982e-01,   6.98660731e-01,  -8.41314912e-01,
                         -3.48011374e-01,   9.86201286e-01,  -6.37175292e-02,
                         -9.59821403e-01,   4.63879883e-01,   7.66030848e-01,
                         -7.83887982e-01,  -4.39326286e-01,   9.66720760e-01,
                          3.55113633e-02,  -9.81939912e-01,   3.73782456e-01,
                          8.25689912e-01,  -7.18547106e-01,  -5.26176929e-01,
                          9.37702894e-01,   1.34537339e-01,  -9.94115233e-01,
                          2.79829532e-01,   8.77029240e-01,  -6.46103919e-01,
                         -6.07751608e-01,   8.99350643e-01,   2.32142851e-01,
                         -9.96550322e-01,   1.83238640e-01,   9.19845760e-01,
                         -5.67370117e-01,  -6.83441579e-01,   8.52069795e-01,
                          3.27516228e-01,  -9.89042222e-01,   8.48214254e-02,
                          9.53327894e-01,  -4.82954532e-01,  -7.52232134e-01,
                          7.96469152e-01,   4.19642866e-01,  -9.71793830e-01,
                         -1.44074671e-02,   9.77475643e-01,  -3.93668830e-01,
                         -8.13514590e-01,   7.32751608e-01,   5.07508099e-01,
                         -9.44805205e-01,  -1.13433443e-01,   9.91883099e-01,
                         -3.00527602e-01,  -8.66680205e-01,   6.61931813e-01,
                          5.90300322e-01,  -9.08482134e-01,  -2.11444810e-01,
                          9.96347427e-01,  -2.04545453e-01,  -9.11323071e-01,
                          5.84618509e-01,   6.67207778e-01,  -8.63230526e-01,
                         -3.07224035e-01,   9.91071403e-01,  -1.06534094e-01,
                         -9.47037339e-01,   5.01420438e-01,   7.37418830e-01,
                         -8.09253275e-01,  -4.00162339e-01,   9.76055205e-01,
                         -7.50811677e-03,  -9.73214269e-01,   4.13149357e-01,
                          8.00527573e-01,  -7.47362018e-01,  -4.88839298e-01,
                          9.51095760e-01,   9.17207822e-02,  -9.89650965e-01,
                          3.20819795e-01,   8.55519474e-01,  -6.78165555e-01,
                         -5.72849035e-01,   9.16801929e-01,   1.89935058e-01,
                         -9.96347427e-01,   2.25446433e-01,   9.01988626e-01,
                         -6.02069795e-01,  -6.51176929e-01,   8.73579562e-01,
                          2.86323041e-01,  -9.93303597e-01,   1.27840906e-01,
                          9.39732134e-01,  -5.20089269e-01,  -7.23011374e-01,
                          8.21428597e-01,   3.79870117e-01,  -9.80316579e-01,
                          2.88149342e-02,   9.67938304e-01,  -4.33035702e-01,
                         -7.87540555e-01,   7.61363626e-01,   4.69764620e-01,
                         -9.57589269e-01,  -7.04139620e-02,   9.86607134e-01,
                         -3.41517866e-01,  -8.44561696e-01,   6.93587661e-01,
                          5.54788947e-01,  -9.25324678e-01,  -1.69034094e-01,
                          9.95535731e-01,  -2.46753246e-01,  -8.93060088e-01,
                          6.18912339e-01,   6.34537339e-01,  -8.83928597e-01,
                         -2.66030848e-01,   9.94724035e-01,  -1.49350643e-01,
                         -9.32629883e-01,   5.38149357e-01,   7.07792222e-01,
                         -8.33806813e-01,  -3.60186696e-01,   9.83766258e-01,
                         -5.05275987e-02,  -9.63068187e-01,   4.52110380e-01,
                          7.74147749e-01,  -7.75365233e-01,  -4.50892866e-01,
                          9.63271081e-01,   4.89042215e-02,  -9.83766258e-01,
                          3.61404210e-01,   8.32792222e-01,  -7.09212661e-01,
                         -5.37134767e-01,   9.33035731e-01,   1.47727266e-01,
                         -9.94926929e-01,   2.67045468e-01,   8.83116901e-01,
                         -6.35957778e-01,  -6.18100643e-01,   8.93465936e-01,
                          2.45129868e-01,  -9.96144474e-01,   1.70251623e-01,
                          9.24715936e-01,  -5.56412339e-01,  -6.92978919e-01,
                          8.45170438e-01,   3.40097398e-01,  -9.87418830e-01,
                          7.16314912e-02,   9.57183421e-01,  -4.71185058e-01,
                         -7.60957778e-01,   7.88555205e-01,   4.31615263e-01,
                         -9.68952894e-01,  -2.78003253e-02,   9.80113626e-01,
                         -3.81493509e-01,  -8.21428597e-01,   7.23823071e-01,
                          5.19074678e-01,  -9.40746725e-01,  -1.26826301e-01,
                          9.93303597e-01,  -2.87946433e-01,  -8.73579562e-01,
                          6.51988626e-01,   6.01258099e-01,  -9.03206170e-01,
                         -2.24837661e-01,   9.96753275e-01,  -1.91355526e-01,
                         -9.17207778e-01,   5.73660731e-01,   6.77556813e-01,
                         -8.56737018e-01,  -3.20413947e-01,   9.90056813e-01,
                         -9.29383114e-02,  -9.51704562e-01,   4.89650965e-01,
                          7.46956170e-01,  -8.01745117e-01,  -4.12946433e-01,
                          9.73620117e-01,   6.49350649e-03,  -9.76663947e-01,
                          4.00771111e-01,   8.09050322e-01,  -7.38636374e-01,
                         -5.01217544e-01,   9.47443187e-01,   1.05722405e-01,
                         -9.91883099e-01,   3.07832778e-01,   8.63230526e-01,
                         -6.68222427e-01,  -5.84618509e-01,   9.11931813e-01,
                          2.03936681e-01,  -9.97159064e-01,   2.11850643e-01,
                          9.08685088e-01,  -5.91112018e-01,  -6.62337661e-01,
                          8.67288947e-01,   3.00121754e-01,  -9.92694795e-01,
                          1.13636367e-01,   9.45008099e-01,  -5.08319795e-01,
                         -7.33157456e-01,   8.13920438e-01,   3.93465906e-01,
                         -9.78287339e-01,   1.44074671e-02,   9.71996725e-01,
                         -4.20251638e-01,  -7.96875000e-01,   7.52435088e-01,
                          4.82751638e-01,  -9.54139590e-01,  -8.50243494e-02,
                          9.89245117e-01,  -3.28125000e-01,  -8.52678597e-01,
                          6.83441579e-01,   5.67167222e-01,  -9.20454562e-01,
                         -1.83441564e-01,   9.96753275e-01,  -2.32548699e-01,
                         -8.99959445e-01,   6.07751608e-01,   6.46103919e-01,
                         -8.77637982e-01,  -2.80235380e-01,   9.94318187e-01,
                         -1.34740263e-01,  -9.38311696e-01,   5.25974035e-01,
                          7.18547106e-01,  -8.25892866e-01,  -3.74188304e-01,
                          9.81939912e-01,  -3.57142873e-02,  -9.67126608e-01,
                          4.38920468e-01,   7.83887982e-01,  -7.66233742e-01,
                         -4.64488626e-01,   9.59618509e-01,   6.37175292e-02,
                         -9.86607134e-01,   3.47605526e-01,   8.41314912e-01,
                         -6.98660731e-01,  -5.49918830e-01,   9.27962661e-01,
                          1.62540585e-01,  -9.95941579e-01,   2.52637982e-01,
                          8.90422106e-01,  -6.24391258e-01,  -6.30073071e-01,
                          8.86972427e-01,   2.59740263e-01,  -9.95535731e-01,
                          1.55438319e-01,   9.30600643e-01,  -5.43831170e-01,
                         -7.03936696e-01,   8.37256491e-01,   3.54301959e-01,
                         -9.85186696e-01,   5.64123392e-02,   9.61444795e-01,
                         -4.57792222e-01,  -7.70698071e-01,   7.79017866e-01,
                          4.45413947e-01,  -9.65097427e-01,  -4.30194810e-02,
                          9.82751608e-01,  -3.67288947e-01,  -8.29748392e-01,
                          7.13271081e-01,   5.31858742e-01,  -9.35470760e-01,
                         -1.41842529e-01,   9.94318187e-01,  -2.73133129e-01,
                         -8.80681813e-01,   6.40422106e-01,   6.13230526e-01,
                         -8.96306813e-01,  -2.39448056e-01,   9.96144474e-01,
                         -1.76339284e-01,  -9.22686696e-01,   5.61079562e-01,
                          6.88311696e-01,  -8.48417222e-01,  -3.34618509e-01,
                          9.87824678e-01,  -7.77191594e-02,  -9.55560088e-01,
                          4.76258129e-01,   7.56696403e-01,  -7.92207778e-01,
                         -4.26339298e-01,   9.69764590e-01,   2.15097405e-02,
                         -9.78896081e-01,   3.86769474e-01,   8.17370117e-01,
                         -7.27881491e-01,  -5.13798714e-01,   9.42167222e-01,
                          1.20535716e-01,  -9.92694795e-01,   2.93425322e-01,
                          8.69926929e-01,  -6.56655848e-01,  -5.96387982e-01,
                          9.05032456e-01,   2.18344152e-01,  -9.96550322e-01,
                          1.97037339e-01,   9.13961053e-01,  -5.78733742e-01,
                         -6.72889590e-01,   8.59172106e-01,   3.14123362e-01,
                         -9.90462661e-01,   9.88230556e-02,   9.48863626e-01,
                         -4.94926959e-01,  -7.42491901e-01,   8.04586053e-01,
                          4.06655848e-01,  -9.74431813e-01,  -2.02922078e-04,
                          9.74431813e-01,  -4.06452924e-01,  -8.04991901e-01,
                          7.42086053e-01,   4.95129883e-01,  -9.48863626e-01,
                         -9.94318202e-02,   9.90056813e-01,  -3.13920468e-01,
                         -8.59375000e-01,   6.72280848e-01,   5.78733742e-01,
                         -9.13961053e-01,  -1.97646111e-01,   9.96144474e-01,
                         -2.18141228e-01,  -9.05235410e-01,   5.95779240e-01,
                          6.56452894e-01,  -8.69926929e-01,  -2.93831170e-01,
                          9.92288947e-01,  -1.20332792e-01,  -9.42167222e-01,
                          5.13189912e-01,   7.27881491e-01,  -8.17167222e-01,
                         -3.87175322e-01,   9.78490233e-01,  -2.13068184e-02,
                         -9.69764590e-01,   4.25730526e-01,   7.91801929e-01,
                         -7.56290555e-01,  -4.76461053e-01,   9.54951286e-01,
                          7.79220760e-02,  -9.87621725e-01,   3.34009737e-01,
                          8.48011374e-01,  -6.88108742e-01,  -5.61282456e-01,
                          9.22077894e-01,   1.76339284e-01,  -9.95738626e-01,
                          2.39042208e-01,   8.95900965e-01,  -6.13027573e-01,
                         -6.40422106e-01,   8.79870117e-01,   2.72930205e-01,
                         -9.94115233e-01,   1.41436681e-01,   9.34862018e-01,
                         -5.31858742e-01,  -7.13068187e-01,   8.29139590e-01,
                          3.67086053e-01,  -9.82548714e-01,   4.26136367e-02,
                          9.64488626e-01,  -4.45211053e-01,  -7.78814912e-01,
                          7.70089269e-01,   4.57386374e-01,  -9.61038947e-01,
                         -5.66152595e-02,   9.84577894e-01,  -3.54504883e-01,
                         -8.36850643e-01,   7.03327894e-01,   5.43222427e-01,
                         -9.30194795e-01,  -1.55235395e-01,   9.94926929e-01,
                         -2.59943187e-01,  -8.86566579e-01,   6.29667222e-01,
                          6.23782456e-01,  -8.90016258e-01,  -2.52435058e-01,
                          9.95332778e-01,  -1.62946433e-01,  -9.27556813e-01,
                          5.49715936e-01,   6.98051929e-01,  -8.41112018e-01,
                         -3.47199678e-01,   9.85795438e-01,  -6.43263012e-02,
                         -9.59212661e-01,   4.64285702e-01,   7.65422106e-01,
                         -7.83887982e-01,  -4.38514620e-01,   9.66517866e-01,
                          3.51055190e-02,  -9.81534064e-01,   3.74188304e-01,
                          8.25081170e-01,  -7.18750000e-01,  -5.25568187e-01,
                          9.37702894e-01,   1.34131491e-01,  -9.93912339e-01,
                          2.80438304e-01,   8.76623392e-01,  -6.46306813e-01,
                         -6.07345760e-01,   8.99553597e-01,   2.31737018e-01,
                         -9.96550322e-01,   1.83847398e-01,   9.19642866e-01,
                         -5.67573071e-01,  -6.83035731e-01,   8.52475643e-01,
                          3.27110380e-01,  -9.89042222e-01,   8.52272734e-02,
                          9.53327894e-01,  -4.83360380e-01,  -7.52029240e-01,
                          7.96875000e-01,   4.19237018e-01,  -9.71996725e-01,
                         -1.40016237e-02,   9.77678597e-01,  -3.94074678e-01,
                         -8.13514590e-01,   7.33157456e-01,   5.07305205e-01,
                         -9.45211053e-01,  -1.13230519e-01,   9.92086053e-01,
                         -3.00933450e-01,  -8.66883099e-01,   6.62337661e-01,
                          5.90300322e-01,  -9.08887982e-01,  -2.11241886e-01,
                          9.96753275e-01,  -2.04748377e-01,  -9.11728919e-01,
                          5.84821403e-01,   6.67410731e-01,  -8.63636374e-01,
                         -3.07426959e-01,   9.91680205e-01,  -1.06534094e-01,
                         -9.47443187e-01,   5.01623392e-01,   7.37824678e-01,
                         -8.09659064e-01,  -4.00365263e-01,   9.76461053e-01,
                         -7.30519462e-03,  -9.73620117e-01,   4.13352281e-01,
                          8.01136374e-01,  -7.47767866e-01,  -4.89245117e-01,
                          9.51704562e-01,   9.21266228e-02,  -9.90259767e-01,
                          3.20819795e-01,   8.56331170e-01,  -6.78165555e-01,
                         -5.73457778e-01,   9.17410731e-01,   1.90543830e-01,
                         -9.96956170e-01,   2.25243509e-01,   9.03003275e-01,
                         -6.02069795e-01,  -6.51988626e-01,   8.73782456e-01,
                          2.87134737e-01,  -9.93912339e-01,   1.27232149e-01,
                          9.40543830e-01,  -5.19886374e-01,  -7.23823071e-01,
                          8.21631491e-01,   3.80884737e-01,  -9.80722427e-01,
                          2.80032475e-02,   9.68952894e-01,  -4.32629883e-01,
                         -7.88555205e-01,   7.61363626e-01,   4.70779210e-01,
                         -9.57995117e-01,  -7.14285746e-02,   9.87621725e-01,
                         -3.40909094e-01,  -8.45576286e-01,   6.93384767e-01,
                          5.56006491e-01,  -9.25730526e-01,  -1.70048699e-01,
                          9.96347427e-01,  -2.45738640e-01,  -8.94074678e-01,
                          6.18709445e-01,   6.35754883e-01,  -8.84131491e-01,
                         -2.67045468e-01,   9.95332778e-01,  -1.48336038e-01,
                         -9.33644474e-01,   5.37540555e-01,   7.09009767e-01,
                         -8.33603919e-01,  -3.61404210e-01,   9.84172106e-01,
                         -4.93100658e-02,  -9.63879883e-01,   4.51298714e-01,
                          7.75365233e-01,  -7.74959445e-01,  -4.52313304e-01,
                          9.63474035e-01,   5.01217544e-02,  -9.84577894e-01,
                          3.60389620e-01,   8.34009767e-01,  -7.08603919e-01,
                         -5.38555205e-01,   9.33035731e-01,   1.48944810e-01,
                         -9.95332778e-01,   2.66030848e-01,   8.84131491e-01,
                         -6.35146081e-01,  -6.19318187e-01,   8.93262982e-01,
                          2.46550322e-01,  -9.96347427e-01,   1.69034094e-01,
                          9.25527573e-01,  -5.55397749e-01,  -6.94196403e-01,
                          8.44764590e-01,   3.41517866e-01,  -9.87418830e-01,
                          7.02110380e-02,   9.57792222e-01,  -4.70170468e-01,
                         -7.61972427e-01,   7.87743509e-01,   4.33035702e-01,
                         -9.68750000e-01,  -2.92207785e-02,   9.80519474e-01,
                         -3.80275965e-01,  -8.22240233e-01,   7.23011374e-01,
                          5.20292222e-01,  -9.40340936e-01,  -1.28246754e-01,
                          9.93506491e-01,  -2.86525965e-01,  -8.74188304e-01,
                          6.50974035e-01,   6.02475643e-01,  -9.02597427e-01,
                         -2.26055190e-01,   9.96753275e-01,  -1.89935058e-01,
                         -9.17613626e-01,   5.72646081e-01,   6.78368509e-01,
                         -8.55925322e-01,  -3.21631491e-01,   9.89853919e-01,
                         -9.17207822e-02,  -9.51907456e-01,   4.88636374e-01,
                          7.47767866e-01,  -8.00730526e-01,  -4.13961053e-01,
                          9.73214269e-01,   7.71103892e-03,  -9.76663947e-01,
                          3.99553567e-01,   8.09659064e-01,  -7.37621725e-01,
                         -5.02029240e-01,   9.46834445e-01,   1.06737010e-01,
                         -9.91680205e-01,   3.06818187e-01,   8.63433421e-01,
                         -6.67207778e-01,  -5.85227251e-01,   9.11120117e-01,
                          2.04951301e-01,  -9.96956170e-01,   2.10836038e-01,
                          9.08685088e-01,  -5.90097427e-01,  -6.62743509e-01,
                          8.66477251e-01,   3.00933450e-01,  -9.92288947e-01,
                          1.12824678e-01,   9.45008099e-01,  -5.07305205e-01,
                         -7.33563304e-01,   8.13108742e-01,   3.94074678e-01,
                         -9.77678597e-01,   1.35957794e-02,   9.71793830e-01,
                         -4.19237018e-01,  -7.97077894e-01,   7.51623392e-01,
                          4.83360380e-01,  -9.53530848e-01,  -8.56331140e-02,
                          9.89042222e-01,  -3.27110380e-01,  -8.52678597e-01,
                          6.82832778e-01,   5.67775965e-01,  -9.19845760e-01,
                         -1.84253246e-01,   9.96347427e-01,  -2.31737018e-01,
                         -8.99959445e-01,   6.07142866e-01,   6.46509767e-01,
                         -8.77029240e-01,  -2.80844152e-01,   9.93912339e-01,
                         -1.34131491e-01,  -9.38311696e-01,   5.25365233e-01,
                          7.18750000e-01,  -8.25487018e-01,  -3.74594152e-01,
                          9.81534064e-01,  -3.51055190e-02,  -9.67329562e-01,
                          4.38514620e-01,   7.84090936e-01,  -7.65827894e-01,
                         -4.64894474e-01,   9.59618509e-01,   6.43263012e-02,
                         -9.86607134e-01,   3.47199678e-01,   8.41517866e-01,
                         -6.98457778e-01,  -5.50324678e-01,   9.27759767e-01,
                          1.62946433e-01,  -9.96144474e-01,   2.52232134e-01,
                          8.90625000e-01,  -6.24188304e-01,  -6.30478919e-01,
                          8.86972427e-01,   2.60146111e-01,  -9.95738626e-01,
                          1.55032471e-01,   9.30803597e-01,  -5.43628275e-01,
                         -7.04342544e-01,   8.37053597e-01,   3.54707778e-01,
                         -9.85389590e-01,   5.60064949e-02,   9.61647749e-01,
                         -4.57386374e-01,  -7.71103919e-01,   7.78814912e-01,
                          4.45819795e-01,  -9.65097427e-01,  -4.36282456e-02,
                          9.82954562e-01,  -3.66680205e-01,  -8.30154240e-01,
                          7.12662339e-01,   5.32670438e-01,  -9.35064912e-01,
                         -1.42857149e-01,   9.94521081e-01,  -2.72118509e-01,
                         -8.81087661e-01,   6.39204562e-01,   6.14245117e-01,
                         -8.95900965e-01,  -2.40462661e-01,   9.95941579e-01,
                         -1.75527602e-01,  -9.22889590e-01,   5.60470760e-01,
                          6.88717544e-01,  -8.48011374e-01,  -3.35024357e-01,
                          9.87621725e-01,  -7.73133114e-02,  -9.55560088e-01,
                          4.75852281e-01,   7.56696403e-01,  -7.92004883e-01,
                         -4.26542222e-01,   9.69561696e-01,   2.17126627e-02,
                         -9.78896081e-01,   3.86566550e-01,   8.17370117e-01,
                         -7.27881491e-01,  -5.13798714e-01,   9.41964269e-01,
                          1.20535716e-01,  -9.92491901e-01,   2.93425322e-01,
                          8.69926929e-01,  -6.56655848e-01,  -5.96185088e-01,
                          9.05032456e-01,   2.18344152e-01,  -9.96347427e-01,
                          1.97240263e-01,   9.13961053e-01,  -5.78733742e-01,
                         -6.72686696e-01,   8.59172106e-01,   3.13920468e-01,
                         -9.90462661e-01,   9.90259722e-02,   9.48863626e-01,
                         -4.95129883e-01,  -7.42694795e-01,   8.04788947e-01,
                          4.06655848e-01,  -9.74837661e-01,  -2.02922078e-04,
                          9.74634767e-01,  -4.06655848e-01,  -8.05194795e-01,
                          7.42491901e-01,   4.95129883e-01,  -9.49269474e-01,
                         -9.94318202e-02,   9.90462661e-01,  -3.14123362e-01,
                         -8.59780848e-01,   6.72686696e-01,   5.78936696e-01,
                         -9.14366901e-01,  -1.97646111e-01,   9.96753275e-01,
                         -2.18547076e-01,  -9.05844152e-01,   5.96185088e-01,
                          6.56858742e-01,  -8.70535731e-01,  -2.94034094e-01,
                          9.92897749e-01,  -1.20535716e-01,  -9.42978919e-01,
                          5.13798714e-01,   7.28287339e-01,  -8.17775965e-01,
                         -3.87378246e-01,   9.79301929e-01,  -2.15097405e-02,
                         -9.70576286e-01,   4.26136374e-01,   7.92410731e-01,
                         -7.57102251e-01,  -4.76866871e-01,   9.55762982e-01,
                          7.79220760e-02,  -9.88636374e-01,   3.34212661e-01,
                          8.48823071e-01,  -6.88717544e-01,  -5.61891258e-01,
                          9.22889590e-01,   1.76542208e-01,  -9.96753275e-01,
                          2.39042208e-01,   8.96712661e-01,  -6.13433421e-01,
                         -6.41030848e-01,   8.80681813e-01,   2.73336053e-01,
                         -9.95129883e-01,   1.41436681e-01,   9.35673714e-01,
                         -5.32061696e-01,  -7.14082778e-01,   8.29748392e-01,
                          3.67694795e-01,  -9.83360410e-01,   4.24107127e-02,
                          9.65503275e-01,  -4.45413947e-01,  -7.79829562e-01,
                          7.70495117e-01,   4.58198041e-01,  -9.62053597e-01,
                         -5.70211038e-02,   9.85592544e-01,  -3.54301959e-01,
                         -8.38068187e-01,   7.03733742e-01,   5.44034064e-01,
                         -9.31006491e-01,  -1.56047076e-01,   9.95941579e-01,
                         -2.59740263e-01,  -8.87784064e-01,   6.29870117e-01,
                          6.24797106e-01,  -8.90827894e-01,  -2.53449678e-01,
                          9.96144474e-01,  -1.62540585e-01,  -9.28774357e-01,
                          5.49715936e-01,   6.99066579e-01,  -8.41720760e-01,
                         -3.48214298e-01,   9.86607134e-01,  -6.37175292e-02,
                         -9.60430205e-01,   4.64082778e-01,   7.66436696e-01,
                         -7.84293830e-01,  -4.39529210e-01,   9.67329562e-01,
                          3.57142873e-02,  -9.82548714e-01,   3.73985380e-01,
                          8.26095760e-01,  -7.18952894e-01,  -5.26582778e-01,
                          9.38311696e-01,   1.34740263e-01,  -9.94926929e-01,
                          2.80032456e-01,   8.77637982e-01,  -6.46509767e-01,
                         -6.08360410e-01,   8.99959445e-01,   2.32548699e-01,
                         -9.97159064e-01,   1.83238640e-01,   9.20454562e-01,
                         -5.67573071e-01,  -6.84050322e-01,   8.52678597e-01,
                          3.27922076e-01,  -9.89853919e-01,   8.46185088e-02,
                          9.54139590e-01,  -4.83157456e-01,  -7.52840936e-01,
                          7.96875000e-01,   4.20048714e-01,  -9.72402573e-01,
                         -1.46103892e-02,   9.78287339e-01,  -3.93668830e-01,
                         -8.14326286e-01,   7.33157456e-01,   5.08116901e-01,
                         -9.45413947e-01,  -1.14042208e-01,   9.92694795e-01,
                         -3.00527602e-01,  -8.67491901e-01,   6.62134767e-01,
                          5.91112018e-01,  -9.08887982e-01,  -2.12053567e-01,
                          9.97159064e-01,  -2.04139605e-01,  -9.12337661e-01,
                          5.84415555e-01,   6.68019474e-01,  -8.63636374e-01,
                         -3.08238626e-01,   9.91680205e-01,  -1.05925322e-01,
                         -9.47849035e-01,   5.01014590e-01,   7.38433421e-01,
                         -8.09456170e-01,  -4.01176959e-01,   9.76461053e-01,
                         -6.69642864e-03,  -9.74025965e-01,   4.12743509e-01,
                          8.01542222e-01,  -7.47564912e-01,  -4.90056813e-01,
                          9.51704562e-01,   9.27353874e-02,  -9.90665555e-01,
                          3.20211053e-01,   8.56737018e-01,  -6.77962661e-01,
                         -5.74066579e-01,   9.17207778e-01,   1.91152602e-01,
                         -9.97159064e-01,   2.24634737e-01,   9.03206170e-01,
                         -6.01866901e-01,  -6.52394474e-01,   8.73579562e-01,
                          2.87540585e-01,  -9.93912339e-01,   1.26826301e-01,
                          9.40746725e-01,  -5.19683421e-01,  -7.24228919e-01,
                          8.21428597e-01,   3.81290585e-01,  -9.80722427e-01,
                          2.75974032e-02,   9.68952894e-01,  -4.32224035e-01,
                         -7.88961053e-01,   7.61160731e-01,   4.70982134e-01,
                         -9.57995117e-01,  -7.16314912e-02,   9.87418830e-01,
                         -3.40503246e-01,  -8.45779240e-01,   6.93181813e-01,
                          5.56209445e-01,  -9.25527573e-01,  -1.70454547e-01,
                          9.96144474e-01,  -2.45535716e-01,  -8.94074678e-01,
                          6.18303597e-01,   6.35754883e-01,  -8.83725643e-01,
                         -2.67451286e-01,   9.95129883e-01,  -1.48133114e-01,
                         -9.33644474e-01,   5.37337661e-01,   7.09009767e-01,
                         -8.33400965e-01,  -3.61607134e-01,   9.83969152e-01,
                         -4.91071418e-02,  -9.63879883e-01,   4.50892866e-01,
                          7.75365233e-01,  -7.74756491e-01,  -4.52516228e-01,
                          9.63068187e-01,   5.03246747e-02,  -9.84375000e-01,
                          3.60186696e-01,   8.33806813e-01,  -7.08400965e-01,
                         -5.38555205e-01,   9.32629883e-01,   1.49147734e-01,
                         -9.95332778e-01,   2.65827924e-01,   8.84131491e-01,
                         -6.34943187e-01,  -6.19521081e-01,   8.93060088e-01,
                          2.46550322e-01,  -9.96144474e-01,   1.68628246e-01,
                          9.25527573e-01,  -5.55194795e-01,  -6.94196403e-01,
                          8.44358742e-01,   3.41517866e-01,  -9.87215936e-01,
                          7.00081140e-02,   9.57589269e-01,  -4.69967544e-01,
                         -7.61972427e-01,   7.87540555e-01,   4.33035702e-01,
                         -9.68547106e-01,  -2.94237006e-02,   9.80316579e-01,
                         -3.80073041e-01,  -8.22037339e-01,   7.22605526e-01,
                          5.20292222e-01,  -9.39935088e-01,  -1.28449678e-01,
                          9.93303597e-01,  -2.86323041e-01,  -8.74188304e-01,
                          6.50568187e-01,   6.02272749e-01,  -9.02191579e-01,
                         -2.26258114e-01,   9.96347427e-01,  -1.89732149e-01,
                         -9.17410731e-01,   5.72240233e-01,   6.78368509e-01,
                         -8.55519474e-01,  -3.21834415e-01,   9.89448071e-01,
                         -9.13149342e-02,  -9.51704562e-01,   4.88027602e-01,
                          7.47767866e-01,  -8.00324678e-01,  -4.14163947e-01,
                          9.72605526e-01,   8.11688323e-03,  -9.76258099e-01,
                          3.98944795e-01,   8.09659064e-01,  -7.37012982e-01,
                         -5.02435088e-01,   9.46225643e-01,   1.07345782e-01,
                         -9.91274357e-01,   3.06006491e-01,   8.63433421e-01,
                         -6.66599035e-01,  -5.85633099e-01,   9.10511374e-01,
                          2.05357149e-01,  -9.96550322e-01,   2.10024357e-01,
                          9.08685088e-01,  -5.89285731e-01,  -6.62946403e-01,
                          8.65665555e-01,   3.01542222e-01,  -9.91680205e-01,
                          1.11810066e-01,   9.44805205e-01,  -5.06290555e-01,
                         -7.33766258e-01,   8.12297106e-01,   3.94683450e-01,
                         -9.77069795e-01,   1.27840908e-02,   9.71590936e-01,
                         -4.18425322e-01,  -7.97280848e-01,   7.50608742e-01,
                          4.83766228e-01,  -9.52719152e-01,  -8.66477266e-02,
                          9.88636374e-01,  -3.26095790e-01,  -8.52881491e-01,
                          6.81615233e-01,   5.68181813e-01,  -9.19034064e-01,
                         -1.85064942e-01,   9.95941579e-01,  -2.30722398e-01,
                         -8.99959445e-01,   6.05925322e-01,   6.46915555e-01,
                         -8.76014590e-01,  -2.81655848e-01,   9.93100643e-01,
                         -1.33116886e-01,  -9.37905848e-01,   5.24147749e-01,
                          7.18952894e-01,  -8.24269474e-01,  -3.75405848e-01,
                          9.80722427e-01,  -3.40909101e-02,  -9.66720760e-01,
                          4.37094152e-01,   7.84090936e-01,  -7.64407456e-01,
                         -4.65503246e-01,   9.58400965e-01,   6.53409064e-02,
                         -9.85795438e-01,   3.45576286e-01,   8.41314912e-01,
                         -6.97037339e-01,  -5.50933421e-01,   9.26542222e-01,
                          1.63961038e-01,  -9.95129883e-01,   2.50811696e-01,
                          8.90219152e-01,  -6.22564912e-01,  -6.30681813e-01,
                          8.85349035e-01,   2.61160702e-01,  -9.94521081e-01,
                          1.53612018e-01,   9.30194795e-01,  -5.42004883e-01,
                         -7.04342544e-01,   8.35430205e-01,   3.55519474e-01,
                         -9.84172106e-01,   5.47889620e-02,   9.61038947e-01,
                         -4.55965906e-01,  -7.71103919e-01,   7.77394474e-01,
                          4.46428567e-01,  -9.63879883e-01,  -4.46428582e-02,
                          9.82142866e-01,  -3.65462661e-01,  -8.29951286e-01,
                          7.11444795e-01,   5.32873392e-01,  -9.34050322e-01,
                         -1.43465906e-01,   9.93506491e-01,  -2.71306813e-01,
                         -8.80681813e-01,   6.38392866e-01,   6.14042222e-01,
                         -8.94886374e-01,  -2.40868509e-01,   9.95129883e-01,
                         -1.74512982e-01,  -9.22483742e-01,   5.59050322e-01,
                          6.88920438e-01,  -8.46793830e-01,  -3.36038947e-01,
                          9.86607134e-01,  -7.58928582e-02,  -9.55154240e-01,
                          4.74228889e-01,   7.57102251e-01,  -7.90381491e-01,
                         -4.27556813e-01,   9.68344152e-01,   2.33360399e-02,
                         -9.78287339e-01,   3.84537339e-01,   8.17573071e-01,
                         -7.26055205e-01,  -5.15016258e-01,   9.40543830e-01,
                          1.22362010e-01,  -9.91883099e-01,   2.91193187e-01,
                          8.70129883e-01,  -6.54423714e-01,  -5.97199678e-01,
                          9.03409064e-01,   2.20170453e-01,  -9.95535731e-01,
                          1.95008114e-01,   9.13758099e-01,  -5.76501608e-01,
                         -6.73498392e-01,   8.57142866e-01,   3.15746754e-01,
                         -9.89042222e-01,   9.67938304e-02,   9.48457778e-01,
                         -4.92694795e-01,  -7.43100643e-01,   8.02556813e-01,
                          4.08076286e-01,  -9.73011374e-01,  -2.43506487e-03,
                          9.73823071e-01,  -4.04017866e-01,  -8.05397749e-01,
                          7.39853919e-01,   4.96550322e-01,  -9.47240233e-01,
                         -1.01461038e-01,   9.89245117e-01,  -3.11485380e-01,
                         -8.59577894e-01,   6.69845760e-01,   5.79951286e-01,
                         -9.11931813e-01,  -1.99675322e-01,   9.94926929e-01,
                         -2.15706170e-01,  -9.05235410e-01,   5.93141258e-01,
                          6.57467544e-01,  -8.67694795e-01,  -2.95657456e-01,
                          9.90868509e-01,  -1.17897727e-01,  -9.41761374e-01,
                          5.10551929e-01,   7.28490233e-01,  -8.14935088e-01,
                         -3.88798714e-01,   9.76866901e-01,  -1.90746747e-02,
                         -9.69155848e-01,   4.23092544e-01,   7.92207778e-01,
                         -7.53855526e-01,  -4.78084415e-01,   9.53125000e-01,
                          8.01542178e-02,  -9.86810088e-01,   3.31371754e-01,
                          8.48214269e-01,  -6.85470760e-01,  -5.62500000e-01,
                          9.19845760e-01,   1.78368509e-01,  -9.94521081e-01,
                          2.36201301e-01,   8.95698071e-01,  -6.10186696e-01,
                         -6.41436696e-01,   8.77435088e-01,   2.74959415e-01,
                         -9.92491901e-01,   1.38798699e-01,   9.34253275e-01,
                         -5.28814912e-01,  -7.13879883e-01,   8.26501608e-01,
                          3.68709415e-01,  -9.80519474e-01,   4.01785709e-02,
                          9.63474035e-01,  -4.42370117e-01,  -7.79220760e-01,
                          7.67248392e-01,   4.58806813e-01,  -9.58806813e-01,
                         -5.90503253e-02,   9.83157456e-01,  -3.51461053e-01,
                         -8.36850643e-01,   7.00284064e-01,   5.44439912e-01,
                         -9.27759767e-01,  -1.57670453e-01,   9.93100643e-01,
                         -2.57102281e-01,  -8.86160731e-01,   6.26420438e-01,
                          6.24594152e-01,  -8.87378275e-01,  -2.54667222e-01,
                          9.93303597e-01,  -1.60105526e-01,  -9.26745117e-01,
                          5.46469152e-01,   6.98457778e-01,  -8.38068187e-01,
                         -3.49025965e-01,   9.83563304e-01,  -6.14853911e-02,
                         -9.57995117e-01,   4.61038947e-01,   7.65422106e-01,
                         -7.80641258e-01,  -4.39935058e-01,   9.63879883e-01,
                          3.75405848e-02,  -9.79910731e-01,   3.70941550e-01,
                          8.24878275e-01,  -7.15300322e-01,  -5.26582778e-01,
                          9.34862018e-01,   1.36363640e-01,  -9.91883099e-01,
                          2.77394474e-01,   8.76014590e-01,  -6.43060088e-01,
                         -6.07954562e-01,   8.96509767e-01,   2.33563319e-01,
                         -9.94115233e-01,   1.81006491e-01,   9.18425322e-01,
                         -5.64326286e-01,  -6.83238626e-01,   8.49228919e-01,
                          3.28733772e-01,  -9.86607134e-01,   8.27922076e-02,
                          9.51704562e-01,  -4.80113626e-01,  -7.51826286e-01,
                          7.93425322e-01,   4.20454532e-01,  -9.69155848e-01,
                         -1.62337665e-02,   9.75649357e-01,  -3.91030848e-01,
                         -8.12905848e-01,   7.29910731e-01,   5.08116901e-01,
                         -9.42167222e-01,  -1.15259737e-01,   9.89853919e-01,
                         -2.98092544e-01,  -8.65868509e-01,   6.59090936e-01,
                          5.90706170e-01,  -9.05844152e-01,  -2.12865263e-01,
                          9.94318187e-01,  -2.02110395e-01,  -9.10308421e-01,
                          5.81777573e-01,   6.67410731e-01,  -8.60389590e-01,
                         -3.08644474e-01,   9.88839269e-01,  -1.04301944e-01,
                         -9.45616901e-01,   4.98579532e-01,   7.37418830e-01,
                         -8.06615233e-01,  -4.01176959e-01,   9.73620117e-01,
                         -5.27597405e-03,  -9.71793830e-01,   4.10511374e-01,
                          8.00121725e-01,  -7.44724035e-01,  -4.89650965e-01,
                          9.48863626e-01,   9.35470760e-02,  -9.88027573e-01,
                          3.18384737e-01,   8.55113626e-01,  -6.75324678e-01,
                         -5.73457778e-01,   9.14569795e-01,   1.91761360e-01,
                         -9.94724035e-01,   2.23011360e-01,   9.01379883e-01,
                         -5.99431813e-01,  -6.51582778e-01,   8.71144474e-01,
                          2.87946433e-01,  -9.91477251e-01,   1.25608772e-01,
                          9.38920438e-01,  -5.17451286e-01,  -7.23214269e-01,
                          8.18993509e-01,   3.81290585e-01,  -9.78287339e-01,
                          2.67857146e-02,   9.66923714e-01,  -4.30397719e-01,
                         -7.87540555e-01,   7.58928597e-01,   4.70779210e-01,
                         -9.55560088e-01,  -7.22402632e-02,   9.85592544e-01,
                         -3.39082778e-01,  -8.44155848e-01,   6.91152573e-01,
                          5.55600643e-01,  -9.23295438e-01,  -1.70657471e-01,
                          9.94318187e-01,  -2.44521111e-01,  -8.92451286e-01,
                          6.16680205e-01,   6.35146081e-01,  -8.81899357e-01,
                         -2.67248362e-01,   9.93303597e-01,  -1.47321433e-01,
                         -9.32021081e-01,   5.35917222e-01,   7.08198071e-01,
                         -8.31574678e-01,  -3.61404210e-01,   9.82345760e-01,
                         -4.87012975e-02,  -9.62256491e-01,   4.49878246e-01,
                          7.74350643e-01,  -7.73336053e-01,  -4.51907456e-01,
                          9.61647749e-01,   5.05275987e-02,  -9.82954562e-01,
                          3.59375000e-01,   8.32792222e-01,  -7.07183421e-01,
                         -5.37946403e-01,   9.31412339e-01,   1.49147734e-01,
                         -9.93912339e-01,   2.65422076e-01,   8.82913947e-01,
                         -6.33928597e-01,  -6.18709445e-01,   8.92045438e-01,
                          2.46347398e-01,  -9.94926929e-01,   1.68628246e-01,
                          9.24310088e-01,  -5.54586053e-01,  -6.93181813e-01,
                          8.43547106e-01,   3.41112018e-01,  -9.86201286e-01,
                          7.02110380e-02,   9.56777573e-01,  -4.69561696e-01,
                         -7.60957778e-01,   7.86931813e-01,   4.32426959e-01,
                         -9.67532456e-01,  -2.88149342e-02,   9.79504883e-01,
                         -3.80073041e-01,  -8.21225643e-01,   7.22402573e-01,
                          5.19480526e-01,  -9.39529240e-01,  -1.27637982e-01,
                          9.92491901e-01,  -2.86728889e-01,  -8.73173714e-01,
                          6.50771081e-01,   6.01461053e-01,  -9.01988626e-01,
                         -2.25243509e-01,   9.95738626e-01,  -1.90340906e-01,
                         -9.16599035e-01,   5.72646081e-01,   6.77556813e-01,
                         -8.55519474e-01,  -3.20616871e-01,   9.89245117e-01,
                         -9.23295468e-02,  -9.50892866e-01,   4.88839298e-01,
                          7.46753275e-01,  -8.00730526e-01,  -4.12946433e-01,
                          9.72808421e-01,   6.89935079e-03,  -9.75852251e-01,
                          4.00162339e-01,   8.08644474e-01,  -7.37824678e-01,
                         -5.01014590e-01,   9.46631491e-01,   1.05925322e-01,
                         -9.91071403e-01,   3.07426959e-01,   8.62621725e-01,
                         -6.67613626e-01,  -5.84212661e-01,   9.11120117e-01,
                          2.03936681e-01,  -9.96550322e-01,   2.11647734e-01,
                          9.07873392e-01,  -5.90706170e-01,  -6.61728919e-01,
                          8.66680205e-01,   2.99918830e-01,  -9.91883099e-01,
                          1.13839284e-01,   9.44196403e-01,  -5.08116901e-01,
                         -7.32548714e-01,   8.13514590e-01,   3.92857134e-01,
                         -9.77678597e-01,   1.48133114e-02,   9.71185088e-01,
                         -4.20251638e-01,  -7.96063304e-01,   7.52232134e-01,
                          4.81939942e-01,  -9.53530848e-01,  -8.44155848e-02,
                          9.88636374e-01,  -3.28327924e-01,  -8.51866901e-01,
                          6.83441579e-01,   5.66355526e-01,  -9.20048714e-01,
                         -1.82629868e-01,   9.96144474e-01,  -2.33157471e-01,
                         -8.98944795e-01,   6.07954562e-01,   6.45089269e-01,
                         -8.77435088e-01,  -2.79220790e-01,   9.93709445e-01,
                         -1.35551944e-01,  -9.37297106e-01,   5.26379883e-01,
                          7.17532456e-01,  -8.25892866e-01,  -3.72970790e-01,
                          9.81331170e-01,  -3.67288962e-02,  -9.66314912e-01,
                          4.39732134e-01,   7.82670438e-01,  -7.66436696e-01,
                         -4.63068187e-01,   9.59415555e-01,   6.25000000e-02,
                         -9.85592544e-01,   3.48417222e-01,   8.40097427e-01,
                         -6.99269474e-01,  -5.48498392e-01,   9.27759767e-01,
                          1.61120132e-01,  -9.95332778e-01,   2.53855526e-01,
                          8.89204562e-01,  -6.25000000e-01,  -6.28652573e-01,
                          8.86972427e-01,   2.58319795e-01,  -9.94926929e-01,
                          1.56655848e-01,   9.29383099e-01,  -5.44642866e-01,
                         -7.02313304e-01,   8.37459445e-01,   3.52678567e-01,
                         -9.84780848e-01,   5.80357127e-02,   9.60430205e-01,
                         -4.58806813e-01,  -7.69074678e-01,   7.79423714e-01,
                          4.43587661e-01,  -9.64894474e-01,  -4.13961038e-02,
                          9.81737018e-01,  -3.68506491e-01,  -8.28327894e-01,
                          7.13879883e-01,   5.30235410e-01,  -9.35267866e-01,
                         -1.40219152e-01,   9.93506491e-01,  -2.74553567e-01,
                         -8.79058421e-01,   6.41030848e-01,   6.11404240e-01,
                         -8.96306813e-01,  -2.37621754e-01,   9.95332778e-01,
                         -1.77759737e-01,  -9.21266258e-01,   5.61891258e-01,
                          6.86485410e-01,  -8.48620117e-01,  -3.32792222e-01,
                          9.87215936e-01,  -7.93425292e-02,  -9.54342544e-01,
                          4.77272719e-01,   7.54870117e-01,  -7.92410731e-01,
                         -4.24512982e-01,   9.69155848e-01,   1.98863633e-02,
                         -9.77678597e-01,   3.87784094e-01,   8.15746725e-01,
                         -7.28287339e-01,  -5.11972427e-01,   9.41558421e-01,
                          1.18912339e-01,  -9.91477251e-01,   2.94439942e-01,
                          8.68303597e-01,  -6.57061696e-01,  -5.94561696e-01,
                          9.04626608e-01,   2.16720775e-01,  -9.95332778e-01,
                          1.98254868e-01,   9.12337661e-01,  -5.79139590e-01,
                         -6.70860410e-01,   8.58766258e-01,   3.12500000e-01,
                         -9.89245117e-01,   1.00040585e-01,   9.47240233e-01,
                         -4.95535702e-01,  -7.40665555e-01,   8.04383099e-01,
                          4.04829532e-01,  -9.73417222e-01,   1.01461040e-03,
                          9.72808421e-01,  -4.07061696e-01,  -8.03165555e-01,
                          7.41883099e-01,   4.93303567e-01,  -9.47849035e-01,
                         -9.82142836e-02,   9.88636374e-01,  -3.14529210e-01,
                         -8.57548714e-01,   6.72077894e-01,   5.76907456e-01,
                         -9.12946403e-01,  -1.96225643e-01,   9.94521081e-01,
                         -2.18952924e-01,  -9.03409064e-01,   5.95576286e-01,
                          6.54626608e-01,  -8.68912339e-01,  -2.92410702e-01,
                          9.90665555e-01,  -1.21144481e-01,  -9.40340936e-01,
                          5.13189912e-01,   7.25852251e-01,  -8.16355526e-01,
                         -3.85551959e-01,   9.76866901e-01,  -2.23214291e-02,
                         -9.67735410e-01,   4.25933450e-01,   7.89772749e-01,
                         -7.55681813e-01,  -4.74837661e-01,   9.53530848e-01,
                          7.67045468e-02,  -9.85795438e-01,   3.34212661e-01,
                          8.45982134e-01,  -6.87500000e-01,  -5.59456170e-01,
                          9.20657456e-01,   1.74918830e-01,  -9.93912339e-01,
                          2.39448056e-01,   8.93668830e-01,  -6.12621725e-01,
                         -6.38392866e-01,   8.78652573e-01,   2.71509737e-01,
                         -9.92086053e-01,   1.42248377e-01,   9.32426929e-01,
                         -5.31655848e-01,  -7.10836053e-01,   8.27922106e-01,
                          3.65259737e-01,  -9.80519474e-01,   4.36282456e-02,
                          9.62053597e-01,  -4.45413947e-01,  -7.76379883e-01,
                          7.69074678e-01,   4.55154210e-01,  -9.59415555e-01,
                         -5.51948063e-02,   9.82142866e-01,  -3.54910702e-01,
                         -8.34212661e-01,   7.02719152e-01,   5.40787339e-01,
                         -9.28571403e-01,  -1.53409094e-01,   9.92491901e-01,
                         -2.60957778e-01,  -8.83725643e-01,   6.29464269e-01,
                          6.20738626e-01,  -8.88798714e-01,  -2.50202924e-01,
                          9.92897749e-01,  -1.64569810e-01,  -9.24512982e-01,
                          5.50121725e-01,   6.94602251e-01,  -8.40300322e-01,
                         -3.44155848e-01,   9.83766258e-01,  -6.65584430e-02,
                         -9.56168830e-01,   4.65503246e-01,   7.61566579e-01,
                         -7.83685088e-01,  -4.35064942e-01,   9.64691579e-01,
                          3.24675329e-02,  -9.78490233e-01,   3.75405848e-01,
                          8.21631491e-01,  -7.18344152e-01,  -5.22321403e-01,
                          9.36079562e-01,   1.31696433e-01,  -9.91274357e-01,
                          2.81452924e-01,   8.73579562e-01,  -6.46103919e-01,
                         -6.04301929e-01,   8.97930205e-01,   2.29504868e-01,
                         -9.93912339e-01,   1.84862018e-01,   9.16599035e-01,
                         -5.67370117e-01,  -6.79991901e-01,   8.50852251e-01,
                          3.24878246e-01,  -9.86607134e-01,   8.64448026e-02,
                          9.50284064e-01,  -4.83157456e-01,  -7.48985410e-01,
                          7.95454562e-01,   4.17004883e-01,  -9.69764590e-01,
                         -1.27840908e-02,   9.74634767e-01,  -3.94277602e-01,
                         -8.10673714e-01,   7.32142866e-01,   5.04870117e-01,
                         -9.42978919e-01,  -1.11810066e-01,   9.89448071e-01,
                         -3.01339298e-01,  -8.64042222e-01,   6.61525965e-01,
                          5.87662339e-01,  -9.07061696e-01,  -2.09618509e-01,
                          9.94115233e-01,  -2.05357149e-01,  -9.08887982e-01,
                          5.84415555e-01,   6.64772749e-01,  -8.62012982e-01,
                         -3.05397719e-01,   9.89245117e-01,  -1.07548699e-01,
                         -9.44602251e-01,   5.01420438e-01,   7.35186696e-01,
                         -8.08441579e-01,  -3.98133129e-01,   9.74228919e-01,
                         -8.52272753e-03,  -9.70982134e-01,   4.13555205e-01,
                          7.98295438e-01,  -7.46753275e-01,  -4.87012982e-01,
                          9.49675322e-01,   9.05032456e-02,  -9.87824678e-01,
                          3.21428567e-01,   8.53490233e-01,  -6.77759767e-01,
                         -5.70819795e-01,   9.15787339e-01,   1.88514605e-01,
                         -9.94724035e-01,   2.26258114e-01,   9.00162339e-01,
                         -6.02069795e-01,  -6.49147749e-01,   8.72767866e-01,
                          2.84902602e-01,  -9.91883099e-01,   1.28652602e-01,
                          9.37905848e-01,  -5.20495117e-01,  -7.21185088e-01,
                          8.21022749e-01,   3.78246754e-01,  -9.79099035e-01,
                          3.00324671e-02,   9.66517866e-01,  -4.33441550e-01,
                         -7.85917222e-01,   7.61160731e-01,   4.67938304e-01,
                         -9.56777573e-01,  -6.91964254e-02,   9.85389590e-01,
                         -3.42329532e-01,  -8.42938304e-01,   6.93790555e-01,
                          5.53165555e-01,  -9.24918830e-01,  -1.67613640e-01,
                          9.94521081e-01,  -2.47767851e-01,  -8.91436696e-01,
                          6.19318187e-01,   6.32711053e-01,  -8.83725643e-01,
                         -2.64407456e-01,   9.93709445e-01,  -1.50568187e-01,
                         -9.31412339e-01,   5.38961053e-01,   7.06168830e-01,
                         -8.33806813e-01,  -3.58563304e-01,   9.83157456e-01,
                         -5.19480519e-02,  -9.61850643e-01,   4.52922076e-01,
                          7.72727251e-01,  -7.75771081e-01,  -4.49269474e-01,
                          9.62865233e-01,   4.72808443e-02,  -9.82954562e-01,
                          3.62621754e-01,   8.31371725e-01,  -7.09821403e-01,
                         -5.35511374e-01,   9.33035731e-01,   1.46103889e-01,
                         -9.94318187e-01,   2.68465906e-01,   8.81899357e-01,
                         -6.36769474e-01,  -6.16680205e-01,   8.93871725e-01,
                          2.43303567e-01,  -9.95738626e-01,   1.71672076e-01,
                          9.23701286e-01,  -5.57426929e-01,  -6.91558421e-01,
                          8.45779240e-01,   3.38271111e-01,  -9.87215936e-01,
                          7.32548684e-02,   9.56371725e-01,  -4.72605526e-01,
                         -7.59537339e-01,   7.89163947e-01,   4.29991871e-01,
                         -9.68952894e-01,  -2.59740259e-02,   9.79504883e-01,
                         -3.82913947e-01,  -8.20008099e-01,   7.24837661e-01,
                          5.17451286e-01,  -9.40949678e-01,  -1.25000000e-01,
                          9.92897749e-01,  -2.89569795e-01,  -8.72564912e-01,
                          6.53206170e-01,   5.99634767e-01,  -9.03814912e-01,
                         -2.23011360e-01,   9.96550322e-01,  -1.93181813e-01,
                         -9.16193187e-01,   5.75081170e-01,   6.75933421e-01,
                         -8.57548714e-01,  -3.18587661e-01,   9.90056813e-01,
                         -9.47646126e-02,  -9.50892866e-01,   4.91274357e-01,
                          7.45738626e-01,  -8.02556813e-01,  -4.11120117e-01,
                          9.73823071e-01,   4.46428591e-03,  -9.76055205e-01,
                          4.02394474e-01,   8.07832778e-01,  -7.39853919e-01,
                         -4.99594152e-01,   9.47849035e-01,   1.03693180e-01,
                         -9.91477251e-01,   3.09659094e-01,   8.62012982e-01,
                         -6.69642866e-01,  -5.82995117e-01,   9.12540555e-01,
                          2.02110395e-01,  -9.97159064e-01,   2.13676944e-01,
                          9.07670438e-01,  -5.92735410e-01,  -6.60714269e-01,
                          8.67897749e-01,   2.98295468e-01,  -9.92694795e-01,
                          1.15665585e-01,   9.44196403e-01,  -5.09740233e-01,
                         -7.31939912e-01,   8.14935088e-01,   3.91639620e-01,
                         -9.78490233e-01,   1.64366886e-02,   9.71387982e-01,
                         -4.21875000e-01,  -7.95657456e-01,   7.53652573e-01,
                          4.80925322e-01,  -9.54545438e-01,  -8.29951316e-02,
                          9.88839269e-01,  -3.29748362e-01,  -8.51663947e-01,
                          6.84862018e-01,   5.65543830e-01,  -9.21063304e-01,
                         -1.81615263e-01,   9.96550322e-01,  -2.34375000e-01,
                         -8.98944795e-01,   6.09172106e-01,   6.44480526e-01,
                         -8.78449678e-01,  -2.78409094e-01,   9.94115233e-01,
                         -1.36769474e-01,  -9.37500000e-01,   5.27394474e-01,
                          7.17126608e-01,  -8.26907456e-01,  -3.72362018e-01,
                          9.81939912e-01,  -3.75405848e-02,  -9.66517866e-01,
                          4.40543830e-01,   7.82467544e-01,  -7.67248392e-01,
                         -4.62662339e-01,   9.60024357e-01,   6.18912354e-02,
                         -9.86201286e-01,   3.49228889e-01,   8.40097427e-01,
                         -7.00081170e-01,  -5.48295438e-01,   9.28368509e-01,
                          1.60714284e-01,  -9.95738626e-01,   2.54464298e-01,
                          8.89204562e-01,  -6.25811696e-01,  -6.28449678e-01,
                          8.87581170e-01,   2.57913947e-01,  -9.95535731e-01,
                          1.57061681e-01,   9.29586053e-01,  -5.45251608e-01,
                         -7.02516258e-01,   8.38068187e-01,   3.52475643e-01,
                         -9.85389590e-01,   5.82386367e-02,   9.60633099e-01,
                         -4.59415585e-01,  -7.69277573e-01,   7.80032456e-01,
                          4.43587661e-01,  -9.65503275e-01,  -4.11931835e-02,
                          9.82142866e-01,  -3.68912339e-01,  -8.28530848e-01,
                          7.14285731e-01,   5.30235410e-01,  -9.35876608e-01,
                         -1.40219152e-01,   9.93912339e-01,  -2.74756491e-01,
                         -8.79667222e-01,   6.41436696e-01,   6.11607134e-01,
                         -8.96915555e-01,  -2.37824678e-01,   9.95738626e-01,
                         -1.77962661e-01,  -9.21875000e-01,   5.62297106e-01,
                          6.86891258e-01,  -8.49228919e-01,  -3.32995117e-01,
                          9.87621725e-01,  -7.95454532e-02,  -9.54951286e-01,
                          4.77475643e-01,   7.55275965e-01,  -7.93019474e-01,
                         -4.24715906e-01,   9.69764590e-01,   1.98863633e-02,
                         -9.78490233e-01,   3.87987018e-01,   8.16152573e-01,
                         -7.28896081e-01,  -5.12378275e-01,   9.42370117e-01,
                          1.18912339e-01,  -9.92288947e-01,   2.94642866e-01,
                          8.68912339e-01,  -6.57467544e-01,  -5.94967544e-01,
                          9.05438304e-01,   2.16923699e-01,  -9.96144474e-01,
                          1.98457792e-01,   9.12946403e-01,  -5.79545438e-01,
                         -6.71469152e-01,   8.59375000e-01,   3.12702924e-01,
                         -9.90259767e-01,   1.00243509e-01,   9.48051929e-01,
                         -4.95941550e-01,  -7.41477251e-01,   8.04991901e-01,
                          4.05235380e-01,  -9.74431813e-01,   1.01461040e-03,
                          9.73620117e-01,  -4.07467544e-01,  -8.03977251e-01,
                          7.42694795e-01,   4.93709415e-01,  -9.48863626e-01,
                         -9.82142836e-02,   9.89448071e-01,  -3.14935058e-01,
                         -8.58360410e-01,   6.72889590e-01,   5.77313304e-01,
                         -9.13961053e-01,  -1.96428567e-01,   9.95535731e-01,
                         -2.19358772e-01,  -9.04423714e-01,   5.96387982e-01,
                          6.55235410e-01,  -8.69926929e-01,  -2.92613626e-01,
                          9.91883099e-01,  -1.21550322e-01,  -9.41355526e-01,
                          5.14001608e-01,   7.26663947e-01,  -8.17370117e-01,
                         -3.85957778e-01,   9.78084445e-01,  -2.25243513e-02,
                         -9.68952894e-01,   4.26339298e-01,   7.90787339e-01,
                         -7.56696403e-01,  -4.75446433e-01,   9.54748392e-01,
                          7.69074708e-02,  -9.87012982e-01,   3.34618509e-01,
                          8.47199678e-01,  -6.88514590e-01,  -5.60267866e-01,
                          9.21875000e-01,   1.75324678e-01,  -9.95332778e-01,
                          2.39650980e-01,   8.94886374e-01,  -6.13433421e-01,
                         -6.39407456e-01,   8.79870117e-01,   2.72118509e-01,
                         -9.93506491e-01,   1.42248377e-01,   9.34050322e-01,
                         -5.32264590e-01,  -7.12256491e-01,   8.28936696e-01,
                          3.66071433e-01,  -9.82142866e-01,   4.34253253e-02,
                          9.63676929e-01,  -4.45616871e-01,  -7.78003275e-01,
                          7.70089269e-01,   4.56371754e-01,  -9.60836053e-01,
                         -5.60064949e-02,   9.83766258e-01,  -3.54910702e-01,
                         -8.36038947e-01,   7.03327894e-01,   5.42410731e-01,
                         -9.29788947e-01,  -1.54626623e-01,   9.94115233e-01,
                         -2.60349035e-01,  -8.85754883e-01,   6.29667222e-01,
                          6.22767866e-01,  -8.89813304e-01,  -2.51826286e-01,
                          9.94521081e-01,  -1.63352266e-01,  -9.26745117e-01,
                          5.49715936e-01,   6.97037339e-01,  -8.40909064e-01,
                         -3.46590906e-01,   9.85186696e-01,  -6.47321418e-02,
                         -9.58400965e-01,   4.64285702e-01,   7.64407456e-01,
                         -7.83482134e-01,  -4.37905848e-01,   9.65909064e-01,
                          3.44967544e-02,  -9.80722427e-01,   3.74188304e-01,
                          8.24269474e-01,  -7.18344152e-01,  -5.24756491e-01,
                          9.37094152e-01,   1.33522734e-01,  -9.93100643e-01,
                          2.80438304e-01,   8.75811696e-01,  -6.46103919e-01,
                         -6.06534064e-01,   8.98944795e-01,   2.31128246e-01,
                         -9.95738626e-01,   1.83847398e-01,   9.18628275e-01,
                         -5.67573071e-01,  -6.82224035e-01,   8.51866901e-01,
                          3.26501638e-01,  -9.88230526e-01,   8.56331140e-02,
                          9.52313304e-01,  -4.83157456e-01,  -7.51014590e-01,
                          7.96266258e-01,   4.18628246e-01,  -9.71185088e-01,
                         -1.37987016e-02,   9.76663947e-01,  -3.94074678e-01,
                         -8.12500000e-01,   7.32751608e-01,   5.06493509e-01,
                         -9.44399357e-01,  -1.12824678e-01,   9.91071403e-01,
                         -3.00933450e-01,  -8.65868509e-01,   6.61931813e-01,
                          5.89488626e-01,  -9.08076286e-01,  -2.10836038e-01,
                          9.95738626e-01,  -2.04951301e-01,  -9.10511374e-01,
                          5.84415555e-01,   6.66396081e-01,  -8.62824678e-01,
                         -3.06818187e-01,   9.90462661e-01,  -1.06737010e-01,
                         -9.46225643e-01,   5.01217544e-01,   7.36810088e-01,
                         -8.09050322e-01,  -3.99553567e-01,   9.75446403e-01,
                         -7.50811677e-03,  -9.72605526e-01,   4.12946433e-01,
                          7.99918830e-01,  -7.46956170e-01,  -4.88433450e-01,
                          9.50689912e-01,   9.17207822e-02,  -9.89042222e-01,
                          3.20819795e-01,   8.55113626e-01,  -6.77759767e-01,
                         -5.72646081e-01,   9.16396081e-01,   1.89935058e-01,
                         -9.95941579e-01,   2.25243509e-01,   9.01582778e-01,
                         -6.01663947e-01,  -6.50974035e-01,   8.72970760e-01,
                          2.86525965e-01,  -9.92694795e-01,   1.27435058e-01,
                          9.39326286e-01,  -5.19480526e-01,  -7.22808421e-01,
                          8.20819795e-01,   3.80073041e-01,  -9.79707778e-01,
                          2.84090918e-02,   9.67532456e-01,  -4.32426959e-01,
                         -7.87337661e-01,   7.60551929e-01,   4.69764620e-01,
                         -9.56777573e-01,  -7.08198026e-02,   9.86201286e-01,
                         -3.40909094e-01,  -8.44155848e-01,   6.92775965e-01,
                          5.54991901e-01,  -9.24512982e-01,  -1.69439942e-01,
                          9.94926929e-01,  -2.45941564e-01,  -8.92654240e-01,
                          6.18100643e-01,   6.34537339e-01,  -8.83116901e-01,
                         -2.66233772e-01,   9.93912339e-01,  -1.48538962e-01,
                         -9.32224035e-01,   5.37337661e-01,   7.07792222e-01,
                         -8.32792222e-01,  -3.60592544e-01,   9.82954562e-01,
                         -4.99188304e-02,  -9.62459445e-01,   4.51095790e-01,
                          7.73944795e-01,  -7.74147749e-01,  -4.51095790e-01,
                          9.62256491e-01,   4.95129861e-02,  -9.83157456e-01,
                          3.60389620e-01,   8.32386374e-01,  -7.07995117e-01,
                         -5.37337661e-01,   9.32021081e-01,   1.48133114e-01,
                         -9.93912339e-01,   2.66233772e-01,   8.82711053e-01,
                         -6.34740233e-01,  -6.18100643e-01,   8.92451286e-01,
                          2.45535716e-01,  -9.95129883e-01,   1.69439942e-01,
                          9.24107134e-01,  -5.55194795e-01,  -6.92775965e-01,
                          8.43952894e-01,   3.40300322e-01,  -9.86201286e-01,
                          7.08198026e-02,   9.56371725e-01,  -4.70170468e-01,
                         -7.60551929e-01,   7.87134767e-01,   4.31818187e-01,
                         -9.67532456e-01,  -2.84090918e-02,   9.79099035e-01,
                         -3.80478889e-01,  -8.20616901e-01,   7.22605526e-01,
                          5.18871725e-01,  -9.39326286e-01,  -1.27232149e-01,
                          9.92288947e-01,  -2.86931813e-01,  -8.72767866e-01,
                          6.50771081e-01,   6.00852251e-01,  -9.01785731e-01,
                         -2.24837661e-01,   9.95332778e-01,  -1.90746754e-01,
                         -9.15990233e-01,   5.72646081e-01,   6.76948071e-01,
                         -8.55316579e-01,  -3.20211053e-01,   9.88636374e-01,
                         -9.25324708e-02,  -9.50284064e-01,   4.88839298e-01,
                          7.46144474e-01,  -8.00324678e-01,  -4.12540585e-01,
                          9.72199678e-01,   6.69642864e-03,  -9.75243509e-01,
                          3.99959415e-01,   8.08035731e-01,  -7.37418830e-01,
                         -5.00608742e-01,   9.46022749e-01,   1.05722405e-01,
                         -9.90462661e-01,   3.07224035e-01,   8.62012982e-01,
                         -6.67207778e-01,  -5.83806813e-01,   9.10511374e-01,
                          2.03733772e-01,  -9.95738626e-01,   2.11647734e-01,
                          9.07264590e-01,  -5.90300322e-01,  -6.61120117e-01,
                          8.66071403e-01,   2.99715906e-01,  -9.91274357e-01,
                          1.13636367e-01,   9.43587661e-01,  -5.07711053e-01,
                         -7.31939912e-01,   8.12905848e-01,   3.92654210e-01,
                         -9.76866901e-01,   1.46103892e-02,   9.70576286e-01,
                         -4.19845790e-01,  -7.95657456e-01,   7.51623392e-01,
                          4.81737018e-01,  -9.52922106e-01,  -8.44155848e-02,
                          9.87824678e-01,  -3.27922076e-01,  -8.51258099e-01,
                          6.82832778e-01,   5.66152573e-01,  -9.19439912e-01,
                         -1.82832792e-01,   9.95332778e-01,  -2.32751623e-01,
                         -8.98538947e-01,   6.07548714e-01,   6.44886374e-01,
                         -8.76826286e-01,  -2.79220790e-01,   9.93100643e-01,
                         -1.35349020e-01,  -9.36891258e-01,   5.25974035e-01,
                          7.17126608e-01,  -8.25487018e-01,  -3.72970790e-01,
                          9.80925322e-01,  -3.63230519e-02,  -9.65909064e-01,
                          4.39123362e-01,   7.82467544e-01,  -7.65827894e-01,
                         -4.63068187e-01,   9.59009767e-01,   6.29058406e-02,
                         -9.85389590e-01,   3.48011374e-01,   8.39894474e-01,
                         -6.98863626e-01,  -5.48701286e-01,   9.27556813e-01,
                          1.61525980e-01,  -9.95129883e-01,   2.53449678e-01,
                          8.89001608e-01,  -6.24594152e-01,  -6.28652573e-01,
                          8.86769474e-01,   2.58522719e-01,  -9.94926929e-01,
                          1.56452924e-01,   9.29383099e-01,  -5.44439912e-01,
                         -7.02516258e-01,   8.37256491e-01,   3.53084415e-01,
                         -9.84780848e-01,   5.76298684e-02,   9.60430205e-01,
                         -4.58603889e-01,  -7.69480526e-01,   7.79423714e-01,
                          4.43993509e-01,  -9.64894474e-01,  -4.15990278e-02,
                          9.82142866e-01,  -3.68303567e-01,  -8.28733742e-01,
                          7.13879883e-01,   5.30641258e-01,  -9.35470760e-01,
                         -1.40625000e-01,   9.93912339e-01,  -2.74350643e-01,
                         -8.79667222e-01,   6.41030848e-01,   6.12012982e-01,
                         -8.96712661e-01,  -2.38027602e-01,   9.95738626e-01,
                         -1.77556813e-01,  -9.21875000e-01,   5.62094152e-01,
                          6.87297106e-01,  -8.49025965e-01,  -3.33198041e-01,
                          9.87824678e-01,  -7.91396126e-02,  -9.55154240e-01,
                          4.77272719e-01,   7.55681813e-01,  -7.92816579e-01,
                         -4.25121754e-01,   9.69967544e-01,   2.02922076e-02,
                         -9.78693187e-01,   3.87784094e-01,   8.16761374e-01,
                         -7.28896081e-01,  -5.12784064e-01,   9.42573071e-01,
                          1.19521104e-01,  -9.92694795e-01,   2.94439942e-01,
                          8.69521081e-01,  -6.57467544e-01,  -5.95576286e-01,
                          9.05844152e-01,   2.17329547e-01,  -9.96753275e-01,
                          1.98254868e-01,   9.13758099e-01,  -5.79545438e-01,
                         -6.72077894e-01,   8.59780848e-01,   3.13311696e-01,
                         -9.90665555e-01,   9.98376608e-02,   9.48863626e-01,
                         -4.95941550e-01,  -7.42086053e-01,   8.05397749e-01,
                          4.05844152e-01,  -9.75040555e-01,   6.08766219e-04,
                          9.74431813e-01,  -4.07467544e-01,  -8.04788947e-01,
                          7.42897749e-01,   4.94724035e-01,  -9.49472427e-01,
                         -9.86201316e-02,   9.90462661e-01,  -3.14732134e-01,
                         -8.59375000e-01,   6.73092544e-01,   5.78327894e-01,
                         -9.14569795e-01,  -1.97037339e-01,   9.96550322e-01,
                         -2.18952924e-01,  -9.05438304e-01,   5.96387982e-01,
                          6.56452894e-01,  -8.70535731e-01,  -2.93425322e-01,
                          9.92694795e-01,  -1.20941557e-01,  -9.42573071e-01,
                          5.14001608e-01,   7.27881491e-01,  -8.17775965e-01,
                         -3.86972398e-01,   9.79099035e-01,  -2.17126627e-02,
                         -9.70170438e-01,   4.26339298e-01,   7.92004883e-01,
                         -7.56899357e-01,  -4.76461053e-01,   9.55560088e-01,
                          7.77191594e-02,  -9.88230526e-01,   3.34415585e-01,
                          8.48417222e-01,  -6.88514590e-01,  -5.61282456e-01,
                          9.22483742e-01,   1.76136360e-01,  -9.96347427e-01,
                          2.39245132e-01,   8.96306813e-01,  -6.13433421e-01,
                         -6.40625000e-01,   8.80478919e-01,   2.73133129e-01,
                         -9.94521081e-01,   1.41639605e-01,   9.35267866e-01,
                         -5.32061696e-01,  -7.13474035e-01,   8.29342544e-01,
                          3.67086053e-01,  -9.82751608e-01,   4.26136367e-02,
                          9.64894474e-01,  -4.45413947e-01,  -7.79220760e-01,
                          7.70292222e-01,   4.57589298e-01,  -9.61444795e-01,
                         -5.68181835e-02,   9.84780848e-01,  -3.54301959e-01,
                         -8.37053597e-01,   7.03327894e-01,   5.43425322e-01,
                         -9.30397749e-01,  -1.55438319e-01,   9.94926929e-01,
                         -2.59740263e-01,  -8.86769474e-01,   6.29464269e-01,
                          6.23985410e-01,  -8.90016258e-01,  -2.52840906e-01,
                          9.95332778e-01,  -1.62743509e-01,  -9.27556813e-01,
                          5.49512982e-01,   6.98051929e-01,  -8.40909064e-01,
                         -3.47605526e-01,   9.85592544e-01,  -6.39204532e-02,
                         -9.59212661e-01,   4.63879883e-01,   7.65422106e-01,
                         -7.83482134e-01,  -4.38717544e-01,   9.66314912e-01,
                          3.55113633e-02,  -9.81331170e-01,   3.73782456e-01,
                          8.25081170e-01,  -7.18141258e-01,  -5.25771081e-01,
                          9.37297106e-01,   1.34334415e-01,  -9.93506491e-01,
                          2.79829532e-01,   8.76623392e-01,  -6.45698071e-01,
                         -6.07345760e-01,   8.98944795e-01,   2.31939942e-01,
                         -9.95941579e-01,   1.83238640e-01,   9.19237018e-01,
                         -5.66964269e-01,  -6.82832778e-01,   8.51663947e-01,
                          3.27313304e-01,  -9.88433421e-01,   8.48214254e-02,
                          9.52922106e-01,  -4.82751638e-01,  -7.51623392e-01,
                          7.96063304e-01,   4.19237018e-01,  -9.71185088e-01,
                         -1.44074671e-02,   9.77069795e-01,  -3.93465906e-01,
                         -8.12905848e-01,   7.32548714e-01,   5.07102251e-01,
                         -9.44399357e-01,  -1.13433443e-01,   9.91274357e-01,
                         -3.00527602e-01,  -8.66274357e-01,   6.61728919e-01,
                          5.89894474e-01,  -9.08076286e-01,  -2.11241886e-01,
                          9.95941579e-01,  -2.04342529e-01,  -9.10917222e-01,
                          5.84212661e-01,   6.66801929e-01,  -8.62621725e-01,
                         -3.07224035e-01,   9.90665555e-01,  -1.06331170e-01,
                         -9.46428597e-01,   5.01014590e-01,   7.37215936e-01,
                         -8.08847427e-01,  -3.99959415e-01,   9.75446403e-01,
                         -7.30519462e-03,  -9.72605526e-01,   4.12743509e-01,
                          8.00121725e-01,  -7.46956170e-01,  -4.88839298e-01,
                          9.50487018e-01,   9.19236988e-02,  -9.89245117e-01,
                          3.20616871e-01,   8.55113626e-01,  -6.77556813e-01,
                         -5.72849035e-01,   9.16396081e-01,   1.90137982e-01,
                         -9.95941579e-01,   2.25040585e-01,   9.01785731e-01,
                         -6.01461053e-01,  -6.50974035e-01,   8.72970760e-01,
                          2.86728889e-01,  -9.92694795e-01,   1.27232149e-01,
                          9.39529240e-01,  -5.19480526e-01,  -7.23011374e-01,
                          8.20819795e-01,   3.80275965e-01,  -9.79707778e-01,
                          2.84090918e-02,   9.67735410e-01,  -4.32426959e-01,
                         -7.87540555e-01,   7.60754883e-01,   4.69967544e-01,
                         -9.56980526e-01,  -7.10227266e-02,   9.86404240e-01,
                         -3.40909094e-01,  -8.44561696e-01,   6.92978919e-01,
                          5.55194795e-01,  -9.24715936e-01,  -1.69642851e-01,
                          9.95332778e-01,  -2.45941564e-01,  -8.92857134e-01,
                          6.18303597e-01,   6.34740233e-01,  -8.83319795e-01,
                         -2.66436696e-01,   9.94318187e-01,  -1.48538962e-01,
                         -9.32426929e-01,   5.37337661e-01,   7.07995117e-01,
                         -8.32995117e-01,  -3.60795468e-01,   9.83157456e-01,
                         -4.97159101e-02,  -9.62662339e-01,   4.50892866e-01,
                          7.74350643e-01,  -7.74147749e-01,  -4.51501638e-01,
                          9.62256491e-01,   4.99188304e-02,  -9.83360410e-01,
                          3.59983772e-01,   8.32995117e-01,  -7.07589269e-01,
                         -5.37946403e-01,   9.31818187e-01,   1.49147734e-01,
                         -9.94115233e-01,   2.65219152e-01,   8.83116901e-01,
                         -6.33928597e-01,  -6.19115233e-01,   8.91842544e-01,
                          2.46347398e-01,  -9.94926929e-01,   1.68628246e-01,
                          9.24310088e-01,  -5.54586053e-01,  -6.92978919e-01,
                          8.43547106e-01,   3.40706170e-01,  -9.85998392e-01,
                          7.04139620e-02,   9.56371725e-01,  -4.69764620e-01,
                         -7.60551929e-01,   7.86931813e-01,   4.31818187e-01,
                         -9.67329562e-01,  -2.84090918e-02,   9.78896081e-01,
                         -3.80275965e-01,  -8.20413947e-01,   7.22402573e-01,
                          5.18871725e-01,  -9.39123392e-01,  -1.27232149e-01,
                          9.91883099e-01,  -2.86931813e-01,  -8.72564912e-01,
                          6.50771081e-01,   6.00649357e-01,  -9.01582778e-01,
                         -2.24837661e-01,   9.95129883e-01,  -1.90746754e-01,
                         -9.15990233e-01,   5.72646081e-01,   6.76745117e-01,
                         -8.55316579e-01,  -3.20211053e-01,   9.88636374e-01,
                         -9.25324708e-02,  -9.50284064e-01,   4.88636374e-01,
                          7.46144474e-01,  -8.00324678e-01,  -4.12540585e-01,
                          9.72199678e-01,   6.69642864e-03,  -9.75243509e-01,
                          3.99959415e-01,   8.08035731e-01,  -7.37418830e-01,
                         -5.00811696e-01,   9.46225643e-01,   1.05722405e-01,
                         -9.90665555e-01,   3.07224035e-01,   8.62012982e-01,
                         -6.67207778e-01,  -5.84009767e-01,   9.10714269e-01,
                          2.03733772e-01,  -9.95941579e-01,   2.11444810e-01,
                          9.07467544e-01,  -5.90503275e-01,  -6.61525965e-01,
                          8.66274357e-01,   2.99918830e-01,  -9.91680205e-01,
                          1.13636367e-01,   9.43993509e-01,  -5.07711053e-01,
                         -7.32345760e-01,   8.13108742e-01,   3.92857134e-01,
                         -9.77272749e-01,   1.46103892e-02,   9.70982134e-01,
                         -4.19845790e-01,  -7.96063304e-01,   7.51826286e-01,
                          4.82142866e-01,  -9.53125000e-01,  -8.48214254e-02,
                          9.88230526e-01,  -3.27922076e-01,  -8.51866901e-01,
                          6.83035731e-01,   5.66558421e-01,  -9.19642866e-01,
                         -1.83238640e-01,   9.95738626e-01,  -2.32548699e-01,
                         -8.99147749e-01,   6.07345760e-01,   6.45495117e-01,
                         -8.77029240e-01,  -2.79829532e-01,   9.93506491e-01,
                         -1.34943187e-01,  -9.37500000e-01,   5.25771081e-01,
                          7.17938304e-01,  -8.25487018e-01,  -3.73782456e-01,
                          9.81128275e-01,  -3.59172076e-02,  -9.66517866e-01,
                          4.38717544e-01,   7.83076286e-01,  -7.65827894e-01,
                         -4.63879883e-01,   9.59009767e-01,   6.35146126e-02,
                         -9.85998392e-01,   3.47402602e-01,   8.40706170e-01,
                         -6.98457778e-01,  -5.49512982e-01,   9.27556813e-01,
                          1.62337661e-01,  -9.95535731e-01,   2.52840906e-01,
                          8.89813304e-01,  -6.24391258e-01,  -6.29667222e-01,
                          8.86769474e-01,   2.59537339e-01,  -9.95332778e-01,
                          1.55438319e-01,   9.30194795e-01,  -5.43831170e-01,
                         -7.03530848e-01,   8.37053597e-01,   3.53896111e-01,
                         -9.84983742e-01,   5.66152595e-02,   9.61038947e-01,
                         -4.57995117e-01,  -7.70292222e-01,   7.79017866e-01,
                          4.45008129e-01,  -9.65097427e-01,  -4.26136367e-02,
                          9.82548714e-01,  -3.67491871e-01,  -8.29545438e-01,
                          7.13271081e-01,   5.31655848e-01,  -9.35470760e-01,
                         -1.41639605e-01,   9.94318187e-01,  -2.73538947e-01,
                         -8.80478919e-01,   6.40422106e-01,   6.12824678e-01,
                         -8.96509767e-01,  -2.39245132e-01,   9.95941579e-01,
                         -1.76745132e-01,  -9.22483742e-01,   5.61282456e-01,
                          6.88108742e-01,  -8.48620117e-01,  -3.34415585e-01,
                          9.87824678e-01,  -7.81250000e-02,  -9.55560088e-01,
                          4.76461053e-01,   7.56493509e-01,  -7.92410731e-01,
                         -4.26136374e-01,   9.69764590e-01,   2.13068184e-02,
                         -9.79099035e-01,   3.86769474e-01,   8.17370117e-01,
                         -7.28084445e-01,  -5.13798714e-01,   9.42167222e-01,
                          1.20332792e-01,  -9.92694795e-01,   2.93425322e-01,
                          8.69926929e-01,  -6.56655848e-01,  -5.96387982e-01,
                          9.05235410e-01,   2.18344152e-01,  -9.96550322e-01,
                          1.97037339e-01,   9.14163947e-01,  -5.78733742e-01,
                         -6.72889590e-01,   8.59172106e-01,   3.14123362e-01,
                         -9.90665555e-01,   9.88230556e-02,   9.49066579e-01,
                         -4.95129883e-01,  -7.42897749e-01,   8.04586053e-01,
                          4.06858772e-01,  -9.74634767e-01,  -4.05844155e-04,
                          9.74634767e-01,  -4.06452924e-01,  -8.05397749e-01,
                          7.42086053e-01,   4.95332778e-01,  -9.49066579e-01,
                         -9.96347368e-02,   9.90462661e-01,  -3.13920468e-01,
                         -8.59780848e-01,   6.72280848e-01,   5.78936696e-01,
                         -9.14163947e-01,  -1.98051944e-01,   9.96347427e-01,
                         -2.18141228e-01,  -9.05844152e-01,   5.95576286e-01,
                          6.56858742e-01,  -8.70129883e-01,  -2.94237018e-01,
                          9.92491901e-01,  -1.20129868e-01,  -9.42775965e-01,
                          5.13189912e-01,   7.28287339e-01,  -8.17370117e-01,
                         -3.87581170e-01,   9.78693187e-01,  -2.11038962e-02,
                         -9.70170438e-01,   4.25527602e-01,   7.92410731e-01,
                         -7.56493509e-01,  -4.77069795e-01,   9.55154240e-01,
                          7.81250000e-02,  -9.88230526e-01,   3.33806813e-01,
                          8.48620117e-01,  -6.88108742e-01,  -5.61891258e-01,
                          9.22077894e-01,   1.76745132e-01,  -9.96144474e-01,
                          2.38636360e-01,   8.96306813e-01,  -6.12824678e-01,
                         -6.41030848e-01,   8.80073071e-01,   2.73538947e-01,
                         -9.94318187e-01,   1.41030848e-01,   9.35267866e-01,
                         -5.31655848e-01,  -7.13676929e-01,   8.29139590e-01,
                          3.67491871e-01,  -9.82751608e-01,   4.22077924e-02,
                          9.64894474e-01,  -4.45008129e-01,  -7.79423714e-01,
                          7.69886374e-01,   4.57995117e-01,  -9.61241901e-01,
                         -5.72240278e-02,   9.84780848e-01,  -3.54099035e-01,
                         -8.37459445e-01,   7.03125000e-01,   5.43831170e-01,
                         -9.30397749e-01,  -1.55844152e-01,   9.95129883e-01,
                         -2.59537339e-01,  -8.87175322e-01,   6.29261374e-01,
                          6.24188304e-01,  -8.90016258e-01,  -2.53043830e-01,
                          9.95332778e-01,  -1.62540585e-01,  -9.27962661e-01,
                          5.49310088e-01,   6.98457778e-01,  -8.41112018e-01,
                         -3.47808450e-01,   9.85795438e-01,  -6.37175292e-02,
                         -9.59618509e-01,   4.63879883e-01,   7.65625000e-01,
                         -7.83685088e-01,  -4.39123362e-01,   9.66517866e-01,
                          3.55113633e-02,  -9.81534064e-01,   3.73782456e-01,
                          8.25284064e-01,  -7.18344152e-01,  -5.25974035e-01,
                          9.37500000e-01,   1.34537339e-01,  -9.93912339e-01,
                          2.79829532e-01,   8.76826286e-01,  -6.46103919e-01,
                         -6.07548714e-01,   8.99350643e-01,   2.32142851e-01,
                         -9.96347427e-01,   1.83238640e-01,   9.19642866e-01,
                         -5.67370117e-01,  -6.83238626e-01,   8.52069795e-01,
                          3.27313304e-01,  -9.89042222e-01,   8.48214254e-02,
                          9.53125000e-01,  -4.82954532e-01,  -7.52029240e-01,
                          7.96469152e-01,   4.19439942e-01,  -9.71793830e-01,
                         -1.44074671e-02,   9.77475643e-01,  -3.93668830e-01,
                         -8.13514590e-01,   7.32751608e-01,   5.07305205e-01,
                         -9.44805205e-01,  -1.13433443e-01,   9.91883099e-01,
                         -3.00527602e-01,  -8.66680205e-01,   6.61931813e-01,
                          5.90300322e-01,  -9.08482134e-01,  -2.11444810e-01,
                          9.96550322e-01,  -2.04545453e-01,  -9.11525965e-01,
                          5.84618509e-01,   6.67410731e-01,  -8.63230526e-01,
                         -3.07426959e-01,   9.91274357e-01,  -1.06331170e-01,
                         -9.47240233e-01,   5.01217544e-01,   7.37621725e-01,
                         -8.09456170e-01,  -4.00365263e-01,   9.76055205e-01,
                         -7.30519462e-03,  -9.73417222e-01,   4.13149357e-01,
                          8.00730526e-01,  -7.47564912e-01,  -4.89245117e-01,
                          9.51298714e-01,   9.19236988e-02,  -9.90056813e-01,
                          3.20819795e-01,   8.55925322e-01,  -6.78165555e-01,
                         -5.73254883e-01,   9.17004883e-01,   1.90340906e-01,
                         -9.96753275e-01,   2.25243509e-01,   9.02394474e-01,
                         -6.02069795e-01,  -6.51582778e-01,   8.73782456e-01,
                          2.86728889e-01,  -9.93709445e-01,   1.27637982e-01,
                          9.40137982e-01,  -5.20089269e-01,  -7.23417222e-01,
                          8.21631491e-01,   3.80275965e-01,  -9.80519474e-01,
                          2.86120139e-02,   9.68344152e-01,  -4.32832778e-01,
                         -7.88149357e-01,   7.61363626e-01,   4.70170468e-01,
                         -9.57792222e-01,  -7.08198026e-02,   9.87012982e-01,
                         -3.41314942e-01,  -8.44967544e-01,   6.93587661e-01,
                          5.55397749e-01,  -9.25527573e-01,  -1.69439942e-01,
                          9.95941579e-01,  -2.46347398e-01,  -8.93465936e-01,
                          6.18912339e-01,   6.34943187e-01,  -8.84131491e-01,
                         -2.66436696e-01,   9.94926929e-01,  -1.48944810e-01,
                         -9.33035731e-01,   5.38149357e-01,   7.08400965e-01,
                         -8.33806813e-01,  -3.60795468e-01,   9.84172106e-01,
                         -5.01217544e-02,  -9.63474035e-01,   4.51907456e-01,
                          7.74553597e-01,  -7.75365233e-01,  -4.51501638e-01,
                          9.63474035e-01,   4.91071418e-02,  -9.84172106e-01,
                          3.61201286e-01,   8.33198071e-01,  -7.09212661e-01,
                         -5.37743509e-01,   9.33238626e-01,   1.48133114e-01,
                         -9.95332778e-01,   2.66842544e-01,   8.83725643e-01,
                         -6.35957778e-01,  -6.18709445e-01,   8.93668830e-01,
                          2.45535716e-01,  -9.96347427e-01,   1.70048699e-01,
                          9.25121725e-01,  -5.56209445e-01,  -6.93384767e-01,
                          8.45373392e-01,   3.40503246e-01,  -9.87621725e-01,
                          7.12256506e-02,   9.57589269e-01,  -4.71185058e-01,
                         -7.61363626e-01,   7.88555205e-01,   4.32021111e-01,
                         -9.68952894e-01,  -2.80032475e-02,   9.80519474e-01,
                         -3.81290585e-01,  -8.21631491e-01,   7.23823071e-01,
                          5.19480526e-01,  -9.40746725e-01,  -1.27232149e-01,
                          9.93506491e-01,  -2.87743509e-01,  -8.73782456e-01,
                          6.51988626e-01,   6.01663947e-01,  -9.03206170e-01,
                         -2.25040585e-01,   9.96956170e-01,  -1.91152602e-01,
                         -9.17410731e-01,   5.73660731e-01,   6.77759767e-01,
                         -8.56737018e-01,  -3.20616871e-01,   9.90259767e-01,
                         -9.27353874e-02,  -9.51704562e-01,   4.89650965e-01,
                          7.47159064e-01,  -8.01745117e-01,  -4.13149357e-01,
                          9.73823071e-01,   6.49350649e-03,  -9.76663947e-01,
                          4.00771111e-01,   8.09253275e-01,  -7.38636374e-01,
                         -5.01420438e-01,   9.47646081e-01,   1.05722405e-01,
                         -9.92086053e-01,   3.07832778e-01,   8.63433421e-01,
                         -6.68222427e-01,  -5.84821403e-01,   9.11931813e-01,
                          2.03936681e-01,  -9.97362018e-01,   2.11850643e-01,
                          9.08685088e-01,  -5.91314912e-01,  -6.62337661e-01,
                          8.67288947e-01,   3.00324678e-01,  -9.92897749e-01,
                          1.13839284e-01,   9.45211053e-01,  -5.08319795e-01,
                         -7.33360410e-01,   8.14123392e-01,   3.93465906e-01,
                         -9.78490233e-01,   1.46103892e-02,   9.72199678e-01,
                         -4.20454532e-01,  -7.97077894e-01,   7.52637982e-01,
                          4.82751638e-01,  -9.54342544e-01,  -8.48214254e-02,
                          9.89448071e-01,  -3.28327924e-01,  -8.52881491e-01,
                          6.83847427e-01,   5.67167222e-01,  -9.20860410e-01,
                         -1.83441564e-01,   9.96956170e-01,  -2.32954547e-01,
                         -9.00162339e-01,   6.08157456e-01,   6.46103919e-01,
                         -8.78043830e-01,  -2.80032456e-01,   9.94724035e-01,
                         -1.35146111e-01,  -9.38514590e-01,   5.26379883e-01,
                          7.18547106e-01,  -8.26501608e-01,  -3.73985380e-01,
                          9.82345760e-01,  -3.61201316e-02,  -9.67532456e-01,
                          4.39529210e-01,   7.83887982e-01,  -7.66842544e-01,
                         -4.64285702e-01,   9.60227251e-01,   6.33116886e-02,
                         -9.87012982e-01,   3.48214298e-01,   8.41517866e-01,
                         -6.99472427e-01,  -5.49918830e-01,   9.28571403e-01,
                          1.62134737e-01,  -9.96550322e-01,   2.53449678e-01,
                          8.90625000e-01,  -6.25202894e-01,  -6.30073071e-01,
                          8.87784064e-01,   2.59334415e-01,  -9.96347427e-01,
                          1.56047076e-01,   9.31006491e-01,  -5.44642866e-01,
                         -7.03936696e-01,   8.38068187e-01,   3.54099035e-01,
                         -9.86201286e-01,   5.72240278e-02,   9.62053597e-01,
                         -4.58806813e-01,  -7.70900965e-01,   7.80235410e-01,
                          4.45211053e-01,  -9.66112018e-01,  -4.22077924e-02,
                          9.83563304e-01,  -3.68303567e-01,  -8.30154240e-01,
                          7.14488626e-01,   5.31858742e-01,  -9.36485410e-01,
                         -1.41233772e-01,   9.95332778e-01,  -2.74147719e-01,
                         -8.81087661e-01,   6.41639590e-01,   6.13230526e-01,
                         -8.97727251e-01,  -2.38839284e-01,   9.97159064e-01,
                         -1.77353889e-01,  -9.23295438e-01,   5.62297106e-01,
                          6.88514590e-01,  -8.49837661e-01,  -3.34212661e-01,
                          9.89042222e-01,  -7.87337646e-02,  -9.56371725e-01,
                          4.77475643e-01,   7.56899357e-01,  -7.93628275e-01,
                         -4.26136374e-01,   9.71185088e-01,   2.06980519e-02,
                         -9.79910731e-01,   3.87987018e-01,   8.17978919e-01,
                         -7.29504883e-01,  -5.13798714e-01,   9.43587661e-01,
                          1.19926944e-01,  -9.93912339e-01,   2.94439942e-01,
                          8.70738626e-01,  -6.58076286e-01,  -5.96387982e-01,
                          9.06655848e-01,   2.17938319e-01,  -9.97767866e-01],
                          dtype = numpy.float32)
))

sounds.append(Sound(
    name = "ri13",
    rate = 41000,
    data = numpy.array([[  9.30258539e-03,   9.30258539e-03],
                        [ -1.56675128e-03,  -1.56675128e-03],
                        [ -7.39310728e-03,  -7.39310728e-03],
                        [  1.14568686e-02,   1.14568686e-02],
                        [ -7.44206831e-03,  -7.39310728e-03],
                        [ -1.90947810e-03,  -1.90947810e-03],
                        [  1.02328444e-02,   1.02328444e-02],
                        [ -1.13099851e-02,  -1.13099851e-02],
                        [  4.60233167e-03,   4.60233167e-03],
                        [  5.63051226e-03,   5.67947328e-03],
                        [ -1.21423220e-02,  -1.21423220e-02],
                        [  1.00370003e-02,   1.00370003e-02],
                        [ -1.02818047e-03,  -9.79219563e-04],
                        [ -9.00881924e-03,  -9.00881924e-03],
                        [  1.32194636e-02,   1.32194636e-02],
                        [ -7.73583399e-03,  -7.73583399e-03],
                        [ -3.13350256e-03,  -3.08454153e-03],
                        [  1.23381661e-02,   1.23871267e-02],
                        [ -1.25829708e-02,  -1.25829708e-02],
                        [  4.21064394e-03,   4.21064394e-03],
                        [  7.44206831e-03,   7.49102933e-03],
                        [ -1.40028391e-02,  -1.39538785e-02],
                        [  1.10162199e-02,   1.10162199e-02],
                        [ -2.44804891e-04,  -2.44804891e-04],
                        [ -1.15547907e-02,  -1.15547907e-02],
                        [  1.48351761e-02,   1.48841366e-02],
                        [ -8.17648321e-03,  -8.17648321e-03],
                        [ -4.74921474e-03,  -4.74921474e-03],
                        [  1.48841366e-02,   1.48841366e-02],
                        [ -1.42966053e-02,  -1.42966053e-02],
                        [  3.76999518e-03,   3.76999518e-03],
                        [  9.79219470e-03,   9.79219470e-03],
                        [ -1.69404969e-02,  -1.69404969e-02],
                        [  1.21423220e-02,   1.21912826e-02],
                        [  1.46882923e-03,   1.46882923e-03],
                        [ -1.44434879e-02,  -1.44434879e-02],
                        [  1.77728347e-02,   1.77728347e-02],
                        [ -8.47024843e-03,  -8.47024843e-03],
                        [ -7.83375651e-03,  -7.83375651e-03],
                        [  1.82134826e-02,   1.82134826e-02],
                        [ -1.65977702e-02,  -1.65977702e-02],
                        [  2.74181459e-03,   2.74181459e-03],
                        [  1.34153077e-02,   1.34153077e-02],
                        [ -2.11511422e-02,  -2.11511422e-02],
                        [  1.38069950e-02,   1.38069950e-02],
                        [  4.35752701e-03,   4.35752701e-03],
                        [ -2.04656888e-02,  -2.04656888e-02],
                        [  2.14938689e-02,   2.14938689e-02],
                        [ -8.47024843e-03,  -8.47024843e-03],
                        [ -1.31215416e-02,  -1.31215416e-02],
                        [  2.58024335e-02,   2.58024335e-02],
                        [ -1.96823124e-02,  -1.96823124e-02],
                        [  4.89609774e-05,   4.89609774e-05],
                        [  2.17876341e-02,   2.17876341e-02],
                        [ -2.93765850e-02,  -2.93765850e-02],
                        [  1.56675130e-02,   1.56675130e-02],
                        [  1.06734931e-02,   1.06734931e-02],
                        [ -3.17267105e-02,  -3.17267105e-02],
                        [  3.11881416e-02,   3.11881416e-02],
                        [ -7.34414626e-03,  -7.34414626e-03],
                        [ -2.54597068e-02,  -2.54597068e-02],
                        [  4.14699465e-02,   4.14699465e-02],
                        [ -2.91807409e-02,  -2.91807409e-02],
                        [ -6.51180977e-03,  -6.51180977e-03],
                        [  4.46034484e-02,   4.46034484e-02],
                        [ -5.11642210e-02,  -5.11642210e-02],
                        [  2.14938689e-02,   2.14938689e-02],
                        [  2.96213906e-02,   2.96213906e-02],
                        [ -7.16788694e-02,  -7.16788694e-02],
                        [  6.30127788e-02,   6.30127788e-02],
                        [ -3.28038540e-03,  -3.28038540e-03],
                        [ -7.97574297e-02,  -7.97574297e-02],
                        [  1.26221389e-01,   1.26221389e-01],
                        [ -8.06387290e-02,  -8.06387290e-02],
                        [ -6.84474409e-02,  -6.84474409e-02],
                        [  2.84805983e-01,   2.84805983e-01],
                        [ -4.87847149e-01,  -4.87847149e-01],
                        [ -9.99978960e-01,  -9.99978960e-01],
                        [  5.95855080e-02,   5.95855080e-02],
                        [  3.97122473e-01,   3.97122473e-01],
                        [ -1.75623015e-01,  -1.75623015e-01],
                        [ -2.74181459e-03,  -2.74181459e-03],
                        [  1.07909992e-01,   1.07909992e-01],
                        [ -1.12071671e-01,  -1.12071671e-01],
                        [  4.14209850e-02,   4.14209850e-02],
                        [  3.21183987e-02,   3.21183987e-02],
                        [ -7.17278272e-02,  -7.17278272e-02],
                        [  5.55217452e-02,   5.55217452e-02],
                        [ -4.21064394e-03,  -4.21064394e-03],
                        [ -3.72593030e-02,  -3.72593030e-02],
                        [  4.82265614e-02,   4.82265614e-02],
                        [ -2.86911316e-02,  -2.86911316e-02],
                        [ -9.64531209e-03,  -9.64531209e-03],
                        [  3.71124186e-02,   3.71124186e-02],
                        [ -3.44685279e-02,  -3.44685279e-02],
                        [  1.09182978e-02,   1.09182978e-02],
                        [  1.84582882e-02,   1.84582882e-02],
                        [ -3.42726819e-02,  -3.42726819e-02],
                        [  2.12001018e-02,   2.12001018e-02],
                        [  1.37090730e-03,   1.37090730e-03],
                        [ -2.28158142e-02,  -2.28158142e-02],
                        [  2.83973664e-02,   2.83973664e-02],
                        [ -1.22402441e-02,  -1.22402441e-02],
                        [ -1.33663462e-02,  -1.33663462e-02],
                        [  2.90338583e-02,   2.90338583e-02],
                        [ -1.20933615e-02,  -1.20933615e-02],
                        [ -4.11272189e-03,  -4.11272189e-03],
                        [  8.56817048e-03,   8.56817048e-03],
                        [ -1.84582882e-02,  -1.84582882e-02],
                        [  1.14568686e-02,   1.14568686e-02],
                        [  2.79077562e-03,   2.79077562e-03],
                        [ -1.60102397e-02,  -1.60102397e-02],
                        [  1.65977702e-02,   1.65977702e-02],
                        [ -4.30856599e-03,  -4.30856599e-03],
                        [ -6.51180977e-03,  -6.51180977e-03],
                        [  1.77238733e-02,   1.77238733e-02],
                        [ -1.37090730e-02,  -1.37090730e-02],
                        [ -2.35012686e-03,  -2.35012686e-03],
                        [  1.16527127e-02,   1.16527127e-02],
                        [ -1.60591993e-02,  -1.60591993e-02],
                        [  8.51920992e-03,   8.51920992e-03],
                        [  8.17648321e-03,   8.17648321e-03],
                        [ -1.58633552e-02,  -1.58633552e-02],
                        [  1.04776490e-02,   1.04776490e-02],
                        [ -5.87531715e-04,  -5.87531715e-04],
                        [ -9.20466334e-03,  -9.20466334e-03],
                        [  1.60102397e-02,   1.60102397e-02],
                        [ -6.02219999e-03,  -6.02219999e-03],
                        [ -1.02818047e-03,  -1.02818047e-03],
                        [  1.74790677e-02,   1.74790677e-02],
                        [ -2.09552981e-02,  -2.09552981e-02],
                        [ -1.48351761e-02,  -1.48351761e-02],
                        [  1.56675130e-02,   1.56675130e-02],
                        [  4.45544859e-03,   4.45544859e-03],
                        [  2.79077562e-03,   2.79077562e-03],
                        [ -4.40648803e-03,  -4.40648803e-03]],
                        dtype = numpy.float32)
))
